diff --git a/books/bookvol10.2.pamphlet b/books/bookvol10.2.pamphlet
index efb09f8..7a26d5b 100644
--- a/books/bookvol10.2.pamphlet
+++ b/books/bookvol10.2.pamphlet
@@ -7769,7 +7769,8 @@ digraph pic {
 --R cot : % -> %                          coth : % -> %
 --R csc : % -> %                          csch : % -> %
 --R dilog : % -> %                        erf : % -> %
---R exp : % -> %                          integral : (%,Symbol) -> %
+--R exp : % -> %                          fresnelC : % -> %
+--R fresnelS : % -> %                     integral : (%,Symbol) -> %
 --R li : % -> %                           log : % -> %
 --R pi : () -> %                          sec : % -> %
 --R sech : % -> %                         sin : % -> %
@@ -7823,17 +7824,19 @@ o )show LiouvillianFunctionCategory
 \cross{LFCAT}{dilog} &
 \cross{LFCAT}{erf} &
 \cross{LFCAT}{exp} &
-\cross{LFCAT}{integral} \\
+\cross{LFCAT}{frsenelC} \\
+\cross{LFCAT}{frsenelS} &
+\cross{LFCAT}{integral} &
 \cross{LFCAT}{li} &
 \cross{LFCAT}{log} &
-\cross{LFCAT}{pi} &
+\cross{LFCAT}{pi} \\
 \cross{LFCAT}{sec} &
-\cross{LFCAT}{sech} \\
+\cross{LFCAT}{sech} &
 \cross{LFCAT}{sin} &
 \cross{LFCAT}{sinh} &
-\cross{LFCAT}{tan} &
+\cross{LFCAT}{tan} \\
 \cross{LFCAT}{tanh} &
-\cross{LFCAT}{?**?} \\
+\cross{LFCAT}{?**?} &&&
 \end{tabular}
 
 These are directly exported but not implemented:
@@ -7844,6 +7847,8 @@ These are directly exported but not implemented:
  erf : % -> %
  li : % -> %                          
  Si : % -> %
+ fresnelC : % -> %
+ fresnelS : % -> %
 \end{verbatim}
 
 These exports come from \refto{PrimitiveFunctionCategory}()
@@ -7913,6 +7918,12 @@ LiouvillianFunctionCategory(): Category ==
     erf     : $  -> $
       ++ erf(x) returns the error function of x, i.e.
       ++ \spad{2 / sqrt(%pi)} times the integral of \spad{exp(-x**2) dx}.
+    fresnelS : $ -> $
+      ++ fresnelS is the Fresnel integral S, defined by
+      ++ S(x) = integrate(sin(t^2),t=0..x)
+    fresnelC : $ -> $
+      ++ fresnelC is the Fresnel integral C, defined by
+      ++ C(x) = integrate(cos(t^2),t=0..x)
 
 @
 <<LFCAT.dotabb>>=
diff --git a/books/bookvol10.3.pamphlet b/books/bookvol10.3.pamphlet
index d31717e..11803bb 100644
--- a/books/bookvol10.3.pamphlet
+++ b/books/bookvol10.3.pamphlet
@@ -33787,6 +33787,8 @@ Expression(R:OrderedSet): Exports == Implementation where
       Ci x                               == Ci(x)$LF
       li x                               == li(x)$LF
       dilog x                            == dilog(x)$LF
+      fresnelS x                         == fresnelS(x)$LF
+      fresnelC x                         == fresnelC(x)$LF
       integral(x:%, n:Symbol)            == integral(x, n)$LF
       integral(x:%, s:SegmentBinding %)  == integral(x, s)$LF
 
diff --git a/books/bookvol10.4.pamphlet b/books/bookvol10.4.pamphlet
index d40a654..850d053 100644
--- a/books/bookvol10.4.pamphlet
+++ b/books/bookvol10.4.pamphlet
@@ -7983,6 +7983,8 @@ CommonOperators(): Exports == Implementation where
     opli    := operator("li"::Symbol, 1)
     operf   := operator("erf"::Symbol, 1)
     opli2   := operator("dilog"::Symbol, 1)
+    opfis   := operator("fresnelS"::Symbol, 1)
+    opfic   := operator("fresnelC"::Symbol, 1)
     opGamma     := operator("Gamma"::Symbol, 1)
     opGamma2    := operator("Gamma2"::Symbol, 2)
     opBeta      := operator("Beta"::Symbol, 2)
@@ -8012,7 +8014,8 @@ CommonOperators(): Exports == Implementation where
                    opasinh, opacosh, opatanh, opacoth, opasech, opacsch]
     trigop  := concat(rtrigop, htrigop)
     elemop  := concat(trigop, [oppi, oplog, opexp])
-    primop  := [opei, opli, opsi, opci, operf, opli2, opint, opdint]
+    primop  := [opei, opli, opsi, opci, operf, opli2, opint, opdint,
+                opfis, opfic]
     combop  := [opfact, opperm, opbinom, oppow,
                                          opsum, opdsum, opprod, opdprod]
     specop  := [opGamma, opGamma2, opBeta, opdigamma, oppolygamma, opabs,
@@ -58711,6 +58714,10 @@ LiouvillianFunction(R, F): Exports == Implementation where
       ++ erf(f) denotes the error function
     dilog   : F  -> F
       ++ dilog(f) denotes the dilogarithm
+    fresnelS : F -> F
+      ++ fresnelS(f) denotes the Fresnel integral S
+    fresnelC : F -> F
+      ++ fresnelC(f) denotes the Fresnel integral C
     integral: (F, SE) -> F
       ++ integral(f,x) indefinite integral of f with respect to x.
     integral: (F, SegmentBinding F) -> F
@@ -58741,6 +58748,8 @@ LiouvillianFunction(R, F): Exports == Implementation where
     opci   := operator("Ci"::Symbol)$CommonOperators
     opli2  := operator("dilog"::Symbol)$CommonOperators
     operf  := operator("erf"::Symbol)$CommonOperators
+    opfis  := operator("fresnelS"::Symbol)$CommonOperators
+    opfic  := operator("fresnelC"::Symbol)$CommonOperators
 
     Si x                == opsi x
     Ci x                == opci x
@@ -58748,6 +58757,8 @@ LiouvillianFunction(R, F): Exports == Implementation where
     erf x               == operf x
     li  x               == opli x
     dilog x             == opli2 x
+    fresnelS x          == opfis x
+    fresnelC x          == opfic x
 
     belong? op     == has?(op, "prim")
     isi x          == kernel(opsi, x)
@@ -58755,6 +58766,8 @@ LiouvillianFunction(R, F): Exports == Implementation where
     ierf x         == (zero? x => 0; kernel(operf, x))
 --    ili2 x         == (one? x => INV; kernel(opli2, x))
     ili2 x         == ((x = 1) => INV; kernel(opli2, x))
+    ifis(x:F):F    == (zero? x => 0; kernel(opfis,x))
+    ific(x:F):F    == (zero? x => 0; kernel(opfic,x))
     integrand l    == eval(first l, retract(second l)@K, third l)
     integral(f:F, x:SE) == opint [eval(f, k:=kernel(x)$K, dummy), dummy, k::F]
 
@@ -58811,6 +58824,8 @@ LiouvillianFunction(R, F): Exports == Implementation where
       is?(op, "li"::Symbol)         => opli
       is?(op, "erf"::Symbol)        => operf
       is?(op, "dilog"::Symbol)      => opli2
+      is?(op, "fresnelC"::Symbol)   => opfis
+      is?(op, "fresnelS"::Symbol)   => opfic
       error "Not a Liouvillian operator"
 
     evaluate(opei,    iei)$BasicOperatorFunctions1(F)
@@ -58819,6 +58834,8 @@ LiouvillianFunction(R, F): Exports == Implementation where
     evaluate(opci,    ici)
     evaluate(operf,   ierf)
     evaluate(opli2,   ili2)
+    evaluate(opfis,   ifis)
+    evaluate(opfic,   ific)
     evaluate(opint,   iint)
     derivative(opsi,  (z1:F):F +-> sin(z1) / z1)
     derivative(opci,  (z1:F):F +-> cos(z1) / z1)
@@ -58826,6 +58843,8 @@ LiouvillianFunction(R, F): Exports == Implementation where
     derivative(opli,  (z1:F):F +-> inv log(z1))
     derivative(operf, (z1:F):F +-> 2 * exp(-(z1**2)) / sqrt(pi()))
     derivative(opli2, (z1:F):F +-> log(z1) / (1 - z1))
+    derivative(opfis, (z1:F):F +-> sin(z1**2))
+    derivative(opfic, (z1:F):F +-> cos(z1**2))
     setProperty(opint,SPECIALEQUAL,eqint@((K,K) -> Boolean) pretend None)
     setProperty(opint,SPECIALDIFF,dvint@((List F,SE) -> F) pretend None)
     setProperty(opdint,SPECIALDIFF,dvdint@((List F,SE)->F) pretend None)
@@ -132084,7 +132103,9 @@ PowerSeriesLimitPackage(R,FE): Exports == Implementation where
       is?(ker,"acsc" :: Symbol) => true
       is?(ker,"acsch" :: Symbol) => true
       is?(ker,"acoth" :: Symbol) => true
-      false
+      is?(ker,"fresnelS" :: Symbol) => true
+      is?(ker,"fresnelC" :: Symbol) => true
+      error "finiteValueAtInfinity? true, but unknown value at infinity"
 
     knownValueAtInfinity?: Kernel FE -> Boolean
     knownValueAtInfinity? ker ==
@@ -132214,6 +132235,9 @@ PowerSeriesLimitPackage(R,FE): Exports == Implementation where
             is?(ker,"asec" :: Symbol) => pi()/(2 :: FE)
             is?(ker,"acsc" :: Symbol) => 0
             is?(ker,"acsch" :: Symbol) => 0
+            is?(ker,"fresnelS" :: Symbol) => -sqrt(pi()/(8::FE))
+            is?(ker,"fresnelC" :: Symbol) => -sqrt(pi()/(8::FE))
+            error "finiteValueAtInfinity? true, but unknown value at infinity"
             -- ker must be acoth
             0
           val :: OFE
diff --git a/changelog b/changelog
index bae62de..4c30807 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,15 @@
+20100713 wxh src/axiom-website/patches.html 20100713.01.wxh.patch
+20100713 wxh src/share/algebra/users.daase/index.kaf update for fresnel
+20100713 wxh src/share/algebra/operation.daase update for fresnel
+20100713 wxh src/share/algebra/interp.daase update for fresnel
+20100713 wxh src/share/algebra/dependents.daase/index.kaf update for fresnel
+20100713 wxh src/share/algebra/compress.daase update for fresel
+20100713 wxh src/share/algebra/category.daase update for fresnel
+20100713 wxh src/share/algebra/browse.daase update for fresnel
+20100713 wxh src/algebra/Makefile add ignore for EXPR compile
+20100713 wxh books/bookvol10.4 add fresnelS, fresnelC to LF, COMMONOP, LIMITPS
+20100713 wxh books/bookvol10.3 add fresnelS, fresnelC to EXPR
+20100713 wxh books/bookvol10.2 add fresnelS, fresnelC to LFCAT
 20100712 tpd src/axiom-website/patches.html 20100712.02.tpd.patch
 20100712 tpd src/input/Makefile add derivefail.input
 20100712 tpd src/input/derivefail.input failing integrals from derive 6.10
diff --git a/src/algebra/Makefile.pamphlet b/src/algebra/Makefile.pamphlet
index 0f325cf..04407cf 100644
--- a/src/algebra/Makefile.pamphlet
+++ b/src/algebra/Makefile.pamphlet
@@ -15290,7 +15290,7 @@ LAYER18=\
 /*"EXPR" -> {"PI"; "VECTOR"; "IVECTOR"; "IARRAY1"; "VECTCAT-"; "QFCAT"}*/
 /*"EXPR" -> {"FEVALAB"; "DIFEXT"; "DIFRING"; "STEP"; "OINTDOM"; "ORDRING"}*/
 /*"EXPR" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "REAL"; "UPOLYC"}*/
-/*"EXPR" -> {"INS"; "FPS"; "RNS"}*/
+/*"EXPR" -> {"INS"; "FPS"; "RNS"; "LF"}*/
 
 "EXPRSOL" [color="#FF4488",href="bookvol10.4.pdf#nameddest=EXPRSOL"]
 "EXPRSOL" -> "UTSSOL" /* by loadlib */
@@ -16571,6 +16571,16 @@ ${MID}/clique2.spad: ${CLIQUE2FILES}
 	@ cp ${MID}/PAFFFF.nrlib/code.o ${OUT}/PAFFFF.o
 	
 @
+<<ignore>>=
+EXPRDEPS  = LF
+
+${MID}/EXPR.nrlib/code.o: ${MID}/EXPR.spad
+	@echo 1 newcode EXPR.o depends on LF.o
+	@ ( cd ${MID} ; \
+            echo -e ")lib ${EXPRDEPS} \n )co EXPR.spad" | ${INTERPSYS} )
+	@ cp ${MID}/EXPR.nrlib/code.o ${OUT}/EXPR.o
+	
+@
 \section{Broken Files}
 These files are Aldor files
 \begin{verbatim}
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index 1a47357..def7cc5 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -2992,5 +2992,7 @@ books/bookvol4 document the Makefile build process<br/>
 src/axiom-website/index.html fix CATS href in sidebar<br/>
 <a href="patches/20100712.02.tpd.patch">20100712.02.tpd.patch</a>
 src/input/derivefail.input failing integrals from derive 6.10<br/>
+<a href="patches/20100713.01.wxh.patch">20100713.01.wxh.patch</a>
+books/bookvol10.* add fresnelS, fresnelC to LF, COMMONOP, LIMITPS, EXPR<br/>
  </body>
 </html>
diff --git a/src/share/algebra/browse.daase b/src/share/algebra/browse.daase
index 77e2634..3983e54 100644
--- a/src/share/algebra/browse.daase
+++ b/src/share/algebra/browse.daase
@@ -1,12 +1,12 @@
 
-(2465038 . 3487447480)       
+(2465526 . 3488060042)       
 (-18 A S) 
 ((|constructor| (NIL "One-dimensional-array aggregates serves as models for one-dimensional arrays. Categorically,{} these aggregates are finite linear aggregates with the \\spadatt{shallowlyMutable} property,{} that is,{} any component of the array may be changed without affecting the identity of the overall array. Array data structures are typically represented by a fixed area in storage and cannot efficiently grow or shrink on demand as can list structures (see however \\spadtype{FlexibleArray} for a data structure which is a cross between a list and an array). Iteration over,{} and access to,{} elements of arrays is extremely fast (and often can be optimized to open-code). Insertion and deletion however is generally slow since an entirely new data structure must be created for the result."))) 
 NIL 
 NIL 
 (-19 S) 
 ((|constructor| (NIL "One-dimensional-array aggregates serves as models for one-dimensional arrays. Categorically,{} these aggregates are finite linear aggregates with the \\spadatt{shallowlyMutable} property,{} that is,{} any component of the array may be changed without affecting the identity of the overall array. Array data structures are typically represented by a fixed area in storage and cannot efficiently grow or shrink on demand as can list structures (see however \\spadtype{FlexibleArray} for a data structure which is a cross between a list and an array). Iteration over,{} and access to,{} elements of arrays is extremely fast (and often can be optimized to open-code). Insertion and deletion however is generally slow since an entirely new data structure must be created for the result."))) 
-((-4520 . T) (-4519 . T) (-3973 . T)) 
+((-4522 . T) (-4521 . T) (-3973 . T)) 
 NIL 
 (-20 S) 
 ((|constructor| (NIL "The class of abelian groups,{} \\spadignore{i.e.} additive monoids where each element has an additive inverse. \\blankline Axioms\\spad{\\br} \\tab{5}\\spad{-(-x) = x}\\spad{\\br} \\tab{5}\\spad{x+(-x) = 0}")) (* (($ (|Integer|) $) "\\spad{n*x} is the product of \\spad{x} by the integer \\spad{n}.")) (- (($ $ $) "\\spad{x-y} is the difference of \\spad{x} and \\spad{y} \\spadignore{i.e.} \\spad{x + (-y)}.") (($ $) "\\spad{-x} is the additive inverse of \\spad{x}."))) 
@@ -38,7 +38,7 @@ NIL
 NIL 
 (-27) 
 ((|constructor| (NIL "Model for algebraically closed fields.")) (|zerosOf| (((|List| $) (|SparseUnivariatePolynomial| $) (|Symbol|)) "\\indented{1}{zerosOf(\\spad{p},{} \\spad{y}) returns \\spad{[y1,{}...,{}yn]} such that \\spad{p(\\spad{yi}) = 0}.} \\indented{1}{The \\spad{yi}\\spad{'s} are expressed in radicals if possible,{} and otherwise} \\indented{1}{as implicit algebraic quantities} \\indented{1}{which display as \\spad{'yi}.} \\indented{1}{The returned symbols \\spad{y1},{}...,{}\\spad{yn} are bound in the interpreter} \\indented{1}{to respective root values.} \\blankline \\spad{X} a:SparseUnivariatePolynomial(Integer)\\spad{:=}-3*x^3+2*x+13 \\spad{X} zerosOf(a,{}\\spad{x})") (((|List| $) (|SparseUnivariatePolynomial| $)) "\\indented{1}{zerosOf(\\spad{p}) returns \\spad{[y1,{}...,{}yn]} such that \\spad{p(\\spad{yi}) = 0}.} \\indented{1}{The \\spad{yi}\\spad{'s} are expressed in radicals if possible,{} and otherwise} \\indented{1}{as implicit algebraic quantities.} \\indented{1}{The returned symbols \\spad{y1},{}...,{}\\spad{yn} are bound in the interpreter} \\indented{1}{to respective root values.} \\blankline \\spad{X} a:SparseUnivariatePolynomial(Integer)\\spad{:=}-3*x^3+2*x+13 \\spad{X} zerosOf(a)") (((|List| $) (|Polynomial| $)) "\\indented{1}{zerosOf(\\spad{p}) returns \\spad{[y1,{}...,{}yn]} such that \\spad{p(\\spad{yi}) = 0}.} \\indented{1}{The \\spad{yi}\\spad{'s} are expressed in radicals if possible.} \\indented{1}{Otherwise they are implicit algebraic quantities.} \\indented{1}{The returned symbols \\spad{y1},{}...,{}\\spad{yn} are bound in the interpreter} \\indented{1}{to respective root values.} \\indented{1}{Error: if \\spad{p} has more than one variable \\spad{y}.} \\blankline \\spad{X} a:Polynomial(Integer)\\spad{:=}-3*x^2+2*x-13 \\spad{X} zerosOf(a)")) (|zeroOf| (($ (|SparseUnivariatePolynomial| $) (|Symbol|)) "\\indented{1}{zeroOf(\\spad{p},{} \\spad{y}) returns \\spad{y} such that \\spad{p(y) = 0};} \\indented{1}{if possible,{} \\spad{y} is expressed in terms of radicals.} \\indented{1}{Otherwise it is an implicit algebraic quantity which} \\indented{1}{displays as \\spad{'y}.} \\blankline \\spad{X} a:SparseUnivariatePolynomial(Integer)\\spad{:=}-3*x^3+2*x+13 \\spad{X} zeroOf(a,{}\\spad{x})") (($ (|SparseUnivariatePolynomial| $)) "\\indented{1}{zeroOf(\\spad{p}) returns \\spad{y} such that \\spad{p(y) = 0};} \\indented{1}{if possible,{} \\spad{y} is expressed in terms of radicals.} \\indented{1}{Otherwise it is an implicit algebraic quantity.} \\blankline \\spad{X} a:SparseUnivariatePolynomial(Integer)\\spad{:=}-3*x^3+2*x+13 \\spad{X} zeroOf(a)") (($ (|Polynomial| $)) "\\indented{1}{zeroOf(\\spad{p}) returns \\spad{y} such that \\spad{p(y) = 0}.} \\indented{1}{If possible,{} \\spad{y} is expressed in terms of radicals.} \\indented{1}{Otherwise it is an implicit algebraic quantity.} \\indented{1}{Error: if \\spad{p} has more than one variable \\spad{y}.} \\blankline \\spad{X} a:Polynomial(Integer)\\spad{:=}-3*x^2+2*x-13 \\spad{X} zeroOf(a)")) (|rootsOf| (((|List| $) (|SparseUnivariatePolynomial| $) (|Symbol|)) "\\indented{1}{rootsOf(\\spad{p},{} \\spad{y}) returns \\spad{[y1,{}...,{}yn]} such that \\spad{p(\\spad{yi}) = 0};} \\indented{1}{The returned roots display as \\spad{'y1},{}...,{}\\spad{'yn}.} \\indented{1}{Note that the returned symbols \\spad{y1},{}...,{}\\spad{yn} are bound in the interpreter} \\indented{1}{to respective root values.} \\blankline \\spad{X} a:SparseUnivariatePolynomial(Integer)\\spad{:=}-3*x^3+2*x+13 \\spad{X} rootsOf(a,{}\\spad{x})") (((|List| $) (|SparseUnivariatePolynomial| $)) "\\indented{1}{rootsOf(\\spad{p}) returns \\spad{[y1,{}...,{}yn]} such that \\spad{p(\\spad{yi}) = 0}.} \\indented{1}{Note that the returned symbols \\spad{y1},{}...,{}\\spad{yn} are bound in the interpreter} \\indented{1}{to respective root values.} \\blankline \\spad{X} a:SparseUnivariatePolynomial(Integer)\\spad{:=}-3*x^3+2*x+13 \\spad{X} rootsOf(a)") (((|List| $) (|Polynomial| $)) "\\indented{1}{rootsOf(\\spad{p}) returns \\spad{[y1,{}...,{}yn]} such that \\spad{p(\\spad{yi}) = 0}.} \\indented{1}{Note that the returned symbols \\spad{y1},{}...,{}\\spad{yn} are bound in the} \\indented{1}{interpreter to respective root values.} \\indented{1}{Error: if \\spad{p} has more than one variable \\spad{y}.} \\blankline \\spad{X} a:Polynomial(Integer)\\spad{:=}-3*x^3+2*x+13 \\spad{X} rootsOf(a)")) (|rootOf| (($ (|SparseUnivariatePolynomial| $) (|Symbol|)) "\\indented{1}{rootOf(\\spad{p},{} \\spad{y}) returns \\spad{y} such that \\spad{p(y) = 0}.} \\indented{1}{The object returned displays as \\spad{'y}.} \\blankline \\spad{X} a:SparseUnivariatePolynomial(Integer)\\spad{:=}-3*x^3+2*x+13 \\spad{X} rootOf(a,{}\\spad{x})") (($ (|SparseUnivariatePolynomial| $)) "\\indented{1}{rootOf(\\spad{p}) returns \\spad{y} such that \\spad{p(y) = 0}.} \\blankline \\spad{X} a:SparseUnivariatePolynomial(Integer)\\spad{:=}-3*x^3+2*x+13 \\spad{X} rootOf(a)") (($ (|Polynomial| $)) "\\indented{1}{rootOf(\\spad{p}) returns \\spad{y} such that \\spad{p(y) = 0}.} \\indented{1}{Error: if \\spad{p} has more than one variable \\spad{y}.} \\blankline \\spad{X} a:Polynomial(Integer)\\spad{:=}-3*x^3+2*x+13 \\spad{X} rootOf(a)"))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-28 S R) 
 ((|constructor| (NIL "Model for algebraically closed function spaces.")) (|zerosOf| (((|List| $) $ (|Symbol|)) "\\spad{zerosOf(p,{} y)} returns \\spad{[y1,{}...,{}yn]} such that \\spad{p(\\spad{yi}) = 0}. The \\spad{yi}\\spad{'s} are expressed in radicals if possible,{} and otherwise as implicit algebraic quantities which display as \\spad{'yi}. The returned symbols \\spad{y1},{}...,{}\\spad{yn} are bound in the interpreter to respective root values.") (((|List| $) $) "\\spad{zerosOf(p)} returns \\spad{[y1,{}...,{}yn]} such that \\spad{p(\\spad{yi}) = 0}. The \\spad{yi}\\spad{'s} are expressed in radicals if possible. The returned symbols \\spad{y1},{}...,{}\\spad{yn} are bound in the interpreter to respective root values. Error: if \\spad{p} has more than one variable.")) (|zeroOf| (($ $ (|Symbol|)) "\\spad{zeroOf(p,{} y)} returns \\spad{y} such that \\spad{p(y) = 0}. The value \\spad{y} is expressed in terms of radicals if possible,{}and otherwise as an implicit algebraic quantity which displays as \\spad{'y}.") (($ $) "\\spad{zeroOf(p)} returns \\spad{y} such that \\spad{p(y) = 0}. The value \\spad{y} is expressed in terms of radicals if possible,{}and otherwise as an implicit algebraic quantity. Error: if \\spad{p} has more than one variable.")) (|rootsOf| (((|List| $) $ (|Symbol|)) "\\spad{rootsOf(p,{} y)} returns \\spad{[y1,{}...,{}yn]} such that \\spad{p(\\spad{yi}) = 0}; The returned roots display as \\spad{'y1},{}...,{}\\spad{'yn}. Note that the returned symbols \\spad{y1},{}...,{}\\spad{yn} are bound in the interpreter to respective root values.") (((|List| $) $) "\\spad{rootsOf(p,{} y)} returns \\spad{[y1,{}...,{}yn]} such that \\spad{p(\\spad{yi}) = 0}; Note that the returned symbols \\spad{y1},{}...,{}\\spad{yn} are bound in the interpreter to respective root values. Error: if \\spad{p} has more than one variable \\spad{y}.")) (|rootOf| (($ $ (|Symbol|)) "\\spad{rootOf(p,{}y)} returns \\spad{y} such that \\spad{p(y) = 0}. The object returned displays as \\spad{'y}.") (($ $) "\\spad{rootOf(p)} returns \\spad{y} such that \\spad{p(y) = 0}. Error: if \\spad{p} has more than one variable \\spad{y}."))) 
@@ -46,7 +46,7 @@ NIL
 NIL 
 (-29 R) 
 ((|constructor| (NIL "Model for algebraically closed function spaces.")) (|zerosOf| (((|List| $) $ (|Symbol|)) "\\spad{zerosOf(p,{} y)} returns \\spad{[y1,{}...,{}yn]} such that \\spad{p(\\spad{yi}) = 0}. The \\spad{yi}\\spad{'s} are expressed in radicals if possible,{} and otherwise as implicit algebraic quantities which display as \\spad{'yi}. The returned symbols \\spad{y1},{}...,{}\\spad{yn} are bound in the interpreter to respective root values.") (((|List| $) $) "\\spad{zerosOf(p)} returns \\spad{[y1,{}...,{}yn]} such that \\spad{p(\\spad{yi}) = 0}. The \\spad{yi}\\spad{'s} are expressed in radicals if possible. The returned symbols \\spad{y1},{}...,{}\\spad{yn} are bound in the interpreter to respective root values. Error: if \\spad{p} has more than one variable.")) (|zeroOf| (($ $ (|Symbol|)) "\\spad{zeroOf(p,{} y)} returns \\spad{y} such that \\spad{p(y) = 0}. The value \\spad{y} is expressed in terms of radicals if possible,{}and otherwise as an implicit algebraic quantity which displays as \\spad{'y}.") (($ $) "\\spad{zeroOf(p)} returns \\spad{y} such that \\spad{p(y) = 0}. The value \\spad{y} is expressed in terms of radicals if possible,{}and otherwise as an implicit algebraic quantity. Error: if \\spad{p} has more than one variable.")) (|rootsOf| (((|List| $) $ (|Symbol|)) "\\spad{rootsOf(p,{} y)} returns \\spad{[y1,{}...,{}yn]} such that \\spad{p(\\spad{yi}) = 0}; The returned roots display as \\spad{'y1},{}...,{}\\spad{'yn}. Note that the returned symbols \\spad{y1},{}...,{}\\spad{yn} are bound in the interpreter to respective root values.") (((|List| $) $) "\\spad{rootsOf(p,{} y)} returns \\spad{[y1,{}...,{}yn]} such that \\spad{p(\\spad{yi}) = 0}; Note that the returned symbols \\spad{y1},{}...,{}\\spad{yn} are bound in the interpreter to respective root values. Error: if \\spad{p} has more than one variable \\spad{y}.")) (|rootOf| (($ $ (|Symbol|)) "\\spad{rootOf(p,{}y)} returns \\spad{y} such that \\spad{p(y) = 0}. The object returned displays as \\spad{'y}.") (($ $) "\\spad{rootOf(p)} returns \\spad{y} such that \\spad{p(y) = 0}. Error: if \\spad{p} has more than one variable \\spad{y}."))) 
-((-4516 . T) (-4514 . T) (-4513 . T) ((-4521 "*") . T) (-4512 . T) (-4517 . T) (-4511 . T) (-3973 . T)) 
+((-4518 . T) (-4516 . T) (-4515 . T) ((-4523 "*") . T) (-4514 . T) (-4519 . T) (-4513 . T) (-3973 . T)) 
 NIL 
 (-30) 
 ((|constructor| (NIL "Plot a NON-SINGULAR plane algebraic curve \\spad{p}(\\spad{x},{}\\spad{y}) = 0.")) (|refine| (($ $ (|DoubleFloat|)) "\\indented{1}{refine(\\spad{p},{}\\spad{x}) is not documented} \\blankline \\spad{X} sketch:=makeSketch(x+y,{}\\spad{x},{}\\spad{y},{}\\spad{-1/2}..1/2,{}\\spad{-1/2}..1/2)\\$ACPLOT \\spad{X} refined:=refine(sketch,{}0.1)")) (|makeSketch| (($ (|Polynomial| (|Integer|)) (|Symbol|) (|Symbol|) (|Segment| (|Fraction| (|Integer|))) (|Segment| (|Fraction| (|Integer|)))) "\\indented{1}{makeSketch(\\spad{p},{}\\spad{x},{}\\spad{y},{}a..\\spad{b},{}\\spad{c}..\\spad{d}) creates an ACPLOT of the} \\indented{1}{curve \\spad{p = 0} in the region a \\spad{<=} \\spad{x} \\spad{<=} \\spad{b},{} \\spad{c} \\spad{<=} \\spad{y} \\spad{<=} \\spad{d}.} \\indented{1}{More specifically,{} 'makeSketch' plots a non-singular algebraic curve} \\indented{1}{\\spad{p = 0} in an rectangular region xMin \\spad{<=} \\spad{x} \\spad{<=} xMax,{}} \\indented{1}{yMin \\spad{<=} \\spad{y} \\spad{<=} yMax. The user inputs} \\indented{1}{\\spad{makeSketch(p,{}x,{}y,{}xMin..xMax,{}yMin..yMax)}.} \\indented{1}{Here \\spad{p} is a polynomial in the variables \\spad{x} and \\spad{y} with} \\indented{1}{integer coefficients (\\spad{p} belongs to the domain} \\indented{1}{\\spad{Polynomial Integer}). The case} \\indented{1}{where \\spad{p} is a polynomial in only one of the variables is} \\indented{1}{allowed.\\space{2}The variables \\spad{x} and \\spad{y} are input to specify the} \\indented{1}{the coordinate axes.\\space{2}The horizontal axis is the \\spad{x}-axis and} \\indented{1}{the vertical axis is the \\spad{y}-axis.\\space{2}The rational numbers} \\indented{1}{xMin,{}...,{}yMax specify the boundaries of the region in} \\indented{1}{which the curve is to be plotted.} \\blankline \\spad{X} makeSketch(x+y,{}\\spad{x},{}\\spad{y},{}\\spad{-1/2}..1/2,{}\\spad{-1/2}..1/2)\\$ACPLOT"))) 
@@ -68,7 +68,7 @@ NIL
 ((|constructor| (NIL "The following is all the categories and domains related to projective space and part of the PAFF package"))) 
 NIL 
 NIL 
-(-35 -2570 K) 
+(-35 -1965 K) 
 ((|constructor| (NIL "The following is all the categories and domains related to projective space and part of the PAFF package"))) 
 NIL 
 NIL 
@@ -83,7 +83,7 @@ NIL
 (-38 S) 
 ((|constructor| (NIL "The notion of aggregate serves to model any data structure aggregate,{} designating any collection of objects,{} with heterogenous or homogeneous members,{} with a finite or infinite number of members,{} explicitly or implicitly represented. An aggregate can in principle represent everything from a string of characters to abstract sets such as \"the set of \\spad{x} satisfying relation \\spad{r}(\\spad{x})\" An attribute \\spadatt{finiteAggregate} is used to assert that a domain has a finite number of elements.")) (|#| (((|NonNegativeInteger|) $) "\\spad{\\# u} returns the number of items in \\spad{u}.")) (|sample| (($) "\\spad{sample yields} a value of type \\%")) (|size?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\spad{size?(u,{}n)} tests if \\spad{u} has exactly \\spad{n} elements.")) (|more?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\spad{more?(u,{}n)} tests if \\spad{u} has greater than \\spad{n} elements.")) (|less?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\spad{less?(u,{}n)} tests if \\spad{u} has less than \\spad{n} elements.")) (|empty?| (((|Boolean|) $) "\\spad{empty?(u)} tests if \\spad{u} has 0 elements.")) (|empty| (($) "\\spad{empty()}\\$\\spad{D} creates an aggregate of type \\spad{D} with 0 elements. Note that The \\$\\spad{D} can be dropped if understood by context,{} \\spadignore{e.g.} \\axiom{u: \\spad{D} \\spad{:=} empty()}.")) (|copy| (($ $) "\\spad{copy(u)} returns a top-level (non-recursive) copy of \\spad{u}. Note that for collections,{} \\axiom{copy(\\spad{u}) \\spad{==} [\\spad{x} for \\spad{x} in \\spad{u}]}.")) (|eq?| (((|Boolean|) $ $) "\\spad{eq?(u,{}v)} tests if \\spad{u} and \\spad{v} are same objects."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE -4519))) 
+((|HasAttribute| |#1| (QUOTE -4521))) 
 (-39) 
 ((|constructor| (NIL "The notion of aggregate serves to model any data structure aggregate,{} designating any collection of objects,{} with heterogenous or homogeneous members,{} with a finite or infinite number of members,{} explicitly or implicitly represented. An aggregate can in principle represent everything from a string of characters to abstract sets such as \"the set of \\spad{x} satisfying relation \\spad{r}(\\spad{x})\" An attribute \\spadatt{finiteAggregate} is used to assert that a domain has a finite number of elements.")) (|#| (((|NonNegativeInteger|) $) "\\spad{\\# u} returns the number of items in \\spad{u}.")) (|sample| (($) "\\spad{sample yields} a value of type \\%")) (|size?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\spad{size?(u,{}n)} tests if \\spad{u} has exactly \\spad{n} elements.")) (|more?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\spad{more?(u,{}n)} tests if \\spad{u} has greater than \\spad{n} elements.")) (|less?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\spad{less?(u,{}n)} tests if \\spad{u} has less than \\spad{n} elements.")) (|empty?| (((|Boolean|) $) "\\spad{empty?(u)} tests if \\spad{u} has 0 elements.")) (|empty| (($) "\\spad{empty()}\\$\\spad{D} creates an aggregate of type \\spad{D} with 0 elements. Note that The \\$\\spad{D} can be dropped if understood by context,{} \\spadignore{e.g.} \\axiom{u: \\spad{D} \\spad{:=} empty()}.")) (|copy| (($ $) "\\spad{copy(u)} returns a top-level (non-recursive) copy of \\spad{u}. Note that for collections,{} \\axiom{copy(\\spad{u}) \\spad{==} [\\spad{x} for \\spad{x} in \\spad{u}]}.")) (|eq?| (((|Boolean|) $ $) "\\spad{eq?(u,{}v)} tests if \\spad{u} and \\spad{v} are same objects."))) 
 ((-3973 . T)) 
@@ -94,7 +94,7 @@ NIL
 NIL 
 (-41 |Key| |Entry|) 
 ((|constructor| (NIL "An association list is a list of key entry pairs which may be viewed as a table. It is a poor mans version of a table: searching for a key is a linear operation.")) (|assoc| (((|Union| (|Record| (|:| |key| |#1|) (|:| |entry| |#2|)) "failed") |#1| $) "\\spad{assoc(k,{}u)} returns the element \\spad{x} in association list \\spad{u} stored with key \\spad{k},{} or \"failed\" if \\spad{u} has no key \\spad{k}."))) 
-((-4519 . T) (-4520 . T) (-3973 . T)) 
+((-4521 . T) (-4522 . T) (-3973 . T)) 
 NIL 
 (-42 S R) 
 ((|constructor| (NIL "The category of associative algebras (modules which are themselves rings). \\blankline Axioms\\spad{\\br} \\tab{5}\\spad{(b+c)::\\% = (b::\\%) + (c::\\%)}\\spad{\\br} \\tab{5}\\spad{(b*c)::\\% = (b::\\%) * (c::\\%)}\\spad{\\br} \\tab{5}\\spad{(1::R)::\\% = 1::\\%}\\spad{\\br} \\tab{5}\\spad{b*x = (b::\\%)*x}\\spad{\\br} \\tab{5}\\spad{r*(a*b) = (r*a)*b = a*(r*b)}")) (|coerce| (($ |#2|) "\\spad{coerce(r)} maps the ring element \\spad{r} to a member of the algebra."))) 
@@ -102,16 +102,16 @@ NIL
 NIL 
 (-43 R) 
 ((|constructor| (NIL "The category of associative algebras (modules which are themselves rings). \\blankline Axioms\\spad{\\br} \\tab{5}\\spad{(b+c)::\\% = (b::\\%) + (c::\\%)}\\spad{\\br} \\tab{5}\\spad{(b*c)::\\% = (b::\\%) * (c::\\%)}\\spad{\\br} \\tab{5}\\spad{(1::R)::\\% = 1::\\%}\\spad{\\br} \\tab{5}\\spad{b*x = (b::\\%)*x}\\spad{\\br} \\tab{5}\\spad{r*(a*b) = (r*a)*b = a*(r*b)}")) (|coerce| (($ |#1|) "\\spad{coerce(r)} maps the ring element \\spad{r} to a member of the algebra."))) 
-((-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-44 UP) 
 ((|constructor| (NIL "Factorization of univariate polynomials with coefficients in \\spadtype{AlgebraicNumber}.")) (|doublyTransitive?| (((|Boolean|) |#1|) "\\spad{doublyTransitive?(p)} is \\spad{true} if \\spad{p} is irreducible over over the field \\spad{K} generated by its coefficients,{} and if \\spad{p(X) / (X - a)} is irreducible over \\spad{K(a)} where \\spad{p(a) = 0}.")) (|split| (((|Factored| |#1|) |#1|) "\\spad{split(p)} returns a prime factorisation of \\spad{p} over its splitting field.")) (|factor| (((|Factored| |#1|) |#1|) "\\spad{factor(p)} returns a prime factorisation of \\spad{p} over the field generated by its coefficients.") (((|Factored| |#1|) |#1| (|List| (|AlgebraicNumber|))) "\\spad{factor(p,{} [a1,{}...,{}an])} returns a prime factorisation of \\spad{p} over the field generated by its coefficients and \\spad{a1},{}...,{}an."))) 
 NIL 
 NIL 
-(-45 -1478 UP UPUP -3094) 
+(-45 -1478 UP UPUP -2477) 
 ((|constructor| (NIL "Function field defined by \\spad{f}(\\spad{x},{} \\spad{y}) = 0.")) (|knownInfBasis| (((|Void|) (|NonNegativeInteger|)) "\\spad{knownInfBasis(n)} is not documented"))) 
-((-4512 |has| (-409 |#2|) (-365)) (-4517 |has| (-409 |#2|) (-365)) (-4511 |has| (-409 |#2|) (-365)) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| (-409 |#2|) (QUOTE (-148))) (|HasCategory| (-409 |#2|) (QUOTE (-150))) (|HasCategory| (-409 |#2|) (QUOTE (-350))) (|HasCategory| (-409 |#2|) (QUOTE (-365))) (-2198 (|HasCategory| (-409 |#2|) (QUOTE (-365))) (|HasCategory| (-409 |#2|) (QUOTE (-350)))) (|HasCategory| (-409 |#2|) (QUOTE (-370))) (|HasCategory| (-409 |#2|) (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| (-409 |#2|) (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| (-409 |#2|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-370))) (-2198 (|HasCategory| (-409 |#2|) (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| (-409 |#2|) (QUOTE (-365)))) (-12 (|HasCategory| (-409 |#2|) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-409 |#2|) (QUOTE (-365)))) (-2198 (-12 (|HasCategory| (-409 |#2|) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-409 |#2|) (QUOTE (-365)))) (-12 (|HasCategory| (-409 |#2|) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-409 |#2|) (QUOTE (-350))))) (-12 (|HasCategory| (-409 |#2|) (QUOTE (-225))) (|HasCategory| (-409 |#2|) (QUOTE (-365)))) (-2198 (-12 (|HasCategory| (-409 |#2|) (QUOTE (-225))) (|HasCategory| (-409 |#2|) (QUOTE (-365)))) (|HasCategory| (-409 |#2|) (QUOTE (-350))))) 
+((-4514 |has| (-409 |#2|) (-365)) (-4519 |has| (-409 |#2|) (-365)) (-4513 |has| (-409 |#2|) (-365)) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| (-409 |#2|) (QUOTE (-148))) (|HasCategory| (-409 |#2|) (QUOTE (-150))) (|HasCategory| (-409 |#2|) (QUOTE (-350))) (|HasCategory| (-409 |#2|) (QUOTE (-365))) (-2199 (|HasCategory| (-409 |#2|) (QUOTE (-365))) (|HasCategory| (-409 |#2|) (QUOTE (-350)))) (|HasCategory| (-409 |#2|) (QUOTE (-370))) (|HasCategory| (-409 |#2|) (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| (-409 |#2|) (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| (-409 |#2|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-370))) (-2199 (|HasCategory| (-409 |#2|) (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| (-409 |#2|) (QUOTE (-365)))) (-12 (|HasCategory| (-409 |#2|) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-409 |#2|) (QUOTE (-365)))) (-2199 (-12 (|HasCategory| (-409 |#2|) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-409 |#2|) (QUOTE (-365)))) (-12 (|HasCategory| (-409 |#2|) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-409 |#2|) (QUOTE (-350))))) (-12 (|HasCategory| (-409 |#2|) (QUOTE (-225))) (|HasCategory| (-409 |#2|) (QUOTE (-365)))) (-2199 (-12 (|HasCategory| (-409 |#2|) (QUOTE (-225))) (|HasCategory| (-409 |#2|) (QUOTE (-365)))) (|HasCategory| (-409 |#2|) (QUOTE (-350))))) 
 (-46 R -1478) 
 ((|constructor| (NIL "AlgebraicManipulations provides functions to simplify and expand expressions involving algebraic operators.")) (|rootKerSimp| ((|#2| (|BasicOperator|) |#2| (|NonNegativeInteger|)) "\\spad{rootKerSimp(op,{}f,{}n)} should be local but conditional.")) (|rootSimp| ((|#2| |#2|) "\\spad{rootSimp(f)} transforms every radical of the form \\spad{(a * b**(q*n+r))**(1/n)} appearing in \\spad{f} into \\spad{b**q * (a * b**r)**(1/n)}. This transformation is not in general valid for all complex numbers \\spad{b}.")) (|rootProduct| ((|#2| |#2|) "\\spad{rootProduct(f)} combines every product of the form \\spad{(a**(1/n))**m * (a**(1/s))**t} into a single power of a root of \\spad{a},{} and transforms every radical power of the form \\spad{(a**(1/n))**m} into a simpler form.")) (|rootPower| ((|#2| |#2|) "\\spad{rootPower(f)} transforms every radical power of the form \\spad{(a**(1/n))**m} into a simpler form if \\spad{m} and \\spad{n} have a common factor.")) (|ratPoly| (((|SparseUnivariatePolynomial| |#2|) |#2|) "\\spad{ratPoly(f)} returns a polynomial \\spad{p} such that \\spad{p} has no algebraic coefficients,{} and \\spad{p(f) = 0}.")) (|ratDenom| ((|#2| |#2| (|List| (|Kernel| |#2|))) "\\spad{ratDenom(f,{} [a1,{}...,{}an])} removes the \\spad{ai}\\spad{'s} which are algebraic from the denominators in \\spad{f}.") ((|#2| |#2| (|List| |#2|)) "\\spad{ratDenom(f,{} [a1,{}...,{}an])} removes the \\spad{ai}\\spad{'s} which are algebraic kernels from the denominators in \\spad{f}.") ((|#2| |#2| |#2|) "\\spad{ratDenom(f,{} a)} removes \\spad{a} from the denominators in \\spad{f} if \\spad{a} is an algebraic kernel.") ((|#2| |#2|) "\\spad{ratDenom(f)} rationalizes the denominators appearing in \\spad{f} by moving all the algebraic quantities into the numerators.")) (|rootSplit| ((|#2| |#2|) "\\spad{rootSplit(f)} transforms every radical of the form \\spad{(a/b)**(1/n)} appearing in \\spad{f} into \\spad{a**(1/n) / b**(1/n)}. This transformation is not in general valid for all complex numbers \\spad{a} and \\spad{b}.")) (|coerce| (($ (|SparseMultivariatePolynomial| |#1| (|Kernel| $))) "\\spad{coerce(x)} \\undocumented")) (|denom| (((|SparseMultivariatePolynomial| |#1| (|Kernel| $)) $) "\\spad{denom(x)} \\undocumented")) (|numer| (((|SparseMultivariatePolynomial| |#1| (|Kernel| $)) $) "\\spad{numer(x)} \\undocumented"))) 
 NIL 
@@ -126,23 +126,23 @@ NIL
 ((|HasCategory| |#1| (QUOTE (-301)))) 
 (-49 R |n| |ls| |gamma|) 
 ((|constructor| (NIL "AlgebraGivenByStructuralConstants implements finite rank algebras over a commutative ring,{} given by the structural constants \\spad{gamma} with respect to a fixed basis \\spad{[a1,{}..,{}an]},{} where \\spad{gamma} is an \\spad{n}-vector of \\spad{n} by \\spad{n} matrices \\spad{[(gammaijk) for k in 1..rank()]} defined by \\spad{\\spad{ai} * aj = gammaij1 * a1 + ... + gammaijn * an}. The symbols for the fixed basis have to be given as a list of symbols.")) (|coerce| (($ (|Vector| |#1|)) "\\spad{coerce(v)} converts a vector to a member of the algebra by forming a linear combination with the basis element. Note: the vector is assumed to have length equal to the dimension of the algebra."))) 
-((-4516 |has| |#1| (-558)) (-4514 . T) (-4513 . T)) 
+((-4518 |has| |#1| (-558)) (-4516 . T) (-4515 . T)) 
 ((|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) 
 (-50 |Key| |Entry|) 
 ((|constructor| (NIL "\\spadtype{AssociationList} implements association lists. These may be viewed as lists of pairs where the first part is a key and the second is the stored value. For example,{} the key might be a string with a persons employee identification number and the value might be a record with personnel data."))) 
-((-4519 . T) (-4520 . T)) 
-((|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-1090))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090))) (-2198 (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2198 (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-842))) (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-1090)))) (-12 (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3649) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4083) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3649) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4083) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-842)))) (-12 (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3649) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4083) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090)))))) 
+((-4521 . T) (-4522 . T)) 
+((|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-1090))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090))) (-2199 (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2199 (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-842))) (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-1090)))) (-12 (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3651) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4085) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3651) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4085) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-842)))) (-12 (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3651) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4085) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090)))))) 
 (-51 S R E) 
 ((|constructor| (NIL "Abelian monoid ring elements (not necessarily of finite support) of this ring are of the form formal SUM (r_i * e_i) where the r_i are coefficents and the e_i,{} elements of the ordered abelian monoid,{} are thought of as exponents or monomials. The monomials commute with each other,{} and with the coefficients (which themselves may or may not be commutative). See \\spadtype{FiniteAbelianMonoidRing} for the case of finite support a useful common model for polynomials and power series. Conceptually at least,{} only the non-zero terms are ever operated on.")) (/ (($ $ |#2|) "\\spad{p/c} divides \\spad{p} by the coefficient \\spad{c}.")) (|coefficient| ((|#2| $ |#3|) "\\spad{coefficient(p,{}e)} extracts the coefficient of the monomial with exponent \\spad{e} from polynomial \\spad{p},{} or returns zero if exponent is not present.")) (|reductum| (($ $) "\\spad{reductum(u)} returns \\spad{u} minus its leading monomial returns zero if handed the zero element.")) (|monomial| (($ |#2| |#3|) "\\spad{monomial(r,{}e)} makes a term from a coefficient \\spad{r} and an exponent \\spad{e}.")) (|monomial?| (((|Boolean|) $) "\\spad{monomial?(p)} tests if \\spad{p} is a single monomial.")) (|map| (($ (|Mapping| |#2| |#2|) $) "\\spad{map(fn,{}u)} maps function \\spad{fn} onto the coefficients of the non-zero monomials of \\spad{u}.")) (|degree| ((|#3| $) "\\spad{degree(p)} returns the maximum of the exponents of the terms of \\spad{p}.")) (|leadingMonomial| (($ $) "\\spad{leadingMonomial(p)} returns the monomial of \\spad{p} with the highest degree.")) (|leadingCoefficient| ((|#2| $) "\\spad{leadingCoefficient(p)} returns the coefficient highest degree term of \\spad{p}."))) 
 NIL 
 ((|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-365)))) 
 (-52 R E) 
 ((|constructor| (NIL "Abelian monoid ring elements (not necessarily of finite support) of this ring are of the form formal SUM (r_i * e_i) where the r_i are coefficents and the e_i,{} elements of the ordered abelian monoid,{} are thought of as exponents or monomials. The monomials commute with each other,{} and with the coefficients (which themselves may or may not be commutative). See \\spadtype{FiniteAbelianMonoidRing} for the case of finite support a useful common model for polynomials and power series. Conceptually at least,{} only the non-zero terms are ever operated on.")) (/ (($ $ |#1|) "\\spad{p/c} divides \\spad{p} by the coefficient \\spad{c}.")) (|coefficient| ((|#1| $ |#2|) "\\spad{coefficient(p,{}e)} extracts the coefficient of the monomial with exponent \\spad{e} from polynomial \\spad{p},{} or returns zero if exponent is not present.")) (|reductum| (($ $) "\\spad{reductum(u)} returns \\spad{u} minus its leading monomial returns zero if handed the zero element.")) (|monomial| (($ |#1| |#2|) "\\spad{monomial(r,{}e)} makes a term from a coefficient \\spad{r} and an exponent \\spad{e}.")) (|monomial?| (((|Boolean|) $) "\\spad{monomial?(p)} tests if \\spad{p} is a single monomial.")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\spad{map(fn,{}u)} maps function \\spad{fn} onto the coefficients of the non-zero monomials of \\spad{u}.")) (|degree| ((|#2| $) "\\spad{degree(p)} returns the maximum of the exponents of the terms of \\spad{p}.")) (|leadingMonomial| (($ $) "\\spad{leadingMonomial(p)} returns the monomial of \\spad{p} with the highest degree.")) (|leadingCoefficient| ((|#1| $) "\\spad{leadingCoefficient(p)} returns the coefficient highest degree term of \\spad{p}."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4513 . T) (-4514 . T) (-4516 . T)) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-53) 
 ((|constructor| (NIL "Algebraic closure of the rational numbers,{} with mathematical =")) (|norm| (($ $ (|List| (|Kernel| $))) "\\spad{norm(f,{}l)} computes the norm of the algebraic number \\spad{f} with respect to the extension generated by kernels \\spad{l}") (($ $ (|Kernel| $)) "\\spad{norm(f,{}k)} computes the norm of the algebraic number \\spad{f} with respect to the extension generated by kernel \\spad{k}") (((|SparseUnivariatePolynomial| $) (|SparseUnivariatePolynomial| $) (|List| (|Kernel| $))) "\\spad{norm(p,{}l)} computes the norm of the polynomial \\spad{p} with respect to the extension generated by kernels \\spad{l}") (((|SparseUnivariatePolynomial| $) (|SparseUnivariatePolynomial| $) (|Kernel| $)) "\\spad{norm(p,{}k)} computes the norm of the polynomial \\spad{p} with respect to the extension generated by kernel \\spad{k}")) (|reduce| (($ $) "\\spad{reduce(f)} simplifies all the unreduced algebraic numbers present in \\spad{f} by applying their defining relations.")) (|denom| (((|SparseMultivariatePolynomial| (|Integer|) (|Kernel| $)) $) "\\spad{denom(f)} returns the denominator of \\spad{f} viewed as a polynomial in the kernels over \\spad{Z}.")) (|numer| (((|SparseMultivariatePolynomial| (|Integer|) (|Kernel| $)) $) "\\spad{numer(f)} returns the numerator of \\spad{f} viewed as a polynomial in the kernels over \\spad{Z}.")) (|coerce| (($ (|SparseMultivariatePolynomial| (|Integer|) (|Kernel| $))) "\\spad{coerce(p)} returns \\spad{p} viewed as an algebraic number."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 ((|HasCategory| $ (QUOTE (-1047))) (|HasCategory| $ (LIST (QUOTE -1037) (QUOTE (-568))))) 
 (-54) 
 ((|constructor| (NIL "This domain implements anonymous functions"))) 
@@ -150,7 +150,7 @@ NIL
 NIL 
 (-55 R |lVar|) 
 ((|constructor| (NIL "The domain of antisymmetric polynomials.")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\spad{map(f,{}p)} changes each coefficient of \\spad{p} by the application of \\spad{f}.")) (|degree| (((|NonNegativeInteger|) $) "\\spad{degree(p)} returns the homogeneous degree of \\spad{p}.")) (|retractable?| (((|Boolean|) $) "\\spad{retractable?(p)} tests if \\spad{p} is a 0-form,{} \\spadignore{i.e.} if degree(\\spad{p}) = 0.")) (|homogeneous?| (((|Boolean|) $) "\\spad{homogeneous?(p)} tests if all of the terms of \\spad{p} have the same degree.")) (|exp| (($ (|List| (|Integer|))) "\\spad{exp([i1,{}...in])} returns \\spad{u_1\\^{i_1} ... u_n\\^{i_n}}")) (|generator| (($ (|NonNegativeInteger|)) "\\spad{generator(n)} returns the \\spad{n}th multiplicative generator,{} a basis term.")) (|coefficient| ((|#1| $ $) "\\spad{coefficient(p,{}u)} returns the coefficient of the term in \\spad{p} containing the basis term \\spad{u} if such a term exists,{} and 0 otherwise. Error: if the second argument \\spad{u} is not a basis element.")) (|reductum| (($ $) "\\spad{reductum(p)},{} where \\spad{p} is an antisymmetric polynomial,{} returns \\spad{p} minus the leading term of \\spad{p} if \\spad{p} has at least two terms,{} and 0 otherwise.")) (|leadingBasisTerm| (($ $) "\\spad{leadingBasisTerm(p)} returns the leading basis term of antisymmetric polynomial \\spad{p}.")) (|leadingCoefficient| ((|#1| $) "\\spad{leadingCoefficient(p)} returns the leading coefficient of antisymmetric polynomial \\spad{p}."))) 
-((-4516 . T)) 
+((-4518 . T)) 
 NIL 
 (-56 S) 
 ((|constructor| (NIL "\\spadtype{AnyFunctions1} implements several utility functions for working with \\spadtype{Any}. These functions are used to go back and forth between objects of \\spadtype{Any} and objects of other types.")) (|retract| ((|#1| (|Any|)) "\\spad{retract(a)} tries to convert \\spad{a} into an object of type \\spad{S}. If possible,{} it returns the object. Error: if no such retraction is possible.")) (|retractable?| (((|Boolean|) (|Any|)) "\\spad{retractable?(a)} tests if \\spad{a} can be converted into an object of type \\spad{S}.")) (|retractIfCan| (((|Union| |#1| "failed") (|Any|)) "\\spad{retractIfCan(a)} tries change \\spad{a} into an object of type \\spad{S}. If it can,{} then such an object is returned. Otherwise,{} \"failed\" is returned.")) (|coerce| (((|Any|) |#1|) "\\spad{coerce(s)} creates an object of \\spadtype{Any} from the object \\spad{s} of type \\spad{S}."))) 
@@ -178,7 +178,7 @@ NIL
 NIL 
 (-62 R |Row| |Col|) 
 ((|constructor| (NIL "Two dimensional array categories and domains")) (|map!| (($ (|Mapping| |#1| |#1|) $) "\\indented{1}{map!(\\spad{f},{}a)\\space{2}assign \\spad{a(i,{}j)} to \\spad{f(a(i,{}j))}} \\indented{1}{for all \\spad{i,{} j}} \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,{}4,{}10) \\spad{X} map!(-,{}arr)")) (|map| (($ (|Mapping| |#1| |#1| |#1|) $ $ |#1|) "\\indented{1}{map(\\spad{f},{}a,{}\\spad{b},{}\\spad{r}) returns \\spad{c},{} where \\spad{c(i,{}j) = f(a(i,{}j),{}b(i,{}j))}} \\indented{1}{when both \\spad{a(i,{}j)} and \\spad{b(i,{}j)} exist;} \\indented{1}{else \\spad{c(i,{}j) = f(r,{} b(i,{}j))} when \\spad{a(i,{}j)} does not exist;} \\indented{1}{else \\spad{c(i,{}j) = f(a(i,{}j),{}r)} when \\spad{b(i,{}j)} does not exist;} \\indented{1}{otherwise \\spad{c(i,{}j) = f(r,{}r)}.} \\blankline \\spad{X} adder(a:Integer,{}b:Integer):Integer \\spad{==} a+b \\spad{X} \\spad{arr1} : \\spad{ARRAY2} INT \\spad{:=} new(5,{}4,{}10) \\spad{X} \\spad{arr2} : \\spad{ARRAY2} INT \\spad{:=} new(3,{}3,{}10) \\spad{X} map(adder,{}\\spad{arr1},{}\\spad{arr2},{}17)") (($ (|Mapping| |#1| |#1| |#1|) $ $) "\\indented{1}{map(\\spad{f},{}a,{}\\spad{b}) returns \\spad{c},{} where \\spad{c(i,{}j) = f(a(i,{}j),{}b(i,{}j))}} \\indented{1}{for all \\spad{i,{} j}} \\blankline \\spad{X} adder(a:Integer,{}b:Integer):Integer \\spad{==} a+b \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,{}4,{}10) \\spad{X} map(adder,{}arr,{}arr)") (($ (|Mapping| |#1| |#1|) $) "\\indented{1}{map(\\spad{f},{}a) returns \\spad{b},{} where \\spad{b(i,{}j) = f(a(i,{}j))}} \\indented{1}{for all \\spad{i,{} j}} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,{}4,{}10) \\spad{X} map(-,{}arr) \\spad{X} map((\\spad{x} +-> \\spad{x} + \\spad{x}),{}arr)")) (|setColumn!| (($ $ (|Integer|) |#3|) "\\indented{1}{setColumn!(\\spad{m},{}\\spad{j},{}\\spad{v}) sets to \\spad{j}th column of \\spad{m} to \\spad{v}} \\blankline \\spad{X} T1:=TwoDimensionalArray Integer \\spad{X} arr:T1:= new(5,{}4,{}0) \\spad{X} T2:=OneDimensionalArray Integer \\spad{X} acol:=construct([1,{}2,{}3,{}4,{}5]::List(INT))\\$\\spad{T2} \\spad{X} setColumn!(arr,{}1,{}acol)\\$\\spad{T1}")) (|setRow!| (($ $ (|Integer|) |#2|) "\\indented{1}{setRow!(\\spad{m},{}\\spad{i},{}\\spad{v}) sets to \\spad{i}th row of \\spad{m} to \\spad{v}} \\blankline \\spad{X} T1:=TwoDimensionalArray Integer \\spad{X} arr:T1:= new(5,{}4,{}0) \\spad{X} T2:=OneDimensionalArray Integer \\spad{X} arow:=construct([1,{}2,{}3,{}4]::List(INT))\\$\\spad{T2} \\spad{X} setRow!(arr,{}1,{}arow)\\$\\spad{T1}")) (|qsetelt!| ((|#1| $ (|Integer|) (|Integer|) |#1|) "\\indented{1}{qsetelt!(\\spad{m},{}\\spad{i},{}\\spad{j},{}\\spad{r}) sets the element in the \\spad{i}th row and \\spad{j}th} \\indented{1}{column of \\spad{m} to \\spad{r}} \\indented{1}{NO error check to determine if indices are in proper ranges} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,{}4,{}0) \\spad{X} qsetelt!(arr,{}1,{}1,{}17)")) (|setelt| ((|#1| $ (|Integer|) (|Integer|) |#1|) "\\indented{1}{setelt(\\spad{m},{}\\spad{i},{}\\spad{j},{}\\spad{r}) sets the element in the \\spad{i}th row and \\spad{j}th} \\indented{1}{column of \\spad{m} to \\spad{r}} \\indented{1}{error check to determine if indices are in proper ranges} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,{}4,{}0) \\spad{X} setelt(arr,{}1,{}1,{}17)")) (|parts| (((|List| |#1|) $) "\\indented{1}{parts(\\spad{m}) returns a list of the elements of \\spad{m} in row major order} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,{}4,{}10) \\spad{X} parts(arr)")) (|column| ((|#3| $ (|Integer|)) "\\indented{1}{column(\\spad{m},{}\\spad{j}) returns the \\spad{j}th column of \\spad{m}} \\indented{1}{error check to determine if index is in proper ranges} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,{}4,{}10) \\spad{X} column(arr,{}1)")) (|row| ((|#2| $ (|Integer|)) "\\indented{1}{row(\\spad{m},{}\\spad{i}) returns the \\spad{i}th row of \\spad{m}} \\indented{1}{error check to determine if index is in proper ranges} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,{}4,{}10) \\spad{X} row(arr,{}1)")) (|qelt| ((|#1| $ (|Integer|) (|Integer|)) "\\indented{1}{qelt(\\spad{m},{}\\spad{i},{}\\spad{j}) returns the element in the \\spad{i}th row and \\spad{j}th} \\indented{1}{column of the array \\spad{m}} \\indented{1}{NO error check to determine if indices are in proper ranges} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,{}4,{}10) \\spad{X} qelt(arr,{}1,{}1)")) (|elt| ((|#1| $ (|Integer|) (|Integer|) |#1|) "\\indented{1}{elt(\\spad{m},{}\\spad{i},{}\\spad{j},{}\\spad{r}) returns the element in the \\spad{i}th row and \\spad{j}th} \\indented{1}{column of the array \\spad{m},{} if \\spad{m} has an \\spad{i}th row and a \\spad{j}th column,{}} \\indented{1}{and returns \\spad{r} otherwise} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,{}4,{}10) \\spad{X} elt(arr,{}1,{}1,{}6) \\spad{X} elt(arr,{}1,{}10,{}6)") ((|#1| $ (|Integer|) (|Integer|)) "\\indented{1}{elt(\\spad{m},{}\\spad{i},{}\\spad{j}) returns the element in the \\spad{i}th row and \\spad{j}th} \\indented{1}{column of the array \\spad{m}} \\indented{1}{error check to determine if indices are in proper ranges} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,{}4,{}10) \\spad{X} elt(arr,{}1,{}1)")) (|ncols| (((|NonNegativeInteger|) $) "\\indented{1}{ncols(\\spad{m}) returns the number of columns in the array \\spad{m}} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,{}4,{}10) \\spad{X} ncols(arr)")) (|nrows| (((|NonNegativeInteger|) $) "\\indented{1}{nrows(\\spad{m}) returns the number of rows in the array \\spad{m}} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,{}4,{}10) \\spad{X} nrows(arr)")) (|maxColIndex| (((|Integer|) $) "\\indented{1}{maxColIndex(\\spad{m}) returns the index of the 'last' column of the array \\spad{m}} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,{}4,{}10) \\spad{X} maxColIndex(arr)")) (|minColIndex| (((|Integer|) $) "\\indented{1}{minColIndex(\\spad{m}) returns the index of the 'first' column of the array \\spad{m}} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,{}4,{}10) \\spad{X} minColIndex(arr)")) (|maxRowIndex| (((|Integer|) $) "\\indented{1}{maxRowIndex(\\spad{m}) returns the index of the 'last' row of the array \\spad{m}} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,{}4,{}10) \\spad{X} maxRowIndex(arr)")) (|minRowIndex| (((|Integer|) $) "\\indented{1}{minRowIndex(\\spad{m}) returns the index of the 'first' row of the array \\spad{m}} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,{}4,{}10) \\spad{X} minRowIndex(arr)")) (|fill!| (($ $ |#1|) "\\indented{1}{fill!(\\spad{m},{}\\spad{r}) fills \\spad{m} with \\spad{r}\\spad{'s}} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,{}4,{}0) \\spad{X} fill!(arr,{}10)")) (|new| (($ (|NonNegativeInteger|) (|NonNegativeInteger|) |#1|) "\\indented{1}{new(\\spad{m},{}\\spad{n},{}\\spad{r}) is an \\spad{m}-by-\\spad{n} array all of whose entries are \\spad{r}} \\blankline \\spad{X} arr : \\spad{ARRAY2} INT \\spad{:=} new(5,{}4,{}0)")) (|finiteAggregate| ((|attribute|) "two-dimensional arrays are finite")) (|shallowlyMutable| ((|attribute|) "one may destructively alter arrays"))) 
-((-4519 . T) (-4520 . T) (-3973 . T)) 
+((-4521 . T) (-4522 . T) (-3973 . T)) 
 NIL 
 (-63 A B) 
 ((|constructor| (NIL "This package provides tools for operating on one-dimensional arrays with unary and binary functions involving different underlying types")) (|map| (((|OneDimensionalArray| |#2|) (|Mapping| |#2| |#1|) (|OneDimensionalArray| |#1|)) "\\indented{1}{map(\\spad{f},{}a) applies function \\spad{f} to each member of one-dimensional array} \\indented{1}{\\spad{a} resulting in a new one-dimensional array over a} \\indented{1}{possibly different underlying domain.} \\blankline \\spad{X} \\spad{T1:=OneDimensionalArrayFunctions2}(Integer,{}Integer) \\spad{X} map(\\spad{x+}-\\spad{>x+2},{}[\\spad{i} for \\spad{i} in 1..10])\\$\\spad{T1}")) (|reduce| ((|#2| (|Mapping| |#2| |#1| |#2|) (|OneDimensionalArray| |#1|) |#2|) "\\indented{1}{reduce(\\spad{f},{}a,{}\\spad{r}) applies function \\spad{f} to each} \\indented{1}{successive element of the} \\indented{1}{one-dimensional array \\spad{a} and an accumulant initialized to \\spad{r}.} \\indented{1}{For example,{} \\spad{reduce(_+\\$Integer,{}[1,{}2,{}3],{}0)}} \\indented{1}{does \\spad{3+(2+(1+0))}. Note that third argument \\spad{r}} \\indented{1}{may be regarded as the identity element for the function \\spad{f}.} \\blankline \\spad{X} \\spad{T1:=OneDimensionalArrayFunctions2}(Integer,{}Integer) \\spad{X} adder(a:Integer,{}b:Integer):Integer \\spad{==} a+b \\spad{X} reduce(adder,{}[\\spad{i} for \\spad{i} in 1..10],{}0)\\$\\spad{T1}")) (|scan| (((|OneDimensionalArray| |#2|) (|Mapping| |#2| |#1| |#2|) (|OneDimensionalArray| |#1|) |#2|) "\\indented{1}{scan(\\spad{f},{}a,{}\\spad{r}) successively applies} \\indented{1}{\\spad{reduce(f,{}x,{}r)} to more and more leading sub-arrays} \\indented{1}{\\spad{x} of one-dimensional array \\spad{a}.} \\indented{1}{More precisely,{} if \\spad{a} is \\spad{[a1,{}a2,{}...]},{} then} \\indented{1}{\\spad{scan(f,{}a,{}r)} returns} \\indented{1}{\\spad{[reduce(f,{}[a1],{}r),{}reduce(f,{}[a1,{}a2],{}r),{}...]}.} \\blankline \\spad{X} \\spad{T1:=OneDimensionalArrayFunctions2}(Integer,{}Integer) \\spad{X} adder(a:Integer,{}b:Integer):Integer \\spad{==} a+b \\spad{X} scan(adder,{}[\\spad{i} for \\spad{i} in 1..10],{}0)\\$\\spad{T1}"))) 
@@ -186,65 +186,65 @@ NIL
 NIL 
 (-64 S) 
 ((|constructor| (NIL "This is the domain of 1-based one dimensional arrays")) (|oneDimensionalArray| (($ (|NonNegativeInteger|) |#1|) "\\indented{1}{oneDimensionalArray(\\spad{n},{}\\spad{s}) creates an array from \\spad{n} copies of element \\spad{s}} \\blankline \\spad{X} oneDimensionalArray(10,{}0.0)") (($ (|List| |#1|)) "\\indented{1}{oneDimensionalArray(\\spad{l}) creates an array from a list of elements \\spad{l}} \\blankline \\spad{X} oneDimensionalArray [\\spad{i**2} for \\spad{i} in 1..10]"))) 
-((-4520 . T) (-4519 . T)) 
-((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (-2198 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
+((-4522 . T) (-4521 . T)) 
+((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (-2199 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
 (-65 R) 
 ((|constructor| (NIL "A TwoDimensionalArray is a two dimensional array with 1-based indexing for both rows and columns.")) (|shallowlyMutable| ((|attribute|) "One may destructively alter TwoDimensionalArray\\spad{'s}."))) 
-((-4519 . T) (-4520 . T)) 
+((-4521 . T) (-4522 . T)) 
 ((|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090))))) 
-(-66 -3391) 
+(-66 -3393) 
 ((|constructor| (NIL "\\spadtype{ASP10} produces Fortran for Type 10 ASPs,{} needed for NAG routine d02kef. This ASP computes the values of a set of functions,{} for example: \\blankline \\tab{5}SUBROUTINE COEFFN(\\spad{P},{}\\spad{Q},{}DQDL,{}\\spad{X},{}ELAM,{}JINT)\\spad{\\br} \\tab{5}DOUBLE PRECISION ELAM,{}\\spad{P},{}\\spad{Q},{}\\spad{X},{}DQDL\\spad{\\br} \\tab{5}INTEGER JINT\\spad{\\br} \\tab{5}\\spad{P=1}.0D0\\spad{\\br} \\tab{5}\\spad{Q=}((\\spad{-1}.0D0*X**3)+ELAM*X*X-2.0D0)/(\\spad{X*X})\\spad{\\br} \\tab{5}\\spad{DQDL=1}.0D0\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END")) (|coerce| (($ (|Vector| (|FortranExpression| (|construct| (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (|construct|) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-67 -3391) 
+(-67 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp12} produces Fortran for Type 12 ASPs,{} needed for NAG routine d02kef etc.,{} for example: \\blankline \\tab{5}SUBROUTINE MONIT (MAXIT,{}IFLAG,{}ELAM,{}FINFO)\\spad{\\br} \\tab{5}DOUBLE PRECISION ELAM,{}FINFO(15)\\spad{\\br} \\tab{5}INTEGER MAXIT,{}IFLAG\\spad{\\br} \\tab{5}IF(MAXIT.EQ.\\spad{-1})THEN\\spad{\\br} \\tab{7}PRINT*,{}\"Output from Monit\"\\spad{\\br} \\tab{5}ENDIF\\spad{\\br} \\tab{5}PRINT*,{}MAXIT,{}IFLAG,{}ELAM,{}(FINFO(\\spad{I}),{}\\spad{I=1},{}4)\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END\\")) (|outputAsFortran| (((|Void|)) "\\spad{outputAsFortran()} generates the default code for \\spadtype{ASP12}."))) 
 NIL 
 NIL 
-(-68 -3391) 
+(-68 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp19} produces Fortran for Type 19 ASPs,{} evaluating a set of functions and their jacobian at a given point,{} for example: \\blankline \\tab{5}SUBROUTINE \\spad{LSFUN2}(\\spad{M},{}\\spad{N},{}\\spad{XC},{}FVECC,{}FJACC,{}\\spad{LJC})\\spad{\\br} \\tab{5}DOUBLE PRECISION FVECC(\\spad{M}),{}FJACC(\\spad{LJC},{}\\spad{N}),{}\\spad{XC}(\\spad{N})\\spad{\\br} \\tab{5}INTEGER \\spad{M},{}\\spad{N},{}\\spad{LJC}\\spad{\\br} \\tab{5}INTEGER \\spad{I},{}\\spad{J}\\spad{\\br} \\tab{5}DO 25003 \\spad{I=1},{}\\spad{LJC}\\spad{\\br} \\tab{7}DO 25004 \\spad{J=1},{}\\spad{N}\\spad{\\br} \\tab{9}FJACC(\\spad{I},{}\\spad{J})\\spad{=0}.0D0\\spad{\\br} 25004 CONTINUE\\spad{\\br} 25003 CONTINUE\\spad{\\br} \\tab{5}FVECC(1)=((\\spad{XC}(1)\\spad{-0}.14D0)\\spad{*XC}(3)+(15.0D0*XC(1)\\spad{-2}.1D0)\\spad{*XC}(2)\\spad{+1}.0D0)/(\\spad{\\br} \\tab{4}\\spad{&XC}(3)\\spad{+15}.0D0*XC(2))\\spad{\\br} \\tab{5}FVECC(2)=((\\spad{XC}(1)\\spad{-0}.18D0)\\spad{*XC}(3)+(7.0D0*XC(1)\\spad{-1}.26D0)\\spad{*XC}(2)\\spad{+1}.0D0)/(\\spad{\\br} \\tab{4}\\spad{&XC}(3)\\spad{+7}.0D0*XC(2))\\spad{\\br} \\tab{5}FVECC(3)=((\\spad{XC}(1)\\spad{-0}.22D0)\\spad{*XC}(3)+(4.333333333333333D0*XC(1)\\spad{-0}.953333\\spad{\\br} \\tab{4}\\spad{&3333333333D0})\\spad{*XC}(2)\\spad{+1}.0D0)/(\\spad{XC}(3)\\spad{+4}.333333333333333D0*XC(2))\\spad{\\br} \\tab{5}FVECC(4)=((\\spad{XC}(1)\\spad{-0}.25D0)\\spad{*XC}(3)+(3.0D0*XC(1)\\spad{-0}.75D0)\\spad{*XC}(2)\\spad{+1}.0D0)/(\\spad{\\br} \\tab{4}\\spad{&XC}(3)\\spad{+3}.0D0*XC(2))\\spad{\\br} \\tab{5}FVECC(5)=((\\spad{XC}(1)\\spad{-0}.29D0)\\spad{*XC}(3)+(2.2D0*XC(1)\\spad{-0}.6379999999999999D0)*\\spad{\\br} \\tab{4}\\spad{&XC}(2)\\spad{+1}.0D0)/(\\spad{XC}(3)\\spad{+2}.2D0*XC(2))\\spad{\\br} \\tab{5}FVECC(6)=((\\spad{XC}(1)\\spad{-0}.32D0)\\spad{*XC}(3)+(1.666666666666667D0*XC(1)\\spad{-0}.533333\\spad{\\br} \\tab{4}\\spad{&3333333333D0})\\spad{*XC}(2)\\spad{+1}.0D0)/(\\spad{XC}(3)\\spad{+1}.666666666666667D0*XC(2))\\spad{\\br} \\tab{5}FVECC(7)=((\\spad{XC}(1)\\spad{-0}.35D0)\\spad{*XC}(3)+(1.285714285714286D0*XC(1)\\spad{-0}.45D0)*\\spad{\\br} \\tab{4}\\spad{&XC}(2)\\spad{+1}.0D0)/(\\spad{XC}(3)\\spad{+1}.285714285714286D0*XC(2))\\spad{\\br} \\tab{5}FVECC(8)=((\\spad{XC}(1)\\spad{-0}.39D0)\\spad{*XC}(3)+(\\spad{XC}(1)\\spad{-0}.39D0)\\spad{*XC}(2)\\spad{+1}.0D0)/(\\spad{XC}(3)+\\spad{\\br} \\tab{4}\\spad{&XC}(2))\\spad{\\br} \\tab{5}FVECC(9)=((\\spad{XC}(1)\\spad{-0}.37D0)\\spad{*XC}(3)+(\\spad{XC}(1)\\spad{-0}.37D0)\\spad{*XC}(2)\\spad{+1}.285714285714\\spad{\\br} \\tab{4}\\spad{&286D0})/(\\spad{XC}(3)\\spad{+XC}(2))\\spad{\\br} \\tab{5}FVECC(10)=((\\spad{XC}(1)\\spad{-0}.58D0)\\spad{*XC}(3)+(\\spad{XC}(1)\\spad{-0}.58D0)\\spad{*XC}(2)\\spad{+1}.66666666666\\spad{\\br} \\tab{4}\\spad{&6667D0})/(\\spad{XC}(3)\\spad{+XC}(2))\\spad{\\br} \\tab{5}FVECC(11)=((\\spad{XC}(1)\\spad{-0}.73D0)\\spad{*XC}(3)+(\\spad{XC}(1)\\spad{-0}.73D0)\\spad{*XC}(2)\\spad{+2}.2D0)/(\\spad{XC}(3)\\spad{\\br} \\tab{4}&+XC(2))\\spad{\\br} \\tab{5}FVECC(12)=((\\spad{XC}(1)\\spad{-0}.96D0)\\spad{*XC}(3)+(\\spad{XC}(1)\\spad{-0}.96D0)\\spad{*XC}(2)\\spad{+3}.0D0)/(\\spad{XC}(3)\\spad{\\br} \\tab{4}&+XC(2))\\spad{\\br} \\tab{5}FVECC(13)=((\\spad{XC}(1)\\spad{-1}.34D0)\\spad{*XC}(3)+(\\spad{XC}(1)\\spad{-1}.34D0)\\spad{*XC}(2)\\spad{+4}.33333333333\\spad{\\br} \\tab{4}\\spad{&3333D0})/(\\spad{XC}(3)\\spad{+XC}(2))\\spad{\\br} \\tab{5}FVECC(14)=((\\spad{XC}(1)\\spad{-2}.1D0)\\spad{*XC}(3)+(\\spad{XC}(1)\\spad{-2}.1D0)\\spad{*XC}(2)\\spad{+7}.0D0)/(\\spad{XC}(3)\\spad{+X}\\spad{\\br} \\tab{4}\\spad{&C}(2))\\spad{\\br} \\tab{5}FVECC(15)=((\\spad{XC}(1)\\spad{-4}.39D0)\\spad{*XC}(3)+(\\spad{XC}(1)\\spad{-4}.39D0)\\spad{*XC}(2)\\spad{+15}.0D0)/(\\spad{XC}(3\\spad{\\br} \\tab{4}&)\\spad{+XC}(2))\\spad{\\br} \\tab{5}FJACC(1,{}1)\\spad{=1}.0D0\\spad{\\br} \\tab{5}FJACC(1,{}2)=-15.0D0/(\\spad{XC}(3)\\spad{**2+30}.0D0*XC(2)\\spad{*XC}(3)\\spad{+225}.0D0*XC(2)\\spad{**2})\\spad{\\br} \\tab{5}FJACC(1,{}3)=-1.0D0/(\\spad{XC}(3)\\spad{**2+30}.0D0*XC(2)\\spad{*XC}(3)\\spad{+225}.0D0*XC(2)\\spad{**2})\\spad{\\br} \\tab{5}FJACC(2,{}1)\\spad{=1}.0D0\\spad{\\br} \\tab{5}FJACC(2,{}2)=-7.0D0/(\\spad{XC}(3)\\spad{**2+14}.0D0*XC(2)\\spad{*XC}(3)\\spad{+49}.0D0*XC(2)\\spad{**2})\\spad{\\br} \\tab{5}FJACC(2,{}3)=-1.0D0/(\\spad{XC}(3)\\spad{**2+14}.0D0*XC(2)\\spad{*XC}(3)\\spad{+49}.0D0*XC(2)\\spad{**2})\\spad{\\br} \\tab{5}FJACC(3,{}1)\\spad{=1}.0D0\\spad{\\br} \\tab{5}FJACC(3,{}2)=((\\spad{-0}.1110223024625157D-15*XC(3))\\spad{-4}.333333333333333D0)/(\\spad{\\br} \\tab{4}\\spad{&XC}(3)\\spad{**2+8}.666666666666666D0*XC(2)\\spad{*XC}(3)\\spad{+18}.77777777777778D0*XC(2)\\spad{\\br} \\tab{4}\\spad{&**2})\\spad{\\br} \\tab{5}FJACC(3,{}3)=(0.1110223024625157D-15*XC(2)\\spad{-1}.0D0)/(\\spad{XC}(3)\\spad{**2+8}.666666\\spad{\\br} \\tab{4}&666666666D0*XC(2)\\spad{*XC}(3)\\spad{+18}.77777777777778D0*XC(2)\\spad{**2})\\spad{\\br} \\tab{5}FJACC(4,{}1)\\spad{=1}.0D0\\spad{\\br} \\tab{5}FJACC(4,{}2)=-3.0D0/(\\spad{XC}(3)\\spad{**2+6}.0D0*XC(2)\\spad{*XC}(3)\\spad{+9}.0D0*XC(2)\\spad{**2})\\spad{\\br} \\tab{5}FJACC(4,{}3)=-1.0D0/(\\spad{XC}(3)\\spad{**2+6}.0D0*XC(2)\\spad{*XC}(3)\\spad{+9}.0D0*XC(2)\\spad{**2})\\spad{\\br} \\tab{5}FJACC(5,{}1)\\spad{=1}.0D0\\spad{\\br} \\tab{5}FJACC(5,{}2)=((\\spad{-0}.1110223024625157D-15*XC(3))\\spad{-2}.2D0)/(\\spad{XC}(3)\\spad{**2+4}.399\\spad{\\br} \\tab{4}&999999999999D0*XC(2)\\spad{*XC}(3)\\spad{+4}.839999999999998D0*XC(2)\\spad{**2})\\spad{\\br} \\tab{5}FJACC(5,{}3)=(0.1110223024625157D-15*XC(2)\\spad{-1}.0D0)/(\\spad{XC}(3)\\spad{**2+4}.399999\\spad{\\br} \\tab{4}&999999999D0*XC(2)\\spad{*XC}(3)\\spad{+4}.839999999999998D0*XC(2)\\spad{**2})\\spad{\\br} \\tab{5}FJACC(6,{}1)\\spad{=1}.0D0\\spad{\\br} \\tab{5}FJACC(6,{}2)=((\\spad{-0}.2220446049250313D-15*XC(3))\\spad{-1}.666666666666667D0)/(\\spad{\\br} \\tab{4}\\spad{&XC}(3)\\spad{**2+3}.333333333333333D0*XC(2)\\spad{*XC}(3)\\spad{+2}.777777777777777D0*XC(2)\\spad{\\br} \\tab{4}\\spad{&**2})\\spad{\\br} \\tab{5}FJACC(6,{}3)=(0.2220446049250313D-15*XC(2)\\spad{-1}.0D0)/(\\spad{XC}(3)\\spad{**2+3}.333333\\spad{\\br} \\tab{4}&333333333D0*XC(2)\\spad{*XC}(3)\\spad{+2}.777777777777777D0*XC(2)\\spad{**2})\\spad{\\br} \\tab{5}FJACC(7,{}1)\\spad{=1}.0D0\\spad{\\br} \\tab{5}FJACC(7,{}2)=((\\spad{-0}.5551115123125783D-16*XC(3))\\spad{-1}.285714285714286D0)/(\\spad{\\br} \\tab{4}\\spad{&XC}(3)\\spad{**2+2}.571428571428571D0*XC(2)\\spad{*XC}(3)\\spad{+1}.653061224489796D0*XC(2)\\spad{\\br} \\tab{4}\\spad{&**2})\\spad{\\br} \\tab{5}FJACC(7,{}3)=(0.5551115123125783D-16*XC(2)\\spad{-1}.0D0)/(\\spad{XC}(3)\\spad{**2+2}.571428\\spad{\\br} \\tab{4}&571428571D0*XC(2)\\spad{*XC}(3)\\spad{+1}.653061224489796D0*XC(2)\\spad{**2})\\spad{\\br} \\tab{5}FJACC(8,{}1)\\spad{=1}.0D0\\spad{\\br} \\tab{5}FJACC(8,{}2)=-1.0D0/(\\spad{XC}(3)\\spad{**2+2}.0D0*XC(2)\\spad{*XC}(3)\\spad{+XC}(2)\\spad{**2})\\spad{\\br} \\tab{5}FJACC(8,{}3)=-1.0D0/(\\spad{XC}(3)\\spad{**2+2}.0D0*XC(2)\\spad{*XC}(3)\\spad{+XC}(2)\\spad{**2})\\spad{\\br} \\tab{5}FJACC(9,{}1)\\spad{=1}.0D0\\spad{\\br} \\tab{5}FJACC(9,{}2)=-1.285714285714286D0/(\\spad{XC}(3)\\spad{**2+2}.0D0*XC(2)\\spad{*XC}(3)\\spad{+XC}(2)*\\spad{\\br} \\tab{4}\\spad{&*2})\\spad{\\br} \\tab{5}FJACC(9,{}3)=-1.285714285714286D0/(\\spad{XC}(3)\\spad{**2+2}.0D0*XC(2)\\spad{*XC}(3)\\spad{+XC}(2)*\\spad{\\br} \\tab{4}\\spad{&*2})\\spad{\\br} \\tab{5}FJACC(10,{}1)\\spad{=1}.0D0\\spad{\\br} \\tab{5}FJACC(10,{}2)=-1.666666666666667D0/(\\spad{XC}(3)\\spad{**2+2}.0D0*XC(2)\\spad{*XC}(3)\\spad{+XC}(2)\\spad{\\br} \\tab{4}\\spad{&**2})\\spad{\\br} \\tab{5}FJACC(10,{}3)=-1.666666666666667D0/(\\spad{XC}(3)\\spad{**2+2}.0D0*XC(2)\\spad{*XC}(3)\\spad{+XC}(2)\\spad{\\br} \\tab{4}\\spad{&**2})\\spad{\\br} \\tab{5}FJACC(11,{}1)\\spad{=1}.0D0\\spad{\\br} \\tab{5}FJACC(11,{}2)=-2.2D0/(\\spad{XC}(3)\\spad{**2+2}.0D0*XC(2)\\spad{*XC}(3)\\spad{+XC}(2)\\spad{**2})\\spad{\\br} \\tab{5}FJACC(11,{}3)=-2.2D0/(\\spad{XC}(3)\\spad{**2+2}.0D0*XC(2)\\spad{*XC}(3)\\spad{+XC}(2)\\spad{**2})\\spad{\\br} \\tab{5}FJACC(12,{}1)\\spad{=1}.0D0\\spad{\\br} \\tab{5}FJACC(12,{}2)=-3.0D0/(\\spad{XC}(3)\\spad{**2+2}.0D0*XC(2)\\spad{*XC}(3)\\spad{+XC}(2)\\spad{**2})\\spad{\\br} \\tab{5}FJACC(12,{}3)=-3.0D0/(\\spad{XC}(3)\\spad{**2+2}.0D0*XC(2)\\spad{*XC}(3)\\spad{+XC}(2)\\spad{**2})\\spad{\\br} \\tab{5}FJACC(13,{}1)\\spad{=1}.0D0\\spad{\\br} \\tab{5}FJACC(13,{}2)=-4.333333333333333D0/(\\spad{XC}(3)\\spad{**2+2}.0D0*XC(2)\\spad{*XC}(3)\\spad{+XC}(2)\\spad{\\br} \\tab{4}\\spad{&**2})\\spad{\\br} \\tab{5}FJACC(13,{}3)=-4.333333333333333D0/(\\spad{XC}(3)\\spad{**2+2}.0D0*XC(2)\\spad{*XC}(3)\\spad{+XC}(2)\\spad{\\br} \\tab{4}\\spad{&**2})\\spad{\\br} \\tab{5}FJACC(14,{}1)\\spad{=1}.0D0\\spad{\\br} \\tab{5}FJACC(14,{}2)=-7.0D0/(\\spad{XC}(3)\\spad{**2+2}.0D0*XC(2)\\spad{*XC}(3)\\spad{+XC}(2)\\spad{**2})\\spad{\\br} \\tab{5}FJACC(14,{}3)=-7.0D0/(\\spad{XC}(3)\\spad{**2+2}.0D0*XC(2)\\spad{*XC}(3)\\spad{+XC}(2)\\spad{**2})\\spad{\\br} \\tab{5}FJACC(15,{}1)\\spad{=1}.0D0\\spad{\\br} \\tab{5}FJACC(15,{}2)=-15.0D0/(\\spad{XC}(3)\\spad{**2+2}.0D0*XC(2)\\spad{*XC}(3)\\spad{+XC}(2)\\spad{**2})\\spad{\\br} \\tab{5}FJACC(15,{}3)=-15.0D0/(\\spad{XC}(3)\\spad{**2+2}.0D0*XC(2)\\spad{*XC}(3)\\spad{+XC}(2)\\spad{**2})\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END")) (|coerce| (($ (|Vector| (|FortranExpression| (|construct|) (|construct| (QUOTE XC)) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-69 -3391) 
+(-69 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp1} produces Fortran for Type 1 ASPs,{} needed for various NAG routines. Type 1 ASPs take a univariate expression (in the symbol \\spad{x}) and turn it into a Fortran Function like the following: \\blankline \\tab{5}DOUBLE PRECISION FUNCTION \\spad{F}(\\spad{X})\\spad{\\br} \\tab{5}DOUBLE PRECISION \\spad{X}\\spad{\\br} \\tab{5}F=DSIN(\\spad{X})\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END")) (|coerce| (($ (|FortranExpression| (|construct| (QUOTE X)) (|construct|) (|MachineFloat|))) "\\spad{coerce(f)} takes an object from the appropriate instantiation of \\spadtype{FortranExpression} and turns it into an ASP."))) 
 NIL 
 NIL 
-(-70 -3391) 
+(-70 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp20} produces Fortran for Type 20 ASPs,{} for example: \\blankline \\tab{5}SUBROUTINE QPHESS(\\spad{N},{}NROWH,{}NCOLH,{}JTHCOL,{}HESS,{}\\spad{X},{}\\spad{HX})\\spad{\\br} \\tab{5}DOUBLE PRECISION \\spad{HX}(\\spad{N}),{}\\spad{X}(\\spad{N}),{}HESS(NROWH,{}NCOLH)\\spad{\\br} \\tab{5}INTEGER JTHCOL,{}\\spad{N},{}NROWH,{}NCOLH\\spad{\\br} \\tab{5}\\spad{HX}(1)\\spad{=2}.0D0*X(1)\\spad{\\br} \\tab{5}\\spad{HX}(2)\\spad{=2}.0D0*X(2)\\spad{\\br} \\tab{5}\\spad{HX}(3)\\spad{=2}.0D0*X(4)\\spad{+2}.0D0*X(3)\\spad{\\br} \\tab{5}\\spad{HX}(4)\\spad{=2}.0D0*X(4)\\spad{+2}.0D0*X(3)\\spad{\\br} \\tab{5}\\spad{HX}(5)\\spad{=2}.0D0*X(5)\\spad{\\br} \\tab{5}\\spad{HX}(6)=(\\spad{-2}.0D0*X(7))+(\\spad{-2}.0D0*X(6))\\spad{\\br} \\tab{5}\\spad{HX}(7)=(\\spad{-2}.0D0*X(7))+(\\spad{-2}.0D0*X(6))\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END")) (|coerce| (($ (|Matrix| (|FortranExpression| (|construct|) (|construct| (QUOTE X) (QUOTE HESS)) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-71 -3391) 
+(-71 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp24} produces Fortran for Type 24 ASPs which evaluate a multivariate function at a point (needed for NAG routine e04jaf),{} for example: \\blankline \\tab{5}SUBROUTINE \\spad{FUNCT1}(\\spad{N},{}\\spad{XC},{}\\spad{FC})\\spad{\\br} \\tab{5}DOUBLE PRECISION \\spad{FC},{}\\spad{XC}(\\spad{N})\\spad{\\br} \\tab{5}INTEGER \\spad{N}\\spad{\\br} \\tab{5}\\spad{FC=10}.0D0*XC(4)**4+(\\spad{-40}.0D0*XC(1)\\spad{*XC}(4)\\spad{**3})+(60.0D0*XC(1)\\spad{**2+5}\\spad{\\br} \\tab{4}&.0D0)\\spad{*XC}(4)**2+((\\spad{-10}.0D0*XC(3))+(\\spad{-40}.0D0*XC(1)\\spad{**3}))\\spad{*XC}(4)\\spad{+16}.0D0*X\\spad{\\br} \\tab{4}\\spad{&C}(3)**4+(\\spad{-32}.0D0*XC(2)\\spad{*XC}(3)\\spad{**3})+(24.0D0*XC(2)\\spad{**2+5}.0D0)\\spad{*XC}(3)**2+\\spad{\\br} \\tab{4}&(\\spad{-8}.0D0*XC(2)**3*XC(3))\\spad{+XC}(2)\\spad{**4+100}.0D0*XC(2)\\spad{**2+20}.0D0*XC(1)\\spad{*XC}(\\spad{\\br} \\tab{4}\\spad{&2})\\spad{+10}.0D0*XC(1)**4+XC(1)\\spad{**2}\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END\\spad{\\br}")) (|coerce| (($ (|FortranExpression| (|construct|) (|construct| (QUOTE XC)) (|MachineFloat|))) "\\spadtype{FortranExpression} and turns it into an ASP. coerce(\\spad{f}) takes an object from the appropriate instantiation of"))) 
 NIL 
 NIL 
-(-72 -3391) 
+(-72 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp27} produces Fortran for Type 27 ASPs,{} needed for NAG routine f02fjf ,{}for example: \\blankline \\tab{5}FUNCTION DOT(IFLAG,{}\\spad{N},{}\\spad{Z},{}\\spad{W},{}RWORK,{}LRWORK,{}IWORK,{}LIWORK)\\spad{\\br} \\tab{5}DOUBLE PRECISION \\spad{W}(\\spad{N}),{}\\spad{Z}(\\spad{N}),{}RWORK(LRWORK)\\spad{\\br} \\tab{5}INTEGER \\spad{N},{}LIWORK,{}IFLAG,{}LRWORK,{}IWORK(LIWORK)\\spad{\\br} \\tab{5}DOT=(\\spad{W}(16)+(\\spad{-0}.5D0*W(15)))\\spad{*Z}(16)+((\\spad{-0}.5D0*W(16))\\spad{+W}(15)+(\\spad{-0}.5D0*W(1\\spad{\\br} \\tab{4}\\spad{&4})))\\spad{*Z}(15)+((\\spad{-0}.5D0*W(15))\\spad{+W}(14)+(\\spad{-0}.5D0*W(13)))\\spad{*Z}(14)+((\\spad{-0}.5D0*W(\\spad{\\br} \\tab{4}\\spad{&14}))\\spad{+W}(13)+(\\spad{-0}.5D0*W(12)))\\spad{*Z}(13)+((\\spad{-0}.5D0*W(13))\\spad{+W}(12)+(\\spad{-0}.5D0*W(1\\spad{\\br} \\tab{4}\\spad{&1})))\\spad{*Z}(12)+((\\spad{-0}.5D0*W(12))\\spad{+W}(11)+(\\spad{-0}.5D0*W(10)))\\spad{*Z}(11)+((\\spad{-0}.5D0*W(\\spad{\\br} \\tab{4}\\spad{&11}))\\spad{+W}(10)+(\\spad{-0}.5D0*W(9)))\\spad{*Z}(10)+((\\spad{-0}.5D0*W(10))\\spad{+W}(9)+(\\spad{-0}.5D0*W(8))\\spad{\\br} \\tab{4}&)\\spad{*Z}(9)+((\\spad{-0}.5D0*W(9))\\spad{+W}(8)+(\\spad{-0}.5D0*W(7)))\\spad{*Z}(8)+((\\spad{-0}.5D0*W(8))\\spad{+W}(7)\\spad{\\br} \\tab{4}\\spad{&+}(\\spad{-0}.5D0*W(6)))\\spad{*Z}(7)+((\\spad{-0}.5D0*W(7))\\spad{+W}(6)+(\\spad{-0}.5D0*W(5)))\\spad{*Z}(6)+((\\spad{-0}.\\spad{\\br} \\tab{4}&5D0*W(6))\\spad{+W}(5)+(\\spad{-0}.5D0*W(4)))\\spad{*Z}(5)+((\\spad{-0}.5D0*W(5))\\spad{+W}(4)+(\\spad{-0}.5D0*W(3\\spad{\\br} \\tab{4}&)))\\spad{*Z}(4)+((\\spad{-0}.5D0*W(4))\\spad{+W}(3)+(\\spad{-0}.5D0*W(2)))\\spad{*Z}(3)+((\\spad{-0}.5D0*W(3))\\spad{+W}(\\spad{\\br} \\tab{4}\\spad{&2})+(\\spad{-0}.5D0*W(1)))\\spad{*Z}(2)+((\\spad{-0}.5D0*W(2))\\spad{+W}(1))\\spad{*Z}(1)\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END"))) 
 NIL 
 NIL 
-(-73 -3391) 
+(-73 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp28} produces Fortran for Type 28 ASPs,{} used in NAG routine f02fjf,{} for example: \\blankline \\tab{5}SUBROUTINE IMAGE(IFLAG,{}\\spad{N},{}\\spad{Z},{}\\spad{W},{}RWORK,{}LRWORK,{}IWORK,{}LIWORK)\\spad{\\br} \\tab{5}DOUBLE PRECISION \\spad{Z}(\\spad{N}),{}\\spad{W}(\\spad{N}),{}IWORK(LRWORK),{}RWORK(LRWORK)\\spad{\\br} \\tab{5}INTEGER \\spad{N},{}LIWORK,{}IFLAG,{}LRWORK\\spad{\\br} \\tab{5}\\spad{W}(1)\\spad{=0}.01707454969713436D0*Z(16)\\spad{+0}.001747395874954051D0*Z(15)\\spad{+0}.00\\spad{\\br} \\tab{4}&2106973900813502D0*Z(14)\\spad{+0}.002957434991769087D0*Z(13)+(\\spad{-0}.00700554\\spad{\\br} \\tab{4}&0882865317D0*Z(12))+(\\spad{-0}.01219194009813166D0*Z(11))\\spad{+0}.0037230647365\\spad{\\br} \\tab{4}&3087D0*Z(10)\\spad{+0}.04932374658377151D0*Z(9)+(\\spad{-0}.03586220812223305D0*Z(\\spad{\\br} \\tab{4}\\spad{&8}))+(\\spad{-0}.04723268012114625D0*Z(7))+(\\spad{-0}.02434652144032987D0*Z(6))\\spad{+0}.\\spad{\\br} \\tab{4}&2264766947290192D0*Z(5)+(\\spad{-0}.1385343580686922D0*Z(4))+(\\spad{-0}.116530050\\spad{\\br} \\tab{4}&8238904D0*Z(3))+(\\spad{-0}.2803531651057233D0*Z(2))\\spad{+1}.019463911841327D0*Z\\spad{\\br} \\tab{4}&(1)\\spad{\\br} \\tab{5}\\spad{W}(2)\\spad{=0}.0227345011107737D0*Z(16)\\spad{+0}.008812321197398072D0*Z(15)\\spad{+0}.010\\spad{\\br} \\tab{4}&94012210519586D0*Z(14)+(\\spad{-0}.01764072463999744D0*Z(13))+(\\spad{-0}.01357136\\spad{\\br} \\tab{4}&72105995D0*Z(12))\\spad{+0}.00157466157362272D0*Z(11)\\spad{+0}.05258889186338282D\\spad{\\br} \\tab{4}&0*Z(10)+(\\spad{-0}.01981532388243379D0*Z(9))+(\\spad{-0}.06095390688679697D0*Z(8)\\spad{\\br} \\tab{4}&)+(\\spad{-0}.04153119955569051D0*Z(7))\\spad{+0}.2176561076571465D0*Z(6)+(\\spad{-0}.0532\\spad{\\br} \\tab{4}&5555586632358D0*Z(5))+(\\spad{-0}.1688977368984641D0*Z(4))+(\\spad{-0}.32440166056\\spad{\\br} \\tab{4}&67343D0*Z(3))\\spad{+0}.9128222941872173D0*Z(2)+(\\spad{-0}.2419652703415429D0*Z(1\\spad{\\br} \\tab{4}&))\\spad{\\br} \\tab{5}\\spad{W}(3)\\spad{=0}.03371198197190302D0*Z(16)\\spad{+0}.02021603150122265D0*Z(15)+(\\spad{-0}.0\\spad{\\br} \\tab{4}&06607305534689702D0*Z(14))+(\\spad{-0}.03032392238968179D0*Z(13))\\spad{+0}.002033\\spad{\\br} \\tab{4}&305231024948D0*Z(12)\\spad{+0}.05375944956767728D0*Z(11)+(\\spad{-0}.0163213312502\\spad{\\br} \\tab{4}&9967D0*Z(10))+(\\spad{-0}.05483186562035512D0*Z(9))+(\\spad{-0}.04901428822579872D\\spad{\\br} \\tab{4}&0*Z(8))\\spad{+0}.2091097927887612D0*Z(7)+(\\spad{-0}.05760560341383113D0*Z(6))+(-\\spad{\\br} \\tab{4}\\spad{&0}.1236679206156403D0*Z(5))+(\\spad{-0}.3523683853026259D0*Z(4))\\spad{+0}.88929961\\spad{\\br} \\tab{4}&32269974D0*Z(3)+(\\spad{-0}.2995429545781457D0*Z(2))+(\\spad{-0}.02986582812574917\\spad{\\br} \\tab{4}&D0*Z(1))\\spad{\\br} \\tab{5}\\spad{W}(4)\\spad{=0}.05141563713660119D0*Z(16)\\spad{+0}.005239165960779299D0*Z(15)+(\\spad{-0}.\\spad{\\br} \\tab{4}&01623427735779699D0*Z(14))+(\\spad{-0}.01965809746040371D0*Z(13))\\spad{+0}.054688\\spad{\\br} \\tab{4}&97337339577D0*Z(12)+(\\spad{-0}.014224695935687D0*Z(11))+(\\spad{-0}.0505181779315\\spad{\\br} \\tab{4}&6355D0*Z(10))+(\\spad{-0}.04353074206076491D0*Z(9))\\spad{+0}.2012230497530726D0*Z\\spad{\\br} \\tab{4}&(8)+(\\spad{-0}.06630874514535952D0*Z(7))+(\\spad{-0}.1280829963720053D0*Z(6))+(\\spad{-0}\\spad{\\br} \\tab{4}&.305169742604165D0*Z(5))\\spad{+0}.8600427128450191D0*Z(4)+(\\spad{-0}.32415033802\\spad{\\br} \\tab{4}&68184D0*Z(3))+(\\spad{-0}.09033531980693314D0*Z(2))\\spad{+0}.09089205517109111D0*\\spad{\\br} \\tab{4}\\spad{&Z}(1)\\spad{\\br} \\tab{5}\\spad{W}(5)\\spad{=0}.04556369767776375D0*Z(16)+(\\spad{-0}.001822737697581869D0*Z(15))+(\\spad{\\br} \\tab{4}&-0.002512226501941856D0*Z(14))\\spad{+0}.02947046460707379D0*Z(13)+(\\spad{-0}.014\\spad{\\br} \\tab{4}&45079632086177D0*Z(12))+(\\spad{-0}.05034242196614937D0*Z(11))+(\\spad{-0}.0376966\\spad{\\br} \\tab{4}&3291725935D0*Z(10))\\spad{+0}.2171103102175198D0*Z(9)+(\\spad{-0}.0824949256021352\\spad{\\br} \\tab{4}&4D0*Z(8))+(\\spad{-0}.1473995209288945D0*Z(7))+(\\spad{-0}.315042193418466D0*Z(6))\\spad{\\br} \\tab{4}\\spad{&+0}.9591623347824002D0*Z(5)+(\\spad{-0}.3852396953763045D0*Z(4))+(\\spad{-0}.141718\\spad{\\br} \\tab{4}&5427288274D0*Z(3))+(\\spad{-0}.03423495461011043D0*Z(2))\\spad{+0}.319820917706851\\spad{\\br} \\tab{4}&6D0*Z(1)\\spad{\\br} \\tab{5}\\spad{W}(6)\\spad{=0}.04015147277405744D0*Z(16)\\spad{+0}.01328585741341559D0*Z(15)\\spad{+0}.048\\spad{\\br} \\tab{4}&26082005465965D0*Z(14)+(\\spad{-0}.04319641116207706D0*Z(13))+(\\spad{-0}.04931323\\spad{\\br} \\tab{4}&319055762D0*Z(12))+(\\spad{-0}.03526886317505474D0*Z(11))\\spad{+0}.22295383396730\\spad{\\br} \\tab{4}&01D0*Z(10)+(\\spad{-0}.07375317649315155D0*Z(9))+(\\spad{-0}.1589391311991561D0*Z(\\spad{\\br} \\tab{4}\\spad{&8}))+(\\spad{-0}.328001910890377D0*Z(7))\\spad{+0}.952576555482747D0*Z(6)+(\\spad{-0}.31583\\spad{\\br} \\tab{4}&09975786731D0*Z(5))+(\\spad{-0}.1846882042225383D0*Z(4))+(\\spad{-0}.0703762046700\\spad{\\br} \\tab{4}&4427D0*Z(3))\\spad{+0}.2311852964327382D0*Z(2)\\spad{+0}.04254083491825025D0*Z(1)\\spad{\\br} \\tab{5}\\spad{W}(7)\\spad{=0}.06069778964023718D0*Z(16)\\spad{+0}.06681263884671322D0*Z(15)+(\\spad{-0}.0\\spad{\\br} \\tab{4}&2113506688615768D0*Z(14))+(\\spad{-0}.083996867458326D0*Z(13))+(\\spad{-0}.0329843\\spad{\\br} \\tab{4}&8523869648D0*Z(12))\\spad{+0}.2276878326327734D0*Z(11)+(\\spad{-0}.067356038933017\\spad{\\br} \\tab{4}&95D0*Z(10))+(\\spad{-0}.1559813965382218D0*Z(9))+(\\spad{-0}.3363262957694705D0*Z(\\spad{\\br} \\tab{4}\\spad{&8}))\\spad{+0}.9442791158560948D0*Z(7)+(\\spad{-0}.3199955249404657D0*Z(6))+(\\spad{-0}.136\\spad{\\br} \\tab{4}&2463839920727D0*Z(5))+(\\spad{-0}.1006185171570586D0*Z(4))\\spad{+0}.2057504515015\\spad{\\br} \\tab{4}&423D0*Z(3)+(\\spad{-0}.02065879269286707D0*Z(2))\\spad{+0}.03160990266745513D0*Z(1\\spad{\\br} \\tab{4}&)\\spad{\\br} \\tab{5}\\spad{W}(8)\\spad{=0}.126386868896738D0*Z(16)\\spad{+0}.002563370039476418D0*Z(15)+(\\spad{-0}.05\\spad{\\br} \\tab{4}&581757739455641D0*Z(14))+(\\spad{-0}.07777893205900685D0*Z(13))\\spad{+0}.23117338\\spad{\\br} \\tab{4}&45834199D0*Z(12)+(\\spad{-0}.06031581134427592D0*Z(11))+(\\spad{-0}.14805474755869\\spad{\\br} \\tab{4}&52D0*Z(10))+(\\spad{-0}.3364014128402243D0*Z(9))\\spad{+0}.9364014128402244D0*Z(8)\\spad{\\br} \\tab{4}\\spad{&+}(\\spad{-0}.3269452524413048D0*Z(7))+(\\spad{-0}.1396841886557241D0*Z(6))+(\\spad{-0}.056\\spad{\\br} \\tab{4}&1733845834199D0*Z(5))\\spad{+0}.1777789320590069D0*Z(4)+(\\spad{-0}.04418242260544\\spad{\\br} \\tab{4}&359D0*Z(3))+(\\spad{-0}.02756337003947642D0*Z(2))\\spad{+0}.07361313110326199D0*Z(\\spad{\\br} \\tab{4}\\spad{&1})\\spad{\\br} \\tab{5}\\spad{W}(9)\\spad{=0}.07361313110326199D0*Z(16)+(\\spad{-0}.02756337003947642D0*Z(15))+(-\\spad{\\br} \\tab{4}\\spad{&0}.04418242260544359D0*Z(14))\\spad{+0}.1777789320590069D0*Z(13)+(\\spad{-0}.056173\\spad{\\br} \\tab{4}&3845834199D0*Z(12))+(\\spad{-0}.1396841886557241D0*Z(11))+(\\spad{-0}.326945252441\\spad{\\br} \\tab{4}&3048D0*Z(10))\\spad{+0}.9364014128402244D0*Z(9)+(\\spad{-0}.3364014128402243D0*Z(8\\spad{\\br} \\tab{4}&))+(\\spad{-0}.1480547475586952D0*Z(7))+(\\spad{-0}.06031581134427592D0*Z(6))\\spad{+0}.23\\spad{\\br} \\tab{4}&11733845834199D0*Z(5)+(\\spad{-0}.07777893205900685D0*Z(4))+(\\spad{-0}.0558175773\\spad{\\br} \\tab{4}&9455641D0*Z(3))\\spad{+0}.002563370039476418D0*Z(2)\\spad{+0}.126386868896738D0*Z(\\spad{\\br} \\tab{4}\\spad{&1})\\spad{\\br} \\tab{5}\\spad{W}(10)\\spad{=0}.03160990266745513D0*Z(16)+(\\spad{-0}.02065879269286707D0*Z(15))\\spad{+0}\\spad{\\br} \\tab{4}&.2057504515015423D0*Z(14)+(\\spad{-0}.1006185171570586D0*Z(13))+(\\spad{-0}.136246\\spad{\\br} \\tab{4}&3839920727D0*Z(12))+(\\spad{-0}.3199955249404657D0*Z(11))\\spad{+0}.94427911585609\\spad{\\br} \\tab{4}&48D0*Z(10)+(\\spad{-0}.3363262957694705D0*Z(9))+(\\spad{-0}.1559813965382218D0*Z(8\\spad{\\br} \\tab{4}&))+(\\spad{-0}.06735603893301795D0*Z(7))\\spad{+0}.2276878326327734D0*Z(6)+(\\spad{-0}.032\\spad{\\br} \\tab{4}&98438523869648D0*Z(5))+(\\spad{-0}.083996867458326D0*Z(4))+(\\spad{-0}.02113506688\\spad{\\br} \\tab{4}&615768D0*Z(3))\\spad{+0}.06681263884671322D0*Z(2)\\spad{+0}.06069778964023718D0*Z(\\spad{\\br} \\tab{4}\\spad{&1})\\spad{\\br} \\tab{5}\\spad{W}(11)\\spad{=0}.04254083491825025D0*Z(16)\\spad{+0}.2311852964327382D0*Z(15)+(\\spad{-0}.0\\spad{\\br} \\tab{4}&7037620467004427D0*Z(14))+(\\spad{-0}.1846882042225383D0*Z(13))+(\\spad{-0}.315830\\spad{\\br} \\tab{4}&9975786731D0*Z(12))\\spad{+0}.952576555482747D0*Z(11)+(\\spad{-0}.328001910890377D\\spad{\\br} \\tab{4}&0*Z(10))+(\\spad{-0}.1589391311991561D0*Z(9))+(\\spad{-0}.07375317649315155D0*Z(8)\\spad{\\br} \\tab{4}&)\\spad{+0}.2229538339673001D0*Z(7)+(\\spad{-0}.03526886317505474D0*Z(6))+(\\spad{-0}.0493\\spad{\\br} \\tab{4}&1323319055762D0*Z(5))+(\\spad{-0}.04319641116207706D0*Z(4))\\spad{+0}.048260820054\\spad{\\br} \\tab{4}&65965D0*Z(3)\\spad{+0}.01328585741341559D0*Z(2)\\spad{+0}.04015147277405744D0*Z(1)\\spad{\\br} \\tab{5}\\spad{W}(12)\\spad{=0}.3198209177068516D0*Z(16)+(\\spad{-0}.03423495461011043D0*Z(15))+(-\\spad{\\br} \\tab{4}\\spad{&0}.1417185427288274D0*Z(14))+(\\spad{-0}.3852396953763045D0*Z(13))\\spad{+0}.959162\\spad{\\br} \\tab{4}&3347824002D0*Z(12)+(\\spad{-0}.315042193418466D0*Z(11))+(\\spad{-0}.14739952092889\\spad{\\br} \\tab{4}&45D0*Z(10))+(\\spad{-0}.08249492560213524D0*Z(9))\\spad{+0}.2171103102175198D0*Z(8\\spad{\\br} \\tab{4}&)+(\\spad{-0}.03769663291725935D0*Z(7))+(\\spad{-0}.05034242196614937D0*Z(6))+(\\spad{-0}.\\spad{\\br} \\tab{4}&01445079632086177D0*Z(5))\\spad{+0}.02947046460707379D0*Z(4)+(\\spad{-0}.002512226\\spad{\\br} \\tab{4}&501941856D0*Z(3))+(\\spad{-0}.001822737697581869D0*Z(2))\\spad{+0}.045563697677763\\spad{\\br} \\tab{4}&75D0*Z(1)\\spad{\\br} \\tab{5}\\spad{W}(13)\\spad{=0}.09089205517109111D0*Z(16)+(\\spad{-0}.09033531980693314D0*Z(15))+(\\spad{\\br} \\tab{4}&-0.3241503380268184D0*Z(14))\\spad{+0}.8600427128450191D0*Z(13)+(\\spad{-0}.305169\\spad{\\br} \\tab{4}&742604165D0*Z(12))+(\\spad{-0}.1280829963720053D0*Z(11))+(\\spad{-0}.0663087451453\\spad{\\br} \\tab{4}&5952D0*Z(10))\\spad{+0}.2012230497530726D0*Z(9)+(\\spad{-0}.04353074206076491D0*Z(\\spad{\\br} \\tab{4}\\spad{&8}))+(\\spad{-0}.05051817793156355D0*Z(7))+(\\spad{-0}.014224695935687D0*Z(6))\\spad{+0}.05\\spad{\\br} \\tab{4}&468897337339577D0*Z(5)+(\\spad{-0}.01965809746040371D0*Z(4))+(\\spad{-0}.016234277\\spad{\\br} \\tab{4}&35779699D0*Z(3))\\spad{+0}.005239165960779299D0*Z(2)\\spad{+0}.05141563713660119D0\\spad{\\br} \\tab{4}\\spad{&*Z}(1)\\spad{\\br} \\tab{5}\\spad{W}(14)=(\\spad{-0}.02986582812574917D0*Z(16))+(\\spad{-0}.2995429545781457D0*Z(15))\\spad{\\br} \\tab{4}\\spad{&+0}.8892996132269974D0*Z(14)+(\\spad{-0}.3523683853026259D0*Z(13))+(\\spad{-0}.1236\\spad{\\br} \\tab{4}&679206156403D0*Z(12))+(\\spad{-0}.05760560341383113D0*Z(11))\\spad{+0}.20910979278\\spad{\\br} \\tab{4}&87612D0*Z(10)+(\\spad{-0}.04901428822579872D0*Z(9))+(\\spad{-0}.05483186562035512D\\spad{\\br} \\tab{4}&0*Z(8))+(\\spad{-0}.01632133125029967D0*Z(7))\\spad{+0}.05375944956767728D0*Z(6)\\spad{+0}\\spad{\\br} \\tab{4}&.002033305231024948D0*Z(5)+(\\spad{-0}.03032392238968179D0*Z(4))+(\\spad{-0}.00660\\spad{\\br} \\tab{4}&7305534689702D0*Z(3))\\spad{+0}.02021603150122265D0*Z(2)\\spad{+0}.033711981971903\\spad{\\br} \\tab{4}&02D0*Z(1)\\spad{\\br} \\tab{5}\\spad{W}(15)=(\\spad{-0}.2419652703415429D0*Z(16))\\spad{+0}.9128222941872173D0*Z(15)+(\\spad{-0}\\spad{\\br} \\tab{4}&.3244016605667343D0*Z(14))+(\\spad{-0}.1688977368984641D0*Z(13))+(\\spad{-0}.05325\\spad{\\br} \\tab{4}&555586632358D0*Z(12))\\spad{+0}.2176561076571465D0*Z(11)+(\\spad{-0}.0415311995556\\spad{\\br} \\tab{4}&9051D0*Z(10))+(\\spad{-0}.06095390688679697D0*Z(9))+(\\spad{-0}.01981532388243379D\\spad{\\br} \\tab{4}&0*Z(8))\\spad{+0}.05258889186338282D0*Z(7)\\spad{+0}.00157466157362272D0*Z(6)+(\\spad{-0}.\\spad{\\br} \\tab{4}&0135713672105995D0*Z(5))+(\\spad{-0}.01764072463999744D0*Z(4))\\spad{+0}.010940122\\spad{\\br} \\tab{4}&10519586D0*Z(3)\\spad{+0}.008812321197398072D0*Z(2)\\spad{+0}.0227345011107737D0*Z\\spad{\\br} \\tab{4}&(1)\\spad{\\br} \\tab{5}\\spad{W}(16)\\spad{=1}.019463911841327D0*Z(16)+(\\spad{-0}.2803531651057233D0*Z(15))+(\\spad{-0}.\\spad{\\br} \\tab{4}&1165300508238904D0*Z(14))+(\\spad{-0}.1385343580686922D0*Z(13))\\spad{+0}.22647669\\spad{\\br} \\tab{4}&47290192D0*Z(12)+(\\spad{-0}.02434652144032987D0*Z(11))+(\\spad{-0}.04723268012114\\spad{\\br} \\tab{4}&625D0*Z(10))+(\\spad{-0}.03586220812223305D0*Z(9))\\spad{+0}.04932374658377151D0*Z\\spad{\\br} \\tab{4}&(8)\\spad{+0}.00372306473653087D0*Z(7)+(\\spad{-0}.01219194009813166D0*Z(6))+(\\spad{-0}.0\\spad{\\br} \\tab{4}&07005540882865317D0*Z(5))\\spad{+0}.002957434991769087D0*Z(4)\\spad{+0}.0021069739\\spad{\\br} \\tab{4}&00813502D0*Z(3)\\spad{+0}.001747395874954051D0*Z(2)\\spad{+0}.01707454969713436D0*\\spad{\\br} \\tab{4}\\spad{&Z}(1)\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END\\spad{\\br}"))) 
 NIL 
 NIL 
-(-74 -3391) 
+(-74 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp29} produces Fortran for Type 29 ASPs,{} needed for NAG routine f02fjf,{} for example: \\blankline \\tab{5}SUBROUTINE MONIT(ISTATE,{}NEXTIT,{}NEVALS,{}NEVECS,{}\\spad{K},{}\\spad{F},{}\\spad{D})\\spad{\\br} \\tab{5}DOUBLE PRECISION \\spad{D}(\\spad{K}),{}\\spad{F}(\\spad{K})\\spad{\\br} \\tab{5}INTEGER \\spad{K},{}NEXTIT,{}NEVALS,{}NVECS,{}ISTATE\\spad{\\br} \\tab{5}CALL F02FJZ(ISTATE,{}NEXTIT,{}NEVALS,{}NEVECS,{}\\spad{K},{}\\spad{F},{}\\spad{D})\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END\\spad{\\br}")) (|outputAsFortran| (((|Void|)) "\\spad{outputAsFortran()} generates the default code for \\spadtype{ASP29}."))) 
 NIL 
 NIL 
-(-75 -3391) 
+(-75 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp30} produces Fortran for Type 30 ASPs,{} needed for NAG routine f04qaf,{} for example: \\blankline \\tab{5}SUBROUTINE APROD(MODE,{}\\spad{M},{}\\spad{N},{}\\spad{X},{}\\spad{Y},{}RWORK,{}LRWORK,{}IWORK,{}LIWORK)\\spad{\\br} \\tab{5}DOUBLE PRECISION \\spad{X}(\\spad{N}),{}\\spad{Y}(\\spad{M}),{}RWORK(LRWORK)\\spad{\\br} \\tab{5}INTEGER \\spad{M},{}\\spad{N},{}LIWORK,{}IFAIL,{}LRWORK,{}IWORK(LIWORK),{}MODE\\spad{\\br} \\tab{5}DOUBLE PRECISION A(5,{}5)\\spad{\\br} \\tab{5}EXTERNAL F06PAF\\spad{\\br} \\tab{5}A(1,{}1)\\spad{=1}.0D0\\spad{\\br} \\tab{5}A(1,{}2)\\spad{=0}.0D0\\spad{\\br} \\tab{5}A(1,{}3)\\spad{=0}.0D0\\spad{\\br} \\tab{5}A(1,{}4)=-1.0D0\\spad{\\br} \\tab{5}A(1,{}5)\\spad{=0}.0D0\\spad{\\br} \\tab{5}A(2,{}1)\\spad{=0}.0D0\\spad{\\br} \\tab{5}A(2,{}2)\\spad{=1}.0D0\\spad{\\br} \\tab{5}A(2,{}3)\\spad{=0}.0D0\\spad{\\br} \\tab{5}A(2,{}4)\\spad{=0}.0D0\\spad{\\br} \\tab{5}A(2,{}5)=-1.0D0\\spad{\\br} \\tab{5}A(3,{}1)\\spad{=0}.0D0\\spad{\\br} \\tab{5}A(3,{}2)\\spad{=0}.0D0\\spad{\\br} \\tab{5}A(3,{}3)\\spad{=1}.0D0\\spad{\\br} \\tab{5}A(3,{}4)=-1.0D0\\spad{\\br} \\tab{5}A(3,{}5)\\spad{=0}.0D0\\spad{\\br} \\tab{5}A(4,{}1)=-1.0D0\\spad{\\br} \\tab{5}A(4,{}2)\\spad{=0}.0D0\\spad{\\br} \\tab{5}A(4,{}3)=-1.0D0\\spad{\\br} \\tab{5}A(4,{}4)\\spad{=4}.0D0\\spad{\\br} \\tab{5}A(4,{}5)=-1.0D0\\spad{\\br} \\tab{5}A(5,{}1)\\spad{=0}.0D0\\spad{\\br} \\tab{5}A(5,{}2)=-1.0D0\\spad{\\br} \\tab{5}A(5,{}3)\\spad{=0}.0D0\\spad{\\br} \\tab{5}A(5,{}4)=-1.0D0\\spad{\\br} \\tab{5}A(5,{}5)\\spad{=4}.0D0\\spad{\\br} \\tab{5}IF(MODE.EQ.1)THEN\\spad{\\br} \\tab{7}CALL F06PAF(\\spad{'N'},{}\\spad{M},{}\\spad{N},{}1.0D0,{}A,{}\\spad{M},{}\\spad{X},{}1,{}1.0D0,{}\\spad{Y},{}1)\\spad{\\br} \\tab{5}ELSEIF(MODE.EQ.2)THEN\\spad{\\br} \\tab{7}CALL F06PAF(\\spad{'T'},{}\\spad{M},{}\\spad{N},{}1.0D0,{}A,{}\\spad{M},{}\\spad{Y},{}1,{}1.0D0,{}\\spad{X},{}1)\\spad{\\br} \\tab{5}ENDIF\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END"))) 
 NIL 
 NIL 
-(-76 -3391) 
+(-76 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp31} produces Fortran for Type 31 ASPs,{} needed for NAG routine d02ejf,{} for example: \\blankline \\tab{5}SUBROUTINE PEDERV(\\spad{X},{}\\spad{Y},{}\\spad{PW})\\spad{\\br} \\tab{5}DOUBLE PRECISION \\spad{X},{}\\spad{Y}(*)\\spad{\\br} \\tab{5}DOUBLE PRECISION \\spad{PW}(3,{}3)\\spad{\\br} \\tab{5}\\spad{PW}(1,{}1)=-0.03999999999999999D0\\spad{\\br} \\tab{5}\\spad{PW}(1,{}2)\\spad{=10000}.0D0*Y(3)\\spad{\\br} \\tab{5}\\spad{PW}(1,{}3)\\spad{=10000}.0D0*Y(2)\\spad{\\br} \\tab{5}\\spad{PW}(2,{}1)\\spad{=0}.03999999999999999D0\\spad{\\br} \\tab{5}\\spad{PW}(2,{}2)=(\\spad{-10000}.0D0*Y(3))+(\\spad{-60000000}.0D0*Y(2))\\spad{\\br} \\tab{5}\\spad{PW}(2,{}3)=-10000.0D0*Y(2)\\spad{\\br} \\tab{5}\\spad{PW}(3,{}1)\\spad{=0}.0D0\\spad{\\br} \\tab{5}\\spad{PW}(3,{}2)\\spad{=60000000}.0D0*Y(2)\\spad{\\br} \\tab{5}\\spad{PW}(3,{}3)\\spad{=0}.0D0\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END")) (|coerce| (($ (|Vector| (|FortranExpression| (|construct| (QUOTE X)) (|construct| (QUOTE Y)) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-77 -3391) 
+(-77 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp33} produces Fortran for Type 33 ASPs,{} needed for NAG routine d02kef. The code is a dummy ASP: \\blankline \\tab{5}SUBROUTINE REPORT(\\spad{X},{}\\spad{V},{}JINT)\\spad{\\br} \\tab{5}DOUBLE PRECISION \\spad{V}(3),{}\\spad{X}\\spad{\\br} \\tab{5}INTEGER JINT\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END")) (|outputAsFortran| (((|Void|)) "\\spad{outputAsFortran()} generates the default code for \\spadtype{ASP33}."))) 
 NIL 
 NIL 
-(-78 -3391) 
+(-78 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp34} produces Fortran for Type 34 ASPs,{} needed for NAG routine f04mbf,{} for example: \\blankline \\tab{5}SUBROUTINE MSOLVE(IFLAG,{}\\spad{N},{}\\spad{X},{}\\spad{Y},{}RWORK,{}LRWORK,{}IWORK,{}LIWORK)\\spad{\\br} \\tab{5}DOUBLE PRECISION RWORK(LRWORK),{}\\spad{X}(\\spad{N}),{}\\spad{Y}(\\spad{N})\\spad{\\br} \\tab{5}INTEGER \\spad{I},{}\\spad{J},{}\\spad{N},{}LIWORK,{}IFLAG,{}LRWORK,{}IWORK(LIWORK)\\spad{\\br} \\tab{5}DOUBLE PRECISION \\spad{W1}(3),{}\\spad{W2}(3),{}\\spad{MS}(3,{}3)\\spad{\\br} \\tab{5}IFLAG=-1\\spad{\\br} \\tab{5}\\spad{MS}(1,{}1)\\spad{=2}.0D0\\spad{\\br} \\tab{5}\\spad{MS}(1,{}2)\\spad{=1}.0D0\\spad{\\br} \\tab{5}\\spad{MS}(1,{}3)\\spad{=0}.0D0\\spad{\\br} \\tab{5}\\spad{MS}(2,{}1)\\spad{=1}.0D0\\spad{\\br} \\tab{5}\\spad{MS}(2,{}2)\\spad{=2}.0D0\\spad{\\br} \\tab{5}\\spad{MS}(2,{}3)\\spad{=1}.0D0\\spad{\\br} \\tab{5}\\spad{MS}(3,{}1)\\spad{=0}.0D0\\spad{\\br} \\tab{5}\\spad{MS}(3,{}2)\\spad{=1}.0D0\\spad{\\br} \\tab{5}\\spad{MS}(3,{}3)\\spad{=2}.0D0\\spad{\\br} \\tab{5}CALL F04ASF(\\spad{MS},{}\\spad{N},{}\\spad{X},{}\\spad{N},{}\\spad{Y},{}\\spad{W1},{}\\spad{W2},{}IFLAG)\\spad{\\br} \\tab{5}IFLAG=-IFLAG\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END"))) 
 NIL 
 NIL 
-(-79 -3391) 
+(-79 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp35} produces Fortran for Type 35 ASPs,{} needed for NAG routines c05pbf,{} c05pcf,{} for example: \\blankline \\tab{5}SUBROUTINE \\spad{FCN}(\\spad{N},{}\\spad{X},{}FVEC,{}FJAC,{}LDFJAC,{}IFLAG)\\spad{\\br} \\tab{5}DOUBLE PRECISION \\spad{X}(\\spad{N}),{}FVEC(\\spad{N}),{}FJAC(LDFJAC,{}\\spad{N})\\spad{\\br} \\tab{5}INTEGER LDFJAC,{}\\spad{N},{}IFLAG\\spad{\\br} \\tab{5}IF(IFLAG.EQ.1)THEN\\spad{\\br} \\tab{7}FVEC(1)=(\\spad{-1}.0D0*X(2))\\spad{+X}(1)\\spad{\\br} \\tab{7}FVEC(2)=(\\spad{-1}.0D0*X(3))\\spad{+2}.0D0*X(2)\\spad{\\br} \\tab{7}FVEC(3)\\spad{=3}.0D0*X(3)\\spad{\\br} \\tab{5}ELSEIF(IFLAG.EQ.2)THEN\\spad{\\br} \\tab{7}FJAC(1,{}1)\\spad{=1}.0D0\\spad{\\br} \\tab{7}FJAC(1,{}2)=-1.0D0\\spad{\\br} \\tab{7}FJAC(1,{}3)\\spad{=0}.0D0\\spad{\\br} \\tab{7}FJAC(2,{}1)\\spad{=0}.0D0\\spad{\\br} \\tab{7}FJAC(2,{}2)\\spad{=2}.0D0\\spad{\\br} \\tab{7}FJAC(2,{}3)=-1.0D0\\spad{\\br} \\tab{7}FJAC(3,{}1)\\spad{=0}.0D0\\spad{\\br} \\tab{7}FJAC(3,{}2)\\spad{=0}.0D0\\spad{\\br} \\tab{7}FJAC(3,{}3)\\spad{=3}.0D0\\spad{\\br} \\tab{5}ENDIF\\spad{\\br} \\tab{5}END")) (|coerce| (($ (|Vector| (|FortranExpression| (|construct|) (|construct| (QUOTE X)) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
@@ -256,55 +256,55 @@ NIL
 ((|constructor| (NIL "\\spadtype{Asp42} produces Fortran for Type 42 ASPs,{} needed for NAG routines d02raf and d02saf in particular. These ASPs are in fact three Fortran routines which return a vector of functions,{} and their derivatives \\spad{wrt} \\spad{Y}(\\spad{i}) and also a continuation parameter EPS,{} for example: \\blankline \\tab{5}SUBROUTINE \\spad{G}(EPS,{}YA,{}\\spad{YB},{}\\spad{BC},{}\\spad{N})\\spad{\\br} \\tab{5}DOUBLE PRECISION EPS,{}YA(\\spad{N}),{}\\spad{YB}(\\spad{N}),{}\\spad{BC}(\\spad{N})\\spad{\\br} \\tab{5}INTEGER \\spad{N}\\spad{\\br} \\tab{5}\\spad{BC}(1)=YA(1)\\spad{\\br} \\tab{5}\\spad{BC}(2)=YA(2)\\spad{\\br} \\tab{5}\\spad{BC}(3)\\spad{=YB}(2)\\spad{-1}.0D0\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END\\spad{\\br} \\tab{5}SUBROUTINE JACOBG(EPS,{}YA,{}\\spad{YB},{}AJ,{}\\spad{BJ},{}\\spad{N})\\spad{\\br} \\tab{5}DOUBLE PRECISION EPS,{}YA(\\spad{N}),{}AJ(\\spad{N},{}\\spad{N}),{}\\spad{BJ}(\\spad{N},{}\\spad{N}),{}\\spad{YB}(\\spad{N})\\spad{\\br} \\tab{5}INTEGER \\spad{N}\\spad{\\br} \\tab{5}AJ(1,{}1)\\spad{=1}.0D0\\spad{\\br} \\tab{5}AJ(1,{}2)\\spad{=0}.0D0\\spad{\\br} \\tab{5}AJ(1,{}3)\\spad{=0}.0D0\\spad{\\br} \\tab{5}AJ(2,{}1)\\spad{=0}.0D0\\spad{\\br} \\tab{5}AJ(2,{}2)\\spad{=1}.0D0\\spad{\\br} \\tab{5}AJ(2,{}3)\\spad{=0}.0D0\\spad{\\br} \\tab{5}AJ(3,{}1)\\spad{=0}.0D0\\spad{\\br} \\tab{5}AJ(3,{}2)\\spad{=0}.0D0\\spad{\\br} \\tab{5}AJ(3,{}3)\\spad{=0}.0D0\\spad{\\br} \\tab{5}\\spad{BJ}(1,{}1)\\spad{=0}.0D0\\spad{\\br} \\tab{5}\\spad{BJ}(1,{}2)\\spad{=0}.0D0\\spad{\\br} \\tab{5}\\spad{BJ}(1,{}3)\\spad{=0}.0D0\\spad{\\br} \\tab{5}\\spad{BJ}(2,{}1)\\spad{=0}.0D0\\spad{\\br} \\tab{5}\\spad{BJ}(2,{}2)\\spad{=0}.0D0\\spad{\\br} \\tab{5}\\spad{BJ}(2,{}3)\\spad{=0}.0D0\\spad{\\br} \\tab{5}\\spad{BJ}(3,{}1)\\spad{=0}.0D0\\spad{\\br} \\tab{5}\\spad{BJ}(3,{}2)\\spad{=1}.0D0\\spad{\\br} \\tab{5}\\spad{BJ}(3,{}3)\\spad{=0}.0D0\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END\\spad{\\br} \\tab{5}SUBROUTINE JACGEP(EPS,{}YA,{}\\spad{YB},{}BCEP,{}\\spad{N})\\spad{\\br} \\tab{5}DOUBLE PRECISION EPS,{}YA(\\spad{N}),{}\\spad{YB}(\\spad{N}),{}BCEP(\\spad{N})\\spad{\\br} \\tab{5}INTEGER \\spad{N}\\spad{\\br} \\tab{5}BCEP(1)\\spad{=0}.0D0\\spad{\\br} \\tab{5}BCEP(2)\\spad{=0}.0D0\\spad{\\br} \\tab{5}BCEP(3)\\spad{=0}.0D0\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END")) (|coerce| (($ (|Vector| (|FortranExpression| (|construct| (QUOTE EPS)) (|construct| (QUOTE YA) (QUOTE YB)) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-82 -3391) 
+(-82 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp49} produces Fortran for Type 49 ASPs,{} needed for NAG routines e04dgf,{} e04ucf,{} for example: \\blankline \\tab{5}SUBROUTINE OBJFUN(MODE,{}\\spad{N},{}\\spad{X},{}OBJF,{}OBJGRD,{}NSTATE,{}IUSER,{}USER)\\spad{\\br} \\tab{5}DOUBLE PRECISION \\spad{X}(\\spad{N}),{}OBJF,{}OBJGRD(\\spad{N}),{}USER(*)\\spad{\\br} \\tab{5}INTEGER \\spad{N},{}IUSER(*),{}MODE,{}NSTATE\\spad{\\br} \\tab{5}OBJF=X(4)\\spad{*X}(9)+((\\spad{-1}.0D0*X(5))\\spad{+X}(3))\\spad{*X}(8)+((\\spad{-1}.0D0*X(3))\\spad{+X}(1))\\spad{*X}(7)\\spad{\\br} \\tab{4}\\spad{&+}(\\spad{-1}.0D0*X(2)\\spad{*X}(6))\\spad{\\br} \\tab{5}OBJGRD(1)\\spad{=X}(7)\\spad{\\br} \\tab{5}OBJGRD(2)=-1.0D0*X(6)\\spad{\\br} \\tab{5}OBJGRD(3)\\spad{=X}(8)+(\\spad{-1}.0D0*X(7))\\spad{\\br} \\tab{5}OBJGRD(4)\\spad{=X}(9)\\spad{\\br} \\tab{5}OBJGRD(5)=-1.0D0*X(8)\\spad{\\br} \\tab{5}OBJGRD(6)=-1.0D0*X(2)\\spad{\\br} \\tab{5}OBJGRD(7)=(\\spad{-1}.0D0*X(3))\\spad{+X}(1)\\spad{\\br} \\tab{5}OBJGRD(8)=(\\spad{-1}.0D0*X(5))\\spad{+X}(3)\\spad{\\br} \\tab{5}OBJGRD(9)\\spad{=X}(4)\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END")) (|coerce| (($ (|FortranExpression| (|construct|) (|construct| (QUOTE X)) (|MachineFloat|))) "\\spad{coerce(f)} takes an object from the appropriate instantiation of \\spadtype{FortranExpression} and turns it into an ASP."))) 
 NIL 
 NIL 
-(-83 -3391) 
+(-83 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp4} produces Fortran for Type 4 ASPs,{} which take an expression in \\spad{X}(1) .. \\spad{X}(NDIM) and produce a real function of the form: \\blankline \\tab{5}DOUBLE PRECISION FUNCTION FUNCTN(NDIM,{}\\spad{X})\\spad{\\br} \\tab{5}DOUBLE PRECISION \\spad{X}(NDIM)\\spad{\\br} \\tab{5}INTEGER NDIM\\spad{\\br} \\tab{5}FUNCTN=(4.0D0*X(1)\\spad{*X}(3)**2*DEXP(2.0D0*X(1)\\spad{*X}(3)))/(\\spad{X}(4)**2+(2.0D0*\\spad{\\br} \\tab{4}\\spad{&X}(2)\\spad{+2}.0D0)\\spad{*X}(4)\\spad{+X}(2)\\spad{**2+2}.0D0*X(2)\\spad{+1}.0D0)\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END")) (|coerce| (($ (|FortranExpression| (|construct|) (|construct| (QUOTE X)) (|MachineFloat|))) "\\spad{coerce(f)} takes an object from the appropriate instantiation of \\spadtype{FortranExpression} and turns it into an ASP."))) 
 NIL 
 NIL 
-(-84 -3391) 
+(-84 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp50} produces Fortran for Type 50 ASPs,{} needed for NAG routine e04fdf,{} for example: \\blankline \\tab{5}SUBROUTINE \\spad{LSFUN1}(\\spad{M},{}\\spad{N},{}\\spad{XC},{}FVECC)\\spad{\\br} \\tab{5}DOUBLE PRECISION FVECC(\\spad{M}),{}\\spad{XC}(\\spad{N})\\spad{\\br} \\tab{5}INTEGER \\spad{I},{}\\spad{M},{}\\spad{N}\\spad{\\br} \\tab{5}FVECC(1)=((\\spad{XC}(1)\\spad{-2}.4D0)\\spad{*XC}(3)+(15.0D0*XC(1)\\spad{-36}.0D0)\\spad{*XC}(2)\\spad{+1}.0D0)/(\\spad{\\br} \\tab{4}\\spad{&XC}(3)\\spad{+15}.0D0*XC(2))\\spad{\\br} \\tab{5}FVECC(2)=((\\spad{XC}(1)\\spad{-2}.8D0)\\spad{*XC}(3)+(7.0D0*XC(1)\\spad{-19}.6D0)\\spad{*XC}(2)\\spad{+1}.0D0)/(\\spad{X}\\spad{\\br} \\tab{4}\\spad{&C}(3)\\spad{+7}.0D0*XC(2))\\spad{\\br} \\tab{5}FVECC(3)=((\\spad{XC}(1)\\spad{-3}.2D0)\\spad{*XC}(3)+(4.333333333333333D0*XC(1)\\spad{-13}.866666\\spad{\\br} \\tab{4}\\spad{&66666667D0})\\spad{*XC}(2)\\spad{+1}.0D0)/(\\spad{XC}(3)\\spad{+4}.333333333333333D0*XC(2))\\spad{\\br} \\tab{5}FVECC(4)=((\\spad{XC}(1)\\spad{-3}.5D0)\\spad{*XC}(3)+(3.0D0*XC(1)\\spad{-10}.5D0)\\spad{*XC}(2)\\spad{+1}.0D0)/(\\spad{X}\\spad{\\br} \\tab{4}\\spad{&C}(3)\\spad{+3}.0D0*XC(2))\\spad{\\br} \\tab{5}FVECC(5)=((\\spad{XC}(1)\\spad{-3}.9D0)\\spad{*XC}(3)+(2.2D0*XC(1)\\spad{-8}.579999999999998D0)\\spad{*XC}\\spad{\\br} \\tab{4}&(2)\\spad{+1}.0D0)/(\\spad{XC}(3)\\spad{+2}.2D0*XC(2))\\spad{\\br} \\tab{5}FVECC(6)=((\\spad{XC}(1)\\spad{-4}.199999999999999D0)\\spad{*XC}(3)+(1.666666666666667D0*X\\spad{\\br} \\tab{4}\\spad{&C}(1)\\spad{-7}.0D0)\\spad{*XC}(2)\\spad{+1}.0D0)/(\\spad{XC}(3)\\spad{+1}.666666666666667D0*XC(2))\\spad{\\br} \\tab{5}FVECC(7)=((\\spad{XC}(1)\\spad{-4}.5D0)\\spad{*XC}(3)+(1.285714285714286D0*XC(1)\\spad{-5}.7857142\\spad{\\br} \\tab{4}\\spad{&85714286D0})\\spad{*XC}(2)\\spad{+1}.0D0)/(\\spad{XC}(3)\\spad{+1}.285714285714286D0*XC(2))\\spad{\\br} \\tab{5}FVECC(8)=((\\spad{XC}(1)\\spad{-4}.899999999999999D0)\\spad{*XC}(3)+(\\spad{XC}(1)\\spad{-4}.8999999999999\\spad{\\br} \\tab{4}\\spad{&99D0})\\spad{*XC}(2)\\spad{+1}.0D0)/(\\spad{XC}(3)\\spad{+XC}(2))\\spad{\\br} \\tab{5}FVECC(9)=((\\spad{XC}(1)\\spad{-4}.699999999999999D0)\\spad{*XC}(3)+(\\spad{XC}(1)\\spad{-4}.6999999999999\\spad{\\br} \\tab{4}\\spad{&99D0})\\spad{*XC}(2)\\spad{+1}.285714285714286D0)/(\\spad{XC}(3)\\spad{+XC}(2))\\spad{\\br} \\tab{5}FVECC(10)=((\\spad{XC}(1)\\spad{-6}.8D0)\\spad{*XC}(3)+(\\spad{XC}(1)\\spad{-6}.8D0)\\spad{*XC}(2)\\spad{+1}.6666666666666\\spad{\\br} \\tab{4}\\spad{&67D0})/(\\spad{XC}(3)\\spad{+XC}(2))\\spad{\\br} \\tab{5}FVECC(11)=((\\spad{XC}(1)\\spad{-8}.299999999999999D0)\\spad{*XC}(3)+(\\spad{XC}(1)\\spad{-8}.299999999999\\spad{\\br} \\tab{4}\\spad{&999D0})\\spad{*XC}(2)\\spad{+2}.2D0)/(\\spad{XC}(3)\\spad{+XC}(2))\\spad{\\br} \\tab{5}FVECC(12)=((\\spad{XC}(1)\\spad{-10}.6D0)\\spad{*XC}(3)+(\\spad{XC}(1)\\spad{-10}.6D0)\\spad{*XC}(2)\\spad{+3}.0D0)/(\\spad{XC}(3)\\spad{\\br} \\tab{4}&+XC(2))\\spad{\\br} \\tab{5}FVECC(13)=((\\spad{XC}(1)\\spad{-1}.34D0)\\spad{*XC}(3)+(\\spad{XC}(1)\\spad{-1}.34D0)\\spad{*XC}(2)\\spad{+4}.33333333333\\spad{\\br} \\tab{4}\\spad{&3333D0})/(\\spad{XC}(3)\\spad{+XC}(2))\\spad{\\br} \\tab{5}FVECC(14)=((\\spad{XC}(1)\\spad{-2}.1D0)\\spad{*XC}(3)+(\\spad{XC}(1)\\spad{-2}.1D0)\\spad{*XC}(2)\\spad{+7}.0D0)/(\\spad{XC}(3)\\spad{+X}\\spad{\\br} \\tab{4}\\spad{&C}(2))\\spad{\\br} \\tab{5}FVECC(15)=((\\spad{XC}(1)\\spad{-4}.39D0)\\spad{*XC}(3)+(\\spad{XC}(1)\\spad{-4}.39D0)\\spad{*XC}(2)\\spad{+15}.0D0)/(\\spad{XC}(3\\spad{\\br} \\tab{4}&)\\spad{+XC}(2))\\spad{\\br} \\tab{5}END")) (|coerce| (($ (|Vector| (|FortranExpression| (|construct|) (|construct| (QUOTE XC)) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-85 -3391) 
+(-85 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp55} produces Fortran for Type 55 ASPs,{} needed for NAG routines e04dgf and e04ucf,{} for example: \\blankline \\tab{5}SUBROUTINE CONFUN(MODE,{}NCNLN,{}\\spad{N},{}NROWJ,{}NEEDC,{}\\spad{X},{}\\spad{C},{}CJAC,{}NSTATE,{}IUSER\\spad{\\br} \\tab{4}&,{}USER)\\spad{\\br} \\tab{5}DOUBLE PRECISION \\spad{C}(NCNLN),{}\\spad{X}(\\spad{N}),{}CJAC(NROWJ,{}\\spad{N}),{}USER(*)\\spad{\\br} \\tab{5}INTEGER \\spad{N},{}IUSER(*),{}NEEDC(NCNLN),{}NROWJ,{}MODE,{}NCNLN,{}NSTATE\\spad{\\br} \\tab{5}IF(NEEDC(1).\\spad{GT}.0)THEN\\spad{\\br} \\tab{7}\\spad{C}(1)\\spad{=X}(6)**2+X(1)\\spad{**2}\\spad{\\br} \\tab{7}CJAC(1,{}1)\\spad{=2}.0D0*X(1)\\spad{\\br} \\tab{7}CJAC(1,{}2)\\spad{=0}.0D0\\spad{\\br} \\tab{7}CJAC(1,{}3)\\spad{=0}.0D0\\spad{\\br} \\tab{7}CJAC(1,{}4)\\spad{=0}.0D0\\spad{\\br} \\tab{7}CJAC(1,{}5)\\spad{=0}.0D0\\spad{\\br} \\tab{7}CJAC(1,{}6)\\spad{=2}.0D0*X(6)\\spad{\\br} \\tab{5}ENDIF\\spad{\\br} \\tab{5}IF(NEEDC(2).\\spad{GT}.0)THEN\\spad{\\br} \\tab{7}\\spad{C}(2)\\spad{=X}(2)**2+(\\spad{-2}.0D0*X(1)\\spad{*X}(2))\\spad{+X}(1)\\spad{**2}\\spad{\\br} \\tab{7}CJAC(2,{}1)=(\\spad{-2}.0D0*X(2))\\spad{+2}.0D0*X(1)\\spad{\\br} \\tab{7}CJAC(2,{}2)\\spad{=2}.0D0*X(2)+(\\spad{-2}.0D0*X(1))\\spad{\\br} \\tab{7}CJAC(2,{}3)\\spad{=0}.0D0\\spad{\\br} \\tab{7}CJAC(2,{}4)\\spad{=0}.0D0\\spad{\\br} \\tab{7}CJAC(2,{}5)\\spad{=0}.0D0\\spad{\\br} \\tab{7}CJAC(2,{}6)\\spad{=0}.0D0\\spad{\\br} \\tab{5}ENDIF\\spad{\\br} \\tab{5}IF(NEEDC(3).\\spad{GT}.0)THEN\\spad{\\br} \\tab{7}\\spad{C}(3)\\spad{=X}(3)**2+(\\spad{-2}.0D0*X(1)\\spad{*X}(3))\\spad{+X}(2)**2+X(1)\\spad{**2}\\spad{\\br} \\tab{7}CJAC(3,{}1)=(\\spad{-2}.0D0*X(3))\\spad{+2}.0D0*X(1)\\spad{\\br} \\tab{7}CJAC(3,{}2)\\spad{=2}.0D0*X(2)\\spad{\\br} \\tab{7}CJAC(3,{}3)\\spad{=2}.0D0*X(3)+(\\spad{-2}.0D0*X(1))\\spad{\\br} \\tab{7}CJAC(3,{}4)\\spad{=0}.0D0\\spad{\\br} \\tab{7}CJAC(3,{}5)\\spad{=0}.0D0\\spad{\\br} \\tab{7}CJAC(3,{}6)\\spad{=0}.0D0\\spad{\\br} \\tab{5}ENDIF\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END")) (|coerce| (($ (|Vector| (|FortranExpression| (|construct|) (|construct| (QUOTE X)) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-86 -3391) 
+(-86 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp6} produces Fortran for Type 6 ASPs,{} needed for NAG routines c05nbf,{} c05ncf. These represent vectors of functions of \\spad{X}(\\spad{i}) and look like: \\blankline \\tab{5}SUBROUTINE \\spad{FCN}(\\spad{N},{}\\spad{X},{}FVEC,{}IFLAG) \\tab{5}DOUBLE PRECISION \\spad{X}(\\spad{N}),{}FVEC(\\spad{N}) \\tab{5}INTEGER \\spad{N},{}IFLAG \\tab{5}FVEC(1)=(\\spad{-2}.0D0*X(2))+(\\spad{-2}.0D0*X(1)\\spad{**2})\\spad{+3}.0D0*X(1)\\spad{+1}.0D0 \\tab{5}FVEC(2)=(\\spad{-2}.0D0*X(3))+(\\spad{-2}.0D0*X(2)\\spad{**2})\\spad{+3}.0D0*X(2)+(\\spad{-1}.0D0*X(1))\\spad{+1}. \\tab{4}\\spad{&0D0} \\tab{5}FVEC(3)=(\\spad{-2}.0D0*X(4))+(\\spad{-2}.0D0*X(3)\\spad{**2})\\spad{+3}.0D0*X(3)+(\\spad{-1}.0D0*X(2))\\spad{+1}. \\tab{4}\\spad{&0D0} \\tab{5}FVEC(4)=(\\spad{-2}.0D0*X(5))+(\\spad{-2}.0D0*X(4)\\spad{**2})\\spad{+3}.0D0*X(4)+(\\spad{-1}.0D0*X(3))\\spad{+1}. \\tab{4}\\spad{&0D0} \\tab{5}FVEC(5)=(\\spad{-2}.0D0*X(6))+(\\spad{-2}.0D0*X(5)\\spad{**2})\\spad{+3}.0D0*X(5)+(\\spad{-1}.0D0*X(4))\\spad{+1}. \\tab{4}\\spad{&0D0} \\tab{5}FVEC(6)=(\\spad{-2}.0D0*X(7))+(\\spad{-2}.0D0*X(6)\\spad{**2})\\spad{+3}.0D0*X(6)+(\\spad{-1}.0D0*X(5))\\spad{+1}. \\tab{4}\\spad{&0D0} \\tab{5}FVEC(7)=(\\spad{-2}.0D0*X(8))+(\\spad{-2}.0D0*X(7)\\spad{**2})\\spad{+3}.0D0*X(7)+(\\spad{-1}.0D0*X(6))\\spad{+1}. \\tab{4}\\spad{&0D0} \\tab{5}FVEC(8)=(\\spad{-2}.0D0*X(9))+(\\spad{-2}.0D0*X(8)\\spad{**2})\\spad{+3}.0D0*X(8)+(\\spad{-1}.0D0*X(7))\\spad{+1}. \\tab{4}\\spad{&0D0} \\tab{5}FVEC(9)=(\\spad{-2}.0D0*X(9)\\spad{**2})\\spad{+3}.0D0*X(9)+(\\spad{-1}.0D0*X(8))\\spad{+1}.0D0 \\tab{5}RETURN \\tab{5}END")) (|coerce| (($ (|Vector| (|FortranExpression| (|construct|) (|construct| (QUOTE X)) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-87 -3391) 
+(-87 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp73} produces Fortran for Type 73 ASPs,{} needed for NAG routine d03eef,{} for example: \\blankline \\tab{5}SUBROUTINE PDEF(\\spad{X},{}\\spad{Y},{}ALPHA,{}BETA,{}GAMMA,{}DELTA,{}EPSOLN,{}PHI,{}PSI)\\spad{\\br} \\tab{5}DOUBLE PRECISION ALPHA,{}EPSOLN,{}PHI,{}\\spad{X},{}\\spad{Y},{}BETA,{}DELTA,{}GAMMA,{}PSI\\spad{\\br} \\tab{5}ALPHA=DSIN(\\spad{X})\\spad{\\br} \\tab{5}BETA=Y\\spad{\\br} \\tab{5}GAMMA=X*Y\\spad{\\br} \\tab{5}DELTA=DCOS(\\spad{X})*DSIN(\\spad{Y})\\spad{\\br} \\tab{5}EPSOLN=Y+X\\spad{\\br} \\tab{5}PHI=X\\spad{\\br} \\tab{5}PSI=Y\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END")) (|coerce| (($ (|Vector| (|FortranExpression| (|construct| (QUOTE X) (QUOTE Y)) (|construct|) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-88 -3391) 
+(-88 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp74} produces Fortran for Type 74 ASPs,{} needed for NAG routine d03eef,{} for example: \\blankline \\tab{5} SUBROUTINE BNDY(\\spad{X},{}\\spad{Y},{}A,{}\\spad{B},{}\\spad{C},{}IBND)\\spad{\\br} \\tab{5} DOUBLE PRECISION A,{}\\spad{B},{}\\spad{C},{}\\spad{X},{}\\spad{Y}\\spad{\\br} \\tab{5} INTEGER IBND\\spad{\\br} \\tab{5} IF(IBND.EQ.0)THEN\\spad{\\br} \\tab{7} \\spad{A=0}.0D0\\spad{\\br} \\tab{7} \\spad{B=1}.0D0\\spad{\\br} \\tab{7} \\spad{C=}-1.0D0*DSIN(\\spad{X})\\spad{\\br} \\tab{5} ELSEIF(IBND.EQ.1)THEN\\spad{\\br} \\tab{7} \\spad{A=1}.0D0\\spad{\\br} \\tab{7} \\spad{B=0}.0D0\\spad{\\br} \\tab{7} C=DSIN(\\spad{X})*DSIN(\\spad{Y})\\spad{\\br} \\tab{5} ELSEIF(IBND.EQ.2)THEN\\spad{\\br} \\tab{7} \\spad{A=1}.0D0\\spad{\\br} \\tab{7} \\spad{B=0}.0D0\\spad{\\br} \\tab{7} C=DSIN(\\spad{X})*DSIN(\\spad{Y})\\spad{\\br} \\tab{5} ELSEIF(IBND.EQ.3)THEN\\spad{\\br} \\tab{7} \\spad{A=0}.0D0\\spad{\\br} \\tab{7} \\spad{B=1}.0D0\\spad{\\br} \\tab{7} \\spad{C=}-1.0D0*DSIN(\\spad{Y})\\spad{\\br} \\tab{5} ENDIF\\spad{\\br} \\tab{5} END")) (|coerce| (($ (|Matrix| (|FortranExpression| (|construct| (QUOTE X) (QUOTE Y)) (|construct|) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-89 -3391) 
+(-89 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp77} produces Fortran for Type 77 ASPs,{} needed for NAG routine d02gbf,{} for example: \\blankline \\tab{5}SUBROUTINE FCNF(\\spad{X},{}\\spad{F})\\spad{\\br} \\tab{5}DOUBLE PRECISION \\spad{X}\\spad{\\br} \\tab{5}DOUBLE PRECISION \\spad{F}(2,{}2)\\spad{\\br} \\tab{5}\\spad{F}(1,{}1)\\spad{=0}.0D0\\spad{\\br} \\tab{5}\\spad{F}(1,{}2)\\spad{=1}.0D0\\spad{\\br} \\tab{5}\\spad{F}(2,{}1)\\spad{=0}.0D0\\spad{\\br} \\tab{5}\\spad{F}(2,{}2)=-10.0D0\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END")) (|coerce| (($ (|Matrix| (|FortranExpression| (|construct| (QUOTE X)) (|construct|) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-90 -3391) 
+(-90 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp78} produces Fortran for Type 78 ASPs,{} needed for NAG routine d02gbf,{} for example: \\blankline \\tab{5}SUBROUTINE FCNG(\\spad{X},{}\\spad{G})\\spad{\\br} \\tab{5}DOUBLE PRECISION \\spad{G}(*),{}\\spad{X}\\spad{\\br} \\tab{5}\\spad{G}(1)\\spad{=0}.0D0\\spad{\\br} \\tab{5}\\spad{G}(2)\\spad{=0}.0D0\\spad{\\br} \\tab{5}END")) (|coerce| (($ (|Vector| (|FortranExpression| (|construct| (QUOTE X)) (|construct|) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-91 -3391) 
+(-91 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp7} produces Fortran for Type 7 ASPs,{} needed for NAG routines d02bbf,{} d02gaf. These represent a vector of functions of the scalar \\spad{X} and the array \\spad{Z},{} and look like: \\blankline \\tab{5}SUBROUTINE \\spad{FCN}(\\spad{X},{}\\spad{Z},{}\\spad{F})\\spad{\\br} \\tab{5}DOUBLE PRECISION \\spad{F}(*),{}\\spad{X},{}\\spad{Z}(*)\\spad{\\br} \\tab{5}\\spad{F}(1)=DTAN(\\spad{Z}(3))\\spad{\\br} \\tab{5}\\spad{F}(2)=((\\spad{-0}.03199999999999999D0*DCOS(\\spad{Z}(3))*DTAN(\\spad{Z}(3)))+(\\spad{-0}.02D0*Z(2)\\spad{\\br} \\tab{4}\\spad{&**2}))/(\\spad{Z}(2)*DCOS(\\spad{Z}(3)))\\spad{\\br} \\tab{5}\\spad{F}(3)=-0.03199999999999999D0/(\\spad{X*Z}(2)\\spad{**2})\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END")) (|coerce| (($ (|Vector| (|FortranExpression| (|construct| (QUOTE X)) (|construct| (QUOTE Y)) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-92 -3391) 
+(-92 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp80} produces Fortran for Type 80 ASPs,{} needed for NAG routine d02kef,{} for example: \\blankline \\tab{5}SUBROUTINE BDYVAL(\\spad{XL},{}\\spad{XR},{}ELAM,{}\\spad{YL},{}\\spad{YR})\\spad{\\br} \\tab{5}DOUBLE PRECISION ELAM,{}\\spad{XL},{}\\spad{YL}(3),{}\\spad{XR},{}\\spad{YR}(3)\\spad{\\br} \\tab{5}\\spad{YL}(1)\\spad{=XL}\\spad{\\br} \\tab{5}\\spad{YL}(2)\\spad{=2}.0D0\\spad{\\br} \\tab{5}\\spad{YR}(1)\\spad{=1}.0D0\\spad{\\br} \\tab{5}\\spad{YR}(2)=-1.0D0*DSQRT(\\spad{XR+}(\\spad{-1}.0D0*ELAM))\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END")) (|coerce| (($ (|Matrix| (|FortranExpression| (|construct| (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (|construct|) (|MachineFloat|)))) "\\spad{coerce(f)} takes objects from the appropriate instantiation of \\spadtype{FortranExpression} and turns them into an ASP."))) 
 NIL 
 NIL 
-(-93 -3391) 
+(-93 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp8} produces Fortran for Type 8 ASPs,{} needed for NAG routine d02bbf. This ASP prints intermediate values of the computed solution of an ODE and might look like: \\blankline \\tab{5}SUBROUTINE OUTPUT(XSOL,{}\\spad{Y},{}COUNT,{}\\spad{M},{}\\spad{N},{}RESULT,{}FORWRD)\\spad{\\br} \\tab{5}DOUBLE PRECISION \\spad{Y}(\\spad{N}),{}RESULT(\\spad{M},{}\\spad{N}),{}XSOL\\spad{\\br} \\tab{5}INTEGER \\spad{M},{}\\spad{N},{}COUNT\\spad{\\br} \\tab{5}LOGICAL FORWRD\\spad{\\br} \\tab{5}DOUBLE PRECISION X02ALF,{}POINTS(8)\\spad{\\br} \\tab{5}EXTERNAL X02ALF\\spad{\\br} \\tab{5}INTEGER \\spad{I}\\spad{\\br} \\tab{5}POINTS(1)\\spad{=1}.0D0\\spad{\\br} \\tab{5}POINTS(2)\\spad{=2}.0D0\\spad{\\br} \\tab{5}POINTS(3)\\spad{=3}.0D0\\spad{\\br} \\tab{5}POINTS(4)\\spad{=4}.0D0\\spad{\\br} \\tab{5}POINTS(5)\\spad{=5}.0D0\\spad{\\br} \\tab{5}POINTS(6)\\spad{=6}.0D0\\spad{\\br} \\tab{5}POINTS(7)\\spad{=7}.0D0\\spad{\\br} \\tab{5}POINTS(8)\\spad{=8}.0D0\\spad{\\br} \\tab{5}\\spad{COUNT=COUNT+1}\\spad{\\br} \\tab{5}DO 25001 \\spad{I=1},{}\\spad{N}\\spad{\\br} \\tab{7} RESULT(COUNT,{}\\spad{I})\\spad{=Y}(\\spad{I})\\spad{\\br} 25001 CONTINUE\\spad{\\br} \\tab{5}IF(COUNT.EQ.\\spad{M})THEN\\spad{\\br} \\tab{7}IF(FORWRD)THEN\\spad{\\br} \\tab{9}XSOL=X02ALF()\\spad{\\br} \\tab{7}ELSE\\spad{\\br} \\tab{9}XSOL=-X02ALF()\\spad{\\br} \\tab{7}ENDIF\\spad{\\br} \\tab{5}ELSE\\spad{\\br} \\tab{7} XSOL=POINTS(COUNT)\\spad{\\br} \\tab{5}ENDIF\\spad{\\br} \\tab{5}END"))) 
 NIL 
 NIL 
-(-94 -3391) 
+(-94 -3393) 
 ((|constructor| (NIL "\\spadtype{Asp9} produces Fortran for Type 9 ASPs,{} needed for NAG routines d02bhf,{} d02cjf,{} d02ejf. These ASPs represent a function of a scalar \\spad{X} and a vector \\spad{Y},{} for example: \\blankline \\tab{5}DOUBLE PRECISION FUNCTION \\spad{G}(\\spad{X},{}\\spad{Y})\\spad{\\br} \\tab{5}DOUBLE PRECISION \\spad{X},{}\\spad{Y}(*)\\spad{\\br} \\tab{5}G=X+Y(1)\\spad{\\br} \\tab{5}RETURN\\spad{\\br} \\tab{5}END \\blankline If the user provides a constant value for \\spad{G},{} then extra information is added via COMMON blocks used by certain routines. This specifies that the value returned by \\spad{G} in this case is to be ignored.")) (|coerce| (($ (|FortranExpression| (|construct| (QUOTE X)) (|construct| (QUOTE Y)) (|MachineFloat|))) "\\spad{coerce(f)} takes an object from the appropriate instantiation of \\spadtype{FortranExpression} and turns it into an ASP."))) 
 NIL 
 NIL 
@@ -314,7 +314,7 @@ NIL
 ((|HasCategory| |#1| (QUOTE (-365)))) 
 (-96 S) 
 ((|constructor| (NIL "A stack represented as a flexible array.")) (|member?| (((|Boolean|) |#1| $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} member?(3,{}a)")) (|members| (((|List| |#1|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} members a")) (|parts| (((|List| |#1|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} parts a")) (|#| (((|NonNegativeInteger|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} \\#a")) (|count| (((|NonNegativeInteger|) |#1| $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} count(4,{}a)") (((|NonNegativeInteger|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} count(\\spad{x+}->(\\spad{x>2}),{}a)")) (|any?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} any?(\\spad{x+}->(\\spad{x=4}),{}a)")) (|every?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} every?(\\spad{x+}->(\\spad{x=4}),{}a)")) (~= (((|Boolean|) $ $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} b:=copy a \\spad{X} (a~=b)")) (= (((|Boolean|) $ $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} b:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} (a=b)@Boolean")) (|coerce| (((|OutputForm|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} coerce a")) (|hash| (((|SingleInteger|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} hash a")) (|latex| (((|String|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} latex a")) (|map!| (($ (|Mapping| |#1| |#1|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} map!(\\spad{x+}-\\spad{>x+10},{}a) \\spad{X} a")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} map(\\spad{x+}-\\spad{>x+10},{}a) \\spad{X} a")) (|eq?| (((|Boolean|) $ $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} b:=copy a \\spad{X} eq?(a,{}\\spad{b})")) (|copy| (($ $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} copy a")) (|sample| (($) "\\blankline \\spad{X} sample()\\$ArrayStack(INT)")) (|empty| (($) "\\blankline \\spad{X} b:=empty()\\$(ArrayStack INT)")) (|empty?| (((|Boolean|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} empty? a")) (|bag| (($ (|List| |#1|)) "\\blankline \\spad{X} bag([1,{}2,{}3,{}4,{}5])\\$ArrayStack(INT)")) (|size?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} size?(a,{}5)")) (|more?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} more?(a,{}9)")) (|less?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} less?(a,{}9)")) (|depth| (((|NonNegativeInteger|) $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} depth a")) (|top| ((|#1| $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} top a")) (|inspect| ((|#1| $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} inspect a")) (|insert!| (($ |#1| $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} insert!(8,{}a) \\spad{X} a")) (|push!| ((|#1| |#1| $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} push!(9,{}a) \\spad{X} a")) (|extract!| ((|#1| $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} extract! a \\spad{X} a")) (|pop!| ((|#1| $) "\\blankline \\spad{X} a:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5] \\spad{X} pop! a \\spad{X} a")) (|arrayStack| (($ (|List| |#1|)) "\\indented{1}{arrayStack([\\spad{x},{}\\spad{y},{}...,{}\\spad{z}]) creates an array stack with first (top)} \\indented{1}{element \\spad{x},{} second element \\spad{y},{}...,{}and last element \\spad{z}.} \\blankline \\spad{E} c:ArrayStack INT:= arrayStack [1,{}2,{}3,{}4,{}5]"))) 
-((-4519 . T) (-4520 . T)) 
+((-4521 . T) (-4522 . T)) 
 ((|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090))))) 
 (-97 S) 
 ((|constructor| (NIL "Category for the inverse trigonometric functions.")) (|atan| (($ $) "\\spad{atan(x)} returns the arc-tangent of \\spad{x}.")) (|asin| (($ $) "\\spad{asin(x)} returns the arc-sine of \\spad{x}.")) (|asec| (($ $) "\\spad{asec(x)} returns the arc-secant of \\spad{x}.")) (|acsc| (($ $) "\\spad{acsc(x)} returns the arc-cosecant of \\spad{x}.")) (|acot| (($ $) "\\spad{acot(x)} returns the arc-cotangent of \\spad{x}.")) (|acos| (($ $) "\\spad{acos(x)} returns the arc-cosine of \\spad{x}."))) 
@@ -326,15 +326,15 @@ NIL
 NIL 
 (-99) 
 ((|constructor| (NIL "\\axiomType{AttributeButtons} implements a database and associated adjustment mechanisms for a set of attributes. \\blankline For ODEs these attributes are \"stiffness\",{} \"stability\" (\\spadignore{i.e.} how much affect the cosine or sine component of the solution has on the stability of the result),{} \"accuracy\" and \"expense\" (\\spadignore{i.e.} how expensive is the evaluation of the ODE). All these have bearing on the cost of calculating the solution given that reducing the step-length to achieve greater accuracy requires considerable number of evaluations and calculations. \\blankline The effect of each of these attributes can be altered by increasing or decreasing the button value. \\blankline For Integration there is a button for increasing and decreasing the preset number of function evaluations for each method. This is automatically used by ANNA when a method fails due to insufficient workspace or where the limit of function evaluations has been reached before the required accuracy is achieved.")) (|setButtonValue| (((|Float|) (|String|) (|String|) (|Float|)) "\\axiom{setButtonValue(attributeName,{}routineName,{}\\spad{n})} sets the value of the button of attribute \\spad{attributeName} to routine \\spad{routineName} to \\spad{n}. \\spad{n} must be in the range [0..1]. \\blankline \\axiom{attributeName} should be one of the values \"stiffness\",{} \"stability\",{} \"accuracy\",{} \"expense\" or \"functionEvaluations\".") (((|Float|) (|String|) (|Float|)) "\\axiom{setButtonValue(attributeName,{}\\spad{n})} sets the value of all buttons of attribute \\spad{attributeName} to \\spad{n}. \\spad{n} must be in the range [0..1]. \\blankline \\axiom{attributeName} should be one of the values \"stiffness\",{} \"stability\",{} \"accuracy\",{} \"expense\" or \"functionEvaluations\".")) (|setAttributeButtonStep| (((|Float|) (|Float|)) "\\axiom{setAttributeButtonStep(\\spad{n})} sets the value of the steps for increasing and decreasing the button values. \\axiom{\\spad{n}} must be greater than 0 and less than 1. The preset value is 0.5.")) (|resetAttributeButtons| (((|Void|)) "\\axiom{resetAttributeButtons()} resets the Attribute buttons to a neutral level.")) (|getButtonValue| (((|Float|) (|String|) (|String|)) "\\axiom{getButtonValue(routineName,{}attributeName)} returns the current value for the effect of the attribute \\axiom{attributeName} with routine \\axiom{routineName}. \\blankline \\axiom{attributeName} should be one of the values \"stiffness\",{} \"stability\",{} \"accuracy\",{} \"expense\" or \"functionEvaluations\".")) (|decrease| (((|Float|) (|String|)) "\\axiom{decrease(attributeName)} decreases the value for the effect of the attribute \\axiom{attributeName} with all routines. \\blankline \\axiom{attributeName} should be one of the values \"stiffness\",{} \"stability\",{} \"accuracy\",{} \"expense\" or \"functionEvaluations\".") (((|Float|) (|String|) (|String|)) "\\axiom{decrease(routineName,{}attributeName)} decreases the value for the effect of the attribute \\axiom{attributeName} with routine \\axiom{routineName}. \\blankline \\axiom{attributeName} should be one of the values \"stiffness\",{} \"stability\",{} \"accuracy\",{} \"expense\" or \"functionEvaluations\".")) (|increase| (((|Float|) (|String|)) "\\axiom{increase(attributeName)} increases the value for the effect of the attribute \\axiom{attributeName} with all routines. \\blankline \\axiom{attributeName} should be one of the values \"stiffness\",{} \"stability\",{} \"accuracy\",{} \"expense\" or \"functionEvaluations\".") (((|Float|) (|String|) (|String|)) "\\axiom{increase(routineName,{}attributeName)} increases the value for the effect of the attribute \\axiom{attributeName} with routine \\axiom{routineName}. \\blankline \\axiom{attributeName} should be one of the values \"stiffness\",{} \"stability\",{} \"accuracy\",{} \"expense\" or \"functionEvaluations\"."))) 
-((-4519 . T)) 
+((-4521 . T)) 
 NIL 
 (-100) 
 ((|constructor| (NIL "This category exports the attributes in the AXIOM Library")) (|approximate| ((|attribute|) "\\spad{approximate} means \"is an approximation to the real numbers\".")) (|canonical| ((|attribute|) "\\spad{canonical} is \\spad{true} if and only if distinct elements have distinct data structures. For example,{} a domain of mathematical objects which has the \\spad{canonical} attribute means that two objects are mathematically equal if and only if their data structures are equal.")) (|multiplicativeValuation| ((|attribute|) "\\spad{multiplicativeValuation} implies \\spad{euclideanSize(a*b)=euclideanSize(a)*euclideanSize(b)}.")) (|additiveValuation| ((|attribute|) "\\spad{additiveValuation} implies \\spad{euclideanSize(a*b)=euclideanSize(a)+euclideanSize(b)}.")) (|noetherian| ((|attribute|) "\\spad{noetherian} is \\spad{true} if all of its ideals are finitely generated.")) (|central| ((|attribute|) "\\spad{central} is \\spad{true} if,{} given an algebra over a ring \\spad{R},{} the image of \\spad{R} is the center of the algebra,{} \\spadignore{i.e.} the set of members of the algebra which commute with all others is precisely the image of \\spad{R} in the algebra.")) (|partiallyOrderedSet| ((|attribute|) "\\spad{partiallyOrderedSet} is \\spad{true} if a set with \\spadop{<} which is transitive,{} but \\spad{not(a < b or a = b)} does not necessarily imply \\spad{b<a}.")) (|arbitraryPrecision| ((|attribute|) "\\spad{arbitraryPrecision} means the user can set the precision for subsequent calculations.")) (|canonicalsClosed| ((|attribute|) "\\spad{canonicalsClosed} is \\spad{true} if \\spad{unitCanonical(a)*unitCanonical(b) = unitCanonical(a*b)}.")) (|canonicalUnitNormal| ((|attribute|) "\\spad{canonicalUnitNormal} is \\spad{true} if we can choose a canonical representative for each class of associate elements,{} that is \\spad{associates?(a,{}b)} returns \\spad{true} if and only if \\spad{unitCanonical(a) = unitCanonical(b)}.")) (|noZeroDivisors| ((|attribute|) "\\spad{noZeroDivisors} is \\spad{true} if \\spad{x * y \\~~= 0} implies both \\spad{x} and \\spad{y} are non-zero.")) (|rightUnitary| ((|attribute|) "\\spad{rightUnitary} is \\spad{true} if \\spad{x * 1 = x} for all \\spad{x}.")) (|leftUnitary| ((|attribute|) "\\spad{leftUnitary} is \\spad{true} if \\spad{1 * x = x} for all \\spad{x}.")) (|unitsKnown| ((|attribute|) "\\spad{unitsKnown} is \\spad{true} if a monoid (a multiplicative semigroup with a 1) has \\spad{unitsKnown} means that the operation \\spadfun{recip} can only return \"failed\" if its argument is not a unit.")) (|shallowlyMutable| ((|attribute|) "\\spad{shallowlyMutable} is \\spad{true} if its values have immediate components that are updateable (mutable). Note that the properties of any component domain are irrevelant to the \\spad{shallowlyMutable} proper.")) (|commutative| ((|attribute| "*") "\\spad{commutative(\"*\")} is \\spad{true} if it has an operation \\spad{\"*\": (D,{}D) -> D} which is commutative.")) (|finiteAggregate| ((|attribute|) "\\spad{finiteAggregate} is \\spad{true} if it is an aggregate with a finite number of elements."))) 
-((-4519 . T) ((-4521 "*") . T) (-4520 . T) (-4516 . T) (-4514 . T) (-4513 . T) (-4512 . T) (-4517 . T) (-4511 . T) (-4510 . T) (-4509 . T) (-4508 . T) (-4507 . T) (-4515 . T) (-4518 . T) (|NullSquare| . T) (|JacobiIdentity| . T) (-4506 . T) (-3996 . T)) 
+((-4521 . T) ((-4523 "*") . T) (-4522 . T) (-4518 . T) (-4516 . T) (-4515 . T) (-4514 . T) (-4519 . T) (-4513 . T) (-4512 . T) (-4511 . T) (-4510 . T) (-4509 . T) (-4517 . T) (-4520 . T) (|NullSquare| . T) (|JacobiIdentity| . T) (-4508 . T) (-3999 . T)) 
 NIL 
 (-101 R) 
 ((|constructor| (NIL "Automorphism \\spad{R} is the multiplicative group of automorphisms of \\spad{R}.")) (|morphism| (($ (|Mapping| |#1| |#1| (|Integer|))) "\\spad{morphism(f)} returns the morphism given by \\spad{f^n(x) = f(x,{}n)}.") (($ (|Mapping| |#1| |#1|) (|Mapping| |#1| |#1|)) "\\spad{morphism(f,{} g)} returns the invertible morphism given by \\spad{f},{} where \\spad{g} is the inverse of \\spad{f}..") (($ (|Mapping| |#1| |#1|)) "\\spad{morphism(f)} returns the non-invertible morphism given by \\spad{f}."))) 
-((-4516 . T)) 
+((-4518 . T)) 
 NIL 
 (-102) 
 ((|constructor| (NIL "This package provides a functions to support a web server for the new Axiom Browser functions."))) 
@@ -354,7 +354,7 @@ NIL
 NIL 
 (-106 S) 
 ((|constructor| (NIL "\\spadtype{BalancedBinaryTree(S)} is the domain of balanced binary trees (bbtree). A balanced binary tree of \\spad{2**k} leaves,{} for some \\spad{k > 0},{} is symmetric,{} that is,{} the left and right subtree of each interior node have identical shape. In general,{} the left and right subtree of a given node can differ by at most leaf node.")) (|mapDown!| (($ $ |#1| (|Mapping| (|List| |#1|) |#1| |#1| |#1|)) "\\indented{1}{mapDown!(\\spad{t},{}\\spad{p},{}\\spad{f}) returns \\spad{t} after traversing \\spad{t} in \"preorder\"} \\indented{1}{(node then left then right) fashion replacing the successive} \\indented{1}{interior nodes as follows. Let \\spad{l} and \\spad{r} denote the left and} \\indented{1}{right subtrees of \\spad{t}. The root value \\spad{x} of \\spad{t} is replaced by \\spad{p}.} \\indented{1}{Then \\spad{f}(value \\spad{l},{} value \\spad{r},{} \\spad{p}),{} where \\spad{l} and \\spad{r} denote the left} \\indented{1}{and right subtrees of \\spad{t},{} is evaluated producing two values} \\indented{1}{\\spad{pl} and \\spad{pr}. Then \\spad{mapDown!(l,{}pl,{}f)} and \\spad{mapDown!(l,{}pr,{}f)}} \\indented{1}{are evaluated.} \\blankline \\spad{X} T1:=BalancedBinaryTree Integer \\spad{X} t2:=balancedBinaryTree(4,{} 0)\\$\\spad{T1} \\spad{X} setleaves!(\\spad{t2},{}[1,{}2,{}3,{}4]::List(Integer)) \\spad{X} \\spad{adder3}(i:Integer,{}j:Integer,{}k:Integer):List Integer \\spad{==} [i+j,{}\\spad{j+k}] \\spad{X} mapDown!(\\spad{t2},{}4::INT,{}\\spad{adder3}) \\spad{X} \\spad{t2}") (($ $ |#1| (|Mapping| |#1| |#1| |#1|)) "\\indented{1}{mapDown!(\\spad{t},{}\\spad{p},{}\\spad{f}) returns \\spad{t} after traversing \\spad{t} in \"preorder\"} \\indented{1}{(node then left then right) fashion replacing the successive} \\indented{1}{interior nodes as follows. The root value \\spad{x} is} \\indented{1}{replaced by \\spad{q} \\spad{:=} \\spad{f}(\\spad{p},{}\\spad{x}). The mapDown!(\\spad{l},{}\\spad{q},{}\\spad{f}) and} \\indented{1}{mapDown!(\\spad{r},{}\\spad{q},{}\\spad{f}) are evaluated for the left and right subtrees} \\indented{1}{\\spad{l} and \\spad{r} of \\spad{t}.} \\blankline \\spad{X} T1:=BalancedBinaryTree Integer \\spad{X} t2:=balancedBinaryTree(4,{} 0)\\$\\spad{T1} \\spad{X} setleaves!(\\spad{t2},{}[1,{}2,{}3,{}4]::List(Integer)) \\spad{X} adder(i:Integer,{}j:Integer):Integer \\spad{==} i+j \\spad{X} mapDown!(\\spad{t2},{}4::INT,{}adder) \\spad{X} \\spad{t2}")) (|mapUp!| (($ $ $ (|Mapping| |#1| |#1| |#1| |#1| |#1|)) "\\indented{1}{mapUp!(\\spad{t},{}\\spad{t1},{}\\spad{f}) traverses balanced binary tree \\spad{t} in an \"endorder\"} \\indented{1}{(left then right then node) fashion returning \\spad{t} with the value} \\indented{1}{at each successive interior node of \\spad{t} replaced by} \\indented{1}{\\spad{f}(\\spad{l},{}\\spad{r},{}\\spad{l1},{}\\spad{r1}) where \\spad{l} and \\spad{r} are the values at the immediate} \\indented{1}{left and right nodes. Values \\spad{l1} and \\spad{r1} are values at the} \\indented{1}{corresponding nodes of a balanced binary tree \\spad{t1},{} of identical} \\indented{1}{shape at \\spad{t}.} \\blankline \\spad{X} T1:=BalancedBinaryTree Integer \\spad{X} t2:=balancedBinaryTree(4,{} 0)\\$\\spad{T1} \\spad{X} setleaves!(\\spad{t2},{}[1,{}2,{}3,{}4]::List(Integer)) \\spad{X} \\spad{adder4}(i:INT,{}j:INT,{}k:INT,{}l:INT):INT \\spad{==} i+j+k+l \\spad{X} mapUp!(\\spad{t2},{}\\spad{t2},{}\\spad{adder4}) \\spad{X} \\spad{t2}") ((|#1| $ (|Mapping| |#1| |#1| |#1|)) "\\indented{1}{mapUp!(\\spad{t},{}\\spad{f}) traverses balanced binary tree \\spad{t} in an \"endorder\"} \\indented{1}{(left then right then node) fashion returning \\spad{t} with the value} \\indented{1}{at each successive interior node of \\spad{t} replaced by} \\indented{1}{\\spad{f}(\\spad{l},{}\\spad{r}) where \\spad{l} and \\spad{r} are the values at the immediate} \\indented{1}{left and right nodes.} \\blankline \\spad{X} T1:=BalancedBinaryTree Integer \\spad{X} t2:=balancedBinaryTree(4,{} 0)\\$\\spad{T1} \\spad{X} setleaves!(\\spad{t2},{}[1,{}2,{}3,{}4]::List(Integer)) \\spad{X} adder(a:Integer,{}b:Integer):Integer \\spad{==} a+b \\spad{X} mapUp!(\\spad{t2},{}adder) \\spad{X} \\spad{t2}")) (|setleaves!| (($ $ (|List| |#1|)) "\\indented{1}{setleaves!(\\spad{t},{} \\spad{ls}) sets the leaves of \\spad{t} in left-to-right order} \\indented{1}{to the elements of \\spad{ls}.} \\blankline \\spad{X} t1:=balancedBinaryTree(4,{} 0) \\spad{X} setleaves!(\\spad{t1},{}[1,{}2,{}3,{}4])")) (|balancedBinaryTree| (($ (|NonNegativeInteger|) |#1|) "\\indented{1}{balancedBinaryTree(\\spad{n},{} \\spad{s}) creates a balanced binary tree with} \\indented{1}{\\spad{n} nodes each with value \\spad{s}.} \\blankline \\spad{X} balancedBinaryTree(4,{} 0)"))) 
-((-4519 . T) (-4520 . T)) 
+((-4521 . T) (-4522 . T)) 
 ((|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090))))) 
 (-107 R) 
 ((|constructor| (NIL "Provide linear,{} quadratic,{} and cubic spline bezier curves")) (|cubicBezier| (((|Mapping| (|List| |#1|) |#1|) (|List| |#1|) (|List| |#1|) (|List| |#1|) (|List| |#1|)) "\\indented{1}{A cubic Bezier curve is a simple interpolation between the} \\indented{1}{starting point,{} a left-middle point,{},{} a right-middle point,{}} \\indented{1}{and the ending point based on a parameter \\spad{t}.} \\indented{1}{Given a start point a=[\\spad{x1},{}\\spad{y1}],{} the left-middle point \\spad{b=}[\\spad{x2},{}\\spad{y2}],{}} \\indented{1}{the right-middle point \\spad{c=}[\\spad{x3},{}\\spad{y3}] and an endpoint \\spad{d=}[\\spad{x4},{}\\spad{y4}]} \\indented{1}{\\spad{f}(\\spad{t}) \\spad{==} [(1-\\spad{t})\\spad{^3} \\spad{x1} + 3t(1-\\spad{t})\\spad{^2} \\spad{x2} + 3t^2 (1-\\spad{t}) \\spad{x3} + \\spad{t^3} \\spad{x4},{}} \\indented{10}{(1-\\spad{t})\\spad{^3} \\spad{y1} + 3t(1-\\spad{t})\\spad{^2} \\spad{y2} + 3t^2 (1-\\spad{t}) \\spad{y3} + \\spad{t^3} \\spad{y4}]} \\blankline \\spad{X} n:=cubicBezier([2.0,{}2.0],{}[2.0,{}4.0],{}[6.0,{}4.0],{}[6.0,{}2.0]) \\spad{X} [\\spad{n}(\\spad{t/10}.0) for \\spad{t} in 0..10 by 1]")) (|quadraticBezier| (((|Mapping| (|List| |#1|) |#1|) (|List| |#1|) (|List| |#1|) (|List| |#1|)) "\\indented{1}{A quadratic Bezier curve is a simple interpolation between the} \\indented{1}{starting point,{} a middle point,{} and the ending point based on} \\indented{1}{a parameter \\spad{t}.} \\indented{1}{Given a start point a=[\\spad{x1},{}\\spad{y1}],{} a middle point \\spad{b=}[\\spad{x2},{}\\spad{y2}],{}} \\indented{1}{and an endpoint \\spad{c=}[\\spad{x3},{}\\spad{y3}]} \\indented{1}{\\spad{f}(\\spad{t}) \\spad{==} [(1-\\spad{t})\\spad{^2} \\spad{x1} + 2t(1-\\spad{t}) \\spad{x2} + \\spad{t^2} \\spad{x3},{}} \\indented{10}{(1-\\spad{t})\\spad{^2} \\spad{y1} + 2t(1-\\spad{t}) \\spad{y2} + \\spad{t^2} \\spad{y3}]} \\blankline \\spad{X} n:=quadraticBezier([2.0,{}2.0],{}[4.0,{}4.0],{}[6.0,{}2.0]) \\spad{X} [\\spad{n}(\\spad{t/10}.0) for \\spad{t} in 0..10 by 1]")) (|linearBezier| (((|Mapping| (|List| |#1|) |#1|) (|List| |#1|) (|List| |#1|)) "\\indented{1}{A linear Bezier curve is a simple interpolation between the} \\indented{1}{starting point and the ending point based on a parameter \\spad{t}.} \\indented{1}{Given a start point a=[\\spad{x1},{}\\spad{y1}] and an endpoint \\spad{b=}[\\spad{x2},{}\\spad{y2}]} \\indented{1}{\\spad{f}(\\spad{t}) \\spad{==} [(1-\\spad{t})\\spad{*x1} + \\spad{t*x2},{} (1-\\spad{t})\\spad{*y1} + \\spad{t*y2}]} \\blankline \\spad{X} n:=linearBezier([2.0,{}2.0],{}[4.0,{}4.0]) \\spad{X} [\\spad{n}(\\spad{t/10}.0) for \\spad{t} in 0..10 by 1]"))) 
@@ -363,10 +363,10 @@ NIL
 (-108 R UP M |Row| |Col|) 
 ((|constructor| (NIL "\\spadtype{BezoutMatrix} contains functions for computing resultants and discriminants using Bezout matrices.")) (|bezoutDiscriminant| ((|#1| |#2|) "\\spad{bezoutDiscriminant(p)} computes the discriminant of a polynomial \\spad{p} by computing the determinant of a Bezout matrix.")) (|bezoutResultant| ((|#1| |#2| |#2|) "\\spad{bezoutResultant(p,{}q)} computes the resultant of the two polynomials \\spad{p} and \\spad{q} by computing the determinant of a Bezout matrix.")) (|bezoutMatrix| ((|#3| |#2| |#2|) "\\spad{bezoutMatrix(p,{}q)} returns the Bezout matrix for the two polynomials \\spad{p} and \\spad{q}.")) (|sylvesterMatrix| ((|#3| |#2| |#2|) "\\spad{sylvesterMatrix(p,{}q)} returns the Sylvester matrix for the two polynomials \\spad{p} and \\spad{q}."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE (-4521 "*")))) 
+((|HasAttribute| |#1| (QUOTE (-4523 "*")))) 
 (-109) 
 ((|constructor| (NIL "A Domain which implements a table containing details of points at which particular functions have evaluation problems.")) (|bfEntry| (((|Record| (|:| |zeros| (|Stream| (|DoubleFloat|))) (|:| |ones| (|Stream| (|DoubleFloat|))) (|:| |singularities| (|Stream| (|DoubleFloat|)))) (|Symbol|)) "\\spad{bfEntry(k)} returns the entry in the \\axiomType{BasicFunctions} table corresponding to \\spad{k}")) (|bfKeys| (((|List| (|Symbol|))) "\\spad{bfKeys()} returns the names of each function in the \\axiomType{BasicFunctions} table"))) 
-((-4519 . T)) 
+((-4521 . T)) 
 NIL 
 (-110 A S) 
 ((|constructor| (NIL "A bag aggregate is an aggregate for which one can insert and extract objects,{} and where the order in which objects are inserted determines the order of extraction. Examples of bags are stacks,{} queues,{} and dequeues.")) (|inspect| ((|#2| $) "\\spad{inspect(u)} returns an (random) element from a bag.")) (|insert!| (($ |#2| $) "\\spad{insert!(x,{}u)} inserts item \\spad{x} into bag \\spad{u}.")) (|extract!| ((|#2| $) "\\spad{extract!(u)} destructively removes a (random) item from bag \\spad{u}.")) (|bag| (($ (|List| |#2|)) "\\spad{bag([x,{}y,{}...,{}z])} creates a bag with elements \\spad{x},{}\\spad{y},{}...,{}\\spad{z}.")) (|shallowlyMutable| ((|attribute|) "shallowlyMutable means that elements of bags may be destructively changed."))) 
@@ -374,19 +374,19 @@ NIL
 NIL 
 (-111 S) 
 ((|constructor| (NIL "A bag aggregate is an aggregate for which one can insert and extract objects,{} and where the order in which objects are inserted determines the order of extraction. Examples of bags are stacks,{} queues,{} and dequeues.")) (|inspect| ((|#1| $) "\\spad{inspect(u)} returns an (random) element from a bag.")) (|insert!| (($ |#1| $) "\\spad{insert!(x,{}u)} inserts item \\spad{x} into bag \\spad{u}.")) (|extract!| ((|#1| $) "\\spad{extract!(u)} destructively removes a (random) item from bag \\spad{u}.")) (|bag| (($ (|List| |#1|)) "\\spad{bag([x,{}y,{}...,{}z])} creates a bag with elements \\spad{x},{}\\spad{y},{}...,{}\\spad{z}.")) (|shallowlyMutable| ((|attribute|) "shallowlyMutable means that elements of bags may be destructively changed."))) 
-((-4520 . T) (-3973 . T)) 
+((-4522 . T) (-3973 . T)) 
 NIL 
 (-112) 
 ((|constructor| (NIL "This domain allows rational numbers to be presented as repeating binary expansions.")) (|binary| (($ (|Fraction| (|Integer|))) "\\indented{1}{binary(\\spad{r}) converts a rational number to a binary expansion.} \\blankline \\spad{X} binary(22/7)")) (|fractionPart| (((|Fraction| (|Integer|)) $) "\\spad{fractionPart(b)} returns the fractional part of a binary expansion.")) (|coerce| (((|RadixExpansion| 2) $) "\\spad{coerce(b)} converts a binary expansion to a radix expansion with base 2.") (((|Fraction| (|Integer|)) $) "\\spad{coerce(b)} converts a binary expansion to a rational number."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| (-568) (QUOTE (-904))) (|HasCategory| (-568) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| (-568) (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-150))) (|HasCategory| (-568) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-568) (QUOTE (-1021))) (|HasCategory| (-568) (QUOTE (-815))) (|HasCategory| (-568) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| (-568) (QUOTE (-1136))) (|HasCategory| (-568) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| (-568) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| (-568) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| (-568) (QUOTE (-225))) (|HasCategory| (-568) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-568) (LIST (QUOTE -523) (QUOTE (-1161)) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -303) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -281) (QUOTE (-568)) (QUOTE (-568)))) (|HasCategory| (-568) (QUOTE (-301))) (|HasCategory| (-568) (QUOTE (-550))) (|HasCategory| (-568) (QUOTE (-842))) (-2198 (|HasCategory| (-568) (QUOTE (-815))) (|HasCategory| (-568) (QUOTE (-842)))) (|HasCategory| (-568) (LIST (QUOTE -630) (QUOTE (-568)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-904)))) (|HasCategory| (-568) (QUOTE (-148))))) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| (-568) (QUOTE (-904))) (|HasCategory| (-568) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| (-568) (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-150))) (|HasCategory| (-568) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-568) (QUOTE (-1021))) (|HasCategory| (-568) (QUOTE (-815))) (|HasCategory| (-568) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| (-568) (QUOTE (-1136))) (|HasCategory| (-568) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| (-568) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| (-568) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| (-568) (QUOTE (-225))) (|HasCategory| (-568) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-568) (LIST (QUOTE -523) (QUOTE (-1161)) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -303) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -281) (QUOTE (-568)) (QUOTE (-568)))) (|HasCategory| (-568) (QUOTE (-301))) (|HasCategory| (-568) (QUOTE (-550))) (|HasCategory| (-568) (QUOTE (-842))) (-2199 (|HasCategory| (-568) (QUOTE (-815))) (|HasCategory| (-568) (QUOTE (-842)))) (|HasCategory| (-568) (LIST (QUOTE -630) (QUOTE (-568)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-904)))) (|HasCategory| (-568) (QUOTE (-148))))) 
 (-113) 
 ((|constructor| (NIL "This domain provides an implementation of binary files. Data is accessed one byte at a time as a small integer.")) (|position!| (((|SingleInteger|) $ (|SingleInteger|)) "\\spad{position!(f,{} i)} sets the current byte-position to \\spad{i}.")) (|position| (((|SingleInteger|) $) "\\spad{position(f)} returns the current byte-position in the file \\spad{f}.")) (|readIfCan!| (((|Union| (|SingleInteger|) "failed") $) "\\spad{readIfCan!(f)} returns a value from the file \\spad{f},{} if possible. If \\spad{f} is not open for reading,{} or if \\spad{f} is at the end of file then \\spad{\"failed\"} is the result."))) 
 NIL 
 NIL 
 (-114) 
 ((|constructor| (NIL "\\spadtype{Bits} provides logical functions for Indexed Bits.")) (|bits| (($ (|NonNegativeInteger|) (|Boolean|)) "\\spad{bits(n,{}b)} creates bits with \\spad{n} values of \\spad{b}"))) 
-((-4520 . T) (-4519 . T)) 
+((-4522 . T) (-4521 . T)) 
 ((|HasCategory| (-121) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-121) (QUOTE (-842))) (|HasCategory| (-568) (QUOTE (-842))) (|HasCategory| (-121) (QUOTE (-1090))) (-12 (|HasCategory| (-121) (LIST (QUOTE -303) (QUOTE (-121)))) (|HasCategory| (-121) (QUOTE (-1090))))) 
 (-115) 
 ((|constructor| (NIL "This package provides an interface to the Blas library (level 1)")) (|dcopy| (((|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|) (|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|) (|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|)) "\\indented{1}{dcopy(\\spad{n},{}\\spad{x},{}incx,{}\\spad{y},{}incy) copies \\spad{y} from \\spad{x}} \\indented{1}{for each of the chosen elements of the vectors \\spad{x} and \\spad{y}} \\indented{1}{Note that the vector \\spad{y} is modified with the results.} \\blankline \\spad{X} x:PRIMARR(DFLOAT)\\spad{:=}[ [1.0,{}2.0,{}3.0,{}4.0,{}5.0,{}6.0] ] \\spad{X} y:PRIMARR(DFLOAT)\\spad{:=}[ [0.0,{}0.0,{}0.0,{}0.0,{}0.0,{}0.0] ] \\spad{X} dcopy(6,{}\\spad{x},{}1,{}\\spad{y},{}1) \\spad{X} \\spad{y} \\spad{X} m:PRIMARR(DFLOAT)\\spad{:=}[ [1.0,{}2.0,{}3.0] ] \\spad{X} n:PRIMARR(DFLOAT)\\spad{:=}[ [0.0,{}0.0,{}0.0,{}0.0,{}0.0,{}0.0] ] \\spad{X} dcopy(3,{}\\spad{m},{}1,{}\\spad{n},{}2) \\spad{X} \\spad{n}")) (|daxpy| (((|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|) (|DoubleFloat|) (|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|) (|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|)) "\\indented{1}{daxpy(\\spad{n},{}da,{}\\spad{x},{}incx,{}\\spad{y},{}incy) computes a \\spad{y} = a*x + \\spad{y}} \\indented{1}{for each of the chosen elements of the vectors \\spad{x} and \\spad{y}} \\indented{1}{and a constant multiplier a} \\indented{1}{Note that the vector \\spad{y} is modified with the results.} \\blankline \\spad{X} x:PRIMARR(DFLOAT)\\spad{:=}[ [1.0,{}2.0,{}3.0,{}4.0,{}5.0,{}6.0] ] \\spad{X} y:PRIMARR(DFLOAT)\\spad{:=}[ [1.0,{}2.0,{}3.0,{}4.0,{}5.0,{}6.0] ] \\spad{X} daxpy(6,{}2.0,{}\\spad{x},{}1,{}\\spad{y},{}1) \\spad{X} \\spad{y} \\spad{X} m:PRIMARR(DFLOAT)\\spad{:=}[ [1.0,{}2.0,{}3.0] ] \\spad{X} n:PRIMARR(DFLOAT)\\spad{:=}[ [1.0,{}2.0,{}3.0,{}4.0,{}5.0,{}6.0] ] \\spad{X} daxpy(3,{}\\spad{-2}.0,{}\\spad{m},{}1,{}\\spad{n},{}2) \\spad{X} \\spad{n}")) (|dasum| (((|DoubleFloat|) (|SingleInteger|) (|PrimitiveArray| (|DoubleFloat|)) (|SingleInteger|)) "\\indented{1}{dasum(\\spad{n},{}array,{}incx) computes the sum of \\spad{n} elements in array} \\indented{1}{using a stride of incx} \\blankline \\spad{X} dx:PRIMARR(DFLOAT)\\spad{:=}[ [1.0,{}2.0,{}3.0,{}4.0,{}5.0,{}6.0] ] \\spad{X} dasum(6,{}\\spad{dx},{}1) \\spad{X} dasum(3,{}\\spad{dx},{}2)")) (|dcabs1| (((|DoubleFloat|) (|Complex| (|DoubleFloat|))) "\\indented{1}{\\spad{dcabs1}(\\spad{z}) computes (+ (abs (realpart \\spad{z})) (abs (imagpart \\spad{z})))} \\blankline \\spad{X} t1:Complex DoubleFloat \\spad{:=} complex(1.0,{}0) \\spad{X} dcabs(\\spad{t1})"))) 
@@ -410,7 +410,7 @@ NIL
 NIL 
 (-120 R S) 
 ((|constructor| (NIL "A \\spadtype{BiModule} is both a left and right module with respect to potentially different rings. \\blankline Axiom\\spad{\\br} \\tab{5}\\spad{ r*(x*s) = (r*x)*s }")) (|rightUnitary| ((|attribute|) "\\spad{x * 1 = x}")) (|leftUnitary| ((|attribute|) "\\spad{1 * x = x}"))) 
-((-4514 . T) (-4513 . T)) 
+((-4516 . T) (-4515 . T)) 
 NIL 
 (-121) 
 ((|constructor| (NIL "\\spadtype{Boolean} is the elementary logic with 2 values: \\spad{true} and \\spad{false}")) (|test| (((|Boolean|) $) "\\spad{test(b)} returns \\spad{b} and is provided for compatibility with the new compiler.")) (|implies| (($ $ $) "\\spad{implies(a,{}b)} returns the logical implication of Boolean \\spad{a} and \\spad{b}.")) (|nor| (($ $ $) "\\spad{nor(a,{}b)} returns the logical negation of \\spad{a} or \\spad{b}.")) (|nand| (($ $ $) "\\spad{nand(a,{}b)} returns the logical negation of \\spad{a} and \\spad{b}.")) (|xor| (($ $ $) "\\spad{xor(a,{}b)} returns the logical exclusive or of Boolean \\spad{a} and \\spad{b}.")) (|or| (($ $ $) "\\spad{a or b} returns the logical inclusive or of Boolean \\spad{a} and \\spad{b}.")) (|and| (($ $ $) "\\spad{a and b} returns the logical and of Boolean \\spad{a} and \\spad{b}.")) (|not| (($ $) "\\spad{not n} returns the negation of \\spad{n}.")) (^ (($ $) "\\spad{^ n} returns the negation of \\spad{n}.")) (|false| (($) "\\spad{false} is a logical constant.")) (|true| (($) "\\spad{true} is a logical constant."))) 
@@ -430,16 +430,16 @@ NIL
 NIL 
 (-125 |p|) 
 ((|constructor| (NIL "Stream-based implementation of \\spad{Zp:} \\spad{p}-adic numbers are represented as sum(\\spad{i} = 0..,{} a[\\spad{i}] * p^i),{} where the a[\\spad{i}] lie in -(\\spad{p} - 1)\\spad{/2},{}...,{}(\\spad{p} - 1)\\spad{/2}."))) 
-((-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-126 |p|) 
 ((|constructor| (NIL "Stream-based implementation of \\spad{Qp:} numbers are represented as sum(\\spad{i} = \\spad{k}..,{} a[\\spad{i}] * p^i),{} where the a[\\spad{i}] lie in -(\\spad{p} - 1)\\spad{/2},{}...,{}(\\spad{p} - 1)\\spad{/2}."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| (-125 |#1|) (QUOTE (-904))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| (-125 |#1|) (QUOTE (-148))) (|HasCategory| (-125 |#1|) (QUOTE (-150))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-125 |#1|) (QUOTE (-1021))) (|HasCategory| (-125 |#1|) (QUOTE (-815))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| (-125 |#1|) (QUOTE (-1136))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| (-125 |#1|) (QUOTE (-225))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -523) (QUOTE (-1161)) (LIST (QUOTE -125) (|devaluate| |#1|)))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -303) (LIST (QUOTE -125) (|devaluate| |#1|)))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -281) (LIST (QUOTE -125) (|devaluate| |#1|)) (LIST (QUOTE -125) (|devaluate| |#1|)))) (|HasCategory| (-125 |#1|) (QUOTE (-301))) (|HasCategory| (-125 |#1|) (QUOTE (-550))) (|HasCategory| (-125 |#1|) (QUOTE (-842))) (-2198 (|HasCategory| (-125 |#1|) (QUOTE (-815))) (|HasCategory| (-125 |#1|) (QUOTE (-842)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-125 |#1|) (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-125 |#1|) (QUOTE (-904)))) (|HasCategory| (-125 |#1|) (QUOTE (-148))))) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| (-125 |#1|) (QUOTE (-904))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| (-125 |#1|) (QUOTE (-148))) (|HasCategory| (-125 |#1|) (QUOTE (-150))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-125 |#1|) (QUOTE (-1021))) (|HasCategory| (-125 |#1|) (QUOTE (-815))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| (-125 |#1|) (QUOTE (-1136))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| (-125 |#1|) (QUOTE (-225))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -523) (QUOTE (-1161)) (LIST (QUOTE -125) (|devaluate| |#1|)))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -303) (LIST (QUOTE -125) (|devaluate| |#1|)))) (|HasCategory| (-125 |#1|) (LIST (QUOTE -281) (LIST (QUOTE -125) (|devaluate| |#1|)) (LIST (QUOTE -125) (|devaluate| |#1|)))) (|HasCategory| (-125 |#1|) (QUOTE (-301))) (|HasCategory| (-125 |#1|) (QUOTE (-550))) (|HasCategory| (-125 |#1|) (QUOTE (-842))) (-2199 (|HasCategory| (-125 |#1|) (QUOTE (-815))) (|HasCategory| (-125 |#1|) (QUOTE (-842)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-125 |#1|) (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-125 |#1|) (QUOTE (-904)))) (|HasCategory| (-125 |#1|) (QUOTE (-148))))) 
 (-127 A S) 
 ((|constructor| (NIL "A binary-recursive aggregate has 0,{} 1 or 2 children and serves as a model for a binary tree or a doubly-linked aggregate structure")) (|setright!| (($ $ $) "\\spad{setright!(a,{}x)} sets the right child of \\spad{t} to be \\spad{x}.")) (|setleft!| (($ $ $) "\\spad{setleft!(a,{}b)} sets the left child of \\axiom{a} to be \\spad{b}.")) (|setelt| (($ $ "right" $) "\\spad{setelt(a,{}\"right\",{}b)} (also written \\axiom{\\spad{b} . right \\spad{:=} \\spad{b}}) is equivalent to \\axiom{setright!(a,{}\\spad{b})}.") (($ $ "left" $) "\\spad{setelt(a,{}\"left\",{}b)} (also written \\axiom{a . left \\spad{:=} \\spad{b}}) is equivalent to \\axiom{setleft!(a,{}\\spad{b})}.")) (|right| (($ $) "\\spad{right(a)} returns the right child.")) (|elt| (($ $ "right") "\\spad{elt(a,{}\"right\")} (also written: \\axiom{a . right}) is equivalent to \\axiom{right(a)}.") (($ $ "left") "\\spad{elt(u,{}\"left\")} (also written: \\axiom{a . left}) is equivalent to \\axiom{left(a)}.")) (|left| (($ $) "\\spad{left(u)} returns the left child."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE -4520))) 
+((|HasAttribute| |#1| (QUOTE -4522))) 
 (-128 S) 
 ((|constructor| (NIL "A binary-recursive aggregate has 0,{} 1 or 2 children and serves as a model for a binary tree or a doubly-linked aggregate structure")) (|setright!| (($ $ $) "\\spad{setright!(a,{}x)} sets the right child of \\spad{t} to be \\spad{x}.")) (|setleft!| (($ $ $) "\\spad{setleft!(a,{}b)} sets the left child of \\axiom{a} to be \\spad{b}.")) (|setelt| (($ $ "right" $) "\\spad{setelt(a,{}\"right\",{}b)} (also written \\axiom{\\spad{b} . right \\spad{:=} \\spad{b}}) is equivalent to \\axiom{setright!(a,{}\\spad{b})}.") (($ $ "left" $) "\\spad{setelt(a,{}\"left\",{}b)} (also written \\axiom{a . left \\spad{:=} \\spad{b}}) is equivalent to \\axiom{setleft!(a,{}\\spad{b})}.")) (|right| (($ $) "\\spad{right(a)} returns the right child.")) (|elt| (($ $ "right") "\\spad{elt(a,{}\"right\")} (also written: \\axiom{a . right}) is equivalent to \\axiom{right(a)}.") (($ $ "left") "\\spad{elt(u,{}\"left\")} (also written: \\axiom{a . left}) is equivalent to \\axiom{left(a)}.")) (|left| (($ $) "\\spad{left(u)} returns the left child."))) 
 ((-3973 . T)) 
@@ -450,7 +450,7 @@ NIL
 NIL 
 (-130 S) 
 ((|constructor| (NIL "BinarySearchTree(\\spad{S}) is the domain of a binary trees where elements are ordered across the tree. A binary search tree is either empty or has a value which is an \\spad{S},{} and a right and left which are both BinaryTree(\\spad{S}) Elements are ordered across the tree.")) (|split| (((|Record| (|:| |less| $) (|:| |greater| $)) |#1| $) "\\indented{1}{split(\\spad{x},{}\\spad{b}) splits binary tree \\spad{b} into two trees,{} one with elements} \\indented{1}{greater than \\spad{x},{} the other with elements less than \\spad{x}.} \\blankline \\spad{X} t1:=binarySearchTree [1,{}2,{}3,{}4] \\spad{X} split(3,{}\\spad{t1})")) (|insertRoot!| (($ |#1| $) "\\indented{1}{insertRoot!(\\spad{x},{}\\spad{b}) inserts element \\spad{x} as a root of binary search tree \\spad{b}.} \\blankline \\spad{X} t1:=binarySearchTree [1,{}2,{}3,{}4] \\spad{X} insertRoot!(5,{}\\spad{t1})")) (|insert!| (($ |#1| $) "\\indented{1}{insert!(\\spad{x},{}\\spad{b}) inserts element \\spad{x} as leaves into binary search tree \\spad{b}.} \\blankline \\spad{X} t1:=binarySearchTree [1,{}2,{}3,{}4] \\spad{X} insert!(5,{}\\spad{t1})")) (|binarySearchTree| (($ (|List| |#1|)) "\\indented{1}{binarySearchTree(\\spad{l}) is not documented} \\blankline \\spad{X} binarySearchTree [1,{}2,{}3,{}4]"))) 
-((-4519 . T) (-4520 . T)) 
+((-4521 . T) (-4522 . T)) 
 ((|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090))))) 
 (-131 S) 
 ((|constructor| (NIL "The bit aggregate category models aggregates representing large quantities of Boolean data.")) (|xor| (($ $ $) "\\spad{xor(a,{}b)} returns the logical exclusive-or of bit aggregates \\axiom{a} and \\axiom{\\spad{b}}.")) (|or| (($ $ $) "\\spad{a or b} returns the logical or of bit aggregates \\axiom{a} and \\axiom{\\spad{b}}.")) (|and| (($ $ $) "\\spad{a and b} returns the logical and of bit aggregates \\axiom{a} and \\axiom{\\spad{b}}.")) (|nor| (($ $ $) "\\spad{nor(a,{}b)} returns the logical nor of bit aggregates \\axiom{a} and \\axiom{\\spad{b}}.")) (|nand| (($ $ $) "\\spad{nand(a,{}b)} returns the logical nand of bit aggregates \\axiom{a} and \\axiom{\\spad{b}}.")) (^ (($ $) "\\spad{^ b} returns the logical not of bit aggregate \\axiom{\\spad{b}}.")) (|not| (($ $) "\\spad{not(b)} returns the logical not of bit aggregate \\axiom{\\spad{b}}."))) 
@@ -458,7 +458,7 @@ NIL
 NIL 
 (-132) 
 ((|constructor| (NIL "The bit aggregate category models aggregates representing large quantities of Boolean data.")) (|xor| (($ $ $) "\\spad{xor(a,{}b)} returns the logical exclusive-or of bit aggregates \\axiom{a} and \\axiom{\\spad{b}}.")) (|or| (($ $ $) "\\spad{a or b} returns the logical or of bit aggregates \\axiom{a} and \\axiom{\\spad{b}}.")) (|and| (($ $ $) "\\spad{a and b} returns the logical and of bit aggregates \\axiom{a} and \\axiom{\\spad{b}}.")) (|nor| (($ $ $) "\\spad{nor(a,{}b)} returns the logical nor of bit aggregates \\axiom{a} and \\axiom{\\spad{b}}.")) (|nand| (($ $ $) "\\spad{nand(a,{}b)} returns the logical nand of bit aggregates \\axiom{a} and \\axiom{\\spad{b}}.")) (^ (($ $) "\\spad{^ b} returns the logical not of bit aggregate \\axiom{\\spad{b}}.")) (|not| (($ $) "\\spad{not(b)} returns the logical not of bit aggregate \\axiom{\\spad{b}}."))) 
-((-4520 . T) (-4519 . T) (-3973 . T)) 
+((-4522 . T) (-4521 . T) (-3973 . T)) 
 NIL 
 (-133 A S) 
 ((|constructor| (NIL "\\spadtype{BinaryTreeCategory(S)} is the category of binary trees: a tree which is either empty or else is a \\spadfun{node} consisting of a value and a \\spadfun{left} and \\spadfun{right},{} both binary trees.")) (|node| (($ $ |#2| $) "\\spad{node(left,{}v,{}right)} creates a binary tree with value \\spad{v},{} a binary tree \\spad{left},{} and a binary tree \\spad{right}. \\blankline")) (|finiteAggregate| ((|attribute|) "Binary trees have a finite number of components")) (|shallowlyMutable| ((|attribute|) "Binary trees have updateable components"))) 
@@ -466,15 +466,15 @@ NIL
 NIL 
 (-134 S) 
 ((|constructor| (NIL "\\spadtype{BinaryTreeCategory(S)} is the category of binary trees: a tree which is either empty or else is a \\spadfun{node} consisting of a value and a \\spadfun{left} and \\spadfun{right},{} both binary trees.")) (|node| (($ $ |#1| $) "\\spad{node(left,{}v,{}right)} creates a binary tree with value \\spad{v},{} a binary tree \\spad{left},{} and a binary tree \\spad{right}. \\blankline")) (|finiteAggregate| ((|attribute|) "Binary trees have a finite number of components")) (|shallowlyMutable| ((|attribute|) "Binary trees have updateable components"))) 
-((-4519 . T) (-4520 . T) (-3973 . T)) 
+((-4521 . T) (-4522 . T) (-3973 . T)) 
 NIL 
 (-135 S) 
 ((|constructor| (NIL "BinaryTournament creates a binary tournament with the elements of \\spad{ls} as values at the nodes.")) (|insert!| (($ |#1| $) "\\indented{1}{insert!(\\spad{x},{}\\spad{b}) inserts element \\spad{x} as leaves into binary tournament \\spad{b}.} \\blankline \\spad{X} t1:=binaryTournament [1,{}2,{}3,{}4] \\spad{X} insert!(5,{}\\spad{t1}) \\spad{X} \\spad{t1}")) (|binaryTournament| (($ (|List| |#1|)) "\\indented{1}{binaryTournament(\\spad{ls}) creates a binary tournament with the} \\indented{1}{elements of \\spad{ls} as values at the nodes.} \\blankline \\spad{X} binaryTournament [1,{}2,{}3,{}4]"))) 
-((-4519 . T) (-4520 . T)) 
+((-4521 . T) (-4522 . T)) 
 ((|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090))))) 
 (-136 S) 
 ((|constructor| (NIL "\\spadtype{BinaryTree(S)} is the domain of all binary trees. A binary tree over \\spad{S} is either empty or has a \\spadfun{value} which is an \\spad{S} and a \\spadfun{right} and \\spadfun{left} which are both binary trees.")) (|binaryTree| (($ $ |#1| $) "\\indented{1}{binaryTree(\\spad{l},{}\\spad{v},{}\\spad{r}) creates a binary tree with} \\indented{1}{value \\spad{v} with left subtree \\spad{l} and right subtree \\spad{r}.} \\blankline \\spad{X} t1:=binaryTree([1,{}2,{}3]) \\spad{X} t2:=binaryTree([4,{}5,{}6]) \\spad{X} binaryTree(\\spad{t1},{}[7,{}8,{}9],{}\\spad{t2})") (($ |#1|) "\\indented{1}{binaryTree(\\spad{v}) is an non-empty binary tree} \\indented{1}{with value \\spad{v},{} and left and right empty.} \\blankline \\spad{X} t1:=binaryTree([1,{}2,{}3])"))) 
-((-4519 . T) (-4520 . T)) 
+((-4521 . T) (-4522 . T)) 
 ((|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090))))) 
 (-137) 
 ((|constructor| (NIL "This is an \\spadtype{AbelianMonoid} with the cancellation property,{} \\spadignore{i.e.} \\tab{5}\\spad{ a+b = a+c => b=c }.\\spad{\\br} This is formalised by the partial subtraction operator,{} which satisfies the Axioms\\spad{\\br} \\tab{5}\\spad{c = a+b <=> c-b = a}")) (|subtractIfCan| (((|Union| $ "failed") $ $) "\\spad{subtractIfCan(x,{} y)} returns an element \\spad{z} such that \\spad{z+y=x} or \"failed\" if no such element exists."))) 
@@ -486,32 +486,32 @@ NIL
 NIL 
 (-139) 
 ((|constructor| (NIL "Members of the domain CardinalNumber are values indicating the cardinality of sets,{} both finite and infinite. Arithmetic operations are defined on cardinal numbers as follows. \\blankline If \\spad{x = \\#X} and \\spad{y = \\#Y} then\\spad{\\br} \\tab{5}\\spad{x+y = \\#(X+Y)} \\tab{5}disjoint union\\spad{\\br} \\tab{5}\\spad{x-y = \\#(X-Y)} \\tab{5}relative complement\\spad{\\br} \\tab{5}\\spad{x*y = \\#(X*Y)} \\tab{5}cartesian product\\spad{\\br} \\tab{5}\\spad{x**y = \\#(X**Y)} \\tab{4}\\spad{X**Y = g| g:Y->X} \\blankline The non-negative integers have a natural construction as cardinals\\spad{\\br} \\spad{0 = \\#\\{\\}},{} \\spad{1 = \\{0\\}},{} \\spad{2 = \\{0,{} 1\\}},{} ...,{} \\spad{n = \\{i| 0 <= i < n\\}}. \\blankline That \\spad{0} acts as a zero for the multiplication of cardinals is equivalent to the axiom of choice. \\blankline The generalized continuum hypothesis asserts \\spad{\\br} \\spad{2**Aleph i = Aleph(i+1)} and is independent of the axioms of set theory [Goedel 1940]. \\blankline Three commonly encountered cardinal numbers are\\spad{\\br} \\tab{5}\\spad{a = \\#Z} \\tab{5}countable infinity\\spad{\\br} \\tab{5}\\spad{c = \\#R} \\tab{5}the continuum\\spad{\\br} \\tab{5}\\spad{f = \\# g | g:[0,{}1]->R\\} \\blankline In this domain,{} these values are obtained using\\br \\tab{5}\\spad{a := Aleph 0},{} \\spad{c := 2**a},{} \\spad{f := 2**c}.")) (|generalizedContinuumHypothesisAssumed| (((|Boolean|) (|Boolean|)) "\\indented{1}{generalizedContinuumHypothesisAssumed(bool)} \\indented{1}{is used to dictate whether the hypothesis is to be assumed.} \\blankline \\spad{X} generalizedContinuumHypothesisAssumed \\spad{true} \\spad{X} a:=Aleph 0 \\spad{X} c:=2**a \\spad{X} f:=2**c")) (|generalizedContinuumHypothesisAssumed?| (((|Boolean|)) "\\indented{1}{generalizedContinuumHypothesisAssumed?()} \\indented{1}{tests if the hypothesis is currently assumed.} \\blankline \\spad{X} generalizedContinuumHypothesisAssumed?")) (|countable?| (((|Boolean|) $) "\\indented{1}{countable?(\\spad{a}) determines} \\indented{1}{whether \\spad{a} is a countable cardinal,{}} \\indented{1}{\\spadignore{i.e.} an integer or \\spad{Aleph 0}.} \\blankline \\spad{X} c2:=2::CardinalNumber \\spad{X} countable? \\spad{c2} \\spad{X} A0:=Aleph 0 \\spad{X} countable? \\spad{A0} \\spad{X} A1:=Aleph 1 \\spad{X} countable? \\spad{A1}")) (|finite?| (((|Boolean|) $) "\\indented{1}{finite?(\\spad{a}) determines whether} \\indented{1}{\\spad{a} is a finite cardinal,{} \\spadignore{i.e.} an integer.} \\blankline \\spad{X} c2:=2::CardinalNumber \\spad{X} finite? \\spad{c2} \\spad{X} A0:=Aleph 0 \\spad{X} finite? \\spad{A0}")) (|Aleph| (($ (|NonNegativeInteger|)) "\\indented{1}{Aleph(\\spad{n}) provides the named (infinite) cardinal number.} \\blankline \\spad{X} A0:=Aleph 0")) (** (($ $ $) "\\indented{1}{\\spad{x**y} returns \\spad{\\#(X**Y)} where \\spad{X**Y} is defined} \\indented{2}{as \\spad{\\{g| g:Y->X\\}}.} \\blankline \\spad{X} c2:=2::CardinalNumber \\spad{X} \\spad{c2**c2} \\spad{X} A1:=Aleph 1 \\spad{X} \\spad{A1**c2} \\spad{X} generalizedContinuumHypothesisAssumed \\spad{true} \\spad{X} \\spad{A1**A1}")) (- (((|Union| $ "failed") $ $) "\\indented{1}{\\spad{x - y} returns an element \\spad{z} such that} \\indented{1}{\\spad{z+y=x} or \"failed\" if no such element exists.} \\blankline \\spad{X} c2:=2::CardinalNumber \\spad{X} \\spad{c2}-\\spad{c2} \\spad{X} A1:=Aleph 1 \\spad{X} \\spad{A1}-\\spad{c2}")) (|commutative| ((|attribute| "*") "a domain \\spad{D} has \\spad{commutative(\"*\")} if it has an operation \\spad{\"*\": (D,{}D) -> D} which is commutative."))) 
-(((-4521 "*") . T)) 
+(((-4523 "*") . T)) 
 NIL 
-(-140 |minix| -2570 S T$) 
+(-140 |minix| -1965 S T$) 
 ((|constructor| (NIL "This package provides functions to enable conversion of tensors given conversion of the components.")) (|map| (((|CartesianTensor| |#1| |#2| |#4|) (|Mapping| |#4| |#3|) (|CartesianTensor| |#1| |#2| |#3|)) "\\spad{map(f,{}ts)} does a componentwise conversion of the tensor \\spad{ts} to a tensor with components of type \\spad{T}.")) (|reshape| (((|CartesianTensor| |#1| |#2| |#4|) (|List| |#4|) (|CartesianTensor| |#1| |#2| |#3|)) "\\spad{reshape(lt,{}ts)} organizes the list of components \\spad{lt} into a tensor with the same shape as \\spad{ts}."))) 
 NIL 
 NIL 
-(-141 |minix| -2570 R) 
+(-141 |minix| -1965 R) 
 ((|constructor| (NIL "CartesianTensor(minix,{}dim,{}\\spad{R}) provides Cartesian tensors with components belonging to a commutative ring \\spad{R}. These tensors can have any number of indices. Each index takes values from \\spad{minix} to \\spad{minix + dim - 1}.")) (|sample| (($) "\\spad{sample()} returns an object of type \\%.")) (|unravel| (($ (|List| |#3|)) "\\spad{unravel(t)} produces a tensor from a list of components such that \\indented{2}{\\spad{unravel(ravel(t)) = t}.}")) (|ravel| (((|List| |#3|) $) "\\indented{1}{ravel(\\spad{t}) produces a list of components from a tensor such that} \\indented{3}{\\spad{unravel(ravel(t)) = t}.} \\blankline \\spad{X} n:SquareMatrix(2,{}Integer):=matrix [[2,{}3],{}[0,{}1]] \\spad{X} tn:CartesianTensor(1,{}2,{}Integer)\\spad{:=n} \\spad{X} ravel \\spad{tn}")) (|leviCivitaSymbol| (($) "\\indented{1}{leviCivitaSymbol() is the rank \\spad{dim} tensor defined by} \\indented{1}{\\spad{leviCivitaSymbol()(i1,{}...idim) = +1/0/-1}} \\indented{1}{if \\spad{i1,{}...,{}idim} is an even/is nota /is an odd permutation} \\indented{1}{of \\spad{minix,{}...,{}minix+dim-1}.} \\blankline \\spad{X} lcs:CartesianTensor(1,{}2,{}Integer):=leviCivitaSymbol()")) (|kroneckerDelta| (($) "\\indented{1}{kroneckerDelta() is the rank 2 tensor defined by} \\indented{4}{\\spad{kroneckerDelta()(i,{}j)}} \\indented{7}{\\spad{= 1\\space{2}if i = j}} \\indented{7}{\\spad{= 0 if\\space{2}i \\^= j}} \\blankline \\spad{X} delta:CartesianTensor(1,{}2,{}Integer):=kroneckerDelta()")) (|reindex| (($ $ (|List| (|Integer|))) "\\indented{1}{reindex(\\spad{t},{}[\\spad{i1},{}...,{}idim]) permutes the indices of \\spad{t}.} \\indented{1}{For example,{} if \\spad{r = reindex(t,{} [4,{}1,{}2,{}3])}} \\indented{1}{for a rank 4 tensor \\spad{t},{}} \\indented{1}{then \\spad{r} is the rank for tensor given by} \\indented{5}{\\spad{r(i,{}j,{}k,{}l) = t(l,{}i,{}j,{}k)}.} \\blankline \\spad{X} n:SquareMatrix(2,{}Integer):=matrix [[2,{}3],{}[0,{}1]] \\spad{X} tn:CartesianTensor(1,{}2,{}Integer)\\spad{:=n} \\spad{X} p:=product(\\spad{tn},{}\\spad{tn}) \\spad{X} reindex(\\spad{p},{}[4,{}3,{}2,{}1])")) (|transpose| (($ $ (|Integer|) (|Integer|)) "\\indented{1}{transpose(\\spad{t},{}\\spad{i},{}\\spad{j}) exchanges the \\spad{i}\\spad{-}th and \\spad{j}\\spad{-}th} \\indented{1}{indices of \\spad{t}. For example,{} if \\spad{r = transpose(t,{}2,{}3)}} \\indented{1}{for a rank 4 tensor \\spad{t},{} then \\spad{r} is the rank 4 tensor} \\indented{1}{given by} \\indented{5}{\\spad{r(i,{}j,{}k,{}l) = t(i,{}k,{}j,{}l)}.} \\blankline \\spad{X} m:SquareMatrix(2,{}Integer):=matrix [[1,{}2],{}[4,{}5]] \\spad{X} tm:CartesianTensor(1,{}2,{}Integer)\\spad{:=m} \\spad{X} tn:CartesianTensor(1,{}2,{}Integer)\\spad{:=}[\\spad{tm},{}\\spad{tm}] \\spad{X} transpose(\\spad{tn},{}1,{}2)") (($ $) "\\indented{1}{transpose(\\spad{t}) exchanges the first and last indices of \\spad{t}.} \\indented{1}{For example,{} if \\spad{r = transpose(t)} for a rank 4} \\indented{1}{tensor \\spad{t},{} then \\spad{r} is the rank 4 tensor given by} \\indented{5}{\\spad{r(i,{}j,{}k,{}l) = t(l,{}j,{}k,{}i)}.} \\blankline \\spad{X} m:SquareMatrix(2,{}Integer):=matrix [[1,{}2],{}[4,{}5]] \\spad{X} Tm:CartesianTensor(1,{}2,{}Integer)\\spad{:=m} \\spad{X} transpose(\\spad{Tm})")) (|contract| (($ $ (|Integer|) (|Integer|)) "\\indented{1}{contract(\\spad{t},{}\\spad{i},{}\\spad{j}) is the contraction of tensor \\spad{t} which} \\indented{1}{sums along the \\spad{i}\\spad{-}th and \\spad{j}\\spad{-}th indices.} \\indented{1}{For example,{}\\space{2}if} \\indented{1}{\\spad{r = contract(t,{}1,{}3)} for a rank 4 tensor \\spad{t},{} then} \\indented{1}{\\spad{r} is the rank 2 \\spad{(= 4 - 2)} tensor given by} \\indented{5}{\\spad{r(i,{}j) = sum(h=1..dim,{}t(h,{}i,{}h,{}j))}.} \\blankline \\spad{X} m:SquareMatrix(2,{}Integer):=matrix [[1,{}2],{}[4,{}5]] \\spad{X} Tm:CartesianTensor(1,{}2,{}Integer)\\spad{:=m} \\spad{X} v:DirectProduct(2,{}Integer):=directProduct [3,{}4] \\spad{X} Tv:CartesianTensor(1,{}2,{}Integer)\\spad{:=v} \\spad{X} Tmv:=contract(\\spad{Tm},{}2,{}1)") (($ $ (|Integer|) $ (|Integer|)) "\\indented{1}{contract(\\spad{t},{}\\spad{i},{}\\spad{s},{}\\spad{j}) is the inner product of tenors \\spad{s} and \\spad{t}} \\indented{1}{which sums along the \\spad{k1}\\spad{-}th index of} \\indented{1}{\\spad{t} and the \\spad{k2}\\spad{-}th index of \\spad{s}.} \\indented{1}{For example,{} if \\spad{r = contract(s,{}2,{}t,{}1)} for rank 3 tensors} \\indented{1}{rank 3 tensors \\spad{s} and \\spad{t},{} then \\spad{r} is} \\indented{1}{the rank 4 \\spad{(= 3 + 3 - 2)} tensor\\space{2}given by} \\indented{5}{\\spad{r(i,{}j,{}k,{}l) = sum(h=1..dim,{}s(i,{}h,{}j)*t(h,{}k,{}l))}.} \\blankline \\spad{X} m:SquareMatrix(2,{}Integer):=matrix [[1,{}2],{}[4,{}5]] \\spad{X} Tm:CartesianTensor(1,{}2,{}Integer)\\spad{:=m} \\spad{X} v:DirectProduct(2,{}Integer):=directProduct [3,{}4] \\spad{X} Tv:CartesianTensor(1,{}2,{}Integer)\\spad{:=v} \\spad{X} Tmv:=contract(\\spad{Tm},{}2,{}\\spad{Tv},{}1)")) (* (($ $ $) "\\indented{1}{\\spad{s*t} is the inner product of the tensors \\spad{s} and \\spad{t} which contracts} \\indented{1}{the last index of \\spad{s} with the first index of \\spad{t},{} that is,{}} \\indented{5}{\\spad{t*s = contract(t,{}rank t,{} s,{} 1)}} \\indented{5}{\\spad{t*s = sum(k=1..N,{} t[i1,{}..,{}iN,{}k]*s[k,{}j1,{}..,{}jM])}} \\indented{1}{This is compatible with the use of \\spad{M*v} to denote} \\indented{1}{the matrix-vector inner product.} \\blankline \\spad{X} m:SquareMatrix(2,{}Integer):=matrix [[1,{}2],{}[4,{}5]] \\spad{X} Tm:CartesianTensor(1,{}2,{}Integer)\\spad{:=m} \\spad{X} v:DirectProduct(2,{}Integer):=directProduct [3,{}4] \\spad{X} Tv:CartesianTensor(1,{}2,{}Integer)\\spad{:=v} \\spad{X} Tm*Tv")) (|product| (($ $ $) "\\indented{1}{product(\\spad{s},{}\\spad{t}) is the outer product of the tensors \\spad{s} and \\spad{t}.} \\indented{1}{For example,{} if \\spad{r = product(s,{}t)} for rank 2 tensors} \\indented{1}{\\spad{s} and \\spad{t},{} then \\spad{r} is a rank 4 tensor given by} \\indented{5}{\\spad{r(i,{}j,{}k,{}l) = s(i,{}j)*t(k,{}l)}.} \\blankline \\spad{X} m:SquareMatrix(2,{}Integer):=matrix [[1,{}2],{}[4,{}5]] \\spad{X} Tm:CartesianTensor(1,{}2,{}Integer)\\spad{:=m} \\spad{X} n:SquareMatrix(2,{}Integer):=matrix [[2,{}3],{}[0,{}1]] \\spad{X} Tn:CartesianTensor(1,{}2,{}Integer)\\spad{:=n} \\spad{X} Tmn:=product(\\spad{Tm},{}\\spad{Tn})")) (|elt| ((|#3| $ (|List| (|Integer|))) "\\indented{1}{elt(\\spad{t},{}[\\spad{i1},{}...,{}iN]) gives a component of a rank \\spad{N} tensor.} \\blankline \\spad{X} \\spad{v:=}[2,{}3] \\spad{X} tv:CartesianTensor(1,{}2,{}Integer)\\spad{:=v} \\spad{X} tm:CartesianTensor(1,{}2,{}Integer)\\spad{:=}[\\spad{tv},{}\\spad{tv}] \\spad{X} tn:CartesianTensor(1,{}2,{}Integer)\\spad{:=}[\\spad{tm},{}\\spad{tm}] \\spad{X} tp:CartesianTensor(1,{}2,{}Integer)\\spad{:=}[\\spad{tn},{}\\spad{tn}] \\spad{X} tq:CartesianTensor(1,{}2,{}Integer)\\spad{:=}[\\spad{tp},{}\\spad{tp}] \\spad{X} elt(\\spad{tq},{}[2,{}2,{}2,{}2,{}2])") ((|#3| $ (|Integer|) (|Integer|) (|Integer|) (|Integer|)) "\\indented{1}{elt(\\spad{t},{}\\spad{i},{}\\spad{j},{}\\spad{k},{}\\spad{l}) gives a component of a rank 4 tensor.} \\blankline \\spad{X} \\spad{v:=}[2,{}3] \\spad{X} tv:CartesianTensor(1,{}2,{}Integer)\\spad{:=v} \\spad{X} tm:CartesianTensor(1,{}2,{}Integer)\\spad{:=}[\\spad{tv},{}\\spad{tv}] \\spad{X} tn:CartesianTensor(1,{}2,{}Integer)\\spad{:=}[\\spad{tm},{}\\spad{tm}] \\spad{X} tp:CartesianTensor(1,{}2,{}Integer)\\spad{:=}[\\spad{tn},{}\\spad{tn}] \\spad{X} elt(\\spad{tp},{}2,{}2,{}2,{}2) \\spad{X} \\spad{tp}[2,{}2,{}2,{}2]") ((|#3| $ (|Integer|) (|Integer|) (|Integer|)) "\\indented{1}{elt(\\spad{t},{}\\spad{i},{}\\spad{j},{}\\spad{k}) gives a component of a rank 3 tensor.} \\blankline \\spad{X} \\spad{v:=}[2,{}3] \\spad{X} tv:CartesianTensor(1,{}2,{}Integer)\\spad{:=v} \\spad{X} tm:CartesianTensor(1,{}2,{}Integer)\\spad{:=}[\\spad{tv},{}\\spad{tv}] \\spad{X} tn:CartesianTensor(1,{}2,{}Integer)\\spad{:=}[\\spad{tm},{}\\spad{tm}] \\spad{X} elt(\\spad{tn},{}2,{}2,{}2) \\spad{X} \\spad{tn}[2,{}2,{}2]") ((|#3| $ (|Integer|) (|Integer|)) "\\indented{1}{elt(\\spad{t},{}\\spad{i},{}\\spad{j}) gives a component of a rank 2 tensor.} \\blankline \\spad{X} \\spad{v:=}[2,{}3] \\spad{X} tv:CartesianTensor(1,{}2,{}Integer)\\spad{:=v} \\spad{X} tm:CartesianTensor(1,{}2,{}Integer)\\spad{:=}[\\spad{tv},{}\\spad{tv}] \\spad{X} elt(\\spad{tm},{}2,{}2) \\spad{X} \\spad{tm}[2,{}2]") ((|#3| $ (|Integer|)) "\\indented{1}{elt(\\spad{t},{}\\spad{i}) gives a component of a rank 1 tensor.} \\blankline \\spad{X} \\spad{v:=}[2,{}3] \\spad{X} tv:CartesianTensor(1,{}2,{}Integer)\\spad{:=v} \\spad{X} elt(\\spad{tv},{}2) \\spad{X} \\spad{tv}[2]") ((|#3| $) "\\indented{1}{elt(\\spad{t}) gives the component of a rank 0 tensor.} \\blankline \\spad{X} tv:CartesianTensor(1,{}2,{}Integer)\\spad{:=8} \\spad{X} elt(\\spad{tv}) \\spad{X} \\spad{tv}[]")) (|rank| (((|NonNegativeInteger|) $) "\\indented{1}{rank(\\spad{t}) returns the tensorial rank of \\spad{t} (that is,{} the} \\indented{1}{number of indices).\\space{2}This is the same as the graded module} \\indented{1}{degree.} \\blankline \\spad{X} CT:=CARTEN(1,{}2,{}Integer) \\spad{X} \\spad{t0:CT:=8} \\spad{X} rank \\spad{t0}")) (|coerce| (($ (|List| $)) "\\indented{1}{coerce([\\spad{t_1},{}...,{}t_dim]) allows tensors to be constructed} \\indented{1}{using lists.} \\blankline \\spad{X} \\spad{v:=}[2,{}3] \\spad{X} tv:CartesianTensor(1,{}2,{}Integer)\\spad{:=v} \\spad{X} tm:CartesianTensor(1,{}2,{}Integer)\\spad{:=}[\\spad{tv},{}\\spad{tv}]") (($ (|List| |#3|)) "\\indented{1}{coerce([\\spad{r_1},{}...,{}r_dim]) allows tensors to be constructed} \\indented{1}{using lists.} \\blankline \\spad{X} \\spad{v:=}[2,{}3] \\spad{X} tv:CartesianTensor(1,{}2,{}Integer)\\spad{:=v}") (($ (|SquareMatrix| |#2| |#3|)) "\\indented{1}{coerce(\\spad{m}) views a matrix as a rank 2 tensor.} \\blankline \\spad{X} v:SquareMatrix(2,{}Integer)\\spad{:=}[[1,{}2],{}[3,{}4]] \\spad{X} tv:CartesianTensor(1,{}2,{}Integer)\\spad{:=v}") (($ (|DirectProduct| |#2| |#3|)) "\\indented{1}{coerce(\\spad{v}) views a vector as a rank 1 tensor.} \\blankline \\spad{X} v:DirectProduct(2,{}Integer):=directProduct [3,{}4] \\spad{X} tv:CartesianTensor(1,{}2,{}Integer)\\spad{:=v}"))) 
 NIL 
 NIL 
 (-142) 
 ((|constructor| (NIL "This domain allows classes of characters to be defined and manipulated efficiently.")) (|alphanumeric| (($) "\\spad{alphanumeric()} returns the class of all characters for which alphanumeric? is \\spad{true}.")) (|alphabetic| (($) "\\spad{alphabetic()} returns the class of all characters for which alphabetic? is \\spad{true}.")) (|lowerCase| (($) "\\spad{lowerCase()} returns the class of all characters for which lowerCase? is \\spad{true}.")) (|upperCase| (($) "\\spad{upperCase()} returns the class of all characters for which upperCase? is \\spad{true}.")) (|hexDigit| (($) "\\spad{hexDigit()} returns the class of all characters for which hexDigit? is \\spad{true}.")) (|digit| (($) "\\spad{digit()} returns the class of all characters for which digit? is \\spad{true}.")) (|charClass| (($ (|List| (|Character|))) "\\spad{charClass(l)} creates a character class which contains exactly the characters given in the list \\spad{l}.") (($ (|String|)) "\\spad{charClass(s)} creates a character class which contains exactly the characters given in the string \\spad{s}."))) 
-((-4519 . T) (-4509 . T) (-4520 . T)) 
-((|HasCategory| (-147) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-147) (QUOTE (-370))) (|HasCategory| (-147) (QUOTE (-842))) (|HasCategory| (-147) (QUOTE (-1090))) (-12 (|HasCategory| (-147) (LIST (QUOTE -303) (QUOTE (-147)))) (|HasCategory| (-147) (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| (-147) (LIST (QUOTE -303) (QUOTE (-147)))) (|HasCategory| (-147) (QUOTE (-370)))) (-12 (|HasCategory| (-147) (LIST (QUOTE -303) (QUOTE (-147)))) (|HasCategory| (-147) (QUOTE (-1090)))))) 
+((-4521 . T) (-4511 . T) (-4522 . T)) 
+((|HasCategory| (-147) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-147) (QUOTE (-370))) (|HasCategory| (-147) (QUOTE (-842))) (|HasCategory| (-147) (QUOTE (-1090))) (-12 (|HasCategory| (-147) (LIST (QUOTE -303) (QUOTE (-147)))) (|HasCategory| (-147) (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| (-147) (LIST (QUOTE -303) (QUOTE (-147)))) (|HasCategory| (-147) (QUOTE (-370)))) (-12 (|HasCategory| (-147) (LIST (QUOTE -303) (QUOTE (-147)))) (|HasCategory| (-147) (QUOTE (-1090)))))) 
 (-143 R Q A) 
 ((|constructor| (NIL "CommonDenominator provides functions to compute the common denominator of a finite linear aggregate of elements of the quotient field of an integral domain.")) (|splitDenominator| (((|Record| (|:| |num| |#3|) (|:| |den| |#1|)) |#3|) "\\spad{splitDenominator([q1,{}...,{}qn])} returns \\spad{[[p1,{}...,{}pn],{} d]} such that \\spad{\\spad{qi} = pi/d} and \\spad{d} is a common denominator for the \\spad{qi}\\spad{'s}.")) (|clearDenominator| ((|#3| |#3|) "\\spad{clearDenominator([q1,{}...,{}qn])} returns \\spad{[p1,{}...,{}pn]} such that \\spad{\\spad{qi} = pi/d} where \\spad{d} is a common denominator for the \\spad{qi}\\spad{'s}.")) (|commonDenominator| ((|#1| |#3|) "\\spad{commonDenominator([q1,{}...,{}qn])} returns a common denominator \\spad{d} for \\spad{q1},{}...,{}\\spad{qn}."))) 
 NIL 
 NIL 
 (-144) 
 ((|constructor| (NIL "This is a low-level domain which implements matrices (two dimensional arrays) of complex double precision floating point numbers. Indexing is 0 based,{} there is no bound checking (unless provided by lower level).")) (|qnew| (($ (|Integer|) (|Integer|)) "\\indented{1}{qnew(\\spad{n},{} \\spad{m}) creates a new uninitialized \\spad{n} by \\spad{m} matrix.} \\blankline \\spad{X} t1:CDFMAT:=qnew(3,{}4)"))) 
-((-4519 . T) (-4520 . T)) 
-((|HasCategory| (-169 (-215)) (QUOTE (-1090))) (-12 (|HasCategory| (-169 (-215)) (LIST (QUOTE -303) (LIST (QUOTE -169) (QUOTE (-215))))) (|HasCategory| (-169 (-215)) (QUOTE (-1090)))) (|HasCategory| (-169 (-215)) (QUOTE (-301))) (|HasCategory| (-169 (-215)) (QUOTE (-558))) (|HasAttribute| (-169 (-215)) (QUOTE (-4521 "*"))) (|HasCategory| (-169 (-215)) (QUOTE (-172))) (|HasCategory| (-169 (-215)) (QUOTE (-365)))) 
+((-4521 . T) (-4522 . T)) 
+((|HasCategory| (-169 (-215)) (QUOTE (-1090))) (-12 (|HasCategory| (-169 (-215)) (LIST (QUOTE -303) (LIST (QUOTE -169) (QUOTE (-215))))) (|HasCategory| (-169 (-215)) (QUOTE (-1090)))) (|HasCategory| (-169 (-215)) (QUOTE (-301))) (|HasCategory| (-169 (-215)) (QUOTE (-558))) (|HasAttribute| (-169 (-215)) (QUOTE (-4523 "*"))) (|HasCategory| (-169 (-215)) (QUOTE (-172))) (|HasCategory| (-169 (-215)) (QUOTE (-365)))) 
 (-145) 
 ((|constructor| (NIL "This is a low-level domain which implements vectors (one dimensional arrays) of complex double precision floating point numbers. Indexing is 0 based,{} there is no bound checking (unless provided by lower level).")) (|vector| (($ (|List| (|Complex| (|DoubleFloat|)))) "\\indented{1}{vector(\\spad{l}) converts the list \\spad{l} to a vector.} \\blankline \\spad{X} t1:List(Complex(DoubleFloat))\\spad{:=}[1+2*\\%\\spad{i},{}3+4*\\%\\spad{i},{}\\spad{-5}-6*\\%\\spad{i}] \\spad{X} t2:CDFVEC:=vector(\\spad{t1})")) (|qnew| (($ (|Integer|)) "\\indented{1}{qnew(\\spad{n}) creates a new uninitialized vector of length \\spad{n}.} \\blankline \\spad{X} t1:CDFVEC:=qnew 7"))) 
-((-4520 . T) (-4519 . T)) 
-((|HasCategory| (-169 (-215)) (QUOTE (-1090))) (|HasCategory| (-169 (-215)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-169 (-215)) (QUOTE (-842))) (-2198 (|HasCategory| (-169 (-215)) (QUOTE (-842))) (|HasCategory| (-169 (-215)) (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (|HasCategory| (-169 (-215)) (QUOTE (-25))) (|HasCategory| (-169 (-215)) (QUOTE (-23))) (|HasCategory| (-169 (-215)) (QUOTE (-21))) (|HasCategory| (-169 (-215)) (QUOTE (-716))) (|HasCategory| (-169 (-215)) (QUOTE (-1047))) (-12 (|HasCategory| (-169 (-215)) (QUOTE (-1002))) (|HasCategory| (-169 (-215)) (QUOTE (-1047)))) (-12 (|HasCategory| (-169 (-215)) (LIST (QUOTE -303) (LIST (QUOTE -169) (QUOTE (-215))))) (|HasCategory| (-169 (-215)) (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| (-169 (-215)) (LIST (QUOTE -303) (LIST (QUOTE -169) (QUOTE (-215))))) (|HasCategory| (-169 (-215)) (QUOTE (-842)))) (-12 (|HasCategory| (-169 (-215)) (LIST (QUOTE -303) (LIST (QUOTE -169) (QUOTE (-215))))) (|HasCategory| (-169 (-215)) (QUOTE (-1090)))))) 
+((-4522 . T) (-4521 . T)) 
+((|HasCategory| (-169 (-215)) (QUOTE (-1090))) (|HasCategory| (-169 (-215)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-169 (-215)) (QUOTE (-842))) (-2199 (|HasCategory| (-169 (-215)) (QUOTE (-842))) (|HasCategory| (-169 (-215)) (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (|HasCategory| (-169 (-215)) (QUOTE (-25))) (|HasCategory| (-169 (-215)) (QUOTE (-23))) (|HasCategory| (-169 (-215)) (QUOTE (-21))) (|HasCategory| (-169 (-215)) (QUOTE (-716))) (|HasCategory| (-169 (-215)) (QUOTE (-1047))) (-12 (|HasCategory| (-169 (-215)) (QUOTE (-1002))) (|HasCategory| (-169 (-215)) (QUOTE (-1047)))) (-12 (|HasCategory| (-169 (-215)) (LIST (QUOTE -303) (LIST (QUOTE -169) (QUOTE (-215))))) (|HasCategory| (-169 (-215)) (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| (-169 (-215)) (LIST (QUOTE -303) (LIST (QUOTE -169) (QUOTE (-215))))) (|HasCategory| (-169 (-215)) (QUOTE (-842)))) (-12 (|HasCategory| (-169 (-215)) (LIST (QUOTE -303) (LIST (QUOTE -169) (QUOTE (-215))))) (|HasCategory| (-169 (-215)) (QUOTE (-1090)))))) 
 (-146) 
 ((|constructor| (NIL "Category for the usual combinatorial functions.")) (|permutation| (($ $ $) "\\spad{permutation(n,{} m)} returns the number of permutations of \\spad{n} objects taken \\spad{m} at a time. Note that \\spad{permutation(n,{}m) = n!/(n-m)!}.")) (|factorial| (($ $) "\\spad{factorial(n)} computes the factorial of \\spad{n} (denoted in the literature by \\spad{n!}) Note that \\spad{n! = n (n-1)! when n > 0}; also,{} \\spad{0! = 1}.")) (|binomial| (($ $ $) "\\indented{1}{binomial(\\spad{n},{}\\spad{r}) returns the \\spad{(n,{}r)} binomial coefficient} \\indented{1}{(often denoted in the literature by \\spad{C(n,{}r)}).} \\indented{1}{Note that \\spad{C(n,{}r) = n!/(r!(n-r)!)} where \\spad{n >= r >= 0}.} \\blankline \\spad{X} [binomial(5,{}\\spad{i}) for \\spad{i} in 0..5]"))) 
 NIL 
@@ -522,7 +522,7 @@ NIL
 NIL 
 (-148) 
 ((|constructor| (NIL "Rings of Characteristic Non Zero")) (|charthRoot| (((|Union| $ "failed") $) "\\spad{charthRoot(x)} returns the \\spad{p}th root of \\spad{x} where \\spad{p} is the characteristic of the ring."))) 
-((-4516 . T)) 
+((-4518 . T)) 
 NIL 
 (-149 R) 
 ((|constructor| (NIL "This package provides a characteristicPolynomial function for any matrix over a commutative ring.")) (|characteristicPolynomial| ((|#1| (|Matrix| |#1|) |#1|) "\\spad{characteristicPolynomial(m,{}r)} computes the characteristic polynomial of the matrix \\spad{m} evaluated at the point \\spad{r}. In particular,{} if \\spad{r} is the polynomial \\spad{'x},{} then it returns the characteristic polynomial expressed as a polynomial in \\spad{'x}."))) 
@@ -530,7 +530,7 @@ NIL
 NIL 
 (-150) 
 ((|constructor| (NIL "Rings of Characteristic Zero."))) 
-((-4516 . T)) 
+((-4518 . T)) 
 NIL 
 (-151 -1478 UP UPUP) 
 ((|constructor| (NIL "Tools to send a point to infinity on an algebraic curve.")) (|chvar| (((|Record| (|:| |func| |#3|) (|:| |poly| |#3|) (|:| |c1| (|Fraction| |#2|)) (|:| |c2| (|Fraction| |#2|)) (|:| |deg| (|NonNegativeInteger|))) |#3| |#3|) "\\spad{chvar(f(x,{}y),{} p(x,{}y))} returns \\spad{[g(z,{}t),{} q(z,{}t),{} c1(z),{} c2(z),{} n]} such that under the change of variable \\spad{x = c1(z)},{} \\spad{y = t * c2(z)},{} one gets \\spad{f(x,{}y) = g(z,{}t)}. The algebraic relation between \\spad{x} and \\spad{y} is \\spad{p(x,{} y) = 0}. The algebraic relation between \\spad{z} and \\spad{t} is \\spad{q(z,{} t) = 0}.")) (|eval| ((|#3| |#3| (|Fraction| |#2|) (|Fraction| |#2|)) "\\spad{eval(p(x,{}y),{} f(x),{} g(x))} returns \\spad{p(f(x),{} y * g(x))}.")) (|goodPoint| ((|#1| |#3| |#3|) "\\spad{goodPoint(p,{} q)} returns an integer a such that a is neither a pole of \\spad{p(x,{}y)} nor a branch point of \\spad{q(x,{}y) = 0}.")) (|rootPoly| (((|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| (|Fraction| |#2|)) (|:| |radicand| |#2|)) (|Fraction| |#2|) (|NonNegativeInteger|)) "\\spad{rootPoly(g,{} n)} returns \\spad{[m,{} c,{} P]} such that \\spad{c * g ** (1/n) = P ** (1/m)} thus if \\spad{y**n = g},{} then \\spad{z**m = P} where \\spad{z = c * y}.")) (|radPoly| (((|Union| (|Record| (|:| |radicand| (|Fraction| |#2|)) (|:| |deg| (|NonNegativeInteger|))) "failed") |#3|) "\\spad{radPoly(p(x,{} y))} returns \\spad{[c(x),{} n]} if \\spad{p} is of the form \\spad{y**n - c(x)},{} \"failed\" otherwise.")) (|mkIntegral| (((|Record| (|:| |coef| (|Fraction| |#2|)) (|:| |poly| |#3|)) |#3|) "\\spad{mkIntegral(p(x,{}y))} returns \\spad{[c(x),{} q(x,{}z)]} such that \\spad{z = c * y} is integral. The algebraic relation between \\spad{x} and \\spad{y} is \\spad{p(x,{} y) = 0}. The algebraic relation between \\spad{x} and \\spad{z} is \\spad{q(x,{} z) = 0}."))) 
@@ -543,14 +543,14 @@ NIL
 (-153 A S) 
 ((|constructor| (NIL "A collection is a homogeneous aggregate which can built from list of members. The operation used to build the aggregate is generically named \\spadfun{construct}. However,{} each collection provides its own special function with the same name as the data type,{} except with an initial lower case letter,{} \\spadignore{e.g.} \\spadfun{list} for \\spadtype{List},{} \\spadfun{flexibleArray} for \\spadtype{FlexibleArray},{} and so on.")) (|removeDuplicates| (($ $) "\\spad{removeDuplicates(u)} returns a copy of \\spad{u} with all duplicates removed.")) (|select| (($ (|Mapping| (|Boolean|) |#2|) $) "\\spad{select(p,{}u)} returns a copy of \\spad{u} containing only those elements such \\axiom{\\spad{p}(\\spad{x})} is \\spad{true}. Note that \\axiom{select(\\spad{p},{}\\spad{u}) \\spad{==} [\\spad{x} for \\spad{x} in \\spad{u} | \\spad{p}(\\spad{x})]}.")) (|remove| (($ |#2| $) "\\spad{remove(x,{}u)} returns a copy of \\spad{u} with all elements \\axiom{\\spad{y} = \\spad{x}} removed. Note that \\axiom{remove(\\spad{y},{}\\spad{c}) \\spad{==} [\\spad{x} for \\spad{x} in \\spad{c} | \\spad{x} \\spad{^=} \\spad{y}]}.") (($ (|Mapping| (|Boolean|) |#2|) $) "\\spad{remove(p,{}u)} returns a copy of \\spad{u} removing all elements \\spad{x} such that \\axiom{\\spad{p}(\\spad{x})} is \\spad{true}. Note that \\axiom{remove(\\spad{p},{}\\spad{u}) \\spad{==} [\\spad{x} for \\spad{x} in \\spad{u} | not \\spad{p}(\\spad{x})]}.")) (|reduce| ((|#2| (|Mapping| |#2| |#2| |#2|) $ |#2| |#2|) "\\spad{reduce(f,{}u,{}x,{}z)} reduces the binary operation \\spad{f} across \\spad{u},{} stopping when an \"absorbing element\" \\spad{z} is encountered. As for \\axiom{reduce(\\spad{f},{}\\spad{u},{}\\spad{x})},{} \\spad{x} is the identity operation of \\spad{f}. Same as \\axiom{reduce(\\spad{f},{}\\spad{u},{}\\spad{x})} when \\spad{u} contains no element \\spad{z}. Thus the third argument \\spad{x} is returned when \\spad{u} is empty.") ((|#2| (|Mapping| |#2| |#2| |#2|) $ |#2|) "\\spad{reduce(f,{}u,{}x)} reduces the binary operation \\spad{f} across \\spad{u},{} where \\spad{x} is the identity operation of \\spad{f}. Same as \\axiom{reduce(\\spad{f},{}\\spad{u})} if \\spad{u} has 2 or more elements. Returns \\axiom{\\spad{f}(\\spad{x},{}\\spad{y})} if \\spad{u} has one element \\spad{y},{} \\spad{x} if \\spad{u} is empty. For example,{} \\axiom{reduce(+,{}\\spad{u},{}0)} returns the sum of the elements of \\spad{u}.") ((|#2| (|Mapping| |#2| |#2| |#2|) $) "\\indented{1}{reduce(\\spad{f},{}\\spad{u}) reduces the binary operation \\spad{f} across \\spad{u}. For example,{}} \\indented{1}{if \\spad{u} is \\axiom{[\\spad{x},{}\\spad{y},{}...,{}\\spad{z}]} then \\axiom{reduce(\\spad{f},{}\\spad{u})}} \\indented{1}{returns \\axiom{\\spad{f}(..\\spad{f}(\\spad{f}(\\spad{x},{}\\spad{y}),{}...),{}\\spad{z})}.} \\indented{1}{Note that if \\spad{u} has one element \\spad{x},{} \\axiom{reduce(\\spad{f},{}\\spad{u})} returns \\spad{x}.} \\indented{1}{Error: if \\spad{u} is empty.} \\blankline \\spad{C} )clear all \\spad{X} reduce(+,{}[\\spad{C}[\\spad{i}]*x**i for \\spad{i} in 1..5])")) (|find| (((|Union| |#2| "failed") (|Mapping| (|Boolean|) |#2|) $) "\\spad{find(p,{}u)} returns the first \\spad{x} in \\spad{u} such that \\axiom{\\spad{p}(\\spad{x})} is \\spad{true},{} and \"failed\" otherwise.")) (|construct| (($ (|List| |#2|)) "\\axiom{construct(\\spad{x},{}\\spad{y},{}...,{}\\spad{z})} returns the collection of elements \\axiom{\\spad{x},{}\\spad{y},{}...,{}\\spad{z}} ordered as given. Equivalently written as \\axiom{[\\spad{x},{}\\spad{y},{}...,{}\\spad{z}]\\$\\spad{D}},{} where \\spad{D} is the domain. \\spad{D} may be omitted for those of type List."))) 
 NIL 
-((|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (QUOTE (-1090))) (|HasAttribute| |#1| (QUOTE -4519))) 
+((|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (QUOTE (-1090))) (|HasAttribute| |#1| (QUOTE -4521))) 
 (-154 S) 
 ((|constructor| (NIL "A collection is a homogeneous aggregate which can built from list of members. The operation used to build the aggregate is generically named \\spadfun{construct}. However,{} each collection provides its own special function with the same name as the data type,{} except with an initial lower case letter,{} \\spadignore{e.g.} \\spadfun{list} for \\spadtype{List},{} \\spadfun{flexibleArray} for \\spadtype{FlexibleArray},{} and so on.")) (|removeDuplicates| (($ $) "\\spad{removeDuplicates(u)} returns a copy of \\spad{u} with all duplicates removed.")) (|select| (($ (|Mapping| (|Boolean|) |#1|) $) "\\spad{select(p,{}u)} returns a copy of \\spad{u} containing only those elements such \\axiom{\\spad{p}(\\spad{x})} is \\spad{true}. Note that \\axiom{select(\\spad{p},{}\\spad{u}) \\spad{==} [\\spad{x} for \\spad{x} in \\spad{u} | \\spad{p}(\\spad{x})]}.")) (|remove| (($ |#1| $) "\\spad{remove(x,{}u)} returns a copy of \\spad{u} with all elements \\axiom{\\spad{y} = \\spad{x}} removed. Note that \\axiom{remove(\\spad{y},{}\\spad{c}) \\spad{==} [\\spad{x} for \\spad{x} in \\spad{c} | \\spad{x} \\spad{^=} \\spad{y}]}.") (($ (|Mapping| (|Boolean|) |#1|) $) "\\spad{remove(p,{}u)} returns a copy of \\spad{u} removing all elements \\spad{x} such that \\axiom{\\spad{p}(\\spad{x})} is \\spad{true}. Note that \\axiom{remove(\\spad{p},{}\\spad{u}) \\spad{==} [\\spad{x} for \\spad{x} in \\spad{u} | not \\spad{p}(\\spad{x})]}.")) (|reduce| ((|#1| (|Mapping| |#1| |#1| |#1|) $ |#1| |#1|) "\\spad{reduce(f,{}u,{}x,{}z)} reduces the binary operation \\spad{f} across \\spad{u},{} stopping when an \"absorbing element\" \\spad{z} is encountered. As for \\axiom{reduce(\\spad{f},{}\\spad{u},{}\\spad{x})},{} \\spad{x} is the identity operation of \\spad{f}. Same as \\axiom{reduce(\\spad{f},{}\\spad{u},{}\\spad{x})} when \\spad{u} contains no element \\spad{z}. Thus the third argument \\spad{x} is returned when \\spad{u} is empty.") ((|#1| (|Mapping| |#1| |#1| |#1|) $ |#1|) "\\spad{reduce(f,{}u,{}x)} reduces the binary operation \\spad{f} across \\spad{u},{} where \\spad{x} is the identity operation of \\spad{f}. Same as \\axiom{reduce(\\spad{f},{}\\spad{u})} if \\spad{u} has 2 or more elements. Returns \\axiom{\\spad{f}(\\spad{x},{}\\spad{y})} if \\spad{u} has one element \\spad{y},{} \\spad{x} if \\spad{u} is empty. For example,{} \\axiom{reduce(+,{}\\spad{u},{}0)} returns the sum of the elements of \\spad{u}.") ((|#1| (|Mapping| |#1| |#1| |#1|) $) "\\indented{1}{reduce(\\spad{f},{}\\spad{u}) reduces the binary operation \\spad{f} across \\spad{u}. For example,{}} \\indented{1}{if \\spad{u} is \\axiom{[\\spad{x},{}\\spad{y},{}...,{}\\spad{z}]} then \\axiom{reduce(\\spad{f},{}\\spad{u})}} \\indented{1}{returns \\axiom{\\spad{f}(..\\spad{f}(\\spad{f}(\\spad{x},{}\\spad{y}),{}...),{}\\spad{z})}.} \\indented{1}{Note that if \\spad{u} has one element \\spad{x},{} \\axiom{reduce(\\spad{f},{}\\spad{u})} returns \\spad{x}.} \\indented{1}{Error: if \\spad{u} is empty.} \\blankline \\spad{C} )clear all \\spad{X} reduce(+,{}[\\spad{C}[\\spad{i}]*x**i for \\spad{i} in 1..5])")) (|find| (((|Union| |#1| "failed") (|Mapping| (|Boolean|) |#1|) $) "\\spad{find(p,{}u)} returns the first \\spad{x} in \\spad{u} such that \\axiom{\\spad{p}(\\spad{x})} is \\spad{true},{} and \"failed\" otherwise.")) (|construct| (($ (|List| |#1|)) "\\axiom{construct(\\spad{x},{}\\spad{y},{}...,{}\\spad{z})} returns the collection of elements \\axiom{\\spad{x},{}\\spad{y},{}...,{}\\spad{z}} ordered as given. Equivalently written as \\axiom{[\\spad{x},{}\\spad{y},{}...,{}\\spad{z}]\\$\\spad{D}},{} where \\spad{D} is the domain. \\spad{D} may be omitted for those of type List."))) 
 ((-3973 . T)) 
 NIL 
 (-155 |n| K Q) 
 ((|constructor| (NIL "CliffordAlgebra(\\spad{n},{} \\spad{K},{} \\spad{Q}) defines a vector space of dimension \\spad{2**n} over \\spad{K},{} given a quadratic form \\spad{Q} on \\spad{K**n}. \\blankline If \\spad{e[i]},{} \\spad{1<=i<=n} is a basis for \\spad{K**n} then 1,{} \\spad{e[i]} (\\spad{1<=i<=n}),{} \\spad{e[i1]*e[i2]} (\\spad{1<=i1<i2<=n}),{}...,{}\\spad{e[1]*e[2]*..*e[n]} is a basis for the Clifford Algebra. \\blankline The algebra is defined by the relations\\spad{\\br} \\tab{5}\\spad{e[i]*e[j] = -e[j]*e[i]} (\\spad{i \\~~= j}),{}\\spad{\\br} \\tab{5}\\spad{e[i]*e[i] = Q(e[i])} \\blankline Examples of Clifford Algebras are: gaussians,{} quaternions,{} exterior algebras and spin algebras.")) (|recip| (((|Union| $ "failed") $) "\\spad{recip(x)} computes the multiplicative inverse of \\spad{x} or \"failed\" if \\spad{x} is not invertible.")) (|coefficient| ((|#2| $ (|List| (|PositiveInteger|))) "\\spad{coefficient(x,{}[i1,{}i2,{}...,{}iN])} extracts the coefficient of \\spad{e(i1)*e(i2)*...*e(iN)} in \\spad{x}.")) (|monomial| (($ |#2| (|List| (|PositiveInteger|))) "\\spad{monomial(c,{}[i1,{}i2,{}...,{}iN])} produces the value given by \\spad{c*e(i1)*e(i2)*...*e(iN)}.")) (|e| (($ (|PositiveInteger|)) "\\spad{e(n)} produces the appropriate unit element."))) 
-((-4514 . T) (-4513 . T) (-4516 . T)) 
+((-4516 . T) (-4515 . T) (-4518 . T)) 
 NIL 
 (-156) 
 ((|constructor| (NIL "Automatic clipping for 2-dimensional plots The purpose of this package is to provide reasonable plots of functions with singularities.")) (|clipWithRanges| (((|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|)))) (|List| (|List| (|Point| (|DoubleFloat|)))) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) "\\spad{clipWithRanges(pointLists,{}xMin,{}xMax,{}yMin,{}yMax)} performs clipping on a list of lists of points,{} \\spad{pointLists}. Clipping is done within the specified ranges of \\spad{xMin},{} \\spad{xMax} and \\spad{yMin},{} \\spad{yMax}. This function is used internally by the \\fakeAxiomFun{iClipParametric} subroutine in this package.")) (|clipParametric| (((|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|)))) (|Plot|) (|Fraction| (|Integer|)) (|Fraction| (|Integer|))) "\\spad{clipParametric(p,{}frac,{}sc)} performs two-dimensional clipping on a plot,{} \\spad{p},{} from the domain \\spadtype{Plot} for the parametric curve \\spad{x = f(t)},{} \\spad{y = g(t)}; the fraction parameter is specified by \\spad{frac} and the scale parameter is specified by \\spad{sc} for use in the \\fakeAxiomFun{iClipParametric} subroutine,{} which is called by this function.") (((|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|)))) (|Plot|)) "\\spad{clipParametric(p)} performs two-dimensional clipping on a plot,{} \\spad{p},{} from the domain \\spadtype{Plot} for the parametric curve \\spad{x = f(t)},{} \\spad{y = g(t)}; the default parameters \\spad{1/2} for the fraction and \\spad{5/1} for the scale are used in the \\fakeAxiomFun{iClipParametric} subroutine,{} which is called by this function.")) (|clip| (((|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|)))) (|List| (|List| (|Point| (|DoubleFloat|))))) "\\spad{clip(ll)} performs two-dimensional clipping on a list of lists of points,{} \\spad{ll}; the default parameters \\spad{1/2} for the fraction and \\spad{5/1} for the scale are used in the \\fakeAxiomFun{iClipParametric} subroutine,{} which is called by this function.") (((|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|)))) (|List| (|Point| (|DoubleFloat|)))) "\\spad{clip(l)} performs two-dimensional clipping on a curve \\spad{l},{} which is a list of points; the default parameters \\spad{1/2} for the fraction and \\spad{5/1} for the scale are used in the \\fakeAxiomFun{iClipParametric} subroutine,{} which is called by this function.") (((|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|)))) (|Plot|) (|Fraction| (|Integer|)) (|Fraction| (|Integer|))) "\\spad{clip(p,{}frac,{}sc)} performs two-dimensional clipping on a plot,{} \\spad{p},{} from the domain \\spadtype{Plot} for the graph of one variable \\spad{y = f(x)}; the fraction parameter is specified by \\spad{frac} and the scale parameter is specified by \\spad{sc} for use in the \\spadfun{clip} function.") (((|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|)))) (|Plot|)) "\\spad{clip(p)} performs two-dimensional clipping on a plot,{} \\spad{p},{} from the domain \\spadtype{Plot} for the graph of one variable,{} \\spad{y = f(x)}; the default parameters \\spad{1/4} for the fraction and \\spad{5/1} for the scale are used in the \\spadfun{clip} function."))) 
@@ -591,10 +591,10 @@ NIL
 (-165 S R) 
 ((|constructor| (NIL "This category represents the extension of a ring by a square root of \\spad{-1}.")) (|rationalIfCan| (((|Union| (|Fraction| (|Integer|)) "failed") $) "\\spad{rationalIfCan(x)} returns \\spad{x} as a rational number,{} or \"failed\" if \\spad{x} is not a rational number.")) (|rational| (((|Fraction| (|Integer|)) $) "\\spad{rational(x)} returns \\spad{x} as a rational number. Error: if \\spad{x} is not a rational number.")) (|rational?| (((|Boolean|) $) "\\spad{rational?(x)} tests if \\spad{x} is a rational number.")) (|polarCoordinates| (((|Record| (|:| |r| |#2|) (|:| |phi| |#2|)) $) "\\spad{polarCoordinates(x)} returns (\\spad{r},{} phi) such that \\spad{x} = \\spad{r} * exp(\\%\\spad{i} * phi).")) (|argument| ((|#2| $) "\\spad{argument(x)} returns the angle made by (0,{}1) and (0,{}\\spad{x}).")) (|abs| (($ $) "\\spad{abs(x)} returns the absolute value of \\spad{x} = sqrt(norm(\\spad{x})).")) (|exquo| (((|Union| $ "failed") $ |#2|) "\\spad{exquo(x,{} r)} returns the exact quotient of \\spad{x} by \\spad{r},{} or \"failed\" if \\spad{r} does not divide \\spad{x} exactly.")) (|norm| ((|#2| $) "\\spad{norm(x)} returns \\spad{x} * conjugate(\\spad{x})")) (|real| ((|#2| $) "\\spad{real(x)} returns real part of \\spad{x}.")) (|imag| ((|#2| $) "\\spad{imag(x)} returns imaginary part of \\spad{x}.")) (|conjugate| (($ $) "\\spad{conjugate(x + \\%i y)} returns \\spad{x} - \\%\\spad{i} \\spad{y}.")) (|imaginary| (($) "\\spad{imaginary()} = sqrt(\\spad{-1}) = \\%\\spad{i}.")) (|complex| (($ |#2| |#2|) "\\spad{complex(x,{}y)} constructs \\spad{x} + \\%i*y.") ((|attribute|) "indicates that \\% has sqrt(\\spad{-1})"))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-904))) (|HasCategory| |#2| (QUOTE (-550))) (|HasCategory| |#2| (QUOTE (-1002))) (|HasCategory| |#2| (QUOTE (-1181))) (|HasCategory| |#2| (QUOTE (-1056))) (|HasCategory| |#2| (QUOTE (-1021))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (QUOTE (-365))) (|HasAttribute| |#2| (QUOTE -4515)) (|HasAttribute| |#2| (QUOTE -4518)) (|HasCategory| |#2| (QUOTE (-301))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-842)))) 
+((|HasCategory| |#2| (QUOTE (-904))) (|HasCategory| |#2| (QUOTE (-550))) (|HasCategory| |#2| (QUOTE (-1002))) (|HasCategory| |#2| (QUOTE (-1181))) (|HasCategory| |#2| (QUOTE (-1056))) (|HasCategory| |#2| (QUOTE (-1021))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (QUOTE (-365))) (|HasAttribute| |#2| (QUOTE -4517)) (|HasAttribute| |#2| (QUOTE -4520)) (|HasCategory| |#2| (QUOTE (-301))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-842)))) 
 (-166 R) 
 ((|constructor| (NIL "This category represents the extension of a ring by a square root of \\spad{-1}.")) (|rationalIfCan| (((|Union| (|Fraction| (|Integer|)) "failed") $) "\\spad{rationalIfCan(x)} returns \\spad{x} as a rational number,{} or \"failed\" if \\spad{x} is not a rational number.")) (|rational| (((|Fraction| (|Integer|)) $) "\\spad{rational(x)} returns \\spad{x} as a rational number. Error: if \\spad{x} is not a rational number.")) (|rational?| (((|Boolean|) $) "\\spad{rational?(x)} tests if \\spad{x} is a rational number.")) (|polarCoordinates| (((|Record| (|:| |r| |#1|) (|:| |phi| |#1|)) $) "\\spad{polarCoordinates(x)} returns (\\spad{r},{} phi) such that \\spad{x} = \\spad{r} * exp(\\%\\spad{i} * phi).")) (|argument| ((|#1| $) "\\spad{argument(x)} returns the angle made by (0,{}1) and (0,{}\\spad{x}).")) (|abs| (($ $) "\\spad{abs(x)} returns the absolute value of \\spad{x} = sqrt(norm(\\spad{x})).")) (|exquo| (((|Union| $ "failed") $ |#1|) "\\spad{exquo(x,{} r)} returns the exact quotient of \\spad{x} by \\spad{r},{} or \"failed\" if \\spad{r} does not divide \\spad{x} exactly.")) (|norm| ((|#1| $) "\\spad{norm(x)} returns \\spad{x} * conjugate(\\spad{x})")) (|real| ((|#1| $) "\\spad{real(x)} returns real part of \\spad{x}.")) (|imag| ((|#1| $) "\\spad{imag(x)} returns imaginary part of \\spad{x}.")) (|conjugate| (($ $) "\\spad{conjugate(x + \\%i y)} returns \\spad{x} - \\%\\spad{i} \\spad{y}.")) (|imaginary| (($) "\\spad{imaginary()} = sqrt(\\spad{-1}) = \\%\\spad{i}.")) (|complex| (($ |#1| |#1|) "\\spad{complex(x,{}y)} constructs \\spad{x} + \\%i*y.") ((|attribute|) "indicates that \\% has sqrt(\\spad{-1})"))) 
-((-4512 -2198 (|has| |#1| (-558)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))) (-4517 |has| |#1| (-365)) (-4511 |has| |#1| (-365)) (-4515 |has| |#1| (-6 -4515)) (-4518 |has| |#1| (-6 -4518)) (-4003 . T) (-3973 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4514 -2199 (|has| |#1| (-558)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))) (-4519 |has| |#1| (-365)) (-4513 |has| |#1| (-365)) (-4517 |has| |#1| (-6 -4517)) (-4520 |has| |#1| (-6 -4520)) (-4005 . T) (-3973 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-167 RR PR) 
 ((|constructor| (NIL "This package has no description")) (|factor| (((|Factored| |#2|) |#2|) "\\spad{factor(p)} factorizes the polynomial \\spad{p} with complex coefficients."))) 
@@ -606,8 +606,8 @@ NIL
 NIL 
 (-169 R) 
 ((|constructor| (NIL "\\spadtype{Complex(R)} creates the domain of elements of the form \\spad{a + b * i} where \\spad{a} and \\spad{b} come from the ring \\spad{R},{} and \\spad{i} is a new element such that \\spad{i**2 = -1}."))) 
-((-4512 -2198 (|has| |#1| (-558)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))) (-4517 |has| |#1| (-365)) (-4511 |has| |#1| (-365)) (-4515 |has| |#1| (-6 -4515)) (-4518 |has| |#1| (-6 -4518)) (-4003 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-350))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-365))) (-2198 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-350)))) (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (-2198 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-1181))) (-12 (|HasCategory| |#1| (QUOTE (-1002))) (|HasCategory| |#1| (QUOTE (-1181)))) (|HasCategory| |#1| (QUOTE (-1021))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (LIST (QUOTE -523) (QUOTE (-1161)) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -281) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-823))) (|HasCategory| |#1| (QUOTE (-1056))) (-12 (|HasCategory| |#1| (QUOTE (-1056))) (|HasCategory| |#1| (QUOTE (-1181)))) (|HasCategory| |#1| (QUOTE (-550))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-301))) (-2198 (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-350))) (|HasCategory| |#1| (QUOTE (-558)))) (-2198 (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-350)))) (|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-225))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -281) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -523) (QUOTE (-1161)) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-350)))) (|HasCategory| |#1| (QUOTE (-225))) (-12 (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (QUOTE (-350))) (|HasCategory| |#1| (QUOTE (-370)))) (-12 (|HasCategory| |#1| (QUOTE (-350))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| |#1| (QUOTE (-350))) (|HasCategory| |#1| (QUOTE (-823)))) (-12 (|HasCategory| |#1| (QUOTE (-350))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (QUOTE (-350))) (|HasCategory| |#1| (QUOTE (-1021)))) (-12 (|HasCategory| |#1| (QUOTE (-350))) (|HasCategory| |#1| (QUOTE (-1181))))) (-12 (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (-12 (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-365))) (-12 (|HasCategory| |#1| (QUOTE (-350))) (|HasCategory| |#1| (QUOTE (-904))))) (-2198 (-12 (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| |#1| (QUOTE (-350))) (|HasCategory| |#1| (QUOTE (-904))))) (-2198 (-12 (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-365)))) (-2198 (-12 (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasAttribute| |#1| (QUOTE -4515)) (|HasAttribute| |#1| (QUOTE -4518)) (-12 (|HasCategory| |#1| (QUOTE (-225))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-350))))) 
+((-4514 -2199 (|has| |#1| (-558)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))) (-4519 |has| |#1| (-365)) (-4513 |has| |#1| (-365)) (-4517 |has| |#1| (-6 -4517)) (-4520 |has| |#1| (-6 -4520)) (-4005 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-350))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-365))) (-2199 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-350)))) (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (-2199 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-1181))) (-12 (|HasCategory| |#1| (QUOTE (-1002))) (|HasCategory| |#1| (QUOTE (-1181)))) (|HasCategory| |#1| (QUOTE (-1021))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (LIST (QUOTE -523) (QUOTE (-1161)) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -281) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-823))) (|HasCategory| |#1| (QUOTE (-1056))) (-12 (|HasCategory| |#1| (QUOTE (-1056))) (|HasCategory| |#1| (QUOTE (-1181)))) (|HasCategory| |#1| (QUOTE (-550))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-301))) (-2199 (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-350))) (|HasCategory| |#1| (QUOTE (-558)))) (-2199 (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-350)))) (|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-225))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -281) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -523) (QUOTE (-1161)) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-350)))) (|HasCategory| |#1| (QUOTE (-225))) (-12 (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-350)))) (-12 (|HasCategory| |#1| (QUOTE (-350))) (|HasCategory| |#1| (QUOTE (-370)))) (-12 (|HasCategory| |#1| (QUOTE (-350))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| |#1| (QUOTE (-350))) (|HasCategory| |#1| (QUOTE (-823)))) (-12 (|HasCategory| |#1| (QUOTE (-350))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (QUOTE (-350))) (|HasCategory| |#1| (QUOTE (-1021)))) (-12 (|HasCategory| |#1| (QUOTE (-350))) (|HasCategory| |#1| (QUOTE (-1181))))) (-12 (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (-12 (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-365))) (-12 (|HasCategory| |#1| (QUOTE (-350))) (|HasCategory| |#1| (QUOTE (-904))))) (-2199 (-12 (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| |#1| (QUOTE (-350))) (|HasCategory| |#1| (QUOTE (-904))))) (-2199 (-12 (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-365)))) (-2199 (-12 (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasAttribute| |#1| (QUOTE -4517)) (|HasAttribute| |#1| (QUOTE -4520)) (-12 (|HasCategory| |#1| (QUOTE (-225))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-350))))) 
 (-170 R S CS) 
 ((|constructor| (NIL "This package supports converting complex expressions to patterns")) (|convert| (((|Pattern| |#1|) |#3|) "\\spad{convert(cs)} converts the complex expression \\spad{cs} to a pattern"))) 
 NIL 
@@ -618,11 +618,11 @@ NIL
 NIL 
 (-172) 
 ((|constructor| (NIL "The category of commutative rings with unity,{} \\spadignore{i.e.} rings where \\spadop{*} is commutative,{} and which have a multiplicative identity element.")) (|commutative| ((|attribute| "*") "multiplication is commutative."))) 
-(((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+(((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-173 R) 
 ((|constructor| (NIL "\\spadtype{ContinuedFraction} implements general continued fractions. This version is not restricted to simple,{} finite fractions and uses the \\spadtype{Stream} as a representation. The arithmetic functions assume that the approximants alternate below/above the convergence point. This is enforced by ensuring the partial numerators and partial denominators are greater than 0 in the Euclidean domain view of \\spad{R} (\\spadignore{i.e.} \\spad{sizeLess?(0,{} x)}).")) (|complete| (($ $) "\\spad{complete(x)} causes all entries in \\spadvar{\\spad{x}} to be computed. Normally entries are only computed as needed. If \\spadvar{\\spad{x}} is an infinite continued fraction,{} a user-initiated interrupt is necessary to stop the computation.")) (|extend| (($ $ (|Integer|)) "\\spad{extend(x,{}n)} causes the first \\spadvar{\\spad{n}} entries in the continued fraction \\spadvar{\\spad{x}} to be computed. Normally entries are only computed as needed.")) (|denominators| (((|Stream| |#1|) $) "\\spad{denominators(x)} returns the stream of denominators of the approximants of the continued fraction \\spadvar{\\spad{x}}. If the continued fraction is finite,{} then the stream will be finite.")) (|numerators| (((|Stream| |#1|) $) "\\spad{numerators(x)} returns the stream of numerators of the approximants of the continued fraction \\spadvar{\\spad{x}}. If the continued fraction is finite,{} then the stream will be finite.")) (|convergents| (((|Stream| (|Fraction| |#1|)) $) "\\spad{convergents(x)} returns the stream of the convergents of the continued fraction \\spadvar{\\spad{x}}. If the continued fraction is finite,{} then the stream will be finite.")) (|approximants| (((|Stream| (|Fraction| |#1|)) $) "\\spad{approximants(x)} returns the stream of approximants of the continued fraction \\spadvar{\\spad{x}}. If the continued fraction is finite,{} then the stream will be infinite and periodic with period 1.")) (|reducedForm| (($ $) "\\spad{reducedForm(x)} puts the continued fraction \\spadvar{\\spad{x}} in reduced form,{} \\spadignore{i.e.} the function returns an equivalent continued fraction of the form \\spad{continuedFraction(b0,{}[1,{}1,{}1,{}...],{}[b1,{}b2,{}b3,{}...])}.")) (|wholePart| ((|#1| $) "\\spad{wholePart(x)} extracts the whole part of \\spadvar{\\spad{x}}. That is,{} if \\spad{x = continuedFraction(b0,{} [a1,{}a2,{}a3,{}...],{} [b1,{}b2,{}b3,{}...])},{} then \\spad{wholePart(x) = b0}.")) (|partialQuotients| (((|Stream| |#1|) $) "\\spad{partialQuotients(x)} extracts the partial quotients in \\spadvar{\\spad{x}}. That is,{} if \\spad{x = continuedFraction(b0,{} [a1,{}a2,{}a3,{}...],{} [b1,{}b2,{}b3,{}...])},{} then \\spad{partialQuotients(x) = [b0,{}b1,{}b2,{}b3,{}...]}.")) (|partialDenominators| (((|Stream| |#1|) $) "\\spad{partialDenominators(x)} extracts the denominators in \\spadvar{\\spad{x}}. That is,{} if \\spad{x = continuedFraction(b0,{} [a1,{}a2,{}a3,{}...],{} [b1,{}b2,{}b3,{}...])},{} then \\spad{partialDenominators(x) = [b1,{}b2,{}b3,{}...]}.")) (|partialNumerators| (((|Stream| |#1|) $) "\\spad{partialNumerators(x)} extracts the numerators in \\spadvar{\\spad{x}}. That is,{} if \\spad{x = continuedFraction(b0,{} [a1,{}a2,{}a3,{}...],{} [b1,{}b2,{}b3,{}...])},{} then \\spad{partialNumerators(x) = [a1,{}a2,{}a3,{}...]}.")) (|reducedContinuedFraction| (($ |#1| (|Stream| |#1|)) "\\spad{reducedContinuedFraction(b0,{}b)} constructs a continued fraction in the following way: if \\spad{b = [b1,{}b2,{}...]} then the result is the continued fraction \\spad{b0 + 1/(b1 + 1/(b2 + ...))}. That is,{} the result is the same as \\spad{continuedFraction(b0,{}[1,{}1,{}1,{}...],{}[b1,{}b2,{}b3,{}...])}.")) (|continuedFraction| (($ |#1| (|Stream| |#1|) (|Stream| |#1|)) "\\spad{continuedFraction(b0,{}a,{}b)} constructs a continued fraction in the following way: if \\spad{a = [a1,{}a2,{}...]} and \\spad{b = [b1,{}b2,{}...]} then the result is the continued fraction \\spad{b0 + a1/(b1 + a2/(b2 + ...))}.") (($ (|Fraction| |#1|)) "\\spad{continuedFraction(r)} converts the fraction \\spadvar{\\spad{r}} with components of type \\spad{R} to a continued fraction over \\spad{R}."))) 
-(((-4521 "*") . T) (-4512 . T) (-4517 . T) (-4511 . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+(((-4523 "*") . T) (-4514 . T) (-4519 . T) (-4513 . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-174 R) 
 ((|constructor| (NIL "CoordinateSystems provides coordinate transformation functions for plotting. Functions in this package return conversion functions which take points expressed in other coordinate systems and return points with the corresponding Cartesian coordinates.")) (|conical| (((|Mapping| (|Point| |#1|) (|Point| |#1|)) |#1| |#1|) "\\spad{conical(a,{}b)} transforms from conical coordinates to Cartesian coordinates: \\spad{conical(a,{}b)} is a function which will map the point \\spad{(lambda,{}mu,{}nu)} to \\spad{x = lambda*mu*nu/(a*b)},{} \\spad{y = lambda/a*sqrt((mu**2-a**2)*(nu**2-a**2)/(a**2-b**2))},{} \\spad{z = lambda/b*sqrt((mu**2-b**2)*(nu**2-b**2)/(b**2-a**2))}.")) (|toroidal| (((|Mapping| (|Point| |#1|) (|Point| |#1|)) |#1|) "\\spad{toroidal(a)} transforms from toroidal coordinates to Cartesian coordinates: \\spad{toroidal(a)} is a function which will map the point \\spad{(u,{}v,{}phi)} to \\spad{x = a*sinh(v)*cos(phi)/(cosh(v)-cos(u))},{} \\spad{y = a*sinh(v)*sin(phi)/(cosh(v)-cos(u))},{} \\spad{z = a*sin(u)/(cosh(v)-cos(u))}.")) (|bipolarCylindrical| (((|Mapping| (|Point| |#1|) (|Point| |#1|)) |#1|) "\\spad{bipolarCylindrical(a)} transforms from bipolar cylindrical coordinates to Cartesian coordinates: \\spad{bipolarCylindrical(a)} is a function which will map the point \\spad{(u,{}v,{}z)} to \\spad{x = a*sinh(v)/(cosh(v)-cos(u))},{} \\spad{y = a*sin(u)/(cosh(v)-cos(u))},{} \\spad{z}.")) (|bipolar| (((|Mapping| (|Point| |#1|) (|Point| |#1|)) |#1|) "\\spad{bipolar(a)} transforms from bipolar coordinates to Cartesian coordinates: \\spad{bipolar(a)} is a function which will map the point \\spad{(u,{}v)} to \\spad{x = a*sinh(v)/(cosh(v)-cos(u))},{} \\spad{y = a*sin(u)/(cosh(v)-cos(u))}.")) (|oblateSpheroidal| (((|Mapping| (|Point| |#1|) (|Point| |#1|)) |#1|) "\\spad{oblateSpheroidal(a)} transforms from oblate spheroidal coordinates to Cartesian coordinates: \\spad{oblateSpheroidal(a)} is a function which will map the point \\spad{(\\spad{xi},{}eta,{}phi)} to \\spad{x = a*sinh(\\spad{xi})*sin(eta)*cos(phi)},{} \\spad{y = a*sinh(\\spad{xi})*sin(eta)*sin(phi)},{} \\spad{z = a*cosh(\\spad{xi})*cos(eta)}.")) (|prolateSpheroidal| (((|Mapping| (|Point| |#1|) (|Point| |#1|)) |#1|) "\\spad{prolateSpheroidal(a)} transforms from prolate spheroidal coordinates to Cartesian coordinates: \\spad{prolateSpheroidal(a)} is a function which will map the point \\spad{(\\spad{xi},{}eta,{}phi)} to \\spad{x = a*sinh(\\spad{xi})*sin(eta)*cos(phi)},{} \\spad{y = a*sinh(\\spad{xi})*sin(eta)*sin(phi)},{} \\spad{z = a*cosh(\\spad{xi})*cos(eta)}.")) (|ellipticCylindrical| (((|Mapping| (|Point| |#1|) (|Point| |#1|)) |#1|) "\\spad{ellipticCylindrical(a)} transforms from elliptic cylindrical coordinates to Cartesian coordinates: \\spad{ellipticCylindrical(a)} is a function which will map the point \\spad{(u,{}v,{}z)} to \\spad{x = a*cosh(u)*cos(v)},{} \\spad{y = a*sinh(u)*sin(v)},{} \\spad{z}.")) (|elliptic| (((|Mapping| (|Point| |#1|) (|Point| |#1|)) |#1|) "\\spad{elliptic(a)} transforms from elliptic coordinates to Cartesian coordinates: \\spad{elliptic(a)} is a function which will map the point \\spad{(u,{}v)} to \\spad{x = a*cosh(u)*cos(v)},{} \\spad{y = a*sinh(u)*sin(v)}.")) (|paraboloidal| (((|Point| |#1|) (|Point| |#1|)) "\\spad{paraboloidal(pt)} transforms \\spad{pt} from paraboloidal coordinates to Cartesian coordinates: the function produced will map the point \\spad{(u,{}v,{}phi)} to \\spad{x = u*v*cos(phi)},{} \\spad{y = u*v*sin(phi)},{} \\spad{z = 1/2 * (u**2 - v**2)}.")) (|parabolicCylindrical| (((|Point| |#1|) (|Point| |#1|)) "\\spad{parabolicCylindrical(pt)} transforms \\spad{pt} from parabolic cylindrical coordinates to Cartesian coordinates: the function produced will map the point \\spad{(u,{}v,{}z)} to \\spad{x = 1/2*(u**2 - v**2)},{} \\spad{y = u*v},{} \\spad{z}.")) (|parabolic| (((|Point| |#1|) (|Point| |#1|)) "\\spad{parabolic(pt)} transforms \\spad{pt} from parabolic coordinates to Cartesian coordinates: the function produced will map the point \\spad{(u,{}v)} to \\spad{x = 1/2*(u**2 - v**2)},{} \\spad{y = u*v}.")) (|spherical| (((|Point| |#1|) (|Point| |#1|)) "\\spad{spherical(pt)} transforms \\spad{pt} from spherical coordinates to Cartesian coordinates: the function produced will map the point \\spad{(r,{}theta,{}phi)} to \\spad{x = r*sin(phi)*cos(theta)},{} \\spad{y = r*sin(phi)*sin(theta)},{} \\spad{z = r*cos(phi)}.")) (|cylindrical| (((|Point| |#1|) (|Point| |#1|)) "\\spad{cylindrical(pt)} transforms \\spad{pt} from polar coordinates to Cartesian coordinates: the function produced will map the point \\spad{(r,{}theta,{}z)} to \\spad{x = r * cos(theta)},{} \\spad{y = r * sin(theta)},{} \\spad{z}.")) (|polar| (((|Point| |#1|) (|Point| |#1|)) "\\spad{polar(pt)} transforms \\spad{pt} from polar coordinates to Cartesian coordinates: the function produced will map the point \\spad{(r,{}theta)} to \\spad{x = r * cos(theta)} ,{} \\spad{y = r * sin(theta)}.")) (|cartesian| (((|Point| |#1|) (|Point| |#1|)) "\\spad{cartesian(pt)} returns the Cartesian coordinates of point \\spad{pt}."))) 
@@ -762,8 +762,8 @@ NIL
 NIL 
 (-208) 
 ((|constructor| (NIL "This domain allows rational numbers to be presented as repeating decimal expansions.")) (|decimal| (($ (|Fraction| (|Integer|))) "\\spad{decimal(r)} converts a rational number to a decimal expansion.")) (|fractionPart| (((|Fraction| (|Integer|)) $) "\\spad{fractionPart(d)} returns the fractional part of a decimal expansion.")) (|coerce| (((|RadixExpansion| 10) $) "\\spad{coerce(d)} converts a decimal expansion to a radix expansion with base 10.") (((|Fraction| (|Integer|)) $) "\\spad{coerce(d)} converts a decimal expansion to a rational number."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| (-568) (QUOTE (-904))) (|HasCategory| (-568) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| (-568) (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-150))) (|HasCategory| (-568) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-568) (QUOTE (-1021))) (|HasCategory| (-568) (QUOTE (-815))) (|HasCategory| (-568) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| (-568) (QUOTE (-1136))) (|HasCategory| (-568) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| (-568) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| (-568) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| (-568) (QUOTE (-225))) (|HasCategory| (-568) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-568) (LIST (QUOTE -523) (QUOTE (-1161)) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -303) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -281) (QUOTE (-568)) (QUOTE (-568)))) (|HasCategory| (-568) (QUOTE (-301))) (|HasCategory| (-568) (QUOTE (-550))) (|HasCategory| (-568) (QUOTE (-842))) (-2198 (|HasCategory| (-568) (QUOTE (-815))) (|HasCategory| (-568) (QUOTE (-842)))) (|HasCategory| (-568) (LIST (QUOTE -630) (QUOTE (-568)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-904)))) (|HasCategory| (-568) (QUOTE (-148))))) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| (-568) (QUOTE (-904))) (|HasCategory| (-568) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| (-568) (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-150))) (|HasCategory| (-568) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-568) (QUOTE (-1021))) (|HasCategory| (-568) (QUOTE (-815))) (|HasCategory| (-568) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| (-568) (QUOTE (-1136))) (|HasCategory| (-568) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| (-568) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| (-568) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| (-568) (QUOTE (-225))) (|HasCategory| (-568) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-568) (LIST (QUOTE -523) (QUOTE (-1161)) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -303) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -281) (QUOTE (-568)) (QUOTE (-568)))) (|HasCategory| (-568) (QUOTE (-301))) (|HasCategory| (-568) (QUOTE (-550))) (|HasCategory| (-568) (QUOTE (-842))) (-2199 (|HasCategory| (-568) (QUOTE (-815))) (|HasCategory| (-568) (QUOTE (-842)))) (|HasCategory| (-568) (LIST (QUOTE -630) (QUOTE (-568)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-904)))) (|HasCategory| (-568) (QUOTE (-148))))) 
 (-209 R -1478) 
 ((|constructor| (NIL "\\spadtype{ElementaryFunctionDefiniteIntegration} provides functions to compute definite integrals of elementary functions.")) (|innerint| (((|Union| (|:| |f1| (|OrderedCompletion| |#2|)) (|:| |f2| (|List| (|OrderedCompletion| |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (|Symbol|) (|OrderedCompletion| |#2|) (|OrderedCompletion| |#2|) (|Boolean|)) "\\spad{innerint(f,{} x,{} a,{} b,{} ignore?)} should be local but conditional")) (|integrate| (((|Union| (|:| |f1| (|OrderedCompletion| |#2|)) (|:| |f2| (|List| (|OrderedCompletion| |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (|SegmentBinding| (|OrderedCompletion| |#2|)) (|String|)) "\\spad{integrate(f,{} x = a..b,{} \"noPole\")} returns the integral of \\spad{f(x)dx} from a to \\spad{b}. If it is not possible to check whether \\spad{f} has a pole for \\spad{x} between a and \\spad{b} (because of parameters),{} then this function will assume that \\spad{f} has no such pole. Error: if \\spad{f} has a pole for \\spad{x} between a and \\spad{b} or if the last argument is not \"noPole\".") (((|Union| (|:| |f1| (|OrderedCompletion| |#2|)) (|:| |f2| (|List| (|OrderedCompletion| |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (|SegmentBinding| (|OrderedCompletion| |#2|))) "\\spad{integrate(f,{} x = a..b)} returns the integral of \\spad{f(x)dx} from a to \\spad{b}. Error: if \\spad{f} has a pole for \\spad{x} between a and \\spad{b}."))) 
 NIL 
@@ -778,11 +778,11 @@ NIL
 NIL 
 (-212 S) 
 ((|constructor| (NIL "Linked list implementation of a Dequeue")) (|member?| (((|Boolean|) |#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} member?(3,{}a)")) (|members| (((|List| |#1|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} members a")) (|parts| (((|List| |#1|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} parts a")) (|#| (((|NonNegativeInteger|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} \\#a")) (|count| (((|NonNegativeInteger|) |#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} count(4,{}a)") (((|NonNegativeInteger|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} count(\\spad{x+}->(\\spad{x>2}),{}a)")) (|any?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} any?(\\spad{x+}->(\\spad{x=4}),{}a)")) (|every?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} every?(\\spad{x+}->(\\spad{x=4}),{}a)")) (~= (((|Boolean|) $ $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} b:=copy a \\spad{X} (a~=b)")) (= (((|Boolean|) $ $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} b:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} (a=b)@Boolean")) (|coerce| (((|OutputForm|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} coerce a")) (|hash| (((|SingleInteger|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} hash a")) (|latex| (((|String|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} latex a")) (|map!| (($ (|Mapping| |#1| |#1|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} map!(\\spad{x+}-\\spad{>x+10},{}a) \\spad{X} a")) (|top!| ((|#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} top! a \\spad{X} a")) (|reverse!| (($ $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} reverse! a \\spad{X} a")) (|push!| ((|#1| |#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} push! a \\spad{X} a")) (|pop!| ((|#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} pop! a \\spad{X} a")) (|insertTop!| ((|#1| |#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} insertTop! a \\spad{X} a")) (|insertBottom!| ((|#1| |#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} insertBottom! a \\spad{X} a")) (|extractTop!| ((|#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} extractTop! a \\spad{X} a")) (|extractBottom!| ((|#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} extractBottom! a \\spad{X} a")) (|bottom!| ((|#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} bottom! a \\spad{X} a")) (|top| ((|#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} top a")) (|height| (((|NonNegativeInteger|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} height a")) (|depth| (((|NonNegativeInteger|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} depth a")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} map(\\spad{x+}-\\spad{>x+10},{}a) \\spad{X} a")) (|eq?| (((|Boolean|) $ $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} b:=copy a \\spad{X} eq?(a,{}\\spad{b})")) (|copy| (($ $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} copy a")) (|sample| (($) "\\blankline \\spad{X} sample()\\$Dequeue(INT)")) (|empty| (($) "\\blankline \\spad{X} b:=empty()\\$(Dequeue INT)")) (|empty?| (((|Boolean|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} empty? a")) (|bag| (($ (|List| |#1|)) "\\blankline \\spad{X} bag([1,{}2,{}3,{}4,{}5])\\$Dequeue(INT)")) (|size?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} size?(a,{}5)")) (|more?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} more?(a,{}9)")) (|less?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} less?(a,{}9)")) (|length| (((|NonNegativeInteger|) $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} length a")) (|rotate!| (($ $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} rotate! a")) (|back| ((|#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} back a")) (|front| ((|#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} front a")) (|inspect| ((|#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} inspect a")) (|insert!| (($ |#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} insert! (8,{}a) \\spad{X} a")) (|enqueue!| ((|#1| |#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} enqueue! (9,{}a) \\spad{X} a")) (|extract!| ((|#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} extract! a \\spad{X} a")) (|dequeue!| ((|#1| $) "\\blankline \\spad{X} a:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5] \\spad{X} dequeue! a \\spad{X} a")) (|dequeue| (($) "\\blankline \\spad{X} a:Dequeue INT:= dequeue ()") (($ (|List| |#1|)) "\\indented{1}{dequeue([\\spad{x},{}\\spad{y},{}...,{}\\spad{z}]) creates a dequeue with first (top or front)} \\indented{1}{element \\spad{x},{} second element \\spad{y},{}...,{}and last (bottom or back) element \\spad{z}.} \\blankline \\spad{E} g:Dequeue INT:= dequeue [1,{}2,{}3,{}4,{}5]"))) 
-((-4519 . T) (-4520 . T)) 
+((-4521 . T) (-4522 . T)) 
 ((|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090))))) 
 (-213 |CoefRing| |listIndVar|) 
 ((|constructor| (NIL "The deRham complex of Euclidean space,{} that is,{} the class of differential forms of arbitary degree over a coefficient ring. See Flanders,{} Harley,{} Differential Forms,{} With Applications to the Physical Sciences,{} New York,{} Academic Press,{} 1963.")) (|exteriorDifferential| (($ $) "\\spad{exteriorDifferential(df)} returns the exterior derivative (gradient,{} curl,{} divergence,{} ...) of the differential form \\spad{df}.")) (|totalDifferential| (($ (|Expression| |#1|)) "\\spad{totalDifferential(x)} returns the total differential (gradient) form for element \\spad{x}.")) (|map| (($ (|Mapping| (|Expression| |#1|) (|Expression| |#1|)) $) "\\spad{map(f,{}df)} replaces each coefficient \\spad{x} of differential form \\spad{df} by \\spad{f(x)}.")) (|degree| (((|Integer|) $) "\\spad{degree(df)} returns the homogeneous degree of differential form \\spad{df}.")) (|retractable?| (((|Boolean|) $) "\\spad{retractable?(df)} tests if differential form \\spad{df} is a 0-form,{} \\spadignore{i.e.} if degree(\\spad{df}) = 0.")) (|homogeneous?| (((|Boolean|) $) "\\spad{homogeneous?(df)} tests if all of the terms of differential form \\spad{df} have the same degree.")) (|generator| (($ (|NonNegativeInteger|)) "\\spad{generator(n)} returns the \\spad{n}th basis term for a differential form.")) (|coefficient| (((|Expression| |#1|) $ $) "\\spad{coefficient(df,{}u)},{} where \\spad{df} is a differential form,{} returns the coefficient of \\spad{df} containing the basis term \\spad{u} if such a term exists,{} and 0 otherwise.")) (|reductum| (($ $) "\\spad{reductum(df)},{} where \\spad{df} is a differential form,{} returns \\spad{df} minus the leading term of \\spad{df} if \\spad{df} has two or more terms,{} and 0 otherwise.")) (|leadingBasisTerm| (($ $) "\\spad{leadingBasisTerm(df)} returns the leading basis term of differential form \\spad{df}.")) (|leadingCoefficient| (((|Expression| |#1|) $) "\\spad{leadingCoefficient(df)} returns the leading coefficient of differential form \\spad{df}."))) 
-((-4516 . T)) 
+((-4518 . T)) 
 NIL 
 (-214 R -1478) 
 ((|constructor| (NIL "\\spadtype{DefiniteIntegrationTools} provides common tools used by the definite integration of both rational and elementary functions.")) (|checkForZero| (((|Union| (|Boolean|) "failed") (|SparseUnivariatePolynomial| |#2|) (|OrderedCompletion| |#2|) (|OrderedCompletion| |#2|) (|Boolean|)) "\\spad{checkForZero(p,{} a,{} b,{} incl?)} is \\spad{true} if \\spad{p} has a zero between a and \\spad{b},{} \\spad{false} otherwise,{} \"failed\" if this cannot be determined. Check for a and \\spad{b} inclusive if incl? is \\spad{true},{} exclusive otherwise.") (((|Union| (|Boolean|) "failed") (|Polynomial| |#1|) (|Symbol|) (|OrderedCompletion| |#2|) (|OrderedCompletion| |#2|) (|Boolean|)) "\\spad{checkForZero(p,{} x,{} a,{} b,{} incl?)} is \\spad{true} if \\spad{p} has a zero for \\spad{x} between a and \\spad{b},{} \\spad{false} otherwise,{} \"failed\" if this cannot be determined. Check for a and \\spad{b} inclusive if incl? is \\spad{true},{} exclusive otherwise.")) (|computeInt| (((|Union| (|OrderedCompletion| |#2|) "failed") (|Kernel| |#2|) |#2| (|OrderedCompletion| |#2|) (|OrderedCompletion| |#2|) (|Boolean|)) "\\spad{computeInt(x,{} g,{} a,{} b,{} eval?)} returns the integral of \\spad{f} for \\spad{x} between a and \\spad{b},{} assuming that \\spad{g} is an indefinite integral of \\spad{f} and \\spad{f} has no pole between a and \\spad{b}. If \\spad{eval?} is \\spad{true},{} then \\spad{g} can be evaluated safely at \\spad{a} and \\spad{b},{} provided that they are finite values. Otherwise,{} limits must be computed.")) (|ignore?| (((|Boolean|) (|String|)) "\\spad{ignore?(s)} is \\spad{true} if \\spad{s} is the string that tells the integrator to assume that the function has no pole in the integration interval."))) 
@@ -790,31 +790,31 @@ NIL
 NIL 
 (-215) 
 ((|constructor| (NIL "\\spadtype{DoubleFloat} is intended to make accessible hardware floating point arithmetic in Axiom,{} either native double precision,{} or IEEE. On most machines,{} there will be hardware support for the arithmetic operations: \\spad{++} +,{} *,{} / and possibly also the sqrt operation. The operations exp,{} log,{} sin,{} cos,{} atan are normally coded in software based on minimax polynomial/rational approximations. \\blankline Some general comments about the accuracy of the operations: the operations +,{} *,{} / and sqrt are expected to be fully accurate. The operations exp,{} log,{} sin,{} cos and atan are not expected to be fully accurate. In particular,{} sin and cos will lose all precision for large arguments. \\blankline The Float domain provides an alternative to the DoubleFloat domain. It provides an arbitrary precision model of floating point arithmetic. This means that accuracy problems like those above are eliminated by increasing the working precision where necessary. \\spadtype{Float} provides some special functions such as erf,{} the error function in addition to the elementary functions. The disadvantage of Float is that it is much more expensive than small floats when the latter can be used.")) (|integerDecode| (((|List| (|Integer|)) $) "\\indented{1}{integerDecode(\\spad{x}) returns the multiple values of the\\space{2}common} \\indented{1}{lisp integer-decode-float function.} \\indented{1}{See Steele,{} ISBN 0-13-152414-3 \\spad{p354}. This function can be used} \\indented{1}{to ensure that the results are bit-exact and do not depend on} \\indented{1}{the binary-to-decimal conversions.} \\blankline \\spad{X} a:DFLOAT:=-1.0/3.0 \\spad{X} integerDecode a")) (|machineFraction| (((|Fraction| (|Integer|)) $) "\\indented{1}{machineFraction(\\spad{x}) returns a bit-exact fraction of the machine} \\indented{1}{floating point number using the common lisp integer-decode-float} \\indented{1}{function. See Steele,{} ISBN 0-13-152414-3 \\spad{p354}} \\indented{1}{This function can be used to print results which do not depend} \\indented{1}{on binary-to-decimal conversions} \\blankline \\spad{X} a:DFLOAT:=-1.0/3.0 \\spad{X} machineFraction a")) (|rationalApproximation| (((|Fraction| (|Integer|)) $ (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{rationalApproximation(f,{} n,{} b)} computes a rational approximation \\spad{r} to \\spad{f} with relative error \\spad{< b**(-n)} (that is,{} \\spad{|(r-f)/f| < b**(-n)}).") (((|Fraction| (|Integer|)) $ (|NonNegativeInteger|)) "\\spad{rationalApproximation(f,{} n)} computes a rational approximation \\spad{r} to \\spad{f} with relative error \\spad{< 10**(-n)}.")) (|doubleFloatFormat| (((|String|) (|String|)) "change the output format for doublefloats using lisp format strings")) (|Beta| (($ $ $) "\\spad{Beta(x,{}y)} is \\spad{Gamma(x) * Gamma(y)/Gamma(x+y)}.")) (|Gamma| (($ $) "\\spad{Gamma(x)} is the Euler Gamma function.")) (|atan| (($ $ $) "\\spad{atan(x,{}y)} computes the arc tangent from \\spad{x} with phase \\spad{y}.")) (|log10| (($ $) "\\spad{log10(x)} computes the logarithm with base 10 for \\spad{x}.")) (|log2| (($ $) "\\spad{log2(x)} computes the logarithm with base 2 for \\spad{x}.")) (|hash| (((|Integer|) $) "\\spad{hash(x)} returns the hash key for \\spad{x}")) (|exp1| (($) "\\spad{exp1()} returns the natural log base \\spad{2.718281828...}.")) (** (($ $ $) "\\spad{x ** y} returns the \\spad{y}th power of \\spad{x} (equal to \\spad{exp(y log x)}).")) (/ (($ $ (|Integer|)) "\\spad{x / i} computes the division from \\spad{x} by an integer \\spad{i}."))) 
-((-3996 . T) (-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-3999 . T) (-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-216) 
 ((|constructor| (NIL "This is a low-level domain which implements matrices (two dimensional arrays) of double precision floating point numbers. Indexing is 0 based,{} there is no bound checking (unless provided by lower level).")) (|qnew| (($ (|Integer|) (|Integer|)) "\\indented{1}{qnew(\\spad{n},{} \\spad{m}) creates a new uninitialized \\spad{n} by \\spad{m} matrix.} \\blankline \\spad{X} t1:DFMAT:=qnew(3,{}4)"))) 
-((-4519 . T) (-4520 . T)) 
-((|HasCategory| (-215) (QUOTE (-1090))) (-12 (|HasCategory| (-215) (LIST (QUOTE -303) (QUOTE (-215)))) (|HasCategory| (-215) (QUOTE (-1090)))) (|HasCategory| (-215) (QUOTE (-301))) (|HasCategory| (-215) (QUOTE (-558))) (|HasAttribute| (-215) (QUOTE (-4521 "*"))) (|HasCategory| (-215) (QUOTE (-172))) (|HasCategory| (-215) (QUOTE (-365)))) 
+((-4521 . T) (-4522 . T)) 
+((|HasCategory| (-215) (QUOTE (-1090))) (-12 (|HasCategory| (-215) (LIST (QUOTE -303) (QUOTE (-215)))) (|HasCategory| (-215) (QUOTE (-1090)))) (|HasCategory| (-215) (QUOTE (-301))) (|HasCategory| (-215) (QUOTE (-558))) (|HasAttribute| (-215) (QUOTE (-4523 "*"))) (|HasCategory| (-215) (QUOTE (-172))) (|HasCategory| (-215) (QUOTE (-365)))) 
 (-217) 
 ((|constructor| (NIL "This package provides special functions for double precision real and complex floating point.")) (|hypergeometric0F1| (((|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) "\\spad{hypergeometric0F1(c,{}z)} is the hypergeometric function \\spad{0F1(; c; z)}.") (((|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) "\\spad{hypergeometric0F1(c,{}z)} is the hypergeometric function \\spad{0F1(; c; z)}.")) (|airyBi| (((|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) "\\spad{airyBi(x)} is the Airy function \\spad{\\spad{Bi}(x)}. This function satisfies the differential equation: \\indented{2}{\\spad{\\spad{Bi}''(x) - x * \\spad{Bi}(x) = 0}.}") (((|DoubleFloat|) (|DoubleFloat|)) "\\spad{airyBi(x)} is the Airy function \\spad{\\spad{Bi}(x)}. This function satisfies the differential equation: \\indented{2}{\\spad{\\spad{Bi}''(x) - x * \\spad{Bi}(x) = 0}.}")) (|airyAi| (((|DoubleFloat|) (|DoubleFloat|)) "\\spad{airyAi(x)} is the Airy function \\spad{\\spad{Ai}(x)}. This function satisfies the differential equation: \\indented{2}{\\spad{\\spad{Ai}''(x) - x * \\spad{Ai}(x) = 0}.}") (((|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) "\\spad{airyAi(x)} is the Airy function \\spad{\\spad{Ai}(x)}. This function satisfies the differential equation: \\indented{2}{\\spad{\\spad{Ai}''(x) - x * \\spad{Ai}(x) = 0}.}")) (|besselK| (((|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) "\\spad{besselK(v,{}x)} is the modified Bessel function of the second kind,{} \\spad{K(v,{}x)}. This function satisfies the differential equation: \\indented{2}{\\spad{x^2 w''(x) + x w'(x) - (x^2+v^2)w(x) = 0}.} Note that the default implementation uses the relation \\indented{2}{\\spad{K(v,{}x) = \\%pi/2*(I(-v,{}x) - I(v,{}x))/sin(v*\\%\\spad{pi})}} so is not valid for integer values of \\spad{v}.") (((|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) "\\spad{besselK(v,{}x)} is the modified Bessel function of the second kind,{} \\spad{K(v,{}x)}. This function satisfies the differential equation: \\indented{2}{\\spad{x^2 w''(x) + x w'(x) - (x^2+v^2)w(x) = 0}.} Note that the default implementation uses the relation \\indented{2}{\\spad{K(v,{}x) = \\%pi/2*(I(-v,{}x) - I(v,{}x))/sin(v*\\%\\spad{pi})}.} so is not valid for integer values of \\spad{v}.")) (|besselI| (((|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) "\\spad{besselI(v,{}x)} is the modified Bessel function of the first kind,{} \\spad{I(v,{}x)}. This function satisfies the differential equation: \\indented{2}{\\spad{x^2 w''(x) + x w'(x) - (x^2+v^2)w(x) = 0}.}") (((|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) "\\spad{besselI(v,{}x)} is the modified Bessel function of the first kind,{} \\spad{I(v,{}x)}. This function satisfies the differential equation: \\indented{2}{\\spad{x^2 w''(x) + x w'(x) - (x^2+v^2)w(x) = 0}.}")) (|besselY| (((|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) "\\spad{besselY(v,{}x)} is the Bessel function of the second kind,{} \\spad{Y(v,{}x)}. This function satisfies the differential equation: \\indented{2}{\\spad{x^2 w''(x) + x w'(x) + (x^2-v^2)w(x) = 0}.} Note that the default implementation uses the relation \\indented{2}{\\spad{Y(v,{}x) = (J(v,{}x) cos(v*\\%\\spad{pi}) - J(-v,{}x))/sin(v*\\%\\spad{pi})}} so is not valid for integer values of \\spad{v}.") (((|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) "\\spad{besselY(v,{}x)} is the Bessel function of the second kind,{} \\spad{Y(v,{}x)}. This function satisfies the differential equation: \\indented{2}{\\spad{x^2 w''(x) + x w'(x) + (x^2-v^2)w(x) = 0}.} Note that the default implementation uses the relation \\indented{2}{\\spad{Y(v,{}x) = (J(v,{}x) cos(v*\\%\\spad{pi}) - J(-v,{}x))/sin(v*\\%\\spad{pi})}} so is not valid for integer values of \\spad{v}.")) (|besselJ| (((|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) "\\spad{besselJ(v,{}x)} is the Bessel function of the first kind,{} \\spad{J(v,{}x)}. This function satisfies the differential equation: \\indented{2}{\\spad{x^2 w''(x) + x w'(x) + (x^2-v^2)w(x) = 0}.}") (((|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) "\\spad{besselJ(v,{}x)} is the Bessel function of the first kind,{} \\spad{J(v,{}x)}. This function satisfies the differential equation: \\indented{2}{\\spad{x^2 w''(x) + x w'(x) + (x^2-v^2)w(x) = 0}.}")) (|polygamma| (((|Complex| (|DoubleFloat|)) (|NonNegativeInteger|) (|Complex| (|DoubleFloat|))) "\\spad{polygamma(n,{} x)} is the \\spad{n}-th derivative of \\spad{digamma(x)}.") (((|DoubleFloat|) (|NonNegativeInteger|) (|DoubleFloat|)) "\\spad{polygamma(n,{} x)} is the \\spad{n}-th derivative of \\spad{digamma(x)}.")) (|digamma| (((|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) "\\spad{digamma(x)} is the function,{} \\spad{psi(x)},{} defined by \\indented{2}{\\spad{psi(x) = Gamma'(x)/Gamma(x)}.}") (((|DoubleFloat|) (|DoubleFloat|)) "\\spad{digamma(x)} is the function,{} \\spad{psi(x)},{} defined by \\indented{2}{\\spad{psi(x) = Gamma'(x)/Gamma(x)}.}")) (|logGamma| (((|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) "\\spad{logGamma(x)} is the natural log of \\spad{Gamma(x)}. This can often be computed even if \\spad{Gamma(x)} cannot.") (((|DoubleFloat|) (|DoubleFloat|)) "\\spad{logGamma(x)} is the natural log of \\spad{Gamma(x)}. This can often be computed even if \\spad{Gamma(x)} cannot.")) (|Beta| (((|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) "\\spad{Beta(x,{} y)} is the Euler beta function,{} \\spad{B(x,{}y)},{} defined by \\indented{2}{\\spad{Beta(x,{}y) = integrate(t^(x-1)*(1-t)^(y-1),{} t=0..1)}.} This is related to \\spad{Gamma(x)} by \\indented{2}{\\spad{Beta(x,{}y) = Gamma(x)*Gamma(y) / Gamma(x + y)}.}") (((|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) "\\spad{Beta(x,{} y)} is the Euler beta function,{} \\spad{B(x,{}y)},{} defined by \\indented{2}{\\spad{Beta(x,{}y) = integrate(t^(x-1)*(1-t)^(y-1),{} t=0..1)}.} This is related to \\spad{Gamma(x)} by \\indented{2}{\\spad{Beta(x,{}y) = Gamma(x)*Gamma(y) / Gamma(x + y)}.}")) (|Ei6| (((|OnePointCompletion| (|DoubleFloat|)) (|OnePointCompletion| (|DoubleFloat|))) "\\spad{Ei6} is the first approximation of \\spad{Ei} where the result is \\spad{x*}\\%e^-x*Ei(\\spad{x}) from 32 to infinity (preserves digits)")) (|Ei5| (((|OnePointCompletion| (|DoubleFloat|)) (|OnePointCompletion| (|DoubleFloat|))) "\\spad{Ei5} is the first approximation of \\spad{Ei} where the result is \\spad{x*}\\%e^-x*Ei(\\spad{x}) from 12 to 32 (preserves digits)")) (|Ei4| (((|OnePointCompletion| (|DoubleFloat|)) (|OnePointCompletion| (|DoubleFloat|))) "\\spad{Ei4} is the first approximation of \\spad{Ei} where the result is \\spad{x*}\\%e^-x*Ei(\\spad{x}) from 4 to 12 (preserves digits)")) (|Ei3| (((|OnePointCompletion| (|DoubleFloat|)) (|OnePointCompletion| (|DoubleFloat|))) "\\spad{Ei3} is the first approximation of \\spad{Ei} where the result is (\\spad{Ei}(\\spad{x})-log \\spad{|x|} - gamma)\\spad{/x} from \\spad{-4} to 4 (preserves digits)")) (|Ei2| (((|OnePointCompletion| (|DoubleFloat|)) (|OnePointCompletion| (|DoubleFloat|))) "\\spad{Ei2} is the first approximation of \\spad{Ei} where the result is \\spad{x*}\\%e^-x*Ei(\\spad{x}) from \\spad{-10} to \\spad{-4} (preserves digits)")) (|Ei1| (((|OnePointCompletion| (|DoubleFloat|)) (|OnePointCompletion| (|DoubleFloat|))) "\\spad{Ei1} is the first approximation of \\spad{Ei} where the result is \\spad{x*}\\%e^-x*Ei(\\spad{x}) from -infinity to \\spad{-10} (preserves digits)")) (|Ei| (((|OnePointCompletion| (|DoubleFloat|)) (|OnePointCompletion| (|DoubleFloat|))) "\\spad{Ei} is the Exponential Integral function This is computed using a 6 part piecewise approximation. DoubleFloat can only preserve about 16 digits but the Chebyshev approximation used can give 30 digits.")) (|En| (((|OnePointCompletion| (|DoubleFloat|)) (|Integer|) (|DoubleFloat|)) "\\spad{En(n,{}x)} is the \\spad{n}th Exponential Integral Function")) (E1 (((|OnePointCompletion| (|DoubleFloat|)) (|DoubleFloat|)) "\\spad{E1(x)} is the Exponential Integral function The current implementation is a piecewise approximation involving one poly from \\spad{-4}..4 and a second poly for \\spad{x} > 4")) (|Gamma| (((|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|))) "\\spad{Gamma(x)} is the Euler gamma function,{} \\spad{Gamma(x)},{} defined by \\indented{2}{\\spad{Gamma(x) = integrate(t^(x-1)*exp(-t),{} t=0..\\%infinity)}.}") (((|DoubleFloat|) (|DoubleFloat|)) "\\spad{Gamma(x)} is the Euler gamma function,{} \\spad{Gamma(x)},{} defined by \\indented{2}{\\spad{Gamma(x) = integrate(t^(x-1)*exp(-t),{} t=0..\\%infinity)}.}"))) 
 NIL 
 NIL 
 (-218) 
 ((|constructor| (NIL "This is a low-level domain which implements vectors (one dimensional arrays) of double precision floating point numbers. Indexing is 0 based,{} there is no bound checking (unless provided by lower level).")) (|qnew| (($ (|Integer|)) "\\indented{1}{qnew(\\spad{n}) creates a new uninitialized vector of length \\spad{n}.} \\blankline \\spad{X} t1:DFVEC:=qnew(7)"))) 
-((-4520 . T) (-4519 . T)) 
-((|HasCategory| (-215) (QUOTE (-1090))) (|HasCategory| (-215) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-215) (QUOTE (-842))) (-2198 (|HasCategory| (-215) (QUOTE (-842))) (|HasCategory| (-215) (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (|HasCategory| (-215) (QUOTE (-25))) (|HasCategory| (-215) (QUOTE (-23))) (|HasCategory| (-215) (QUOTE (-21))) (|HasCategory| (-215) (QUOTE (-716))) (|HasCategory| (-215) (QUOTE (-1047))) (-12 (|HasCategory| (-215) (QUOTE (-1002))) (|HasCategory| (-215) (QUOTE (-1047)))) (-12 (|HasCategory| (-215) (LIST (QUOTE -303) (QUOTE (-215)))) (|HasCategory| (-215) (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| (-215) (LIST (QUOTE -303) (QUOTE (-215)))) (|HasCategory| (-215) (QUOTE (-842)))) (-12 (|HasCategory| (-215) (LIST (QUOTE -303) (QUOTE (-215)))) (|HasCategory| (-215) (QUOTE (-1090)))))) 
+((-4522 . T) (-4521 . T)) 
+((|HasCategory| (-215) (QUOTE (-1090))) (|HasCategory| (-215) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-215) (QUOTE (-842))) (-2199 (|HasCategory| (-215) (QUOTE (-842))) (|HasCategory| (-215) (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (|HasCategory| (-215) (QUOTE (-25))) (|HasCategory| (-215) (QUOTE (-23))) (|HasCategory| (-215) (QUOTE (-21))) (|HasCategory| (-215) (QUOTE (-716))) (|HasCategory| (-215) (QUOTE (-1047))) (-12 (|HasCategory| (-215) (QUOTE (-1002))) (|HasCategory| (-215) (QUOTE (-1047)))) (-12 (|HasCategory| (-215) (LIST (QUOTE -303) (QUOTE (-215)))) (|HasCategory| (-215) (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| (-215) (LIST (QUOTE -303) (QUOTE (-215)))) (|HasCategory| (-215) (QUOTE (-842)))) (-12 (|HasCategory| (-215) (LIST (QUOTE -303) (QUOTE (-215)))) (|HasCategory| (-215) (QUOTE (-1090)))))) 
 (-219 R) 
 ((|constructor| (NIL "4x4 Matrices for coordinate transformations\\spad{\\br} This package contains functions to create 4x4 matrices useful for rotating and transforming coordinate systems. These matrices are useful for graphics and robotics. (Reference: Robot Manipulators Richard Paul MIT Press 1981) \\blankline A Denavit-Hartenberg Matrix is a 4x4 Matrix of the form:\\spad{\\br} \\tab{5}\\spad{nx ox ax px}\\spad{\\br} \\tab{5}\\spad{ny oy ay py}\\spad{\\br} \\tab{5}\\spad{nz oz az pz}\\spad{\\br} \\tab{5}\\spad{0 0 0 1}\\spad{\\br} (\\spad{n},{} \\spad{o},{} and a are the direction cosines)")) (|translate| (($ |#1| |#1| |#1|) "\\spad{translate(x,{}y,{}z)} returns a dhmatrix for translation by \\spad{x},{} \\spad{y},{} and \\spad{z}")) (|scale| (($ |#1| |#1| |#1|) "\\spad{scale(sx,{}sy,{}sz)} returns a dhmatrix for scaling in the \\spad{x},{} \\spad{y} and \\spad{z} directions")) (|rotatez| (($ |#1|) "\\spad{rotatez(r)} returns a dhmatrix for rotation about axis \\spad{z} for \\spad{r} degrees")) (|rotatey| (($ |#1|) "\\spad{rotatey(r)} returns a dhmatrix for rotation about axis \\spad{y} for \\spad{r} degrees")) (|rotatex| (($ |#1|) "\\spad{rotatex(r)} returns a dhmatrix for rotation about axis \\spad{x} for \\spad{r} degrees")) (|identity| (($) "\\spad{identity()} create the identity dhmatrix")) (* (((|Point| |#1|) $ (|Point| |#1|)) "\\spad{t*p} applies the dhmatrix \\spad{t} to point \\spad{p}"))) 
-((-4519 . T) (-4520 . T)) 
-((|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-558))) (|HasAttribute| |#1| (QUOTE (-4521 "*"))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365)))) 
+((-4521 . T) (-4522 . T)) 
+((|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-558))) (|HasAttribute| |#1| (QUOTE (-4523 "*"))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365)))) 
 (-220 A S) 
 ((|constructor| (NIL "A dictionary is an aggregate in which entries can be inserted,{} searched for and removed. Duplicates are thrown away on insertion. This category models the usual notion of dictionary which involves large amounts of data where copying is impractical. Principal operations are thus destructive (non-copying) ones."))) 
 NIL 
 NIL 
 (-221 S) 
 ((|constructor| (NIL "A dictionary is an aggregate in which entries can be inserted,{} searched for and removed. Duplicates are thrown away on insertion. This category models the usual notion of dictionary which involves large amounts of data where copying is impractical. Principal operations are thus destructive (non-copying) ones."))) 
-((-4520 . T) (-3973 . T)) 
+((-4522 . T) (-3973 . T)) 
 NIL 
 (-222 S R) 
 ((|constructor| (NIL "Differential extensions of a ring \\spad{R}. Given a differentiation on \\spad{R},{} extend it to a differentiation on \\%.")) (D (($ $ (|Mapping| |#2| |#2|) (|NonNegativeInteger|)) "\\spad{D(x,{} deriv,{} n)} differentiate \\spad{x} \\spad{n} times using a derivation which extends \\spad{deriv} on \\spad{R}.") (($ $ (|Mapping| |#2| |#2|)) "\\spad{D(x,{} deriv)} differentiates \\spad{x} extending the derivation deriv on \\spad{R}.")) (|differentiate| (($ $ (|Mapping| |#2| |#2|) (|NonNegativeInteger|)) "\\spad{differentiate(x,{} deriv,{} n)} differentiate \\spad{x} \\spad{n} times using a derivation which extends \\spad{deriv} on \\spad{R}.") (($ $ (|Mapping| |#2| |#2|)) "\\spad{differentiate(x,{} deriv)} differentiates \\spad{x} extending the derivation deriv on \\spad{R}."))) 
@@ -822,7 +822,7 @@ NIL
 ((|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-225)))) 
 (-223 R) 
 ((|constructor| (NIL "Differential extensions of a ring \\spad{R}. Given a differentiation on \\spad{R},{} extend it to a differentiation on \\%.")) (D (($ $ (|Mapping| |#1| |#1|) (|NonNegativeInteger|)) "\\spad{D(x,{} deriv,{} n)} differentiate \\spad{x} \\spad{n} times using a derivation which extends \\spad{deriv} on \\spad{R}.") (($ $ (|Mapping| |#1| |#1|)) "\\spad{D(x,{} deriv)} differentiates \\spad{x} extending the derivation deriv on \\spad{R}.")) (|differentiate| (($ $ (|Mapping| |#1| |#1|) (|NonNegativeInteger|)) "\\spad{differentiate(x,{} deriv,{} n)} differentiate \\spad{x} \\spad{n} times using a derivation which extends \\spad{deriv} on \\spad{R}.") (($ $ (|Mapping| |#1| |#1|)) "\\spad{differentiate(x,{} deriv)} differentiates \\spad{x} extending the derivation deriv on \\spad{R}."))) 
-((-4516 . T)) 
+((-4518 . T)) 
 NIL 
 (-224 S) 
 ((|constructor| (NIL "An ordinary differential ring,{} that is,{} a ring with an operation \\spadfun{differentiate}. \\blankline Axioms\\spad{\\br} \\tab{5}\\spad{differentiate(x+y) = differentiate(x)+differentiate(y)}\\spad{\\br} \\tab{5}\\spad{differentiate(x*y) = x*differentiate(y) + differentiate(x)*y}")) (D (($ $ (|NonNegativeInteger|)) "\\spad{D(x,{} n)} returns the \\spad{n}-th derivative of \\spad{x}.") (($ $) "\\spad{D(x)} returns the derivative of \\spad{x}. This function is a simple differential operator where no variable needs to be specified.")) (|differentiate| (($ $ (|NonNegativeInteger|)) "\\spad{differentiate(x,{} n)} returns the \\spad{n}-th derivative of \\spad{x}.") (($ $) "\\spad{differentiate(x)} returns the derivative of \\spad{x}. This function is a simple differential operator where no variable needs to be specified."))) 
@@ -830,39 +830,39 @@ NIL
 NIL 
 (-225) 
 ((|constructor| (NIL "An ordinary differential ring,{} that is,{} a ring with an operation \\spadfun{differentiate}. \\blankline Axioms\\spad{\\br} \\tab{5}\\spad{differentiate(x+y) = differentiate(x)+differentiate(y)}\\spad{\\br} \\tab{5}\\spad{differentiate(x*y) = x*differentiate(y) + differentiate(x)*y}")) (D (($ $ (|NonNegativeInteger|)) "\\spad{D(x,{} n)} returns the \\spad{n}-th derivative of \\spad{x}.") (($ $) "\\spad{D(x)} returns the derivative of \\spad{x}. This function is a simple differential operator where no variable needs to be specified.")) (|differentiate| (($ $ (|NonNegativeInteger|)) "\\spad{differentiate(x,{} n)} returns the \\spad{n}-th derivative of \\spad{x}.") (($ $) "\\spad{differentiate(x)} returns the derivative of \\spad{x}. This function is a simple differential operator where no variable needs to be specified."))) 
-((-4516 . T)) 
+((-4518 . T)) 
 NIL 
 (-226 A S) 
 ((|constructor| (NIL "This category is a collection of operations common to both categories \\spadtype{Dictionary} and \\spadtype{MultiDictionary}")) (|select!| (($ (|Mapping| (|Boolean|) |#2|) $) "\\spad{select!(p,{}d)} destructively changes dictionary \\spad{d} by removing all entries \\spad{x} such that \\axiom{\\spad{p}(\\spad{x})} is not \\spad{true}.")) (|remove!| (($ (|Mapping| (|Boolean|) |#2|) $) "\\spad{remove!(p,{}d)} destructively changes dictionary \\spad{d} by removeing all entries \\spad{x} such that \\axiom{\\spad{p}(\\spad{x})} is \\spad{true}.") (($ |#2| $) "\\spad{remove!(x,{}d)} destructively changes dictionary \\spad{d} by removing all entries \\spad{y} such that \\axiom{\\spad{y} = \\spad{x}}.")) (|dictionary| (($ (|List| |#2|)) "\\spad{dictionary([x,{}y,{}...,{}z])} creates a dictionary consisting of entries \\axiom{\\spad{x},{}\\spad{y},{}...,{}\\spad{z}}.") (($) "\\spad{dictionary()}\\$\\spad{D} creates an empty dictionary of type \\spad{D}."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE -4519))) 
+((|HasAttribute| |#1| (QUOTE -4521))) 
 (-227 S) 
 ((|constructor| (NIL "This category is a collection of operations common to both categories \\spadtype{Dictionary} and \\spadtype{MultiDictionary}")) (|select!| (($ (|Mapping| (|Boolean|) |#1|) $) "\\spad{select!(p,{}d)} destructively changes dictionary \\spad{d} by removing all entries \\spad{x} such that \\axiom{\\spad{p}(\\spad{x})} is not \\spad{true}.")) (|remove!| (($ (|Mapping| (|Boolean|) |#1|) $) "\\spad{remove!(p,{}d)} destructively changes dictionary \\spad{d} by removeing all entries \\spad{x} such that \\axiom{\\spad{p}(\\spad{x})} is \\spad{true}.") (($ |#1| $) "\\spad{remove!(x,{}d)} destructively changes dictionary \\spad{d} by removing all entries \\spad{y} such that \\axiom{\\spad{y} = \\spad{x}}.")) (|dictionary| (($ (|List| |#1|)) "\\spad{dictionary([x,{}y,{}...,{}z])} creates a dictionary consisting of entries \\axiom{\\spad{x},{}\\spad{y},{}...,{}\\spad{z}}.") (($) "\\spad{dictionary()}\\$\\spad{D} creates an empty dictionary of type \\spad{D}."))) 
-((-4520 . T) (-3973 . T)) 
+((-4522 . T) (-3973 . T)) 
 NIL 
 (-228) 
 ((|constructor| (NIL "Any solution of a homogeneous linear Diophantine equation can be represented as a sum of minimal solutions,{} which form a \"basis\" (a minimal solution cannot be represented as a nontrivial sum of solutions) in the case of an inhomogeneous linear Diophantine equation,{} each solution is the sum of a inhomogeneous solution and any number of homogeneous solutions therefore,{} it suffices to compute two sets:\\spad{\\br} \\tab{5}1. all minimal inhomogeneous solutions\\spad{\\br} \\tab{5}2. all minimal homogeneous solutions\\spad{\\br} the algorithm implemented is a completion procedure,{} which enumerates all solutions in a recursive depth-first-search it can be seen as finding monotone paths in a graph for more details see Reference")) (|dioSolve| (((|Record| (|:| |varOrder| (|List| (|Symbol|))) (|:| |inhom| (|Union| (|List| (|Vector| (|NonNegativeInteger|))) "failed")) (|:| |hom| (|List| (|Vector| (|NonNegativeInteger|))))) (|Equation| (|Polynomial| (|Integer|)))) "\\spad{dioSolve(u)} computes a basis of all minimal solutions for linear homogeneous Diophantine equation \\spad{u},{} then all minimal solutions of inhomogeneous equation"))) 
 NIL 
 NIL 
-(-229 S -2570 R) 
+(-229 S -1965 R) 
 ((|constructor| (NIL "This category represents a finite cartesian product of a given type. Many categorical properties are preserved under this construction.")) (|dot| ((|#3| $ $) "\\spad{dot(x,{}y)} computes the inner product of the vectors \\spad{x} and \\spad{y}.")) (|unitVector| (($ (|PositiveInteger|)) "\\spad{unitVector(n)} produces a vector with 1 in position \\spad{n} and zero elsewhere.")) (|directProduct| (($ (|Vector| |#3|)) "\\spad{directProduct(v)} converts the vector \\spad{v} to become a direct product. Error: if the length of \\spad{v} is different from dim.")) (|finiteAggregate| ((|attribute|) "attribute to indicate an aggregate of finite size"))) 
 NIL 
-((|HasCategory| |#3| (QUOTE (-365))) (|HasCategory| |#3| (QUOTE (-788))) (|HasCategory| |#3| (QUOTE (-840))) (|HasAttribute| |#3| (QUOTE -4516)) (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-370))) (|HasCategory| |#3| (QUOTE (-716))) (|HasCategory| |#3| (QUOTE (-137))) (|HasCategory| |#3| (QUOTE (-25))) (|HasCategory| |#3| (QUOTE (-1047))) (|HasCategory| |#3| (QUOTE (-1090)))) 
-(-230 -2570 R) 
+((|HasCategory| |#3| (QUOTE (-365))) (|HasCategory| |#3| (QUOTE (-788))) (|HasCategory| |#3| (QUOTE (-840))) (|HasAttribute| |#3| (QUOTE -4518)) (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-370))) (|HasCategory| |#3| (QUOTE (-716))) (|HasCategory| |#3| (QUOTE (-137))) (|HasCategory| |#3| (QUOTE (-25))) (|HasCategory| |#3| (QUOTE (-1047))) (|HasCategory| |#3| (QUOTE (-1090)))) 
+(-230 -1965 R) 
 ((|constructor| (NIL "This category represents a finite cartesian product of a given type. Many categorical properties are preserved under this construction.")) (|dot| ((|#2| $ $) "\\spad{dot(x,{}y)} computes the inner product of the vectors \\spad{x} and \\spad{y}.")) (|unitVector| (($ (|PositiveInteger|)) "\\spad{unitVector(n)} produces a vector with 1 in position \\spad{n} and zero elsewhere.")) (|directProduct| (($ (|Vector| |#2|)) "\\spad{directProduct(v)} converts the vector \\spad{v} to become a direct product. Error: if the length of \\spad{v} is different from dim.")) (|finiteAggregate| ((|attribute|) "attribute to indicate an aggregate of finite size"))) 
-((-4513 |has| |#2| (-1047)) (-4514 |has| |#2| (-1047)) (-4516 |has| |#2| (-6 -4516)) ((-4521 "*") |has| |#2| (-172)) (-4519 . T) (-3973 . T)) 
+((-4515 |has| |#2| (-1047)) (-4516 |has| |#2| (-1047)) (-4518 |has| |#2| (-6 -4518)) ((-4523 "*") |has| |#2| (-172)) (-4521 . T) (-3973 . T)) 
 NIL 
-(-231 -2570 A B) 
+(-231 -1965 A B) 
 ((|constructor| (NIL "This package provides operations which all take as arguments direct products of elements of some type \\spad{A} and functions from \\spad{A} to another type \\spad{B}. The operations all iterate over their vector argument and either return a value of type \\spad{B} or a direct product over \\spad{B}.")) (|map| (((|DirectProduct| |#1| |#3|) (|Mapping| |#3| |#2|) (|DirectProduct| |#1| |#2|)) "\\spad{map(f,{} v)} applies the function \\spad{f} to every element of the vector \\spad{v} producing a new vector containing the values.")) (|reduce| ((|#3| (|Mapping| |#3| |#2| |#3|) (|DirectProduct| |#1| |#2|) |#3|) "\\spad{reduce(func,{}vec,{}ident)} combines the elements in \\spad{vec} using the binary function \\spad{func}. Argument \\spad{ident} is returned if the vector is empty.")) (|scan| (((|DirectProduct| |#1| |#3|) (|Mapping| |#3| |#2| |#3|) (|DirectProduct| |#1| |#2|) |#3|) "\\spad{scan(func,{}vec,{}ident)} creates a new vector whose elements are the result of applying reduce to the binary function \\spad{func},{} increasing initial subsequences of the vector \\spad{vec},{} and the element \\spad{ident}."))) 
 NIL 
 NIL 
-(-232 -2570 R) 
+(-232 -1965 R) 
 ((|constructor| (NIL "This type represents the finite direct or cartesian product of an underlying component type. This contrasts with simple vectors in that the members can be viewed as having constant length. Thus many categorical properties can by lifted from the underlying component type. Component extraction operations are provided but no updating operations. Thus new direct product elements can either be created by converting vector elements using the \\spadfun{directProduct} function or by taking appropriate linear combinations of basis vectors provided by the \\spad{unitVector} operation."))) 
-((-4513 |has| |#2| (-1047)) (-4514 |has| |#2| (-1047)) (-4516 |has| |#2| (-6 -4516)) ((-4521 "*") |has| |#2| (-172)) (-4519 . T)) 
-((|HasCategory| |#2| (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047))) (|HasCategory| |#2| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-840))) (-2198 (|HasCategory| |#2| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-840)))) (|HasCategory| |#2| (QUOTE (-716))) (|HasCategory| |#2| (QUOTE (-172))) (-2198 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (-2198 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-365)))) (-2198 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-1047)))) (|HasCategory| |#2| (QUOTE (-370))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-225))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-1047)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1090)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-1090)))) (|HasAttribute| |#2| (QUOTE -4516)) (|HasCategory| |#2| (QUOTE (-137))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (|HasCategory| |#2| (QUOTE (-25))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-370))) (|HasCategory| |#2| (QUOTE (-716))) (|HasCategory| |#2| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-840))) (|HasCategory| |#2| (QUOTE (-1047))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (-2198 (-12 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-172)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-365)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-370)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-716)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-788)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-840)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-1090))))) (-2198 (-12 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-172)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-365)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-370)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-716)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-788)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-840)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1090))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-172)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-365)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-370)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-716)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-788)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-840)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))))) 
+((-4515 |has| |#2| (-1047)) (-4516 |has| |#2| (-1047)) (-4518 |has| |#2| (-6 -4518)) ((-4523 "*") |has| |#2| (-172)) (-4521 . T)) 
+((|HasCategory| |#2| (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047))) (|HasCategory| |#2| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-840))) (-2199 (|HasCategory| |#2| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-840)))) (|HasCategory| |#2| (QUOTE (-716))) (|HasCategory| |#2| (QUOTE (-172))) (-2199 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (-2199 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-365)))) (-2199 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-1047)))) (|HasCategory| |#2| (QUOTE (-370))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-225))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-1047)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1090)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-1090)))) (|HasAttribute| |#2| (QUOTE -4518)) (|HasCategory| |#2| (QUOTE (-137))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (|HasCategory| |#2| (QUOTE (-25))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-370))) (|HasCategory| |#2| (QUOTE (-716))) (|HasCategory| |#2| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-840))) (|HasCategory| |#2| (QUOTE (-1047))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (-2199 (-12 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-172)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-365)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-370)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-716)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-788)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-840)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-1090))))) (-2199 (-12 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-172)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-365)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-370)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-716)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-788)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-840)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1090))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-172)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-365)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-370)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-716)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-788)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-840)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))))) 
 (-233 |Coef|) 
 ((|constructor| (NIL "DirichletRing is the ring of arithmetical functions with Dirichlet convolution as multiplication")) (|additive?| (((|Boolean|) $ (|PositiveInteger|)) "\\spad{additive?(a,{} n)} returns \\spad{true} if the first \\spad{n} coefficients of a are additive")) (|multiplicative?| (((|Boolean|) $ (|PositiveInteger|)) "\\spad{multiplicative?(a,{} n)} returns \\spad{true} if the first \\spad{n} coefficients of a are multiplicative")) (|zeta| (($) "\\spad{zeta()} returns the function which is constantly one"))) 
-((-4514 |has| |#1| (-172)) (-4513 |has| |#1| (-172)) ((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-172)) (-4516 . T)) 
+((-4516 |has| |#1| (-172)) (-4515 |has| |#1| (-172)) ((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-172)) (-4518 . T)) 
 ((|HasCategory| |#1| (QUOTE (-172)))) 
 (-234) 
 ((|constructor| (NIL "DisplayPackage allows one to print strings in a nice manner,{} including highlighting substrings.")) (|sayLength| (((|Integer|) (|List| (|String|))) "\\spad{sayLength(l)} returns the length of a list of strings \\spad{l} as an integer.") (((|Integer|) (|String|)) "\\spad{sayLength(s)} returns the length of a string \\spad{s} as an integer.")) (|say| (((|Void|) (|List| (|String|))) "\\spad{say(l)} sends a list of strings \\spad{l} to output.") (((|Void|) (|String|)) "\\spad{say(s)} sends a string \\spad{s} to output.")) (|center| (((|List| (|String|)) (|List| (|String|)) (|Integer|) (|String|)) "\\spad{center(l,{}i,{}s)} takes a list of strings \\spad{l},{} and centers them within a list of strings which is \\spad{i} characters long,{} in which the remaining spaces are filled with strings composed of as many repetitions as possible of the last string parameter \\spad{s}.") (((|String|) (|String|) (|Integer|) (|String|)) "\\spad{center(s,{}i,{}s)} takes the first string \\spad{s},{} and centers it within a string of length \\spad{i},{} in which the other elements of the string are composed of as many replications as possible of the second indicated string,{} \\spad{s} which must have a length greater than that of an empty string.")) (|copies| (((|String|) (|Integer|) (|String|)) "\\spad{copies(i,{}s)} will take a string \\spad{s} and create a new string composed of \\spad{i} copies of \\spad{s}.")) (|newLine| (((|String|)) "\\spad{newLine()} sends a new line command to output.")) (|bright| (((|List| (|String|)) (|List| (|String|))) "\\spad{bright(l)} sets the font property of a list of strings,{} \\spad{l},{} to bold-face type.") (((|List| (|String|)) (|String|)) "\\spad{bright(s)} sets the font property of the string \\spad{s} to bold-face type."))) 
@@ -870,11 +870,11 @@ NIL
 NIL 
 (-235 S) 
 ((|constructor| (NIL "This category exports the function for domains")) (|divOfPole| (($ $) "\\spad{divOfPole(d)} returns the negative part of \\spad{d}.")) (|divOfZero| (($ $) "\\spad{divOfZero(d)} returns the positive part of \\spad{d}.")) (|suppOfPole| (((|List| |#1|) $) "suppOfZero(\\spad{d}) returns the elements of the support of \\spad{d} that have a negative coefficient.")) (|suppOfZero| (((|List| |#1|) $) "\\spad{suppOfZero(d)} returns the elements of the support of \\spad{d} that have a positive coefficient.")) (|supp| (((|List| |#1|) $) "\\spad{supp(d)} returns the support of the divisor \\spad{d}.")) (|effective?| (((|Boolean|) $) "\\spad{effective?(d)} returns \\spad{true} if \\spad{d} \\spad{>=} 0.")) (|concat| (($ $ $) "\\spad{concat(a,{}b)} concats the divisor a and \\spad{b} without collecting the duplicative points.")) (|collect| (($ $) "\\spad{collect collects} the duplicative points in the divisor.")) (|split| (((|List| $) $) "\\spad{split(d)} splits the divisor \\spad{d}. For example,{} split( 2 \\spad{p1} + 3p2 ) returns the list [ 2 \\spad{p1},{} 3 \\spad{p2} ].")) (|degree| (((|Integer|) $) "\\spad{degree(d)} returns the degree of the divisor \\spad{d}"))) 
-((-4514 . T) (-4513 . T)) 
+((-4516 . T) (-4515 . T)) 
 NIL 
 (-236 S) 
 ((|constructor| (NIL "The following is part of the PAFF package"))) 
-((-4514 . T) (-4513 . T)) 
+((-4516 . T) (-4515 . T)) 
 ((|HasCategory| (-568) (QUOTE (-787)))) 
 (-237 S) 
 ((|constructor| (NIL "A division ring (sometimes called a skew field),{} \\spadignore{i.e.} a not necessarily commutative ring where all non-zero elements have multiplicative inverses.")) (|inv| (($ $) "\\spad{inv x} returns the multiplicative inverse of \\spad{x}. Error: if \\spad{x} is 0.")) (^ (($ $ (|Integer|)) "\\spad{x^n} returns \\spad{x} raised to the integer power \\spad{n}.")) (** (($ $ (|Integer|)) "\\spad{x**n} returns \\spad{x} raised to the integer power \\spad{n}."))) 
@@ -882,7 +882,7 @@ NIL
 NIL 
 (-238) 
 ((|constructor| (NIL "A division ring (sometimes called a skew field),{} \\spadignore{i.e.} a not necessarily commutative ring where all non-zero elements have multiplicative inverses.")) (|inv| (($ $) "\\spad{inv x} returns the multiplicative inverse of \\spad{x}. Error: if \\spad{x} is 0.")) (^ (($ $ (|Integer|)) "\\spad{x^n} returns \\spad{x} raised to the integer power \\spad{n}.")) (** (($ $ (|Integer|)) "\\spad{x**n} returns \\spad{x} raised to the integer power \\spad{n}."))) 
-((-4512 . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4514 . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-239 S) 
 ((|constructor| (NIL "A doubly-linked aggregate serves as a model for a doubly-linked list,{} that is,{} a list which can has links to both next and previous nodes and thus can be efficiently traversed in both directions.")) (|setnext!| (($ $ $) "\\spad{setnext!(u,{}v)} destructively sets the next node of doubly-linked aggregate \\spad{u} to \\spad{v},{} returning \\spad{v}.")) (|setprevious!| (($ $ $) "\\spad{setprevious!(u,{}v)} destructively sets the previous node of doubly-linked aggregate \\spad{u} to \\spad{v},{} returning \\spad{v}.")) (|concat!| (($ $ $) "\\spad{concat!(u,{}v)} destructively concatenates doubly-linked aggregate \\spad{v} to the end of doubly-linked aggregate \\spad{u}.")) (|next| (($ $) "\\spad{next(l)} returns the doubly-linked aggregate beginning with its next element. Error: if \\spad{l} has no next element. Note that \\axiom{next(\\spad{l}) = rest(\\spad{l})} and \\axiom{previous(next(\\spad{l})) = \\spad{l}}.")) (|previous| (($ $) "\\spad{previous(l)} returns the doubly-link list beginning with its previous element. Error: if \\spad{l} has no previous element. Note that \\axiom{next(previous(\\spad{l})) = \\spad{l}}.")) (|tail| (($ $) "\\spad{tail(l)} returns the doubly-linked aggregate \\spad{l} starting at its second element. Error: if \\spad{l} is empty.")) (|head| (($ $) "\\spad{head(l)} returns the first element of a doubly-linked aggregate \\spad{l}. Error: if \\spad{l} is empty.")) (|last| ((|#1| $) "\\spad{last(l)} returns the last element of a doubly-linked aggregate \\spad{l}. Error: if \\spad{l} is empty."))) 
@@ -890,35 +890,35 @@ NIL
 NIL 
 (-240 S) 
 ((|constructor| (NIL "This domain provides some nice functions on lists")) (|elt| (((|NonNegativeInteger|) $ "count") "\\axiom{\\spad{l}.\"count\"} returns the number of elements in \\axiom{\\spad{l}}.") (($ $ "sort") "\\axiom{\\spad{l}.sort} returns \\axiom{\\spad{l}} with elements sorted. Note: \\axiom{\\spad{l}.sort = sort(\\spad{l})}") (($ $ "unique") "\\axiom{\\spad{l}.unique} returns \\axiom{\\spad{l}} with duplicates removed. Note: \\axiom{\\spad{l}.unique = removeDuplicates(\\spad{l})}.")) (|datalist| (($ (|List| |#1|)) "\\spad{datalist(l)} creates a datalist from \\spad{l}")) (|coerce| (((|List| |#1|) $) "\\spad{coerce(x)} returns the list of elements in \\spad{x}") (($ (|List| |#1|)) "\\spad{coerce(l)} creates a datalist from \\spad{l}"))) 
-((-4520 . T) (-4519 . T)) 
-((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (-2198 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
+((-4522 . T) (-4521 . T)) 
+((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (-2199 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
 (-241 M) 
 ((|constructor| (NIL "DiscreteLogarithmPackage implements help functions for discrete logarithms in monoids using small cyclic groups.")) (|shanksDiscLogAlgorithm| (((|Union| (|NonNegativeInteger|) "failed") |#1| |#1| (|NonNegativeInteger|)) "\\spad{shanksDiscLogAlgorithm(b,{}a,{}p)} computes \\spad{s} with \\spad{b**s = a} for assuming that \\spad{a} and \\spad{b} are elements in a 'small' cyclic group of order \\spad{p} by Shank\\spad{'s} algorithm. Note that this is a subroutine of the function \\spadfun{discreteLog}.")) (** ((|#1| |#1| (|Integer|)) "\\spad{x ** n} returns \\spad{x} raised to the integer power \\spad{n}"))) 
 NIL 
 NIL 
 (-242 |vl| R) 
 ((|constructor| (NIL "This type supports distributed multivariate polynomials whose variables are from a user specified list of symbols. The coefficient ring may be non commutative,{} but the variables are assumed to commute. The term ordering is lexicographic specified by the variable list parameter with the most significant variable first in the list.")) (|reorder| (($ $ (|List| (|Integer|))) "\\spad{reorder(p,{} perm)} applies the permutation perm to the variables in a polynomial and returns the new correctly ordered polynomial"))) 
-(((-4521 "*") |has| |#2| (-172)) (-4512 |has| |#2| (-558)) (-4517 |has| |#2| (-6 -4517)) (-4514 . T) (-4513 . T) (-4516 . T)) 
-((|HasCategory| |#2| (QUOTE (-904))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-172))) (-2198 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-558)))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#2| (QUOTE (-842))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-365))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#2| (QUOTE -4517)) (|HasCategory| |#2| (QUOTE (-453))) (-2198 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2198 (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2198 (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (|HasCategory| |#2| (QUOTE (-148))))) 
+(((-4523 "*") |has| |#2| (-172)) (-4514 |has| |#2| (-558)) (-4519 |has| |#2| (-6 -4519)) (-4516 . T) (-4515 . T) (-4518 . T)) 
+((|HasCategory| |#2| (QUOTE (-904))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-172))) (-2199 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-558)))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#2| (QUOTE (-842))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-365))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#2| (QUOTE -4519)) (|HasCategory| |#2| (QUOTE (-453))) (-2199 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2199 (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2199 (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (|HasCategory| |#2| (QUOTE (-148))))) 
 (-243 |n| R M S) 
 ((|constructor| (NIL "This constructor provides a direct product type with a left matrix-module view."))) 
-((-4516 -2198 (-2139 (|has| |#4| (-1047)) (|has| |#4| (-225))) (-2139 (|has| |#4| (-1047)) (|has| |#4| (-895 (-1161)))) (|has| |#4| (-6 -4516)) (-2139 (|has| |#4| (-1047)) (|has| |#4| (-630 (-568))))) (-4513 |has| |#4| (-1047)) (-4514 |has| |#4| (-1047)) ((-4521 "*") |has| |#4| (-172)) (-4519 . T)) 
-((|HasCategory| |#4| (QUOTE (-365))) (|HasCategory| |#4| (QUOTE (-1047))) (|HasCategory| |#4| (QUOTE (-788))) (|HasCategory| |#4| (QUOTE (-840))) (-2198 (|HasCategory| |#4| (QUOTE (-788))) (|HasCategory| |#4| (QUOTE (-840)))) (|HasCategory| |#4| (QUOTE (-716))) (|HasCategory| |#4| (QUOTE (-172))) (-2198 (|HasCategory| |#4| (QUOTE (-172))) (|HasCategory| |#4| (QUOTE (-365))) (|HasCategory| |#4| (QUOTE (-1047)))) (-2198 (|HasCategory| |#4| (QUOTE (-172))) (|HasCategory| |#4| (QUOTE (-365)))) (-2198 (|HasCategory| |#4| (QUOTE (-172))) (|HasCategory| |#4| (QUOTE (-1047)))) (|HasCategory| |#4| (QUOTE (-370))) (|HasCategory| |#4| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#4| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#4| (QUOTE (-225))) (-2198 (|HasCategory| |#4| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#4| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#4| (QUOTE (-172))) (|HasCategory| |#4| (QUOTE (-225))) (|HasCategory| |#4| (QUOTE (-1047)))) (|HasCategory| |#4| (QUOTE (-1090))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#4| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-1047)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#4| (QUOTE (-1047)))) (-12 (|HasCategory| |#4| (QUOTE (-225))) (|HasCategory| |#4| (QUOTE (-1047)))) (-2198 (-12 (|HasCategory| |#4| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-1047)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#4| (QUOTE (-1047)))) (-12 (|HasCategory| |#4| (QUOTE (-225))) (|HasCategory| |#4| (QUOTE (-1047)))) (|HasCategory| |#4| (QUOTE (-716)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#4| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-172)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-225)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-365)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-370)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-716)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-788)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-840)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-1047)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-1090))))) (-2198 (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-1090)))) (|HasCategory| |#4| (QUOTE (-1047)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#4| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#4| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#4| (QUOTE (-172)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#4| (QUOTE (-225)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#4| (QUOTE (-365)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#4| (QUOTE (-370)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#4| (QUOTE (-716)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#4| (QUOTE (-788)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#4| (QUOTE (-840)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#4| (QUOTE (-1047)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#4| (QUOTE (-1090))))) (-2198 (|HasAttribute| |#4| (QUOTE -4516)) (-12 (|HasCategory| |#4| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-1047)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#4| (QUOTE (-1047)))) (-12 (|HasCategory| |#4| (QUOTE (-225))) (|HasCategory| |#4| (QUOTE (-1047))))) (|HasCategory| |#4| (QUOTE (-137))) (|HasCategory| |#4| (QUOTE (-25))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (LIST (QUOTE -630) (QUOTE (-568))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (LIST (QUOTE -895) (QUOTE (-1161))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-172)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-225)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-365)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-370)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-716)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-788)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-840)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1047)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1090)))))) 
+((-4518 -2199 (-2141 (|has| |#4| (-1047)) (|has| |#4| (-225))) (-2141 (|has| |#4| (-1047)) (|has| |#4| (-895 (-1161)))) (|has| |#4| (-6 -4518)) (-2141 (|has| |#4| (-1047)) (|has| |#4| (-630 (-568))))) (-4515 |has| |#4| (-1047)) (-4516 |has| |#4| (-1047)) ((-4523 "*") |has| |#4| (-172)) (-4521 . T)) 
+((|HasCategory| |#4| (QUOTE (-365))) (|HasCategory| |#4| (QUOTE (-1047))) (|HasCategory| |#4| (QUOTE (-788))) (|HasCategory| |#4| (QUOTE (-840))) (-2199 (|HasCategory| |#4| (QUOTE (-788))) (|HasCategory| |#4| (QUOTE (-840)))) (|HasCategory| |#4| (QUOTE (-716))) (|HasCategory| |#4| (QUOTE (-172))) (-2199 (|HasCategory| |#4| (QUOTE (-172))) (|HasCategory| |#4| (QUOTE (-365))) (|HasCategory| |#4| (QUOTE (-1047)))) (-2199 (|HasCategory| |#4| (QUOTE (-172))) (|HasCategory| |#4| (QUOTE (-365)))) (-2199 (|HasCategory| |#4| (QUOTE (-172))) (|HasCategory| |#4| (QUOTE (-1047)))) (|HasCategory| |#4| (QUOTE (-370))) (|HasCategory| |#4| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#4| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#4| (QUOTE (-225))) (-2199 (|HasCategory| |#4| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#4| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#4| (QUOTE (-172))) (|HasCategory| |#4| (QUOTE (-225))) (|HasCategory| |#4| (QUOTE (-1047)))) (|HasCategory| |#4| (QUOTE (-1090))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#4| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-1047)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#4| (QUOTE (-1047)))) (-12 (|HasCategory| |#4| (QUOTE (-225))) (|HasCategory| |#4| (QUOTE (-1047)))) (-2199 (-12 (|HasCategory| |#4| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-1047)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#4| (QUOTE (-1047)))) (-12 (|HasCategory| |#4| (QUOTE (-225))) (|HasCategory| |#4| (QUOTE (-1047)))) (|HasCategory| |#4| (QUOTE (-716)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#4| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-172)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-225)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-365)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-370)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-716)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-788)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-840)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-1047)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-1090))))) (-2199 (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-1090)))) (|HasCategory| |#4| (QUOTE (-1047)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#4| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#4| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#4| (QUOTE (-172)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#4| (QUOTE (-225)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#4| (QUOTE (-365)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#4| (QUOTE (-370)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#4| (QUOTE (-716)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#4| (QUOTE (-788)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#4| (QUOTE (-840)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#4| (QUOTE (-1047)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#4| (QUOTE (-1090))))) (-2199 (|HasAttribute| |#4| (QUOTE -4518)) (-12 (|HasCategory| |#4| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#4| (QUOTE (-1047)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#4| (QUOTE (-1047)))) (-12 (|HasCategory| |#4| (QUOTE (-225))) (|HasCategory| |#4| (QUOTE (-1047))))) (|HasCategory| |#4| (QUOTE (-137))) (|HasCategory| |#4| (QUOTE (-25))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (LIST (QUOTE -630) (QUOTE (-568))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (LIST (QUOTE -895) (QUOTE (-1161))))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-172)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-225)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-365)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-370)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-716)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-788)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-840)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1047)))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1090)))))) 
 (-244 |n| R S) 
 ((|constructor| (NIL "This constructor provides a direct product of \\spad{R}-modules with an \\spad{R}-module view."))) 
-((-4516 -2198 (-2139 (|has| |#3| (-1047)) (|has| |#3| (-225))) (-2139 (|has| |#3| (-1047)) (|has| |#3| (-895 (-1161)))) (|has| |#3| (-6 -4516)) (-2139 (|has| |#3| (-1047)) (|has| |#3| (-630 (-568))))) (-4513 |has| |#3| (-1047)) (-4514 |has| |#3| (-1047)) ((-4521 "*") |has| |#3| (-172)) (-4519 . T)) 
-((|HasCategory| |#3| (QUOTE (-365))) (|HasCategory| |#3| (QUOTE (-1047))) (|HasCategory| |#3| (QUOTE (-788))) (|HasCategory| |#3| (QUOTE (-840))) (-2198 (|HasCategory| |#3| (QUOTE (-788))) (|HasCategory| |#3| (QUOTE (-840)))) (|HasCategory| |#3| (QUOTE (-716))) (|HasCategory| |#3| (QUOTE (-172))) (-2198 (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-365))) (|HasCategory| |#3| (QUOTE (-1047)))) (-2198 (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-365)))) (-2198 (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-1047)))) (|HasCategory| |#3| (QUOTE (-370))) (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-225))) (-2198 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-225))) (|HasCategory| |#3| (QUOTE (-1047)))) (|HasCategory| |#3| (QUOTE (-1090))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (QUOTE (-225))) (|HasCategory| |#3| (QUOTE (-1047)))) (-2198 (-12 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (QUOTE (-225))) (|HasCategory| |#3| (QUOTE (-1047)))) (|HasCategory| |#3| (QUOTE (-716)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-172)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-225)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-365)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-370)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-716)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-788)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-840)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1090))))) (-2198 (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1090)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-172)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-225)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-365)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-370)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-716)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-788)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-840)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-1090))))) (-2198 (|HasAttribute| |#3| (QUOTE -4516)) (-12 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (QUOTE (-225))) (|HasCategory| |#3| (QUOTE (-1047))))) (|HasCategory| |#3| (QUOTE (-137))) (|HasCategory| |#3| (QUOTE (-25))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-172)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-225)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-365)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-370)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-716)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-788)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-840)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1090)))))) 
+((-4518 -2199 (-2141 (|has| |#3| (-1047)) (|has| |#3| (-225))) (-2141 (|has| |#3| (-1047)) (|has| |#3| (-895 (-1161)))) (|has| |#3| (-6 -4518)) (-2141 (|has| |#3| (-1047)) (|has| |#3| (-630 (-568))))) (-4515 |has| |#3| (-1047)) (-4516 |has| |#3| (-1047)) ((-4523 "*") |has| |#3| (-172)) (-4521 . T)) 
+((|HasCategory| |#3| (QUOTE (-365))) (|HasCategory| |#3| (QUOTE (-1047))) (|HasCategory| |#3| (QUOTE (-788))) (|HasCategory| |#3| (QUOTE (-840))) (-2199 (|HasCategory| |#3| (QUOTE (-788))) (|HasCategory| |#3| (QUOTE (-840)))) (|HasCategory| |#3| (QUOTE (-716))) (|HasCategory| |#3| (QUOTE (-172))) (-2199 (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-365))) (|HasCategory| |#3| (QUOTE (-1047)))) (-2199 (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-365)))) (-2199 (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-1047)))) (|HasCategory| |#3| (QUOTE (-370))) (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-225))) (-2199 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-225))) (|HasCategory| |#3| (QUOTE (-1047)))) (|HasCategory| |#3| (QUOTE (-1090))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (QUOTE (-225))) (|HasCategory| |#3| (QUOTE (-1047)))) (-2199 (-12 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (QUOTE (-225))) (|HasCategory| |#3| (QUOTE (-1047)))) (|HasCategory| |#3| (QUOTE (-716)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-172)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-225)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-365)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-370)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-716)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-788)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-840)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1090))))) (-2199 (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1090)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-172)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-225)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-365)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-370)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-716)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-788)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-840)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-1090))))) (-2199 (|HasAttribute| |#3| (QUOTE -4518)) (-12 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (QUOTE (-225))) (|HasCategory| |#3| (QUOTE (-1047))))) (|HasCategory| |#3| (QUOTE (-137))) (|HasCategory| |#3| (QUOTE (-25))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-172)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-225)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-365)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-370)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-716)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-788)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-840)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1090)))))) 
 (-245 A R S V E) 
 ((|constructor| (NIL "\\spadtype{DifferentialPolynomialCategory} is a category constructor specifying basic functions in an ordinary differential polynomial ring with a given ordered set of differential indeterminates. In addition,{} it implements defaults for the basic functions. The functions \\spadfun{order} and \\spadfun{weight} are extended from the set of derivatives of differential indeterminates to the set of differential polynomials. Other operations provided on differential polynomials are \\spadfun{leader},{} \\spadfun{initial},{} \\spadfun{separant},{} \\spadfun{differentialVariables},{} and \\spadfun{isobaric?}. Furthermore,{} if the ground ring is a differential ring,{} then evaluation (substitution of differential indeterminates by elements of the ground ring or by differential polynomials) is provided by \\spadfun{eval}. A convenient way of referencing derivatives is provided by the functions \\spadfun{makeVariable}. \\blankline To construct a domain using this constructor,{} one needs to provide a ground ring \\spad{R},{} an ordered set \\spad{S} of differential indeterminates,{} a ranking \\spad{V} on the set of derivatives of the differential indeterminates,{} and a set \\spad{E} of exponents in bijection with the set of differential monomials in the given differential indeterminates.")) (|separant| (($ $) "\\spad{separant(p)} returns the partial derivative of the differential polynomial \\spad{p} with respect to its leader.")) (|initial| (($ $) "\\spad{initial(p)} returns the leading coefficient when the differential polynomial \\spad{p} is written as a univariate polynomial in its leader.")) (|leader| ((|#4| $) "\\spad{leader(p)} returns the derivative of the highest rank appearing in the differential polynomial \\spad{p} Note that an error occurs if \\spad{p} is in the ground ring.")) (|isobaric?| (((|Boolean|) $) "\\spad{isobaric?(p)} returns \\spad{true} if every differential monomial appearing in the differential polynomial \\spad{p} has same weight,{} and returns \\spad{false} otherwise.")) (|weight| (((|NonNegativeInteger|) $ |#3|) "\\spad{weight(p,{} s)} returns the maximum weight of all differential monomials appearing in the differential polynomial \\spad{p} when \\spad{p} is viewed as a differential polynomial in the differential indeterminate \\spad{s} alone.") (((|NonNegativeInteger|) $) "\\spad{weight(p)} returns the maximum weight of all differential monomials appearing in the differential polynomial \\spad{p}.")) (|weights| (((|List| (|NonNegativeInteger|)) $ |#3|) "\\spad{weights(p,{} s)} returns a list of weights of differential monomials appearing in the differential polynomial \\spad{p} when \\spad{p} is viewed as a differential polynomial in the differential indeterminate \\spad{s} alone.") (((|List| (|NonNegativeInteger|)) $) "\\spad{weights(p)} returns a list of weights of differential monomials appearing in differential polynomial \\spad{p}.")) (|degree| (((|NonNegativeInteger|) $ |#3|) "\\spad{degree(p,{} s)} returns the maximum degree of the differential polynomial \\spad{p} viewed as a differential polynomial in the differential indeterminate \\spad{s} alone.")) (|order| (((|NonNegativeInteger|) $) "\\spad{order(p)} returns the order of the differential polynomial \\spad{p},{} which is the maximum number of differentiations of a differential indeterminate,{} among all those appearing in \\spad{p}.") (((|NonNegativeInteger|) $ |#3|) "\\spad{order(p,{}s)} returns the order of the differential polynomial \\spad{p} in differential indeterminate \\spad{s}.")) (|differentialVariables| (((|List| |#3|) $) "\\spad{differentialVariables(p)} returns a list of differential indeterminates occurring in a differential polynomial \\spad{p}.")) (|makeVariable| (((|Mapping| $ (|NonNegativeInteger|)) $) "\\spad{makeVariable(p)} views \\spad{p} as an element of a differential ring,{} in such a way that the \\spad{n}-th derivative of \\spad{p} may be simply referenced as \\spad{z}.\\spad{n} where \\spad{z} \\spad{:=} makeVariable(\\spad{p}). Note that In the interpreter,{} \\spad{z} is given as an internal map,{} which may be ignored.") (((|Mapping| $ (|NonNegativeInteger|)) |#3|) "\\spad{makeVariable(s)} views \\spad{s} as a differential indeterminate,{} in such a way that the \\spad{n}-th derivative of \\spad{s} may be simply referenced as \\spad{z}.\\spad{n} where \\spad{z} :=makeVariable(\\spad{s}). Note that In the interpreter,{} \\spad{z} is given as an internal map,{} which may be ignored."))) 
 NIL 
 ((|HasCategory| |#2| (QUOTE (-225)))) 
 (-246 R S V E) 
 ((|constructor| (NIL "\\spadtype{DifferentialPolynomialCategory} is a category constructor specifying basic functions in an ordinary differential polynomial ring with a given ordered set of differential indeterminates. In addition,{} it implements defaults for the basic functions. The functions \\spadfun{order} and \\spadfun{weight} are extended from the set of derivatives of differential indeterminates to the set of differential polynomials. Other operations provided on differential polynomials are \\spadfun{leader},{} \\spadfun{initial},{} \\spadfun{separant},{} \\spadfun{differentialVariables},{} and \\spadfun{isobaric?}. Furthermore,{} if the ground ring is a differential ring,{} then evaluation (substitution of differential indeterminates by elements of the ground ring or by differential polynomials) is provided by \\spadfun{eval}. A convenient way of referencing derivatives is provided by the functions \\spadfun{makeVariable}. \\blankline To construct a domain using this constructor,{} one needs to provide a ground ring \\spad{R},{} an ordered set \\spad{S} of differential indeterminates,{} a ranking \\spad{V} on the set of derivatives of the differential indeterminates,{} and a set \\spad{E} of exponents in bijection with the set of differential monomials in the given differential indeterminates.")) (|separant| (($ $) "\\spad{separant(p)} returns the partial derivative of the differential polynomial \\spad{p} with respect to its leader.")) (|initial| (($ $) "\\spad{initial(p)} returns the leading coefficient when the differential polynomial \\spad{p} is written as a univariate polynomial in its leader.")) (|leader| ((|#3| $) "\\spad{leader(p)} returns the derivative of the highest rank appearing in the differential polynomial \\spad{p} Note that an error occurs if \\spad{p} is in the ground ring.")) (|isobaric?| (((|Boolean|) $) "\\spad{isobaric?(p)} returns \\spad{true} if every differential monomial appearing in the differential polynomial \\spad{p} has same weight,{} and returns \\spad{false} otherwise.")) (|weight| (((|NonNegativeInteger|) $ |#2|) "\\spad{weight(p,{} s)} returns the maximum weight of all differential monomials appearing in the differential polynomial \\spad{p} when \\spad{p} is viewed as a differential polynomial in the differential indeterminate \\spad{s} alone.") (((|NonNegativeInteger|) $) "\\spad{weight(p)} returns the maximum weight of all differential monomials appearing in the differential polynomial \\spad{p}.")) (|weights| (((|List| (|NonNegativeInteger|)) $ |#2|) "\\spad{weights(p,{} s)} returns a list of weights of differential monomials appearing in the differential polynomial \\spad{p} when \\spad{p} is viewed as a differential polynomial in the differential indeterminate \\spad{s} alone.") (((|List| (|NonNegativeInteger|)) $) "\\spad{weights(p)} returns a list of weights of differential monomials appearing in differential polynomial \\spad{p}.")) (|degree| (((|NonNegativeInteger|) $ |#2|) "\\spad{degree(p,{} s)} returns the maximum degree of the differential polynomial \\spad{p} viewed as a differential polynomial in the differential indeterminate \\spad{s} alone.")) (|order| (((|NonNegativeInteger|) $) "\\spad{order(p)} returns the order of the differential polynomial \\spad{p},{} which is the maximum number of differentiations of a differential indeterminate,{} among all those appearing in \\spad{p}.") (((|NonNegativeInteger|) $ |#2|) "\\spad{order(p,{}s)} returns the order of the differential polynomial \\spad{p} in differential indeterminate \\spad{s}.")) (|differentialVariables| (((|List| |#2|) $) "\\spad{differentialVariables(p)} returns a list of differential indeterminates occurring in a differential polynomial \\spad{p}.")) (|makeVariable| (((|Mapping| $ (|NonNegativeInteger|)) $) "\\spad{makeVariable(p)} views \\spad{p} as an element of a differential ring,{} in such a way that the \\spad{n}-th derivative of \\spad{p} may be simply referenced as \\spad{z}.\\spad{n} where \\spad{z} \\spad{:=} makeVariable(\\spad{p}). Note that In the interpreter,{} \\spad{z} is given as an internal map,{} which may be ignored.") (((|Mapping| $ (|NonNegativeInteger|)) |#2|) "\\spad{makeVariable(s)} views \\spad{s} as a differential indeterminate,{} in such a way that the \\spad{n}-th derivative of \\spad{s} may be simply referenced as \\spad{z}.\\spad{n} where \\spad{z} :=makeVariable(\\spad{s}). Note that In the interpreter,{} \\spad{z} is given as an internal map,{} which may be ignored."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-6 -4517)) (-4514 . T) (-4513 . T) (-4516 . T)) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-6 -4519)) (-4516 . T) (-4515 . T) (-4518 . T)) 
 NIL 
 (-247 S) 
 ((|constructor| (NIL "A dequeue is a doubly ended stack,{} that is,{} a bag where first items inserted are the first items extracted,{} at either the front or the back end of the data structure.")) (|reverse!| (($ $) "\\spad{reverse!(d)} destructively replaces \\spad{d} by its reverse dequeue,{} \\spadignore{i.e.} the top (front) element is now the bottom (back) element,{} and so on.")) (|extractBottom!| ((|#1| $) "\\spad{extractBottom!(d)} destructively extracts the bottom (back) element from the dequeue \\spad{d}. Error: if \\spad{d} is empty.")) (|extractTop!| ((|#1| $) "\\spad{extractTop!(d)} destructively extracts the top (front) element from the dequeue \\spad{d}. Error: if \\spad{d} is empty.")) (|insertBottom!| ((|#1| |#1| $) "\\spad{insertBottom!(x,{}d)} destructively inserts \\spad{x} into the dequeue \\spad{d} at the bottom (back) of the dequeue.")) (|insertTop!| ((|#1| |#1| $) "\\spad{insertTop!(x,{}d)} destructively inserts \\spad{x} into the dequeue \\spad{d},{} that is,{} at the top (front) of the dequeue. The element previously at the top of the dequeue becomes the second in the dequeue,{} and so on.")) (|bottom!| ((|#1| $) "\\spad{bottom!(d)} returns the element at the bottom (back) of the dequeue.")) (|top!| ((|#1| $) "\\spad{top!(d)} returns the element at the top (front) of the dequeue.")) (|height| (((|NonNegativeInteger|) $) "\\spad{height(d)} returns the number of elements in dequeue \\spad{d}. Note that \\axiom{height(\\spad{d}) = \\# \\spad{d}}.")) (|dequeue| (($ (|List| |#1|)) "\\spad{dequeue([x,{}y,{}...,{}z])} creates a dequeue with first (top or front) element \\spad{x},{} second element \\spad{y},{}...,{}and last (bottom or back) element \\spad{z}.") (($) "\\spad{dequeue()}\\$\\spad{D} creates an empty dequeue of type \\spad{D}."))) 
-((-4519 . T) (-4520 . T) (-3973 . T)) 
+((-4521 . T) (-4522 . T) (-3973 . T)) 
 NIL 
 (-248) 
 ((|constructor| (NIL "TopLevelDrawFunctionsForCompiledFunctions provides top level functions for drawing graphics of expressions.")) (|recolor| (((|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|)) (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) "\\spad{recolor()},{} uninteresting to top level user; exported in order to compile package.")) (|makeObject| (((|ThreeSpace| (|DoubleFloat|)) (|ParametricSurface| (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|Segment| (|Float|)) (|Segment| (|Float|))) "\\spad{makeObject(surface(f,{}g,{}h),{}a..b,{}c..d,{}l)} returns a space of the domain \\spadtype{ThreeSpace} which contains the graph of the parametric surface \\spad{x = f(u,{}v)},{} \\spad{y = g(u,{}v)},{} \\spad{z = h(u,{}v)} as \\spad{u} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)} and \\spad{v} ranges from \\spad{min(c,{}d)} to \\spad{max(c,{}d)}.") (((|ThreeSpace| (|DoubleFloat|)) (|ParametricSurface| (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|Segment| (|Float|)) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{makeObject(surface(f,{}g,{}h),{}a..b,{}c..d,{}l)} returns a space of the domain \\spadtype{ThreeSpace} which contains the graph of the parametric surface \\spad{x = f(u,{}v)},{} \\spad{y = g(u,{}v)},{} \\spad{z = h(u,{}v)} as \\spad{u} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)} and \\spad{v} ranges from \\spad{min(c,{}d)} to \\spad{max(c,{}d)}. The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeSpace| (|DoubleFloat|)) (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|Float|)) (|Segment| (|Float|))) "\\spad{makeObject(f,{}a..b,{}c..d,{}l)} returns a space of the domain \\spadtype{ThreeSpace} which contains the graph of the parametric surface \\spad{f(u,{}v)} as \\spad{u} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)} and \\spad{v} ranges from \\spad{min(c,{}d)} to \\spad{max(c,{}d)}.") (((|ThreeSpace| (|DoubleFloat|)) (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|Float|)) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{makeObject(f,{}a..b,{}c..d,{}l)} returns a space of the domain \\spadtype{ThreeSpace} which contains the graph of the parametric surface \\spad{f(u,{}v)} as \\spad{u} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)} and \\spad{v} ranges from \\spad{min(c,{}d)} to \\spad{max(c,{}d)}; The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeSpace| (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|Float|)) (|Segment| (|Float|))) "\\spad{makeObject(f,{}a..b,{}c..d)} returns a space of the domain \\spadtype{ThreeSpace} which contains the graph of \\spad{z = f(x,{}y)} as \\spad{x} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)} and \\spad{y} ranges from \\spad{min(c,{}d)} to \\spad{max(c,{}d)}.") (((|ThreeSpace| (|DoubleFloat|)) (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|Float|)) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{makeObject(f,{}a..b,{}c..d,{}l)} returns a space of the domain \\spadtype{ThreeSpace} which contains the graph of \\spad{z = f(x,{}y)} as \\spad{x} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)} and \\spad{y} ranges from \\spad{min(c,{}d)} to \\spad{max(c,{}d)},{} and the options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeSpace| (|DoubleFloat|)) (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|)) (|Segment| (|Float|))) "\\spad{makeObject(sp,{}curve(f,{}g,{}h),{}a..b)} returns the space \\spad{sp} of the domain \\spadtype{ThreeSpace} with the addition of the graph of the parametric curve \\spad{x = f(t),{} y = g(t),{} z = h(t)} as \\spad{t} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)}.") (((|ThreeSpace| (|DoubleFloat|)) (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|)) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{makeObject(curve(f,{}g,{}h),{}a..b,{}l)} returns a space of the domain \\spadtype{ThreeSpace} which contains the graph of the parametric curve \\spad{x = f(t),{} y = g(t),{} z = h(t)} as \\spad{t} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)}. The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeSpace| (|DoubleFloat|)) (|ParametricSpaceCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|Segment| (|Float|))) "\\spad{makeObject(sp,{}curve(f,{}g,{}h),{}a..b)} returns the space \\spad{sp} of the domain \\spadtype{ThreeSpace} with the addition of the graph of the parametric curve \\spad{x = f(t),{} y = g(t),{} z = h(t)} as \\spad{t} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)}.") (((|ThreeSpace| (|DoubleFloat|)) (|ParametricSpaceCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{makeObject(curve(f,{}g,{}h),{}a..b,{}l)} returns a space of the domain \\spadtype{ThreeSpace} which contains the graph of the parametric curve \\spad{x = f(t),{} y = g(t),{} z = h(t)} as \\spad{t} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)}; The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.")) (|draw| (((|ThreeDimensionalViewport|) (|ParametricSurface| (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|Segment| (|Float|)) (|Segment| (|Float|))) "\\spad{draw(surface(f,{}g,{}h),{}a..b,{}c..d)} draws the graph of the parametric surface \\spad{x = f(u,{}v)},{} \\spad{y = g(u,{}v)},{} \\spad{z = h(u,{}v)} as \\spad{u} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)} and \\spad{v} ranges from \\spad{min(c,{}d)} to \\spad{max(c,{}d)}.") (((|ThreeDimensionalViewport|) (|ParametricSurface| (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|Segment| (|Float|)) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{draw(surface(f,{}g,{}h),{}a..b,{}c..d)} draws the graph of the parametric surface \\spad{x = f(u,{}v)},{} \\spad{y = g(u,{}v)},{} \\spad{z = h(u,{}v)} as \\spad{u} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)} and \\spad{v} ranges from \\spad{min(c,{}d)} to \\spad{max(c,{}d)}; The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeDimensionalViewport|) (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|Float|)) (|Segment| (|Float|))) "\\spad{draw(f,{}a..b,{}c..d)} draws the graph of the parametric surface \\spad{f(u,{}v)} as \\spad{u} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)} and \\spad{v} ranges from \\spad{min(c,{}d)} to \\spad{max(c,{}d)} The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeDimensionalViewport|) (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|Float|)) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{draw(f,{}a..b,{}c..d)} draws the graph of the parametric surface \\spad{f(u,{}v)} as \\spad{u} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)} and \\spad{v} ranges from \\spad{min(c,{}d)} to \\spad{max(c,{}d)}. The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeDimensionalViewport|) (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|Float|)) (|Segment| (|Float|))) "\\spad{draw(f,{}a..b,{}c..d)} draws the graph of \\spad{z = f(x,{}y)} as \\spad{x} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)} and \\spad{y} ranges from \\spad{min(c,{}d)} to \\spad{max(c,{}d)}.") (((|ThreeDimensionalViewport|) (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|Float|)) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{draw(f,{}a..b,{}c..d,{}l)} draws the graph of \\spad{z = f(x,{}y)} as \\spad{x} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)} and \\spad{y} ranges from \\spad{min(c,{}d)} to \\spad{max(c,{}d)}. and the options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeDimensionalViewport|) (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|)) (|Segment| (|Float|))) "\\spad{draw(f,{}a..b,{}l)} draws the graph of the parametric curve \\spad{f} as \\spad{t} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)}.") (((|ThreeDimensionalViewport|) (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|)) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{draw(f,{}a..b,{}l)} draws the graph of the parametric curve \\spad{f} as \\spad{t} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)}. The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|ThreeDimensionalViewport|) (|ParametricSpaceCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|Segment| (|Float|))) "\\spad{draw(curve(f,{}g,{}h),{}a..b,{}l)} draws the graph of the parametric curve \\spad{x = f(t),{} y = g(t),{} z = h(t)} as \\spad{t} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)}.") (((|ThreeDimensionalViewport|) (|ParametricSpaceCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{draw(curve(f,{}g,{}h),{}a..b,{}l)} draws the graph of the parametric curve \\spad{x = f(t),{} y = g(t),{} z = h(t)} as \\spad{t} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)}. The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|TwoDimensionalViewport|) (|ParametricPlaneCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|Segment| (|Float|))) "\\spad{draw(curve(f,{}g),{}a..b)} draws the graph of the parametric curve \\spad{x = f(t),{} y = g(t)} as \\spad{t} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)}.") (((|TwoDimensionalViewport|) (|ParametricPlaneCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{draw(curve(f,{}g),{}a..b,{}l)} draws the graph of the parametric curve \\spad{x = f(t),{} y = g(t)} as \\spad{t} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)}. The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied.") (((|TwoDimensionalViewport|) (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|Float|))) "\\spad{draw(f,{}a..b)} draws the graph of \\spad{y = f(x)} as \\spad{x} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)}.") (((|TwoDimensionalViewport|) (|Mapping| (|DoubleFloat|) (|DoubleFloat|)) (|Segment| (|Float|)) (|List| (|DrawOption|))) "\\spad{draw(f,{}a..b,{}l)} draws the graph of \\spad{y = f(x)} as \\spad{x} ranges from \\spad{min(a,{}b)} to \\spad{max(a,{}b)}. The options contained in the list \\spad{l} of the domain \\spad{DrawOption} are applied."))) 
@@ -958,15 +958,15 @@ NIL
 NIL 
 (-257 R S V) 
 ((|constructor| (NIL "\\spadtype{DifferentialSparseMultivariatePolynomial} implements an ordinary differential polynomial ring by combining a domain belonging to the category \\spadtype{DifferentialVariableCategory} with the domain \\spadtype{SparseMultivariatePolynomial}."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-6 -4517)) (-4514 . T) (-4513 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#3| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#3| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#3| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#3| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-225))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#1| (QUOTE -4517)) (|HasCategory| |#1| (QUOTE (-453))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-6 -4519)) (-4516 . T) (-4515 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#3| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#3| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#3| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#3| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-225))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#1| (QUOTE -4519)) (|HasCategory| |#1| (QUOTE (-453))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))))) 
 (-258 S) 
 ((|constructor| (NIL "This category is part of the PAFF package")) (|tree| (($ (|List| |#1|)) "\\spad{tree(l)} creates a chain tree from the list \\spad{l}") (($ |#1|) "\\spad{tree(nd)} creates a tree with value \\spad{nd},{} and no children") (($ |#1| (|List| $)) "\\spad{tree(nd,{}ls)} creates a tree with value \\spad{nd},{} and children \\spad{ls}."))) 
-((-4519 . T) (-4520 . T) (-3973 . T)) 
+((-4521 . T) (-4522 . T) (-3973 . T)) 
 NIL 
 (-259 S) 
 ((|constructor| (NIL "This category is part of the PAFF package")) (|fullOutput| (((|Boolean|)) "\\spad{fullOutput returns} the value of the flag set by fullOutput(\\spad{b}).") (((|Boolean|) (|Boolean|)) "\\spad{fullOutput(b)} sets a flag such that when \\spad{true},{} a coerce to OutputForm yields the full output of \\spad{tr},{} otherwise encode(\\spad{tr}) is output (see encode function). The default is \\spad{false}.")) (|fullOut| (((|OutputForm|) $) "\\spad{fullOut(tr)} yields a full output of \\spad{tr} (see function fullOutput).")) (|encode| (((|String|) $) "\\spad{encode(t)} returns a string indicating the \"shape\" of the tree"))) 
-((-4519 . T) (-4520 . T)) 
+((-4521 . T) (-4522 . T)) 
 ((|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090))))) 
 (-260 K |symb| |PolyRing| E |ProjPt| PCS |Plc| DIVISOR |InfClsPoint| |DesTree| BLMET) 
 ((|constructor| (NIL "\\indented{1}{The following is all the categories,{} domains and package} used for the desingularisation be means of monoidal transformation (Blowing-up)")) (|genusTreeNeg| (((|Integer|) (|NonNegativeInteger|) (|List| |#10|)) "\\spad{genusTreeNeg(n,{}listOfTrees)} computes the \"genus\" of a curve that may be not absolutly irreducible,{} where \\spad{n} is the degree of a polynomial pol defining the curve and \\spad{listOfTrees} is all the desingularisation trees at all singular points on the curve defined by pol. A \"negative\" genus means that the curve is reducible \\spad{!!}.")) (|genusTree| (((|NonNegativeInteger|) (|NonNegativeInteger|) (|List| |#10|)) "\\spad{genusTree(n,{}listOfTrees)} computes the genus of a curve,{} where \\spad{n} is the degree of a polynomial pol defining the curve and \\spad{listOfTrees} is all the desingularisation trees at all singular points on the curve defined by pol.")) (|genusNeg| (((|Integer|) |#3|) "\\spad{genusNeg(pol)} computes the \"genus\" of a curve that may be not absolutly irreducible. A \"negative\" genus means that the curve is reducible \\spad{!!}.")) (|genus| (((|NonNegativeInteger|) |#3|) "\\spad{genus(pol)} computes the genus of the curve defined by \\spad{pol}.")) (|initializeParamOfPlaces| (((|Void|) |#10| (|List| |#3|)) "initParLocLeaves(\\spad{tr},{}listOfFnc) initialize the local parametrization at places corresponding to the leaves of \\spad{tr} according to the given list of functions in listOfFnc.") (((|Void|) |#10|) "initParLocLeaves(\\spad{tr}) initialize the local parametrization at places corresponding to the leaves of \\spad{tr}.")) (|initParLocLeaves| (((|Void|) |#10|) "\\spad{initParLocLeaves(tr)} initialize the local parametrization at simple points corresponding to the leaves of \\spad{tr}.")) (|fullParamInit| (((|Void|) |#10|) "\\spad{fullParamInit(tr)} initialize the local parametrization at all places (leaves of \\spad{tr}),{} computes the local exceptional divisor at each infinytly close points in the tree. This function is equivalent to the following called: initParLocLeaves(\\spad{tr}) initializeParamOfPlaces(\\spad{tr}) blowUpWithExcpDiv(\\spad{tr})")) (|desingTree| (((|List| |#10|) |#3|) "\\spad{desingTree(pol)} returns all the desingularisation trees of all singular points on the curve defined by \\spad{pol}.")) (|desingTreeAtPoint| ((|#10| |#5| |#3|) "\\spad{desingTreeAtPoint(pt,{}pol)} computes the desingularisation tree at the point \\spad{pt} on the curve defined by \\spad{pol}. This function recursively compute the tree.")) (|adjunctionDivisor| ((|#8| |#10|) "\\spad{adjunctionDivisor(tr)} compute the local adjunction divisor of a desingularisation tree \\spad{tr} of a singular point.")) (|divisorAtDesingTree| ((|#8| |#3| |#10|) "\\spad{divisorAtDesingTree(f,{}tr)} computes the local divisor of \\spad{f} at a desingularisation tree \\spad{tr} of a singular point."))) 
@@ -1038,7 +1038,7 @@ NIL
 ((|HasCategory| |#2| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-1090)))) 
 (-277 S) 
 ((|constructor| (NIL "An extensible aggregate is one which allows insertion and deletion of entries. These aggregates are models of lists and streams which are represented by linked structures so as to make insertion,{} deletion,{} and concatenation efficient. However,{} access to elements of these extensible aggregates is generally slow since access is made from the end. See \\spadtype{FlexibleArray} for an exception.")) (|removeDuplicates!| (($ $) "\\spad{removeDuplicates!(u)} destructively removes duplicates from \\spad{u}.")) (|select!| (($ (|Mapping| (|Boolean|) |#1|) $) "\\spad{select!(p,{}u)} destructively changes \\spad{u} by keeping only values \\spad{x} such that \\axiom{\\spad{p}(\\spad{x})}.")) (|merge!| (($ $ $) "\\spad{merge!(u,{}v)} destructively merges \\spad{u} and \\spad{v} in ascending order.") (($ (|Mapping| (|Boolean|) |#1| |#1|) $ $) "\\spad{merge!(p,{}u,{}v)} destructively merges \\spad{u} and \\spad{v} using predicate \\spad{p}.")) (|insert!| (($ $ $ (|Integer|)) "\\spad{insert!(v,{}u,{}i)} destructively inserts aggregate \\spad{v} into \\spad{u} at position \\spad{i}.") (($ |#1| $ (|Integer|)) "\\spad{insert!(x,{}u,{}i)} destructively inserts \\spad{x} into \\spad{u} at position \\spad{i}.")) (|remove!| (($ |#1| $) "\\spad{remove!(x,{}u)} destructively removes all values \\spad{x} from \\spad{u}.") (($ (|Mapping| (|Boolean|) |#1|) $) "\\spad{remove!(p,{}u)} destructively removes all elements \\spad{x} of \\spad{u} such that \\axiom{\\spad{p}(\\spad{x})} is \\spad{true}.")) (|delete!| (($ $ (|UniversalSegment| (|Integer|))) "\\spad{delete!(u,{}i..j)} destructively deletes elements \\spad{u}.\\spad{i} through \\spad{u}.\\spad{j}.") (($ $ (|Integer|)) "\\indented{1}{delete!(\\spad{u},{}\\spad{i}) destructively deletes the \\axiom{\\spad{i}}th element of \\spad{u}.} \\blankline \\spad{E} Data:=Record(age:Integer,{}gender:String) \\spad{E} a1:AssociationList(String,{}Data):=table() \\spad{E} \\spad{a1}.\"tim\":=[55,{}\"male\"]\\$Data \\spad{E} delete!(\\spad{a1},{}1)")) (|concat!| (($ $ $) "\\spad{concat!(u,{}v)} destructively appends \\spad{v} to the end of \\spad{u}. \\spad{v} is unchanged") (($ $ |#1|) "\\spad{concat!(u,{}x)} destructively adds element \\spad{x} to the end of \\spad{u}."))) 
-((-4520 . T) (-3973 . T)) 
+((-4522 . T) (-3973 . T)) 
 NIL 
 (-278 S) 
 ((|constructor| (NIL "Category for the elementary functions.")) (** (($ $ $) "\\spad{x**y} returns \\spad{x} to the power \\spad{y}.")) (|exp| (($ $) "\\spad{exp(x)} returns \\%\\spad{e} to the power \\spad{x}.")) (|log| (($ $) "\\spad{log(x)} returns the natural logarithm of \\spad{x}."))) 
@@ -1059,18 +1059,18 @@ NIL
 (-282 S |Dom| |Im|) 
 ((|constructor| (NIL "An eltable aggregate is one which can be viewed as a function. For example,{} the list \\axiom{[1,{}7,{}4]} can applied to 0,{}1,{} and 2 respectively will return the integers 1,{}7,{} and 4; thus this list may be viewed as mapping 0 to 1,{} 1 to 7 and 2 to 4. In general,{} an aggregate can map members of a domain Dom to an image domain Im.")) (|qsetelt!| ((|#3| $ |#2| |#3|) "\\spad{qsetelt!(u,{}x,{}y)} sets the image of \\axiom{\\spad{x}} to be \\axiom{\\spad{y}} under \\axiom{\\spad{u}},{} without checking that \\axiom{\\spad{x}} is in the domain of \\axiom{\\spad{u}}. If such a check is required use the function \\axiom{setelt}.")) (|setelt| ((|#3| $ |#2| |#3|) "\\spad{setelt(u,{}x,{}y)} sets the image of \\spad{x} to be \\spad{y} under \\spad{u},{} assuming \\spad{x} is in the domain of \\spad{u}. Error: if \\spad{x} is not in the domain of \\spad{u}.")) (|qelt| ((|#3| $ |#2|) "\\spad{qelt(u,{} x)} applies \\axiom{\\spad{u}} to \\axiom{\\spad{x}} without checking whether \\axiom{\\spad{x}} is in the domain of \\axiom{\\spad{u}}. If \\axiom{\\spad{x}} is not in the domain of \\axiom{\\spad{u}} a memory-access violation may occur. If a check on whether \\axiom{\\spad{x}} is in the domain of \\axiom{\\spad{u}} is required,{} use the function \\axiom{elt}.")) (|elt| ((|#3| $ |#2| |#3|) "\\spad{elt(u,{} x,{} y)} applies \\spad{u} to \\spad{x} if \\spad{x} is in the domain of \\spad{u},{} and returns \\spad{y} otherwise. For example,{} if \\spad{u} is a polynomial in \\axiom{\\spad{x}} over the rationals,{} \\axiom{elt(\\spad{u},{}\\spad{n},{}0)} may define the coefficient of \\axiom{\\spad{x}} to the power \\spad{n},{} returning 0 when \\spad{n} is out of range."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE -4520))) 
+((|HasAttribute| |#1| (QUOTE -4522))) 
 (-283 |Dom| |Im|) 
 ((|constructor| (NIL "An eltable aggregate is one which can be viewed as a function. For example,{} the list \\axiom{[1,{}7,{}4]} can applied to 0,{}1,{} and 2 respectively will return the integers 1,{}7,{} and 4; thus this list may be viewed as mapping 0 to 1,{} 1 to 7 and 2 to 4. In general,{} an aggregate can map members of a domain Dom to an image domain Im.")) (|qsetelt!| ((|#2| $ |#1| |#2|) "\\spad{qsetelt!(u,{}x,{}y)} sets the image of \\axiom{\\spad{x}} to be \\axiom{\\spad{y}} under \\axiom{\\spad{u}},{} without checking that \\axiom{\\spad{x}} is in the domain of \\axiom{\\spad{u}}. If such a check is required use the function \\axiom{setelt}.")) (|setelt| ((|#2| $ |#1| |#2|) "\\spad{setelt(u,{}x,{}y)} sets the image of \\spad{x} to be \\spad{y} under \\spad{u},{} assuming \\spad{x} is in the domain of \\spad{u}. Error: if \\spad{x} is not in the domain of \\spad{u}.")) (|qelt| ((|#2| $ |#1|) "\\spad{qelt(u,{} x)} applies \\axiom{\\spad{u}} to \\axiom{\\spad{x}} without checking whether \\axiom{\\spad{x}} is in the domain of \\axiom{\\spad{u}}. If \\axiom{\\spad{x}} is not in the domain of \\axiom{\\spad{u}} a memory-access violation may occur. If a check on whether \\axiom{\\spad{x}} is in the domain of \\axiom{\\spad{u}} is required,{} use the function \\axiom{elt}.")) (|elt| ((|#2| $ |#1| |#2|) "\\spad{elt(u,{} x,{} y)} applies \\spad{u} to \\spad{x} if \\spad{x} is in the domain of \\spad{u},{} and returns \\spad{y} otherwise. For example,{} if \\spad{u} is a polynomial in \\axiom{\\spad{x}} over the rationals,{} \\axiom{elt(\\spad{u},{}\\spad{n},{}0)} may define the coefficient of \\axiom{\\spad{x}} to the power \\spad{n},{} returning 0 when \\spad{n} is out of range."))) 
 NIL 
 NIL 
-(-284 S R |Mod| -3627 -1347 |exactQuo|) 
+(-284 S R |Mod| -3121 -3645 |exactQuo|) 
 ((|constructor| (NIL "These domains are used for the factorization and gcds of univariate polynomials over the integers in order to work modulo different primes. See \\spadtype{ModularRing},{} \\spadtype{ModularField}")) (|elt| ((|#2| $ |#2|) "\\spad{elt(x,{}r)} or \\spad{x}.\\spad{r} is not documented")) (|inv| (($ $) "\\spad{inv(x)} is not documented")) (|recip| (((|Union| $ "failed") $) "\\spad{recip(x)} is not documented")) (|exQuo| (((|Union| $ "failed") $ $) "\\spad{exQuo(x,{}y)} is not documented")) (|reduce| (($ |#2| |#3|) "\\spad{reduce(r,{}m)} is not documented")) (|coerce| ((|#2| $) "\\spad{coerce(x)} is not documented")) (|modulus| ((|#3| $) "\\spad{modulus(x)} is not documented"))) 
-((-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-285) 
 ((|constructor| (NIL "Entire Rings (non-commutative Integral Domains),{} \\spadignore{i.e.} a ring not necessarily commutative which has no zero divisors. \\blankline Axioms\\spad{\\br} \\tab{5}\\spad{ab=0 => a=0 or b=0} \\spad{--} known as noZeroDivisors\\spad{\\br} \\tab{5}\\spad{not(1=0)}")) (|noZeroDivisors| ((|attribute|) "if a product is zero then one of the factors must be zero."))) 
-((-4512 . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4514 . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-286 R) 
 ((|constructor| (NIL "This is a package for the exact computation of eigenvalues and eigenvectors. This package can be made to work for matrices with coefficients which are rational functions over a ring where we can factor polynomials. Rational eigenvalues are always explicitly computed while the non-rational ones are expressed in terms of their minimal polynomial.")) (|eigenvectors| (((|List| (|Record| (|:| |eigval| (|Union| (|Fraction| (|Polynomial| |#1|)) (|SuchThat| (|Symbol|) (|Polynomial| |#1|)))) (|:| |eigmult| (|NonNegativeInteger|)) (|:| |eigvec| (|List| (|Matrix| (|Fraction| (|Polynomial| |#1|))))))) (|Matrix| (|Fraction| (|Polynomial| |#1|)))) "\\spad{eigenvectors(m)} returns the eigenvalues and eigenvectors for the matrix \\spad{m}. The rational eigenvalues and the correspondent eigenvectors are explicitely computed,{} while the non rational ones are given via their minimal polynomial and the corresponding eigenvectors are expressed in terms of a \"generic\" root of such a polynomial.")) (|generalizedEigenvectors| (((|List| (|Record| (|:| |eigval| (|Union| (|Fraction| (|Polynomial| |#1|)) (|SuchThat| (|Symbol|) (|Polynomial| |#1|)))) (|:| |geneigvec| (|List| (|Matrix| (|Fraction| (|Polynomial| |#1|))))))) (|Matrix| (|Fraction| (|Polynomial| |#1|)))) "\\spad{generalizedEigenvectors(m)} returns the generalized eigenvectors of the matrix \\spad{m}.")) (|generalizedEigenvector| (((|List| (|Matrix| (|Fraction| (|Polynomial| |#1|)))) (|Record| (|:| |eigval| (|Union| (|Fraction| (|Polynomial| |#1|)) (|SuchThat| (|Symbol|) (|Polynomial| |#1|)))) (|:| |eigmult| (|NonNegativeInteger|)) (|:| |eigvec| (|List| (|Matrix| (|Fraction| (|Polynomial| |#1|)))))) (|Matrix| (|Fraction| (|Polynomial| |#1|)))) "\\spad{generalizedEigenvector(eigen,{}m)} returns the generalized eigenvectors of the matrix relative to the eigenvalue \\spad{eigen},{} as returned by the function eigenvectors.") (((|List| (|Matrix| (|Fraction| (|Polynomial| |#1|)))) (|Union| (|Fraction| (|Polynomial| |#1|)) (|SuchThat| (|Symbol|) (|Polynomial| |#1|))) (|Matrix| (|Fraction| (|Polynomial| |#1|))) (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{generalizedEigenvector(alpha,{}m,{}k,{}g)} returns the generalized eigenvectors of the matrix relative to the eigenvalue \\spad{alpha}. The integers \\spad{k} and \\spad{g} are respectively the algebraic and the geometric multiplicity of tye eigenvalue \\spad{alpha}. \\spad{alpha} can be either rational or not. In the seconda case apha is the minimal polynomial of the eigenvalue.")) (|eigenvector| (((|List| (|Matrix| (|Fraction| (|Polynomial| |#1|)))) (|Union| (|Fraction| (|Polynomial| |#1|)) (|SuchThat| (|Symbol|) (|Polynomial| |#1|))) (|Matrix| (|Fraction| (|Polynomial| |#1|)))) "\\spad{eigenvector(eigval,{}m)} returns the eigenvectors belonging to the eigenvalue \\spad{eigval} for the matrix \\spad{m}.")) (|eigenvalues| (((|List| (|Union| (|Fraction| (|Polynomial| |#1|)) (|SuchThat| (|Symbol|) (|Polynomial| |#1|)))) (|Matrix| (|Fraction| (|Polynomial| |#1|)))) "\\spad{eigenvalues(m)} returns the eigenvalues of the matrix \\spad{m} which are expressible as rational functions over the rational numbers.")) (|characteristicPolynomial| (((|Polynomial| |#1|) (|Matrix| (|Fraction| (|Polynomial| |#1|)))) "\\spad{characteristicPolynomial(m)} returns the characteristicPolynomial of the matrix \\spad{m} using a new generated symbol symbol as the main variable.") (((|Polynomial| |#1|) (|Matrix| (|Fraction| (|Polynomial| |#1|))) (|Symbol|)) "\\spad{characteristicPolynomial(m,{}var)} returns the characteristicPolynomial of the matrix \\spad{m} using the symbol \\spad{var} as the main variable."))) 
@@ -1082,12 +1082,12 @@ NIL
 NIL 
 (-288 S) 
 ((|constructor| (NIL "Equations as mathematical objects. All properties of the basis domain,{} \\spadignore{e.g.} being an abelian group are carried over the equation domain,{} by performing the structural operations on the left and on the right hand side.")) (|subst| (($ $ $) "\\spad{subst(eq1,{}eq2)} substitutes \\spad{eq2} into both sides of \\spad{eq1} the \\spad{lhs} of \\spad{eq2} should be a kernel")) (|inv| (($ $) "\\spad{inv(x)} returns the multiplicative inverse of \\spad{x}.")) (/ (($ $ $) "\\spad{e1/e2} produces a new equation by dividing the left and right hand sides of equations \\spad{e1} and \\spad{e2}.")) (|factorAndSplit| (((|List| $) $) "\\spad{factorAndSplit(eq)} make the right hand side 0 and factors the new left hand side. Each factor is equated to 0 and put into the resulting list without repetitions.")) (|rightOne| (((|Union| $ "failed") $) "\\spad{rightOne(eq)} divides by the right hand side.") (((|Union| $ "failed") $) "\\spad{rightOne(eq)} divides by the right hand side,{} if possible.")) (|leftOne| (((|Union| $ "failed") $) "\\spad{leftOne(eq)} divides by the left hand side.") (((|Union| $ "failed") $) "\\spad{leftOne(eq)} divides by the left hand side,{} if possible.")) (* (($ $ |#1|) "\\spad{eqn*x} produces a new equation by multiplying both sides of equation eqn by \\spad{x}.") (($ |#1| $) "\\spad{x*eqn} produces a new equation by multiplying both sides of equation eqn by \\spad{x}.")) (- (($ $ |#1|) "\\spad{eqn-x} produces a new equation by subtracting \\spad{x} from both sides of equation eqn.") (($ |#1| $) "\\spad{x-eqn} produces a new equation by subtracting both sides of equation eqn from \\spad{x}.")) (|rightZero| (($ $) "\\spad{rightZero(eq)} subtracts the right hand side.")) (|leftZero| (($ $) "\\spad{leftZero(eq)} subtracts the left hand side.")) (+ (($ $ |#1|) "\\spad{eqn+x} produces a new equation by adding \\spad{x} to both sides of equation eqn.") (($ |#1| $) "\\spad{x+eqn} produces a new equation by adding \\spad{x} to both sides of equation eqn.")) (|eval| (($ $ (|List| $)) "\\spad{eval(eqn,{} [x1=v1,{} ... xn=vn])} replaces \\spad{xi} by \\spad{vi} in equation \\spad{eqn}.") (($ $ $) "\\spad{eval(eqn,{} x=f)} replaces \\spad{x} by \\spad{f} in equation \\spad{eqn}.")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\spad{map(f,{}eqn)} constructs a new equation by applying \\spad{f} to both sides of \\spad{eqn}.")) (|rhs| ((|#1| $) "\\spad{rhs(eqn)} returns the right hand side of equation \\spad{eqn}.")) (|lhs| ((|#1| $) "\\spad{lhs(eqn)} returns the left hand side of equation \\spad{eqn}.")) (|swap| (($ $) "\\spad{swap(eq)} interchanges left and right hand side of equation \\spad{eq}.")) (|equation| (($ |#1| |#1|) "\\spad{equation(a,{}b)} creates an equation.")) (= (($ |#1| |#1|) "\\spad{a=b} creates an equation."))) 
-((-4516 -2198 (|has| |#1| (-1047)) (|has| |#1| (-478))) (-4513 |has| |#1| (-1047)) (-4514 |has| |#1| (-1047))) 
-((|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (QUOTE (-1047))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-1047)))) (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#1| (LIST (QUOTE -523) (QUOTE (-1161)) (|devaluate| |#1|))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-296))) (-2198 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-478)))) (-2198 (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#1| (QUOTE (-1047)))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-1047)))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-716))) (-2198 (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#1| (QUOTE (-716)))) (|HasCategory| |#1| (QUOTE (-1102))) (-2198 (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#1| (QUOTE (-716))) (|HasCategory| |#1| (QUOTE (-1102)))) (|HasCategory| |#1| (QUOTE (-21))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-1047)))) (-2198 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-716)))) (|HasCategory| |#1| (QUOTE (-25))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-1047)))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#1| (QUOTE (-716))) (|HasCategory| |#1| (QUOTE (-1047))) (|HasCategory| |#1| (QUOTE (-1102))) (|HasCategory| |#1| (QUOTE (-1090))))) 
+((-4518 -2199 (|has| |#1| (-1047)) (|has| |#1| (-478))) (-4515 |has| |#1| (-1047)) (-4516 |has| |#1| (-1047))) 
+((|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (QUOTE (-1047))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-1047)))) (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#1| (LIST (QUOTE -523) (QUOTE (-1161)) (|devaluate| |#1|))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-296))) (-2199 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-478)))) (-2199 (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#1| (QUOTE (-1047)))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-1047)))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-716))) (-2199 (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#1| (QUOTE (-716)))) (|HasCategory| |#1| (QUOTE (-1102))) (-2199 (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#1| (QUOTE (-716))) (|HasCategory| |#1| (QUOTE (-1102)))) (|HasCategory| |#1| (QUOTE (-21))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-1047)))) (-2199 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-716)))) (|HasCategory| |#1| (QUOTE (-25))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-1047)))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#1| (QUOTE (-716))) (|HasCategory| |#1| (QUOTE (-1047))) (|HasCategory| |#1| (QUOTE (-1102))) (|HasCategory| |#1| (QUOTE (-1090))))) 
 (-289 |Key| |Entry|) 
 ((|constructor| (NIL "This domain provides tables where the keys are compared using \\spadfun{eq?}. Thus keys are considered equal only if they are the same instance of a structure."))) 
-((-4519 . T) (-4520 . T)) 
-((|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3649) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4083) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-1090))) (-2198 (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-1090)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090))))) 
+((-4521 . T) (-4522 . T)) 
+((|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3651) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4085) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-1090))) (-2199 (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-1090)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090))))) 
 (-290) 
 ((|constructor| (NIL "ErrorFunctions implements error functions callable from the system interpreter. Typically,{} these functions would be called in user functions. The simple forms of the functions take one argument which is either a string (an error message) or a list of strings which all together make up a message. The list can contain formatting codes (see below). The more sophisticated versions takes two arguments where the first argument is the name of the function from which the error was invoked and the second argument is either a string or a list of strings,{} as above. When you use the one argument version in an interpreter function,{} the system will automatically insert the name of the function as the new first argument. Thus in the user interpreter function\\spad{\\br} \\tab{5}\\spad{f x == if x < 0 then error \"negative argument\" else x}\\spad{\\br} the call to error will actually be of the form\\spad{\\br} \\tab{5}\\spad{error(\"f\",{}\"negative argument\")}\\spad{\\br} because the interpreter will have created a new first argument. \\blankline Formatting codes: error messages may contain the following formatting codes (they should either start or end a string or else have blanks around them):\\spad{\\br} \\spad{\\%l}\\tab{6}start a new line\\spad{\\br} \\spad{\\%b}\\tab{6}start printing in a bold font (where available)\\spad{\\br} \\spad{\\%d}\\tab{6}stop printing in a bold font (where available)\\spad{\\br} \\spad{\\%ceon}\\tab{3}start centering message lines\\spad{\\br} \\spad{\\%ceoff}\\tab{2}stop centering message lines\\spad{\\br} \\spad{\\%rjon}\\tab{3}start displaying lines \"ragged left\"\\spad{\\br} \\spad{\\%rjoff}\\tab{2}stop displaying lines \"ragged left\"\\spad{\\br} \\spad{\\%i}\\tab{6}indent following lines 3 additional spaces\\spad{\\br} \\spad{\\%u}\\tab{6}unindent following lines 3 additional spaces\\spad{\\br} \\spad{\\%xN}\\tab{5}insert \\spad{N} blanks (eg,{} \\spad{\\%x10} inserts 10 blanks) \\blankline")) (|error| (((|Exit|) (|String|) (|List| (|String|))) "\\spad{error(nam,{}lmsg)} displays error messages \\spad{lmsg} preceded by a message containing the name \\spad{nam} of the function in which the error is contained.") (((|Exit|) (|String|) (|String|)) "\\spad{error(nam,{}msg)} displays error message \\spad{msg} preceded by a message containing the name \\spad{nam} of the function in which the error is contained.") (((|Exit|) (|List| (|String|))) "\\spad{error(lmsg)} displays error message \\spad{lmsg} and terminates.") (((|Exit|) (|String|)) "\\spad{error(msg)} displays error message \\spad{msg} and terminates."))) 
 NIL 
@@ -1134,7 +1134,7 @@ NIL
 NIL 
 (-301) 
 ((|constructor| (NIL "A constructive euclidean domain,{} \\spadignore{i.e.} one can divide producing a quotient and a remainder where the remainder is either zero or is smaller (\\spadfun{euclideanSize}) than the divisor. \\blankline Conditional attributes\\spad{\\br} \\tab{5}multiplicativeValuation\\tab{5}Size(a*b)=Size(a)*Size(\\spad{b})\\spad{\\br} \\tab{5}additiveValuation\\tab{11}Size(a*b)=Size(a)+Size(\\spad{b})")) (|multiEuclidean| (((|Union| (|List| $) "failed") (|List| $) $) "\\spad{multiEuclidean([f1,{}...,{}fn],{}z)} returns a list of coefficients \\spad{[a1,{} ...,{} an]} such that \\spad{ z / prod \\spad{fi} = sum aj/fj}. If no such list of coefficients exists,{} \"failed\" is returned.")) (|extendedEuclidean| (((|Union| (|Record| (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) "\\spad{extendedEuclidean(x,{}y,{}z)} either returns a record rec where \\spad{rec.coef1*x+rec.coef2*y=z} or returns \"failed\" if \\spad{z} cannot be expressed as a linear combination of \\spad{x} and \\spad{y}.") (((|Record| (|:| |coef1| $) (|:| |coef2| $) (|:| |generator| $)) $ $) "\\spad{extendedEuclidean(x,{}y)} returns a record rec where \\spad{rec.coef1*x+rec.coef2*y = rec.generator} and rec.generator is a \\spad{gcd} of \\spad{x} and \\spad{y}. The \\spad{gcd} is unique only up to associates if \\spadatt{canonicalUnitNormal} is not asserted. \\spadfun{principalIdeal} provides a version of this operation which accepts an arbitrary length list of arguments.")) (|rem| (($ $ $) "\\spad{x rem y} is the same as \\spad{divide(x,{}y).remainder}. See \\spadfunFrom{divide}{EuclideanDomain}.")) (|quo| (($ $ $) "\\spad{x quo y} is the same as \\spad{divide(x,{}y).quotient}. See \\spadfunFrom{divide}{EuclideanDomain}.")) (|divide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{divide(x,{}y)} divides \\spad{x} by \\spad{y} producing a record containing a \\spad{quotient} and \\spad{remainder},{} where the remainder is smaller (see \\spadfunFrom{sizeLess?}{EuclideanDomain}) than the divisor \\spad{y}.")) (|euclideanSize| (((|NonNegativeInteger|) $) "\\spad{euclideanSize(x)} returns the euclidean size of the element \\spad{x}. Error: if \\spad{x} is zero.")) (|sizeLess?| (((|Boolean|) $ $) "\\spad{sizeLess?(x,{}y)} tests whether \\spad{x} is strictly smaller than \\spad{y} with respect to the \\spadfunFrom{euclideanSize}{EuclideanDomain}."))) 
-((-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-302 S R) 
 ((|constructor| (NIL "This category provides \\spadfun{eval} operations. A domain may belong to this category if it is possible to make ``evaluation\\spad{''} substitutions.")) (|eval| (($ $ (|List| (|Equation| |#2|))) "\\spad{eval(f,{} [x1 = v1,{}...,{}xn = vn])} replaces \\spad{xi} by \\spad{vi} in \\spad{f}.") (($ $ (|Equation| |#2|)) "\\spad{eval(f,{}x = v)} replaces \\spad{x} by \\spad{v} in \\spad{f}."))) 
@@ -1158,8 +1158,8 @@ NIL
 NIL 
 (-307 R FE |var| |cen|) 
 ((|constructor| (NIL "UnivariatePuiseuxSeriesWithExponentialSingularity is a domain used to represent essential singularities of functions. Objects in this domain are quotients of sums,{} where each term in the sum is a univariate Puiseux series times the exponential of a univariate Puiseux series.")) (|coerce| (($ (|UnivariatePuiseuxSeries| |#2| |#3| |#4|)) "\\spad{coerce(f)} converts a \\spadtype{UnivariatePuiseuxSeries} to an \\spadtype{ExponentialExpansion}.")) (|limitPlus| (((|Union| (|OrderedCompletion| |#2|) "failed") $) "\\spad{limitPlus(f(var))} returns \\spad{limit(var -> a+,{}f(var))}."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-904))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-148))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-150))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-1021))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-815))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-1136))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-225))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -523) (QUOTE (-1161)) (LIST (QUOTE -1229) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|) (|devaluate| |#4|)))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -303) (LIST (QUOTE -1229) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|) (|devaluate| |#4|)))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -281) (LIST (QUOTE -1229) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|) (|devaluate| |#4|)) (LIST (QUOTE -1229) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|) (|devaluate| |#4|)))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-301))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-550))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-842))) (-2198 (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-815))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-842)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-904)))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-148))))) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-904))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-148))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-150))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-1021))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-815))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-1136))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-225))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -523) (QUOTE (-1161)) (LIST (QUOTE -1229) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|) (|devaluate| |#4|)))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -303) (LIST (QUOTE -1229) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|) (|devaluate| |#4|)))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (LIST (QUOTE -281) (LIST (QUOTE -1229) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|) (|devaluate| |#4|)) (LIST (QUOTE -1229) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|) (|devaluate| |#4|)))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-301))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-550))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-842))) (-2199 (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-815))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-842)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-904)))) (|HasCategory| (-1229 |#1| |#2| |#3| |#4|) (QUOTE (-148))))) 
 (-308 R S) 
 ((|constructor| (NIL "Lifting of maps to Expressions.")) (|map| (((|Expression| |#2|) (|Mapping| |#2| |#1|) (|Expression| |#1|)) "\\spad{map(f,{} e)} applies \\spad{f} to all the constants appearing in \\spad{e}."))) 
 NIL 
@@ -1170,8 +1170,8 @@ NIL
 NIL 
 (-310 R) 
 ((|constructor| (NIL "Top-level mathematical expressions involving symbolic functions.")) (|squareFreePolynomial| (((|Factored| (|SparseUnivariatePolynomial| $)) (|SparseUnivariatePolynomial| $)) "\\spad{squareFreePolynomial(p)} is not documented")) (|factorPolynomial| (((|Factored| (|SparseUnivariatePolynomial| $)) (|SparseUnivariatePolynomial| $)) "\\spad{factorPolynomial(p)} is not documented")) (|simplifyPower| (($ $ (|Integer|)) "simplifyPower?(\\spad{f},{}\\spad{n}) is not documented")) (|number?| (((|Boolean|) $) "\\spad{number?(f)} tests if \\spad{f} is rational")) (|reduce| (($ $) "\\spad{reduce(f)} simplifies all the unreduced algebraic quantities present in \\spad{f} by applying their defining relations."))) 
-((-4516 -2198 (-2139 (|has| |#1| (-1047)) (|has| |#1| (-630 (-568)))) (-12 (|has| |#1| (-558)) (-2198 (-2139 (|has| |#1| (-1047)) (|has| |#1| (-630 (-568)))) (|has| |#1| (-1047)) (|has| |#1| (-478)))) (|has| |#1| (-1047)) (|has| |#1| (-478))) (-4514 |has| |#1| (-172)) (-4513 |has| |#1| (-172)) ((-4521 "*") |has| |#1| (-558)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-558)) (-4511 |has| |#1| (-558))) 
-((|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-1047))) (-2198 (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-1047)))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-558)))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-1047)))) (-12 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558)))) (-2198 (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-1047)))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-1047)))) (-2198 (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#1| (QUOTE (-1047)))) (|HasCategory| |#1| (QUOTE (-21))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-1047)))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-1047)))) (|HasCategory| |#1| (QUOTE (-21)))) (|HasCategory| |#1| (QUOTE (-25))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-1047)))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-1047)))) (|HasCategory| |#1| (QUOTE (-25)))) (|HasCategory| |#1| (QUOTE (-1102))) (-2198 (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#1| (QUOTE (-1102)))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-1047)))) (|HasCategory| |#1| (QUOTE (-1102)))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-1047)))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-1102)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-558))))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558)))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-558))))) (|HasCategory| $ (QUOTE (-1047))) (|HasCategory| $ (LIST (QUOTE -1037) (QUOTE (-568))))) 
+((-4518 -2199 (-2141 (|has| |#1| (-1047)) (|has| |#1| (-630 (-568)))) (-12 (|has| |#1| (-558)) (-2199 (-2141 (|has| |#1| (-1047)) (|has| |#1| (-630 (-568)))) (|has| |#1| (-1047)) (|has| |#1| (-478)))) (|has| |#1| (-1047)) (|has| |#1| (-478))) (-4516 |has| |#1| (-172)) (-4515 |has| |#1| (-172)) ((-4523 "*") |has| |#1| (-558)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-558)) (-4513 |has| |#1| (-558))) 
+((|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-1047))) (-2199 (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-1047)))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-558)))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-1047)))) (-12 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558)))) (-2199 (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-1047)))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-1047)))) (-2199 (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#1| (QUOTE (-1047)))) (|HasCategory| |#1| (QUOTE (-21))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-1047)))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-1047)))) (|HasCategory| |#1| (QUOTE (-21)))) (|HasCategory| |#1| (QUOTE (-25))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-1047)))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-1047)))) (|HasCategory| |#1| (QUOTE (-25)))) (|HasCategory| |#1| (QUOTE (-1102))) (-2199 (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#1| (QUOTE (-1102)))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-1047)))) (|HasCategory| |#1| (QUOTE (-1102)))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-1047)))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-1102)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-558))))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558)))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-558))))) (|HasCategory| $ (QUOTE (-1047))) (|HasCategory| $ (LIST (QUOTE -1037) (QUOTE (-568))))) 
 (-311 R -1478) 
 ((|constructor| (NIL "Taylor series solutions of explicit ODE\\spad{'s}.")) (|seriesSolve| (((|Any|) |#2| (|BasicOperator|) (|Equation| |#2|) (|List| |#2|)) "\\spad{seriesSolve(eq,{} y,{} x = a,{} [b0,{}...,{}bn])} is equivalent to \\spad{seriesSolve(eq = 0,{} y,{} x = a,{} [b0,{}...,{}b(n-1)])}.") (((|Any|) |#2| (|BasicOperator|) (|Equation| |#2|) (|Equation| |#2|)) "\\spad{seriesSolve(eq,{} y,{} x = a,{} y a = b)} is equivalent to \\spad{seriesSolve(eq=0,{} y,{} x=a,{} y a = b)}.") (((|Any|) |#2| (|BasicOperator|) (|Equation| |#2|) |#2|) "\\spad{seriesSolve(eq,{} y,{} x = a,{} b)} is equivalent to \\spad{seriesSolve(eq = 0,{} y,{} x = a,{} y a = b)}.") (((|Any|) (|Equation| |#2|) (|BasicOperator|) (|Equation| |#2|) |#2|) "\\spad{seriesSolve(eq,{}y,{} x=a,{} b)} is equivalent to \\spad{seriesSolve(eq,{} y,{} x=a,{} y a = b)}.") (((|Any|) (|List| |#2|) (|List| (|BasicOperator|)) (|Equation| |#2|) (|List| (|Equation| |#2|))) "seriesSolve([\\spad{eq1},{}...,{}eqn],{} [\\spad{y1},{}...,{}\\spad{yn}],{} \\spad{x} = a,{}[\\spad{y1} a = \\spad{b1},{}...,{} \\spad{yn} a = \\spad{bn}]) is equivalent to \\spad{seriesSolve([eq1=0,{}...,{}eqn=0],{} [y1,{}...,{}yn],{} x = a,{} [y1 a = b1,{}...,{} yn a = bn])}.") (((|Any|) (|List| |#2|) (|List| (|BasicOperator|)) (|Equation| |#2|) (|List| |#2|)) "\\spad{seriesSolve([eq1,{}...,{}eqn],{} [y1,{}...,{}yn],{} x=a,{} [b1,{}...,{}bn])} is equivalent to \\spad{seriesSolve([eq1=0,{}...,{}eqn=0],{} [y1,{}...,{}yn],{} x=a,{} [b1,{}...,{}bn])}.") (((|Any|) (|List| (|Equation| |#2|)) (|List| (|BasicOperator|)) (|Equation| |#2|) (|List| |#2|)) "\\spad{seriesSolve([eq1,{}...,{}eqn],{} [y1,{}...,{}yn],{} x=a,{} [b1,{}...,{}bn])} is equivalent to \\spad{seriesSolve([eq1,{}...,{}eqn],{} [y1,{}...,{}yn],{} x = a,{} [y1 a = b1,{}...,{} yn a = bn])}.") (((|Any|) (|List| (|Equation| |#2|)) (|List| (|BasicOperator|)) (|Equation| |#2|) (|List| (|Equation| |#2|))) "\\spad{seriesSolve([eq1,{}...,{}eqn],{}[y1,{}...,{}yn],{}x = a,{}[y1 a = b1,{}...,{}yn a = bn])} returns a taylor series solution of \\spad{[eq1,{}...,{}eqn]} around \\spad{x = a} with initial conditions \\spad{\\spad{yi}(a) = \\spad{bi}}. Note that eqi must be of the form \\spad{\\spad{fi}(x,{} y1 x,{} y2 x,{}...,{} yn x) y1'(x) + \\spad{gi}(x,{} y1 x,{} y2 x,{}...,{} yn x) = h(x,{} y1 x,{} y2 x,{}...,{} yn x)}.") (((|Any|) (|Equation| |#2|) (|BasicOperator|) (|Equation| |#2|) (|List| |#2|)) "\\spad{seriesSolve(eq,{}y,{}x=a,{}[b0,{}...,{}b(n-1)])} returns a Taylor series solution of \\spad{eq} around \\spad{x = a} with initial conditions \\spad{y(a) = b0},{} \\spad{y'(a) = b1},{} \\spad{y''(a) = b2},{} ...,{}\\spad{y(n-1)(a) = b(n-1)} \\spad{eq} must be of the form \\spad{f(x,{} y x,{} y'(x),{}...,{} y(n-1)(x)) y(n)(x) + g(x,{}y x,{}y'(x),{}...,{}y(n-1)(x)) = h(x,{}y x,{} y'(x),{}...,{} y(n-1)(x))}.") (((|Any|) (|Equation| |#2|) (|BasicOperator|) (|Equation| |#2|) (|Equation| |#2|)) "\\spad{seriesSolve(eq,{}y,{}x=a,{} y a = b)} returns a Taylor series solution of \\spad{eq} around \\spad{x} = a with initial condition \\spad{y(a) = b}. Note that \\spad{eq} must be of the form \\spad{f(x,{} y x) y'(x) + g(x,{} y x) = h(x,{} y x)}."))) 
 NIL 
@@ -1186,8 +1186,8 @@ NIL
 NIL 
 (-314 FE |var| |cen|) 
 ((|constructor| (NIL "ExponentialOfUnivariatePuiseuxSeries is a domain used to represent essential singularities of functions. An object in this domain is a function of the form \\spad{exp(f(x))},{} where \\spad{f(x)} is a Puiseux series with no terms of non-negative degree. Objects are ordered according to order of singularity,{} with functions which tend more rapidly to zero or infinity considered to be larger. Thus,{} if \\spad{order(f(x)) < order(g(x))},{} \\spadignore{i.e.} the first non-zero term of \\spad{f(x)} has lower degree than the first non-zero term of \\spad{g(x)},{} then \\spad{exp(f(x)) > exp(g(x))}. If \\spad{order(f(x)) = order(g(x))},{} then the ordering is essentially random. This domain is used in computing limits involving functions with essential singularities.")) (|exponentialOrder| (((|Fraction| (|Integer|)) $) "\\spad{exponentialOrder(exp(c * x **(-n) + ...))} returns \\spad{-n}. exponentialOrder(0) returns \\spad{0}.")) (|exponent| (((|UnivariatePuiseuxSeries| |#1| |#2| |#3|) $) "\\spad{exponent(exp(f(x)))} returns \\spad{f(x)}")) (|exponential| (($ (|UnivariatePuiseuxSeries| |#1| |#2| |#3|)) "\\spad{exponential(f(x))} returns \\spad{exp(f(x))}. Note: the function does NOT check that \\spad{f(x)} has no non-negative terms."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-365)) (-4511 |has| |#1| (-365)) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568))) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568))) (|devaluate| |#1|))))) (|HasCategory| (-409 (-568)) (QUOTE (-1102))) (|HasCategory| |#1| (QUOTE (-365))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (-2198 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasSignature| |#1| (LIST (QUOTE -2745) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -3837) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2055) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|))))))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-365)) (-4513 |has| |#1| (-365)) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568))) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568))) (|devaluate| |#1|))))) (|HasCategory| (-409 (-568)) (QUOTE (-1102))) (|HasCategory| |#1| (QUOTE (-365))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (-2199 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasSignature| |#1| (LIST (QUOTE -2747) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -1845) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2057) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|))))))) 
 (-315 K) 
 ((|constructor| (NIL "Part of the Package for Algebraic Function Fields in one variable PAFF"))) 
 NIL 
@@ -1206,7 +1206,7 @@ NIL
 NIL 
 (-319 S) 
 ((|constructor| (NIL "The free abelian group on a set \\spad{S} is the monoid of finite sums of the form \\spad{reduce(+,{}[\\spad{ni} * \\spad{si}])} where the \\spad{si}\\spad{'s} are in \\spad{S},{} and the \\spad{ni}\\spad{'s} are integers. The operation is commutative."))) 
-((-4514 . T) (-4513 . T)) 
+((-4516 . T) (-4515 . T)) 
 ((|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| (-568) (QUOTE (-787)))) 
 (-320 S E) 
 ((|constructor| (NIL "A free abelian monoid on a set \\spad{S} is the monoid of finite sums of the form \\spad{reduce(+,{}[\\spad{ni} * \\spad{si}])} where the \\spad{si}\\spad{'s} are in \\spad{S},{} and the \\spad{ni}\\spad{'s} are in a given abelian monoid. The operation is commutative.")) (|highCommonTerms| (($ $ $) "\\spad{highCommonTerms(e1 a1 + ... + en an,{} f1 b1 + ... + fm bm)} returns \\spad{reduce(+,{}[max(\\spad{ei},{} \\spad{fi}) \\spad{ci}])} where \\spad{ci} ranges in the intersection of \\spad{{a1,{}...,{}an}} and \\spad{{b1,{}...,{}bm}}.")) (|mapGen| (($ (|Mapping| |#1| |#1|) $) "\\spad{mapGen(f,{} e1 a1 +...+ en an)} returns \\spad{e1 f(a1) +...+ en f(an)}.")) (|mapCoef| (($ (|Mapping| |#2| |#2|) $) "\\spad{mapCoef(f,{} e1 a1 +...+ en an)} returns \\spad{f(e1) a1 +...+ f(en) an}.")) (|coefficient| ((|#2| |#1| $) "\\spad{coefficient(s,{} e1 a1 + ... + en an)} returns \\spad{ei} such that \\spad{ai} = \\spad{s},{} or 0 if \\spad{s} is not one of the \\spad{ai}\\spad{'s}.")) (|nthFactor| ((|#1| $ (|Integer|)) "\\spad{nthFactor(x,{} n)} returns the factor of the n^th term of \\spad{x}.")) (|nthCoef| ((|#2| $ (|Integer|)) "\\spad{nthCoef(x,{} n)} returns the coefficient of the n^th term of \\spad{x}.")) (|terms| (((|List| (|Record| (|:| |gen| |#1|) (|:| |exp| |#2|))) $) "\\spad{terms(e1 a1 + ... + en an)} returns \\spad{[[a1,{} e1],{}...,{}[an,{} en]]}.")) (|size| (((|NonNegativeInteger|) $) "\\indented{1}{size(\\spad{x}) returns the number of terms in \\spad{x}.} \\indented{1}{mapGen(\\spad{f},{} \\spad{a1}\\spad{\\^}\\spad{e1} ... an\\spad{\\^}en) returns} \\spad{f(a1)\\^e1 ... f(an)\\^en}.")) (* (($ |#2| |#1|) "\\spad{e * s} returns \\spad{e} times \\spad{s}.")) (+ (($ |#1| $) "\\spad{s + x} returns the sum of \\spad{s} and \\spad{x}."))) 
@@ -1226,19 +1226,19 @@ NIL
 ((|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-172)))) 
 (-324 R E) 
 ((|constructor| (NIL "This category is similar to AbelianMonoidRing,{} except that the sum is assumed to be finite. It is a useful model for polynomials,{} but is somewhat more general.")) (|primitivePart| (($ $) "\\spad{primitivePart(p)} returns the unit normalized form of polynomial \\spad{p} divided by the content of \\spad{p}.")) (|content| ((|#1| $) "\\spad{content(p)} gives the \\spad{gcd} of the coefficients of polynomial \\spad{p}.")) (|exquo| (((|Union| $ "failed") $ |#1|) "\\spad{exquo(p,{}r)} returns the exact quotient of polynomial \\spad{p} by \\spad{r},{} or \"failed\" if none exists.")) (|binomThmExpt| (($ $ $ (|NonNegativeInteger|)) "\\spad{binomThmExpt(p,{}q,{}n)} returns \\spad{(x+y)^n} by means of the binomial theorem trick.")) (|pomopo!| (($ $ |#1| |#2| $) "\\spad{pomopo!(p1,{}r,{}e,{}p2)} returns \\spad{p1 + monomial(e,{}r) * p2} and may use \\spad{p1} as workspace. The constaant \\spad{r} is assumed to be nonzero.")) (|mapExponents| (($ (|Mapping| |#2| |#2|) $) "\\spad{mapExponents(fn,{}u)} maps function \\spad{fn} onto the exponents of the non-zero monomials of polynomial \\spad{u}.")) (|minimumDegree| ((|#2| $) "\\spad{minimumDegree(p)} gives the least exponent of a non-zero term of polynomial \\spad{p}. Error: if applied to 0.")) (|numberOfMonomials| (((|NonNegativeInteger|) $) "\\spad{numberOfMonomials(p)} gives the number of non-zero monomials in polynomial \\spad{p}.")) (|coefficients| (((|List| |#1|) $) "\\spad{coefficients(p)} gives the list of non-zero coefficients of polynomial \\spad{p}.")) (|ground| ((|#1| $) "\\spad{ground(p)} retracts polynomial \\spad{p} to the coefficient ring.")) (|ground?| (((|Boolean|) $) "\\spad{ground?(p)} tests if polynomial \\spad{p} is a member of the coefficient ring."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4513 . T) (-4514 . T) (-4516 . T)) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-325 S) 
 ((|constructor| (NIL "A FlexibleArray is the notion of an array intended to allow for growth at the end only. Hence the following efficient operations \\spad{append(x,{}a)} meaning append item \\spad{x} at the end of the array \\spad{a} \\spad{delete(a,{}n)} meaning delete the last item from the array \\spad{a} Flexible arrays support the other operations inherited from \\spadtype{ExtensibleLinearAggregate}. However,{} these are not efficient. Flexible arrays combine the \\spad{O(1)} access time property of arrays with growing and shrinking at the end in \\spad{O(1)} (average) time. This is done by using an ordinary array which may have zero or more empty slots at the end. When the array becomes full it is copied into a new larger (50\\% larger) array. Conversely,{} when the array becomes less than 1/2 full,{} it is copied into a smaller array. Flexible arrays provide for an efficient implementation of many data structures in particular heaps,{} stacks and sets."))) 
-((-4520 . T) (-4519 . T)) 
-((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (-2198 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
+((-4522 . T) (-4521 . T)) 
+((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (-2199 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
 (-326 S -1478) 
 ((|constructor| (NIL "FiniteAlgebraicExtensionField \\spad{F} is the category of fields which are finite algebraic extensions of the field \\spad{F}. If \\spad{F} is finite then any finite algebraic extension of \\spad{F} is finite,{} too. Let \\spad{K} be a finite algebraic extension of the finite field \\spad{F}. The exponentiation of elements of \\spad{K} defines a \\spad{Z}-module structure on the multiplicative group of \\spad{K}. The additive group of \\spad{K} becomes a module over the ring of polynomials over \\spad{F} via the operation \\spadfun{linearAssociatedExp}(a:K,{}f:SparseUnivariatePolynomial \\spad{F}) which is linear over \\spad{F},{} \\spadignore{i.e.} for elements a from \\spad{K},{} \\spad{c},{}\\spad{d} from \\spad{F} and \\spad{f},{}\\spad{g} univariate polynomials over \\spad{F} we have \\spadfun{linearAssociatedExp}(a,{}cf+dg) equals \\spad{c} times \\spadfun{linearAssociatedExp}(a,{}\\spad{f}) plus \\spad{d} times \\spadfun{linearAssociatedExp}(a,{}\\spad{g}). Therefore \\spadfun{linearAssociatedExp} is defined completely by its action on monomials from \\spad{F}[\\spad{X}]: \\spadfun{linearAssociatedExp}(a,{}monomial(1,{}\\spad{k})\\spad{\\$}SUP(\\spad{F})) is defined to be \\spadfun{Frobenius}(a,{}\\spad{k}) which is a**(q**k) where q=size()\\spad{\\$}\\spad{F}. The operations order and discreteLog associated with the multiplicative exponentiation have additive analogues associated to the operation \\spadfun{linearAssociatedExp}. These are the functions \\spadfun{linearAssociatedOrder} and \\spadfun{linearAssociatedLog},{} respectively.")) (|linearAssociatedLog| (((|Union| (|SparseUnivariatePolynomial| |#2|) "failed") $ $) "\\spad{linearAssociatedLog(b,{}a)} returns a polynomial \\spad{g},{} such that the \\spadfun{linearAssociatedExp}(\\spad{b},{}\\spad{g}) equals a. If there is no such polynomial \\spad{g},{} then \\spadfun{linearAssociatedLog} fails.") (((|SparseUnivariatePolynomial| |#2|) $) "\\spad{linearAssociatedLog(a)} returns a polynomial \\spad{g},{} such that \\spadfun{linearAssociatedExp}(normalElement(),{}\\spad{g}) equals a.")) (|linearAssociatedOrder| (((|SparseUnivariatePolynomial| |#2|) $) "\\spad{linearAssociatedOrder(a)} retruns the monic polynomial \\spad{g} of least degree,{} such that \\spadfun{linearAssociatedExp}(a,{}\\spad{g}) is 0.")) (|linearAssociatedExp| (($ $ (|SparseUnivariatePolynomial| |#2|)) "\\spad{linearAssociatedExp(a,{}f)} is linear over \\spad{F},{} \\spadignore{i.e.} for elements a from \\spad{\\$},{} \\spad{c},{}\\spad{d} form \\spad{F} and \\spad{f},{}\\spad{g} univariate polynomials over \\spad{F} we have \\spadfun{linearAssociatedExp}(a,{}cf+dg) equals \\spad{c} times \\spadfun{linearAssociatedExp}(a,{}\\spad{f}) plus \\spad{d} times \\spadfun{linearAssociatedExp}(a,{}\\spad{g}). Therefore \\spadfun{linearAssociatedExp} is defined completely by its action on monomials from \\spad{F}[\\spad{X}]: \\spadfun{linearAssociatedExp}(a,{}monomial(1,{}\\spad{k})\\spad{\\$}SUP(\\spad{F})) is defined to be \\spadfun{Frobenius}(a,{}\\spad{k}) which is a**(q**k),{} where q=size()\\spad{\\$}\\spad{F}.")) (|generator| (($) "\\spad{generator()} returns a root of the defining polynomial. This element generates the field as an algebra over the ground field.")) (|normal?| (((|Boolean|) $) "\\spad{normal?(a)} tests whether the element \\spad{a} is normal over the ground field \\spad{F},{} \\spadignore{i.e.} \\spad{a**(q**i),{} 0 <= i <= extensionDegree()-1} is an \\spad{F}-basis,{} where \\spad{q = size()\\$F}. Implementation according to Lidl/Niederreiter: Theorem 2.39.")) (|normalElement| (($) "\\spad{normalElement()} returns a element,{} normal over the ground field \\spad{F},{} \\spadignore{i.e.} \\spad{a**(q**i),{} 0 <= i < extensionDegree()} is an \\spad{F}-basis,{} where \\spad{q = size()\\$F}. At the first call,{} the element is computed by \\spadfunFrom{createNormalElement}{FiniteAlgebraicExtensionField} then cached in a global variable. On subsequent calls,{} the element is retrieved by referencing the global variable.")) (|createNormalElement| (($) "\\spad{createNormalElement()} computes a normal element over the ground field \\spad{F},{} that is,{} \\spad{a**(q**i),{} 0 <= i < extensionDegree()} is an \\spad{F}-basis,{} where \\spad{q = size()\\$F}. Reference: Such an element exists Lidl/Niederreiter: Theorem 2.35.")) (|trace| (($ $ (|PositiveInteger|)) "\\spad{trace(a,{}d)} computes the trace of \\spad{a} with respect to the field of extension degree \\spad{d} over the ground field of size \\spad{q}. Error: if \\spad{d} does not divide the extension degree of \\spad{a}. Note that \\spad{trace(a,{}d)=reduce(+,{}[a**(q**(d*i)) for i in 0..n/d])}.") ((|#2| $) "\\spad{trace(a)} computes the trace of \\spad{a} with respect to the field considered as an algebra with 1 over the ground field \\spad{F}.")) (|norm| (($ $ (|PositiveInteger|)) "\\spad{norm(a,{}d)} computes the norm of \\spad{a} with respect to the field of extension degree \\spad{d} over the ground field of size. Error: if \\spad{d} does not divide the extension degree of \\spad{a}. Note that norm(a,{}\\spad{d}) = reduce(*,{}[a**(\\spad{q**}(d*i)) for \\spad{i} in 0..\\spad{n/d}])") ((|#2| $) "\\spad{norm(a)} computes the norm of \\spad{a} with respect to the field considered as an algebra with 1 over the ground field \\spad{F}.")) (|degree| (((|PositiveInteger|) $) "\\spad{degree(a)} returns the degree of the minimal polynomial of an element \\spad{a} over the ground field \\spad{F}.")) (|extensionDegree| (((|PositiveInteger|)) "\\spad{extensionDegree()} returns the degree of field extension.")) (|definingPolynomial| (((|SparseUnivariatePolynomial| |#2|)) "\\spad{definingPolynomial()} returns the polynomial used to define the field extension.")) (|minimalPolynomial| (((|SparseUnivariatePolynomial| $) $ (|PositiveInteger|)) "\\spad{minimalPolynomial(x,{}n)} computes the minimal polynomial of \\spad{x} over the field of extension degree \\spad{n} over the ground field \\spad{F}.") (((|SparseUnivariatePolynomial| |#2|) $) "\\spad{minimalPolynomial(a)} returns the minimal polynomial of an element \\spad{a} over the ground field \\spad{F}.")) (|represents| (($ (|Vector| |#2|)) "\\spad{represents([a1,{}..,{}an])} returns \\spad{a1*v1 + ... + an*vn},{} where \\spad{v1},{}...,{}\\spad{vn} are the elements of the fixed basis.")) (|coordinates| (((|Matrix| |#2|) (|Vector| $)) "\\spad{coordinates([v1,{}...,{}vm])} returns the coordinates of the \\spad{vi}\\spad{'s} with to the fixed basis. The coordinates of \\spad{vi} are contained in the \\spad{i}th row of the matrix returned by this function.") (((|Vector| |#2|) $) "\\spad{coordinates(a)} returns the coordinates of \\spad{a} with respect to the fixed \\spad{F}-vectorspace basis.")) (|basis| (((|Vector| $) (|PositiveInteger|)) "\\spad{basis(n)} returns a fixed basis of a subfield of \\spad{\\$} as \\spad{F}-vectorspace.") (((|Vector| $)) "\\spad{basis()} returns a fixed basis of \\spad{\\$} as \\spad{F}-vectorspace."))) 
 NIL 
 ((|HasCategory| |#2| (QUOTE (-370)))) 
 (-327 -1478) 
 ((|constructor| (NIL "FiniteAlgebraicExtensionField \\spad{F} is the category of fields which are finite algebraic extensions of the field \\spad{F}. If \\spad{F} is finite then any finite algebraic extension of \\spad{F} is finite,{} too. Let \\spad{K} be a finite algebraic extension of the finite field \\spad{F}. The exponentiation of elements of \\spad{K} defines a \\spad{Z}-module structure on the multiplicative group of \\spad{K}. The additive group of \\spad{K} becomes a module over the ring of polynomials over \\spad{F} via the operation \\spadfun{linearAssociatedExp}(a:K,{}f:SparseUnivariatePolynomial \\spad{F}) which is linear over \\spad{F},{} \\spadignore{i.e.} for elements a from \\spad{K},{} \\spad{c},{}\\spad{d} from \\spad{F} and \\spad{f},{}\\spad{g} univariate polynomials over \\spad{F} we have \\spadfun{linearAssociatedExp}(a,{}cf+dg) equals \\spad{c} times \\spadfun{linearAssociatedExp}(a,{}\\spad{f}) plus \\spad{d} times \\spadfun{linearAssociatedExp}(a,{}\\spad{g}). Therefore \\spadfun{linearAssociatedExp} is defined completely by its action on monomials from \\spad{F}[\\spad{X}]: \\spadfun{linearAssociatedExp}(a,{}monomial(1,{}\\spad{k})\\spad{\\$}SUP(\\spad{F})) is defined to be \\spadfun{Frobenius}(a,{}\\spad{k}) which is a**(q**k) where q=size()\\spad{\\$}\\spad{F}. The operations order and discreteLog associated with the multiplicative exponentiation have additive analogues associated to the operation \\spadfun{linearAssociatedExp}. These are the functions \\spadfun{linearAssociatedOrder} and \\spadfun{linearAssociatedLog},{} respectively.")) (|linearAssociatedLog| (((|Union| (|SparseUnivariatePolynomial| |#1|) "failed") $ $) "\\spad{linearAssociatedLog(b,{}a)} returns a polynomial \\spad{g},{} such that the \\spadfun{linearAssociatedExp}(\\spad{b},{}\\spad{g}) equals a. If there is no such polynomial \\spad{g},{} then \\spadfun{linearAssociatedLog} fails.") (((|SparseUnivariatePolynomial| |#1|) $) "\\spad{linearAssociatedLog(a)} returns a polynomial \\spad{g},{} such that \\spadfun{linearAssociatedExp}(normalElement(),{}\\spad{g}) equals a.")) (|linearAssociatedOrder| (((|SparseUnivariatePolynomial| |#1|) $) "\\spad{linearAssociatedOrder(a)} retruns the monic polynomial \\spad{g} of least degree,{} such that \\spadfun{linearAssociatedExp}(a,{}\\spad{g}) is 0.")) (|linearAssociatedExp| (($ $ (|SparseUnivariatePolynomial| |#1|)) "\\spad{linearAssociatedExp(a,{}f)} is linear over \\spad{F},{} \\spadignore{i.e.} for elements a from \\spad{\\$},{} \\spad{c},{}\\spad{d} form \\spad{F} and \\spad{f},{}\\spad{g} univariate polynomials over \\spad{F} we have \\spadfun{linearAssociatedExp}(a,{}cf+dg) equals \\spad{c} times \\spadfun{linearAssociatedExp}(a,{}\\spad{f}) plus \\spad{d} times \\spadfun{linearAssociatedExp}(a,{}\\spad{g}). Therefore \\spadfun{linearAssociatedExp} is defined completely by its action on monomials from \\spad{F}[\\spad{X}]: \\spadfun{linearAssociatedExp}(a,{}monomial(1,{}\\spad{k})\\spad{\\$}SUP(\\spad{F})) is defined to be \\spadfun{Frobenius}(a,{}\\spad{k}) which is a**(q**k),{} where q=size()\\spad{\\$}\\spad{F}.")) (|generator| (($) "\\spad{generator()} returns a root of the defining polynomial. This element generates the field as an algebra over the ground field.")) (|normal?| (((|Boolean|) $) "\\spad{normal?(a)} tests whether the element \\spad{a} is normal over the ground field \\spad{F},{} \\spadignore{i.e.} \\spad{a**(q**i),{} 0 <= i <= extensionDegree()-1} is an \\spad{F}-basis,{} where \\spad{q = size()\\$F}. Implementation according to Lidl/Niederreiter: Theorem 2.39.")) (|normalElement| (($) "\\spad{normalElement()} returns a element,{} normal over the ground field \\spad{F},{} \\spadignore{i.e.} \\spad{a**(q**i),{} 0 <= i < extensionDegree()} is an \\spad{F}-basis,{} where \\spad{q = size()\\$F}. At the first call,{} the element is computed by \\spadfunFrom{createNormalElement}{FiniteAlgebraicExtensionField} then cached in a global variable. On subsequent calls,{} the element is retrieved by referencing the global variable.")) (|createNormalElement| (($) "\\spad{createNormalElement()} computes a normal element over the ground field \\spad{F},{} that is,{} \\spad{a**(q**i),{} 0 <= i < extensionDegree()} is an \\spad{F}-basis,{} where \\spad{q = size()\\$F}. Reference: Such an element exists Lidl/Niederreiter: Theorem 2.35.")) (|trace| (($ $ (|PositiveInteger|)) "\\spad{trace(a,{}d)} computes the trace of \\spad{a} with respect to the field of extension degree \\spad{d} over the ground field of size \\spad{q}. Error: if \\spad{d} does not divide the extension degree of \\spad{a}. Note that \\spad{trace(a,{}d)=reduce(+,{}[a**(q**(d*i)) for i in 0..n/d])}.") ((|#1| $) "\\spad{trace(a)} computes the trace of \\spad{a} with respect to the field considered as an algebra with 1 over the ground field \\spad{F}.")) (|norm| (($ $ (|PositiveInteger|)) "\\spad{norm(a,{}d)} computes the norm of \\spad{a} with respect to the field of extension degree \\spad{d} over the ground field of size. Error: if \\spad{d} does not divide the extension degree of \\spad{a}. Note that norm(a,{}\\spad{d}) = reduce(*,{}[a**(\\spad{q**}(d*i)) for \\spad{i} in 0..\\spad{n/d}])") ((|#1| $) "\\spad{norm(a)} computes the norm of \\spad{a} with respect to the field considered as an algebra with 1 over the ground field \\spad{F}.")) (|degree| (((|PositiveInteger|) $) "\\spad{degree(a)} returns the degree of the minimal polynomial of an element \\spad{a} over the ground field \\spad{F}.")) (|extensionDegree| (((|PositiveInteger|)) "\\spad{extensionDegree()} returns the degree of field extension.")) (|definingPolynomial| (((|SparseUnivariatePolynomial| |#1|)) "\\spad{definingPolynomial()} returns the polynomial used to define the field extension.")) (|minimalPolynomial| (((|SparseUnivariatePolynomial| $) $ (|PositiveInteger|)) "\\spad{minimalPolynomial(x,{}n)} computes the minimal polynomial of \\spad{x} over the field of extension degree \\spad{n} over the ground field \\spad{F}.") (((|SparseUnivariatePolynomial| |#1|) $) "\\spad{minimalPolynomial(a)} returns the minimal polynomial of an element \\spad{a} over the ground field \\spad{F}.")) (|represents| (($ (|Vector| |#1|)) "\\spad{represents([a1,{}..,{}an])} returns \\spad{a1*v1 + ... + an*vn},{} where \\spad{v1},{}...,{}\\spad{vn} are the elements of the fixed basis.")) (|coordinates| (((|Matrix| |#1|) (|Vector| $)) "\\spad{coordinates([v1,{}...,{}vm])} returns the coordinates of the \\spad{vi}\\spad{'s} with to the fixed basis. The coordinates of \\spad{vi} are contained in the \\spad{i}th row of the matrix returned by this function.") (((|Vector| |#1|) $) "\\spad{coordinates(a)} returns the coordinates of \\spad{a} with respect to the fixed \\spad{F}-vectorspace basis.")) (|basis| (((|Vector| $) (|PositiveInteger|)) "\\spad{basis(n)} returns a fixed basis of a subfield of \\spad{\\$} as \\spad{F}-vectorspace.") (((|Vector| $)) "\\spad{basis()} returns a fixed basis of \\spad{\\$} as \\spad{F}-vectorspace."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-328) 
 ((|constructor| (NIL "This domain builds representations of program code segments for use with the FortranProgram domain.")) (|setLabelValue| (((|SingleInteger|) (|SingleInteger|)) "\\spad{setLabelValue(i)} resets the counter which produces labels to \\spad{i}")) (|getCode| (((|SExpression|) $) "\\spad{getCode(f)} returns a Lisp list of strings representing \\spad{f} in Fortran notation. This is used by the FortranProgram domain.")) (|printCode| (((|Void|) $) "\\spad{printCode(f)} prints out \\spad{f} in FORTRAN notation.")) (|code| (((|Union| (|:| |nullBranch| "null") (|:| |assignmentBranch| (|Record| (|:| |var| (|Symbol|)) (|:| |arrayIndex| (|List| (|Polynomial| (|Integer|)))) (|:| |rand| (|Record| (|:| |ints2Floats?| (|Boolean|)) (|:| |expr| (|OutputForm|)))))) (|:| |arrayAssignmentBranch| (|Record| (|:| |var| (|Symbol|)) (|:| |rand| (|OutputForm|)) (|:| |ints2Floats?| (|Boolean|)))) (|:| |conditionalBranch| (|Record| (|:| |switch| (|Switch|)) (|:| |thenClause| $) (|:| |elseClause| $))) (|:| |returnBranch| (|Record| (|:| |empty?| (|Boolean|)) (|:| |value| (|Record| (|:| |ints2Floats?| (|Boolean|)) (|:| |expr| (|OutputForm|)))))) (|:| |blockBranch| (|List| $)) (|:| |commentBranch| (|List| (|String|))) (|:| |callBranch| (|String|)) (|:| |forBranch| (|Record| (|:| |range| (|SegmentBinding| (|Polynomial| (|Integer|)))) (|:| |span| (|Polynomial| (|Integer|))) (|:| |body| $))) (|:| |labelBranch| (|SingleInteger|)) (|:| |loopBranch| (|Record| (|:| |switch| (|Switch|)) (|:| |body| $))) (|:| |commonBranch| (|Record| (|:| |name| (|Symbol|)) (|:| |contents| (|List| (|Symbol|))))) (|:| |printBranch| (|List| (|OutputForm|)))) $) "\\spad{code(f)} returns the internal representation of the object represented by \\spad{f}.")) (|operation| (((|Union| (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print")) $) "\\spad{operation(f)} returns the name of the operation represented by \\spad{f}.")) (|common| (($ (|Symbol|) (|List| (|Symbol|))) "\\spad{common(name,{}contents)} creates a representation a named common block.")) (|printStatement| (($ (|List| (|OutputForm|))) "\\spad{printStatement(l)} creates a representation of a PRINT statement.")) (|save| (($) "\\spad{save()} creates a representation of a SAVE statement.")) (|stop| (($) "\\spad{stop()} creates a representation of a STOP statement.")) (|block| (($ (|List| $)) "\\spad{block(l)} creates a representation of the statements in \\spad{l} as a block.")) (|assign| (($ (|Symbol|) (|List| (|Polynomial| (|Integer|))) (|Expression| (|Complex| (|Float|)))) "\\spad{assign(x,{}l,{}y)} creates a representation of the assignment of \\spad{y} to the \\spad{l}\\spad{'}th element of array \\spad{x} (\\spad{l} is a list of indices).") (($ (|Symbol|) (|List| (|Polynomial| (|Integer|))) (|Expression| (|Float|))) "\\spad{assign(x,{}l,{}y)} creates a representation of the assignment of \\spad{y} to the \\spad{l}\\spad{'}th element of array \\spad{x} (\\spad{l} is a list of indices).") (($ (|Symbol|) (|List| (|Polynomial| (|Integer|))) (|Expression| (|Integer|))) "\\spad{assign(x,{}l,{}y)} creates a representation of the assignment of \\spad{y} to the \\spad{l}\\spad{'}th element of array \\spad{x} (\\spad{l} is a list of indices).") (($ (|Symbol|) (|Vector| (|Expression| (|Complex| (|Float|))))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Vector| (|Expression| (|Float|)))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Vector| (|Expression| (|Integer|)))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Matrix| (|Expression| (|Complex| (|Float|))))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Matrix| (|Expression| (|Float|)))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Matrix| (|Expression| (|Integer|)))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Expression| (|Complex| (|Float|)))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Expression| (|Float|))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Expression| (|Integer|))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|List| (|Polynomial| (|Integer|))) (|Expression| (|MachineComplex|))) "\\spad{assign(x,{}l,{}y)} creates a representation of the assignment of \\spad{y} to the \\spad{l}\\spad{'}th element of array \\spad{x} (\\spad{l} is a list of indices).") (($ (|Symbol|) (|List| (|Polynomial| (|Integer|))) (|Expression| (|MachineFloat|))) "\\spad{assign(x,{}l,{}y)} creates a representation of the assignment of \\spad{y} to the \\spad{l}\\spad{'}th element of array \\spad{x} (\\spad{l} is a list of indices).") (($ (|Symbol|) (|List| (|Polynomial| (|Integer|))) (|Expression| (|MachineInteger|))) "\\spad{assign(x,{}l,{}y)} creates a representation of the assignment of \\spad{y} to the \\spad{l}\\spad{'}th element of array \\spad{x} (\\spad{l} is a list of indices).") (($ (|Symbol|) (|Vector| (|Expression| (|MachineComplex|)))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Vector| (|Expression| (|MachineFloat|)))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Vector| (|Expression| (|MachineInteger|)))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Matrix| (|Expression| (|MachineComplex|)))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Matrix| (|Expression| (|MachineFloat|)))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Matrix| (|Expression| (|MachineInteger|)))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Vector| (|MachineComplex|))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Vector| (|MachineFloat|))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Vector| (|MachineInteger|))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Matrix| (|MachineComplex|))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Matrix| (|MachineFloat|))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Matrix| (|MachineInteger|))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Expression| (|MachineComplex|))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Expression| (|MachineFloat|))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|Expression| (|MachineInteger|))) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.") (($ (|Symbol|) (|String|)) "\\spad{assign(x,{}y)} creates a representation of the FORTRAN expression x=y.")) (|cond| (($ (|Switch|) $ $) "\\spad{cond(s,{}e,{}f)} creates a representation of the FORTRAN expression IF (\\spad{s}) THEN \\spad{e} ELSE \\spad{f}.") (($ (|Switch|) $) "\\spad{cond(s,{}e)} creates a representation of the FORTRAN expression IF (\\spad{s}) THEN \\spad{e}.")) (|returns| (($ (|Expression| (|Complex| (|Float|)))) "\\spad{returns(e)} creates a representation of a FORTRAN RETURN statement with a returned value.") (($ (|Expression| (|Integer|))) "\\spad{returns(e)} creates a representation of a FORTRAN RETURN statement with a returned value.") (($ (|Expression| (|Float|))) "\\spad{returns(e)} creates a representation of a FORTRAN RETURN statement with a returned value.") (($ (|Expression| (|MachineComplex|))) "\\spad{returns(e)} creates a representation of a FORTRAN RETURN statement with a returned value.") (($ (|Expression| (|MachineInteger|))) "\\spad{returns(e)} creates a representation of a FORTRAN RETURN statement with a returned value.") (($ (|Expression| (|MachineFloat|))) "\\spad{returns(e)} creates a representation of a FORTRAN RETURN statement with a returned value.") (($) "\\spad{returns()} creates a representation of a FORTRAN RETURN statement.")) (|call| (($ (|String|)) "\\spad{call(s)} creates a representation of a FORTRAN CALL statement")) (|comment| (($ (|List| (|String|))) "\\spad{comment(s)} creates a representation of the Strings \\spad{s} as a multi-line FORTRAN comment.") (($ (|String|)) "\\spad{comment(s)} creates a representation of the String \\spad{s} as a single FORTRAN comment.")) (|continue| (($ (|SingleInteger|)) "\\spad{continue(l)} creates a representation of a FORTRAN CONTINUE labelled with \\spad{l}")) (|goto| (($ (|SingleInteger|)) "\\spad{goto(l)} creates a representation of a FORTRAN GOTO statement")) (|repeatUntilLoop| (($ (|Switch|) $) "\\spad{repeatUntilLoop(s,{}c)} creates a repeat ... until loop in FORTRAN.")) (|whileLoop| (($ (|Switch|) $) "\\spad{whileLoop(s,{}c)} creates a while loop in FORTRAN.")) (|forLoop| (($ (|SegmentBinding| (|Polynomial| (|Integer|))) (|Polynomial| (|Integer|)) $) "\\spad{forLoop(i=1..10,{}n,{}c)} creates a representation of a FORTRAN DO loop with \\spad{i} ranging over the values 1 to 10 by \\spad{n}.") (($ (|SegmentBinding| (|Polynomial| (|Integer|))) $) "\\spad{forLoop(i=1..10,{}c)} creates a representation of a FORTRAN DO loop with \\spad{i} ranging over the values 1 to 10.")) (|coerce| (((|OutputForm|) $) "\\spad{coerce(f)} returns an object of type OutputForm."))) 
@@ -1278,7 +1278,7 @@ NIL
 NIL 
 (-337 |basicSymbols| |subscriptedSymbols| R) 
 ((|constructor| (NIL "A domain of expressions involving functions which can be translated into standard Fortran-77,{} with some extra extensions from the NAG Fortran Library.")) (|useNagFunctions| (((|Boolean|) (|Boolean|)) "\\spad{useNagFunctions(v)} sets the flag which controls whether NAG functions \\indented{1}{are being used for mathematical and machine constants.\\space{2}The previous} \\indented{1}{value is returned.}") (((|Boolean|)) "\\spad{useNagFunctions()} indicates whether NAG functions are being used \\indented{1}{for mathematical and machine constants.}")) (|variables| (((|List| (|Symbol|)) $) "\\spad{variables(e)} return a list of all the variables in \\spad{e}.")) (|pi| (($) "\\spad{\\spad{pi}(x)} represents the NAG Library function X01AAF which returns \\indented{1}{an approximation to the value of \\spad{pi}}")) (|tanh| (($ $) "\\spad{tanh(x)} represents the Fortran intrinsic function TANH")) (|cosh| (($ $) "\\spad{cosh(x)} represents the Fortran intrinsic function COSH")) (|sinh| (($ $) "\\spad{sinh(x)} represents the Fortran intrinsic function SINH")) (|atan| (($ $) "\\spad{atan(x)} represents the Fortran intrinsic function ATAN")) (|acos| (($ $) "\\spad{acos(x)} represents the Fortran intrinsic function ACOS")) (|asin| (($ $) "\\spad{asin(x)} represents the Fortran intrinsic function ASIN")) (|tan| (($ $) "\\spad{tan(x)} represents the Fortran intrinsic function TAN")) (|cos| (($ $) "\\spad{cos(x)} represents the Fortran intrinsic function COS")) (|sin| (($ $) "\\spad{sin(x)} represents the Fortran intrinsic function SIN")) (|log10| (($ $) "\\spad{log10(x)} represents the Fortran intrinsic function \\spad{LOG10}")) (|log| (($ $) "\\spad{log(x)} represents the Fortran intrinsic function LOG")) (|exp| (($ $) "\\spad{exp(x)} represents the Fortran intrinsic function EXP")) (|sqrt| (($ $) "\\spad{sqrt(x)} represents the Fortran intrinsic function SQRT")) (|abs| (($ $) "\\spad{abs(x)} represents the Fortran intrinsic function ABS")) (|coerce| (((|Expression| |#3|) $) "\\spad{coerce(x)} is not documented")) (|retractIfCan| (((|Union| $ "failed") (|Polynomial| (|Float|))) "\\spad{retractIfCan(e)} takes \\spad{e} and tries to transform it into a FortranExpression checking that it contains no non-Fortran functions,{} and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (((|Union| $ "failed") (|Fraction| (|Polynomial| (|Float|)))) "\\spad{retractIfCan(e)} takes \\spad{e} and tries to transform it into a FortranExpression checking that it contains no non-Fortran functions,{} and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (((|Union| $ "failed") (|Expression| (|Float|))) "\\spad{retractIfCan(e)} takes \\spad{e} and tries to transform it into a FortranExpression checking that it contains no non-Fortran functions,{} and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (((|Union| $ "failed") (|Polynomial| (|Integer|))) "\\spad{retractIfCan(e)} takes \\spad{e} and tries to transform it into a FortranExpression checking that it contains no non-Fortran functions,{} and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (((|Union| $ "failed") (|Fraction| (|Polynomial| (|Integer|)))) "\\spad{retractIfCan(e)} takes \\spad{e} and tries to transform it into a FortranExpression checking that it contains no non-Fortran functions,{} and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (((|Union| $ "failed") (|Expression| (|Integer|))) "\\spad{retractIfCan(e)} takes \\spad{e} and tries to transform it into a FortranExpression checking that it contains no non-Fortran functions,{} and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (((|Union| $ "failed") (|Symbol|)) "\\spad{retractIfCan(e)} takes \\spad{e} and tries to transform it into a FortranExpression checking that it is one of the given basic symbols or subscripted symbols which correspond to scalar and array parameters respectively.") (((|Union| $ "failed") (|Expression| |#3|)) "\\spad{retractIfCan(e)} takes \\spad{e} and tries to transform it into a FortranExpression checking that it contains no non-Fortran functions,{} and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.")) (|retract| (($ (|Polynomial| (|Float|))) "\\spad{retract(e)} takes \\spad{e} and transforms it into a FortranExpression checking that it contains no non-Fortran functions,{} and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (($ (|Fraction| (|Polynomial| (|Float|)))) "\\spad{retract(e)} takes \\spad{e} and transforms it into a FortranExpression checking that it contains no non-Fortran functions,{} and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (($ (|Expression| (|Float|))) "\\spad{retract(e)} takes \\spad{e} and transforms it into a FortranExpression checking that it contains no non-Fortran functions,{} and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (($ (|Polynomial| (|Integer|))) "\\spad{retract(e)} takes \\spad{e} and transforms it into a FortranExpression checking that it contains no non-Fortran functions,{} and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (($ (|Fraction| (|Polynomial| (|Integer|)))) "\\spad{retract(e)} takes \\spad{e} and transforms it into a FortranExpression checking that it contains no non-Fortran functions,{} and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (($ (|Expression| (|Integer|))) "\\spad{retract(e)} takes \\spad{e} and transforms it into a FortranExpression checking that it contains no non-Fortran functions,{} and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively.") (($ (|Symbol|)) "\\spad{retract(e)} takes \\spad{e} and transforms it into a FortranExpression checking that it is one of the given basic symbols or subscripted symbols which correspond to scalar and array parameters respectively.") (($ (|Expression| |#3|)) "\\spad{retract(e)} takes \\spad{e} and transforms it into a FortranExpression checking that it contains no non-Fortran functions,{} and that it only contains the given basic symbols and subscripted symbols which correspond to scalar and array parameters respectively."))) 
-((-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4515 . T) (-4516 . T) (-4518 . T)) 
 ((|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-381)))) (|HasCategory| $ (QUOTE (-1047))) (|HasCategory| $ (LIST (QUOTE -1037) (QUOTE (-568))))) 
 (-338 R1 UP1 UPUP1 F1 R2 UP2 UPUP2 F2) 
 ((|constructor| (NIL "Lifts a map from rings to function fields over them.")) (|map| ((|#8| (|Mapping| |#5| |#1|) |#4|) "\\spad{map(f,{} p)} lifts \\spad{f} to \\spad{F1} and applies it to \\spad{p}."))) 
@@ -1290,29 +1290,29 @@ NIL
 ((|HasCategory| |#2| (QUOTE (-370))) (|HasCategory| |#2| (QUOTE (-365)))) 
 (-340 -1478 UP UPUP) 
 ((|constructor| (NIL "This category is a model for the function field of a plane algebraic curve.")) (|rationalPoints| (((|List| (|List| |#1|))) "\\indented{1}{rationalPoints() returns the list of all the affine} rational points.")) (|nonSingularModel| (((|List| (|Polynomial| |#1|)) (|Symbol|)) "\\spad{nonSingularModel(u)} returns the equations in \\spad{u1},{}...,{}un of an affine non-singular model for the curve.")) (|algSplitSimple| (((|Record| (|:| |num| $) (|:| |den| |#2|) (|:| |derivden| |#2|) (|:| |gd| |#2|)) $ (|Mapping| |#2| |#2|)) "\\spad{algSplitSimple(f,{} D)} returns \\spad{[h,{}d,{}d',{}g]} such that \\spad{f=h/d},{} \\spad{h} is integral at all the normal places \\spad{w}.\\spad{r}.\\spad{t}. \\spad{D},{} \\spad{d' = Dd},{} \\spad{g = gcd(d,{} discriminant())} and \\spad{D} is the derivation to use. \\spad{f} must have at most simple finite poles.")) (|hyperelliptic| (((|Union| |#2| "failed")) "\\spad{hyperelliptic()} returns \\spad{p(x)} if the curve is the hyperelliptic defined by \\spad{y**2 = p(x)},{} \"failed\" otherwise.")) (|elliptic| (((|Union| |#2| "failed")) "\\spad{elliptic()} returns \\spad{p(x)} if the curve is the elliptic defined by \\spad{y**2 = p(x)},{} \"failed\" otherwise.")) (|elt| ((|#1| $ |#1| |#1|) "\\spad{elt(f,{}a,{}b)} or \\spad{f}(a,{} \\spad{b}) returns the value of \\spad{f} at the point \\spad{(x = a,{} y = b)} if it is not singular.")) (|primitivePart| (($ $) "\\spad{primitivePart(f)} removes the content of the denominator and the common content of the numerator of \\spad{f}.")) (|differentiate| (($ $ (|Mapping| |#2| |#2|)) "\\spad{differentiate(x,{} d)} extends the derivation \\spad{d} from UP to \\$ and applies it to \\spad{x}.")) (|integralDerivationMatrix| (((|Record| (|:| |num| (|Matrix| |#2|)) (|:| |den| |#2|)) (|Mapping| |#2| |#2|)) "\\spad{integralDerivationMatrix(d)} extends the derivation \\spad{d} from UP to \\$ and returns (\\spad{M},{} \\spad{Q}) such that the i^th row of \\spad{M} divided by \\spad{Q} form the coordinates of \\spad{d(\\spad{wi})} with respect to \\spad{(w1,{}...,{}wn)} where \\spad{(w1,{}...,{}wn)} is the integral basis returned by integralBasis().")) (|integralRepresents| (($ (|Vector| |#2|) |#2|) "\\spad{integralRepresents([A1,{}...,{}An],{} D)} returns \\spad{(A1 w1+...+An wn)/D} where \\spad{(w1,{}...,{}wn)} is the integral basis of \\spad{integralBasis()}.")) (|integralCoordinates| (((|Record| (|:| |num| (|Vector| |#2|)) (|:| |den| |#2|)) $) "\\spad{integralCoordinates(f)} returns \\spad{[[A1,{}...,{}An],{} D]} such that \\spad{f = (A1 w1 +...+ An wn) / D} where \\spad{(w1,{}...,{}wn)} is the integral basis returned by \\spad{integralBasis()}.")) (|represents| (($ (|Vector| |#2|) |#2|) "\\spad{represents([A0,{}...,{}A(n-1)],{}D)} returns \\spad{(A0 + A1 y +...+ A(n-1)*y**(n-1))/D}.") (($ (|Vector| |#2|) |#2|) "\\spad{represents([A0,{}...,{}A(n-1)],{}D)} returns \\spad{(A0 + A1 y +...+ A(n-1)*y**(n-1))/D}.")) (|yCoordinates| (((|Record| (|:| |num| (|Vector| |#2|)) (|:| |den| |#2|)) $) "\\spad{yCoordinates(f)} returns \\spad{[[A1,{}...,{}An],{} D]} such that \\spad{f = (A1 + A2 y +...+ An y**(n-1)) / D}.")) (|inverseIntegralMatrixAtInfinity| (((|Matrix| (|Fraction| |#2|))) "\\indented{1}{inverseIntegralMatrixAtInfinity() returns \\spad{M} such} \\indented{1}{that \\spad{M (v1,{}...,{}vn) = (1,{} y,{} ...,{} y**(n-1))}} \\indented{1}{where \\spad{(v1,{}...,{}vn)} is the local integral basis at infinity} \\indented{1}{returned by \\spad{infIntBasis()}.} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(\\spad{x},{} Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(\\spad{y},{} Fraction \\spad{P0}) \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT,{} \\spad{P0},{} \\spad{P1},{} 1 - \\spad{x**20},{} 20) \\spad{X} inverseIntegralMatrixAtInfinity()\\$\\spad{R}")) (|integralMatrixAtInfinity| (((|Matrix| (|Fraction| |#2|))) "\\indented{1}{integralMatrixAtInfinity() returns \\spad{M} such that} \\indented{1}{\\spad{(v1,{}...,{}vn) = M (1,{} y,{} ...,{} y**(n-1))}} \\indented{1}{where \\spad{(v1,{}...,{}vn)} is the local integral basis at infinity} \\indented{1}{returned by \\spad{infIntBasis()}.} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(\\spad{x},{} Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(\\spad{y},{} Fraction \\spad{P0}) \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT,{} \\spad{P0},{} \\spad{P1},{} 1 - \\spad{x**20},{} 20) \\spad{X} integralMatrixAtInfinity()\\$\\spad{R}")) (|inverseIntegralMatrix| (((|Matrix| (|Fraction| |#2|))) "\\indented{1}{inverseIntegralMatrix() returns \\spad{M} such that} \\indented{1}{\\spad{M (w1,{}...,{}wn) = (1,{} y,{} ...,{} y**(n-1))}} \\indented{1}{where \\spad{(w1,{}...,{}wn)} is the integral basis of} \\indented{1}{\\spadfunFrom{integralBasis}{FunctionFieldCategory}.} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(\\spad{x},{} Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(\\spad{y},{} Fraction \\spad{P0}) \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT,{} \\spad{P0},{} \\spad{P1},{} 1 - \\spad{x**20},{} 20) \\spad{X} inverseIntegralMatrix()\\$\\spad{R}")) (|integralMatrix| (((|Matrix| (|Fraction| |#2|))) "\\indented{1}{integralMatrix() returns \\spad{M} such that} \\indented{1}{\\spad{(w1,{}...,{}wn) = M (1,{} y,{} ...,{} y**(n-1))},{}} \\indented{1}{where \\spad{(w1,{}...,{}wn)} is the integral basis of} \\indented{1}{\\spadfunFrom{integralBasis}{FunctionFieldCategory}.} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(\\spad{x},{} Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(\\spad{y},{} Fraction \\spad{P0}) \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT,{} \\spad{P0},{} \\spad{P1},{} 1 - \\spad{x**20},{} 20) \\spad{X} integralMatrix()\\$\\spad{R}")) (|reduceBasisAtInfinity| (((|Vector| $) (|Vector| $)) "\\spad{reduceBasisAtInfinity(b1,{}...,{}bn)} returns \\spad{(x**i * bj)} for all \\spad{i},{}\\spad{j} such that \\spad{x**i*bj} is locally integral at infinity.")) (|normalizeAtInfinity| (((|Vector| $) (|Vector| $)) "\\spad{normalizeAtInfinity(v)} makes \\spad{v} normal at infinity.")) (|complementaryBasis| (((|Vector| $) (|Vector| $)) "\\spad{complementaryBasis(b1,{}...,{}bn)} returns the complementary basis \\spad{(b1',{}...,{}bn')} of \\spad{(b1,{}...,{}bn)}.")) (|integral?| (((|Boolean|) $ |#2|) "\\spad{integral?(f,{} p)} tests whether \\spad{f} is locally integral at \\spad{p(x) = 0}") (((|Boolean|) $ |#1|) "\\spad{integral?(f,{} a)} tests whether \\spad{f} is locally integral at \\spad{x = a}.") (((|Boolean|) $) "\\spad{integral?()} tests if \\spad{f} is integral over \\spad{k[x]}.")) (|integralAtInfinity?| (((|Boolean|) $) "\\spad{integralAtInfinity?()} tests if \\spad{f} is locally integral at infinity.")) (|integralBasisAtInfinity| (((|Vector| $)) "\\indented{1}{integralBasisAtInfinity() returns the local integral basis} \\indented{1}{at infinity} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(\\spad{x},{} Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(\\spad{y},{} Fraction \\spad{P0}) \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT,{} \\spad{P0},{} \\spad{P1},{} 1 - \\spad{x**20},{} 20) \\spad{X} integralBasisAtInfinity()\\$\\spad{R}")) (|integralBasis| (((|Vector| $)) "\\indented{1}{integralBasis() returns the integral basis for the curve.} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(\\spad{x},{} Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(\\spad{y},{} Fraction \\spad{P0}) \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT,{} \\spad{P0},{} \\spad{P1},{} 1 - \\spad{x**20},{} 20) \\spad{X} integralBasis()\\$\\spad{R}")) (|ramified?| (((|Boolean|) |#2|) "\\spad{ramified?(p)} tests whether \\spad{p(x) = 0} is ramified.") (((|Boolean|) |#1|) "\\spad{ramified?(a)} tests whether \\spad{x = a} is ramified.")) (|ramifiedAtInfinity?| (((|Boolean|)) "\\spad{ramifiedAtInfinity?()} tests if infinity is ramified.")) (|singular?| (((|Boolean|) |#2|) "\\spad{singular?(p)} tests whether \\spad{p(x) = 0} is singular.") (((|Boolean|) |#1|) "\\spad{singular?(a)} tests whether \\spad{x = a} is singular.")) (|singularAtInfinity?| (((|Boolean|)) "\\spad{singularAtInfinity?()} tests if there is a singularity at infinity.")) (|branchPoint?| (((|Boolean|) |#2|) "\\spad{branchPoint?(p)} tests whether \\spad{p(x) = 0} is a branch point.") (((|Boolean|) |#1|) "\\spad{branchPoint?(a)} tests whether \\spad{x = a} is a branch point.")) (|branchPointAtInfinity?| (((|Boolean|)) "\\indented{1}{branchPointAtInfinity?() tests if there is a branch point} \\indented{1}{at infinity.} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(\\spad{x},{} Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(\\spad{y},{} Fraction \\spad{P0}) \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT,{} \\spad{P0},{} \\spad{P1},{} 1 - \\spad{x**20},{} 20) \\spad{X} branchPointAtInfinity?()\\$\\spad{R} \\spad{X} \\spad{R2} \\spad{:=} RadicalFunctionField(INT,{} \\spad{P0},{} \\spad{P1},{} 2 * \\spad{x**2},{} 4) \\spad{X} branchPointAtInfinity?()\\$\\spad{R}")) (|rationalPoint?| (((|Boolean|) |#1| |#1|) "\\indented{1}{rationalPoint?(a,{} \\spad{b}) tests if \\spad{(x=a,{}y=b)} is on the curve.} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(\\spad{x},{} Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(\\spad{y},{} Fraction \\spad{P0}) \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT,{} \\spad{P0},{} \\spad{P1},{} 1 - \\spad{x**20},{} 20) \\spad{X} rationalPoint?(0,{}0)\\$\\spad{R} \\spad{X} \\spad{R2} \\spad{:=} RadicalFunctionField(INT,{} \\spad{P0},{} \\spad{P1},{} 2 * \\spad{x**2},{} 4) \\spad{X} rationalPoint?(0,{}0)\\$\\spad{R2}")) (|absolutelyIrreducible?| (((|Boolean|)) "\\indented{1}{absolutelyIrreducible?() tests if the curve absolutely irreducible?} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(\\spad{x},{} Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(\\spad{y},{} Fraction \\spad{P0}) \\spad{X} \\spad{R2} \\spad{:=} RadicalFunctionField(INT,{} \\spad{P0},{} \\spad{P1},{} 2 * \\spad{x**2},{} 4) \\spad{X} absolutelyIrreducible?()\\$\\spad{R2}")) (|genus| (((|NonNegativeInteger|)) "\\indented{1}{genus() returns the genus of one absolutely irreducible component} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(\\spad{x},{} Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(\\spad{y},{} Fraction \\spad{P0}) \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT,{} \\spad{P0},{} \\spad{P1},{} 1 - \\spad{x**20},{} 20) \\spad{X} genus()\\$\\spad{R}")) (|numberOfComponents| (((|NonNegativeInteger|)) "\\indented{1}{numberOfComponents() returns the number of absolutely irreducible} \\indented{1}{components.} \\blankline \\spad{X} \\spad{P0} \\spad{:=} UnivariatePolynomial(\\spad{x},{} Integer) \\spad{X} \\spad{P1} \\spad{:=} UnivariatePolynomial(\\spad{y},{} Fraction \\spad{P0}) \\spad{X} \\spad{R} \\spad{:=} RadicalFunctionField(INT,{} \\spad{P0},{} \\spad{P1},{} 1 - \\spad{x**20},{} 20) \\spad{X} numberOfComponents()\\$\\spad{R}"))) 
-((-4512 |has| (-409 |#2|) (-365)) (-4517 |has| (-409 |#2|) (-365)) (-4511 |has| (-409 |#2|) (-365)) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4514 |has| (-409 |#2|) (-365)) (-4519 |has| (-409 |#2|) (-365)) (-4513 |has| (-409 |#2|) (-365)) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-341 |p| |extdeg|) 
 ((|constructor| (NIL "FiniteFieldCyclicGroup(\\spad{p},{}\\spad{n}) implements a finite field extension of degee \\spad{n} over the prime field with \\spad{p} elements. Its elements are represented by powers of a primitive element,{} \\spadignore{i.e.} a generator of the multiplicative (cyclic) group. As primitive element we choose the root of the extension polynomial,{} which is created by createPrimitivePoly from \\spadtype{FiniteFieldPolynomialPackage}. The Zech logarithms are stored in a table of size half of the field size,{} and use \\spadtype{SingleInteger} for representing field elements,{} hence,{} there are restrictions on the size of the field.")) (|getZechTable| (((|PrimitiveArray| (|SingleInteger|))) "\\spad{getZechTable()} returns the zech logarithm table of the field. This table is used to perform additions in the field quickly."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| (-905 |#1|) (QUOTE (-150))) (|HasCategory| (-905 |#1|) (QUOTE (-370))) (|HasCategory| (-905 |#1|) (QUOTE (-148))) (-2198 (|HasCategory| (-905 |#1|) (QUOTE (-148))) (|HasCategory| (-905 |#1|) (QUOTE (-370))))) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| (-905 |#1|) (QUOTE (-150))) (|HasCategory| (-905 |#1|) (QUOTE (-370))) (|HasCategory| (-905 |#1|) (QUOTE (-148))) (-2199 (|HasCategory| (-905 |#1|) (QUOTE (-148))) (|HasCategory| (-905 |#1|) (QUOTE (-370))))) 
 (-342 GF |defpol|) 
 ((|constructor| (NIL "FiniteFieldCyclicGroupExtensionByPolynomial(\\spad{GF},{}defpol) implements a finite extension field of the ground field \\spad{GF}. Its elements are represented by powers of a primitive element,{} \\spadignore{i.e.} a generator of the multiplicative (cyclic) group. As primitive element we choose the root of the extension polynomial defpol,{} which MUST be primitive (user responsibility). Zech logarithms are stored in a table of size half of the field size,{} and use \\spadtype{SingleInteger} for representing field elements,{} hence,{} there are restrictions on the size of the field.")) (|getZechTable| (((|PrimitiveArray| (|SingleInteger|))) "\\spad{getZechTable()} returns the zech logarithm table of the field it is used to perform additions in the field quickly."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (QUOTE (-148))) (-2198 (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-370))))) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (QUOTE (-148))) (-2199 (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-370))))) 
 (-343 GF |extdeg|) 
 ((|constructor| (NIL "FiniteFieldCyclicGroupExtension(\\spad{GF},{}\\spad{n}) implements a extension of degree \\spad{n} over the ground field \\spad{GF}. Its elements are represented by powers of a primitive element,{} \\spadignore{i.e.} a generator of the multiplicative (cyclic) group. As primitive element we choose the root of the extension polynomial,{} which is created by createPrimitivePoly from \\spadtype{FiniteFieldPolynomialPackage}. Zech logarithms are stored in a table of size half of the field size,{} and use \\spadtype{SingleInteger} for representing field elements,{} hence,{} there are restrictions on the size of the field.")) (|getZechTable| (((|PrimitiveArray| (|SingleInteger|))) "\\spad{getZechTable()} returns the zech logarithm table of the field. This table is used to perform additions in the field quickly."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (QUOTE (-148))) (-2198 (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-370))))) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (QUOTE (-148))) (-2199 (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-370))))) 
 (-344 K |PolK|) 
 ((|constructor| (NIL "Part of the package for Algebraic Function Fields in one variable (\\spad{PAFF}) It has been modified (very slitely) so that each time the \"factor\" function is used,{} the variable related to the size of the field over which the polynomial is factorized is reset. This is done in order to be used with a \"dynamic extension field\" which size is not fixed but set before calling the \"factor\" function and which is parse by side effect to this package via the function \"size\". See the local function \"initialize\" of this package."))) 
 NIL 
 NIL 
-(-345 -3190 V VF) 
+(-345 -3192 V VF) 
 ((|constructor| (NIL "This package lifts the interpolation functions from \\spadtype{FractionFreeFastGaussian} to fractions. The packages defined in this file provide fast fraction free rational interpolation algorithms. (see \\spad{FAMR2},{} FFFG,{} FFFGF,{} NEWTON)")) (|generalInterpolation| (((|Stream| (|Matrix| (|SparseUnivariatePolynomial| |#1|))) (|List| |#1|) (|Mapping| |#1| (|NonNegativeInteger|) (|NonNegativeInteger|) |#2|) (|Vector| |#3|) (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{generalInterpolation(l,{} CA,{} f,{} sumEta,{} maxEta)} applies generalInterpolation(\\spad{l},{} \\spad{CA},{} \\spad{f},{} eta) for all possible eta with maximal entry maxEta and sum of entries \\spad{sumEta}") (((|Matrix| (|SparseUnivariatePolynomial| |#1|)) (|List| |#1|) (|Mapping| |#1| (|NonNegativeInteger|) (|NonNegativeInteger|) |#2|) (|Vector| |#3|) (|List| (|NonNegativeInteger|))) "\\spad{generalInterpolation(l,{} CA,{} f,{} eta)} performs Hermite-Pade approximation using the given action \\spad{CA} of polynomials on the elements of \\spad{f}. The result is guaranteed to be correct up to order |eta|-1. Given that eta is a \"normal\" point,{} the degrees on the diagonal are given by eta. The degrees of column \\spad{i} are in this case eta + \\spad{e}.\\spad{i} - [1,{}1,{}...,{}1],{} where the degree of zero is \\spad{-1}."))) 
 NIL 
 NIL 
-(-346 -3190 V) 
+(-346 -3192 V) 
 ((|constructor| (NIL "This package implements the interpolation algorithm proposed in Beckermann,{} Bernhard and Labahn,{} George,{} Fraction-free computation of matrix rational interpolants and matrix GCDs,{} SIAM Journal on Matrix Analysis and Applications 22. The packages defined in this file provide fast fraction free rational interpolation algorithms. (see \\spad{FAMR2},{} FFFG,{} FFFGF,{} NEWTON)")) (|qShiftC| (((|List| |#1|) |#1| (|NonNegativeInteger|)) "\\spad{qShiftC} gives the coefficients \\spad{c_}{\\spad{k},{}\\spad{k}} in the expansion <x^k> \\spad{z} \\spad{g}(\\spad{x}) = sum_{\\spad{i=0}}\\spad{^k} \\spad{c_}{\\spad{k},{}\\spad{i}} <x^i> \\spad{g}(\\spad{x}),{} where \\spad{z} acts on \\spad{g}(\\spad{x}) by shifting. In fact,{} the result is [1,{}\\spad{q},{}\\spad{q^2},{}...]")) (|qShiftAction| ((|#1| |#1| (|NonNegativeInteger|) (|NonNegativeInteger|) |#2|) "\\spad{qShiftAction(q,{} k,{} l,{} g)} gives the coefficient of \\spad{x^k} in \\spad{z^l} \\spad{g}(\\spad{x}),{} where \\spad{z*}(a+b*x+c*x^2+d*x^3+...) = (a+q*b*x+q^2*c*x^2+q^3*d*x^3+...). In terms of sequences,{} z*u(\\spad{n})=q^n*u(\\spad{n}).")) (|DiffC| (((|List| |#1|) (|NonNegativeInteger|)) "\\spad{DiffC} gives the coefficients \\spad{c_}{\\spad{k},{}\\spad{k}} in the expansion <x^k> \\spad{z} \\spad{g}(\\spad{x}) = sum_{\\spad{i=0}}\\spad{^k} \\spad{c_}{\\spad{k},{}\\spad{i}} <x^i> \\spad{g}(\\spad{x}),{} where \\spad{z} acts on \\spad{g}(\\spad{x}) by shifting. In fact,{} the result is [0,{}0,{}0,{}...]")) (|DiffAction| ((|#1| (|NonNegativeInteger|) (|NonNegativeInteger|) |#2|) "\\spad{DiffAction(k,{} l,{} g)} gives the coefficient of \\spad{x^k} in \\spad{z^l} \\spad{g}(\\spad{x}),{} where \\spad{z*}(a+b*x+c*x^2+d*x^3+...) = (a*x+b*x^2+c*x^3+...),{} \\spadignore{i.e.} multiplication with \\spad{x}.")) (|ShiftC| (((|List| |#1|) (|NonNegativeInteger|)) "\\spad{ShiftC} gives the coefficients \\spad{c_}{\\spad{k},{}\\spad{k}} in the expansion <x^k> \\spad{z} \\spad{g}(\\spad{x}) = sum_{\\spad{i=0}}\\spad{^k} \\spad{c_}{\\spad{k},{}\\spad{i}} <x^i> \\spad{g}(\\spad{x}),{} where \\spad{z} acts on \\spad{g}(\\spad{x}) by shifting. In fact,{} the result is [0,{}1,{}2,{}...]")) (|ShiftAction| ((|#1| (|NonNegativeInteger|) (|NonNegativeInteger|) |#2|) "\\spad{ShiftAction(k,{} l,{} g)} gives the coefficient of \\spad{x^k} in \\spad{z^l} \\spad{g}(\\spad{x}),{} where \\spad{z*(a+b*x+c*x^2+d*x^3+...) = (b*x+2*c*x^2+3*d*x^3+...)}. In terms of sequences,{} z*u(\\spad{n})=n*u(\\spad{n}).")) (|generalCoefficient| ((|#1| (|Mapping| |#1| (|NonNegativeInteger|) (|NonNegativeInteger|) |#2|) (|Vector| |#2|) (|NonNegativeInteger|) (|Vector| (|SparseUnivariatePolynomial| |#1|))) "\\spad{generalCoefficient(action,{} f,{} k,{} p)} gives the coefficient of \\spad{x^k} in \\spad{p}(\\spad{z})\\dot \\spad{f}(\\spad{x}),{} where the \\spad{action} of \\spad{z^l} on a polynomial in \\spad{x} is given by \\spad{action},{} \\spadignore{i.e.} \\spad{action}(\\spad{k},{} \\spad{l},{} \\spad{f}) should return the coefficient of \\spad{x^k} in \\spad{z^l} \\spad{f}(\\spad{x}).")) (|generalInterpolation| (((|Stream| (|Matrix| (|SparseUnivariatePolynomial| |#1|))) (|List| |#1|) (|Mapping| |#1| (|NonNegativeInteger|) (|NonNegativeInteger|) |#2|) (|Vector| |#2|) (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{generalInterpolation(C,{} CA,{} f,{} sumEta,{} maxEta)} applies \\spad{generalInterpolation(C,{} CA,{} f,{} eta)} for all possible \\spad{eta} with maximal entry \\spad{maxEta} and sum of entries at most \\spad{sumEta}. \\blankline The first argument \\spad{C} is the list of coefficients \\spad{c_}{\\spad{k},{}\\spad{k}} in the expansion <x^k> \\spad{z} \\spad{g}(\\spad{x}) = sum_{\\spad{i=0}}\\spad{^k} \\spad{c_}{\\spad{k},{}\\spad{i}} <x^i> \\spad{g}(\\spad{x}). \\blankline The second argument,{} \\spad{CA}(\\spad{k},{} \\spad{l},{} \\spad{f}),{} should return the coefficient of \\spad{x^k} in \\spad{z^l} \\spad{f}(\\spad{x}).") (((|Matrix| (|SparseUnivariatePolynomial| |#1|)) (|List| |#1|) (|Mapping| |#1| (|NonNegativeInteger|) (|NonNegativeInteger|) |#2|) (|Vector| |#2|) (|List| (|NonNegativeInteger|))) "\\spad{generalInterpolation(C,{} CA,{} f,{} eta)} performs Hermite-Pade approximation using the given action \\spad{CA} of polynomials on the elements of \\spad{f}. The result is guaranteed to be correct up to order |eta|-1. Given that eta is a \"normal\" point,{} the degrees on the diagonal are given by eta. The degrees of column \\spad{i} are in this case eta + \\spad{e}.\\spad{i} - [1,{}1,{}...,{}1],{} where the degree of zero is \\spad{-1}. \\blankline The first argument \\spad{C} is the list of coefficients \\spad{c_}{\\spad{k},{}\\spad{k}} in the expansion <x^k> \\spad{z} \\spad{g}(\\spad{x}) = sum_{\\spad{i=0}}\\spad{^k} \\spad{c_}{\\spad{k},{}\\spad{i}} <x^i> \\spad{g}(\\spad{x}). \\blankline The second argument,{} \\spad{CA}(\\spad{k},{} \\spad{l},{} \\spad{f}),{} should return the coefficient of \\spad{x^k} in \\spad{z^l} \\spad{f}(\\spad{x}).")) (|interpolate| (((|Fraction| (|SparseUnivariatePolynomial| |#1|)) (|List| (|Fraction| |#1|)) (|List| (|Fraction| |#1|)) (|NonNegativeInteger|)) "\\spad{interpolate(xlist,{} ylist,{} deg} returns the rational function with numerator degree \\spad{deg} that interpolates the given points using fraction free arithmetic.") (((|Fraction| (|SparseUnivariatePolynomial| |#1|)) (|List| |#1|) (|List| |#1|) (|NonNegativeInteger|)) "\\spad{interpolate(xlist,{} ylist,{} deg} returns the rational function with numerator degree at most \\spad{deg} and denominator degree at most \\spad{\\#xlist-deg-1} that interpolates the given points using fraction free arithmetic. Note that rational interpolation does not guarantee that all given points are interpolated correctly: unattainable points may make this impossible.")) (|fffg| (((|Matrix| (|SparseUnivariatePolynomial| |#1|)) (|List| |#1|) (|Mapping| |#1| (|NonNegativeInteger|) (|Vector| (|SparseUnivariatePolynomial| |#1|))) (|List| (|NonNegativeInteger|))) "\\spad{fffg} is the general algorithm as proposed by Beckermann and Labahn. \\blankline The first argument is the list of \\spad{c_}{\\spad{i},{}\\spad{i}}. These are the only values of \\spad{C} explicitely needed in \\spad{fffg}. \\blankline The second argument \\spad{c},{} computes \\spad{c_k}(\\spad{M}),{} \\spadignore{i.e.} \\spad{c_k}(.) is the dual basis of the vector space \\spad{V},{} but also knows about the special multiplication rule as descibed in Equation (2). Note that the information about \\spad{f} is therefore encoded in \\spad{c}. \\blankline The third argument is the vector of degree bounds \\spad{n},{} as introduced in Definition 2.1. In particular,{} the sum of the entries is the order of the Mahler system computed."))) 
 NIL 
 NIL 
@@ -1330,7 +1330,7 @@ NIL
 NIL 
 (-350) 
 ((|constructor| (NIL "FiniteFieldCategory is the category of finite fields")) (|representationType| (((|Union| "prime" "polynomial" "normal" "cyclic")) "\\spad{representationType()} returns the type of the representation,{} one of: \\spad{prime},{} \\spad{polynomial},{} \\spad{normal},{} or \\spad{cyclic}.")) (|order| (((|PositiveInteger|) $) "\\spad{order(b)} computes the order of an element \\spad{b} in the multiplicative group of the field. Error: if \\spad{b} equals 0.")) (|discreteLog| (((|NonNegativeInteger|) $) "\\spad{discreteLog(a)} computes the discrete logarithm of \\spad{a} with respect to \\spad{primitiveElement()} of the field.")) (|primitive?| (((|Boolean|) $) "\\spad{primitive?(b)} tests whether the element \\spad{b} is a generator of the (cyclic) multiplicative group of the field,{} \\spadignore{i.e.} is a primitive element. Implementation Note that see \\spad{ch}.IX.1.3,{} th.2 in \\spad{D}. Lipson.")) (|primitiveElement| (($) "\\spad{primitiveElement()} returns a primitive element stored in a global variable in the domain. At first call,{} the primitive element is computed by calling \\spadfun{createPrimitiveElement}.")) (|createPrimitiveElement| (($) "\\spad{createPrimitiveElement()} computes a generator of the (cyclic) multiplicative group of the field.")) (|tableForDiscreteLogarithm| (((|Table| (|PositiveInteger|) (|NonNegativeInteger|)) (|Integer|)) "\\spad{tableForDiscreteLogarithm(a,{}n)} returns a table of the discrete logarithms of \\spad{a**0} up to \\spad{a**(n-1)} which,{} called with key \\spad{lookup(a**i)} returns \\spad{i} for \\spad{i} in \\spad{0..n-1}. Error: if not called for prime divisors of order of \\indented{7}{multiplicative group.}")) (|factorsOfCyclicGroupSize| (((|List| (|Record| (|:| |factor| (|Integer|)) (|:| |exponent| (|Integer|))))) "\\spad{factorsOfCyclicGroupSize()} returns the factorization of size()\\spad{-1}")) (|conditionP| (((|Union| (|Vector| $) "failed") (|Matrix| $)) "\\spad{conditionP(mat)},{} given a matrix representing a homogeneous system of equations,{} returns a vector whose characteristic'th powers is a non-trivial solution,{} or \"failed\" if no such vector exists.")) (|charthRoot| (($ $) "\\spad{charthRoot(a)} takes the characteristic'th root of a. Note that such a root is alway defined in finite fields."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-351 R UP -1478) 
 ((|constructor| (NIL "Integral bases for function fields of dimension one In this package \\spad{R} is a Euclidean domain and \\spad{F} is a framed algebra over \\spad{R}. The package provides functions to compute the integral closure of \\spad{R} in the quotient field of \\spad{F}. It is assumed that \\spad{char(R/P) = char(R)} for any prime \\spad{P} of \\spad{R}. A typical instance of this is when \\spad{R = K[x]} and \\spad{F} is a function field over \\spad{R}.")) (|localIntegralBasis| (((|Record| (|:| |basis| (|Matrix| |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (|Matrix| |#1|))) |#1|) "\\spad{integralBasis(p)} returns a record \\spad{[basis,{}basisDen,{}basisInv]} containing information regarding the local integral closure of \\spad{R} at the prime \\spad{p} in the quotient field of \\spad{F},{} where \\spad{F} is a framed algebra with \\spad{R}-module basis \\spad{w1,{}w2,{}...,{}wn}. If \\spad{basis} is the matrix \\spad{(aij,{} i = 1..n,{} j = 1..n)},{} then the \\spad{i}th element of the local integral basis is \\spad{\\spad{vi} = (1/basisDen) * sum(aij * wj,{} j = 1..n)},{} \\spadignore{i.e.} the \\spad{i}th row of \\spad{basis} contains the coordinates of the \\spad{i}th basis vector. Similarly,{} the \\spad{i}th row of the matrix \\spad{basisInv} contains the coordinates of \\spad{\\spad{wi}} with respect to the basis \\spad{v1,{}...,{}vn}: if \\spad{basisInv} is the matrix \\spad{(bij,{} i = 1..n,{} j = 1..n)},{} then \\spad{\\spad{wi} = sum(bij * vj,{} j = 1..n)}.")) (|integralBasis| (((|Record| (|:| |basis| (|Matrix| |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (|Matrix| |#1|)))) "\\spad{integralBasis()} returns a record \\spad{[basis,{}basisDen,{}basisInv]} containing information regarding the integral closure of \\spad{R} in the quotient field of \\spad{F},{} where \\spad{F} is a framed algebra with \\spad{R}-module basis \\spad{w1,{}w2,{}...,{}wn}. If \\spad{basis} is the matrix \\spad{(aij,{} i = 1..n,{} j = 1..n)},{} then the \\spad{i}th element of the integral basis is \\spad{\\spad{vi} = (1/basisDen) * sum(aij * wj,{} j = 1..n)},{} \\spadignore{i.e.} the \\spad{i}th row of \\spad{basis} contains the coordinates of the \\spad{i}th basis vector. Similarly,{} the \\spad{i}th row of the matrix \\spad{basisInv} contains the coordinates of \\spad{\\spad{wi}} with respect to the basis \\spad{v1,{}...,{}vn}: if \\spad{basisInv} is the matrix \\spad{(bij,{} i = 1..n,{} j = 1..n)},{} then \\spad{\\spad{wi} = sum(bij * vj,{} j = 1..n)}.")) (|squareFree| (((|Factored| $) $) "\\spad{squareFree(x)} returns a square-free factorisation of \\spad{x}"))) 
@@ -1338,24 +1338,24 @@ NIL
 NIL 
 (-352 |p| |extdeg|) 
 ((|constructor| (NIL "FiniteFieldNormalBasis(\\spad{p},{}\\spad{n}) implements a finite extension field of degree \\spad{n} over the prime field with \\spad{p} elements. The elements are represented by coordinate vectors with respect to a normal basis,{} \\spadignore{i.e.} a basis consisting of the conjugates (\\spad{q}-powers) of an element,{} in this case called normal element. This is chosen as a root of the extension polynomial created by createNormalPoly")) (|sizeMultiplication| (((|NonNegativeInteger|)) "\\spad{sizeMultiplication()} returns the number of entries in the multiplication table of the field. Note: The time of multiplication of field elements depends on this size.")) (|getMultiplicationMatrix| (((|Matrix| (|PrimeField| |#1|))) "\\spad{getMultiplicationMatrix()} returns the multiplication table in form of a matrix.")) (|getMultiplicationTable| (((|Vector| (|List| (|Record| (|:| |value| (|PrimeField| |#1|)) (|:| |index| (|SingleInteger|)))))) "\\spad{getMultiplicationTable()} returns the multiplication table for the normal basis of the field. This table is used to perform multiplications between field elements."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| (-905 |#1|) (QUOTE (-150))) (|HasCategory| (-905 |#1|) (QUOTE (-370))) (|HasCategory| (-905 |#1|) (QUOTE (-148))) (-2198 (|HasCategory| (-905 |#1|) (QUOTE (-148))) (|HasCategory| (-905 |#1|) (QUOTE (-370))))) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| (-905 |#1|) (QUOTE (-150))) (|HasCategory| (-905 |#1|) (QUOTE (-370))) (|HasCategory| (-905 |#1|) (QUOTE (-148))) (-2199 (|HasCategory| (-905 |#1|) (QUOTE (-148))) (|HasCategory| (-905 |#1|) (QUOTE (-370))))) 
 (-353 GF |uni|) 
 ((|constructor| (NIL "FiniteFieldNormalBasisExtensionByPolynomial(\\spad{GF},{}uni) implements a finite extension of the ground field \\spad{GF}. The elements are represented by coordinate vectors with respect to. a normal basis,{} \\spadignore{i.e.} a basis consisting of the conjugates (\\spad{q}-powers) of an element,{} in this case called normal element,{} where \\spad{q} is the size of \\spad{GF}. The normal element is chosen as a root of the extension polynomial,{} which MUST be normal over \\spad{GF} (user responsibility)")) (|sizeMultiplication| (((|NonNegativeInteger|)) "\\spad{sizeMultiplication()} returns the number of entries in the multiplication table of the field. Note: the time of multiplication of field elements depends on this size.")) (|getMultiplicationMatrix| (((|Matrix| |#1|)) "\\spad{getMultiplicationMatrix()} returns the multiplication table in form of a matrix.")) (|getMultiplicationTable| (((|Vector| (|List| (|Record| (|:| |value| |#1|) (|:| |index| (|SingleInteger|)))))) "\\spad{getMultiplicationTable()} returns the multiplication table for the normal basis of the field. This table is used to perform multiplications between field elements."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (QUOTE (-148))) (-2198 (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-370))))) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (QUOTE (-148))) (-2199 (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-370))))) 
 (-354 GF |extdeg|) 
 ((|constructor| (NIL "FiniteFieldNormalBasisExtensionByPolynomial(\\spad{GF},{}\\spad{n}) implements a finite extension field of degree \\spad{n} over the ground field \\spad{GF}. The elements are represented by coordinate vectors with respect to a normal basis,{} \\spadignore{i.e.} a basis consisting of the conjugates (\\spad{q}-powers) of an element,{} in this case called normal element. This is chosen as a root of the extension polynomial,{} created by createNormalPoly from \\spadtype{FiniteFieldPolynomialPackage}")) (|sizeMultiplication| (((|NonNegativeInteger|)) "\\spad{sizeMultiplication()} returns the number of entries in the multiplication table of the field. Note: the time of multiplication of field elements depends on this size.")) (|getMultiplicationMatrix| (((|Matrix| |#1|)) "\\spad{getMultiplicationMatrix()} returns the multiplication table in form of a matrix.")) (|getMultiplicationTable| (((|Vector| (|List| (|Record| (|:| |value| |#1|) (|:| |index| (|SingleInteger|)))))) "\\spad{getMultiplicationTable()} returns the multiplication table for the normal basis of the field. This table is used to perform multiplications between field elements."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (QUOTE (-148))) (-2198 (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-370))))) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (QUOTE (-148))) (-2199 (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-370))))) 
 (-355 |p| |n|) 
 ((|constructor| (NIL "FiniteField(\\spad{p},{}\\spad{n}) implements finite fields with p**n elements. This packages checks that \\spad{p} is prime. For a non-checking version,{} see \\spadtype{InnerFiniteField}."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| (-905 |#1|) (QUOTE (-150))) (|HasCategory| (-905 |#1|) (QUOTE (-370))) (|HasCategory| (-905 |#1|) (QUOTE (-148))) (-2198 (|HasCategory| (-905 |#1|) (QUOTE (-148))) (|HasCategory| (-905 |#1|) (QUOTE (-370))))) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| (-905 |#1|) (QUOTE (-150))) (|HasCategory| (-905 |#1|) (QUOTE (-370))) (|HasCategory| (-905 |#1|) (QUOTE (-148))) (-2199 (|HasCategory| (-905 |#1|) (QUOTE (-148))) (|HasCategory| (-905 |#1|) (QUOTE (-370))))) 
 (-356 GF |defpol|) 
 ((|constructor| (NIL "FiniteFieldExtensionByPolynomial(\\spad{GF},{} defpol) implements the extension of the finite field \\spad{GF} generated by the extension polynomial defpol which MUST be irreducible."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (QUOTE (-148))) (-2198 (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-370))))) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (QUOTE (-148))) (-2199 (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-370))))) 
 (-357 -1478 GF) 
 ((|constructor| (NIL "\\spad{FiniteFieldPolynomialPackage2}(\\spad{F},{}\\spad{GF}) exports some functions concerning finite fields,{} which depend on a finite field \\spad{GF} and an algebraic extension \\spad{F} of \\spad{GF},{} \\spadignore{e.g.} a zero of a polynomial over \\spad{GF} in \\spad{F}.")) (|rootOfIrreduciblePoly| ((|#1| (|SparseUnivariatePolynomial| |#2|)) "\\spad{rootOfIrreduciblePoly(f)} computes one root of the monic,{} irreducible polynomial \\spad{f},{} which degree must divide the extension degree of \\spad{F} over \\spad{GF},{} \\spadignore{i.e.} \\spad{f} splits into linear factors over \\spad{F}.")) (|Frobenius| ((|#1| |#1|) "\\spad{Frobenius(x)} \\undocumented{}")) (|basis| (((|Vector| |#1|) (|PositiveInteger|)) "\\spad{basis(n)} \\undocumented{}")) (|lookup| (((|PositiveInteger|) |#1|) "\\spad{lookup(x)} \\undocumented{}")) (|coerce| ((|#1| |#2|) "\\spad{coerce(x)} \\undocumented{}"))) 
 NIL 
@@ -1374,15 +1374,15 @@ NIL
 NIL 
 (-361 GF |n|) 
 ((|constructor| (NIL "FiniteFieldExtensionByPolynomial(\\spad{GF},{} \\spad{n}) implements an extension of the finite field \\spad{GF} of degree \\spad{n} generated by the extension polynomial constructed by createIrreduciblePoly from \\spadtype{FiniteFieldPolynomialPackage}."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (QUOTE (-148))) (-2198 (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-370))))) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (QUOTE (-148))) (-2199 (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-370))))) 
 (-362 R |ls|) 
 ((|constructor| (NIL "This is just an interface between several packages and domains. The goal is to compute lexicographical Groebner bases of sets of polynomial with type \\spadtype{Polynomial R} by the FGLM algorithm if this is possible (\\spadignore{i.e.} if the input system generates a zero-dimensional ideal).")) (|groebner| (((|List| (|Polynomial| |#1|)) (|List| (|Polynomial| |#1|))) "\\axiom{groebner(\\spad{lq1})} returns the lexicographical Groebner basis of \\axiom{\\spad{lq1}}. If \\axiom{\\spad{lq1}} generates a zero-dimensional ideal then the FGLM strategy is used,{} otherwise the Sugar strategy is used.")) (|fglmIfCan| (((|Union| (|List| (|Polynomial| |#1|)) "failed") (|List| (|Polynomial| |#1|))) "\\axiom{fglmIfCan(\\spad{lq1})} returns the lexicographical Groebner basis of \\axiom{\\spad{lq1}} by using the FGLM strategy,{} if \\axiom{zeroDimensional?(\\spad{lq1})} holds.")) (|zeroDimensional?| (((|Boolean|) (|List| (|Polynomial| |#1|))) "\\axiom{zeroDimensional?(\\spad{lq1})} returns \\spad{true} iff \\axiom{\\spad{lq1}} generates a zero-dimensional ideal \\spad{w}.\\spad{r}.\\spad{t}. the variables of \\axiom{\\spad{ls}}."))) 
 NIL 
 NIL 
 (-363 S) 
 ((|constructor| (NIL "The free group on a set \\spad{S} is the group of finite products of the form \\spad{reduce(*,{}[\\spad{si} ** \\spad{ni}])} where the \\spad{si}\\spad{'s} are in \\spad{S},{} and the \\spad{ni}\\spad{'s} are integers. The multiplication is not commutative.")) (|factors| (((|List| (|Record| (|:| |gen| |#1|) (|:| |exp| (|Integer|)))) $) "\\spad{factors(a1\\^e1,{}...,{}an\\^en)} returns \\spad{[[a1,{} e1],{}...,{}[an,{} en]]}.")) (|mapGen| (($ (|Mapping| |#1| |#1|) $) "\\spad{mapGen(f,{} a1\\^e1 ... an\\^en)} returns \\spad{f(a1)\\^e1 ... f(an)\\^en}.")) (|mapExpon| (($ (|Mapping| (|Integer|) (|Integer|)) $) "\\spad{mapExpon(f,{} a1\\^e1 ... an\\^en)} returns \\spad{a1\\^f(e1) ... an\\^f(en)}.")) (|nthFactor| ((|#1| $ (|Integer|)) "\\spad{nthFactor(x,{} n)} returns the factor of the n^th monomial of \\spad{x}.")) (|nthExpon| (((|Integer|) $ (|Integer|)) "\\spad{nthExpon(x,{} n)} returns the exponent of the n^th monomial of \\spad{x}.")) (|size| (((|NonNegativeInteger|) $) "\\spad{size(x)} returns the number of monomials in \\spad{x}.")) (** (($ |#1| (|Integer|)) "\\spad{s ** n} returns the product of \\spad{s} by itself \\spad{n} times.")) (* (($ $ |#1|) "\\spad{x * s} returns the product of \\spad{x} by \\spad{s} on the right.") (($ |#1| $) "\\spad{s * x} returns the product of \\spad{x} by \\spad{s} on the left."))) 
-((-4516 . T)) 
+((-4518 . T)) 
 NIL 
 (-364 S) 
 ((|constructor| (NIL "The category of commutative fields,{} \\spadignore{i.e.} commutative rings where all non-zero elements have multiplicative inverses. The \\spadfun{factor} operation while trivial is useful to have defined. \\blankline Axioms\\spad{\\br} \\tab{5}\\spad{a*(b/a) = b}\\spad{\\br} \\tab{5}\\spad{inv(a) = 1/a}")) (|canonicalsClosed| ((|attribute|) "since \\spad{0*0=0},{} \\spad{1*1=1}")) (|canonicalUnitNormal| ((|attribute|) "either 0 or 1.")) (/ (($ $ $) "\\spad{x/y} divides the element \\spad{x} by the element \\spad{y}. Error: if \\spad{y} is 0."))) 
@@ -1390,7 +1390,7 @@ NIL
 NIL 
 (-365) 
 ((|constructor| (NIL "The category of commutative fields,{} \\spadignore{i.e.} commutative rings where all non-zero elements have multiplicative inverses. The \\spadfun{factor} operation while trivial is useful to have defined. \\blankline Axioms\\spad{\\br} \\tab{5}\\spad{a*(b/a) = b}\\spad{\\br} \\tab{5}\\spad{inv(a) = 1/a}")) (|canonicalsClosed| ((|attribute|) "since \\spad{0*0=0},{} \\spad{1*1=1}")) (|canonicalUnitNormal| ((|attribute|) "either 0 or 1.")) (/ (($ $ $) "\\spad{x/y} divides the element \\spad{x} by the element \\spad{y}. Error: if \\spad{y} is 0."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-366 |Name| S) 
 ((|constructor| (NIL "This category provides an interface to operate on files in the computer\\spad{'s} file system. The precise method of naming files is determined by the Name parameter. The type of the contents of the file is determined by \\spad{S}.")) (|flush| (((|Void|) $) "\\spad{flush(f)} makes sure that buffered data is written out")) (|write!| ((|#2| $ |#2|) "\\spad{write!(f,{}s)} puts the value \\spad{s} into the file \\spad{f}. The state of \\spad{f} is modified so subsequents call to \\spad{write!} will append one after another.")) (|read!| ((|#2| $) "\\spad{read!(f)} extracts a value from file \\spad{f}. The state of \\spad{f} is modified so a subsequent call to \\spadfun{read!} will return the next element.")) (|iomode| (((|String|) $) "\\spad{iomode(f)} returns the status of the file \\spad{f}. The input/output status of \\spad{f} may be \"input\",{} \"output\" or \"closed\" mode.")) (|name| ((|#1| $) "\\spad{name(f)} returns the external name of the file \\spad{f}.")) (|close!| (($ $) "\\spad{close!(f)} returns the file \\spad{f} closed to input and output.")) (|reopen!| (($ $ (|String|)) "\\spad{reopen!(f,{}mode)} returns a file \\spad{f} reopened for operation in the indicated mode: \"input\" or \"output\". \\spad{reopen!(f,{}\"input\")} will reopen the file \\spad{f} for input.")) (|open| (($ |#1| (|String|)) "\\spad{open(s,{}mode)} returns a file \\spad{s} open for operation in the indicated mode: \"input\" or \"output\".") (($ |#1|) "\\spad{open(s)} returns the file \\spad{s} open for input."))) 
@@ -1406,7 +1406,7 @@ NIL
 ((|HasCategory| |#2| (QUOTE (-558)))) 
 (-369 R) 
 ((|constructor| (NIL "A FiniteRankNonAssociativeAlgebra is a non associative algebra over a commutative ring \\spad{R} which is a free \\spad{R}-module of finite rank.")) (|unitsKnown| ((|attribute|) "unitsKnown means that \\spadfun{recip} truly yields reciprocal or \\spad{\"failed\"} if not a unit,{} similarly for \\spadfun{leftRecip} and \\spadfun{rightRecip}. The reason is that we use left,{} respectively right,{} minimal polynomials to decide this question.")) (|unit| (((|Union| $ "failed")) "\\spad{unit()} returns a unit of the algebra (necessarily unique),{} or \\spad{\"failed\"} if there is none.")) (|rightUnit| (((|Union| $ "failed")) "\\spad{rightUnit()} returns a right unit of the algebra (not necessarily unique),{} or \\spad{\"failed\"} if there is none.")) (|leftUnit| (((|Union| $ "failed")) "\\spad{leftUnit()} returns a left unit of the algebra (not necessarily unique),{} or \\spad{\"failed\"} if there is none.")) (|rightUnits| (((|Union| (|Record| (|:| |particular| $) (|:| |basis| (|List| $))) "failed")) "\\spad{rightUnits()} returns the affine space of all right units of the algebra,{} or \\spad{\"failed\"} if there is none.")) (|leftUnits| (((|Union| (|Record| (|:| |particular| $) (|:| |basis| (|List| $))) "failed")) "\\spad{leftUnits()} returns the affine space of all left units of the algebra,{} or \\spad{\"failed\"} if there is none.")) (|rightMinimalPolynomial| (((|SparseUnivariatePolynomial| |#1|) $) "\\spad{rightMinimalPolynomial(a)} returns the polynomial determined by the smallest non-trivial linear combination of right powers of \\spad{a}. Note that the polynomial never has a constant term as in general the algebra has no unit.")) (|leftMinimalPolynomial| (((|SparseUnivariatePolynomial| |#1|) $) "\\spad{leftMinimalPolynomial(a)} returns the polynomial determined by the smallest non-trivial linear combination of left powers of \\spad{a}. Note that the polynomial never has a constant term as in general the algebra has no unit.")) (|associatorDependence| (((|List| (|Vector| |#1|))) "\\spad{associatorDependence()} looks for the associator identities,{} \\spadignore{i.e.} finds a basis of the solutions of the linear combinations of the six permutations of \\spad{associator(a,{}b,{}c)} which yield 0,{} for all \\spad{a},{}\\spad{b},{}\\spad{c} in the algebra. The order of the permutations is \\spad{123 231 312 132 321 213}.")) (|rightRecip| (((|Union| $ "failed") $) "\\spad{rightRecip(a)} returns an element,{} which is a right inverse of \\spad{a},{} or \\spad{\"failed\"} if there is no unit element,{} if such an element doesn\\spad{'t} exist or cannot be determined (see unitsKnown).")) (|leftRecip| (((|Union| $ "failed") $) "\\spad{leftRecip(a)} returns an element,{} which is a left inverse of \\spad{a},{} or \\spad{\"failed\"} if there is no unit element,{} if such an element doesn\\spad{'t} exist or cannot be determined (see unitsKnown).")) (|recip| (((|Union| $ "failed") $) "\\spad{recip(a)} returns an element,{} which is both a left and a right inverse of \\spad{a},{} or \\spad{\"failed\"} if there is no unit element,{} if such an element doesn\\spad{'t} exist or cannot be determined (see unitsKnown).")) (|lieAlgebra?| (((|Boolean|)) "\\spad{lieAlgebra?()} tests if the algebra is anticommutative and \\spad{(a*b)*c + (b*c)*a + (c*a)*b = 0} for all \\spad{a},{}\\spad{b},{}\\spad{c} in the algebra (Jacobi identity). Example: for every associative algebra \\spad{(A,{}+,{}@)} we can construct a Lie algebra \\spad{(A,{}+,{}*)},{} where \\spad{a*b := a@b-b@a}.")) (|jordanAlgebra?| (((|Boolean|)) "\\spad{jordanAlgebra?()} tests if the algebra is commutative,{} characteristic is not 2,{} and \\spad{(a*b)*a**2 - a*(b*a**2) = 0} for all \\spad{a},{}\\spad{b},{}\\spad{c} in the algebra (Jordan identity). Example: for every associative algebra \\spad{(A,{}+,{}@)} we can construct a Jordan algebra \\spad{(A,{}+,{}*)},{} where \\spad{a*b := (a@b+b@a)/2}.")) (|noncommutativeJordanAlgebra?| (((|Boolean|)) "\\spad{noncommutativeJordanAlgebra?()} tests if the algebra is flexible and Jordan admissible.")) (|jordanAdmissible?| (((|Boolean|)) "\\spad{jordanAdmissible?()} tests if 2 is invertible in the coefficient domain and the multiplication defined by \\spad{(1/2)(a*b+b*a)} determines a Jordan algebra,{} \\spadignore{i.e.} satisfies the Jordan identity. The property of \\spadatt{commutative(\\spad{\"*\"})} follows from by definition.")) (|lieAdmissible?| (((|Boolean|)) "\\spad{lieAdmissible?()} tests if the algebra defined by the commutators is a Lie algebra,{} \\spadignore{i.e.} satisfies the Jacobi identity. The property of anticommutativity follows from definition.")) (|jacobiIdentity?| (((|Boolean|)) "\\spad{jacobiIdentity?()} tests if \\spad{(a*b)*c + (b*c)*a + (c*a)*b = 0} for all \\spad{a},{}\\spad{b},{}\\spad{c} in the algebra. For example,{} this holds for crossed products of 3-dimensional vectors.")) (|powerAssociative?| (((|Boolean|)) "\\spad{powerAssociative?()} tests if all subalgebras generated by a single element are associative.")) (|alternative?| (((|Boolean|)) "\\spad{alternative?()} tests if \\spad{2*associator(a,{}a,{}b) = 0 = 2*associator(a,{}b,{}b)} for all \\spad{a},{} \\spad{b} in the algebra. Note that we only can test this; in general we don\\spad{'t} know whether \\spad{2*a=0} implies \\spad{a=0}.")) (|flexible?| (((|Boolean|)) "\\spad{flexible?()} tests if \\spad{2*associator(a,{}b,{}a) = 0} for all \\spad{a},{} \\spad{b} in the algebra. Note that we only can test this; in general we don\\spad{'t} know whether \\spad{2*a=0} implies \\spad{a=0}.")) (|rightAlternative?| (((|Boolean|)) "\\spad{rightAlternative?()} tests if \\spad{2*associator(a,{}b,{}b) = 0} for all \\spad{a},{} \\spad{b} in the algebra. Note that we only can test this; in general we don\\spad{'t} know whether \\spad{2*a=0} implies \\spad{a=0}.")) (|leftAlternative?| (((|Boolean|)) "\\spad{leftAlternative?()} tests if \\spad{2*associator(a,{}a,{}b) = 0} for all \\spad{a},{} \\spad{b} in the algebra. Note that we only can test this; in general we don\\spad{'t} know whether \\spad{2*a=0} implies \\spad{a=0}.")) (|antiAssociative?| (((|Boolean|)) "\\spad{antiAssociative?()} tests if multiplication in algebra is anti-associative,{} \\spadignore{i.e.} \\spad{(a*b)*c + a*(b*c) = 0} for all \\spad{a},{}\\spad{b},{}\\spad{c} in the algebra.")) (|associative?| (((|Boolean|)) "\\spad{associative?()} tests if multiplication in algebra is associative.")) (|antiCommutative?| (((|Boolean|)) "\\spad{antiCommutative?()} tests if \\spad{a*a = 0} for all \\spad{a} in the algebra. Note that this implies \\spad{a*b + b*a = 0} for all \\spad{a} and \\spad{b}.")) (|commutative?| (((|Boolean|)) "\\spad{commutative?()} tests if multiplication in the algebra is commutative.")) (|rightCharacteristicPolynomial| (((|SparseUnivariatePolynomial| |#1|) $) "\\spad{rightCharacteristicPolynomial(a)} returns the characteristic polynomial of the right regular representation of \\spad{a} with respect to any basis.")) (|leftCharacteristicPolynomial| (((|SparseUnivariatePolynomial| |#1|) $) "\\spad{leftCharacteristicPolynomial(a)} returns the characteristic polynomial of the left regular representation of \\spad{a} with respect to any basis.")) (|rightTraceMatrix| (((|Matrix| |#1|) (|Vector| $)) "\\spad{rightTraceMatrix([v1,{}...,{}vn])} is the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}\\spad{-}th row and \\spad{j}\\spad{-}th column is given by the right trace of the product \\spad{vi*vj}.")) (|leftTraceMatrix| (((|Matrix| |#1|) (|Vector| $)) "\\spad{leftTraceMatrix([v1,{}...,{}vn])} is the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}\\spad{-}th row and \\spad{j}\\spad{-}th column is given by the left trace of the product \\spad{vi*vj}.")) (|rightDiscriminant| ((|#1| (|Vector| $)) "\\spad{rightDiscriminant([v1,{}...,{}vn])} returns the determinant of the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}\\spad{-}th row and \\spad{j}\\spad{-}th column is given by the right trace of the product \\spad{vi*vj}. Note that this is the same as \\spad{determinant(rightTraceMatrix([v1,{}...,{}vn]))}.")) (|leftDiscriminant| ((|#1| (|Vector| $)) "\\spad{leftDiscriminant([v1,{}...,{}vn])} returns the determinant of the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}\\spad{-}th row and \\spad{j}\\spad{-}th column is given by the left trace of the product \\spad{vi*vj}. Note that this is the same as \\spad{determinant(leftTraceMatrix([v1,{}...,{}vn]))}.")) (|represents| (($ (|Vector| |#1|) (|Vector| $)) "\\spad{represents([a1,{}...,{}am],{}[v1,{}...,{}vm])} returns the linear combination \\spad{a1*vm + ... + an*vm}.")) (|coordinates| (((|Matrix| |#1|) (|Vector| $) (|Vector| $)) "\\spad{coordinates([a1,{}...,{}am],{}[v1,{}...,{}vn])} returns a matrix whose \\spad{i}-th row is formed by the coordinates of \\spad{\\spad{ai}} with respect to the \\spad{R}-module basis \\spad{v1},{}...,{}\\spad{vn}.") (((|Vector| |#1|) $ (|Vector| $)) "\\spad{coordinates(a,{}[v1,{}...,{}vn])} returns the coordinates of \\spad{a} with respect to the \\spad{R}-module basis \\spad{v1},{}...,{}\\spad{vn}.")) (|rightNorm| ((|#1| $) "\\spad{rightNorm(a)} returns the determinant of the right regular representation of \\spad{a}.")) (|leftNorm| ((|#1| $) "\\spad{leftNorm(a)} returns the determinant of the left regular representation of \\spad{a}.")) (|rightTrace| ((|#1| $) "\\spad{rightTrace(a)} returns the trace of the right regular representation of \\spad{a}.")) (|leftTrace| ((|#1| $) "\\spad{leftTrace(a)} returns the trace of the left regular representation of \\spad{a}.")) (|rightRegularRepresentation| (((|Matrix| |#1|) $ (|Vector| $)) "\\spad{rightRegularRepresentation(a,{}[v1,{}...,{}vn])} returns the matrix of the linear map defined by right multiplication by \\spad{a} with respect to the \\spad{R}-module basis \\spad{[v1,{}...,{}vn]}.")) (|leftRegularRepresentation| (((|Matrix| |#1|) $ (|Vector| $)) "\\spad{leftRegularRepresentation(a,{}[v1,{}...,{}vn])} returns the matrix of the linear map defined by left multiplication by \\spad{a} with respect to the \\spad{R}-module basis \\spad{[v1,{}...,{}vn]}.")) (|structuralConstants| (((|Vector| (|Matrix| |#1|)) (|Vector| $)) "\\spad{structuralConstants([v1,{}v2,{}...,{}vm])} calculates the structural constants \\spad{[(gammaijk) for k in 1..m]} defined by \\spad{\\spad{vi} * vj = gammaij1 * v1 + ... + gammaijm * vm},{} where \\spad{[v1,{}...,{}vm]} is an \\spad{R}-module basis of a subalgebra.")) (|conditionsForIdempotents| (((|List| (|Polynomial| |#1|)) (|Vector| $)) "\\spad{conditionsForIdempotents([v1,{}...,{}vn])} determines a complete list of polynomial equations for the coefficients of idempotents with respect to the \\spad{R}-module basis \\spad{v1},{}...,{}\\spad{vn}.")) (|rank| (((|PositiveInteger|)) "\\spad{rank()} returns the rank of the algebra as \\spad{R}-module.")) (|someBasis| (((|Vector| $)) "\\spad{someBasis()} returns some \\spad{R}-module basis."))) 
-((-4516 |has| |#1| (-558)) (-4514 . T) (-4513 . T)) 
+((-4518 |has| |#1| (-558)) (-4516 . T) (-4515 . T)) 
 NIL 
 (-370) 
 ((|constructor| (NIL "The category of domains composed of a finite set of elements. We include the functions \\spadfun{lookup} and \\spadfun{index} to give a bijection between the finite set and an initial segment of positive integers. \\blankline")) (|random| (($) "\\spad{random()} returns a random element from the set.")) (|lookup| (((|PositiveInteger|) $) "\\spad{lookup(x)} returns a positive integer such that \\spad{x = index lookup x}.")) (|index| (($ (|PositiveInteger|)) "\\spad{index(i)} takes a positive integer \\spad{i} less than or equal to \\spad{size()} and returns the \\spad{i}\\spad{-}th element of the set. This operation establishs a bijection between the elements of the finite set and \\spad{1..size()}.")) (|size| (((|NonNegativeInteger|)) "\\spad{size()} returns the number of elements in the set."))) 
@@ -1418,7 +1418,7 @@ NIL
 ((|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (QUOTE (-365)))) 
 (-372 R UP) 
 ((|constructor| (NIL "A FiniteRankAlgebra is an algebra over a commutative ring \\spad{R} which is a free \\spad{R}-module of finite rank.")) (|minimalPolynomial| ((|#2| $) "\\spad{minimalPolynomial(a)} returns the minimal polynomial of \\spad{a}.")) (|characteristicPolynomial| ((|#2| $) "\\spad{characteristicPolynomial(a)} returns the characteristic polynomial of the regular representation of \\spad{a} with respect to any basis.")) (|traceMatrix| (((|Matrix| |#1|) (|Vector| $)) "\\spad{traceMatrix([v1,{}..,{}vn])} is the \\spad{n}-by-\\spad{n} matrix ( \\spad{Tr}(\\spad{vi} * \\spad{vj}) )")) (|discriminant| ((|#1| (|Vector| $)) "\\spad{discriminant([v1,{}..,{}vn])} returns \\spad{determinant(traceMatrix([v1,{}..,{}vn]))}.")) (|represents| (($ (|Vector| |#1|) (|Vector| $)) "\\spad{represents([a1,{}..,{}an],{}[v1,{}..,{}vn])} returns \\spad{a1*v1+...+an*vn}.")) (|coordinates| (((|Matrix| |#1|) (|Vector| $) (|Vector| $)) "\\spad{coordinates([v1,{}...,{}vm],{} basis)} returns the coordinates of the \\spad{vi}\\spad{'s} with to the basis \\spad{basis}. The coordinates of \\spad{vi} are contained in the \\spad{i}th row of the matrix returned by this function.") (((|Vector| |#1|) $ (|Vector| $)) "\\spad{coordinates(a,{}basis)} returns the coordinates of \\spad{a} with respect to the \\spad{basis} \\spad{basis}.")) (|norm| ((|#1| $) "\\spad{norm(a)} returns the determinant of the regular representation of \\spad{a} with respect to any basis.")) (|trace| ((|#1| $) "\\spad{trace(a)} returns the trace of the regular representation of \\spad{a} with respect to any basis.")) (|regularRepresentation| (((|Matrix| |#1|) $ (|Vector| $)) "\\spad{regularRepresentation(a,{}basis)} returns the matrix of the linear map defined by left multiplication by \\spad{a} with respect to the \\spad{basis} \\spad{basis}.")) (|rank| (((|PositiveInteger|)) "\\spad{rank()} returns the rank of the algebra."))) 
-((-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-373 S A R B) 
 ((|constructor| (NIL "\\spad{FiniteLinearAggregateFunctions2} provides functions involving two FiniteLinearAggregates where the underlying domains might be different. An example of this might be creating a list of rational numbers by mapping a function across a list of integers where the function divides each integer by 1000.")) (|scan| ((|#4| (|Mapping| |#3| |#1| |#3|) |#2| |#3|) "\\spad{scan(f,{}a,{}r)} successively applies \\spad{reduce(f,{}x,{}r)} to more and more leading sub-aggregates \\spad{x} of aggregrate \\spad{a}. More precisely,{} if \\spad{a} is \\spad{[a1,{}a2,{}...]},{} then \\spad{scan(f,{}a,{}r)} returns \\spad{[reduce(f,{}[a1],{}r),{}reduce(f,{}[a1,{}a2],{}r),{}...]}.")) (|reduce| ((|#3| (|Mapping| |#3| |#1| |#3|) |#2| |#3|) "\\spad{reduce(f,{}a,{}r)} applies function \\spad{f} to each successive element of the aggregate \\spad{a} and an accumulant initialized to \\spad{r}. For example,{} \\spad{reduce(_+\\$Integer,{}[1,{}2,{}3],{}0)} does \\spad{3+(2+(1+0))}. Note that third argument \\spad{r} may be regarded as the identity element for the function \\spad{f}.")) (|map| ((|#4| (|Mapping| |#3| |#1|) |#2|) "\\spad{map(f,{}a)} applies function \\spad{f} to each member of aggregate \\spad{a} resulting in a new aggregate over a possibly different underlying domain."))) 
@@ -1427,14 +1427,14 @@ NIL
 (-374 A S) 
 ((|constructor| (NIL "A finite linear aggregate is a linear aggregate of finite length. The finite property of the aggregate adds several exports to the list of exports from \\spadtype{LinearAggregate} such as \\spadfun{reverse},{} \\spadfun{sort},{} and so on.")) (|sort!| (($ $) "\\spad{sort!(u)} returns \\spad{u} with its elements in ascending order.") (($ (|Mapping| (|Boolean|) |#2| |#2|) $) "\\spad{sort!(p,{}u)} returns \\spad{u} with its elements ordered by \\spad{p}.")) (|reverse!| (($ $) "\\spad{reverse!(u)} returns \\spad{u} with its elements in reverse order.")) (|copyInto!| (($ $ $ (|Integer|)) "\\spad{copyInto!(u,{}v,{}i)} returns aggregate \\spad{u} containing a copy of \\spad{v} inserted at element \\spad{i}.")) (|position| (((|Integer|) |#2| $ (|Integer|)) "\\spad{position(x,{}a,{}n)} returns the index \\spad{i} of the first occurrence of \\spad{x} in \\axiom{a} where \\axiom{\\spad{i} \\spad{>=} \\spad{n}},{} and \\axiom{minIndex(a) - 1} if no such \\spad{x} is found.") (((|Integer|) |#2| $) "\\spad{position(x,{}a)} returns the index \\spad{i} of the first occurrence of \\spad{x} in a,{} and \\axiom{minIndex(a) - 1} if there is no such \\spad{x}.") (((|Integer|) (|Mapping| (|Boolean|) |#2|) $) "\\spad{position(p,{}a)} returns the index \\spad{i} of the first \\spad{x} in \\axiom{a} such that \\axiom{\\spad{p}(\\spad{x})} is \\spad{true},{} and \\axiom{minIndex(a) - 1} if there is no such \\spad{x}.")) (|sorted?| (((|Boolean|) $) "\\spad{sorted?(u)} tests if the elements of \\spad{u} are in ascending order.") (((|Boolean|) (|Mapping| (|Boolean|) |#2| |#2|) $) "\\spad{sorted?(p,{}a)} tests if \\axiom{a} is sorted according to predicate \\spad{p}.")) (|sort| (($ $) "\\spad{sort(u)} returns an \\spad{u} with elements in ascending order. Note that \\axiom{sort(\\spad{u}) = sort(\\spad{<=},{}\\spad{u})}.") (($ (|Mapping| (|Boolean|) |#2| |#2|) $) "\\spad{sort(p,{}a)} returns a copy of \\axiom{a} sorted using total ordering predicate \\spad{p}.")) (|reverse| (($ $) "\\spad{reverse(a)} returns a copy of \\axiom{a} with elements in reverse order.")) (|merge| (($ $ $) "\\spad{merge(u,{}v)} merges \\spad{u} and \\spad{v} in ascending order. Note that \\axiom{merge(\\spad{u},{}\\spad{v}) = merge(\\spad{<=},{}\\spad{u},{}\\spad{v})}.") (($ (|Mapping| (|Boolean|) |#2| |#2|) $ $) "\\spad{merge(p,{}a,{}b)} returns an aggregate \\spad{c} which merges \\axiom{a} and \\spad{b}. The result is produced by examining each element \\spad{x} of \\axiom{a} and \\spad{y} of \\spad{b} successively. If \\axiom{\\spad{p}(\\spad{x},{}\\spad{y})} is \\spad{true},{} then \\spad{x} is inserted into the result; otherwise \\spad{y} is inserted. If \\spad{x} is chosen,{} the next element of \\axiom{a} is examined,{} and so on. When all the elements of one aggregate are examined,{} the remaining elements of the other are appended. For example,{} \\axiom{merge(<,{}[1,{}3],{}[2,{}7,{}5])} returns \\axiom{[1,{}2,{}3,{}7,{}5]}."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE -4520)) (|HasCategory| |#2| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-1090)))) 
+((|HasAttribute| |#1| (QUOTE -4522)) (|HasCategory| |#2| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-1090)))) 
 (-375 S) 
 ((|constructor| (NIL "A finite linear aggregate is a linear aggregate of finite length. The finite property of the aggregate adds several exports to the list of exports from \\spadtype{LinearAggregate} such as \\spadfun{reverse},{} \\spadfun{sort},{} and so on.")) (|sort!| (($ $) "\\spad{sort!(u)} returns \\spad{u} with its elements in ascending order.") (($ (|Mapping| (|Boolean|) |#1| |#1|) $) "\\spad{sort!(p,{}u)} returns \\spad{u} with its elements ordered by \\spad{p}.")) (|reverse!| (($ $) "\\spad{reverse!(u)} returns \\spad{u} with its elements in reverse order.")) (|copyInto!| (($ $ $ (|Integer|)) "\\spad{copyInto!(u,{}v,{}i)} returns aggregate \\spad{u} containing a copy of \\spad{v} inserted at element \\spad{i}.")) (|position| (((|Integer|) |#1| $ (|Integer|)) "\\spad{position(x,{}a,{}n)} returns the index \\spad{i} of the first occurrence of \\spad{x} in \\axiom{a} where \\axiom{\\spad{i} \\spad{>=} \\spad{n}},{} and \\axiom{minIndex(a) - 1} if no such \\spad{x} is found.") (((|Integer|) |#1| $) "\\spad{position(x,{}a)} returns the index \\spad{i} of the first occurrence of \\spad{x} in a,{} and \\axiom{minIndex(a) - 1} if there is no such \\spad{x}.") (((|Integer|) (|Mapping| (|Boolean|) |#1|) $) "\\spad{position(p,{}a)} returns the index \\spad{i} of the first \\spad{x} in \\axiom{a} such that \\axiom{\\spad{p}(\\spad{x})} is \\spad{true},{} and \\axiom{minIndex(a) - 1} if there is no such \\spad{x}.")) (|sorted?| (((|Boolean|) $) "\\spad{sorted?(u)} tests if the elements of \\spad{u} are in ascending order.") (((|Boolean|) (|Mapping| (|Boolean|) |#1| |#1|) $) "\\spad{sorted?(p,{}a)} tests if \\axiom{a} is sorted according to predicate \\spad{p}.")) (|sort| (($ $) "\\spad{sort(u)} returns an \\spad{u} with elements in ascending order. Note that \\axiom{sort(\\spad{u}) = sort(\\spad{<=},{}\\spad{u})}.") (($ (|Mapping| (|Boolean|) |#1| |#1|) $) "\\spad{sort(p,{}a)} returns a copy of \\axiom{a} sorted using total ordering predicate \\spad{p}.")) (|reverse| (($ $) "\\spad{reverse(a)} returns a copy of \\axiom{a} with elements in reverse order.")) (|merge| (($ $ $) "\\spad{merge(u,{}v)} merges \\spad{u} and \\spad{v} in ascending order. Note that \\axiom{merge(\\spad{u},{}\\spad{v}) = merge(\\spad{<=},{}\\spad{u},{}\\spad{v})}.") (($ (|Mapping| (|Boolean|) |#1| |#1|) $ $) "\\spad{merge(p,{}a,{}b)} returns an aggregate \\spad{c} which merges \\axiom{a} and \\spad{b}. The result is produced by examining each element \\spad{x} of \\axiom{a} and \\spad{y} of \\spad{b} successively. If \\axiom{\\spad{p}(\\spad{x},{}\\spad{y})} is \\spad{true},{} then \\spad{x} is inserted into the result; otherwise \\spad{y} is inserted. If \\spad{x} is chosen,{} the next element of \\axiom{a} is examined,{} and so on. When all the elements of one aggregate are examined,{} the remaining elements of the other are appended. For example,{} \\axiom{merge(<,{}[1,{}3],{}[2,{}7,{}5])} returns \\axiom{[1,{}2,{}3,{}7,{}5]}."))) 
-((-4519 . T) (-3973 . T)) 
+((-4521 . T) (-3973 . T)) 
 NIL 
 (-376 |VarSet| R) 
 ((|constructor| (NIL "The category of free Lie algebras. It is used by domains of non-commutative algebra: \\spadtype{LiePolynomial} and \\spadtype{XPBWPolynomial}.")) (|eval| (($ $ (|List| |#1|) (|List| $)) "\\axiom{eval(\\spad{p},{} [\\spad{x1},{}...,{}\\spad{xn}],{} [\\spad{v1},{}...,{}\\spad{vn}])} replaces \\axiom{\\spad{xi}} by \\axiom{\\spad{vi}} in \\axiom{\\spad{p}}.") (($ $ |#1| $) "\\axiom{eval(\\spad{p},{} \\spad{x},{} \\spad{v})} replaces \\axiom{\\spad{x}} by \\axiom{\\spad{v}} in \\axiom{\\spad{p}}.")) (|varList| (((|List| |#1|) $) "\\axiom{varList(\\spad{x})} returns the list of distinct entries of \\axiom{\\spad{x}}.")) (|trunc| (($ $ (|NonNegativeInteger|)) "\\axiom{trunc(\\spad{p},{}\\spad{n})} returns the polynomial \\axiom{\\spad{p}} truncated at order \\axiom{\\spad{n}}.")) (|mirror| (($ $) "\\axiom{mirror(\\spad{x})} returns \\axiom{Sum(r_i mirror(w_i))} if \\axiom{\\spad{x}} is \\axiom{Sum(r_i w_i)}.")) (|LiePoly| (($ (|LyndonWord| |#1|)) "\\axiom{LiePoly(\\spad{l})} returns the bracketed form of \\axiom{\\spad{l}} as a Lie polynomial.")) (|rquo| (((|XRecursivePolynomial| |#1| |#2|) (|XRecursivePolynomial| |#1| |#2|) $) "\\axiom{rquo(\\spad{x},{}\\spad{y})} returns the right simplification of \\axiom{\\spad{x}} by \\axiom{\\spad{y}}.")) (|lquo| (((|XRecursivePolynomial| |#1| |#2|) (|XRecursivePolynomial| |#1| |#2|) $) "\\axiom{lquo(\\spad{x},{}\\spad{y})} returns the left simplification of \\axiom{\\spad{x}} by \\axiom{\\spad{y}}.")) (|degree| (((|NonNegativeInteger|) $) "\\axiom{degree(\\spad{x})} returns the greatest length of a word in the support of \\axiom{\\spad{x}}.")) (|coerce| (((|XRecursivePolynomial| |#1| |#2|) $) "\\axiom{coerce(\\spad{x})} returns \\axiom{\\spad{x}} as a recursive polynomial.") (((|XDistributedPolynomial| |#1| |#2|) $) "\\axiom{coerce(\\spad{x})} returns \\axiom{\\spad{x}} as distributed polynomial.") (($ |#1|) "\\axiom{coerce(\\spad{x})} returns \\axiom{\\spad{x}} as a Lie polynomial.")) (|coef| ((|#2| (|XRecursivePolynomial| |#1| |#2|) $) "\\axiom{coef(\\spad{x},{}\\spad{y})} returns the scalar product of \\axiom{\\spad{x}} by \\axiom{\\spad{y}},{} the set of words being regarded as an orthogonal basis."))) 
-((|JacobiIdentity| . T) (|NullSquare| . T) (-4514 . T) (-4513 . T)) 
+((|JacobiIdentity| . T) (|NullSquare| . T) (-4516 . T) (-4515 . T)) 
 NIL 
 (-377 S V) 
 ((|constructor| (NIL "This package exports 3 sorting algorithms which work over FiniteLinearAggregates. Sort package (in-place) for shallowlyMutable Finite Linear Aggregates")) (|shellSort| ((|#2| (|Mapping| (|Boolean|) |#1| |#1|) |#2|) "\\spad{shellSort(f,{} agg)} sorts the aggregate agg with the ordering function \\spad{f} using the shellSort algorithm.")) (|heapSort| ((|#2| (|Mapping| (|Boolean|) |#1| |#1|) |#2|) "\\spad{heapSort(f,{} agg)} sorts the aggregate agg with the ordering function \\spad{f} using the heapsort algorithm.")) (|quickSort| ((|#2| (|Mapping| (|Boolean|) |#1| |#1|) |#2|) "\\spad{quickSort(f,{} agg)} sorts the aggregate agg with the ordering function \\spad{f} using the quicksort algorithm."))) 
@@ -1446,7 +1446,7 @@ NIL
 ((|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568))))) 
 (-379 R) 
 ((|constructor| (NIL "\\spad{S} is \\spadtype{FullyLinearlyExplicitRingOver R} means that \\spad{S} is a \\spadtype{LinearlyExplicitRingOver R} and,{} in addition,{} if \\spad{R} is a \\spadtype{LinearlyExplicitRingOver Integer},{} then so is \\spad{S}"))) 
-((-4516 . T)) 
+((-4518 . T)) 
 NIL 
 (-380 |Par|) 
 ((|constructor| (NIL "This is a package for the approximation of complex solutions for systems of equations of rational functions with complex rational coefficients. The results are expressed as either complex rational numbers or complex floats depending on the type of the precision parameter which can be either a rational number or a floating point number.")) (|complexRoots| (((|List| (|List| (|Complex| |#1|))) (|List| (|Fraction| (|Polynomial| (|Complex| (|Integer|))))) (|List| (|Symbol|)) |#1|) "\\spad{complexRoots(lrf,{} lv,{} eps)} finds all the complex solutions of a list of rational functions with rational number coefficients with respect the the variables appearing in \\spad{lv}. Each solution is computed to precision eps and returned as list corresponding to the order of variables in \\spad{lv}.") (((|List| (|Complex| |#1|)) (|Fraction| (|Polynomial| (|Complex| (|Integer|)))) |#1|) "\\spad{complexRoots(rf,{} eps)} finds all the complex solutions of a univariate rational function with rational number coefficients. The solutions are computed to precision eps.")) (|complexSolve| (((|List| (|Equation| (|Polynomial| (|Complex| |#1|)))) (|Equation| (|Fraction| (|Polynomial| (|Complex| (|Integer|))))) |#1|) "\\spad{complexSolve(eq,{}eps)} finds all the complex solutions of the equation \\spad{eq} of rational functions with rational rational coefficients with respect to all the variables appearing in \\spad{eq},{} with precision \\spad{eps}.") (((|List| (|Equation| (|Polynomial| (|Complex| |#1|)))) (|Fraction| (|Polynomial| (|Complex| (|Integer|)))) |#1|) "\\spad{complexSolve(p,{}eps)} find all the complex solutions of the rational function \\spad{p} with complex rational coefficients with respect to all the variables appearing in \\spad{p},{} with precision \\spad{eps}.") (((|List| (|List| (|Equation| (|Polynomial| (|Complex| |#1|))))) (|List| (|Equation| (|Fraction| (|Polynomial| (|Complex| (|Integer|)))))) |#1|) "\\spad{complexSolve(leq,{}eps)} finds all the complex solutions to precision \\spad{eps} of the system \\spad{leq} of equations of rational functions over complex rationals with respect to all the variables appearing in \\spad{lp}.") (((|List| (|List| (|Equation| (|Polynomial| (|Complex| |#1|))))) (|List| (|Fraction| (|Polynomial| (|Complex| (|Integer|))))) |#1|) "\\spad{complexSolve(lp,{}eps)} finds all the complex solutions to precision \\spad{eps} of the system \\spad{lp} of rational functions over the complex rationals with respect to all the variables appearing in \\spad{lp}."))) 
@@ -1454,7 +1454,7 @@ NIL
 NIL 
 (-381) 
 ((|constructor| (NIL "\\spadtype{Float} implements arbitrary precision floating point arithmetic. The number of significant digits of each operation can be set to an arbitrary value (the default is 20 decimal digits). The operation \\spad{float(mantissa,{}exponent,{}base)} for integer \\spad{mantissa},{} \\spad{exponent} specifies the number \\spad{mantissa * base ** exponent} The underlying representation for floats is binary not decimal. The implications of this are described below. \\blankline The model adopted is that arithmetic operations are rounded to to nearest unit in the last place,{} that is,{} accurate to within \\spad{2**(-bits)}. Also,{} the elementary functions and constants are accurate to one unit in the last place. A float is represented as a record of two integers,{} the mantissa and the exponent. The base of the representation is binary,{} hence a \\spad{Record(m:mantissa,{}e:exponent)} represents the number \\spad{m * 2 ** e}. Though it is not assumed that the underlying integers are represented with a binary base,{} the code will be most efficient when this is the the case (this is \\spad{true} in most implementations of Lisp). The decision to choose the base to be binary has some unfortunate consequences. First,{} decimal numbers like 0.3 cannot be represented exactly. Second,{} there is a further loss of accuracy during conversion to decimal for output. To compensate for this,{} if \\spad{d} digits of precision are specified,{} \\spad{1 + ceiling(log2 d)} bits are used. Two numbers that are displayed identically may therefore be not equal. On the other hand,{} a significant efficiency loss would be incurred if we chose to use a decimal base when the underlying integer base is binary. \\blankline Algorithms used: For the elementary functions,{} the general approach is to apply identities so that the taylor series can be used,{} and,{} so that it will converge within \\spad{O( sqrt n )} steps. For example,{} using the identity \\spad{exp(x) = exp(x/2)**2},{} we can compute \\spad{exp(1/3)} to \\spad{n} digits of precision as follows. We have \\spad{exp(1/3) = exp(2 ** (-sqrt s) / 3) ** (2 ** sqrt s)}. The taylor series will converge in less than sqrt \\spad{n} steps and the exponentiation requires sqrt \\spad{n} multiplications for a total of \\spad{2 sqrt n} multiplications. Assuming integer multiplication costs \\spad{O( n**2 )} the overall running time is \\spad{O( sqrt(n) n**2 )}. This approach is the best known approach for precisions up to about 10,{}000 digits at which point the methods of Brent which are \\spad{O( log(n) n**2 )} become competitive. Note also that summing the terms of the taylor series for the elementary functions is done using integer operations. This avoids the overhead of floating point operations and results in efficient code at low precisions. This implementation makes no attempt to reuse storage,{} relying on the underlying system to do \\spadgloss{garbage collection}. \\spad{I} estimate that the efficiency of this package at low precisions could be improved by a factor of 2 if in-place operations were available. \\blankline Running times: in the following,{} \\spad{n} is the number of bits of precision\\spad{\\br} \\spad{*},{} \\spad{/},{} \\spad{sqrt},{} \\spad{\\spad{pi}},{} \\spad{exp1},{} \\spad{log2},{} \\spad{log10}: \\spad{ O( n**2 )} \\spad{\\br} \\spad{exp},{} \\spad{log},{} \\spad{sin},{} \\spad{atan}: \\spad{O(sqrt(n) n**2)}\\spad{\\br} The other elementary functions are coded in terms of the ones above.")) (|outputSpacing| (((|Void|) (|NonNegativeInteger|)) "\\spad{outputSpacing(n)} inserts a space after \\spad{n} (default 10) digits on output; outputSpacing(0) means no spaces are inserted.")) (|outputGeneral| (((|Void|) (|NonNegativeInteger|)) "\\spad{outputGeneral(n)} sets the output mode to general notation with \\spad{n} significant digits displayed.") (((|Void|)) "\\spad{outputGeneral()} sets the output mode (default mode) to general notation; numbers will be displayed in either fixed or floating (scientific) notation depending on the magnitude.")) (|outputFixed| (((|Void|) (|NonNegativeInteger|)) "\\spad{outputFixed(n)} sets the output mode to fixed point notation,{} with \\spad{n} digits displayed after the decimal point.") (((|Void|)) "\\spad{outputFixed()} sets the output mode to fixed point notation; the output will contain a decimal point.")) (|outputFloating| (((|Void|) (|NonNegativeInteger|)) "\\spad{outputFloating(n)} sets the output mode to floating (scientific) notation with \\spad{n} significant digits displayed after the decimal point.") (((|Void|)) "\\spad{outputFloating()} sets the output mode to floating (scientific) notation,{} \\spadignore{i.e.} \\spad{mantissa * 10 exponent} is displayed as \\spad{0.mantissa E exponent}.")) (|convert| (($ (|DoubleFloat|)) "\\spad{convert(x)} converts a \\spadtype{DoubleFloat} \\spad{x} to a \\spadtype{Float}.")) (|atan| (($ $ $) "\\spad{atan(x,{}y)} computes the arc tangent from \\spad{x} with phase \\spad{y}.")) (|exp1| (($) "\\spad{exp1()} returns exp 1: \\spad{2.7182818284...}.")) (|log10| (($ $) "\\spad{log10(x)} computes the logarithm for \\spad{x} to base 10.") (($) "\\spad{log10()} returns \\spad{ln 10}: \\spad{2.3025809299...}.")) (|log2| (($ $) "\\spad{log2(x)} computes the logarithm for \\spad{x} to base 2.") (($) "\\spad{log2()} returns \\spad{ln 2},{} \\spadignore{i.e.} \\spad{0.6931471805...}.")) (|rationalApproximation| (((|Fraction| (|Integer|)) $ (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{rationalApproximation(f,{} n,{} b)} computes a rational approximation \\spad{r} to \\spad{f} with relative error \\spad{< b**(-n)},{} that is \\spad{|(r-f)/f| < b**(-n)}.") (((|Fraction| (|Integer|)) $ (|NonNegativeInteger|)) "\\spad{rationalApproximation(f,{} n)} computes a rational approximation \\spad{r} to \\spad{f} with relative error \\spad{< 10**(-n)}.")) (|shift| (($ $ (|Integer|)) "\\spad{shift(x,{}n)} adds \\spad{n} to the exponent of float \\spad{x}.")) (|relerror| (((|Integer|) $ $) "\\spad{relerror(x,{}y)} computes the absolute value of \\spad{x - y} divided by \\spad{y},{} when \\spad{y \\^= 0}.")) (|normalize| (($ $) "\\spad{normalize(x)} normalizes \\spad{x} at current precision.")) (** (($ $ $) "\\spad{x ** y} computes \\spad{exp(y log x)} where \\spad{x >= 0}.")) (/ (($ $ (|Integer|)) "\\spad{x / i} computes the division from \\spad{x} by an integer \\spad{i}."))) 
-((-4502 . T) (-4510 . T) (-3996 . T) (-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4504 . T) (-4512 . T) (-3999 . T) (-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-382 |Par|) 
 ((|constructor| (NIL "This is a package for the approximation of real solutions for systems of polynomial equations over the rational numbers. The results are expressed as either rational numbers or floats depending on the type of the precision parameter which can be either a rational number or a floating point number.")) (|realRoots| (((|List| |#1|) (|Fraction| (|Polynomial| (|Integer|))) |#1|) "\\spad{realRoots(rf,{} eps)} finds the real zeros of a univariate rational function with precision given by eps.") (((|List| (|List| |#1|)) (|List| (|Fraction| (|Polynomial| (|Integer|)))) (|List| (|Symbol|)) |#1|) "\\spad{realRoots(lp,{}lv,{}eps)} computes the list of the real solutions of the list \\spad{lp} of rational functions with rational coefficients with respect to the variables in \\spad{lv},{} with precision \\spad{eps}. Each solution is expressed as a list of numbers in order corresponding to the variables in \\spad{lv}.")) (|solve| (((|List| (|Equation| (|Polynomial| |#1|))) (|Equation| (|Fraction| (|Polynomial| (|Integer|)))) |#1|) "\\spad{solve(eq,{}eps)} finds all of the real solutions of the univariate equation \\spad{eq} of rational functions with respect to the unique variables appearing in \\spad{eq},{} with precision \\spad{eps}.") (((|List| (|Equation| (|Polynomial| |#1|))) (|Fraction| (|Polynomial| (|Integer|))) |#1|) "\\spad{solve(p,{}eps)} finds all of the real solutions of the univariate rational function \\spad{p} with rational coefficients with respect to the unique variable appearing in \\spad{p},{} with precision \\spad{eps}.") (((|List| (|List| (|Equation| (|Polynomial| |#1|)))) (|List| (|Equation| (|Fraction| (|Polynomial| (|Integer|))))) |#1|) "\\spad{solve(leq,{}eps)} finds all of the real solutions of the system \\spad{leq} of equationas of rational functions with respect to all the variables appearing in \\spad{lp},{} with precision \\spad{eps}.") (((|List| (|List| (|Equation| (|Polynomial| |#1|)))) (|List| (|Fraction| (|Polynomial| (|Integer|)))) |#1|) "\\spad{solve(lp,{}eps)} finds all of the real solutions of the system \\spad{lp} of rational functions over the rational numbers with respect to all the variables appearing in \\spad{lp},{} with precision \\spad{eps}."))) 
@@ -1462,11 +1462,11 @@ NIL
 NIL 
 (-383 R S) 
 ((|constructor| (NIL "This domain implements linear combinations of elements from the domain \\spad{S} with coefficients in the domain \\spad{R} where \\spad{S} is an ordered set and \\spad{R} is a ring (which may be non-commutative). This domain is used by domains of non-commutative algebra such as: XDistributedPolynomial,{} XRecursivePolynomial.")) (* (($ |#2| |#1|) "\\spad{s*r} returns the product \\spad{r*s} used by \\spadtype{XRecursivePolynomial}"))) 
-((-4514 . T) (-4513 . T)) 
+((-4516 . T) (-4515 . T)) 
 ((|HasCategory| |#1| (QUOTE (-172)))) 
 (-384 R |Basis|) 
 ((|constructor| (NIL "A domain of this category implements formal linear combinations of elements from a domain \\spad{Basis} with coefficients in a domain \\spad{R}. The domain \\spad{Basis} needs only to belong to the category \\spadtype{SetCategory} and \\spad{R} to the category \\spadtype{Ring}. Thus the coefficient ring may be non-commutative. See the \\spadtype{XDistributedPolynomial} constructor for examples of domains built with the \\spadtype{FreeModuleCat} category constructor.")) (|reductum| (($ $) "\\spad{reductum(x)} returns \\spad{x} minus its leading term.")) (|leadingTerm| (((|Record| (|:| |k| |#2|) (|:| |c| |#1|)) $) "\\spad{leadingTerm(x)} returns the first term which appears in \\spad{listOfTerms(x)}.")) (|leadingCoefficient| ((|#1| $) "\\spad{leadingCoefficient(x)} returns the first coefficient which appears in \\spad{listOfTerms(x)}.")) (|leadingMonomial| ((|#2| $) "\\spad{leadingMonomial(x)} returns the first element from \\spad{Basis} which appears in \\spad{listOfTerms(x)}.")) (|numberOfMonomials| (((|NonNegativeInteger|) $) "\\spad{numberOfMonomials(x)} returns the number of monomials of \\spad{x}.")) (|monomials| (((|List| $) $) "\\spad{monomials(x)} returns the list of \\spad{r_i*b_i} whose sum is \\spad{x}.")) (|coefficients| (((|List| |#1|) $) "\\spad{coefficients(x)} returns the list of coefficients of \\spad{x}")) (|listOfTerms| (((|List| (|Record| (|:| |k| |#2|) (|:| |c| |#1|))) $) "\\spad{listOfTerms(x)} returns a list \\spad{lt} of terms with type \\spad{Record(k: Basis,{} c: R)} such that \\spad{x} equals \\spad{reduce(+,{} map(x +-> monom(x.k,{} x.c),{} lt))}.")) (|monomial?| (((|Boolean|) $) "\\spad{monomial?(x)} returns \\spad{true} if \\spad{x} contains a single monomial.")) (|monom| (($ |#2| |#1|) "\\spad{monom(b,{}r)} returns the element with the single monomial \\indented{1}{\\spad{b} and coefficient \\spad{r}.}")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\spad{map(fn,{}u)} maps function \\spad{fn} onto the coefficients \\indented{1}{of the non-zero monomials of \\spad{u}.}")) (|coefficient| ((|#1| $ |#2|) "\\spad{coefficient(x,{}b)} returns the coefficient of \\spad{b} in \\spad{x}.")) (* (($ |#1| |#2|) "\\spad{r*b} returns the product of \\spad{r} by \\spad{b}."))) 
-((-4514 . T) (-4513 . T)) 
+((-4516 . T) (-4515 . T)) 
 NIL 
 (-385) 
 ((|constructor| (NIL "\\axiomType{FortranMatrixCategory} provides support for producing Functions and Subroutines when the input to these is an AXIOM object of type \\axiomType{Matrix} or in domains involving \\axiomType{FortranCode}.")) (|coerce| (($ (|Record| (|:| |localSymbols| (|SymbolTable|)) (|:| |code| (|List| (|FortranCode|))))) "\\spad{coerce(e)} takes the component of \\spad{e} from \\spadtype{List FortranCode} and uses it as the body of the ASP,{} making the declarations in the \\spadtype{SymbolTable} component.") (($ (|FortranCode|)) "\\spad{coerce(e)} takes an object from \\spadtype{FortranCode} and \\indented{1}{uses it as the body of an ASP.}") (($ (|List| (|FortranCode|))) "\\spad{coerce(e)} takes an object from \\spadtype{List FortranCode} and \\indented{1}{uses it as the body of an ASP.}") (($ (|Matrix| (|MachineFloat|))) "\\spad{coerce(v)} produces an ASP which returns the value of \\spad{v}."))) 
@@ -1478,7 +1478,7 @@ NIL
 NIL 
 (-387 R S) 
 ((|constructor| (NIL "A \\spad{bi}-module is a free module over a ring with generators indexed by an ordered set. Each element can be expressed as a finite linear combination of generators. Only non-zero terms are stored."))) 
-((-4514 . T) (-4513 . T)) 
+((-4516 . T) (-4515 . T)) 
 ((|HasCategory| |#1| (QUOTE (-172)))) 
 (-388 S) 
 ((|constructor| (NIL "The free monoid on a set \\spad{S} is the monoid of finite products of the form \\spad{reduce(*,{}[\\spad{si} ** \\spad{ni}])} where the \\spad{si}\\spad{'s} are in \\spad{S},{} and the \\spad{ni}\\spad{'s} are nonnegative integers. The multiplication is not commutative.")) (|mapGen| (($ (|Mapping| |#1| |#1|) $) "\\spad{mapGen(f,{} a1\\^e1 ... an\\^en)} returns \\spad{f(a1)\\^e1 ... f(an)\\^en}.")) (|mapExpon| (($ (|Mapping| (|NonNegativeInteger|) (|NonNegativeInteger|)) $) "\\spad{mapExpon(f,{} a1\\^e1 ... an\\^en)} returns \\spad{a1\\^f(e1) ... an\\^f(en)}.")) (|nthFactor| ((|#1| $ (|Integer|)) "\\spad{nthFactor(x,{} n)} returns the factor of the n^th monomial of \\spad{x}.")) (|nthExpon| (((|NonNegativeInteger|) $ (|Integer|)) "\\spad{nthExpon(x,{} n)} returns the exponent of the n^th monomial of \\spad{x}.")) (|factors| (((|List| (|Record| (|:| |gen| |#1|) (|:| |exp| (|NonNegativeInteger|)))) $) "\\spad{factors(a1\\^e1,{}...,{}an\\^en)} returns \\spad{[[a1,{} e1],{}...,{}[an,{} en]]}.")) (|size| (((|NonNegativeInteger|) $) "\\spad{size(x)} returns the number of monomials in \\spad{x}.")) (|overlap| (((|Record| (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $) "\\spad{overlap(x,{} y)} returns \\spad{[l,{} m,{} r]} such that \\spad{x = l * m},{} \\spad{y = m * r} and \\spad{l} and \\spad{r} have no overlap,{} \\spadignore{i.e.} \\spad{overlap(l,{} r) = [l,{} 1,{} r]}.")) (|divide| (((|Union| (|Record| (|:| |lm| $) (|:| |rm| $)) "failed") $ $) "\\spad{divide(x,{} y)} returns the left and right exact quotients of \\spad{x} by \\spad{y},{} \\spadignore{i.e.} \\spad{[l,{} r]} such that \\spad{x = l * y * r},{} \"failed\" if \\spad{x} is not of the form \\spad{l * y * r}.")) (|rquo| (((|Union| $ "failed") $ $) "\\spad{rquo(x,{} y)} returns the exact right quotient of \\spad{x} by \\spad{y} \\spadignore{i.e.} \\spad{q} such that \\spad{x = q * y},{} \"failed\" if \\spad{x} is not of the form \\spad{q * y}.")) (|lquo| (((|Union| $ "failed") $ $) "\\spad{lquo(x,{} y)} returns the exact left quotient of \\spad{x} by \\spad{y} \\spadignore{i.e.} \\spad{q} such that \\spad{x = y * q},{} \"failed\" if \\spad{x} is not of the form \\spad{y * q}.")) (|hcrf| (($ $ $) "\\spad{hcrf(x,{} y)} returns the highest common right factor of \\spad{x} and \\spad{y},{} \\spadignore{i.e.} the largest \\spad{d} such that \\spad{x = a d} and \\spad{y = b d}.")) (|hclf| (($ $ $) "\\spad{hclf(x,{} y)} returns the highest common left factor of \\spad{x} and \\spad{y},{} \\spadignore{i.e.} the largest \\spad{d} such that \\spad{x = d a} and \\spad{y = d b}.")) (** (($ |#1| (|NonNegativeInteger|)) "\\spad{s ** n} returns the product of \\spad{s} by itself \\spad{n} times.")) (* (($ $ |#1|) "\\spad{x * s} returns the product of \\spad{x} by \\spad{s} on the right.") (($ |#1| $) "\\spad{s * x} returns the product of \\spad{x} by \\spad{s} on the left."))) 
@@ -1486,7 +1486,7 @@ NIL
 ((|HasCategory| |#1| (QUOTE (-842)))) 
 (-389) 
 ((|constructor| (NIL "A category of domains which model machine arithmetic used by machines in the AXIOM-NAG link."))) 
-((-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-390) 
 ((|constructor| (NIL "This domain provides an interface to names in the file system."))) 
@@ -1498,7 +1498,7 @@ NIL
 NIL 
 (-392 |n| |class| R) 
 ((|constructor| (NIL "Generate the Free Lie Algebra over a ring \\spad{R} with identity; A \\spad{P}. Hall basis is generated by a package call to HallBasis.")) (|generator| (($ (|NonNegativeInteger|)) "\\spad{generator(i)} is the \\spad{i}th Hall Basis element")) (|shallowExpand| (((|OutputForm|) $) "\\spad{shallowExpand(x)} is not documented")) (|deepExpand| (((|OutputForm|) $) "\\spad{deepExpand(x)} is not documented")) (|dimension| (((|NonNegativeInteger|)) "\\spad{dimension()} is the rank of this Lie algebra"))) 
-((-4514 . T) (-4513 . T)) 
+((-4516 . T) (-4515 . T)) 
 NIL 
 (-393) 
 ((|constructor| (NIL "Code to manipulate Fortran Output Stack")) (|topFortranOutputStack| (((|String|)) "\\spad{topFortranOutputStack()} returns the top element of the Fortran output stack")) (|pushFortranOutputStack| (((|Void|) (|String|)) "\\spad{pushFortranOutputStack(f)} pushes \\spad{f} onto the Fortran output stack") (((|Void|) (|FileName|)) "\\spad{pushFortranOutputStack(f)} pushes \\spad{f} onto the Fortran output stack")) (|popFortranOutputStack| (((|Void|)) "\\spad{popFortranOutputStack()} pops the Fortran output stack")) (|showFortranOutputStack| (((|Stack| (|String|))) "\\spad{showFortranOutputStack()} returns the Fortran output stack")) (|clearFortranOutputStack| (((|Stack| (|String|))) "\\spad{clearFortranOutputStack()} clears the Fortran output stack"))) 
@@ -1528,7 +1528,7 @@ NIL
 ((|constructor| (NIL "provides an interface to the boot code for calling Fortran")) (|setLegalFortranSourceExtensions| (((|List| (|String|)) (|List| (|String|))) "\\spad{setLegalFortranSourceExtensions(l)} \\undocumented{}")) (|outputAsFortran| (((|Void|) (|FileName|)) "\\spad{outputAsFortran(fn)} \\undocumented{}")) (|linkToFortran| (((|SExpression|) (|Symbol|) (|List| (|Symbol|)) (|TheSymbolTable|) (|List| (|Symbol|))) "\\spad{linkToFortran(s,{}l,{}t,{}lv)} \\undocumented{}") (((|SExpression|) (|Symbol|) (|List| (|Union| (|:| |array| (|List| (|Symbol|))) (|:| |scalar| (|Symbol|)))) (|List| (|List| (|Union| (|:| |array| (|List| (|Symbol|))) (|:| |scalar| (|Symbol|))))) (|List| (|Symbol|)) (|Symbol|)) "\\spad{linkToFortran(s,{}l,{}ll,{}lv,{}t)} \\undocumented{}") (((|SExpression|) (|Symbol|) (|List| (|Union| (|:| |array| (|List| (|Symbol|))) (|:| |scalar| (|Symbol|)))) (|List| (|List| (|Union| (|:| |array| (|List| (|Symbol|))) (|:| |scalar| (|Symbol|))))) (|List| (|Symbol|))) "\\spad{linkToFortran(s,{}l,{}ll,{}lv)} \\undocumented{}"))) 
 NIL 
 NIL 
-(-400 -3391 |returnType| |arguments| |symbols|) 
+(-400 -3393 |returnType| |arguments| |symbols|) 
 ((|constructor| (NIL "\\axiomType{FortranProgram} allows the user to build and manipulate simple models of FORTRAN subprograms. These can then be transformed into actual FORTRAN notation.")) (|coerce| (($ (|Equation| (|Expression| (|Complex| (|Float|))))) "\\spad{coerce(eq)} is not documented") (($ (|Equation| (|Expression| (|Float|)))) "\\spad{coerce(eq)} is not documented") (($ (|Equation| (|Expression| (|Integer|)))) "\\spad{coerce(eq)} is not documented") (($ (|Expression| (|Complex| (|Float|)))) "\\spad{coerce(e)} is not documented") (($ (|Expression| (|Float|))) "\\spad{coerce(e)} is not documented") (($ (|Expression| (|Integer|))) "\\spad{coerce(e)} is not documented") (($ (|Equation| (|Expression| (|MachineComplex|)))) "\\spad{coerce(eq)} is not documented") (($ (|Equation| (|Expression| (|MachineFloat|)))) "\\spad{coerce(eq)} is not documented") (($ (|Equation| (|Expression| (|MachineInteger|)))) "\\spad{coerce(eq)} is not documented") (($ (|Expression| (|MachineComplex|))) "\\spad{coerce(e)} is not documented") (($ (|Expression| (|MachineFloat|))) "\\spad{coerce(e)} is not documented") (($ (|Expression| (|MachineInteger|))) "\\spad{coerce(e)} is not documented") (($ (|Record| (|:| |localSymbols| (|SymbolTable|)) (|:| |code| (|List| (|FortranCode|))))) "\\spad{coerce(r)} is not documented") (($ (|List| (|FortranCode|))) "\\spad{coerce(lfc)} is not documented") (($ (|FortranCode|)) "\\spad{coerce(fc)} is not documented"))) 
 NIL 
 NIL 
@@ -1546,15 +1546,15 @@ NIL
 NIL 
 (-404) 
 ((|constructor| (NIL "FieldOfPrimeCharacteristic is the category of fields of prime characteristic,{} \\spadignore{e.g.} finite fields,{} algebraic closures of fields of prime characteristic,{} transcendental extensions of of fields of prime characteristic.")) (|primeFrobenius| (($ $ (|NonNegativeInteger|)) "\\spad{primeFrobenius(a,{}s)} returns \\spad{a**(p**s)} where \\spad{p} is the characteristic.") (($ $) "\\spad{primeFrobenius(a)} returns \\spad{a**p} where \\spad{p} is the characteristic.")) (|discreteLog| (((|Union| (|NonNegativeInteger|) "failed") $ $) "\\spad{discreteLog(b,{}a)} computes \\spad{s} with \\spad{b**s = a} if such an \\spad{s} exists.")) (|order| (((|OnePointCompletion| (|PositiveInteger|)) $) "\\spad{order(a)} computes the order of an element in the multiplicative group of the field. Error: if \\spad{a} is 0."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-405 S) 
 ((|constructor| (NIL "This category is intended as a model for floating point systems. A floating point system is a model for the real numbers. In fact,{} it is an approximation in the sense that not all real numbers are exactly representable by floating point numbers. A floating point system is characterized by the following: \\blankline 1: base of the exponent where the actual implemenations are usually binary or decimal)\\spad{\\br} 2: precision of the mantissa (arbitrary or fixed)\\spad{\\br} 3: rounding error for operations \\blankline Because a Float is an approximation to the real numbers,{} even though it is defined to be a join of a Field and OrderedRing,{} some of the attributes do not hold. In particular associative(\\spad{\"+\"}) does not hold. Algorithms defined over a field need special considerations when the field is a floating point system.")) (|max| (($) "\\spad{max()} returns the maximum floating point number.")) (|min| (($) "\\spad{min()} returns the minimum floating point number.")) (|decreasePrecision| (((|PositiveInteger|) (|Integer|)) "\\spad{decreasePrecision(n)} decreases the current \\spadfunFrom{precision}{FloatingPointSystem} precision by \\spad{n} decimal digits.")) (|increasePrecision| (((|PositiveInteger|) (|Integer|)) "\\spad{increasePrecision(n)} increases the current \\spadfunFrom{precision}{FloatingPointSystem} by \\spad{n} decimal digits.")) (|precision| (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{precision(n)} set the precision in the base to \\spad{n} decimal digits.") (((|PositiveInteger|)) "\\spad{precision()} returns the precision in digits base.")) (|digits| (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{digits(d)} set the \\spadfunFrom{precision}{FloatingPointSystem} to \\spad{d} digits.") (((|PositiveInteger|)) "\\spad{digits()} returns ceiling\\spad{'s} precision in decimal digits.")) (|bits| (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{bits(n)} set the \\spadfunFrom{precision}{FloatingPointSystem} to \\spad{n} bits.") (((|PositiveInteger|)) "\\spad{bits()} returns ceiling\\spad{'s} precision in bits.")) (|mantissa| (((|Integer|) $) "\\spad{mantissa(x)} returns the mantissa part of \\spad{x}.")) (|exponent| (((|Integer|) $) "\\spad{exponent(x)} returns the \\spadfunFrom{exponent}{FloatingPointSystem} part of \\spad{x}.")) (|base| (((|PositiveInteger|)) "\\indented{1}{base() returns the base of the} \\spadfunFrom{exponent}{FloatingPointSystem}.")) (|order| (((|Integer|) $) "\\spad{order x} is the order of magnitude of \\spad{x}. Note that \\spad{base ** order x <= |x| < base ** (1 + order x)}.")) (|float| (($ (|Integer|) (|Integer|) (|PositiveInteger|)) "\\spad{float(a,{}e,{}b)} returns \\spad{a * b ** e}.") (($ (|Integer|) (|Integer|)) "\\spad{float(a,{}e)} returns \\spad{a * base() ** e}.")) (|approximate| ((|attribute|) "\\spad{approximate} means \"is an approximation to the real numbers\"."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE -4502)) (|HasAttribute| |#1| (QUOTE -4510))) 
+((|HasAttribute| |#1| (QUOTE -4504)) (|HasAttribute| |#1| (QUOTE -4512))) 
 (-406) 
 ((|constructor| (NIL "This category is intended as a model for floating point systems. A floating point system is a model for the real numbers. In fact,{} it is an approximation in the sense that not all real numbers are exactly representable by floating point numbers. A floating point system is characterized by the following: \\blankline 1: base of the exponent where the actual implemenations are usually binary or decimal)\\spad{\\br} 2: precision of the mantissa (arbitrary or fixed)\\spad{\\br} 3: rounding error for operations \\blankline Because a Float is an approximation to the real numbers,{} even though it is defined to be a join of a Field and OrderedRing,{} some of the attributes do not hold. In particular associative(\\spad{\"+\"}) does not hold. Algorithms defined over a field need special considerations when the field is a floating point system.")) (|max| (($) "\\spad{max()} returns the maximum floating point number.")) (|min| (($) "\\spad{min()} returns the minimum floating point number.")) (|decreasePrecision| (((|PositiveInteger|) (|Integer|)) "\\spad{decreasePrecision(n)} decreases the current \\spadfunFrom{precision}{FloatingPointSystem} precision by \\spad{n} decimal digits.")) (|increasePrecision| (((|PositiveInteger|) (|Integer|)) "\\spad{increasePrecision(n)} increases the current \\spadfunFrom{precision}{FloatingPointSystem} by \\spad{n} decimal digits.")) (|precision| (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{precision(n)} set the precision in the base to \\spad{n} decimal digits.") (((|PositiveInteger|)) "\\spad{precision()} returns the precision in digits base.")) (|digits| (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{digits(d)} set the \\spadfunFrom{precision}{FloatingPointSystem} to \\spad{d} digits.") (((|PositiveInteger|)) "\\spad{digits()} returns ceiling\\spad{'s} precision in decimal digits.")) (|bits| (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{bits(n)} set the \\spadfunFrom{precision}{FloatingPointSystem} to \\spad{n} bits.") (((|PositiveInteger|)) "\\spad{bits()} returns ceiling\\spad{'s} precision in bits.")) (|mantissa| (((|Integer|) $) "\\spad{mantissa(x)} returns the mantissa part of \\spad{x}.")) (|exponent| (((|Integer|) $) "\\spad{exponent(x)} returns the \\spadfunFrom{exponent}{FloatingPointSystem} part of \\spad{x}.")) (|base| (((|PositiveInteger|)) "\\indented{1}{base() returns the base of the} \\spadfunFrom{exponent}{FloatingPointSystem}.")) (|order| (((|Integer|) $) "\\spad{order x} is the order of magnitude of \\spad{x}. Note that \\spad{base ** order x <= |x| < base ** (1 + order x)}.")) (|float| (($ (|Integer|) (|Integer|) (|PositiveInteger|)) "\\spad{float(a,{}e,{}b)} returns \\spad{a * b ** e}.") (($ (|Integer|) (|Integer|)) "\\spad{float(a,{}e)} returns \\spad{a * base() ** e}.")) (|approximate| ((|attribute|) "\\spad{approximate} means \"is an approximation to the real numbers\"."))) 
-((-3996 . T) (-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-3999 . T) (-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-407 R S) 
 ((|constructor| (NIL "\\spadtype{FactoredFunctions2} contains functions that involve factored objects whose underlying domains may not be the same. For example,{} \\spadfun{map} might be used to coerce an object of type \\spadtype{Factored(Integer)} to \\spadtype{Factored(Complex(Integer))}.")) (|map| (((|Factored| |#2|) (|Mapping| |#2| |#1|) (|Factored| |#1|)) "\\spad{map(fn,{}u)} is used to apply the function \\userfun{\\spad{fn}} to every factor of \\spadvar{\\spad{u}}. The new factored object will have all its information flags set to \"nil\". This function is used,{} for example,{} to coerce every factor base to another type."))) 
@@ -1566,15 +1566,15 @@ NIL
 NIL 
 (-409 S) 
 ((|constructor| (NIL "Fraction takes an IntegralDomain \\spad{S} and produces the domain of Fractions with numerators and denominators from \\spad{S}. If \\spad{S} is also a GcdDomain,{} then \\spad{gcd}\\spad{'s} between numerator and denominator will be cancelled during all operations.")) (|canonical| ((|attribute|) "\\spad{canonical} means that equal elements are in fact identical."))) 
-((-4506 -12 (|has| |#1| (-6 -4517)) (|has| |#1| (-453)) (|has| |#1| (-6 -4506))) (-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-1021))) (|HasCategory| |#1| (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-1136))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (QUOTE (-225))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (LIST (QUOTE -523) (QUOTE (-1161)) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -281) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-550))) (-12 (|HasCategory| |#1| (QUOTE (-550))) (|HasCategory| |#1| (QUOTE (-823)))) (-12 (|HasAttribute| |#1| (QUOTE -4517)) (|HasAttribute| |#1| (QUOTE -4506)) (|HasCategory| |#1| (QUOTE (-453)))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (-12 (|HasCategory| |#1| (QUOTE (-550))) (|HasCategory| |#1| (QUOTE (-823))))) (|HasCategory| |#1| (QUOTE (-842))) (-2198 (|HasCategory| |#1| (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-842)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (-12 (|HasCategory| |#1| (QUOTE (-550))) (|HasCategory| |#1| (QUOTE (-823))))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568)))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568)))) (-12 (|HasCategory| |#1| (QUOTE (-550))) (|HasCategory| |#1| (QUOTE (-823))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (-12 (|HasCategory| |#1| (QUOTE (-550))) (|HasCategory| |#1| (QUOTE (-823))))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (-12 (|HasCategory| |#1| (QUOTE (-550))) (|HasCategory| |#1| (QUOTE (-823))))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))))) 
+((-4508 -12 (|has| |#1| (-6 -4519)) (|has| |#1| (-453)) (|has| |#1| (-6 -4508))) (-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-1021))) (|HasCategory| |#1| (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-1136))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (QUOTE (-225))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (LIST (QUOTE -523) (QUOTE (-1161)) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -281) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-550))) (-12 (|HasCategory| |#1| (QUOTE (-550))) (|HasCategory| |#1| (QUOTE (-823)))) (-12 (|HasAttribute| |#1| (QUOTE -4519)) (|HasAttribute| |#1| (QUOTE -4508)) (|HasCategory| |#1| (QUOTE (-453)))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (-12 (|HasCategory| |#1| (QUOTE (-550))) (|HasCategory| |#1| (QUOTE (-823))))) (|HasCategory| |#1| (QUOTE (-842))) (-2199 (|HasCategory| |#1| (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-842)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (-12 (|HasCategory| |#1| (QUOTE (-550))) (|HasCategory| |#1| (QUOTE (-823))))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568)))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568)))) (-12 (|HasCategory| |#1| (QUOTE (-550))) (|HasCategory| |#1| (QUOTE (-823))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (-12 (|HasCategory| |#1| (QUOTE (-550))) (|HasCategory| |#1| (QUOTE (-823))))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (-12 (|HasCategory| |#1| (QUOTE (-550))) (|HasCategory| |#1| (QUOTE (-823))))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))))) 
 (-410 S R UP) 
 ((|constructor| (NIL "A \\spadtype{FramedAlgebra} is a \\spadtype{FiniteRankAlgebra} together with a fixed \\spad{R}-module basis.")) (|regularRepresentation| (((|Matrix| |#2|) $) "\\spad{regularRepresentation(a)} returns the matrix of the linear map defined by left multiplication by \\spad{a} with respect to the fixed basis.")) (|discriminant| ((|#2|) "\\spad{discriminant()} = determinant(traceMatrix()).")) (|traceMatrix| (((|Matrix| |#2|)) "\\spad{traceMatrix()} is the \\spad{n}-by-\\spad{n} matrix ( \\spad{Tr(\\spad{vi} * vj)} ),{} where \\spad{v1},{} ...,{} \\spad{vn} are the elements of the fixed basis.")) (|convert| (($ (|Vector| |#2|)) "\\spad{convert([a1,{}..,{}an])} returns \\spad{a1*v1 + ... + an*vn},{} where \\spad{v1},{} ...,{} \\spad{vn} are the elements of the fixed basis.") (((|Vector| |#2|) $) "\\spad{convert(a)} returns the coordinates of \\spad{a} with respect to the fixed \\spad{R}-module basis.")) (|represents| (($ (|Vector| |#2|)) "\\spad{represents([a1,{}..,{}an])} returns \\spad{a1*v1 + ... + an*vn},{} where \\spad{v1},{} ...,{} \\spad{vn} are the elements of the fixed basis.")) (|coordinates| (((|Matrix| |#2|) (|Vector| $)) "\\spad{coordinates([v1,{}...,{}vm])} returns the coordinates of the \\spad{vi}\\spad{'s} with to the fixed basis. The coordinates of \\spad{vi} are contained in the \\spad{i}th row of the matrix returned by this function.") (((|Vector| |#2|) $) "\\spad{coordinates(a)} returns the coordinates of \\spad{a} with respect to the fixed \\spad{R}-module basis.")) (|basis| (((|Vector| $)) "\\spad{basis()} returns the fixed \\spad{R}-module basis."))) 
 NIL 
 NIL 
 (-411 R UP) 
 ((|constructor| (NIL "A \\spadtype{FramedAlgebra} is a \\spadtype{FiniteRankAlgebra} together with a fixed \\spad{R}-module basis.")) (|regularRepresentation| (((|Matrix| |#1|) $) "\\spad{regularRepresentation(a)} returns the matrix of the linear map defined by left multiplication by \\spad{a} with respect to the fixed basis.")) (|discriminant| ((|#1|) "\\spad{discriminant()} = determinant(traceMatrix()).")) (|traceMatrix| (((|Matrix| |#1|)) "\\spad{traceMatrix()} is the \\spad{n}-by-\\spad{n} matrix ( \\spad{Tr(\\spad{vi} * vj)} ),{} where \\spad{v1},{} ...,{} \\spad{vn} are the elements of the fixed basis.")) (|convert| (($ (|Vector| |#1|)) "\\spad{convert([a1,{}..,{}an])} returns \\spad{a1*v1 + ... + an*vn},{} where \\spad{v1},{} ...,{} \\spad{vn} are the elements of the fixed basis.") (((|Vector| |#1|) $) "\\spad{convert(a)} returns the coordinates of \\spad{a} with respect to the fixed \\spad{R}-module basis.")) (|represents| (($ (|Vector| |#1|)) "\\spad{represents([a1,{}..,{}an])} returns \\spad{a1*v1 + ... + an*vn},{} where \\spad{v1},{} ...,{} \\spad{vn} are the elements of the fixed basis.")) (|coordinates| (((|Matrix| |#1|) (|Vector| $)) "\\spad{coordinates([v1,{}...,{}vm])} returns the coordinates of the \\spad{vi}\\spad{'s} with to the fixed basis. The coordinates of \\spad{vi} are contained in the \\spad{i}th row of the matrix returned by this function.") (((|Vector| |#1|) $) "\\spad{coordinates(a)} returns the coordinates of \\spad{a} with respect to the fixed \\spad{R}-module basis.")) (|basis| (((|Vector| $)) "\\spad{basis()} returns the fixed \\spad{R}-module basis."))) 
-((-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-412 A S) 
 ((|constructor| (NIL "A is fully retractable to \\spad{B} means that A is retractable to \\spad{B} and if \\spad{B} is retractable to the integers or rational numbers then so is A. In particular,{} what we are asserting is that there are no integers (rationals) in A which don\\spad{'t} retract into \\spad{B}."))) 
@@ -1590,7 +1590,7 @@ NIL
 NIL 
 (-415 R -1478 UP A) 
 ((|constructor| (NIL "Fractional ideals in a framed algebra.")) (|randomLC| ((|#4| (|NonNegativeInteger|) (|Vector| |#4|)) "\\spad{randomLC(n,{}x)} should be local but conditional.")) (|minimize| (($ $) "\\spad{minimize(I)} returns a reduced set of generators for \\spad{I}.")) (|denom| ((|#1| $) "\\spad{denom(1/d * (f1,{}...,{}fn))} returns \\spad{d}.")) (|numer| (((|Vector| |#4|) $) "\\spad{numer(1/d * (f1,{}...,{}fn))} = the vector \\spad{[f1,{}...,{}fn]}.")) (|norm| ((|#2| $) "\\spad{norm(I)} returns the norm of the ideal \\spad{I}.")) (|basis| (((|Vector| |#4|) $) "\\spad{basis((f1,{}...,{}fn))} returns the vector \\spad{[f1,{}...,{}fn]}.")) (|ideal| (($ (|Vector| |#4|)) "\\spad{ideal([f1,{}...,{}fn])} returns the ideal \\spad{(f1,{}...,{}fn)}."))) 
-((-4516 . T)) 
+((-4518 . T)) 
 NIL 
 (-416 R -1478 UP A |ibasis|) 
 ((|constructor| (NIL "Module representation of fractional ideals.")) (|module| (($ (|FractionalIdeal| |#1| |#2| |#3| |#4|)) "\\spad{module(I)} returns \\spad{I} viewed has a module over \\spad{R}.") (($ (|Vector| |#4|)) "\\spad{module([f1,{}...,{}fn])} = the module generated by \\spad{(f1,{}...,{}fn)} over \\spad{R}.")) (|norm| ((|#2| $) "\\spad{norm(f)} returns the norm of the module \\spad{f}.")) (|basis| (((|Vector| |#4|) $) "\\spad{basis((f1,{}...,{}fn))} = the vector \\spad{[f1,{}...,{}fn]}."))) 
@@ -1606,12 +1606,12 @@ NIL
 ((|HasCategory| |#2| (QUOTE (-365)))) 
 (-419 R) 
 ((|constructor| (NIL "FramedNonAssociativeAlgebra(\\spad{R}) is a \\spadtype{FiniteRankNonAssociativeAlgebra} (\\spadignore{i.e.} a non associative algebra over \\spad{R} which is a free \\spad{R}-module of finite rank) over a commutative ring \\spad{R} together with a fixed \\spad{R}-module basis.")) (|apply| (($ (|Matrix| |#1|) $) "\\spad{apply(m,{}a)} defines a left operation of \\spad{n} by \\spad{n} matrices where \\spad{n} is the rank of the algebra in terms of matrix-vector multiplication,{} this is a substitute for a left module structure. Error: if shape of matrix doesn\\spad{'t} fit.")) (|rightRankPolynomial| (((|SparseUnivariatePolynomial| (|Polynomial| |#1|))) "\\spad{rightRankPolynomial()} calculates the right minimal polynomial of the generic element in the algebra,{} defined by the same structural constants over the polynomial ring in symbolic coefficients with respect to the fixed basis.")) (|leftRankPolynomial| (((|SparseUnivariatePolynomial| (|Polynomial| |#1|))) "\\spad{leftRankPolynomial()} calculates the left minimal polynomial of the generic element in the algebra,{} defined by the same structural constants over the polynomial ring in symbolic coefficients with respect to the fixed basis.")) (|rightRegularRepresentation| (((|Matrix| |#1|) $) "\\spad{rightRegularRepresentation(a)} returns the matrix of the linear map defined by right multiplication by \\spad{a} with respect to the fixed \\spad{R}-module basis.")) (|leftRegularRepresentation| (((|Matrix| |#1|) $) "\\spad{leftRegularRepresentation(a)} returns the matrix of the linear map defined by left multiplication by \\spad{a} with respect to the fixed \\spad{R}-module basis.")) (|rightTraceMatrix| (((|Matrix| |#1|)) "\\spad{rightTraceMatrix()} is the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}\\spad{-}th row and \\spad{j}\\spad{-}th column is given by the right trace of the product \\spad{vi*vj},{} where \\spad{v1},{}...,{}\\spad{vn} are the elements of the fixed \\spad{R}-module basis.")) (|leftTraceMatrix| (((|Matrix| |#1|)) "\\spad{leftTraceMatrix()} is the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}\\spad{-}th row and \\spad{j}\\spad{-}th column is given by left trace of the product \\spad{vi*vj},{} where \\spad{v1},{}...,{}\\spad{vn} are the elements of the fixed \\spad{R}-module basis.")) (|rightDiscriminant| ((|#1|) "\\spad{rightDiscriminant()} returns the determinant of the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}\\spad{-}th row and \\spad{j}\\spad{-}th column is given by the right trace of the product \\spad{vi*vj},{} where \\spad{v1},{}...,{}\\spad{vn} are the elements of the fixed \\spad{R}-module basis. Note that the same as \\spad{determinant(rightTraceMatrix())}.")) (|leftDiscriminant| ((|#1|) "\\spad{leftDiscriminant()} returns the determinant of the \\spad{n}-by-\\spad{n} matrix whose element at the \\spad{i}\\spad{-}th row and \\spad{j}\\spad{-}th column is given by the left trace of the product \\spad{vi*vj},{} where \\spad{v1},{}...,{}\\spad{vn} are the elements of the fixed \\spad{R}-module basis. Note that the same as \\spad{determinant(leftTraceMatrix())}.")) (|convert| (($ (|Vector| |#1|)) "\\spad{convert([a1,{}...,{}an])} returns \\spad{a1*v1 + ... + an*vn},{} where \\spad{v1},{} ...,{} \\spad{vn} are the elements of the fixed \\spad{R}-module basis.") (((|Vector| |#1|) $) "\\spad{convert(a)} returns the coordinates of \\spad{a} with respect to the fixed \\spad{R}-module basis.")) (|represents| (($ (|Vector| |#1|)) "\\spad{represents([a1,{}...,{}an])} returns \\spad{a1*v1 + ... + an*vn},{} where \\spad{v1},{} ...,{} \\spad{vn} are the elements of the fixed \\spad{R}-module basis.")) (|conditionsForIdempotents| (((|List| (|Polynomial| |#1|))) "\\spad{conditionsForIdempotents()} determines a complete list of polynomial equations for the coefficients of idempotents with respect to the fixed \\spad{R}-module basis.")) (|structuralConstants| (((|Vector| (|Matrix| |#1|))) "\\spad{structuralConstants()} calculates the structural constants \\spad{[(gammaijk) for k in 1..rank()]} defined by \\spad{\\spad{vi} * vj = gammaij1 * v1 + ... + gammaijn * vn},{} where \\spad{v1},{}...,{}\\spad{vn} is the fixed \\spad{R}-module basis.")) (|elt| ((|#1| $ (|Integer|)) "\\spad{elt(a,{}i)} returns the \\spad{i}-th coefficient of \\spad{a} with respect to the fixed \\spad{R}-module basis.")) (|coordinates| (((|Matrix| |#1|) (|Vector| $)) "\\spad{coordinates([a1,{}...,{}am])} returns a matrix whose \\spad{i}-th row is formed by the coordinates of \\spad{\\spad{ai}} with respect to the fixed \\spad{R}-module basis.") (((|Vector| |#1|) $) "\\spad{coordinates(a)} returns the coordinates of \\spad{a} with respect to the fixed \\spad{R}-module basis.")) (|basis| (((|Vector| $)) "\\spad{basis()} returns the fixed \\spad{R}-module basis."))) 
-((-4516 |has| |#1| (-558)) (-4514 . T) (-4513 . T)) 
+((-4518 |has| |#1| (-558)) (-4516 . T) (-4515 . T)) 
 NIL 
 (-420 R) 
 ((|constructor| (NIL "\\spadtype{Factored} creates a domain whose objects are kept in factored form as long as possible. Thus certain operations like multiplication and \\spad{gcd} are relatively easy to do. Others,{} like addition require somewhat more work,{} and unless the argument domain provides a factor function,{} the result may not be completely factored. Each object consists of a unit and a list of factors,{} where a factor has a member of \\spad{R} (the \"base\"),{} and exponent and a flag indicating what is known about the base. A flag may be one of \"nil\",{} \"sqfr\",{} \"irred\" or \"prime\",{} which respectively mean that nothing is known about the base,{} it is square-free,{} it is irreducible,{} or it is prime. The current restriction to integral domains allows simplification to be performed without worrying about multiplication order.")) (|rationalIfCan| (((|Union| (|Fraction| (|Integer|)) "failed") $) "\\spad{rationalIfCan(u)} returns a rational number if \\spad{u} really is one,{} and \"failed\" otherwise.")) (|rational| (((|Fraction| (|Integer|)) $) "\\spad{rational(u)} assumes spadvar{\\spad{u}} is actually a rational number and does the conversion to rational number (see \\spadtype{Fraction Integer}).")) (|rational?| (((|Boolean|) $) "\\spad{rational?(u)} tests if \\spadvar{\\spad{u}} is actually a rational number (see \\spadtype{Fraction Integer}).")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\indented{1}{map(\\spad{fn},{}\\spad{u}) maps the function \\userfun{\\spad{fn}} across the factors of} \\indented{1}{\\spadvar{\\spad{u}} and creates a new factored object. Note: this clears} \\indented{1}{the information flags (sets them to \"nil\") because the effect of} \\indented{1}{\\userfun{\\spad{fn}} is clearly not known in general.} \\blankline \\spad{X} \\spad{m}(a:Factored Polynomial Integer):Factored Polynomial Integer \\spad{==} \\spad{a^2} \\spad{X} \\spad{f:=x*y^3}-3*x^2*y^2+3*x^3*y-\\spad{x^4} \\spad{X} map(\\spad{m},{}\\spad{f}) \\spad{X} g:=makeFR(\\spad{z},{}factorList \\spad{f}) \\spad{X} map(\\spad{m},{}\\spad{g})")) (|unitNormalize| (($ $) "\\spad{unitNormalize(u)} normalizes the unit part of the factorization. For example,{} when working with factored integers,{} this operation will ensure that the bases are all positive integers.")) (|unit| ((|#1| $) "\\indented{1}{unit(\\spad{u}) extracts the unit part of the factorization.} \\blankline \\spad{X} \\spad{f:=x*y^3}-3*x^2*y^2+3*x^3*y-\\spad{x^4} \\spad{X} unit \\spad{f} \\spad{X} g:=makeFR(\\spad{z},{}factorList \\spad{f}) \\spad{X} unit \\spad{g}")) (|flagFactor| (($ |#1| (|Integer|) (|Union| "nil" "sqfr" "irred" "prime")) "\\spad{flagFactor(base,{}exponent,{}flag)} creates a factored object with a single factor whose \\spad{base} is asserted to be properly described by the information \\spad{flag}.")) (|sqfrFactor| (($ |#1| (|Integer|)) "\\indented{1}{sqfrFactor(base,{}exponent) creates a factored object with} \\indented{1}{a single factor whose base is asserted to be square-free} \\indented{1}{(flag = \"sqfr\").} \\blankline \\spad{X} a:=sqfrFactor(3,{}5) \\spad{X} nthFlag(a,{}1)")) (|primeFactor| (($ |#1| (|Integer|)) "\\indented{1}{primeFactor(base,{}exponent) creates a factored object with} \\indented{1}{a single factor whose base is asserted to be prime} \\indented{1}{(flag = \"prime\").} \\blankline \\spad{X} a:=primeFactor(3,{}4) \\spad{X} nthFlag(a,{}1)")) (|numberOfFactors| (((|NonNegativeInteger|) $) "\\indented{1}{numberOfFactors(\\spad{u}) returns the number of factors in \\spadvar{\\spad{u}}.} \\blankline \\spad{X} a:=factor 9720000 \\spad{X} numberOfFactors a")) (|nthFlag| (((|Union| "nil" "sqfr" "irred" "prime") $ (|Integer|)) "\\indented{1}{nthFlag(\\spad{u},{}\\spad{n}) returns the information flag of the \\spad{n}th factor of} \\indented{1}{\\spadvar{\\spad{u}}.\\space{2}If \\spadvar{\\spad{n}} is not a valid index for a factor} \\indented{1}{(for example,{} less than 1 or too big),{} \"nil\" is returned.} \\blankline \\spad{X} a:=factor 9720000 \\spad{X} nthFlag(a,{}2)")) (|nthFactor| ((|#1| $ (|Integer|)) "\\indented{1}{nthFactor(\\spad{u},{}\\spad{n}) returns the base of the \\spad{n}th factor of} \\indented{1}{\\spadvar{\\spad{u}}.\\space{2}If \\spadvar{\\spad{n}} is not a valid index for a factor} \\indented{1}{(for example,{} less than 1 or too big),{} 1 is returned.\\space{2}If} \\indented{1}{\\spadvar{\\spad{u}} consists only of a unit,{} the unit is returned.} \\blankline \\spad{X} a:=factor 9720000 \\spad{X} nthFactor(a,{}2)")) (|nthExponent| (((|Integer|) $ (|Integer|)) "\\indented{1}{nthExponent(\\spad{u},{}\\spad{n}) returns the exponent of the \\spad{n}th factor of} \\indented{1}{\\spadvar{\\spad{u}}.\\space{2}If \\spadvar{\\spad{n}} is not a valid index for a factor} \\indented{1}{(for example,{} less than 1 or too big),{} 0 is returned.} \\blankline \\spad{X} a:=factor 9720000 \\spad{X} nthExponent(a,{}2)")) (|irreducibleFactor| (($ |#1| (|Integer|)) "\\indented{1}{irreducibleFactor(base,{}exponent) creates a factored object with} \\indented{1}{a single factor whose base is asserted to be irreducible} \\indented{1}{(flag = \"irred\").} \\blankline \\spad{X} a:=irreducibleFactor(3,{}1) \\spad{X} nthFlag(a,{}1)")) (|factors| (((|List| (|Record| (|:| |factor| |#1|) (|:| |exponent| (|Integer|)))) $) "\\indented{1}{factors(\\spad{u}) returns a list of the factors in a form suitable} \\indented{1}{for iteration. That is,{} it returns a list where each element} \\indented{1}{is a record containing a base and exponent.\\space{2}The original} \\indented{1}{object is the product of all the factors and the unit (which} \\indented{1}{can be extracted by \\axiom{unit(\\spad{u})}).} \\blankline \\spad{X} \\spad{f:=x*y^3}-3*x^2*y^2+3*x^3*y-\\spad{x^4} \\spad{X} factors \\spad{f} \\spad{X} g:=makeFR(\\spad{z},{}factorList \\spad{f}) \\spad{X} factors \\spad{g}")) (|nilFactor| (($ |#1| (|Integer|)) "\\indented{1}{nilFactor(base,{}exponent) creates a factored object with} \\indented{1}{a single factor with no information about the kind of} \\indented{1}{base (flag = \"nil\").} \\blankline \\spad{X} nilFactor(24,{}2) \\spad{X} nilFactor(\\spad{x}-\\spad{y},{}3)")) (|factorList| (((|List| (|Record| (|:| |flg| (|Union| "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (|Integer|)))) $) "\\indented{1}{factorList(\\spad{u}) returns the list of factors with flags (for} \\indented{1}{use by factoring code).} \\blankline \\spad{X} f:=nilFactor(\\spad{x}-\\spad{y},{}3) \\spad{X} factorList \\spad{f}")) (|makeFR| (($ |#1| (|List| (|Record| (|:| |flg| (|Union| "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (|Integer|))))) "\\indented{1}{makeFR(unit,{}listOfFactors) creates a factored object (for} \\indented{1}{use by factoring code).} \\blankline \\spad{X} f:=nilFactor(\\spad{x}-\\spad{y},{}3) \\spad{X} g:=factorList \\spad{f} \\spad{X} makeFR(\\spad{z},{}\\spad{g})")) (|exponent| (((|Integer|) $) "\\indented{1}{exponent(\\spad{u}) returns the exponent of the first factor of} \\indented{1}{\\spadvar{\\spad{u}},{} or 0 if the factored form consists solely of a unit.} \\blankline \\spad{X} f:=nilFactor(\\spad{y}-\\spad{x},{}3) \\spad{X} exponent(\\spad{f})")) (|expand| ((|#1| $) "\\indented{1}{expand(\\spad{f}) multiplies the unit and factors together,{} yielding an} \\indented{1}{\"unfactored\" object. Note: this is purposely not called} \\indented{1}{\\spadfun{coerce} which would cause the interpreter to do this} \\indented{1}{automatically.} \\blankline \\spad{X} f:=nilFactor(\\spad{y}-\\spad{x},{}3) \\spad{X} expand(\\spad{f})"))) 
-((-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -523) (QUOTE (-1161)) (QUOTE $))) (|HasCategory| |#1| (LIST (QUOTE -303) (QUOTE $))) (|HasCategory| |#1| (LIST (QUOTE -281) (QUOTE $) (QUOTE $))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-1199))) (|HasCategory| |#1| (QUOTE (-1021))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -523) (QUOTE (-1161)) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -281) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-225))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-550))) (|HasCategory| |#1| (QUOTE (-453))) (-2198 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-1199))))) 
+((-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -523) (QUOTE (-1161)) (QUOTE $))) (|HasCategory| |#1| (LIST (QUOTE -303) (QUOTE $))) (|HasCategory| |#1| (LIST (QUOTE -281) (QUOTE $) (QUOTE $))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-1199))) (|HasCategory| |#1| (QUOTE (-1021))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -523) (QUOTE (-1161)) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -281) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-225))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-550))) (|HasCategory| |#1| (QUOTE (-453))) (-2199 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-1199))))) 
 (-421 R) 
 ((|constructor| (NIL "\\spadtype{FactoredFunctionUtilities} implements some utility functions for manipulating factored objects.")) (|mergeFactors| (((|Factored| |#1|) (|Factored| |#1|) (|Factored| |#1|)) "\\spad{mergeFactors(u,{}v)} is used when the factorizations of \\spadvar{\\spad{u}} and \\spadvar{\\spad{v}} are known to be disjoint,{} \\spadignore{e.g.} resulting from a content/primitive part split. Essentially,{} it creates a new factored object by multiplying the units together and appending the lists of factors.")) (|refine| (((|Factored| |#1|) (|Factored| |#1|) (|Mapping| (|Factored| |#1|) |#1|)) "\\spad{refine(u,{}fn)} is used to apply the function \\userfun{\\spad{fn}} to each factor of \\spadvar{\\spad{u}} and then build a new factored object from the results. For example,{} if \\spadvar{\\spad{u}} were created by calling \\spad{nilFactor(10,{}2)} then \\spad{refine(u,{}factor)} would create a factored object equal to that created by \\spad{factor(100)} or \\spad{primeFactor(2,{}2) * primeFactor(5,{}2)}."))) 
 NIL 
@@ -1638,7 +1638,7 @@ NIL
 ((|HasCategory| |#2| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-370)))) 
 (-427 S) 
 ((|constructor| (NIL "A finite-set aggregate models the notion of a finite set,{} that is,{} a collection of elements characterized by membership,{} but not by order or multiplicity. See \\spadtype{Set} for an example.")) (|min| ((|#1| $) "\\spad{min(u)} returns the smallest element of aggregate \\spad{u}.")) (|max| ((|#1| $) "\\spad{max(u)} returns the largest element of aggregate \\spad{u}.")) (|universe| (($) "\\spad{universe()}\\$\\spad{D} returns the universal set for finite set aggregate \\spad{D}.")) (|complement| (($ $) "\\spad{complement(u)} returns the complement of the set \\spad{u},{} \\spadignore{i.e.} the set of all values not in \\spad{u}.")) (|cardinality| (((|NonNegativeInteger|) $) "\\spad{cardinality(u)} returns the number of elements of \\spad{u}. Note that \\axiom{cardinality(\\spad{u}) = \\#u}."))) 
-((-4519 . T) (-4509 . T) (-4520 . T) (-3973 . T)) 
+((-4521 . T) (-4511 . T) (-4522 . T) (-3973 . T)) 
 NIL 
 (-428 R -1478) 
 ((|constructor| (NIL "Top-level complex function integration \\spadtype{FunctionSpaceComplexIntegration} provides functions for the indefinite integration of complex-valued functions.")) (|complexIntegrate| ((|#2| |#2| (|Symbol|)) "\\spad{complexIntegrate(f,{} x)} returns the integral of \\spad{f(x)dx} where \\spad{x} is viewed as a complex variable.")) (|internalIntegrate0| (((|IntegrationResult| |#2|) |#2| (|Symbol|)) "\\spad{internalIntegrate0 should} be a local function,{} but is conditional.")) (|internalIntegrate| (((|IntegrationResult| |#2|) |#2| (|Symbol|)) "\\spad{internalIntegrate(f,{} x)} returns the integral of \\spad{f(x)dx} where \\spad{x} is viewed as a complex variable."))) 
@@ -1646,8 +1646,8 @@ NIL
 NIL 
 (-429 R E) 
 ((|constructor| (NIL "This domain converts terms into Fourier series")) (|makeCos| (($ |#2| |#1|) "\\indented{1}{makeCos(\\spad{e},{}\\spad{r}) makes a sin expression with given} argument and coefficient")) (|makeSin| (($ |#2| |#1|) "\\spad{makeSin(e,{}r)} makes a sin expression with given argument and coefficient")) (|coerce| (($ (|FourierComponent| |#2|)) "\\spad{coerce(c)} converts sin/cos terms into Fourier Series") (($ |#1|) "\\spad{coerce(r)} converts coefficients into Fourier Series"))) 
-((-4506 -12 (|has| |#1| (-6 -4506)) (|has| |#2| (-6 -4506))) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((-12 (|HasAttribute| |#1| (QUOTE -4506)) (|HasAttribute| |#2| (QUOTE -4506)))) 
+((-4508 -12 (|has| |#1| (-6 -4508)) (|has| |#2| (-6 -4508))) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((-12 (|HasAttribute| |#1| (QUOTE -4508)) (|HasAttribute| |#2| (QUOTE -4508)))) 
 (-430 R -1478) 
 ((|constructor| (NIL "Top-level real function integration \\spadtype{FunctionSpaceIntegration} provides functions for the indefinite integration of real-valued functions.")) (|integrate| (((|Union| |#2| (|List| |#2|)) |#2| (|Symbol|)) "\\spad{integrate(f,{} x)} returns the integral of \\spad{f(x)dx} where \\spad{x} is viewed as a real variable."))) 
 NIL 
@@ -1658,7 +1658,7 @@ NIL
 ((|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (QUOTE (-1047))) (|HasCategory| |#2| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-478))) (|HasCategory| |#2| (QUOTE (-1102))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541))))) 
 (-432 R) 
 ((|constructor| (NIL "A space of formal functions with arguments in an arbitrary ordered set.")) (|univariate| (((|Fraction| (|SparseUnivariatePolynomial| $)) $ (|Kernel| $)) "\\spad{univariate(f,{} k)} returns \\spad{f} viewed as a univariate fraction in \\spad{k}.")) (/ (($ (|SparseMultivariatePolynomial| |#1| (|Kernel| $)) (|SparseMultivariatePolynomial| |#1| (|Kernel| $))) "\\spad{p1/p2} returns the quotient of \\spad{p1} and \\spad{p2} as an element of \\%.")) (|denominator| (($ $) "\\spad{denominator(f)} returns the denominator of \\spad{f} converted to \\%.")) (|denom| (((|SparseMultivariatePolynomial| |#1| (|Kernel| $)) $) "\\spad{denom(f)} returns the denominator of \\spad{f} viewed as a polynomial in the kernels over \\spad{R}.")) (|convert| (($ (|Factored| $)) "\\spad{convert(f1\\^e1 ... fm\\^em)} returns \\spad{(f1)\\^e1 ... (fm)\\^em} as an element of \\%,{} using formal kernels created using a \\spadfunFrom{paren}{ExpressionSpace}.")) (|isPower| (((|Union| (|Record| (|:| |val| $) (|:| |exponent| (|Integer|))) "failed") $) "\\spad{isPower(p)} returns \\spad{[x,{} n]} if \\spad{p = x**n} and \\spad{n <> 0}.")) (|numerator| (($ $) "\\spad{numerator(f)} returns the numerator of \\spad{f} converted to \\%.")) (|numer| (((|SparseMultivariatePolynomial| |#1| (|Kernel| $)) $) "\\spad{numer(f)} returns the numerator of \\spad{f} viewed as a polynomial in the kernels over \\spad{R} if \\spad{R} is an integral domain. If not,{} then numer(\\spad{f}) = \\spad{f} viewed as a polynomial in the kernels over \\spad{R}.")) (|coerce| (($ (|Fraction| (|Polynomial| (|Fraction| |#1|)))) "\\spad{coerce(f)} returns \\spad{f} as an element of \\%.") (($ (|Polynomial| (|Fraction| |#1|))) "\\spad{coerce(p)} returns \\spad{p} as an element of \\%.") (($ (|Fraction| |#1|)) "\\spad{coerce(q)} returns \\spad{q} as an element of \\%.") (($ (|SparseMultivariatePolynomial| |#1| (|Kernel| $))) "\\spad{coerce(p)} returns \\spad{p} as an element of \\%.")) (|isMult| (((|Union| (|Record| (|:| |coef| (|Integer|)) (|:| |var| (|Kernel| $))) "failed") $) "\\spad{isMult(p)} returns \\spad{[n,{} x]} if \\spad{p = n * x} and \\spad{n <> 0}.")) (|isPlus| (((|Union| (|List| $) "failed") $) "\\spad{isPlus(p)} returns \\spad{[m1,{}...,{}mn]} if \\spad{p = m1 +...+ mn} and \\spad{n > 1}.")) (|isExpt| (((|Union| (|Record| (|:| |var| (|Kernel| $)) (|:| |exponent| (|Integer|))) "failed") $ (|Symbol|)) "\\spad{isExpt(p,{}f)} returns \\spad{[x,{} n]} if \\spad{p = x**n} and \\spad{n <> 0} and \\spad{x = f(a)}.") (((|Union| (|Record| (|:| |var| (|Kernel| $)) (|:| |exponent| (|Integer|))) "failed") $ (|BasicOperator|)) "\\spad{isExpt(p,{}op)} returns \\spad{[x,{} n]} if \\spad{p = x**n} and \\spad{n <> 0} and \\spad{x = op(a)}.") (((|Union| (|Record| (|:| |var| (|Kernel| $)) (|:| |exponent| (|Integer|))) "failed") $) "\\spad{isExpt(p)} returns \\spad{[x,{} n]} if \\spad{p = x**n} and \\spad{n <> 0}.")) (|isTimes| (((|Union| (|List| $) "failed") $) "\\spad{isTimes(p)} returns \\spad{[a1,{}...,{}an]} if \\spad{p = a1*...*an} and \\spad{n > 1}.")) (** (($ $ (|NonNegativeInteger|)) "\\spad{x**n} returns \\spad{x} * \\spad{x} * \\spad{x} * ... * \\spad{x} (\\spad{n} times).")) (|eval| (($ $ (|Symbol|) (|NonNegativeInteger|) (|Mapping| $ $)) "\\spad{eval(x,{} s,{} n,{} f)} replaces every \\spad{s(a)**n} in \\spad{x} by \\spad{f(a)} for any \\spad{a}.") (($ $ (|Symbol|) (|NonNegativeInteger|) (|Mapping| $ (|List| $))) "\\spad{eval(x,{} s,{} n,{} f)} replaces every \\spad{s(a1,{}...,{}am)**n} in \\spad{x} by \\spad{f(a1,{}...,{}am)} for any \\spad{a1},{}...,{}am.") (($ $ (|List| (|Symbol|)) (|List| (|NonNegativeInteger|)) (|List| (|Mapping| $ (|List| $)))) "\\spad{eval(x,{} [s1,{}...,{}sm],{} [n1,{}...,{}nm],{} [f1,{}...,{}fm])} replaces every \\spad{\\spad{si}(a1,{}...,{}an)**ni} in \\spad{x} by \\spad{\\spad{fi}(a1,{}...,{}an)} for any \\spad{a1},{}...,{}am.") (($ $ (|List| (|Symbol|)) (|List| (|NonNegativeInteger|)) (|List| (|Mapping| $ $))) "\\spad{eval(x,{} [s1,{}...,{}sm],{} [n1,{}...,{}nm],{} [f1,{}...,{}fm])} replaces every \\spad{\\spad{si}(a)**ni} in \\spad{x} by \\spad{\\spad{fi}(a)} for any \\spad{a}.") (($ $ (|List| (|BasicOperator|)) (|List| $) (|Symbol|)) "\\spad{eval(x,{} [s1,{}...,{}sm],{} [f1,{}...,{}fm],{} y)} replaces every \\spad{\\spad{si}(a)} in \\spad{x} by \\spad{\\spad{fi}(y)} with \\spad{y} replaced by \\spad{a} for any \\spad{a}.") (($ $ (|BasicOperator|) $ (|Symbol|)) "\\spad{eval(x,{} s,{} f,{} y)} replaces every \\spad{s(a)} in \\spad{x} by \\spad{f(y)} with \\spad{y} replaced by \\spad{a} for any \\spad{a}.") (($ $) "\\spad{eval(f)} unquotes all the quoted operators in \\spad{f}.") (($ $ (|List| (|Symbol|))) "\\spad{eval(f,{} [foo1,{}...,{}foon])} unquotes all the \\spad{fooi}\\spad{'s} in \\spad{f}.") (($ $ (|Symbol|)) "\\spad{eval(f,{} foo)} unquotes all the foo\\spad{'s} in \\spad{f}.")) (|applyQuote| (($ (|Symbol|) (|List| $)) "\\spad{applyQuote(foo,{} [x1,{}...,{}xn])} returns \\spad{'foo(x1,{}...,{}xn)}.") (($ (|Symbol|) $ $ $ $) "\\spad{applyQuote(foo,{} x,{} y,{} z,{} t)} returns \\spad{'foo(x,{}y,{}z,{}t)}.") (($ (|Symbol|) $ $ $) "\\spad{applyQuote(foo,{} x,{} y,{} z)} returns \\spad{'foo(x,{}y,{}z)}.") (($ (|Symbol|) $ $) "\\spad{applyQuote(foo,{} x,{} y)} returns \\spad{'foo(x,{}y)}.") (($ (|Symbol|) $) "\\spad{applyQuote(foo,{} x)} returns \\spad{'foo(x)}.")) (|variables| (((|List| (|Symbol|)) $) "\\spad{variables(f)} returns the list of all the variables of \\spad{f}.")) (|ground| ((|#1| $) "\\spad{ground(f)} returns \\spad{f} as an element of \\spad{R}. An error occurs if \\spad{f} is not an element of \\spad{R}.")) (|ground?| (((|Boolean|) $) "\\spad{ground?(f)} tests if \\spad{f} is an element of \\spad{R}."))) 
-((-4516 -2198 (|has| |#1| (-1047)) (|has| |#1| (-478))) (-4514 |has| |#1| (-172)) (-4513 |has| |#1| (-172)) ((-4521 "*") |has| |#1| (-558)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-558)) (-4511 |has| |#1| (-558)) (-3973 . T)) 
+((-4518 -2199 (|has| |#1| (-1047)) (|has| |#1| (-478))) (-4516 |has| |#1| (-172)) (-4515 |has| |#1| (-172)) ((-4523 "*") |has| |#1| (-558)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-558)) (-4513 |has| |#1| (-558)) (-3973 . T)) 
 NIL 
 (-433 R -1478) 
 ((|constructor| (NIL "Provides some special functions over an integral domain.")) (|iiAiryBi| ((|#2| |#2|) "\\spad{iiAiryBi(x)} should be local but conditional.")) (|iiAiryAi| ((|#2| |#2|) "\\spad{iiAiryAi(x)} should be local but conditional.")) (|iiBesselK| ((|#2| (|List| |#2|)) "\\spad{iiBesselK(x)} should be local but conditional.")) (|iiBesselI| ((|#2| (|List| |#2|)) "\\spad{iiBesselI(x)} should be local but conditional.")) (|iiBesselY| ((|#2| (|List| |#2|)) "\\spad{iiBesselY(x)} should be local but conditional.")) (|iiBesselJ| ((|#2| (|List| |#2|)) "\\spad{iiBesselJ(x)} should be local but conditional.")) (|iipolygamma| ((|#2| (|List| |#2|)) "\\spad{iipolygamma(x)} should be local but conditional.")) (|iidigamma| ((|#2| |#2|) "\\spad{iidigamma(x)} should be local but conditional.")) (|iiBeta| ((|#2| (|List| |#2|)) "iiGamma(\\spad{x}) should be local but conditional.")) (|iiabs| ((|#2| |#2|) "\\spad{iiabs(x)} should be local but conditional.")) (|iiGamma| ((|#2| |#2|) "\\spad{iiGamma(x)} should be local but conditional.")) (|airyBi| ((|#2| |#2|) "\\spad{airyBi(x)} returns the airybi function applied to \\spad{x}")) (|airyAi| ((|#2| |#2|) "\\spad{airyAi(x)} returns the airyai function applied to \\spad{x}")) (|besselK| ((|#2| |#2| |#2|) "\\spad{besselK(x,{}y)} returns the besselk function applied to \\spad{x} and \\spad{y}")) (|besselI| ((|#2| |#2| |#2|) "\\spad{besselI(x,{}y)} returns the besseli function applied to \\spad{x} and \\spad{y}")) (|besselY| ((|#2| |#2| |#2|) "\\spad{besselY(x,{}y)} returns the bessely function applied to \\spad{x} and \\spad{y}")) (|besselJ| ((|#2| |#2| |#2|) "\\spad{besselJ(x,{}y)} returns the besselj function applied to \\spad{x} and \\spad{y}")) (|polygamma| ((|#2| |#2| |#2|) "\\spad{polygamma(x,{}y)} returns the polygamma function applied to \\spad{x} and \\spad{y}")) (|digamma| ((|#2| |#2|) "\\spad{digamma(x)} returns the digamma function applied to \\spad{x}")) (|Beta| ((|#2| |#2| |#2|) "\\spad{Beta(x,{}y)} returns the beta function applied to \\spad{x} and \\spad{y}")) (|Gamma| ((|#2| |#2| |#2|) "\\spad{Gamma(a,{}x)} returns the incomplete Gamma function applied to a and \\spad{x}") ((|#2| |#2|) "\\spad{Gamma(f)} returns the formal Gamma function applied to \\spad{f}")) (|abs| ((|#2| |#2|) "\\spad{abs(f)} returns the absolute value operator applied to \\spad{f}")) (|operator| (((|BasicOperator|) (|BasicOperator|)) "\\spad{operator(op)} returns a copy of \\spad{op} with the domain-dependent properties appropriate for \\spad{F}; error if \\spad{op} is not a special function operator")) (|belong?| (((|Boolean|) (|BasicOperator|)) "\\spad{belong?(op)} is \\spad{true} if \\spad{op} is a special function operator."))) 
@@ -1742,16 +1742,16 @@ NIL
 NIL 
 (-453) 
 ((|constructor| (NIL "This category describes domains where \\spadfun{\\spad{gcd}} can be computed but where there is no guarantee of the existence of \\spadfun{factor} operation for factorisation into irreducibles. However,{} if such a \\spadfun{factor} operation exist,{} factorization will be unique up to order and units.")) (|gcdPolynomial| (((|SparseUnivariatePolynomial| $) (|SparseUnivariatePolynomial| $) (|SparseUnivariatePolynomial| $)) "\\spad{gcdPolynomial(p,{}q)} returns the greatest common divisor (\\spad{gcd}) of univariate polynomials over the domain")) (|lcm| (($ (|List| $)) "\\spad{lcm(l)} returns the least common multiple of the elements of the list \\spad{l}.") (($ $ $) "\\spad{lcm(x,{}y)} returns the least common multiple of \\spad{x} and \\spad{y}.")) (|gcd| (($ (|List| $)) "\\spad{gcd(l)} returns the common \\spad{gcd} of the elements in the list \\spad{l}.") (($ $ $) "\\spad{gcd(x,{}y)} returns the greatest common divisor of \\spad{x} and \\spad{y}."))) 
-((-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-454 R |n| |ls| |gamma|) 
 ((|constructor| (NIL "AlgebraGenericElementPackage allows you to create generic elements of an algebra,{} \\spadignore{i.e.} the scalars are extended to include symbolic coefficients")) (|conditionsForIdempotents| (((|List| (|Polynomial| |#1|))) "\\spad{conditionsForIdempotents()} determines a complete list of polynomial equations for the coefficients of idempotents with respect to the fixed \\spad{R}-module basis") (((|List| (|Polynomial| |#1|)) (|Vector| $)) "\\spad{conditionsForIdempotents([v1,{}...,{}vn])} determines a complete list of polynomial equations for the coefficients of idempotents with respect to the \\spad{R}-module basis \\spad{v1},{}...,{}\\spad{vn}")) (|genericRightDiscriminant| (((|Fraction| (|Polynomial| |#1|))) "\\spad{genericRightDiscriminant()} is the determinant of the generic left trace forms of all products of basis element,{} if the generic left trace form is associative,{} an algebra is separable if the generic left discriminant is invertible,{} if it is non-zero,{} there is some ring extension which makes the algebra separable")) (|genericRightTraceForm| (((|Fraction| (|Polynomial| |#1|)) $ $) "\\spad{genericRightTraceForm (a,{}b)} is defined to be \\spadfun{genericRightTrace (a*b)},{} this defines a symmetric bilinear form on the algebra")) (|genericLeftDiscriminant| (((|Fraction| (|Polynomial| |#1|))) "\\spad{genericLeftDiscriminant()} is the determinant of the generic left trace forms of all products of basis element,{} if the generic left trace form is associative,{} an algebra is separable if the generic left discriminant is invertible,{} if it is non-zero,{} there is some ring extension which makes the algebra separable")) (|genericLeftTraceForm| (((|Fraction| (|Polynomial| |#1|)) $ $) "\\spad{genericLeftTraceForm (a,{}b)} is defined to be \\spad{genericLeftTrace (a*b)},{} this defines a symmetric bilinear form on the algebra")) (|genericRightNorm| (((|Fraction| (|Polynomial| |#1|)) $) "\\spad{genericRightNorm(a)} substitutes the coefficients of \\spad{a} for the generic coefficients into the coefficient of the constant term in \\spadfun{rightRankPolynomial} and changes the sign if the degree of this polynomial is odd")) (|genericRightTrace| (((|Fraction| (|Polynomial| |#1|)) $) "\\spad{genericRightTrace(a)} substitutes the coefficients of \\spad{a} for the generic coefficients into the coefficient of the second highest term in \\spadfun{rightRankPolynomial} and changes the sign")) (|genericRightMinimalPolynomial| (((|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| |#1|))) $) "\\spad{genericRightMinimalPolynomial(a)} substitutes the coefficients of \\spad{a} for the generic coefficients in \\spadfun{rightRankPolynomial}")) (|rightRankPolynomial| (((|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| |#1|)))) "\\spad{rightRankPolynomial()} returns the right minimimal polynomial of the generic element")) (|genericLeftNorm| (((|Fraction| (|Polynomial| |#1|)) $) "\\spad{genericLeftNorm(a)} substitutes the coefficients of \\spad{a} for the generic coefficients into the coefficient of the constant term in \\spadfun{leftRankPolynomial} and changes the sign if the degree of this polynomial is odd. This is a form of degree \\spad{k}")) (|genericLeftTrace| (((|Fraction| (|Polynomial| |#1|)) $) "\\spad{genericLeftTrace(a)} substitutes the coefficients of \\spad{a} for the generic coefficients into the coefficient of the second highest term in \\spadfun{leftRankPolynomial} and changes the sign. \\indented{1}{This is a linear form}")) (|genericLeftMinimalPolynomial| (((|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| |#1|))) $) "\\spad{genericLeftMinimalPolynomial(a)} substitutes the coefficients of {em a} for the generic coefficients in \\spad{leftRankPolynomial()}")) (|leftRankPolynomial| (((|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| |#1|)))) "\\spad{leftRankPolynomial()} returns the left minimimal polynomial of the generic element")) (|generic| (($ (|Vector| (|Symbol|)) (|Vector| $)) "\\spad{generic(vs,{}ve)} returns a generic element,{} \\spadignore{i.e.} the linear combination of \\spad{ve} with the symbolic coefficients \\spad{vs} error,{} if the vector of symbols is shorter than the vector of elements") (($ (|Symbol|) (|Vector| $)) "\\spad{generic(s,{}v)} returns a generic element,{} \\spadignore{i.e.} the linear combination of \\spad{v} with the symbolic coefficients \\spad{s1,{}s2,{}..}") (($ (|Vector| $)) "\\spad{generic(ve)} returns a generic element,{} \\spadignore{i.e.} the linear combination of \\spad{ve} basis with the symbolic coefficients \\spad{\\%x1,{}\\%x2,{}..}") (($ (|Vector| (|Symbol|))) "\\spad{generic(vs)} returns a generic element,{} \\spadignore{i.e.} the linear combination of the fixed basis with the symbolic coefficients \\spad{vs}; error,{} if the vector of symbols is too short") (($ (|Symbol|)) "\\spad{generic(s)} returns a generic element,{} \\spadignore{i.e.} the linear combination of the fixed basis with the symbolic coefficients \\spad{s1,{}s2,{}..}") (($) "\\spad{generic()} returns a generic element,{} \\spadignore{i.e.} the linear combination of the fixed basis with the symbolic coefficients \\spad{\\%x1,{}\\%x2,{}..}")) (|rightUnits| (((|Union| (|Record| (|:| |particular| $) (|:| |basis| (|List| $))) "failed")) "\\spad{rightUnits()} returns the affine space of all right units of the algebra,{} or \\spad{\"failed\"} if there is none")) (|leftUnits| (((|Union| (|Record| (|:| |particular| $) (|:| |basis| (|List| $))) "failed")) "\\spad{leftUnits()} returns the affine space of all left units of the algebra,{} or \\spad{\"failed\"} if there is none")) (|coerce| (($ (|Vector| (|Fraction| (|Polynomial| |#1|)))) "\\spad{coerce(v)} assumes that it is called with a vector of length equal to the dimension of the algebra,{} then a linear combination with the basis element is formed"))) 
-((-4516 |has| (-409 (-953 |#1|)) (-558)) (-4514 . T) (-4513 . T)) 
+((-4518 |has| (-409 (-953 |#1|)) (-558)) (-4516 . T) (-4515 . T)) 
 ((|HasCategory| (-409 (-953 |#1|)) (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| (-409 (-953 |#1|)) (QUOTE (-558)))) 
 (-455 |vl| R E) 
 ((|constructor| (NIL "This type supports distributed multivariate polynomials whose variables are from a user specified list of symbols. The coefficient ring may be non commutative,{} but the variables are assumed to commute. The term ordering is specified by its third parameter. Suggested types which define term orderings include: \\spadtype{DirectProduct},{} \\spadtype{HomogeneousDirectProduct},{} \\spadtype{SplitHomogeneousDirectProduct} and finally \\spadtype{OrderedDirectProduct} which accepts an arbitrary user function to define a term ordering.")) (|reorder| (($ $ (|List| (|Integer|))) "\\spad{reorder(p,{} perm)} applies the permutation perm to the variables in a polynomial and returns the new correctly ordered polynomial"))) 
-(((-4521 "*") |has| |#2| (-172)) (-4512 |has| |#2| (-558)) (-4517 |has| |#2| (-6 -4517)) (-4514 . T) (-4513 . T) (-4516 . T)) 
-((|HasCategory| |#2| (QUOTE (-904))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-172))) (-2198 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-558)))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#2| (QUOTE (-842))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-365))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#2| (QUOTE -4517)) (|HasCategory| |#2| (QUOTE (-453))) (-2198 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2198 (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2198 (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (|HasCategory| |#2| (QUOTE (-148))))) 
+(((-4523 "*") |has| |#2| (-172)) (-4514 |has| |#2| (-558)) (-4519 |has| |#2| (-6 -4519)) (-4516 . T) (-4515 . T) (-4518 . T)) 
+((|HasCategory| |#2| (QUOTE (-904))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-172))) (-2199 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-558)))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#2| (QUOTE (-842))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-365))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#2| (QUOTE -4519)) (|HasCategory| |#2| (QUOTE (-453))) (-2199 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2199 (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2199 (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (|HasCategory| |#2| (QUOTE (-148))))) 
 (-456) 
 ((|constructor| (NIL "This package provides support for gnuplot. These routines generate output files contain gnuplot scripts that may be processed directly by gnuplot. This is especially convenient in the axiom-wiki environment where gnuplot is called from LaTeX via gnuplottex.")) (|gnuDraw| (((|Void|) (|Expression| (|Float|)) (|SegmentBinding| (|Float|)) (|SegmentBinding| (|Float|)) (|String|)) "\\indented{1}{\\spad{gnuDraw} provides 3d surface plotting,{} default options} \\blankline \\spad{X} gnuDraw(sin(\\spad{x})*cos(\\spad{y}),{}\\spad{x=}-6..4,{}\\spad{y=}-4..6,{}\"out3d.dat\") \\spad{X} )\\spad{sys} gnuplot -persist out3d.dat") (((|Void|) (|Expression| (|Float|)) (|SegmentBinding| (|Float|)) (|SegmentBinding| (|Float|)) (|String|) (|List| (|DrawOption|))) "\\indented{1}{\\spad{gnuDraw} provides 3d surface plotting with options} \\blankline \\spad{X} gnuDraw(sin(\\spad{x})*cos(\\spad{y}),{}\\spad{x=}-6..4,{}\\spad{y=}-4..6,{}\"out3d.dat\",{}title==\"out3d\") \\spad{X} )\\spad{sys} gnuplot -persist out3d.dat") (((|Void|) (|Expression| (|Float|)) (|SegmentBinding| (|Float|)) (|String|)) "\\indented{1}{\\spad{gnuDraw} provides 2d plotting,{} default options} \\blankline \\spad{X} gnuDraw(\\spad{D}(cos(exp(\\spad{z}))/exp(\\spad{z^2}),{}\\spad{z}),{}\\spad{z=}-5..5,{}\"out2d.dat\") \\spad{X} )\\spad{sys} gnuplot -persist out2d.dat") (((|Void|) (|Expression| (|Float|)) (|SegmentBinding| (|Float|)) (|String|) (|List| (|DrawOption|))) "\\indented{1}{\\spad{gnuDraw} provides 2d plotting with options} \\blankline \\spad{X} gnuDraw(\\spad{D}(cos(exp(\\spad{z}))/exp(\\spad{z^2}),{}\\spad{z}),{}\\spad{z=}-5..5,{}\"out2d.dat\",{}title==\"out2d\") \\spad{X} )\\spad{sys} gnuplot -persist out2d.dat"))) 
 NIL 
@@ -1782,7 +1782,7 @@ NIL
 NIL 
 (-463 |vl| R IS E |ff| P) 
 ((|constructor| (NIL "This package is undocumented")) (* (($ |#6| $) "\\spad{p*x} is not documented")) (|multMonom| (($ |#2| |#4| $) "\\spad{multMonom(r,{}e,{}x)} is not documented")) (|build| (($ |#2| |#3| |#4|) "\\spad{build(r,{}i,{}e)} is not documented")) (|unitVector| (($ |#3|) "\\spad{unitVector(x)} is not documented")) (|monomial| (($ |#2| (|ModuleMonomial| |#3| |#4| |#5|)) "\\spad{monomial(r,{}x)} is not documented")) (|reductum| (($ $) "\\spad{reductum(x)} is not documented")) (|leadingIndex| ((|#3| $) "\\spad{leadingIndex(x)} is not documented")) (|leadingExponent| ((|#4| $) "\\spad{leadingExponent(x)} is not documented")) (|leadingMonomial| (((|ModuleMonomial| |#3| |#4| |#5|) $) "\\spad{leadingMonomial(x)} is not documented")) (|leadingCoefficient| ((|#2| $) "\\spad{leadingCoefficient(x)} is not documented"))) 
-((-4514 . T) (-4513 . T)) 
+((-4516 . T) (-4515 . T)) 
 NIL 
 (-464) 
 ((|constructor| (NIL "\\spad{GuessOptionFunctions0} provides operations that extract the values of options for \\spadtype{Guess}.")) (|debug| (((|Boolean|) (|List| (|GuessOption|))) "\\spad{debug returns} whether we want additional output on the progress,{} default being \\spad{false}")) (|displayAsGF| (((|Boolean|) (|List| (|GuessOption|))) "\\spad{displayAsGF specifies} whether the result is a generating function or a recurrence. This option should not be set by the user,{} but rather by the \\spad{HP}-specification,{} therefore,{} there is no default.")) (|indexName| (((|Symbol|) (|List| (|GuessOption|))) "\\spad{indexName returns} the name of the index variable used for the formulas,{} default being \\spad{n}")) (|variableName| (((|Symbol|) (|List| (|GuessOption|))) "\\spad{variableName returns} the name of the variable used in by the algebraic differential equation,{} default being \\spad{x}")) (|functionName| (((|Symbol|) (|List| (|GuessOption|))) "\\spad{functionName returns} the name of the function given by the algebraic differential equation,{} default being \\spad{f}")) (|homogeneous| (((|Boolean|) (|List| (|GuessOption|))) "\\spad{homogeneous returns} whether we allow only homogeneous algebraic differential equations,{} default being \\spad{false}")) (|one| (((|Boolean|) (|List| (|GuessOption|))) "\\spad{one returns} whether we need only one solution,{} default being \\spad{true}.")) (|safety| (((|NonNegativeInteger|) (|List| (|GuessOption|))) "\\spad{safety returns} the specified safety or 1 as default.")) (|allDegrees| (((|Boolean|) (|List| (|GuessOption|))) "\\spad{allDegrees returns} whether all possibilities of the degree vector should be tried,{} the default being \\spad{false}.")) (|maxDegree| (((|Integer|) (|List| (|GuessOption|))) "\\spad{maxDegree returns} the specified maxDegree or \\spad{-1} as default.")) (|maxShift| (((|Integer|) (|List| (|GuessOption|))) "\\spad{maxShift returns} the specified maxShift or \\spad{-1} as default.")) (|maxDerivative| (((|Integer|) (|List| (|GuessOption|))) "\\spad{maxDerivative returns} the specified maxDerivative or \\spad{-1} as default.")) (|maxPower| (((|Integer|) (|List| (|GuessOption|))) "\\spad{maxPower returns} the specified maxPower or \\spad{-1} as default.")) (|maxLevel| (((|Integer|) (|List| (|GuessOption|))) "\\spad{maxLevel returns} the specified maxLevel or \\spad{-1} as default."))) 
@@ -1802,7 +1802,7 @@ NIL
 ((|HasCategory| |#1| (QUOTE (-370)))) 
 (-468 R E |VarSet| P) 
 ((|constructor| (NIL "A domain for polynomial sets.")) (|convert| (($ (|List| |#4|)) "\\axiom{convert(\\spad{lp})} returns the polynomial set whose members are the polynomials of \\axiom{\\spad{lp}}."))) 
-((-4520 . T) (-4519 . T)) 
+((-4522 . T) (-4521 . T)) 
 ((|HasCategory| |#4| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#4| (QUOTE (-1090))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-558)))) 
 (-469 S R E) 
 ((|constructor| (NIL "GradedAlgebra(\\spad{R},{}\\spad{E}) denotes ``E-graded \\spad{R}-algebra\\spad{''}. A graded algebra is a graded module together with a degree preserving \\spad{R}-linear map,{} called the product. \\blankline The name ``product\\spad{''} is written out in full so inner and outer products with the same mapping type can be distinguished by name.")) (|product| (($ $ $) "\\spad{product(a,{}b)} is the degree-preserving \\spad{R}-linear product: \\blankline \\indented{2}{\\spad{degree product(a,{}b) = degree a + degree b}} \\indented{2}{\\spad{product(a1+a2,{}b) = product(a1,{}b) + product(a2,{}b)}} \\indented{2}{\\spad{product(a,{}b1+b2) = product(a,{}b1) + product(a,{}b2)}} \\indented{2}{\\spad{product(r*a,{}b) = product(a,{}r*b) = r*product(a,{}b)}} \\indented{2}{\\spad{product(a,{}product(b,{}c)) = product(product(a,{}b),{}c)}}")) ((|One|) (($) "1 is the identity for \\spad{product}."))) 
@@ -1842,19 +1842,19 @@ NIL
 NIL 
 (-478) 
 ((|constructor| (NIL "The class of multiplicative groups,{} \\spadignore{i.e.} monoids with multiplicative inverses. \\blankline Axioms\\spad{\\br} \\tab{5}\\spad{leftInverse(\"*\":(\\%,{}\\%)->\\%,{}inv)}\\tab{5}\\spad{ inv(x)*x = 1 }\\spad{\\br} \\tab{5}\\spad{rightInverse(\"*\":(\\%,{}\\%)->\\%,{}inv)}\\tab{4}\\spad{ x*inv(x) = 1 }")) (|commutator| (($ $ $) "\\spad{commutator(p,{}q)} computes \\spad{inv(p) * inv(q) * p * q}.")) (|conjugate| (($ $ $) "\\spad{conjugate(p,{}q)} computes \\spad{inv(q) * p * q}; this is 'right action by conjugation'.")) (|unitsKnown| ((|attribute|) "unitsKnown asserts that recip only returns \"failed\" for non-units.")) (^ (($ $ (|Integer|)) "\\spad{x^n} returns \\spad{x} raised to the integer power \\spad{n}.")) (** (($ $ (|Integer|)) "\\spad{x**n} returns \\spad{x} raised to the integer power \\spad{n}.")) (/ (($ $ $) "\\spad{x/y} is the same as \\spad{x} times the inverse of \\spad{y}.")) (|inv| (($ $) "\\spad{inv(x)} returns the inverse of \\spad{x}."))) 
-((-4516 . T)) 
+((-4518 . T)) 
 NIL 
 (-479 |Coef| |var| |cen|) 
 ((|constructor| (NIL "This is a category of univariate Puiseux series constructed from univariate Laurent series. A Puiseux series is represented by a pair \\spad{[r,{}f(x)]},{} where \\spad{r} is a positive rational number and \\spad{f(x)} is a Laurent series. This pair represents the Puiseux series \\spad{f(x\\^r)}.")) (|integrate| (($ $ (|Variable| |#2|)) "\\spad{integrate(f(x))} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 0. We may integrate a series when we can divide coefficients by integers.")) (|differentiate| (($ $ (|Variable| |#2|)) "\\spad{differentiate(f(x),{}x)} returns the derivative of \\spad{f(x)} with respect to \\spad{x}.")) (|coerce| (($ (|UnivariatePuiseuxSeries| |#1| |#2| |#3|)) "\\spad{coerce(f)} converts a Puiseux series to a general power series.") (($ (|Variable| |#2|)) "\\spad{coerce(var)} converts the series variable \\spad{var} into a Puiseux series."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-365)) (-4511 |has| |#1| (-365)) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568))) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568))) (|devaluate| |#1|))))) (|HasCategory| (-409 (-568)) (QUOTE (-1102))) (|HasCategory| |#1| (QUOTE (-365))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (-2198 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasSignature| |#1| (LIST (QUOTE -2745) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -3837) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2055) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|))))))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-365)) (-4513 |has| |#1| (-365)) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568))) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568))) (|devaluate| |#1|))))) (|HasCategory| (-409 (-568)) (QUOTE (-1102))) (|HasCategory| |#1| (QUOTE (-365))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (-2199 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasSignature| |#1| (LIST (QUOTE -2747) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -1845) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2057) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|))))))) 
 (-480 |Key| |Entry| |Tbl| |dent|) 
 ((|constructor| (NIL "A sparse table has a default entry,{} which is returned if no other value has been explicitly stored for a key."))) 
-((-4520 . T)) 
-((|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-1090))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))) (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3649) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4083) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090)))) (-2198 (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-1090))))) 
+((-4522 . T)) 
+((|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-1090))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))) (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3651) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4085) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090)))) (-2199 (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-1090))))) 
 (-481 R E V P) 
 ((|constructor| (NIL "A domain constructor of the category \\axiomType{TriangularSetCategory}. The only requirement for a list of polynomials to be a member of such a domain is the following: no polynomial is constant and two distinct polynomials have distinct main variables. Such a triangular set may not be auto-reduced or consistent. Triangular sets are stored as sorted lists \\spad{w}.\\spad{r}.\\spad{t}. the main variables of their members but they are displayed in reverse order."))) 
-((-4520 . T) (-4519 . T)) 
+((-4522 . T) (-4521 . T)) 
 ((|HasCategory| |#4| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#4| (QUOTE (-1090))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#3| (QUOTE (-370)))) 
 (-482) 
 ((|constructor| (NIL "This package exports guessing of sequences of rational functions"))) 
@@ -1872,7 +1872,7 @@ NIL
 ((|constructor| (NIL "This package exports guessing of sequences of rational numbers"))) 
 NIL 
 ((-12 (|HasCategory| (-409 (-568)) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| (-568) (LIST (QUOTE -1037) (QUOTE (-1161)))))) 
-(-486 -1478 S EXPRR R -2854 -2745) 
+(-486 -1478 S EXPRR R -2857 -2747) 
 ((|constructor| (NIL "This package implements guessing of sequences. Packages for the most common cases are provided as \\spadtype{GuessInteger},{} \\spadtype{GuessPolynomial},{} etc.")) (|shiftHP| (((|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| |#1|)) (|UnivariateFormalPowerSeries| |#1|))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|)))) (|:| |exprStream| (|Mapping| (|Stream| |#3|) |#3| (|Symbol|))) (|:| A (|Mapping| |#2| (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| |#2|))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| |#1|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|)))) (|:| AX (|Mapping| |#3| (|NonNegativeInteger|) (|Symbol|) |#3|)) (|:| C (|Mapping| (|List| |#2|) (|NonNegativeInteger|)))) (|List| (|GuessOption|))) (|Symbol|)) "\\spad{shiftHP options} returns a specification for Hermite-Pade approximation with the \\$\\spad{q}\\$-shift operator") (((|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| |#1|)) (|UnivariateFormalPowerSeries| |#1|))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|)))) (|:| |exprStream| (|Mapping| (|Stream| |#3|) |#3| (|Symbol|))) (|:| A (|Mapping| |#2| (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| |#2|))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| |#1|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|)))) (|:| AX (|Mapping| |#3| (|NonNegativeInteger|) (|Symbol|) |#3|)) (|:| C (|Mapping| (|List| |#2|) (|NonNegativeInteger|)))) (|List| (|GuessOption|))) "\\spad{shiftHP options} returns a specification for Hermite-Pade approximation with the shift operator")) (|diffHP| (((|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| |#1|)) (|UnivariateFormalPowerSeries| |#1|))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|)))) (|:| |exprStream| (|Mapping| (|Stream| |#3|) |#3| (|Symbol|))) (|:| A (|Mapping| |#2| (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| |#2|))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| |#1|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|)))) (|:| AX (|Mapping| |#3| (|NonNegativeInteger|) (|Symbol|) |#3|)) (|:| C (|Mapping| (|List| |#2|) (|NonNegativeInteger|)))) (|List| (|GuessOption|))) (|Symbol|)) "\\spad{diffHP options} returns a specification for Hermite-Pade approximation with the \\$\\spad{q}\\$-dilation operator") (((|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| |#1|)) (|UnivariateFormalPowerSeries| |#1|))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|)))) (|:| |exprStream| (|Mapping| (|Stream| |#3|) |#3| (|Symbol|))) (|:| A (|Mapping| |#2| (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| |#2|))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| |#1|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|)))) (|:| AX (|Mapping| |#3| (|NonNegativeInteger|) (|Symbol|) |#3|)) (|:| C (|Mapping| (|List| |#2|) (|NonNegativeInteger|)))) (|List| (|GuessOption|))) "\\spad{diffHP options} returns a specification for Hermite-Pade approximation with the differential operator")) (|guessRat| (((|Mapping| (|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) (|Symbol|)) "\\spad{guessRat q} returns a guesser that tries to find a \\spad{q}-rational function whose first values are given by \\spad{l},{} using the given options. It is equivalent to \\spadfun{guessRec} with \\spad{(l,{} maxShift == 0,{} maxPower == 1,{} allDegrees == true)}.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|)) "\\spad{guessRat l} tries to find a rational function whose first values are given by \\spad{l},{} using the default options described in \\spadtype{GuessOptionFunctions0}. It is equivalent to \\spadfun{guessRec}\\spad{(l,{} maxShift == 0,{} maxPower == 1,{} allDegrees == true)}.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) "\\spad{guessRat(l,{} options)} tries to find a rational function whose first values are given by \\spad{l},{} using the given options. It is equivalent to \\spadfun{guessRec}\\spad{(l,{} maxShift == 0,{} maxPower == 1,{} allDegrees == true)}.")) (|guessPRec| (((|Mapping| (|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) (|Symbol|)) "\\spad{guessPRec q} returns a guesser that tries to find a linear \\spad{q}-recurrence with polynomial coefficients whose first values are given by \\spad{l},{} using the given options. It is equivalent to \\spadfun{guessRec}\\spad{(q)} with \\spad{maxPower == 1}.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|)) "\\spad{guessPRec l} tries to find a linear recurrence with polynomial coefficients whose first values are given by \\spad{l},{} using the default options described in \\spadtype{GuessOptionFunctions0}. It is equivalent to \\spadfun{guessRec}\\spad{(l,{} maxPower == 1)}.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) "\\spad{guessPRec(l,{} options)} tries to find a linear recurrence with polynomial coefficients whose first values are given by \\spad{l},{} using the given options. It is equivalent to \\spadfun{guessRec}\\spad{(l,{} options)} with \\spad{maxPower == 1}.")) (|guessRec| (((|Mapping| (|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) (|Symbol|)) "\\spad{guessRec q} returns a guesser that finds an ordinary \\spad{q}-difference equation whose first values are given by \\spad{l},{} using the given options.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) "\\spad{guessRec(l,{} options)} tries to find an ordinary difference equation whose first values are given by \\spad{l},{} using the given options.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|)) "\\spad{guessRec l} tries to find an ordinary difference equation whose first values are given by \\spad{l},{} using the default options described in \\spadtype{GuessOptionFunctions0}.")) (|guessPade| (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|)) "\\spad{guessPade(l,{} options)} tries to find a rational function whose first Taylor coefficients are given by \\spad{l},{} using the default options described in \\spadtype{GuessOptionFunctions0}. It is equivalent to \\spadfun{guessADE}\\spad{(l,{} options)} with \\spad{maxDerivative == 0,{} maxPower == 1,{} allDegrees == true}.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) "\\spad{guessPade(l,{} options)} tries to find a rational function whose first Taylor coefficients are given by \\spad{l},{} using the given options. It is equivalent to \\spadfun{guessADE}\\spad{(l,{} maxDerivative == 0,{} maxPower == 1,{} allDegrees == true)}.")) (|guessHolo| (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) "\\spad{guessHolo(l,{} options)} tries to find an ordinary linear differential equation for a generating function whose first Taylor coefficients are given by \\spad{l},{} using the given options. It is equivalent to \\spadfun{guessADE}\\spad{(l,{} options)} with \\spad{maxPower == 1}.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|)) "\\spad{guessHolo l} tries to find an ordinary linear differential equation for a generating function whose first Taylor coefficients are given by \\spad{l},{} using the default options described in \\spadtype{GuessOptionFunctions0}. It is equivalent to \\spadfun{guessADE}\\spad{(l,{} maxPower == 1)}.")) (|guessAlg| (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) "\\spad{guessAlg(l,{} options)} tries to find an algebraic equation for a generating function whose first Taylor coefficients are given by \\spad{l},{} using the given options. It is equivalent to \\spadfun{guessADE}(\\spad{l},{} options) with \\spad{maxDerivative == 0}.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|)) "\\spad{guessAlg l} tries to find an algebraic equation for a generating function whose first Taylor coefficients are given by \\spad{l},{} using the default options described in \\spadtype{GuessOptionFunctions0}. It is equivalent to \\spadfun{guessADE}(\\spad{l},{} maxDerivative \\spad{==} 0).")) (|guessADE| (((|Mapping| (|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) (|Symbol|)) "\\spad{guessADE q} returns a guesser that tries to find an algebraic differential equation for a generating function whose first Taylor coefficients are given by \\spad{l},{} using the given options.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) "\\spad{guessADE(l,{} options)} tries to find an algebraic differential equation for a generating function whose first Taylor coefficients are given by \\spad{l},{} using the given options.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|)) "\\spad{guessADE l} tries to find an algebraic differential equation for a generating function whose first Taylor coefficients are given by \\spad{l},{} using the default options described in \\spadtype{GuessOptionFunctions0}.")) (|guessHP| (((|Mapping| (|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| |#1|)) (|UnivariateFormalPowerSeries| |#1|))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|)))) (|:| |exprStream| (|Mapping| (|Stream| |#3|) |#3| (|Symbol|))) (|:| A (|Mapping| |#2| (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| |#2|))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| |#1|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| |#1|)))) (|:| AX (|Mapping| |#3| (|NonNegativeInteger|) (|Symbol|) |#3|)) (|:| C (|Mapping| (|List| |#2|) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) "\\spad{guessHP f} constructs an operation that applies Hermite-Pade approximation to the series generated by the given function \\spad{f}.")) (|guessBinRat| (((|Mapping| (|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) (|Symbol|)) "\\spad{guessBinRat q} returns a guesser that tries to find a function of the form \\spad{n+}->qbinomial(a+b \\spad{n},{} \\spad{n}) \\spad{r}(\\spad{n}),{} where \\spad{r}(\\spad{q^n}) is a \\spad{q}-rational function,{} that fits \\spad{l}.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) "\\spad{guessBinRat(l,{} options)} tries to find a function of the form \\spad{n+}->binomial(a+b \\spad{n},{} \\spad{n}) \\spad{r}(\\spad{n}),{} where \\spad{r}(\\spad{n}) is a rational function,{} that fits \\spad{l}.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|)) "\\spad{guessBinRat(l,{} options)} tries to find a function of the form \\spad{n+}->binomial(a+b \\spad{n},{} \\spad{n}) \\spad{r}(\\spad{n}),{} where \\spad{r}(\\spad{n}) is a rational function,{} that fits \\spad{l}.")) (|guessExpRat| (((|Mapping| (|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) (|Symbol|)) "\\spad{guessExpRat q} returns a guesser that tries to find a function of the form \\spad{n+}->(a+b \\spad{q^n})\\spad{^n} \\spad{r}(\\spad{q^n}),{} where \\spad{r}(\\spad{q^n}) is a \\spad{q}-rational function,{} that fits \\spad{l}.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) "\\spad{guessExpRat(l,{} options)} tries to find a function of the form \\spad{n+}->(a+b \\spad{n})\\spad{^n} \\spad{r}(\\spad{n}),{} where \\spad{r}(\\spad{n}) is a rational function,{} that fits \\spad{l}.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|)) "\\spad{guessExpRat l} tries to find a function of the form \\spad{n+}->(a+b \\spad{n})\\spad{^n} \\spad{r}(\\spad{n}),{} where \\spad{r}(\\spad{n}) is a rational function,{} that fits \\spad{l}.")) (|guess| (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|Mapping| (|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|)))) (|List| (|Symbol|)) (|List| (|GuessOption|))) "\\spad{guess(l,{} guessers,{} ops)} applies recursively the given \\spad{guessers} to the successive differences if ops contains the symbol \\spad{guessSum} and quotients if ops contains the symbol \\spad{guessProduct} to the list. The given options are used.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|Mapping| (|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|)))) (|List| (|Symbol|))) "\\spad{guess(l,{} guessers,{} ops)} applies recursively the given \\spad{guessers} to the successive differences if ops contains the symbol guessSum and quotients if ops contains the symbol guessProduct to the list. Default options as described in \\spadtype{GuessOptionFunctions0} are used.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|) (|List| (|GuessOption|))) "\\spad{guess(l,{} options)} applies recursively \\spadfun{guessRec} and \\spadfun{guessADE} to the successive differences and quotients of the list. The given options are used.") (((|List| (|Record| (|:| |function| |#3|) (|:| |order| (|NonNegativeInteger|)))) (|List| |#1|)) "\\spad{guess l} applies recursively \\spadfun{guessRec} and \\spadfun{guessADE} to the successive differences and quotients of the list. Default options as described in \\spadtype{GuessOptionFunctions0} are used."))) 
 NIL 
 ((-12 (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-1161)))))) 
@@ -1886,27 +1886,27 @@ NIL
 NIL 
 (-489) 
 ((|constructor| (NIL "Symbolic fractions in \\%\\spad{pi} with integer coefficients; The point for using \\spad{Pi} as the default domain for those fractions is that \\spad{Pi} is coercible to the float types,{} and not Expression.")) (|pi| (($) "\\spad{\\spad{pi}()} returns the symbolic \\%\\spad{pi}."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-490 |Key| |Entry| |hashfn|) 
 ((|constructor| (NIL "This domain provides access to the underlying Lisp hash tables. By varying the hashfn parameter,{} tables suited for different purposes can be obtained."))) 
-((-4519 . T) (-4520 . T)) 
-((|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3649) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4083) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-1090))) (-2198 (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-1090)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090))))) 
+((-4521 . T) (-4522 . T)) 
+((|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3651) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4085) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-1090))) (-2199 (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-1090)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090))))) 
 (-491) 
 ((|constructor| (NIL "Generate a basis for the free Lie algebra on \\spad{n} generators over a ring \\spad{R} with identity up to basic commutators of length \\spad{c} using the algorithm of \\spad{P}. Hall as given in Serre\\spad{'s} book Lie Groups \\spad{--} Lie Algebras")) (|generate| (((|Vector| (|List| (|Integer|))) (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{generate(numberOfGens,{} maximalWeight)} generates a vector of elements of the form [left,{}weight,{}right] which represents a \\spad{P}. Hall basis element for the free lie algebra on \\spad{numberOfGens} generators. We only generate those basis elements of weight less than or equal to maximalWeight")) (|inHallBasis?| (((|Boolean|) (|Integer|) (|Integer|) (|Integer|) (|Integer|)) "\\spad{inHallBasis?(numberOfGens,{} leftCandidate,{} rightCandidate,{} left)} tests to see if a new element should be added to the \\spad{P}. Hall basis being constructed. The list \\spad{[leftCandidate,{}wt,{}rightCandidate]} is included in the basis if in the unique factorization of \\spad{rightCandidate},{} we have left factor leftOfRight,{} and leftOfRight \\spad{<=} \\spad{leftCandidate}")) (|lfunc| (((|Integer|) (|Integer|) (|Integer|)) "\\spad{lfunc(d,{}n)} computes the rank of the \\spad{n}th factor in the lower central series of the free \\spad{d}-generated free Lie algebra; This rank is \\spad{d} if \\spad{n} = 1 and binom(\\spad{d},{}2) if \\spad{n} = 2"))) 
 NIL 
 NIL 
 (-492 |vl| R) 
 ((|constructor| (NIL "This type supports distributed multivariate polynomials whose variables are from a user specified list of symbols. The coefficient ring may be non commutative,{} but the variables are assumed to commute. The term ordering is total degree ordering refined by reverse lexicographic ordering with respect to the position that the variables appear in the list of variables parameter.")) (|reorder| (($ $ (|List| (|Integer|))) "\\spad{reorder(p,{} perm)} applies the permutation perm to the variables in a polynomial and returns the new correctly ordered polynomial"))) 
-(((-4521 "*") |has| |#2| (-172)) (-4512 |has| |#2| (-558)) (-4517 |has| |#2| (-6 -4517)) (-4514 . T) (-4513 . T) (-4516 . T)) 
-((|HasCategory| |#2| (QUOTE (-904))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-172))) (-2198 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-558)))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#2| (QUOTE (-842))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-365))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#2| (QUOTE -4517)) (|HasCategory| |#2| (QUOTE (-453))) (-2198 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2198 (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2198 (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (|HasCategory| |#2| (QUOTE (-148))))) 
-(-493 -2570 S) 
+(((-4523 "*") |has| |#2| (-172)) (-4514 |has| |#2| (-558)) (-4519 |has| |#2| (-6 -4519)) (-4516 . T) (-4515 . T) (-4518 . T)) 
+((|HasCategory| |#2| (QUOTE (-904))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-172))) (-2199 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-558)))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#2| (QUOTE (-842))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-365))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#2| (QUOTE -4519)) (|HasCategory| |#2| (QUOTE (-453))) (-2199 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2199 (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2199 (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (|HasCategory| |#2| (QUOTE (-148))))) 
+(-493 -1965 S) 
 ((|constructor| (NIL "This type represents the finite direct or cartesian product of an underlying ordered component type. The vectors are ordered first by the sum of their components,{} and then refined using a reverse lexicographic ordering. This type is a suitable third argument for \\spadtype{GeneralDistributedMultivariatePolynomial}."))) 
-((-4513 |has| |#2| (-1047)) (-4514 |has| |#2| (-1047)) (-4516 |has| |#2| (-6 -4516)) ((-4521 "*") |has| |#2| (-172)) (-4519 . T)) 
-((|HasCategory| |#2| (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047))) (|HasCategory| |#2| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-840))) (-2198 (|HasCategory| |#2| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-840)))) (|HasCategory| |#2| (QUOTE (-716))) (|HasCategory| |#2| (QUOTE (-172))) (-2198 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (-2198 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-365)))) (-2198 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-1047)))) (|HasCategory| |#2| (QUOTE (-370))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-225))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-1047)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1090)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-1090)))) (|HasAttribute| |#2| (QUOTE -4516)) (|HasCategory| |#2| (QUOTE (-137))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (|HasCategory| |#2| (QUOTE (-25))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-370))) (|HasCategory| |#2| (QUOTE (-716))) (|HasCategory| |#2| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-840))) (|HasCategory| |#2| (QUOTE (-1047))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (-2198 (-12 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-172)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-365)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-370)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-716)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-788)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-840)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-1090))))) (-2198 (-12 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-172)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-365)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-370)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-716)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-788)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-840)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1090))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-172)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-365)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-370)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-716)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-788)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-840)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))))) 
+((-4515 |has| |#2| (-1047)) (-4516 |has| |#2| (-1047)) (-4518 |has| |#2| (-6 -4518)) ((-4523 "*") |has| |#2| (-172)) (-4521 . T)) 
+((|HasCategory| |#2| (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047))) (|HasCategory| |#2| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-840))) (-2199 (|HasCategory| |#2| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-840)))) (|HasCategory| |#2| (QUOTE (-716))) (|HasCategory| |#2| (QUOTE (-172))) (-2199 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (-2199 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-365)))) (-2199 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-1047)))) (|HasCategory| |#2| (QUOTE (-370))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-225))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-1047)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1090)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-1090)))) (|HasAttribute| |#2| (QUOTE -4518)) (|HasCategory| |#2| (QUOTE (-137))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (|HasCategory| |#2| (QUOTE (-25))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-370))) (|HasCategory| |#2| (QUOTE (-716))) (|HasCategory| |#2| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-840))) (|HasCategory| |#2| (QUOTE (-1047))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (-2199 (-12 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-172)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-365)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-370)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-716)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-788)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-840)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-1090))))) (-2199 (-12 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-172)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-365)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-370)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-716)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-788)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-840)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1090))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-172)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-365)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-370)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-716)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-788)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-840)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))))) 
 (-494 S) 
 ((|constructor| (NIL "Heap implemented in a flexible array to allow for insertions")) (|member?| (((|Boolean|) |#1| $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} member?(3,{}a)")) (|members| (((|List| |#1|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} members a")) (|parts| (((|List| |#1|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} parts a")) (|#| (((|NonNegativeInteger|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} \\#a")) (|count| (((|NonNegativeInteger|) |#1| $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} count(4,{}a)") (((|NonNegativeInteger|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} count(\\spad{x+}->(\\spad{x>2}),{}a)")) (|any?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} any?(\\spad{x+}->(\\spad{x=4}),{}a)")) (|every?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} every?(\\spad{x+}->(\\spad{x=4}),{}a)")) (~= (((|Boolean|) $ $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} b:=copy a \\spad{X} (a~=b)")) (= (((|Boolean|) $ $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} b:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} (a=b)@Boolean")) (|coerce| (((|OutputForm|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} coerce a")) (|hash| (((|SingleInteger|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} hash a")) (|latex| (((|String|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} latex a")) (|map!| (($ (|Mapping| |#1| |#1|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} map!(\\spad{x+}-\\spad{>x+10},{}a) \\spad{X} a")) (|size?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} size?(a,{}5)")) (|more?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} more?(a,{}9)")) (|less?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} less?(a,{}9)")) (|sample| (($) "\\blankline \\spad{X} sample()\\$Heap(INT)")) (|merge!| (($ $ $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} b:Heap INT:= heap [6,{}7,{}8,{}9,{}10] \\spad{X} merge!(a,{}\\spad{b}) \\spad{X} a \\spad{X} \\spad{b}")) (|merge| (($ $ $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} b:Heap INT:= heap [6,{}7,{}8,{}9,{}10] \\spad{X} merge(a,{}\\spad{b})")) (|max| ((|#1| $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} max a")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} map(\\spad{x+}-\\spad{>x+10},{}a) \\spad{X} a")) (|inspect| ((|#1| $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} inspect a")) (|insert!| (($ |#1| $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} insert!(8,{}a) \\spad{X} a")) (|extract!| ((|#1| $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} extract! a \\spad{X} a")) (|eq?| (((|Boolean|) $ $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} b:=copy a \\spad{X} eq?(a,{}\\spad{b})")) (|empty| (($) "\\blankline \\spad{X} b:=empty()\\$(Heap INT)")) (|empty?| (((|Boolean|) $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} empty? a")) (|copy| (($ $) "\\blankline \\spad{X} a:Heap INT:= heap [1,{}2,{}3,{}4,{}5] \\spad{X} copy a")) (|bag| (($ (|List| |#1|)) "\\blankline \\spad{X} bag([1,{}2,{}3,{}4,{}5])\\$Heap(INT)")) (|heap| (($ (|List| |#1|)) "\\indented{1}{heap(\\spad{ls}) creates a heap of elements consisting of the} \\indented{1}{elements of \\spad{ls}.} \\blankline \\spad{E} i:Heap INT \\spad{:=} heap [1,{}6,{}3,{}7,{}5,{}2,{}4]"))) 
-((-4519 . T) (-4520 . T)) 
+((-4521 . T) (-4522 . T)) 
 ((|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090))))) 
 (-495 -1478 UP UPUP R) 
 ((|constructor| (NIL "This domains implements finite rational divisors on an hyperelliptic curve,{} that is finite formal sums SUM(\\spad{n} * \\spad{P}) where the \\spad{n}\\spad{'s} are integers and the \\spad{P}\\spad{'s} are finite rational points on the curve. The equation of the curve must be \\spad{y^2} = \\spad{f}(\\spad{x}) and \\spad{f} must have odd degree."))) 
@@ -1918,12 +1918,12 @@ NIL
 NIL 
 (-497) 
 ((|constructor| (NIL "This domain allows rational numbers to be presented as repeating hexadecimal expansions.")) (|hex| (($ (|Fraction| (|Integer|))) "\\spad{hex(r)} converts a rational number to a hexadecimal expansion.")) (|fractionPart| (((|Fraction| (|Integer|)) $) "\\spad{fractionPart(h)} returns the fractional part of a hexadecimal expansion.")) (|coerce| (((|RadixExpansion| 16) $) "\\spad{coerce(h)} converts a hexadecimal expansion to a radix expansion with base 16.") (((|Fraction| (|Integer|)) $) "\\spad{coerce(h)} converts a hexadecimal expansion to a rational number."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| (-568) (QUOTE (-904))) (|HasCategory| (-568) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| (-568) (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-150))) (|HasCategory| (-568) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-568) (QUOTE (-1021))) (|HasCategory| (-568) (QUOTE (-815))) (|HasCategory| (-568) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| (-568) (QUOTE (-1136))) (|HasCategory| (-568) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| (-568) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| (-568) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| (-568) (QUOTE (-225))) (|HasCategory| (-568) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-568) (LIST (QUOTE -523) (QUOTE (-1161)) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -303) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -281) (QUOTE (-568)) (QUOTE (-568)))) (|HasCategory| (-568) (QUOTE (-301))) (|HasCategory| (-568) (QUOTE (-550))) (|HasCategory| (-568) (QUOTE (-842))) (-2198 (|HasCategory| (-568) (QUOTE (-815))) (|HasCategory| (-568) (QUOTE (-842)))) (|HasCategory| (-568) (LIST (QUOTE -630) (QUOTE (-568)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-904)))) (|HasCategory| (-568) (QUOTE (-148))))) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| (-568) (QUOTE (-904))) (|HasCategory| (-568) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| (-568) (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-150))) (|HasCategory| (-568) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-568) (QUOTE (-1021))) (|HasCategory| (-568) (QUOTE (-815))) (|HasCategory| (-568) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| (-568) (QUOTE (-1136))) (|HasCategory| (-568) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| (-568) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| (-568) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| (-568) (QUOTE (-225))) (|HasCategory| (-568) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-568) (LIST (QUOTE -523) (QUOTE (-1161)) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -303) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -281) (QUOTE (-568)) (QUOTE (-568)))) (|HasCategory| (-568) (QUOTE (-301))) (|HasCategory| (-568) (QUOTE (-550))) (|HasCategory| (-568) (QUOTE (-842))) (-2199 (|HasCategory| (-568) (QUOTE (-815))) (|HasCategory| (-568) (QUOTE (-842)))) (|HasCategory| (-568) (LIST (QUOTE -630) (QUOTE (-568)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-904)))) (|HasCategory| (-568) (QUOTE (-148))))) 
 (-498 A S) 
 ((|constructor| (NIL "A homogeneous aggregate is an aggregate of elements all of the same type. In the current system,{} all aggregates are homogeneous. Two attributes characterize classes of aggregates. Aggregates from domains with attribute \\spadatt{finiteAggregate} have a finite number of members. Those with attribute \\spadatt{shallowlyMutable} allow an element to be modified or updated without changing its overall value.")) (|member?| (((|Boolean|) |#2| $) "\\spad{member?(x,{}u)} tests if \\spad{x} is a member of \\spad{u}. For collections,{} \\axiom{member?(\\spad{x},{}\\spad{u}) = reduce(or,{}[x=y for \\spad{y} in \\spad{u}],{}\\spad{false})}.")) (|members| (((|List| |#2|) $) "\\spad{members(u)} returns a list of the consecutive elements of \\spad{u}. For collections,{} \\axiom{parts([\\spad{x},{}\\spad{y},{}...,{}\\spad{z}]) = (\\spad{x},{}\\spad{y},{}...,{}\\spad{z})}.")) (|parts| (((|List| |#2|) $) "\\spad{parts(u)} returns a list of the consecutive elements of \\spad{u}. For collections,{} \\axiom{parts([\\spad{x},{}\\spad{y},{}...,{}\\spad{z}]) = (\\spad{x},{}\\spad{y},{}...,{}\\spad{z})}.")) (|count| (((|NonNegativeInteger|) |#2| $) "\\spad{count(x,{}u)} returns the number of occurrences of \\spad{x} in \\spad{u}. For collections,{} \\axiom{count(\\spad{x},{}\\spad{u}) = reduce(+,{}[x=y for \\spad{y} in \\spad{u}],{}0)}.") (((|NonNegativeInteger|) (|Mapping| (|Boolean|) |#2|) $) "\\spad{count(p,{}u)} returns the number of elements \\spad{x} in \\spad{u} such that \\axiom{\\spad{p}(\\spad{x})} is \\spad{true}. For collections,{} \\axiom{count(\\spad{p},{}\\spad{u}) = reduce(+,{}[1 for \\spad{x} in \\spad{u} | \\spad{p}(\\spad{x})],{}0)}.")) (|every?| (((|Boolean|) (|Mapping| (|Boolean|) |#2|) $) "\\spad{every?(f,{}u)} tests if \\spad{p}(\\spad{x}) is \\spad{true} for all elements \\spad{x} of \\spad{u}. Note that for collections,{} \\axiom{every?(\\spad{p},{}\\spad{u}) = reduce(and,{}map(\\spad{f},{}\\spad{u}),{}\\spad{true},{}\\spad{false})}.")) (|any?| (((|Boolean|) (|Mapping| (|Boolean|) |#2|) $) "\\spad{any?(p,{}u)} tests if \\axiom{\\spad{p}(\\spad{x})} is \\spad{true} for any element \\spad{x} of \\spad{u}. Note that for collections,{} \\axiom{any?(\\spad{p},{}\\spad{u}) = reduce(or,{}map(\\spad{f},{}\\spad{u}),{}\\spad{false},{}\\spad{true})}.")) (|map!| (($ (|Mapping| |#2| |#2|) $) "\\spad{map!(f,{}u)} destructively replaces each element \\spad{x} of \\spad{u} by \\axiom{\\spad{f}(\\spad{x})}.")) (|map| (($ (|Mapping| |#2| |#2|) $) "\\spad{map(f,{}u)} returns a copy of \\spad{u} with each element \\spad{x} replaced by \\spad{f}(\\spad{x}). For collections,{} \\axiom{map(\\spad{f},{}\\spad{u}) = [\\spad{f}(\\spad{x}) for \\spad{x} in \\spad{u}]}."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE -4519)) (|HasAttribute| |#1| (QUOTE -4520)) (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))) 
+((|HasAttribute| |#1| (QUOTE -4521)) (|HasAttribute| |#1| (QUOTE -4522)) (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))) 
 (-499 S) 
 ((|constructor| (NIL "A homogeneous aggregate is an aggregate of elements all of the same type. In the current system,{} all aggregates are homogeneous. Two attributes characterize classes of aggregates. Aggregates from domains with attribute \\spadatt{finiteAggregate} have a finite number of members. Those with attribute \\spadatt{shallowlyMutable} allow an element to be modified or updated without changing its overall value.")) (|member?| (((|Boolean|) |#1| $) "\\spad{member?(x,{}u)} tests if \\spad{x} is a member of \\spad{u}. For collections,{} \\axiom{member?(\\spad{x},{}\\spad{u}) = reduce(or,{}[x=y for \\spad{y} in \\spad{u}],{}\\spad{false})}.")) (|members| (((|List| |#1|) $) "\\spad{members(u)} returns a list of the consecutive elements of \\spad{u}. For collections,{} \\axiom{parts([\\spad{x},{}\\spad{y},{}...,{}\\spad{z}]) = (\\spad{x},{}\\spad{y},{}...,{}\\spad{z})}.")) (|parts| (((|List| |#1|) $) "\\spad{parts(u)} returns a list of the consecutive elements of \\spad{u}. For collections,{} \\axiom{parts([\\spad{x},{}\\spad{y},{}...,{}\\spad{z}]) = (\\spad{x},{}\\spad{y},{}...,{}\\spad{z})}.")) (|count| (((|NonNegativeInteger|) |#1| $) "\\spad{count(x,{}u)} returns the number of occurrences of \\spad{x} in \\spad{u}. For collections,{} \\axiom{count(\\spad{x},{}\\spad{u}) = reduce(+,{}[x=y for \\spad{y} in \\spad{u}],{}0)}.") (((|NonNegativeInteger|) (|Mapping| (|Boolean|) |#1|) $) "\\spad{count(p,{}u)} returns the number of elements \\spad{x} in \\spad{u} such that \\axiom{\\spad{p}(\\spad{x})} is \\spad{true}. For collections,{} \\axiom{count(\\spad{p},{}\\spad{u}) = reduce(+,{}[1 for \\spad{x} in \\spad{u} | \\spad{p}(\\spad{x})],{}0)}.")) (|every?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\spad{every?(f,{}u)} tests if \\spad{p}(\\spad{x}) is \\spad{true} for all elements \\spad{x} of \\spad{u}. Note that for collections,{} \\axiom{every?(\\spad{p},{}\\spad{u}) = reduce(and,{}map(\\spad{f},{}\\spad{u}),{}\\spad{true},{}\\spad{false})}.")) (|any?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\spad{any?(p,{}u)} tests if \\axiom{\\spad{p}(\\spad{x})} is \\spad{true} for any element \\spad{x} of \\spad{u}. Note that for collections,{} \\axiom{any?(\\spad{p},{}\\spad{u}) = reduce(or,{}map(\\spad{f},{}\\spad{u}),{}\\spad{false},{}\\spad{true})}.")) (|map!| (($ (|Mapping| |#1| |#1|) $) "\\spad{map!(f,{}u)} destructively replaces each element \\spad{x} of \\spad{u} by \\axiom{\\spad{f}(\\spad{x})}.")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\spad{map(f,{}u)} returns a copy of \\spad{u} with each element \\spad{x} replaced by \\spad{f}(\\spad{x}). For collections,{} \\axiom{map(\\spad{f},{}\\spad{u}) = [\\spad{f}(\\spad{x}) for \\spad{x} in \\spad{u}]}."))) 
 ((-3973 . T)) 
@@ -1946,15 +1946,15 @@ NIL
 NIL 
 (-504) 
 ((|constructor| (NIL "Algebraic closure of the rational numbers.")) (|norm| (($ $ (|List| (|Kernel| $))) "\\spad{norm(f,{}l)} computes the norm of the algebraic number \\spad{f} with respect to the extension generated by kernels \\spad{l}") (($ $ (|Kernel| $)) "\\spad{norm(f,{}k)} computes the norm of the algebraic number \\spad{f} with respect to the extension generated by kernel \\spad{k}") (((|SparseUnivariatePolynomial| $) (|SparseUnivariatePolynomial| $) (|List| (|Kernel| $))) "\\spad{norm(p,{}l)} computes the norm of the polynomial \\spad{p} with respect to the extension generated by kernels \\spad{l}") (((|SparseUnivariatePolynomial| $) (|SparseUnivariatePolynomial| $) (|Kernel| $)) "\\spad{norm(p,{}k)} computes the norm of the polynomial \\spad{p} with respect to the extension generated by kernel \\spad{k}")) (|trueEqual| (((|Boolean|) $ $) "\\spad{trueEqual(x,{}y)} tries to determine if the two numbers are equal")) (|reduce| (($ $) "\\spad{reduce(f)} simplifies all the unreduced algebraic numbers present in \\spad{f} by applying their defining relations.")) (|denom| (((|SparseMultivariatePolynomial| (|Integer|) (|Kernel| $)) $) "\\spad{denom(f)} returns the denominator of \\spad{f} viewed as a polynomial in the kernels over \\spad{Z}.")) (|numer| (((|SparseMultivariatePolynomial| (|Integer|) (|Kernel| $)) $) "\\spad{numer(f)} returns the numerator of \\spad{f} viewed as a polynomial in the kernels over \\spad{Z}.")) (|coerce| (($ (|SparseMultivariatePolynomial| (|Integer|) (|Kernel| $))) "\\spad{coerce(p)} returns \\spad{p} viewed as an algebraic number."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 ((|HasCategory| $ (QUOTE (-1047))) (|HasCategory| $ (LIST (QUOTE -1037) (QUOTE (-568))))) 
 (-505 S |mn|) 
 ((|constructor| (NIL "This is the basic one dimensional array data type."))) 
-((-4520 . T) (-4519 . T)) 
-((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (-2198 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
+((-4522 . T) (-4521 . T)) 
+((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (-2199 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
 (-506 R |mnRow| |mnCol|) 
 ((|constructor| (NIL "This domain implements two dimensional arrays"))) 
-((-4519 . T) (-4520 . T)) 
+((-4521 . T) (-4522 . T)) 
 ((|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090))))) 
 (-507 K R UP) 
 ((|constructor| (NIL "This package has no description")) (|chineseRemainder| (((|Record| (|:| |basis| (|Matrix| |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (|Matrix| |#2|))) (|List| |#3|) (|List| (|Record| (|:| |basis| (|Matrix| |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (|Matrix| |#2|)))) (|NonNegativeInteger|)) "\\spad{chineseRemainder(lu,{}lr,{}n)} \\undocumented")) (|listConjugateBases| (((|List| (|Record| (|:| |basis| (|Matrix| |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (|Matrix| |#2|)))) (|Record| (|:| |basis| (|Matrix| |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (|Matrix| |#2|))) (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{listConjugateBases(bas,{}q,{}n)} returns the list \\spad{[bas,{}bas^Frob,{}bas^(Frob^2),{}...bas^(Frob^(n-1))]},{} where \\spad{Frob} raises the coefficients of all polynomials appearing in the basis \\spad{bas} to the \\spad{q}th power.")) (|factorList| (((|List| (|SparseUnivariatePolynomial| |#1|)) |#1| (|NonNegativeInteger|) (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{factorList(k,{}n,{}m,{}j)} \\undocumented"))) 
@@ -1966,7 +1966,7 @@ NIL
 NIL 
 (-509 |mn|) 
 ((|constructor| (NIL "\\spadtype{IndexedBits} is a domain to compactly represent large quantities of Boolean data.")) (|And| (($ $ $) "\\spad{And(n,{}m)} returns the bit-by-bit logical And of \\spad{n} and \\spad{m}.")) (|Or| (($ $ $) "\\spad{Or(n,{}m)} returns the bit-by-bit logical Or of \\spad{n} and \\spad{m}.")) (|Not| (($ $) "\\spad{Not(n)} returns the bit-by-bit logical Not of \\spad{n}."))) 
-((-4520 . T) (-4519 . T)) 
+((-4522 . T) (-4521 . T)) 
 ((|HasCategory| (-121) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-121) (QUOTE (-842))) (|HasCategory| (-568) (QUOTE (-842))) (|HasCategory| (-121) (QUOTE (-1090))) (-12 (|HasCategory| (-121) (LIST (QUOTE -303) (QUOTE (-121)))) (|HasCategory| (-121) (QUOTE (-1090))))) 
 (-510 K R UP L) 
 ((|constructor| (NIL "IntegralBasisPolynomialTools provides functions for mapping functions on the coefficients of univariate and bivariate polynomials.")) (|mapBivariate| (((|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| |#4|)) (|Mapping| |#4| |#1|) |#3|) "\\spad{mapBivariate(f,{}p(x,{}y))} applies the function \\spad{f} to the coefficients of \\spad{p(x,{}y)}.")) (|mapMatrixIfCan| (((|Union| (|Matrix| |#2|) "failed") (|Mapping| (|Union| |#1| "failed") |#4|) (|Matrix| (|SparseUnivariatePolynomial| |#4|))) "\\spad{mapMatrixIfCan(f,{}mat)} applies the function \\spad{f} to the coefficients of the entries of \\spad{mat} if possible,{} and returns \\spad{\"failed\"} otherwise.")) (|mapUnivariateIfCan| (((|Union| |#2| "failed") (|Mapping| (|Union| |#1| "failed") |#4|) (|SparseUnivariatePolynomial| |#4|)) "\\spad{mapUnivariateIfCan(f,{}p(x))} applies the function \\spad{f} to the coefficients of \\spad{p(x)},{} if possible,{} and returns \\spad{\"failed\"} otherwise.")) (|mapUnivariate| (((|SparseUnivariatePolynomial| |#4|) (|Mapping| |#4| |#1|) |#2|) "\\spad{mapUnivariate(f,{}p(x))} applies the function \\spad{f} to the coefficients of \\spad{p(x)}.") ((|#2| (|Mapping| |#1| |#4|) (|SparseUnivariatePolynomial| |#4|)) "\\spad{mapUnivariate(f,{}p(x))} applies the function \\spad{f} to the coefficients of \\spad{p(x)}."))) 
@@ -2030,32 +2030,32 @@ NIL
 ((|HasCategory| |#2| (QUOTE (-787)))) 
 (-525 S |mn|) 
 ((|constructor| (NIL "A FlexibleArray is the notion of an array intended to allow for growth at the end only. Hence the following efficient operations\\spad{\\br} \\spad{append(x,{}a)} meaning append item \\spad{x} at the end of the array \\spad{a}\\spad{\\br} \\spad{delete(a,{}n)} meaning delete the last item from the array \\spad{a}\\spad{\\br} Flexible arrays support the other operations inherited from \\spadtype{ExtensibleLinearAggregate}. However,{} these are not efficient. Flexible arrays combine the \\spad{O(1)} access time property of arrays with growing and shrinking at the end in \\spad{O(1)} (average) time. This is done by using an ordinary array which may have zero or more empty slots at the end. When the array becomes full it is copied into a new larger (50\\% larger) array. Conversely,{} when the array becomes less than 1/2 full,{} it is copied into a smaller array. Flexible arrays provide for an efficient implementation of many data structures in particular heaps,{} stacks and sets.")) (|shrinkable| (((|Boolean|) (|Boolean|)) "\\indented{1}{shrinkable(\\spad{b}) sets the shrinkable attribute of flexible arrays to \\spad{b}} \\indented{1}{and returns the previous value} \\blankline \\spad{X} T1:=IndexedFlexibleArray(Integer,{}20) \\spad{X} shrinkable(\\spad{false})\\$\\spad{T1}")) (|physicalLength!| (($ $ (|Integer|)) "\\indented{1}{physicalLength!(\\spad{x},{}\\spad{n}) changes the physical length of \\spad{x} to be \\spad{n} and} \\indented{1}{returns the new array.} \\blankline \\spad{X} T1:=IndexedFlexibleArray(Integer,{}20) \\spad{X} t2:=flexibleArray([\\spad{i} for \\spad{i} in 1..10])\\$\\spad{T1} \\spad{X} physicalLength!(\\spad{t2},{}15)")) (|physicalLength| (((|NonNegativeInteger|) $) "\\indented{1}{physicalLength(\\spad{x}) returns the number of elements \\spad{x} can} \\indented{1}{accomodate before growing} \\blankline \\spad{X} T1:=IndexedFlexibleArray(Integer,{}20) \\spad{X} t2:=flexibleArray([\\spad{i} for \\spad{i} in 1..10])\\$\\spad{T1} \\spad{X} physicalLength \\spad{t2}")) (|flexibleArray| (($ (|List| |#1|)) "\\indented{1}{flexibleArray(\\spad{l}) creates a flexible array from the list of elements \\spad{l}} \\blankline \\spad{X} T1:=IndexedFlexibleArray(Integer,{}20) \\spad{X} flexibleArray([\\spad{i} for \\spad{i} in 1..10])\\$\\spad{T1}"))) 
-((-4520 . T) (-4519 . T)) 
-((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (-2198 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
+((-4522 . T) (-4521 . T)) 
+((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (-2199 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
 (-526 |p| |n|) 
 ((|constructor| (NIL "InnerFiniteField(\\spad{p},{}\\spad{n}) implements finite fields with \\spad{p**n} elements where \\spad{p} is assumed prime but does not check. For a version which checks that \\spad{p} is prime,{} see \\spadtype{FiniteField}."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| (-581 |#1|) (QUOTE (-150))) (|HasCategory| (-581 |#1|) (QUOTE (-370))) (|HasCategory| (-581 |#1|) (QUOTE (-148))) (-2198 (|HasCategory| (-581 |#1|) (QUOTE (-148))) (|HasCategory| (-581 |#1|) (QUOTE (-370))))) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| (-581 |#1|) (QUOTE (-150))) (|HasCategory| (-581 |#1|) (QUOTE (-370))) (|HasCategory| (-581 |#1|) (QUOTE (-148))) (-2199 (|HasCategory| (-581 |#1|) (QUOTE (-148))) (|HasCategory| (-581 |#1|) (QUOTE (-370))))) 
 (-527 R |mnRow| |mnCol| |Row| |Col|) 
 ((|constructor| (NIL "There is no description for this domain"))) 
-((-4519 . T) (-4520 . T)) 
+((-4521 . T) (-4522 . T)) 
 ((|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090))))) 
 (-528 S |mn|) 
 ((|constructor| (NIL "\\spadtype{IndexedList} is a basic implementation of the functions in \\spadtype{ListAggregate},{} often using functions in the underlying LISP system. The second parameter to the constructor (\\spad{mn}) is the beginning index of the list. That is,{} if \\spad{l} is a list,{} then \\spad{elt(l,{}mn)} is the first value. This constructor is probably best viewed as the implementation of singly-linked lists that are addressable by index rather than as a mere wrapper for LISP lists."))) 
-((-4520 . T) (-4519 . T)) 
-((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (-2198 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
+((-4522 . T) (-4521 . T)) 
+((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (-2199 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
 (-529 R |Row| |Col| M) 
 ((|constructor| (NIL "\\spadtype{InnerMatrixLinearAlgebraFunctions} is an internal package which provides standard linear algebra functions on domains in \\spad{MatrixCategory}")) (|inverse| (((|Union| |#4| "failed") |#4|) "\\spad{inverse(m)} returns the inverse of the matrix \\spad{m}. If the matrix is not invertible,{} \"failed\" is returned. Error: if the matrix is not square.")) (|generalizedInverse| ((|#4| |#4|) "\\spad{generalizedInverse(m)} returns the generalized (Moore--Penrose) inverse of the matrix \\spad{m},{} \\spadignore{i.e.} the matrix \\spad{h} such that m*h*m=h,{} h*m*h=m,{} \\spad{m*h} and \\spad{h*m} are both symmetric matrices.")) (|determinant| ((|#1| |#4|) "\\spad{determinant(m)} returns the determinant of the matrix \\spad{m}. an error message is returned if the matrix is not square.")) (|nullSpace| (((|List| |#3|) |#4|) "\\spad{nullSpace(m)} returns a basis for the null space of the matrix \\spad{m}.")) (|nullity| (((|NonNegativeInteger|) |#4|) "\\spad{nullity(m)} returns the mullity of the matrix \\spad{m}. This is the dimension of the null space of the matrix \\spad{m}.")) (|rank| (((|NonNegativeInteger|) |#4|) "\\spad{rank(m)} returns the rank of the matrix \\spad{m}.")) (|rowEchelon| ((|#4| |#4|) "\\spad{rowEchelon(m)} returns the row echelon form of the matrix \\spad{m}."))) 
 NIL 
-((|HasAttribute| |#3| (QUOTE -4520))) 
+((|HasAttribute| |#3| (QUOTE -4522))) 
 (-530 R |Row| |Col| M QF |Row2| |Col2| M2) 
 ((|constructor| (NIL "\\spadtype{InnerMatrixQuotientFieldFunctions} provides functions on matrices over an integral domain which involve the quotient field of that integral domain. The functions rowEchelon and inverse return matrices with entries in the quotient field.")) (|nullSpace| (((|List| |#3|) |#4|) "\\spad{nullSpace(m)} returns a basis for the null space of the matrix \\spad{m}.")) (|inverse| (((|Union| |#8| "failed") |#4|) "\\spad{inverse(m)} returns the inverse of the matrix \\spad{m}. If the matrix is not invertible,{} \"failed\" is returned. Error: if the matrix is not square. Note that the result will have entries in the quotient field.")) (|rowEchelon| ((|#8| |#4|) "\\spad{rowEchelon(m)} returns the row echelon form of the matrix \\spad{m}. the result will have entries in the quotient field."))) 
 NIL 
-((|HasAttribute| |#7| (QUOTE -4520))) 
+((|HasAttribute| |#7| (QUOTE -4522))) 
 (-531 R |mnRow| |mnCol|) 
 ((|constructor| (NIL "An \\spad{IndexedMatrix} is a matrix where the minimal row and column indices are parameters of the type. The domains Row and Col are both IndexedVectors. The index of the 'first' row may be obtained by calling the function \\spadfun{minRowIndex}. The index of the 'first' column may be obtained by calling the function \\spadfun{minColIndex}. The index of the first element of a 'Row' is the same as the index of the first column in a matrix and vice versa."))) 
-((-4519 . T) (-4520 . T)) 
-((|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-558))) (|HasAttribute| |#1| (QUOTE (-4521 "*"))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365)))) 
+((-4521 . T) (-4522 . T)) 
+((|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-558))) (|HasAttribute| |#1| (QUOTE (-4523 "*"))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365)))) 
 (-532 GF) 
 ((|constructor| (NIL "InnerNormalBasisFieldFunctions(\\spad{GF}) (unexposed): This package has functions used by every normal basis finite field extension domain.")) (|minimalPolynomial| (((|SparseUnivariatePolynomial| |#1|) (|Vector| |#1|)) "\\spad{minimalPolynomial(x)} \\undocumented{} See \\axiomFunFrom{minimalPolynomial}{FiniteAlgebraicExtensionField}")) (|normalElement| (((|Vector| |#1|) (|PositiveInteger|)) "\\spad{normalElement(n)} \\undocumented{} See \\axiomFunFrom{normalElement}{FiniteAlgebraicExtensionField}")) (|basis| (((|Vector| (|Vector| |#1|)) (|PositiveInteger|)) "\\spad{basis(n)} \\undocumented{} See \\axiomFunFrom{basis}{FiniteAlgebraicExtensionField}")) (|normal?| (((|Boolean|) (|Vector| |#1|)) "\\spad{normal?(x)} \\undocumented{} See \\axiomFunFrom{normal?}{FiniteAlgebraicExtensionField}")) (|lookup| (((|PositiveInteger|) (|Vector| |#1|)) "\\spad{lookup(x)} \\undocumented{} See \\axiomFunFrom{lookup}{Finite}")) (|inv| (((|Vector| |#1|) (|Vector| |#1|)) "\\spad{inv x} \\undocumented{} See \\axiomFunFrom{inv}{DivisionRing}")) (|trace| (((|Vector| |#1|) (|Vector| |#1|) (|PositiveInteger|)) "\\spad{trace(x,{}n)} \\undocumented{} See \\axiomFunFrom{trace}{FiniteAlgebraicExtensionField}")) (|norm| (((|Vector| |#1|) (|Vector| |#1|) (|PositiveInteger|)) "\\spad{norm(x,{}n)} \\undocumented{} See \\axiomFunFrom{norm}{FiniteAlgebraicExtensionField}")) (/ (((|Vector| |#1|) (|Vector| |#1|) (|Vector| |#1|)) "\\spad{x/y} \\undocumented{} See \\axiomFunFrom{/}{Field}")) (* (((|Vector| |#1|) (|Vector| |#1|) (|Vector| |#1|)) "\\spad{x*y} \\undocumented{} See \\axiomFunFrom{*}{SemiGroup}")) (** (((|Vector| |#1|) (|Vector| |#1|) (|Integer|)) "\\spad{x**n} \\undocumented{} See \\axiomFunFrom{\\spad{**}}{DivisionRing}")) (|qPot| (((|Vector| |#1|) (|Vector| |#1|) (|Integer|)) "\\spad{qPot(v,{}e)} computes \\spad{v**(q**e)},{} interpreting \\spad{v} as an element of normal basis field,{} \\spad{q} the size of the ground field. This is done by a cyclic \\spad{e}-shift of the vector \\spad{v}.")) (|expPot| (((|Vector| |#1|) (|Vector| |#1|) (|SingleInteger|) (|SingleInteger|)) "\\spad{expPot(v,{}e,{}d)} returns the sum from \\spad{i = 0} to \\spad{e - 1} of \\spad{v**(q**i*d)},{} interpreting \\spad{v} as an element of a normal basis field and where \\spad{q} is the size of the ground field. Note that for a description of the algorithm,{} see \\spad{T}.Itoh and \\spad{S}.Tsujii,{} \"A fast algorithm for computing multiplicative inverses in \\spad{GF}(2^m) using normal bases\",{} Information and Computation 78,{} \\spad{pp}.171-177,{} 1988.")) (|repSq| (((|Vector| |#1|) (|Vector| |#1|) (|NonNegativeInteger|)) "\\spad{repSq(v,{}e)} computes \\spad{v**e} by repeated squaring,{} interpreting \\spad{v} as an element of a normal basis field.")) (|dAndcExp| (((|Vector| |#1|) (|Vector| |#1|) (|NonNegativeInteger|) (|SingleInteger|)) "\\spad{dAndcExp(v,{}n,{}k)} computes \\spad{v**e} interpreting \\spad{v} as an element of normal basis field. A divide and conquer algorithm similar to the one from \\spad{D}.\\spad{R}.Stinson,{} \"Some observations on parallel Algorithms for fast exponentiation in \\spad{GF}(2^n)\",{} Siam \\spad{J}. Computation,{} Vol.19,{} No.4,{} \\spad{pp}.711-717,{} August 1990 is used. Argument \\spad{k} is a parameter of this algorithm.")) (|xn| (((|SparseUnivariatePolynomial| |#1|) (|NonNegativeInteger|)) "\\spad{xn(n)} returns the polynomial \\spad{x**n-1}.")) (|pol| (((|SparseUnivariatePolynomial| |#1|) (|Vector| |#1|)) "\\spad{pol(v)} turns the vector \\spad{[v0,{}...,{}vn]} into the polynomial \\spad{v0+v1*x+ ... + vn*x**n}.")) (|index| (((|Vector| |#1|) (|PositiveInteger|) (|PositiveInteger|)) "\\spad{index(n,{}m)} is a index function for vectors of length \\spad{n} over the ground field.")) (|random| (((|Vector| |#1|) (|PositiveInteger|)) "\\spad{random(n)} creates a vector over the ground field with random entries.")) (|setFieldInfo| (((|Void|) (|Vector| (|List| (|Record| (|:| |value| |#1|) (|:| |index| (|SingleInteger|))))) |#1|) "\\spad{setFieldInfo(m,{}p)} initializes the field arithmetic,{} where \\spad{m} is the multiplication table and \\spad{p} is the respective normal element of the ground field \\spad{GF}."))) 
 NIL 
@@ -2130,12 +2130,12 @@ NIL
 NIL 
 (-550) 
 ((|constructor| (NIL "An \\spad{IntegerNumberSystem} is a model for the integers.")) (|invmod| (($ $ $) "\\spad{invmod(a,{}b)},{} \\spad{0<=a<b>1},{} \\spad{(a,{}b)=1} means \\spad{1/a mod b}.")) (|powmod| (($ $ $ $) "\\spad{powmod(a,{}b,{}p)},{} \\spad{0<=a,{}b<p>1},{} means \\spad{a**b mod p}.")) (|mulmod| (($ $ $ $) "\\spad{mulmod(a,{}b,{}p)},{} \\spad{0<=a,{}b<p>1},{} means \\spad{a*b mod p}.")) (|submod| (($ $ $ $) "\\spad{submod(a,{}b,{}p)},{} \\spad{0<=a,{}b<p>1},{} means \\spad{a-b mod p}.")) (|addmod| (($ $ $ $) "\\spad{addmod(a,{}b,{}p)},{} \\spad{0<=a,{}b<p>1},{} means \\spad{a+b mod p}.")) (|mask| (($ $) "\\spad{mask(n)} returns \\spad{2**n-1} (an \\spad{n} bit mask).")) (|dec| (($ $) "\\spad{dec(x)} returns \\spad{x - 1}.")) (|inc| (($ $) "\\spad{inc(x)} returns \\spad{x + 1}.")) (|copy| (($ $) "\\spad{copy(n)} gives a copy of \\spad{n}.")) (|hash| (($ $) "\\spad{hash(n)} returns the hash code of \\spad{n}.")) (|random| (($ $) "\\spad{random(a)} creates a random element from 0 to \\spad{n-1}.") (($) "\\spad{random()} creates a random element.")) (|rationalIfCan| (((|Union| (|Fraction| (|Integer|)) "failed") $) "\\spad{rationalIfCan(n)} creates a rational number,{} or returns \"failed\" if this is not possible.")) (|rational| (((|Fraction| (|Integer|)) $) "\\spad{rational(n)} creates a rational number (see \\spadtype{Fraction Integer})..")) (|rational?| (((|Boolean|) $) "\\spad{rational?(n)} tests if \\spad{n} is a rational number (see \\spadtype{Fraction Integer}).")) (|symmetricRemainder| (($ $ $) "\\spad{symmetricRemainder(a,{}b)} (where \\spad{b > 1}) yields \\spad{r} where \\spad{ -b/2 <= r < b/2 }.")) (|positiveRemainder| (($ $ $) "\\spad{positiveRemainder(a,{}b)} (where \\spad{b > 1}) yields \\spad{r} where \\spad{0 <= r < b} and \\spad{r == a rem b}.")) (|bit?| (((|Boolean|) $ $) "\\spad{bit?(n,{}i)} returns \\spad{true} if and only if \\spad{i}-th bit of \\spad{n} is a 1.")) (|shift| (($ $ $) "\\spad{shift(a,{}i)} shift \\spad{a} by \\spad{i} digits.")) (|length| (($ $) "\\spad{length(a)} length of \\spad{a} in digits.")) (|base| (($) "\\spad{base()} returns the base for the operations of \\spad{IntegerNumberSystem}.")) (|multiplicativeValuation| ((|attribute|) "euclideanSize(a*b) returns \\spad{euclideanSize(a)*euclideanSize(b)}.")) (|even?| (((|Boolean|) $) "\\spad{even?(n)} returns \\spad{true} if and only if \\spad{n} is even.")) (|odd?| (((|Boolean|) $) "\\spad{odd?(n)} returns \\spad{true} if and only if \\spad{n} is odd."))) 
-((-4517 . T) (-4518 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4519 . T) (-4520 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-551 |Key| |Entry| |addDom|) 
 ((|constructor| (NIL "This domain is used to provide a conditional \"add\" domain for the implementation of \\spadtype{Table}."))) 
-((-4519 . T) (-4520 . T)) 
-((|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3649) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4083) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-1090))) (-2198 (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-1090)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090))))) 
+((-4521 . T) (-4522 . T)) 
+((|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3651) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4085) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-1090))) (-2199 (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-1090)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090))))) 
 (-552 R -1478) 
 ((|constructor| (NIL "This package provides functions for the integration of algebraic integrands over transcendental functions.")) (|algint| (((|IntegrationResult| |#2|) |#2| (|Kernel| |#2|) (|Kernel| |#2|) (|Mapping| (|SparseUnivariatePolynomial| |#2|) (|SparseUnivariatePolynomial| |#2|))) "\\spad{algint(f,{} x,{} y,{} d)} returns the integral of \\spad{f(x,{}y)dx} where \\spad{y} is an algebraic function of \\spad{x}; \\spad{d} is the derivation to use on \\spad{k[x]}."))) 
 NIL 
@@ -2150,7 +2150,7 @@ NIL
 NIL 
 (-555 R) 
 ((|constructor| (NIL "This category implements of interval arithmetic and transcendental functions over intervals.")) (|contains?| (((|Boolean|) $ |#1|) "\\spad{contains?(i,{}f)} returns \\spad{true} if \\axiom{\\spad{f}} is contained within the interval \\axiom{\\spad{i}},{} \\spad{false} otherwise.")) (|negative?| (((|Boolean|) $) "\\spad{negative?(u)} returns \\axiom{\\spad{true}} if every element of \\spad{u} is negative,{} \\axiom{\\spad{false}} otherwise.")) (|positive?| (((|Boolean|) $) "\\spad{positive?(u)} returns \\axiom{\\spad{true}} if every element of \\spad{u} is positive,{} \\axiom{\\spad{false}} otherwise.")) (|width| ((|#1| $) "\\spad{width(u)} returns \\axiom{sup(\\spad{u}) - inf(\\spad{u})}.")) (|sup| ((|#1| $) "\\spad{sup(u)} returns the supremum of \\axiom{\\spad{u}}.")) (|inf| ((|#1| $) "\\spad{inf(u)} returns the infinum of \\axiom{\\spad{u}}.")) (|qinterval| (($ |#1| |#1|) "\\spad{qinterval(inf,{}sup)} creates a new interval \\axiom{[\\spad{inf},{}\\spad{sup}]},{} without checking the ordering on the elements.")) (|interval| (($ (|Fraction| (|Integer|))) "\\spad{interval(f)} creates a new interval around \\spad{f}.") (($ |#1|) "\\spad{interval(f)} creates a new interval around \\spad{f}.") (($ |#1| |#1|) "\\spad{interval(inf,{}sup)} creates a new interval,{} either \\axiom{[\\spad{inf},{}\\spad{sup}]} if \\axiom{\\spad{inf} \\spad{<=} \\spad{sup}} or \\axiom{[\\spad{sup},{}in]} otherwise."))) 
-((-3996 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-3999 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-556 K |symb| |PolyRing| E |ProjPt| PCS |Plc| DIVISOR |InfClsPoint| |DesTree| BLMET) 
 ((|constructor| (NIL "The following is part of the PAFF package")) (|placesOfDegree| (((|Void|) (|PositiveInteger|) |#3| (|List| |#5|)) "\\spad{placesOfDegree(d,{} f,{} pts)} compute the places of degree dividing \\spad{d} of the curve \\spad{f}. \\spad{pts} should be the singular points of the curve \\spad{f}. For \\spad{d} > 1 this only works if \\spad{K} has \\axiomType{PseudoAlgebraicClosureOfFiniteFieldCategory}.")) (|intersectionDivisor| ((|#8| |#3| |#3| (|List| |#10|) (|List| |#5|)) "\\spad{intersectionDivisor(f,{}pol,{}listOfTree)} returns the intersection divisor of \\spad{f} with a curve defined by \\spad{pol}. \\spad{listOfTree} must contain all the desingularisation trees of all singular points on the curve \\indented{1}{defined by \\spad{pol}.}"))) 
@@ -2162,7 +2162,7 @@ NIL
 NIL 
 (-558) 
 ((|constructor| (NIL "The category of commutative integral domains,{} \\spadignore{i.e.} commutative rings with no zero divisors. \\blankline Conditional attributes\\spad{\\br} canonicalUnitNormal\\tab{5}the canonical field is the same for all associates\\spad{\\br} canonicalsClosed\\tab{5}the product of two canonicals is itself canonical")) (|unit?| (((|Boolean|) $) "\\spad{unit?(x)} tests whether \\spad{x} is a unit,{} \\spadignore{i.e.} is invertible.")) (|associates?| (((|Boolean|) $ $) "\\spad{associates?(x,{}y)} tests whether \\spad{x} and \\spad{y} are associates,{} \\spadignore{i.e.} differ by a unit factor.")) (|unitCanonical| (($ $) "\\spad{unitCanonical(x)} returns \\spad{unitNormal(x).canonical}.")) (|unitNormal| (((|Record| (|:| |unit| $) (|:| |canonical| $) (|:| |associate| $)) $) "\\spad{unitNormal(x)} tries to choose a canonical element from the associate class of \\spad{x}. The attribute canonicalUnitNormal,{} if asserted,{} means that the \"canonical\" element is the same across all associates of \\spad{x} if \\spad{unitNormal(x) = [u,{}c,{}a]} then \\spad{u*c = x},{} \\spad{a*u = 1}.")) (|exquo| (((|Union| $ "failed") $ $) "\\spad{exquo(a,{}b)} either returns an element \\spad{c} such that \\spad{c*b=a} or \"failed\" if no such element can be found."))) 
-((-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-559 R -1478) 
 ((|constructor| (NIL "This package provides functions for integration,{} limited integration,{} extended integration and the risch differential equation for elementary functions.")) (|lfextlimint| (((|Union| (|Record| (|:| |ratpart| |#2|) (|:| |coeff| |#2|)) "failed") |#2| (|Symbol|) (|Kernel| |#2|) (|List| (|Kernel| |#2|))) "\\spad{lfextlimint(f,{}x,{}k,{}[k1,{}...,{}kn])} returns functions \\spad{[h,{} c]} such that \\spad{dh/dx = f - c dk/dx}. Value \\spad{h} is looked for in a field containing \\spad{f} and \\spad{k1},{}...,{}\\spad{kn} (the \\spad{ki}\\spad{'s} must be logs).")) (|lfintegrate| (((|IntegrationResult| |#2|) |#2| (|Symbol|)) "\\spad{lfintegrate(f,{} x)} = \\spad{g} such that \\spad{dg/dx = f}.")) (|lfinfieldint| (((|Union| |#2| "failed") |#2| (|Symbol|)) "\\spad{lfinfieldint(f,{} x)} returns a function \\spad{g} such that \\spad{dg/dx = f} if \\spad{g} exists,{} \"failed\" otherwise.")) (|lflimitedint| (((|Union| (|Record| (|:| |mainpart| |#2|) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (|Symbol|) (|List| |#2|)) "\\spad{lflimitedint(f,{}x,{}[g1,{}...,{}gn])} returns functions \\spad{[h,{}[[\\spad{ci},{} \\spad{gi}]]]} such that the \\spad{gi}\\spad{'s} are among \\spad{[g1,{}...,{}gn]},{} and \\spad{d(h+sum(\\spad{ci} log(\\spad{gi})))/dx = f},{} if possible,{} \"failed\" otherwise.")) (|lfextendedint| (((|Union| (|Record| (|:| |ratpart| |#2|) (|:| |coeff| |#2|)) "failed") |#2| (|Symbol|) |#2|) "\\spad{lfextendedint(f,{} x,{} g)} returns functions \\spad{[h,{} c]} such that \\spad{dh/dx = f - cg},{} if (\\spad{h},{} \\spad{c}) exist,{} \"failed\" otherwise."))) 
@@ -2202,7 +2202,7 @@ NIL
 NIL 
 (-568) 
 ((|constructor| (NIL "\\spadtype{Integer} provides the domain of arbitrary precision integers.")) (|infinite| ((|attribute|) "nextItem never returns \"failed\".")) (|noetherian| ((|attribute|) "ascending chain condition on ideals.")) (|canonicalsClosed| ((|attribute|) "two positives multiply to give positive.")) (|canonical| ((|attribute|) "mathematical equality is data structure equality.")) (|random| (($ $) "\\spad{random(n)} returns a random integer from 0 to \\spad{n-1}."))) 
-((-4501 . T) (-4507 . T) (-4511 . T) (-4506 . T) (-4517 . T) (-4518 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4503 . T) (-4509 . T) (-4513 . T) (-4508 . T) (-4519 . T) (-4520 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-569) 
 ((|constructor| (NIL "\\axiomType{AnnaNumericalIntegrationPackage} is a \\axiom{package} of functions for the \\axiom{category} \\axiomType{NumericalIntegrationCategory} with \\axiom{measure},{} and \\axiom{integrate}.")) (|measure| (((|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|))) (|:| |extra| (|Result|))) (|NumericalIntegrationProblem|) (|RoutinesTable|)) "\\spad{measure(prob,{}R)} is a top level ANNA function for identifying the most appropriate numerical routine from those in the routines table provided for solving the numerical integration problem defined by \\axiom{\\spad{prob}}. \\blankline It calls each \\axiom{domain} listed in \\axiom{\\spad{R}} of \\axiom{category} \\axiomType{NumericalIntegrationCategory} in turn to calculate all measures and returns the best \\spadignore{i.e.} the name of the most appropriate domain and any other relevant information.") (((|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|))) (|:| |extra| (|Result|))) (|NumericalIntegrationProblem|)) "\\spad{measure(prob)} is a top level ANNA function for identifying the most appropriate numerical routine for solving the numerical integration problem defined by \\axiom{\\spad{prob}}. \\blankline It calls each \\axiom{domain} of \\axiom{category} \\axiomType{NumericalIntegrationCategory} in turn to calculate all measures and returns the best \\spadignore{i.e.} the name of the most appropriate domain and any other relevant information.")) (|integrate| (((|Union| (|Result|) "failed") (|Expression| (|Float|)) (|SegmentBinding| (|OrderedCompletion| (|Float|))) (|Symbol|)) "\\spad{integrate(exp,{} x = a..b,{} numerical)} is a top level ANNA function to integrate an expression,{} {\\spad{\\tt} \\spad{exp}},{} over a given range,{} {\\spad{\\tt} a} to {\\spad{\\tt} \\spad{b}}. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalIntegrationCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate,{} \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline It then performs the integration of the given expression on that \\axiom{domain}. \\blankline Default values for the absolute and relative error are used. \\blankline It is an error if the last argument is not {\\spad{\\tt} numerical}.") (((|Union| (|Result|) "failed") (|Expression| (|Float|)) (|SegmentBinding| (|OrderedCompletion| (|Float|))) (|String|)) "\\spad{integrate(exp,{} x = a..b,{} \"numerical\")} is a top level ANNA function to integrate an expression,{} {\\spad{\\tt} \\spad{exp}},{} over a given range,{} {\\spad{\\tt} a} to {\\spad{\\tt} \\spad{b}}. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalIntegrationCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate,{} \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline It then performs the integration of the given expression on that \\axiom{domain}. \\blankline Default values for the absolute and relative error are used. \\blankline It is an error of the last argument is not {\\spad{\\tt} \"numerical\"}.") (((|Result|) (|Expression| (|Float|)) (|List| (|Segment| (|OrderedCompletion| (|Float|)))) (|Float|) (|Float|) (|RoutinesTable|)) "\\spad{integrate(exp,{} [a..b,{}c..d,{}...],{} epsabs,{} epsrel,{} routines)} is a top level ANNA function to integrate a multivariate expression,{} {\\spad{\\tt} \\spad{exp}},{} over a given set of ranges to the required absolute and relative accuracy,{} using the routines available in the RoutinesTable provided. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalIntegrationCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate,{} \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline It then performs the integration of the given expression on that \\axiom{domain}.") (((|Result|) (|Expression| (|Float|)) (|List| (|Segment| (|OrderedCompletion| (|Float|)))) (|Float|) (|Float|)) "\\spad{integrate(exp,{} [a..b,{}c..d,{}...],{} epsabs,{} epsrel)} is a top level ANNA function to integrate a multivariate expression,{} {\\spad{\\tt} \\spad{exp}},{} over a given set of ranges to the required absolute and relative accuracy. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalIntegrationCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate,{} \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline It then performs the integration of the given expression on that \\axiom{domain}.") (((|Result|) (|Expression| (|Float|)) (|List| (|Segment| (|OrderedCompletion| (|Float|)))) (|Float|)) "\\spad{integrate(exp,{} [a..b,{}c..d,{}...],{} epsrel)} is a top level ANNA function to integrate a multivariate expression,{} {\\spad{\\tt} \\spad{exp}},{} over a given set of ranges to the required relative accuracy. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalIntegrationCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate,{} \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline It then performs the integration of the given expression on that \\axiom{domain}. \\blankline If epsrel = 0,{} a default absolute accuracy is used.") (((|Result|) (|Expression| (|Float|)) (|List| (|Segment| (|OrderedCompletion| (|Float|))))) "\\spad{integrate(exp,{} [a..b,{}c..d,{}...])} is a top level ANNA function to integrate a multivariate expression,{} {\\spad{\\tt} \\spad{exp}},{} over a given set of ranges. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalIntegrationCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate,{} \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline It then performs the integration of the given expression on that \\axiom{domain}. \\blankline Default values for the absolute and relative error are used.") (((|Result|) (|Expression| (|Float|)) (|Segment| (|OrderedCompletion| (|Float|)))) "\\spad{integrate(exp,{} a..b)} is a top level ANNA function to integrate an expression,{} {\\spad{\\tt} \\spad{exp}},{} over a given range {\\spad{\\tt} a} to {\\spad{\\tt} \\spad{b}}. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalIntegrationCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate,{} \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline It then performs the integration of the given expression on that \\axiom{domain}. \\blankline Default values for the absolute and relative error are used.") (((|Result|) (|Expression| (|Float|)) (|Segment| (|OrderedCompletion| (|Float|))) (|Float|)) "\\spad{integrate(exp,{} a..b,{} epsrel)} is a top level ANNA function to integrate an expression,{} {\\spad{\\tt} \\spad{exp}},{} over a given range {\\spad{\\tt} a} to {\\spad{\\tt} \\spad{b}} to the required relative accuracy. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalIntegrationCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate,{} \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline It then performs the integration of the given expression on that \\axiom{domain}. \\blankline If epsrel = 0,{} a default absolute accuracy is used.") (((|Result|) (|Expression| (|Float|)) (|Segment| (|OrderedCompletion| (|Float|))) (|Float|) (|Float|)) "\\spad{integrate(exp,{} a..b,{} epsabs,{} epsrel)} is a top level ANNA function to integrate an expression,{} {\\spad{\\tt} \\spad{exp}},{} over a given range {\\spad{\\tt} a} to {\\spad{\\tt} \\spad{b}} to the required absolute and relative accuracy. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalIntegrationCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate,{} \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline It then performs the integration of the given expression on that \\axiom{domain}.") (((|Result|) (|NumericalIntegrationProblem|)) "\\spad{integrate(IntegrationProblem)} is a top level ANNA function to integrate an expression over a given range or ranges to the required absolute and relative accuracy. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalIntegrationCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate,{} \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline It then performs the integration of the given expression on that \\axiom{domain}.") (((|Result|) (|Expression| (|Float|)) (|Segment| (|OrderedCompletion| (|Float|))) (|Float|) (|Float|) (|RoutinesTable|)) "\\spad{integrate(exp,{} a..b,{} epsrel,{} routines)} is a top level ANNA function to integrate an expression,{} {\\spad{\\tt} \\spad{exp}},{} over a given range {\\spad{\\tt} a} to {\\spad{\\tt} \\spad{b}} to the required absolute and relative accuracy using the routines available in the RoutinesTable provided. \\blankline It iterates over the \\axiom{domains} of \\axiomType{NumericalIntegrationCategory} to get the name and other relevant information of the the (domain of the) numerical routine likely to be the most appropriate,{} \\spadignore{i.e.} have the best \\axiom{measure}. \\blankline It then performs the integration of the given expression on that \\axiom{domain}."))) 
@@ -2230,7 +2230,7 @@ NIL
 NIL 
 (-575 R) 
 ((|constructor| (NIL "This domain is an implementation of interval arithmetic and transcendental functions over intervals."))) 
-((-3996 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-3999 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-576) 
 ((|constructor| (NIL "This package provides the implementation for the \\spadfun{solveLinearPolynomialEquation} operation over the integers. It uses a lifting technique from the package GenExEuclid")) (|solveLinearPolynomialEquation| (((|Union| (|List| (|SparseUnivariatePolynomial| (|Integer|))) "failed") (|List| (|SparseUnivariatePolynomial| (|Integer|))) (|SparseUnivariatePolynomial| (|Integer|))) "\\spad{solveLinearPolynomialEquation([f1,{} ...,{} fn],{} g)} (where the \\spad{fi} are relatively prime to each other) returns a list of \\spad{ai} such that \\spad{g/prod \\spad{fi} = sum ai/fi} or returns \"failed\" if no such list of \\spad{ai}\\spad{'s} exists."))) 
@@ -2250,11 +2250,11 @@ NIL
 NIL 
 (-580 |p| |unBalanced?|) 
 ((|constructor| (NIL "This domain implements \\spad{Zp},{} the \\spad{p}-adic completion of the integers. This is an internal domain."))) 
-((-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-581 |p|) 
 ((|constructor| (NIL "InnerPrimeField(\\spad{p}) implements the field with \\spad{p} elements."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 ((|HasCategory| $ (QUOTE (-150))) (|HasCategory| $ (QUOTE (-148))) (|HasCategory| $ (QUOTE (-370)))) 
 (-582) 
 ((|constructor| (NIL "A package to print strings without line-feed nor carriage-return.")) (|iprint| (((|Void|) (|String|)) "\\axiom{iprint(\\spad{s})} prints \\axiom{\\spad{s}} at the current position of the cursor."))) 
@@ -2270,7 +2270,7 @@ NIL
 NIL 
 (-585 -1478) 
 ((|constructor| (NIL "The result of a transcendental integration. If a function \\spad{f} has an elementary integral \\spad{g},{} then \\spad{g} can be written in the form \\spad{g = h + c1 log(u1) + c2 log(u2) + ... + cn log(un)} where \\spad{h},{} which is in the same field than \\spad{f},{} is called the rational part of the integral,{} and \\spad{c1 log(u1) + ... cn log(un)} is called the logarithmic part of the integral. This domain manipulates integrals represented in that form,{} by keeping both parts separately. The logs are not explicitly computed.")) (|differentiate| ((|#1| $ (|Symbol|)) "\\spad{differentiate(ir,{}x)} differentiates \\spad{ir} with respect to \\spad{x}") ((|#1| $ (|Mapping| |#1| |#1|)) "\\spad{differentiate(ir,{}D)} differentiates \\spad{ir} with respect to the derivation \\spad{D}.")) (|integral| (($ |#1| (|Symbol|)) "\\spad{integral(f,{}x)} returns the formal integral of \\spad{f} with respect to \\spad{x}") (($ |#1| |#1|) "\\spad{integral(f,{}x)} returns the formal integral of \\spad{f} with respect to \\spad{x}")) (|elem?| (((|Boolean|) $) "\\spad{elem?(ir)} tests if an integration result is elementary over \\spad{F?}")) (|notelem| (((|List| (|Record| (|:| |integrand| |#1|) (|:| |intvar| |#1|))) $) "\\spad{notelem(ir)} returns the non-elementary part of an integration result")) (|logpart| (((|List| (|Record| (|:| |scalar| (|Fraction| (|Integer|))) (|:| |coeff| (|SparseUnivariatePolynomial| |#1|)) (|:| |logand| (|SparseUnivariatePolynomial| |#1|)))) $) "\\spad{logpart(ir)} returns the logarithmic part of an integration result")) (|ratpart| ((|#1| $) "\\spad{ratpart(ir)} returns the rational part of an integration result")) (|mkAnswer| (($ |#1| (|List| (|Record| (|:| |scalar| (|Fraction| (|Integer|))) (|:| |coeff| (|SparseUnivariatePolynomial| |#1|)) (|:| |logand| (|SparseUnivariatePolynomial| |#1|)))) (|List| (|Record| (|:| |integrand| |#1|) (|:| |intvar| |#1|)))) "\\spad{mkAnswer(r,{}l,{}ne)} creates an integration result from a rational part \\spad{r},{} a logarithmic part \\spad{l},{} and a non-elementary part \\spad{ne}."))) 
-((-4514 . T) (-4513 . T)) 
+((-4516 . T) (-4515 . T)) 
 ((|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-1161))))) 
 (-586 I) 
 ((|constructor| (NIL "The \\spadtype{IntegerRoots} package computes square roots and \\spad{n}th roots of integers efficiently.")) (|approxSqrt| ((|#1| |#1|) "\\spad{approxSqrt(n)} returns an approximation \\spad{x} to \\spad{sqrt(n)} such that \\spad{-1 < x - sqrt(n) < 1}. Compute an approximation \\spad{s} to \\spad{sqrt(n)} such that \\indented{10}{\\spad{-1 < s - sqrt(n) < 1}} A variable precision Newton iteration is used. The running time is \\spad{O( log(n)**2 )}.")) (|perfectSqrt| (((|Union| |#1| "failed") |#1|) "\\spad{perfectSqrt(n)} returns the square root of \\spad{n} if \\spad{n} is a perfect square and returns \"failed\" otherwise")) (|perfectSquare?| (((|Boolean|) |#1|) "\\spad{perfectSquare?(n)} returns \\spad{true} if \\spad{n} is a perfect square and \\spad{false} otherwise")) (|approxNthRoot| ((|#1| |#1| (|NonNegativeInteger|)) "\\spad{approxRoot(n,{}r)} returns an approximation \\spad{x} to \\spad{n**(1/r)} such that \\spad{-1 < x - n**(1/r) < 1}")) (|perfectNthRoot| (((|Record| (|:| |base| |#1|) (|:| |exponent| (|NonNegativeInteger|))) |#1|) "\\spad{perfectNthRoot(n)} returns \\spad{[x,{}r]},{} where \\spad{n = x\\^r} and \\spad{r} is the largest integer such that \\spad{n} is a perfect \\spad{r}th power") (((|Union| |#1| "failed") |#1| (|NonNegativeInteger|)) "\\spad{perfectNthRoot(n,{}r)} returns the \\spad{r}th root of \\spad{n} if \\spad{n} is an \\spad{r}th power and returns \"failed\" otherwise")) (|perfectNthPower?| (((|Boolean|) |#1| (|NonNegativeInteger|)) "\\spad{perfectNthPower?(n,{}r)} returns \\spad{true} if \\spad{n} is an \\spad{r}th power and \\spad{false} otherwise"))) 
@@ -2294,19 +2294,19 @@ NIL
 NIL 
 (-591 |mn|) 
 ((|constructor| (NIL "This domain implements low-level strings")) (|hash| (((|Integer|) $) "\\spad{hash(x)} provides a hashing function for strings"))) 
-((-4520 . T) (-4519 . T)) 
-((|HasCategory| (-147) (QUOTE (-1090))) (|HasCategory| (-147) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-147) (QUOTE (-842))) (-2198 (|HasCategory| (-147) (QUOTE (-842))) (|HasCategory| (-147) (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| (-147) (LIST (QUOTE -303) (QUOTE (-147)))) (|HasCategory| (-147) (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| (-147) (LIST (QUOTE -303) (QUOTE (-147)))) (|HasCategory| (-147) (QUOTE (-842)))) (-12 (|HasCategory| (-147) (LIST (QUOTE -303) (QUOTE (-147)))) (|HasCategory| (-147) (QUOTE (-1090)))))) 
+((-4522 . T) (-4521 . T)) 
+((|HasCategory| (-147) (QUOTE (-1090))) (|HasCategory| (-147) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-147) (QUOTE (-842))) (-2199 (|HasCategory| (-147) (QUOTE (-842))) (|HasCategory| (-147) (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| (-147) (LIST (QUOTE -303) (QUOTE (-147)))) (|HasCategory| (-147) (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| (-147) (LIST (QUOTE -303) (QUOTE (-147)))) (|HasCategory| (-147) (QUOTE (-842)))) (-12 (|HasCategory| (-147) (LIST (QUOTE -303) (QUOTE (-147)))) (|HasCategory| (-147) (QUOTE (-1090)))))) 
 (-592 E V R P) 
 ((|constructor| (NIL "Tools for the summation packages of polynomials")) (|sum| (((|Record| (|:| |num| |#4|) (|:| |den| (|Integer|))) |#4| |#2|) "\\spad{sum(p(n),{} n)} returns \\spad{P(n)},{} the indefinite sum of \\spad{p(n)} with respect to upward difference on \\spad{n},{} \\spadignore{i.e.} \\spad{P(n+1) - P(n) = a(n)}.") (((|Record| (|:| |num| |#4|) (|:| |den| (|Integer|))) |#4| |#2| (|Segment| |#4|)) "\\spad{sum(p(n),{} n = a..b)} returns \\spad{p(a) + p(a+1) + ... + p(b)}."))) 
 NIL 
 NIL 
 (-593 |Coef|) 
 ((|constructor| (NIL "InnerSparseUnivariatePowerSeries is an internal domain used for creating sparse Taylor and Laurent series.")) (|cAcsch| (($ $) "\\spad{cAcsch(f)} computes the inverse hyperbolic cosecant of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cAsech| (($ $) "\\spad{cAsech(f)} computes the inverse hyperbolic secant of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cAcoth| (($ $) "\\spad{cAcoth(f)} computes the inverse hyperbolic cotangent of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cAtanh| (($ $) "\\spad{cAtanh(f)} computes the inverse hyperbolic tangent of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cAcosh| (($ $) "\\spad{cAcosh(f)} computes the inverse hyperbolic cosine of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cAsinh| (($ $) "\\spad{cAsinh(f)} computes the inverse hyperbolic sine of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cCsch| (($ $) "\\spad{cCsch(f)} computes the hyperbolic cosecant of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cSech| (($ $) "\\spad{cSech(f)} computes the hyperbolic secant of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cCoth| (($ $) "\\spad{cCoth(f)} computes the hyperbolic cotangent of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cTanh| (($ $) "\\spad{cTanh(f)} computes the hyperbolic tangent of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cCosh| (($ $) "\\spad{cCosh(f)} computes the hyperbolic cosine of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cSinh| (($ $) "\\spad{cSinh(f)} computes the hyperbolic sine of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cAcsc| (($ $) "\\spad{cAcsc(f)} computes the arccosecant of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cAsec| (($ $) "\\spad{cAsec(f)} computes the arcsecant of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cAcot| (($ $) "\\spad{cAcot(f)} computes the arccotangent of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cAtan| (($ $) "\\spad{cAtan(f)} computes the arctangent of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cAcos| (($ $) "\\spad{cAcos(f)} computes the arccosine of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cAsin| (($ $) "\\spad{cAsin(f)} computes the arcsine of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cCsc| (($ $) "\\spad{cCsc(f)} computes the cosecant of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cSec| (($ $) "\\spad{cSec(f)} computes the secant of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cCot| (($ $) "\\spad{cCot(f)} computes the cotangent of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cTan| (($ $) "\\spad{cTan(f)} computes the tangent of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cCos| (($ $) "\\spad{cCos(f)} computes the cosine of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cSin| (($ $) "\\spad{cSin(f)} computes the sine of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cLog| (($ $) "\\spad{cLog(f)} computes the logarithm of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cExp| (($ $) "\\spad{cExp(f)} computes the exponential of the power series \\spad{f}. For use when the coefficient ring is commutative.")) (|cRationalPower| (($ $ (|Fraction| (|Integer|))) "\\spad{cRationalPower(f,{}r)} computes \\spad{f^r}. For use when the coefficient ring is commutative.")) (|cPower| (($ $ |#1|) "\\spad{cPower(f,{}r)} computes \\spad{f^r},{} where \\spad{f} has constant coefficient 1. For use when the coefficient ring is commutative.")) (|integrate| (($ $) "\\spad{integrate(f(x))} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 0. Warning: function does not check for a term of degree \\spad{-1}.")) (|seriesToOutputForm| (((|OutputForm|) (|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| |#1|))) (|Reference| (|OrderedCompletion| (|Integer|))) (|Symbol|) |#1| (|Fraction| (|Integer|))) "\\spad{seriesToOutputForm(st,{}refer,{}var,{}cen,{}r)} prints the series \\spad{f((var - cen)^r)}.")) (|iCompose| (($ $ $) "\\spad{iCompose(f,{}g)} returns \\spad{f(g(x))}. This is an internal function which should only be called for Taylor series \\spad{f(x)} and \\spad{g(x)} such that the constant coefficient of \\spad{g(x)} is zero.")) (|taylorQuoByVar| (($ $) "\\spad{taylorQuoByVar(a0 + a1 x + a2 x**2 + ...)} returns \\spad{a1 + a2 x + a3 x**2 + ...}")) (|iExquo| (((|Union| $ "failed") $ $ (|Boolean|)) "\\spad{iExquo(f,{}g,{}taylor?)} is the quotient of the power series \\spad{f} and \\spad{g}. If \\spad{taylor?} is \\spad{true},{} then we must have \\spad{order(f) >= order(g)}.")) (|multiplyCoefficients| (($ (|Mapping| |#1| (|Integer|)) $) "\\spad{multiplyCoefficients(fn,{}f)} returns the series \\spad{sum(fn(n) * an * x^n,{}n = n0..)},{} where \\spad{f} is the series \\spad{sum(an * x^n,{}n = n0..)}.")) (|monomial?| (((|Boolean|) $) "\\spad{monomial?(f)} tests if \\spad{f} is a single monomial.")) (|series| (($ (|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| |#1|)))) "\\spad{series(st)} creates a series from a stream of non-zero terms,{} where a term is an exponent-coefficient pair. The terms in the stream should be ordered by increasing order of exponents.")) (|getStream| (((|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| |#1|))) $) "\\spad{getStream(f)} returns the stream of terms representing the series \\spad{f}.")) (|getRef| (((|Reference| (|OrderedCompletion| (|Integer|))) $) "\\spad{getRef(f)} returns a reference containing the order to which the terms of \\spad{f} have been computed.")) (|makeSeries| (($ (|Reference| (|OrderedCompletion| (|Integer|))) (|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| |#1|)))) "\\spad{makeSeries(refer,{}str)} creates a power series from the reference \\spad{refer} and the stream \\spad{str}."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-568)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-568)) (|devaluate| |#1|))))) (|HasCategory| (-568) (QUOTE (-1102))) (|HasCategory| |#1| (QUOTE (-365))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-568))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -2745) (LIST (|devaluate| |#1|) (QUOTE (-1161))))))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-568)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-568)) (|devaluate| |#1|))))) (|HasCategory| (-568) (QUOTE (-1102))) (|HasCategory| |#1| (QUOTE (-365))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-568))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -2747) (LIST (|devaluate| |#1|) (QUOTE (-1161))))))) 
 (-594 |Coef|) 
 ((|constructor| (NIL "Internal package for dense Taylor series. This is an internal Taylor series type in which Taylor series are represented by a \\spadtype{Stream} of \\spadtype{Ring} elements. For univariate series,{} the \\spad{Stream} elements are the Taylor coefficients. For multivariate series,{} the \\spad{n}th Stream element is a form of degree \\spad{n} in the power series variables.")) (* (($ $ (|Integer|)) "\\spad{x*i} returns the product of integer \\spad{i} and the series \\spad{x}.") (($ $ |#1|) "\\spad{x*c} returns the product of \\spad{c} and the series \\spad{x}.") (($ |#1| $) "\\spad{c*x} returns the product of \\spad{c} and the series \\spad{x}.")) (|order| (((|NonNegativeInteger|) $ (|NonNegativeInteger|)) "\\spad{order(x,{}n)} returns the minimum of \\spad{n} and the order of \\spad{x}.") (((|NonNegativeInteger|) $) "\\spad{order(x)} returns the order of a power series \\spad{x},{} \\indented{1}{\\spadignore{i.e.} the degree of the first non-zero term of the series.}")) (|pole?| (((|Boolean|) $) "\\spad{pole?(x)} tests if the series \\spad{x} has a pole. \\indented{1}{Note: this is \\spad{false} when \\spad{x} is a Taylor series.}")) (|series| (($ (|Stream| |#1|)) "\\spad{series(s)} creates a power series from a stream of \\indented{1}{ring elements.} \\indented{1}{For univariate series types,{} the stream \\spad{s} should be a stream} \\indented{1}{of Taylor coefficients. For multivariate series types,{} the} \\indented{1}{stream \\spad{s} should be a stream of forms the \\spad{n}th element} \\indented{1}{of which is a} \\indented{1}{form of degree \\spad{n} in the power series variables.}")) (|coefficients| (((|Stream| |#1|) $) "\\spad{coefficients(x)} returns a stream of ring elements. \\indented{1}{When \\spad{x} is a univariate series,{} this is a stream of Taylor} \\indented{1}{coefficients. When \\spad{x} is a multivariate series,{} the} \\indented{1}{\\spad{n}th element of the stream is a form of} \\indented{1}{degree \\spad{n} in the power series variables.}"))) 
-((-4514 |has| |#1| (-558)) (-4513 |has| |#1| (-558)) ((-4521 "*") |has| |#1| (-558)) (-4512 |has| |#1| (-558)) (-4516 . T)) 
+((-4516 |has| |#1| (-558)) (-4515 |has| |#1| (-558)) ((-4523 "*") |has| |#1| (-558)) (-4514 |has| |#1| (-558)) (-4518 . T)) 
 ((|HasCategory| |#1| (QUOTE (-558)))) 
 (-595 A B) 
 ((|constructor| (NIL "Functions defined on streams with entries in two sets.")) (|map| (((|InfiniteTuple| |#2|) (|Mapping| |#2| |#1|) (|InfiniteTuple| |#1|)) "\\spad{map(f,{}[x0,{}x1,{}x2,{}...])} returns \\spad{[f(x0),{}f(x1),{}f(x2),{}..]}."))) 
@@ -2326,31 +2326,31 @@ NIL
 NIL 
 (-599 R |mn|) 
 ((|constructor| (NIL "This type represents vector like objects with varying lengths and a user-specified initial index."))) 
-((-4520 . T) (-4519 . T)) 
-((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (-2198 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-716))) (|HasCategory| |#1| (QUOTE (-1047))) (-12 (|HasCategory| |#1| (QUOTE (-1002))) (|HasCategory| |#1| (QUOTE (-1047)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
+((-4522 . T) (-4521 . T)) 
+((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (-2199 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-716))) (|HasCategory| |#1| (QUOTE (-1047))) (-12 (|HasCategory| |#1| (QUOTE (-1002))) (|HasCategory| |#1| (QUOTE (-1047)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
 (-600 S |Index| |Entry|) 
 ((|constructor| (NIL "An indexed aggregate is a many-to-one mapping of indices to entries. For example,{} a one-dimensional-array is an indexed aggregate where the index is an integer. Also,{} a table is an indexed aggregate where the indices and entries may have any type.")) (|swap!| (((|Void|) $ |#2| |#2|) "\\spad{swap!(u,{}i,{}j)} interchanges elements \\spad{i} and \\spad{j} of aggregate \\spad{u}. No meaningful value is returned.")) (|fill!| (($ $ |#3|) "\\spad{fill!(u,{}x)} replaces each entry in aggregate \\spad{u} by \\spad{x}. The modified \\spad{u} is returned as value.")) (|first| ((|#3| $) "\\spad{first(u)} returns the first element \\spad{x} of \\spad{u}. Note that for collections,{} \\axiom{first([\\spad{x},{}\\spad{y},{}...,{}\\spad{z}]) = \\spad{x}}. Error: if \\spad{u} is empty.")) (|minIndex| ((|#2| $) "\\spad{minIndex(u)} returns the minimum index \\spad{i} of aggregate \\spad{u}. Note that in general,{} \\axiom{minIndex(a) = reduce(min,{}[\\spad{i} for \\spad{i} in indices a])}; for lists,{} \\axiom{minIndex(a) = 1}.")) (|maxIndex| ((|#2| $) "\\spad{maxIndex(u)} returns the maximum index \\spad{i} of aggregate \\spad{u}. Note that in general,{} \\axiom{maxIndex(\\spad{u}) = reduce(max,{}[\\spad{i} for \\spad{i} in indices \\spad{u}])}; if \\spad{u} is a list,{} \\axiom{maxIndex(\\spad{u}) = \\#u}.")) (|entry?| (((|Boolean|) |#3| $) "\\spad{entry?(x,{}u)} tests if \\spad{x} equals \\axiom{\\spad{u} . \\spad{i}} for some index \\spad{i}.")) (|indices| (((|List| |#2|) $) "\\spad{indices(u)} returns a list of indices of aggregate \\spad{u} in no particular order. to become indices:")) (|index?| (((|Boolean|) |#2| $) "\\spad{index?(i,{}u)} tests if \\spad{i} is an index of aggregate \\spad{u}.")) (|entries| (((|List| |#3|) $) "\\spad{entries(u)} returns a list of all the entries of aggregate \\spad{u} in no assumed order."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE -4520)) (|HasCategory| |#2| (QUOTE (-842))) (|HasAttribute| |#1| (QUOTE -4519)) (|HasCategory| |#3| (QUOTE (-1090)))) 
+((|HasAttribute| |#1| (QUOTE -4522)) (|HasCategory| |#2| (QUOTE (-842))) (|HasAttribute| |#1| (QUOTE -4521)) (|HasCategory| |#3| (QUOTE (-1090)))) 
 (-601 |Index| |Entry|) 
 ((|constructor| (NIL "An indexed aggregate is a many-to-one mapping of indices to entries. For example,{} a one-dimensional-array is an indexed aggregate where the index is an integer. Also,{} a table is an indexed aggregate where the indices and entries may have any type.")) (|swap!| (((|Void|) $ |#1| |#1|) "\\spad{swap!(u,{}i,{}j)} interchanges elements \\spad{i} and \\spad{j} of aggregate \\spad{u}. No meaningful value is returned.")) (|fill!| (($ $ |#2|) "\\spad{fill!(u,{}x)} replaces each entry in aggregate \\spad{u} by \\spad{x}. The modified \\spad{u} is returned as value.")) (|first| ((|#2| $) "\\spad{first(u)} returns the first element \\spad{x} of \\spad{u}. Note that for collections,{} \\axiom{first([\\spad{x},{}\\spad{y},{}...,{}\\spad{z}]) = \\spad{x}}. Error: if \\spad{u} is empty.")) (|minIndex| ((|#1| $) "\\spad{minIndex(u)} returns the minimum index \\spad{i} of aggregate \\spad{u}. Note that in general,{} \\axiom{minIndex(a) = reduce(min,{}[\\spad{i} for \\spad{i} in indices a])}; for lists,{} \\axiom{minIndex(a) = 1}.")) (|maxIndex| ((|#1| $) "\\spad{maxIndex(u)} returns the maximum index \\spad{i} of aggregate \\spad{u}. Note that in general,{} \\axiom{maxIndex(\\spad{u}) = reduce(max,{}[\\spad{i} for \\spad{i} in indices \\spad{u}])}; if \\spad{u} is a list,{} \\axiom{maxIndex(\\spad{u}) = \\#u}.")) (|entry?| (((|Boolean|) |#2| $) "\\spad{entry?(x,{}u)} tests if \\spad{x} equals \\axiom{\\spad{u} . \\spad{i}} for some index \\spad{i}.")) (|indices| (((|List| |#1|) $) "\\spad{indices(u)} returns a list of indices of aggregate \\spad{u} in no particular order. to become indices:")) (|index?| (((|Boolean|) |#1| $) "\\spad{index?(i,{}u)} tests if \\spad{i} is an index of aggregate \\spad{u}.")) (|entries| (((|List| |#2|) $) "\\spad{entries(u)} returns a list of all the entries of aggregate \\spad{u} in no assumed order."))) 
 ((-3973 . T)) 
 NIL 
 (-602 R A) 
 ((|constructor| (NIL "AssociatedJordanAlgebra takes an algebra \\spad{A} and uses \\spadfun{*\\$A} to define the new multiplications \\spad{a*b := (a *\\$A b + b *\\$A a)/2} (anticommutator). The usual notation \\spad{{a,{}b}_+} cannot be used due to restrictions in the current language. This domain only gives a Jordan algebra if the Jordan-identity \\spad{(a*b)*c + (b*c)*a + (c*a)*b = 0} holds for all \\spad{a},{}\\spad{b},{}\\spad{c} in \\spad{A}. This relation can be checked by \\spadfun{jordanAdmissible?()\\$A}. \\blankline If the underlying algebra is of type \\spadtype{FramedNonAssociativeAlgebra(R)} (\\spadignore{i.e.} a non associative algebra over \\spad{R} which is a free \\spad{R}-module of finite rank,{} together with a fixed \\spad{R}-module basis),{} then the same is \\spad{true} for the associated Jordan algebra. Moreover,{} if the underlying algebra is of type \\spadtype{FiniteRankNonAssociativeAlgebra(R)} (\\spadignore{i.e.} a non associative algebra over \\spad{R} which is a free \\spad{R}-module of finite rank),{} then the same \\spad{true} for the associated Jordan algebra.")) (|coerce| (($ |#2|) "\\spad{coerce(a)} coerces the element \\spad{a} of the algebra \\spad{A} to an element of the Jordan algebra \\spadtype{AssociatedJordanAlgebra}(\\spad{R},{}A)."))) 
-((-4516 -2198 (-2139 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))) (-4514 . T) (-4513 . T)) 
-((|HasCategory| |#2| (LIST (QUOTE -419) (|devaluate| |#1|))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -419) (|devaluate| |#1|)))) (|HasCategory| |#2| (LIST (QUOTE -369) (|devaluate| |#1|))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -369) (|devaluate| |#1|))) (|HasCategory| |#2| (LIST (QUOTE -419) (|devaluate| |#1|)))) (-2198 (-12 (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#2| (LIST (QUOTE -369) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#2| (LIST (QUOTE -419) (|devaluate| |#1|)))))) 
+((-4518 -2199 (-2141 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))) (-4516 . T) (-4515 . T)) 
+((|HasCategory| |#2| (LIST (QUOTE -419) (|devaluate| |#1|))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -419) (|devaluate| |#1|)))) (|HasCategory| |#2| (LIST (QUOTE -369) (|devaluate| |#1|))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -369) (|devaluate| |#1|))) (|HasCategory| |#2| (LIST (QUOTE -419) (|devaluate| |#1|)))) (-2199 (-12 (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#2| (LIST (QUOTE -369) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#2| (LIST (QUOTE -419) (|devaluate| |#1|)))))) 
 (-603 |Entry|) 
 ((|constructor| (NIL "This domain allows a random access file to be viewed both as a table and as a file object. The KeyedAccessFile format is a directory containing a single file called ``index.kaf\\spad{''}. This file is a random access file. The first thing in the file is an integer which is the byte offset of an association list (the dictionary) at the end of the file. The association list is of the form ((key . byteoffset) (key . byteoffset)...) where the byte offset is the number of bytes from the beginning of the file. This offset contains an \\spad{s}-expression for the value of the key.")) (|pack!| (($ $) "\\spad{pack!(f)} reorganizes the file \\spad{f} on disk to recover unused space."))) 
-((-4519 . T) (-4520 . T)) 
-((|HasCategory| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| (-1143) (QUOTE (-842))) (|HasCategory| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3649) (QUOTE (-1143))) (LIST (QUOTE |:|) (QUOTE -4083) (|devaluate| |#1|))))) (|HasCategory| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (QUOTE (-1090))))) 
+((-4521 . T) (-4522 . T)) 
+((|HasCategory| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| (-1143) (QUOTE (-842))) (|HasCategory| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3651) (QUOTE (-1143))) (LIST (QUOTE |:|) (QUOTE -4085) (|devaluate| |#1|))))) (|HasCategory| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (QUOTE (-1090))))) 
 (-604 S |Key| |Entry|) 
 ((|constructor| (NIL "A keyed dictionary is a dictionary of key-entry pairs for which there is a unique entry for each key.")) (|search| (((|Union| |#3| "failed") |#2| $) "\\spad{search(k,{}t)} searches the table \\spad{t} for the key \\spad{k},{} returning the entry stored in \\spad{t} for key \\spad{k}. If \\spad{t} has no such key,{} \\axiom{search(\\spad{k},{}\\spad{t})} returns \"failed\".")) (|remove!| (((|Union| |#3| "failed") |#2| $) "\\spad{remove!(k,{}t)} searches the table \\spad{t} for the key \\spad{k} removing (and return) the entry if there. If \\spad{t} has no such key,{} \\axiom{remove!(\\spad{k},{}\\spad{t})} returns \"failed\".")) (|keys| (((|List| |#2|) $) "\\spad{keys(t)} returns the list the keys in table \\spad{t}.")) (|key?| (((|Boolean|) |#2| $) "\\spad{key?(k,{}t)} tests if \\spad{k} is a key in table \\spad{t}."))) 
 NIL 
 NIL 
 (-605 |Key| |Entry|) 
 ((|constructor| (NIL "A keyed dictionary is a dictionary of key-entry pairs for which there is a unique entry for each key.")) (|search| (((|Union| |#2| "failed") |#1| $) "\\spad{search(k,{}t)} searches the table \\spad{t} for the key \\spad{k},{} returning the entry stored in \\spad{t} for key \\spad{k}. If \\spad{t} has no such key,{} \\axiom{search(\\spad{k},{}\\spad{t})} returns \"failed\".")) (|remove!| (((|Union| |#2| "failed") |#1| $) "\\spad{remove!(k,{}t)} searches the table \\spad{t} for the key \\spad{k} removing (and return) the entry if there. If \\spad{t} has no such key,{} \\axiom{remove!(\\spad{k},{}\\spad{t})} returns \"failed\".")) (|keys| (((|List| |#1|) $) "\\spad{keys(t)} returns the list the keys in table \\spad{t}.")) (|key?| (((|Boolean|) |#1| $) "\\spad{key?(k,{}t)} tests if \\spad{k} is a key in table \\spad{t}."))) 
-((-4520 . T) (-3973 . T)) 
+((-4522 . T) (-3973 . T)) 
 NIL 
 (-606 R S) 
 ((|constructor| (NIL "This package exports some auxiliary functions on kernels")) (|constantIfCan| (((|Union| |#1| "failed") (|Kernel| |#2|)) "\\spad{constantIfCan(k)} \\undocumented")) (|constantKernel| (((|Kernel| |#2|) |#1|) "\\spad{constantKernel(r)} \\undocumented"))) 
@@ -2378,11 +2378,11 @@ NIL
 NIL 
 (-612 R) 
 ((|constructor| (NIL "The category of all left algebras over an arbitrary ring.")) (|coerce| (($ |#1|) "\\spad{coerce(r)} returns \\spad{r} * 1 where 1 is the identity of the left algebra."))) 
-((-4516 . T)) 
+((-4518 . T)) 
 NIL 
 (-613 A R S) 
 ((|constructor| (NIL "LocalAlgebra produces the localization of an algebra,{} \\spadignore{i.e.} fractions whose numerators come from some \\spad{R} algebra.")) (|denom| ((|#3| $) "\\spad{denom x} returns the denominator of \\spad{x}.")) (|numer| ((|#1| $) "\\spad{numer x} returns the numerator of \\spad{x}.")) (/ (($ |#1| |#3|) "\\spad{a / d} divides the element \\spad{a} by \\spad{d}.") (($ $ |#3|) "\\spad{x / d} divides the element \\spad{x} by \\spad{d}."))) 
-((-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4515 . T) (-4516 . T) (-4518 . T)) 
 ((|HasCategory| |#1| (QUOTE (-840)))) 
 (-614 R -1478) 
 ((|constructor| (NIL "This package computes the forward Laplace Transform.")) (|laplace| ((|#2| |#2| (|Symbol|) (|Symbol|)) "\\spad{laplace(f,{} t,{} s)} returns the Laplace transform of \\spad{f(t)} using \\spad{s} as the new variable. This is \\spad{integral(exp(-s*t)*f(t),{} t = 0..\\%plusInfinity)}. Returns the formal object \\spad{laplace(f,{} t,{} s)} if it cannot compute the transform."))) 
@@ -2390,7 +2390,7 @@ NIL
 NIL 
 (-615 R UP) 
 ((|constructor| (NIL "Univariate polynomials with negative and positive exponents.")) (|separate| (((|Record| (|:| |polyPart| $) (|:| |fracPart| (|Fraction| |#2|))) (|Fraction| |#2|)) "\\spad{separate(x)} is not documented")) (|monomial| (($ |#1| (|Integer|)) "\\spad{monomial(x,{}n)} is not documented")) (|coefficient| ((|#1| $ (|Integer|)) "\\spad{coefficient(x,{}n)} is not documented")) (|trailingCoefficient| ((|#1| $) "trailingCoefficient is not documented")) (|leadingCoefficient| ((|#1| $) "leadingCoefficient is not documented")) (|reductum| (($ $) "\\spad{reductum(x)} is not documented")) (|order| (((|Integer|) $) "\\spad{order(x)} is not documented")) (|degree| (((|Integer|) $) "\\spad{degree(x)} is not documented")) (|monomial?| (((|Boolean|) $) "\\spad{monomial?(x)} is not documented"))) 
-((-4514 . T) (-4513 . T) ((-4521 "*") . T) (-4512 . T) (-4516 . T)) 
+((-4516 . T) (-4515 . T) ((-4523 "*") . T) (-4514 . T) (-4518 . T)) 
 ((|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568))))) 
 (-616 R E V P TS ST) 
 ((|constructor| (NIL "A package for solving polynomial systems by means of Lazard triangular sets. This package provides two operations. One for solving in the sense of the regular zeros,{} and the other for solving in the sense of the Zariski closure. Both produce square-free regular sets. Moreover,{} the decompositions do not contain any redundant component. However,{} only zero-dimensional regular sets are normalized,{} since normalization may be time consumming in positive dimension. The decomposition process is that of [2].")) (|zeroSetSplit| (((|List| |#6|) (|List| |#4|) (|Boolean|)) "\\axiom{zeroSetSplit(\\spad{lp},{}clos?)} has the same specifications as zeroSetSplit(\\spad{lp},{}clos?) from RegularTriangularSetCategory.")) (|normalizeIfCan| ((|#6| |#6|) "\\axiom{normalizeIfCan(\\spad{ts})} returns \\axiom{\\spad{ts}} in an normalized shape if \\axiom{\\spad{ts}} is zero-dimensional."))) 
@@ -2402,18 +2402,18 @@ NIL
 NIL 
 (-618 |VarSet| R |Order|) 
 ((|constructor| (NIL "Management of the Lie Group associated with a free nilpotent Lie algebra. Every Lie bracket with length greater than \\axiom{Order} are assumed to be null. The implementation inherits from the \\spadtype{XPBWPolynomial} domain constructor: Lyndon coordinates are exponential coordinates of the second kind.")) (|identification| (((|List| (|Equation| |#2|)) $ $) "\\axiom{identification(\\spad{g},{}\\spad{h})} returns the list of equations \\axiom{g_i = h_i},{} where \\axiom{g_i} (resp. \\axiom{h_i}) are exponential coordinates of \\axiom{\\spad{g}} (resp. \\axiom{\\spad{h}}).")) (|LyndonCoordinates| (((|List| (|Record| (|:| |k| (|LyndonWord| |#1|)) (|:| |c| |#2|))) $) "\\axiom{LyndonCoordinates(\\spad{g})} returns the exponential coordinates of \\axiom{\\spad{g}}.")) (|LyndonBasis| (((|List| (|LiePolynomial| |#1| |#2|)) (|List| |#1|)) "\\axiom{LyndonBasis(\\spad{lv})} returns the Lyndon basis of the nilpotent free Lie algebra.")) (|varList| (((|List| |#1|) $) "\\axiom{varList(\\spad{g})} returns the list of variables of \\axiom{\\spad{g}}.")) (|mirror| (($ $) "\\axiom{mirror(\\spad{g})} is the mirror of the internal representation of \\axiom{\\spad{g}}.")) (|coerce| (((|XPBWPolynomial| |#1| |#2|) $) "\\axiom{coerce(\\spad{g})} returns the internal representation of \\axiom{\\spad{g}}.") (((|XDistributedPolynomial| |#1| |#2|) $) "\\axiom{coerce(\\spad{g})} returns the internal representation of \\axiom{\\spad{g}}.")) (|listOfTerms| (((|List| (|Record| (|:| |k| (|PoincareBirkhoffWittLyndonBasis| |#1|)) (|:| |c| |#2|))) $) "\\axiom{listOfTerms(\\spad{p})} returns the internal representation of \\axiom{\\spad{p}}.")) (|log| (((|LiePolynomial| |#1| |#2|) $) "\\axiom{log(\\spad{p})} returns the logarithm of \\axiom{\\spad{p}}.")) (|exp| (($ (|LiePolynomial| |#1| |#2|)) "\\axiom{exp(\\spad{p})} returns the exponential of \\axiom{\\spad{p}}."))) 
-((-4516 . T)) 
+((-4518 . T)) 
 NIL 
 (-619 R |ls|) 
 ((|constructor| (NIL "A package for solving polynomial systems with finitely many solutions. The decompositions are given by means of regular triangular sets. The computations use lexicographical Groebner bases. The main operations are lexTriangular and squareFreeLexTriangular. The second one provide decompositions by means of square-free regular triangular sets. Both are based on the lexTriangular method described in [1]. They differ from the algorithm described in [2] by the fact that multiciplities of the roots are not kept. With the squareFreeLexTriangular operation all multiciplities are removed. With the other operation some multiciplities may remain. Both operations admit an optional argument to produce normalized triangular sets.")) (|zeroSetSplit| (((|List| (|SquareFreeRegularTriangularSet| |#1| (|IndexedExponents| (|OrderedVariableList| |#2|)) (|OrderedVariableList| |#2|) (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|)))) (|List| (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|))) (|Boolean|)) "\\axiom{zeroSetSplit(\\spad{lp},{} norm?)} decomposes the variety associated with \\axiom{\\spad{lp}} into square-free regular chains. Thus a point belongs to this variety iff it is a regular zero of a regular set in in the output. Note that \\axiom{\\spad{lp}} needs to generate a zero-dimensional ideal. If \\axiom{norm?} is \\axiom{\\spad{true}} then the regular sets are normalized.") (((|List| (|RegularChain| |#1| |#2|)) (|List| (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|))) (|Boolean|)) "\\axiom{zeroSetSplit(\\spad{lp},{} norm?)} decomposes the variety associated with \\axiom{\\spad{lp}} into regular chains. Thus a point belongs to this variety iff it is a regular zero of a regular set in in the output. Note that \\axiom{\\spad{lp}} needs to generate a zero-dimensional ideal. If \\axiom{norm?} is \\axiom{\\spad{true}} then the regular sets are normalized.")) (|squareFreeLexTriangular| (((|List| (|SquareFreeRegularTriangularSet| |#1| (|IndexedExponents| (|OrderedVariableList| |#2|)) (|OrderedVariableList| |#2|) (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|)))) (|List| (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|))) (|Boolean|)) "\\axiom{squareFreeLexTriangular(base,{} norm?)} decomposes the variety associated with \\axiom{base} into square-free regular chains. Thus a point belongs to this variety iff it is a regular zero of a regular set in in the output. Note that \\axiom{base} needs to be a lexicographical Groebner basis of a zero-dimensional ideal. If \\axiom{norm?} is \\axiom{\\spad{true}} then the regular sets are normalized.")) (|lexTriangular| (((|List| (|RegularChain| |#1| |#2|)) (|List| (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|))) (|Boolean|)) "\\axiom{lexTriangular(base,{} norm?)} decomposes the variety associated with \\axiom{base} into regular chains. Thus a point belongs to this variety iff it is a regular zero of a regular set in in the output. Note that \\axiom{base} needs to be a lexicographical Groebner basis of a zero-dimensional ideal. If \\axiom{norm?} is \\axiom{\\spad{true}} then the regular sets are normalized.")) (|groebner| (((|List| (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|))) (|List| (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|)))) "\\axiom{groebner(\\spad{lp})} returns the lexicographical Groebner basis of \\axiom{\\spad{lp}}. If \\axiom{\\spad{lp}} generates a zero-dimensional ideal then the FGLM strategy is used,{} otherwise the Sugar strategy is used.")) (|fglmIfCan| (((|Union| (|List| (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|))) "failed") (|List| (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|)))) "\\axiom{fglmIfCan(\\spad{lp})} returns the lexicographical Groebner basis of \\axiom{\\spad{lp}} by using the FGLM strategy,{} if \\axiom{zeroDimensional?(\\spad{lp})} holds .")) (|zeroDimensional?| (((|Boolean|) (|List| (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|)))) "\\axiom{zeroDimensional?(\\spad{lp})} returns \\spad{true} iff \\axiom{\\spad{lp}} generates a zero-dimensional ideal \\spad{w}.\\spad{r}.\\spad{t}. the variables involved in \\axiom{\\spad{lp}}."))) 
 NIL 
 NIL 
 (-620) 
-((|constructor| (NIL "Category for the transcendental Liouvillian functions.")) (|erf| (($ $) "\\spad{erf(x)} returns the error function of \\spad{x},{} \\spadignore{i.e.} \\spad{2 / sqrt(\\%\\spad{pi})} times the integral of \\spad{exp(-x**2) dx}.")) (|dilog| (($ $) "\\spad{dilog(x)} returns the dilogarithm of \\spad{x},{} \\spadignore{i.e.} the integral of \\spad{log(x) / (1 - x) dx}.")) (|li| (($ $) "\\spad{\\spad{li}(x)} returns the logarithmic integral of \\spad{x},{} \\spadignore{i.e.} the integral of \\spad{dx / log(x)}.")) (|Ci| (($ $) "\\spad{\\spad{Ci}(x)} returns the cosine integral of \\spad{x},{} \\spadignore{i.e.} the integral of \\spad{cos(x) / x dx}.")) (|Si| (($ $) "\\spad{\\spad{Si}(x)} returns the sine integral of \\spad{x},{} \\spadignore{i.e.} the integral of \\spad{sin(x) / x dx}.")) (|Ei| (($ $) "\\spad{\\spad{Ei}(x)} returns the exponential integral of \\spad{x},{} \\spadignore{i.e.} the integral of \\spad{exp(x)/x dx}."))) 
+((|constructor| (NIL "Category for the transcendental Liouvillian functions.")) (|fresnelC| (($ $) "fresnelC is the Fresnel integral \\spad{C},{} defined by \\spad{C}(\\spad{x}) = integrate(cos(\\spad{t^2}),{}\\spad{t=0}..\\spad{x})")) (|fresnelS| (($ $) "fresnelS is the Fresnel integral \\spad{S},{} defined by \\spad{S}(\\spad{x}) = integrate(sin(\\spad{t^2}),{}\\spad{t=0}..\\spad{x})")) (|erf| (($ $) "\\spad{erf(x)} returns the error function of \\spad{x},{} \\spadignore{i.e.} \\spad{2 / sqrt(\\%\\spad{pi})} times the integral of \\spad{exp(-x**2) dx}.")) (|dilog| (($ $) "\\spad{dilog(x)} returns the dilogarithm of \\spad{x},{} \\spadignore{i.e.} the integral of \\spad{log(x) / (1 - x) dx}.")) (|li| (($ $) "\\spad{\\spad{li}(x)} returns the logarithmic integral of \\spad{x},{} \\spadignore{i.e.} the integral of \\spad{dx / log(x)}.")) (|Ci| (($ $) "\\spad{\\spad{Ci}(x)} returns the cosine integral of \\spad{x},{} \\spadignore{i.e.} the integral of \\spad{cos(x) / x dx}.")) (|Si| (($ $) "\\spad{\\spad{Si}(x)} returns the sine integral of \\spad{x},{} \\spadignore{i.e.} the integral of \\spad{sin(x) / x dx}.")) (|Ei| (($ $) "\\spad{\\spad{Ei}(x)} returns the exponential integral of \\spad{x},{} \\spadignore{i.e.} the integral of \\spad{exp(x)/x dx}."))) 
 NIL 
 NIL 
 (-621 R -1478) 
-((|constructor| (NIL "This package provides liouvillian functions over an integral domain.")) (|integral| ((|#2| |#2| (|SegmentBinding| |#2|)) "\\spad{integral(f,{}x = a..b)} denotes the definite integral of \\spad{f} with respect to \\spad{x} from \\spad{a} to \\spad{b}.") ((|#2| |#2| (|Symbol|)) "\\spad{integral(f,{}x)} indefinite integral of \\spad{f} with respect to \\spad{x}.")) (|dilog| ((|#2| |#2|) "\\spad{dilog(f)} denotes the dilogarithm")) (|erf| ((|#2| |#2|) "\\spad{erf(f)} denotes the error function")) (|li| ((|#2| |#2|) "\\spad{\\spad{li}(f)} denotes the logarithmic integral")) (|Ci| ((|#2| |#2|) "\\spad{\\spad{Ci}(f)} denotes the cosine integral")) (|Si| ((|#2| |#2|) "\\spad{\\spad{Si}(f)} denotes the sine integral")) (|Ei| ((|#2| |#2|) "\\spad{\\spad{Ei}(f)} denotes the exponential integral")) (|operator| (((|BasicOperator|) (|BasicOperator|)) "\\spad{operator(op)} returns the Liouvillian operator based on \\spad{op}")) (|belong?| (((|Boolean|) (|BasicOperator|)) "\\spad{belong?(op)} checks if \\spad{op} is Liouvillian"))) 
+((|constructor| (NIL "This package provides liouvillian functions over an integral domain.")) (|integral| ((|#2| |#2| (|SegmentBinding| |#2|)) "\\spad{integral(f,{}x = a..b)} denotes the definite integral of \\spad{f} with respect to \\spad{x} from \\spad{a} to \\spad{b}.") ((|#2| |#2| (|Symbol|)) "\\spad{integral(f,{}x)} indefinite integral of \\spad{f} with respect to \\spad{x}.")) (|fresnelC| ((|#2| |#2|) "\\spad{fresnelC(f)} denotes the Fresnel integral \\spad{C}")) (|fresnelS| ((|#2| |#2|) "\\spad{fresnelS(f)} denotes the Fresnel integral \\spad{S}")) (|dilog| ((|#2| |#2|) "\\spad{dilog(f)} denotes the dilogarithm")) (|erf| ((|#2| |#2|) "\\spad{erf(f)} denotes the error function")) (|li| ((|#2| |#2|) "\\spad{\\spad{li}(f)} denotes the logarithmic integral")) (|Ci| ((|#2| |#2|) "\\spad{\\spad{Ci}(f)} denotes the cosine integral")) (|Si| ((|#2| |#2|) "\\spad{\\spad{Si}(f)} denotes the sine integral")) (|Ei| ((|#2| |#2|) "\\spad{\\spad{Ei}(f)} denotes the exponential integral")) (|operator| (((|BasicOperator|) (|BasicOperator|)) "\\spad{operator(op)} returns the Liouvillian operator based on \\spad{op}")) (|belong?| (((|Boolean|) (|BasicOperator|)) "\\spad{belong?(op)} checks if \\spad{op} is Liouvillian"))) 
 NIL 
 NIL 
 (-622 |lv| -1478) 
@@ -2422,20 +2422,20 @@ NIL
 NIL 
 (-623) 
 ((|constructor| (NIL "This domain provides a simple way to save values in files.")) (|close!| (($ $) "\\spad{close!(f)} returns the library \\spad{f} closed to input and output.")) (|setelt| (((|Any|) $ (|Symbol|) (|Any|)) "\\spad{lib.k := v} saves the value \\spad{v} in the library \\spad{lib}. It can later be extracted using the key \\spad{k}.")) (|elt| (((|Any|) $ (|Symbol|)) "\\spad{elt(lib,{}k)} or \\spad{lib}.\\spad{k} extracts the value corresponding to the key \\spad{k} from the library \\spad{lib}.")) (|pack!| (($ $) "\\spad{pack!(f)} reorganizes the file \\spad{f} on disk to recover unused space.")) (|library| (($ (|FileName|)) "\\spad{library(ln)} creates a new library file."))) 
-((-4520 . T)) 
-((|HasCategory| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-1143) (QUOTE (-842))) (|HasCategory| (-57) (QUOTE (-1090))) (-12 (|HasCategory| (-57) (LIST (QUOTE -303) (QUOTE (-57)))) (|HasCategory| (-57) (QUOTE (-1090)))) (|HasCategory| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3649) (QUOTE (-1143))) (LIST (QUOTE |:|) (QUOTE -4083) (QUOTE (-57)))))) (|HasCategory| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (QUOTE (-1090)))) (-2198 (|HasCategory| (-57) (QUOTE (-1090))) (|HasCategory| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (QUOTE (-1090))))) 
+((-4522 . T)) 
+((|HasCategory| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-1143) (QUOTE (-842))) (|HasCategory| (-57) (QUOTE (-1090))) (-12 (|HasCategory| (-57) (LIST (QUOTE -303) (QUOTE (-57)))) (|HasCategory| (-57) (QUOTE (-1090)))) (|HasCategory| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3651) (QUOTE (-1143))) (LIST (QUOTE |:|) (QUOTE -4085) (QUOTE (-57)))))) (|HasCategory| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (QUOTE (-1090)))) (-2199 (|HasCategory| (-57) (QUOTE (-1090))) (|HasCategory| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (QUOTE (-1090))))) 
 (-624 S R) 
 ((|constructor| (NIL "The category of Lie Algebras. It is used by the domains of non-commutative algebra,{} LiePolynomial and XPBWPolynomial.")) (/ (($ $ |#2|) "\\axiom{\\spad{x/r}} returns the division of \\axiom{\\spad{x}} by \\axiom{\\spad{r}}.")) (|construct| (($ $ $) "\\axiom{construct(\\spad{x},{}\\spad{y})} returns the Lie bracket of \\axiom{\\spad{x}} and \\axiom{\\spad{y}}."))) 
 NIL 
 ((|HasCategory| |#2| (QUOTE (-365)))) 
 (-625 R) 
 ((|constructor| (NIL "The category of Lie Algebras. It is used by the domains of non-commutative algebra,{} LiePolynomial and XPBWPolynomial.")) (/ (($ $ |#1|) "\\axiom{\\spad{x/r}} returns the division of \\axiom{\\spad{x}} by \\axiom{\\spad{r}}.")) (|construct| (($ $ $) "\\axiom{construct(\\spad{x},{}\\spad{y})} returns the Lie bracket of \\axiom{\\spad{x}} and \\axiom{\\spad{y}}."))) 
-((|JacobiIdentity| . T) (|NullSquare| . T) (-4514 . T) (-4513 . T)) 
+((|JacobiIdentity| . T) (|NullSquare| . T) (-4516 . T) (-4515 . T)) 
 NIL 
 (-626 R A) 
 ((|constructor| (NIL "AssociatedLieAlgebra takes an algebra \\spad{A} and uses \\spadfun{*\\$A} to define the Lie bracket \\spad{a*b := (a *\\$A b - b *\\$A a)} (commutator). Note that the notation \\spad{[a,{}b]} cannot be used due to restrictions of the current compiler. This domain only gives a Lie algebra if the Jacobi-identity \\spad{(a*b)*c + (b*c)*a + (c*a)*b = 0} holds for all \\spad{a},{}\\spad{b},{}\\spad{c} in \\spad{A}. This relation can be checked by \\spad{lieAdmissible?()\\$A}. \\blankline If the underlying algebra is of type \\spadtype{FramedNonAssociativeAlgebra(R)} (\\spadignore{i.e.} a non associative algebra over \\spad{R} which is a free \\spad{R}-module of finite rank,{} together with a fixed \\spad{R}-module basis),{} then the same is \\spad{true} for the associated Lie algebra. Also,{} if the underlying algebra is of type \\spadtype{FiniteRankNonAssociativeAlgebra(R)} (\\spadignore{i.e.} a non associative algebra over \\spad{R} which is a free \\spad{R}-module of finite rank),{} then the same is \\spad{true} for the associated Lie algebra.")) (|coerce| (($ |#2|) "\\spad{coerce(a)} coerces the element \\spad{a} of the algebra \\spad{A} to an element of the Lie algebra \\spadtype{AssociatedLieAlgebra}(\\spad{R},{}A)."))) 
-((-4516 -2198 (-2139 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))) (-4514 . T) (-4513 . T)) 
-((|HasCategory| |#2| (LIST (QUOTE -419) (|devaluate| |#1|))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -419) (|devaluate| |#1|)))) (|HasCategory| |#2| (LIST (QUOTE -369) (|devaluate| |#1|))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -369) (|devaluate| |#1|))) (|HasCategory| |#2| (LIST (QUOTE -419) (|devaluate| |#1|)))) (-2198 (-12 (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#2| (LIST (QUOTE -369) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#2| (LIST (QUOTE -419) (|devaluate| |#1|)))))) 
+((-4518 -2199 (-2141 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))) (-4516 . T) (-4515 . T)) 
+((|HasCategory| |#2| (LIST (QUOTE -419) (|devaluate| |#1|))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -419) (|devaluate| |#1|)))) (|HasCategory| |#2| (LIST (QUOTE -369) (|devaluate| |#1|))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -369) (|devaluate| |#1|))) (|HasCategory| |#2| (LIST (QUOTE -419) (|devaluate| |#1|)))) (-2199 (-12 (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#2| (LIST (QUOTE -369) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#2| (LIST (QUOTE -419) (|devaluate| |#1|)))))) 
 (-627 R FE) 
 ((|constructor| (NIL "PowerSeriesLimitPackage implements limits of expressions in one or more variables as one of the variables approaches a limiting value. Included are two-sided limits,{} left- and right- hand limits,{} and limits at plus or minus infinity.")) (|complexLimit| (((|Union| (|OnePointCompletion| |#2|) "failed") |#2| (|Equation| (|OnePointCompletion| |#2|))) "\\spad{complexLimit(f(x),{}x = a)} computes the complex limit \\spad{lim(x -> a,{}f(x))}.")) (|limit| (((|Union| (|OrderedCompletion| |#2|) "failed") |#2| (|Equation| |#2|) (|String|)) "\\spad{limit(f(x),{}x=a,{}\"left\")} computes the left hand real limit \\spad{lim(x -> a-,{}f(x))}; \\spad{limit(f(x),{}x=a,{}\"right\")} computes the right hand real limit \\spad{lim(x -> a+,{}f(x))}.") (((|Union| (|OrderedCompletion| |#2|) (|Record| (|:| |leftHandLimit| (|Union| (|OrderedCompletion| |#2|) "failed")) (|:| |rightHandLimit| (|Union| (|OrderedCompletion| |#2|) "failed"))) "failed") |#2| (|Equation| (|OrderedCompletion| |#2|))) "\\spad{limit(f(x),{}x = a)} computes the real limit \\spad{lim(x -> a,{}f(x))}."))) 
 NIL 
@@ -2447,10 +2447,10 @@ NIL
 (-629 S R) 
 ((|constructor| (NIL "Test for linear dependence.")) (|solveLinear| (((|Union| (|Vector| (|Fraction| |#1|)) "failed") (|Vector| |#2|) |#2|) "\\spad{solveLinear([v1,{}...,{}vn],{} u)} returns \\spad{[c1,{}...,{}cn]} such that \\spad{c1*v1 + ... + cn*vn = u},{} \"failed\" if no such \\spad{ci}\\spad{'s} exist in the quotient field of \\spad{S}.") (((|Union| (|Vector| |#1|) "failed") (|Vector| |#2|) |#2|) "\\spad{solveLinear([v1,{}...,{}vn],{} u)} returns \\spad{[c1,{}...,{}cn]} such that \\spad{c1*v1 + ... + cn*vn = u},{} \"failed\" if no such \\spad{ci}\\spad{'s} exist in \\spad{S}.")) (|linearDependence| (((|Union| (|Vector| |#1|) "failed") (|Vector| |#2|)) "\\spad{linearDependence([v1,{}...,{}vn])} returns \\spad{[c1,{}...,{}cn]} if \\spad{c1*v1 + ... + cn*vn = 0} and not all the \\spad{ci}\\spad{'s} are 0,{} \"failed\" if the \\spad{vi}\\spad{'s} are linearly independent over \\spad{S}.")) (|linearlyDependent?| (((|Boolean|) (|Vector| |#2|)) "\\spad{linearlyDependent?([v1,{}...,{}vn])} returns \\spad{true} if the \\spad{vi}\\spad{'s} are linearly dependent over \\spad{S},{} \\spad{false} otherwise."))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-365))) (-3044 (|HasCategory| |#1| (QUOTE (-365))))) 
+((|HasCategory| |#1| (QUOTE (-365))) (-3046 (|HasCategory| |#1| (QUOTE (-365))))) 
 (-630 R) 
 ((|constructor| (NIL "An extension ring with an explicit linear dependence test.")) (|reducedSystem| (((|Record| (|:| |mat| (|Matrix| |#1|)) (|:| |vec| (|Vector| |#1|))) (|Matrix| $) (|Vector| $)) "\\spad{reducedSystem(A,{} v)} returns a matrix \\spad{B} and a vector \\spad{w} such that \\spad{A x = v} and \\spad{B x = w} have the same solutions in \\spad{R}.") (((|Matrix| |#1|) (|Matrix| $)) "\\spad{reducedSystem(A)} returns a matrix \\spad{B} such that \\spad{A x = 0} and \\spad{B x = 0} have the same solutions in \\spad{R}."))) 
-((-4516 . T)) 
+((-4518 . T)) 
 NIL 
 (-631 A B) 
 ((|constructor| (NIL "\\spadtype{ListToMap} allows mappings to be described by a pair of lists of equal lengths. The image of an element \\spad{x},{} which appears in position \\spad{n} in the first list,{} is then the \\spad{n}th element of the second list. A default value or default function can be specified to be used when \\spad{x} does not appear in the first list. In the absence of defaults,{} an error will occur in that case.")) (|match| ((|#2| (|List| |#1|) (|List| |#2|) |#1| (|Mapping| |#2| |#1|)) "\\spad{match(la,{} lb,{} a,{} f)} creates a map defined by lists \\spad{la} and \\spad{lb} of equal length. and applies this map to a. The target of a source value \\spad{x} in \\spad{la} is the value \\spad{y} with the same index \\spad{lb}. Argument \\spad{f} is a default function to call if a is not in \\spad{la}. The value returned is then obtained by applying \\spad{f} to argument a.") (((|Mapping| |#2| |#1|) (|List| |#1|) (|List| |#2|) (|Mapping| |#2| |#1|)) "\\spad{match(la,{} lb,{} f)} creates a map defined by lists \\spad{la} and \\spad{lb} of equal length. The target of a source value \\spad{x} in \\spad{la} is the value \\spad{y} with the same index \\spad{lb}. Argument \\spad{f} is used as the function to call when the given function argument is not in \\spad{la}. The value returned is \\spad{f} applied to that argument.") ((|#2| (|List| |#1|) (|List| |#2|) |#1| |#2|) "\\spad{match(la,{} lb,{} a,{} b)} creates a map defined by lists \\spad{la} and \\spad{lb} of equal length. and applies this map to a. The target of a source value \\spad{x} in \\spad{la} is the value \\spad{y} with the same index \\spad{lb}. Argument \\spad{b} is the default target value if a is not in \\spad{la}. Error: if \\spad{la} and \\spad{lb} are not of equal length.") (((|Mapping| |#2| |#1|) (|List| |#1|) (|List| |#2|) |#2|) "\\spad{match(la,{} lb,{} b)} creates a map defined by lists \\spad{la} and \\spad{lb} of equal length,{} where \\spad{b} is used as the default target value if the given function argument is not in \\spad{la}. The target of a source value \\spad{x} in \\spad{la} is the value \\spad{y} with the same index \\spad{lb}. Error: if \\spad{la} and \\spad{lb} are not of equal length.") ((|#2| (|List| |#1|) (|List| |#2|) |#1|) "\\spad{match(la,{} lb,{} a)} creates a map defined by lists \\spad{la} and \\spad{lb} of equal length,{} where \\spad{a} is used as the default source value if the given one is not in \\spad{la}. The target of a source value \\spad{x} in \\spad{la} is the value \\spad{y} with the same index \\spad{lb}. Error: if \\spad{la} and \\spad{lb} are not of equal length.") (((|Mapping| |#2| |#1|) (|List| |#1|) (|List| |#2|)) "\\spad{match(la,{} lb)} creates a map with no default source or target values defined by lists \\spad{la} and \\spad{lb} of equal length. The target of a source value \\spad{x} in \\spad{la} is the value \\spad{y} with the same index \\spad{lb}. Error: if \\spad{la} and \\spad{lb} are not of equal length. Note that when this map is applied,{} an error occurs when applied to a value missing from \\spad{la}."))) 
@@ -2466,15 +2466,15 @@ NIL
 NIL 
 (-634 S) 
 ((|constructor| (NIL "\\spadtype{List} implements singly-linked lists that are addressable by indices; the index of the first element is 1. In addition to the operations provided by \\spadtype{IndexedList},{} this constructor provides some LISP-like functions such as \\spadfun{null} and \\spadfun{cons}.")) (|setDifference| (($ $ $) "\\spad{setDifference(u1,{}u2)} returns a list of the elements of \\spad{u1} that are not also in \\spad{u2}. The order of elements in the resulting list is unspecified.")) (|setIntersection| (($ $ $) "\\spad{setIntersection(u1,{}u2)} returns a list of the elements that lists \\spad{u1} and \\spad{u2} have in common. The order of elements in the resulting list is unspecified.")) (|setUnion| (($ $ $) "\\spad{setUnion(u1,{}u2)} appends the two lists \\spad{u1} and \\spad{u2},{} then removes all duplicates. The order of elements in the resulting list is unspecified.")) (|append| (($ $ $) "\\spad{append(u1,{}u2)} appends the elements of list \\spad{u1} onto the front of list \\spad{u2}. This new list and \\spad{u2} will share some structure.")) (|cons| (($ |#1| $) "\\spad{cons(element,{}u)} appends \\spad{element} onto the front of list \\spad{u} and returns the new list. This new list and the old one will share some structure.")) (|null| (((|Boolean|) $) "\\spad{null(u)} tests if list \\spad{u} is the empty list.")) (|nil| (($) "\\spad{nil()} returns the empty list."))) 
-((-4520 . T) (-4519 . T)) 
-((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (-2198 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-823))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
+((-4522 . T) (-4521 . T)) 
+((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (-2199 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-823))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
 (-635 K PCS) 
 ((|constructor| (NIL "Part of the PAFF package")) (|finiteSeries2LinSys| (((|Matrix| |#1|) (|List| |#2|) (|Integer|)) "\\spad{finiteSeries2LinSys(ls,{}n)} returns a matrix which right kernel is the solution of the linear combinations of the series in \\spad{ls} which has order greater or equal to \\spad{n}. NOTE: All the series in \\spad{ls} must be finite and must have order at least 0: so one must first call on each of them the function filterUpTo(\\spad{s},{}\\spad{n}) and apply an appropriate shift (mult by a power of \\spad{t})."))) 
 NIL 
 NIL 
 (-636 S) 
 ((|constructor| (NIL "The \\spadtype{ListMultiDictionary} domain implements a dictionary with duplicates allowed. The representation is a list with duplicates represented explicitly. Hence most operations will be relatively inefficient when the number of entries in the dictionary becomes large. If the objects in the dictionary belong to an ordered set,{} the entries are maintained in ascending order.")) (|substitute| (($ |#1| |#1| $) "\\spad{substitute(x,{}y,{}d)} replace \\spad{x}\\spad{'s} with \\spad{y}\\spad{'s} in dictionary \\spad{d}.")) (|duplicates?| (((|Boolean|) $) "\\spad{duplicates?(d)} tests if dictionary \\spad{d} has duplicate entries."))) 
-((-4519 . T) (-4520 . T)) 
+((-4521 . T) (-4522 . T)) 
 ((|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541))))) 
 (-637 R) 
 ((|constructor| (NIL "The category of left modules over an \\spad{rng} (ring not necessarily with unit). This is an abelian group which supports left multiplation by elements of the \\spad{rng}. \\blankline Axioms\\spad{\\br} \\tab{5}\\spad{ (a*b)*x = a*(b*x) }\\spad{\\br} \\tab{5}\\spad{ (a+b)*x = (a*x)+(b*x) }\\spad{\\br} \\tab{5}\\spad{ a*(x+y) = (a*x)+(a*y) }")) (* (($ |#1| $) "\\spad{r*x} returns the left multiplication of the module element \\spad{x} by the ring element \\spad{r}."))) 
@@ -2487,14 +2487,14 @@ NIL
 (-639 A S) 
 ((|constructor| (NIL "A linear aggregate is an aggregate whose elements are indexed by integers. Examples of linear aggregates are strings,{} lists,{} and arrays. Most of the exported operations for linear aggregates are non-destructive but are not always efficient for a particular aggregate. For example,{} \\spadfun{concat} of two lists needs only to copy its first argument,{} whereas \\spadfun{concat} of two arrays needs to copy both arguments. Most of the operations exported here apply to infinite objects (\\spadignore{e.g.} streams) as well to finite ones. For finite linear aggregates,{} see \\spadtype{FiniteLinearAggregate}.")) (|setelt| ((|#2| $ (|UniversalSegment| (|Integer|)) |#2|) "\\spad{setelt(u,{}i..j,{}x)} (also written: \\axiom{\\spad{u}(\\spad{i}..\\spad{j}) \\spad{:=} \\spad{x}}) destructively replaces each element in the segment \\axiom{\\spad{u}(\\spad{i}..\\spad{j})} by \\spad{x}. The value \\spad{x} is returned. Note that \\spad{u} is destructively change so that \\axiom{\\spad{u}.\\spad{k} \\spad{:=} \\spad{x} for \\spad{k} in \\spad{i}..\\spad{j}}; its length remains unchanged.")) (|insert| (($ $ $ (|Integer|)) "\\spad{insert(v,{}u,{}k)} returns a copy of \\spad{u} having \\spad{v} inserted beginning at the \\axiom{\\spad{i}}th element. Note that \\axiom{insert(\\spad{v},{}\\spad{u},{}\\spad{k}) = concat( \\spad{u}(0..\\spad{k}-1),{} \\spad{v},{} \\spad{u}(\\spad{k}..) )}.") (($ |#2| $ (|Integer|)) "\\spad{insert(x,{}u,{}i)} returns a copy of \\spad{u} having \\spad{x} as its \\axiom{\\spad{i}}th element. Note that \\axiom{insert(\\spad{x},{}a,{}\\spad{k}) = concat(concat(a(0..\\spad{k}-1),{}\\spad{x}),{}a(\\spad{k}..))}.")) (|delete| (($ $ (|UniversalSegment| (|Integer|))) "\\spad{delete(u,{}i..j)} returns a copy of \\spad{u} with the \\axiom{\\spad{i}}th through \\axiom{\\spad{j}}th element deleted. Note that \\axiom{delete(a,{}\\spad{i}..\\spad{j}) = concat(a(0..\\spad{i}-1),{}a(\\spad{j+1}..))}.") (($ $ (|Integer|)) "\\spad{delete(u,{}i)} returns a copy of \\spad{u} with the \\axiom{\\spad{i}}th element deleted. Note that for lists,{} \\axiom{delete(a,{}\\spad{i}) \\spad{==} concat(a(0..\\spad{i} - 1),{}a(\\spad{i} + 1,{}..))}.")) (|elt| (($ $ (|UniversalSegment| (|Integer|))) "\\spad{elt(u,{}i..j)} (also written: \\axiom{a(\\spad{i}..\\spad{j})}) returns the aggregate of elements \\axiom{\\spad{u}} for \\spad{k} from \\spad{i} to \\spad{j} in that order. Note that in general,{} \\axiom{a.\\spad{s} = [a.\\spad{k} for \\spad{i} in \\spad{s}]}.")) (|map| (($ (|Mapping| |#2| |#2| |#2|) $ $) "\\spad{map(f,{}u,{}v)} returns a new collection \\spad{w} with elements \\axiom{\\spad{z} = \\spad{f}(\\spad{x},{}\\spad{y})} for corresponding elements \\spad{x} and \\spad{y} from \\spad{u} and \\spad{v}. Note that for linear aggregates,{} \\axiom{\\spad{w}.\\spad{i} = \\spad{f}(\\spad{u}.\\spad{i},{}\\spad{v}.\\spad{i})}.")) (|concat| (($ (|List| $)) "\\spad{concat(u)},{} where \\spad{u} is a lists of aggregates \\axiom{[a,{}\\spad{b},{}...,{}\\spad{c}]},{} returns a single aggregate consisting of the elements of \\axiom{a} followed by those of \\spad{b} followed ... by the elements of \\spad{c}. Note that \\axiom{concat(a,{}\\spad{b},{}...,{}\\spad{c}) = concat(a,{}concat(\\spad{b},{}...,{}\\spad{c}))}.") (($ $ $) "\\spad{concat(u,{}v)} returns an aggregate consisting of the elements of \\spad{u} followed by the elements of \\spad{v}. Note that if \\axiom{\\spad{w} = concat(\\spad{u},{}\\spad{v})} then \\axiom{\\spad{w}.\\spad{i} = \\spad{u}.\\spad{i} for \\spad{i} in indices \\spad{u}} and \\axiom{\\spad{w}.(\\spad{j} + maxIndex \\spad{u}) = \\spad{v}.\\spad{j} for \\spad{j} in indices \\spad{v}}.") (($ |#2| $) "\\spad{concat(x,{}u)} returns aggregate \\spad{u} with additional element at the front. Note that for lists: \\axiom{concat(\\spad{x},{}\\spad{u}) \\spad{==} concat([\\spad{x}],{}\\spad{u})}.") (($ $ |#2|) "\\spad{concat(u,{}x)} returns aggregate \\spad{u} with additional element \\spad{x} at the end. Note that for lists,{} \\axiom{concat(\\spad{u},{}\\spad{x}) \\spad{==} concat(\\spad{u},{}[\\spad{x}])}")) (|new| (($ (|NonNegativeInteger|) |#2|) "\\spad{new(n,{}x)} returns \\axiom{fill!(new \\spad{n},{}\\spad{x})}."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE -4520))) 
+((|HasAttribute| |#1| (QUOTE -4522))) 
 (-640 S) 
 ((|constructor| (NIL "A linear aggregate is an aggregate whose elements are indexed by integers. Examples of linear aggregates are strings,{} lists,{} and arrays. Most of the exported operations for linear aggregates are non-destructive but are not always efficient for a particular aggregate. For example,{} \\spadfun{concat} of two lists needs only to copy its first argument,{} whereas \\spadfun{concat} of two arrays needs to copy both arguments. Most of the operations exported here apply to infinite objects (\\spadignore{e.g.} streams) as well to finite ones. For finite linear aggregates,{} see \\spadtype{FiniteLinearAggregate}.")) (|setelt| ((|#1| $ (|UniversalSegment| (|Integer|)) |#1|) "\\spad{setelt(u,{}i..j,{}x)} (also written: \\axiom{\\spad{u}(\\spad{i}..\\spad{j}) \\spad{:=} \\spad{x}}) destructively replaces each element in the segment \\axiom{\\spad{u}(\\spad{i}..\\spad{j})} by \\spad{x}. The value \\spad{x} is returned. Note that \\spad{u} is destructively change so that \\axiom{\\spad{u}.\\spad{k} \\spad{:=} \\spad{x} for \\spad{k} in \\spad{i}..\\spad{j}}; its length remains unchanged.")) (|insert| (($ $ $ (|Integer|)) "\\spad{insert(v,{}u,{}k)} returns a copy of \\spad{u} having \\spad{v} inserted beginning at the \\axiom{\\spad{i}}th element. Note that \\axiom{insert(\\spad{v},{}\\spad{u},{}\\spad{k}) = concat( \\spad{u}(0..\\spad{k}-1),{} \\spad{v},{} \\spad{u}(\\spad{k}..) )}.") (($ |#1| $ (|Integer|)) "\\spad{insert(x,{}u,{}i)} returns a copy of \\spad{u} having \\spad{x} as its \\axiom{\\spad{i}}th element. Note that \\axiom{insert(\\spad{x},{}a,{}\\spad{k}) = concat(concat(a(0..\\spad{k}-1),{}\\spad{x}),{}a(\\spad{k}..))}.")) (|delete| (($ $ (|UniversalSegment| (|Integer|))) "\\spad{delete(u,{}i..j)} returns a copy of \\spad{u} with the \\axiom{\\spad{i}}th through \\axiom{\\spad{j}}th element deleted. Note that \\axiom{delete(a,{}\\spad{i}..\\spad{j}) = concat(a(0..\\spad{i}-1),{}a(\\spad{j+1}..))}.") (($ $ (|Integer|)) "\\spad{delete(u,{}i)} returns a copy of \\spad{u} with the \\axiom{\\spad{i}}th element deleted. Note that for lists,{} \\axiom{delete(a,{}\\spad{i}) \\spad{==} concat(a(0..\\spad{i} - 1),{}a(\\spad{i} + 1,{}..))}.")) (|elt| (($ $ (|UniversalSegment| (|Integer|))) "\\spad{elt(u,{}i..j)} (also written: \\axiom{a(\\spad{i}..\\spad{j})}) returns the aggregate of elements \\axiom{\\spad{u}} for \\spad{k} from \\spad{i} to \\spad{j} in that order. Note that in general,{} \\axiom{a.\\spad{s} = [a.\\spad{k} for \\spad{i} in \\spad{s}]}.")) (|map| (($ (|Mapping| |#1| |#1| |#1|) $ $) "\\spad{map(f,{}u,{}v)} returns a new collection \\spad{w} with elements \\axiom{\\spad{z} = \\spad{f}(\\spad{x},{}\\spad{y})} for corresponding elements \\spad{x} and \\spad{y} from \\spad{u} and \\spad{v}. Note that for linear aggregates,{} \\axiom{\\spad{w}.\\spad{i} = \\spad{f}(\\spad{u}.\\spad{i},{}\\spad{v}.\\spad{i})}.")) (|concat| (($ (|List| $)) "\\spad{concat(u)},{} where \\spad{u} is a lists of aggregates \\axiom{[a,{}\\spad{b},{}...,{}\\spad{c}]},{} returns a single aggregate consisting of the elements of \\axiom{a} followed by those of \\spad{b} followed ... by the elements of \\spad{c}. Note that \\axiom{concat(a,{}\\spad{b},{}...,{}\\spad{c}) = concat(a,{}concat(\\spad{b},{}...,{}\\spad{c}))}.") (($ $ $) "\\spad{concat(u,{}v)} returns an aggregate consisting of the elements of \\spad{u} followed by the elements of \\spad{v}. Note that if \\axiom{\\spad{w} = concat(\\spad{u},{}\\spad{v})} then \\axiom{\\spad{w}.\\spad{i} = \\spad{u}.\\spad{i} for \\spad{i} in indices \\spad{u}} and \\axiom{\\spad{w}.(\\spad{j} + maxIndex \\spad{u}) = \\spad{v}.\\spad{j} for \\spad{j} in indices \\spad{v}}.") (($ |#1| $) "\\spad{concat(x,{}u)} returns aggregate \\spad{u} with additional element at the front. Note that for lists: \\axiom{concat(\\spad{x},{}\\spad{u}) \\spad{==} concat([\\spad{x}],{}\\spad{u})}.") (($ $ |#1|) "\\spad{concat(u,{}x)} returns aggregate \\spad{u} with additional element \\spad{x} at the end. Note that for lists,{} \\axiom{concat(\\spad{u},{}\\spad{x}) \\spad{==} concat(\\spad{u},{}[\\spad{x}])}")) (|new| (($ (|NonNegativeInteger|) |#1|) "\\spad{new(n,{}x)} returns \\axiom{fill!(new \\spad{n},{}\\spad{x})}."))) 
 ((-3973 . T)) 
 NIL 
 (-641 K) 
 ((|printInfo| (((|Boolean|)) "returns the value of the \\spad{printInfo} flag.") (((|Boolean|) (|Boolean|)) "\\spad{printInfo(b)} set a flag such that when \\spad{true} (\\spad{b} \\spad{<-} \\spad{true}) prints some information during some critical computation.")) (|coefOfFirstNonZeroTerm| ((|#1| $) "\\spad{coefOfFirstNonZeroTerm(s)} returns the first non zero coefficient of the series.")) (|filterUpTo| (($ $ (|Integer|)) "\\spad{filterUpTo(s,{}n)} returns the series consisting of the terms of \\spad{s} having degree strictly less than \\spad{n}.")) (|shift| (($ $ (|Integer|)) "\\spad{shift(s,{}n)} returns t**n * \\spad{s}")) (|series| (($ (|Integer|) |#1| $) "\\spad{series(e,{}c,{}s)} create the series c*t**e + \\spad{s}.")) (|removeZeroes| (($ $) "\\spad{removeZeroes(s)} removes the zero terms in \\spad{s}.") (($ (|Integer|) $) "\\spad{removeZeroes(n,{}s)} removes the zero terms in the first \\spad{n} terms of \\spad{s}.")) (|monomial2series| (($ (|List| $) (|List| (|NonNegativeInteger|)) (|Integer|)) "\\spad{monomial2series(ls,{}le,{}n)} returns t**n * reduce(\\spad{\"*\"},{}[\\spad{s} \\spad{**} \\spad{e} for \\spad{s} in \\spad{ls} for \\spad{e} in \\spad{le}])")) (|delay| (($ (|Mapping| $)) "\\spad{delay delayed} the computation of the next term of the series given by the input function.")) (|posExpnPart| (($ $) "\\spad{posExpnPart(s)} returns the series \\spad{s} less the terms with negative exponant.")) (|order| (((|Integer|) $) "\\spad{order(s)} returns the order of \\spad{s}."))) 
-(((-4521 "*") . T) (-4512 . T) (-4511 . T) (-4517 . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+(((-4523 "*") . T) (-4514 . T) (-4513 . T) (-4519 . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-642 R -1478 L) 
 ((|constructor| (NIL "\\spad{ElementaryFunctionLODESolver} provides the top-level functions for finding closed form solutions of linear ordinary differential equations and initial value problems.")) (|solve| (((|Union| |#2| "failed") |#3| |#2| (|Symbol|) |#2| (|List| |#2|)) "\\spad{solve(op,{} g,{} x,{} a,{} [y0,{}...,{}ym])} returns either the solution of the initial value problem \\spad{op y = g,{} y(a) = y0,{} y'(a) = y1,{}...} or \"failed\" if the solution cannot be found; \\spad{x} is the dependent variable.") (((|Union| (|Record| (|:| |particular| |#2|) (|:| |basis| (|List| |#2|))) "failed") |#3| |#2| (|Symbol|)) "\\spad{solve(op,{} g,{} x)} returns either a solution of the ordinary differential equation \\spad{op y = g} or \"failed\" if no non-trivial solution can be found; When found,{} the solution is returned in the form \\spad{[h,{} [b1,{}...,{}bm]]} where \\spad{h} is a particular solution and and \\spad{[b1,{}...bm]} are linearly independent solutions of the associated homogenuous equation \\spad{op y = 0}. A full basis for the solutions of the homogenuous equation is not always returned,{} only the solutions which were found; \\spad{x} is the dependent variable."))) 
@@ -2502,11 +2502,11 @@ NIL
 NIL 
 (-643 A) 
 ((|constructor| (NIL "\\spad{LinearOrdinaryDifferentialOperator1} defines a ring of differential operators with coefficients in a differential ring A. Multiplication of operators corresponds to functional composition:\\spad{\\br} \\spad{(L1 * L2).(f) = L1 L2 f}"))) 
-((-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4515 . T) (-4516 . T) (-4518 . T)) 
 ((|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-365)))) 
 (-644 A M) 
 ((|constructor| (NIL "\\spad{LinearOrdinaryDifferentialOperator2} defines a ring of differential operators with coefficients in a differential ring A and acting on an A-module \\spad{M}. Multiplication of operators corresponds to functional composition:\\spad{\\br} \\spad{(L1 * L2).(f) = L1 L2 f}")) (|differentiate| (($ $) "\\spad{differentiate(x)} returns the derivative of \\spad{x}"))) 
-((-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4515 . T) (-4516 . T) (-4518 . T)) 
 ((|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-365)))) 
 (-645 S A) 
 ((|constructor| (NIL "LinearOrdinaryDifferentialOperatorCategory is the category of differential operators with coefficients in a ring A with a given derivation. \\blankline Multiplication of operators corresponds to functional composition:\\spad{\\br} (\\spad{L1} * \\spad{L2}).(\\spad{f}) = \\spad{L1} \\spad{L2} \\spad{f}")) (|directSum| (($ $ $) "\\spad{directSum(a,{}b)} computes an operator \\spad{c} of minimal order such that the nullspace of \\spad{c} is generated by all the sums of a solution of \\spad{a} by a solution of \\spad{b}.")) (|symmetricSquare| (($ $) "\\spad{symmetricSquare(a)} computes \\spad{symmetricProduct(a,{}a)} using a more efficient method.")) (|symmetricPower| (($ $ (|NonNegativeInteger|)) "\\spad{symmetricPower(a,{}n)} computes an operator \\spad{c} of minimal order such that the nullspace of \\spad{c} is generated by all the products of \\spad{n} solutions of \\spad{a}.")) (|symmetricProduct| (($ $ $) "\\spad{symmetricProduct(a,{}b)} computes an operator \\spad{c} of minimal order such that the nullspace of \\spad{c} is generated by all the products of a solution of \\spad{a} by a solution of \\spad{b}.")) (|adjoint| (($ $) "\\spad{adjoint(a)} returns the adjoint operator of a.")) (D (($) "\\spad{D()} provides the operator corresponding to a derivation in the ring \\spad{A}."))) 
@@ -2514,15 +2514,15 @@ NIL
 ((|HasCategory| |#2| (QUOTE (-365)))) 
 (-646 A) 
 ((|constructor| (NIL "LinearOrdinaryDifferentialOperatorCategory is the category of differential operators with coefficients in a ring A with a given derivation. \\blankline Multiplication of operators corresponds to functional composition:\\spad{\\br} (\\spad{L1} * \\spad{L2}).(\\spad{f}) = \\spad{L1} \\spad{L2} \\spad{f}")) (|directSum| (($ $ $) "\\spad{directSum(a,{}b)} computes an operator \\spad{c} of minimal order such that the nullspace of \\spad{c} is generated by all the sums of a solution of \\spad{a} by a solution of \\spad{b}.")) (|symmetricSquare| (($ $) "\\spad{symmetricSquare(a)} computes \\spad{symmetricProduct(a,{}a)} using a more efficient method.")) (|symmetricPower| (($ $ (|NonNegativeInteger|)) "\\spad{symmetricPower(a,{}n)} computes an operator \\spad{c} of minimal order such that the nullspace of \\spad{c} is generated by all the products of \\spad{n} solutions of \\spad{a}.")) (|symmetricProduct| (($ $ $) "\\spad{symmetricProduct(a,{}b)} computes an operator \\spad{c} of minimal order such that the nullspace of \\spad{c} is generated by all the products of a solution of \\spad{a} by a solution of \\spad{b}.")) (|adjoint| (($ $) "\\spad{adjoint(a)} returns the adjoint operator of a.")) (D (($) "\\spad{D()} provides the operator corresponding to a derivation in the ring \\spad{A}."))) 
-((-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-647 -1478 UP) 
 ((|constructor| (NIL "\\spadtype{LinearOrdinaryDifferentialOperatorFactorizer} provides a factorizer for linear ordinary differential operators whose coefficients are rational functions.")) (|factor1| (((|List| (|LinearOrdinaryDifferentialOperator1| (|Fraction| |#2|))) (|LinearOrdinaryDifferentialOperator1| (|Fraction| |#2|))) "\\spad{factor1(a)} returns the factorisation of a,{} assuming that a has no first-order right factor.")) (|factor| (((|List| (|LinearOrdinaryDifferentialOperator1| (|Fraction| |#2|))) (|LinearOrdinaryDifferentialOperator1| (|Fraction| |#2|))) "\\spad{factor(a)} returns the factorisation of a.") (((|List| (|LinearOrdinaryDifferentialOperator1| (|Fraction| |#2|))) (|LinearOrdinaryDifferentialOperator1| (|Fraction| |#2|)) (|Mapping| (|List| |#1|) |#2|)) "\\spad{factor(a,{} zeros)} returns the factorisation of a. \\spad{zeros} is a zero finder in \\spad{UP}."))) 
 NIL 
 ((|HasCategory| |#1| (QUOTE (-27)))) 
-(-648 A -2060) 
+(-648 A -1571) 
 ((|constructor| (NIL "\\spad{LinearOrdinaryDifferentialOperator} defines a ring of differential operators with coefficients in a ring A with a given derivation. Multiplication of operators corresponds to functional composition:\\spad{\\br} \\spad{(L1 * L2).(f) = L1 L2 f}"))) 
-((-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4515 . T) (-4516 . T) (-4518 . T)) 
 ((|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-365)))) 
 (-649 A L) 
 ((|constructor| (NIL "\\spad{LinearOrdinaryDifferentialOperatorsOps} provides symmetric products and sums for linear ordinary differential operators.")) (|directSum| ((|#2| |#2| |#2| (|Mapping| |#1| |#1|)) "\\spad{directSum(a,{}b,{}D)} computes an operator \\spad{c} of minimal order such that the nullspace of \\spad{c} is generated by all the sums of a solution of \\spad{a} by a solution of \\spad{b}. \\spad{D} is the derivation to use.")) (|symmetricPower| ((|#2| |#2| (|NonNegativeInteger|) (|Mapping| |#1| |#1|)) "\\spad{symmetricPower(a,{}n,{}D)} computes an operator \\spad{c} of minimal order such that the nullspace of \\spad{c} is generated by all the products of \\spad{n} solutions of \\spad{a}. \\spad{D} is the derivation to use.")) (|symmetricProduct| ((|#2| |#2| |#2| (|Mapping| |#1| |#1|)) "\\spad{symmetricProduct(a,{}b,{}D)} computes an operator \\spad{c} of minimal order such that the nullspace of \\spad{c} is generated by all the products of a solution of \\spad{a} by a solution of \\spad{b}. \\spad{D} is the derivation to use."))) 
@@ -2538,7 +2538,7 @@ NIL
 NIL 
 (-652 M R S) 
 ((|constructor| (NIL "Localize(\\spad{M},{}\\spad{R},{}\\spad{S}) produces fractions with numerators from an \\spad{R} module \\spad{M} and denominators from some multiplicative subset \\spad{D} of \\spad{R}.")) (|denom| ((|#3| $) "\\spad{denom x} returns the denominator of \\spad{x}.")) (|numer| ((|#1| $) "\\spad{numer x} returns the numerator of \\spad{x}.")) (/ (($ |#1| |#3|) "\\spad{m / d} divides the element \\spad{m} by \\spad{d}.") (($ $ |#3|) "\\spad{x / d} divides the element \\spad{x} by \\spad{d}."))) 
-((-4514 . T) (-4513 . T)) 
+((-4516 . T) (-4515 . T)) 
 ((|HasCategory| |#1| (QUOTE (-786)))) 
 (-653 K) 
 ((|constructor| (NIL "A package that exports several linear algebra operations over lines of matrices. Part of the PAFF package.")) (|reduceRowOnList| (((|List| (|List| |#1|)) (|List| |#1|) (|List| (|List| |#1|))) "\\spad{reduceRowOnList(v,{}lvec)} applies a row reduction on each of the element of \\spad{lv} using \\spad{v} according to a pivot in \\spad{v} which is set to be the first non nul element in \\spad{v}.")) (|reduceLineOverLine| (((|List| |#1|) (|List| |#1|) (|List| |#1|) |#1|) "\\spad{reduceLineOverLine(v1,{}v2,{}a)} returns \\spad{v1}-\\spad{a*v1} where \\indented{1}{\\spad{v1} and \\spad{v2} are considered as vector space.}")) (|quotVecSpaceBasis| (((|List| (|List| |#1|)) (|List| (|List| |#1|)) (|List| (|List| |#1|))) "\\spad{quotVecSpaceBasis(b1,{}b2)} returns a basis of \\spad{V1/V2} where \\spad{V1} and \\spad{V2} are vector space with basis \\spad{b1} and \\spad{b2} resp. and \\spad{V2} is suppose to be include in \\spad{V1}; Note that if it is not the case then it returs the basis of V1/W where \\spad{W} = intersection of \\spad{V1} and \\spad{V2}")) (|reduceRow| (((|List| (|List| |#1|)) (|List| (|List| |#1|))) "reduceRow: if the input is considered as a matrix,{} the output would be the row reduction matrix. It\\spad{'s} almost the rowEchelon form except that no permution of lines is performed."))) 
@@ -2554,7 +2554,7 @@ NIL
 NIL 
 (-656 |VarSet| R) 
 ((|constructor| (NIL "This type supports Lie polynomials in Lyndon basis see Free Lie Algebras by \\spad{C}. Reutenauer (Oxford science publications).")) (|construct| (($ $ (|LyndonWord| |#1|)) "\\axiom{construct(\\spad{x},{}\\spad{y})} returns the Lie bracket \\axiom{[\\spad{x},{}\\spad{y}]}.") (($ (|LyndonWord| |#1|) $) "\\axiom{construct(\\spad{x},{}\\spad{y})} returns the Lie bracket \\axiom{[\\spad{x},{}\\spad{y}]}.") (($ (|LyndonWord| |#1|) (|LyndonWord| |#1|)) "\\axiom{construct(\\spad{x},{}\\spad{y})} returns the Lie bracket \\axiom{[\\spad{x},{}\\spad{y}]}.")) (|LiePolyIfCan| (((|Union| $ "failed") (|XDistributedPolynomial| |#1| |#2|)) "\\axiom{LiePolyIfCan(\\spad{p})} returns \\axiom{\\spad{p}} in Lyndon basis if \\axiom{\\spad{p}} is a Lie polynomial,{} otherwise \\axiom{\"failed\"} is returned."))) 
-((|JacobiIdentity| . T) (|NullSquare| . T) (-4514 . T) (-4513 . T)) 
+((|JacobiIdentity| . T) (|NullSquare| . T) (-4516 . T) (-4515 . T)) 
 ((|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-172)))) 
 (-657 A S) 
 ((|constructor| (NIL "A list aggregate is a model for a linked list data structure. A linked list is a versatile data structure. Insertion and deletion are efficient and searching is a linear operation.")) (|list| (($ |#2|) "\\spad{list(x)} returns the list of one element \\spad{x}."))) 
@@ -2562,7 +2562,7 @@ NIL
 NIL 
 (-658 S) 
 ((|constructor| (NIL "A list aggregate is a model for a linked list data structure. A linked list is a versatile data structure. Insertion and deletion are efficient and searching is a linear operation.")) (|list| (($ |#1|) "\\spad{list(x)} returns the list of one element \\spad{x}."))) 
-((-4520 . T) (-4519 . T) (-3973 . T)) 
+((-4522 . T) (-4521 . T) (-3973 . T)) 
 NIL 
 (-659 -1478) 
 ((|constructor| (NIL "This package solves linear system in the matrix form \\spad{AX = B}. It is essentially a particular instantiation of the package \\spadtype{LinearSystemMatrixPackage} for Matrix and Vector. This package\\spad{'s} existence makes it easier to use \\spadfun{solve} in the AXIOM interpreter.")) (|rank| (((|NonNegativeInteger|) (|Matrix| |#1|) (|Vector| |#1|)) "\\spad{rank(A,{}B)} computes the rank of the complete matrix \\spad{(A|B)} of the linear system \\spad{AX = B}.")) (|hasSolution?| (((|Boolean|) (|Matrix| |#1|) (|Vector| |#1|)) "\\spad{hasSolution?(A,{}B)} tests if the linear system \\spad{AX = B} has a solution.")) (|particularSolution| (((|Union| (|Vector| |#1|) "failed") (|Matrix| |#1|) (|Vector| |#1|)) "\\spad{particularSolution(A,{}B)} finds a particular solution of the linear system \\spad{AX = B}.")) (|solve| (((|List| (|Record| (|:| |particular| (|Union| (|Vector| |#1|) "failed")) (|:| |basis| (|List| (|Vector| |#1|))))) (|List| (|List| |#1|)) (|List| (|Vector| |#1|))) "\\spad{solve(A,{}LB)} finds a particular soln of the systems \\spad{AX = B} and a basis of the associated homogeneous systems \\spad{AX = 0} where \\spad{B} varies in the list of column vectors \\spad{LB}.") (((|List| (|Record| (|:| |particular| (|Union| (|Vector| |#1|) "failed")) (|:| |basis| (|List| (|Vector| |#1|))))) (|Matrix| |#1|) (|List| (|Vector| |#1|))) "\\spad{solve(A,{}LB)} finds a particular soln of the systems \\spad{AX = B} and a basis of the associated homogeneous systems \\spad{AX = 0} where \\spad{B} varies in the list of column vectors \\spad{LB}.") (((|Record| (|:| |particular| (|Union| (|Vector| |#1|) "failed")) (|:| |basis| (|List| (|Vector| |#1|)))) (|List| (|List| |#1|)) (|Vector| |#1|)) "\\spad{solve(A,{}B)} finds a particular solution of the system \\spad{AX = B} and a basis of the associated homogeneous system \\spad{AX = 0}.") (((|Record| (|:| |particular| (|Union| (|Vector| |#1|) "failed")) (|:| |basis| (|List| (|Vector| |#1|)))) (|Matrix| |#1|) (|Vector| |#1|)) "\\spad{solve(A,{}B)} finds a particular solution of the system \\spad{AX = B} and a basis of the associated homogeneous system \\spad{AX = 0}."))) 
@@ -2578,8 +2578,8 @@ NIL
 NIL 
 (-662 |n| R) 
 ((|constructor| (NIL "LieSquareMatrix(\\spad{n},{}\\spad{R}) implements the Lie algebra of the \\spad{n} by \\spad{n} matrices over the commutative ring \\spad{R}. The Lie bracket (commutator) of the algebra is given by\\spad{\\br} \\spad{a*b := (a *\\$SQMATRIX(n,{}R) b - b *\\$SQMATRIX(n,{}R) a)},{}\\spad{\\br} where \\spadfun{*\\$SQMATRIX(\\spad{n},{}\\spad{R})} is the usual matrix multiplication."))) 
-((-4516 . T) (-4519 . T) (-4513 . T) (-4514 . T)) 
-((|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-225))) (|HasAttribute| |#2| (QUOTE (-4521 "*"))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-301))) (|HasCategory| |#2| (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-558))) (-2198 (|HasAttribute| |#2| (QUOTE (-4521 "*"))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090))))) (|HasCategory| |#2| (QUOTE (-172)))) 
+((-4518 . T) (-4521 . T) (-4515 . T) (-4516 . T)) 
+((|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-225))) (|HasAttribute| |#2| (QUOTE (-4523 "*"))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-301))) (|HasCategory| |#2| (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-558))) (-2199 (|HasAttribute| |#2| (QUOTE (-4523 "*"))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090))))) (|HasCategory| |#2| (QUOTE (-172)))) 
 (-663 |VarSet|) 
 ((|constructor| (NIL "Lyndon words over arbitrary (ordered) symbols: see Free Lie Algebras by \\spad{C}. Reutenauer (Oxford science publications). A Lyndon word is a word which is smaller than any of its right factors \\spad{w}.\\spad{r}.\\spad{t}. the pure lexicographical ordering. If \\axiom{a} and \\axiom{\\spad{b}} are two Lyndon words such that \\axiom{a < \\spad{b}} holds \\spad{w}.\\spad{r}.\\spad{t} lexicographical ordering then \\axiom{a*b} is a Lyndon word. Parenthesized Lyndon words can be generated from symbols by using the following rule:\\spad{\\br} \\axiom{[[a,{}\\spad{b}],{}\\spad{c}]} is a Lyndon word iff \\axiom{a*b < \\spad{c} \\spad{<=} \\spad{b}} holds.\\spad{\\br} Lyndon words are internally represented by binary trees using the \\spadtype{Magma} domain constructor. Two ordering are provided: lexicographic and length-lexicographic.")) (|LyndonWordsList| (((|List| $) (|List| |#1|) (|PositiveInteger|)) "\\axiom{LyndonWordsList(\\spad{vl},{} \\spad{n})} returns the list of Lyndon words over the alphabet \\axiom{\\spad{vl}},{} up to order \\axiom{\\spad{n}}.")) (|LyndonWordsList1| (((|OneDimensionalArray| (|List| $)) (|List| |#1|) (|PositiveInteger|)) "\\axiom{\\spad{LyndonWordsList1}(\\spad{vl},{} \\spad{n})} returns an array of lists of Lyndon words over the alphabet \\axiom{\\spad{vl}},{} up to order \\axiom{\\spad{n}}.")) (|varList| (((|List| |#1|) $) "\\axiom{varList(\\spad{x})} returns the list of distinct entries of \\axiom{\\spad{x}}.")) (|lyndonIfCan| (((|Union| $ "failed") (|OrderedFreeMonoid| |#1|)) "\\axiom{lyndonIfCan(\\spad{w})} convert \\axiom{\\spad{w}} into a Lyndon word.")) (|lyndon| (($ (|OrderedFreeMonoid| |#1|)) "\\axiom{lyndon(\\spad{w})} convert \\axiom{\\spad{w}} into a Lyndon word,{} error if \\axiom{\\spad{w}} is not a Lyndon word.")) (|lyndon?| (((|Boolean|) (|OrderedFreeMonoid| |#1|)) "\\axiom{lyndon?(\\spad{w})} test if \\axiom{\\spad{w}} is a Lyndon word.")) (|factor| (((|List| $) (|OrderedFreeMonoid| |#1|)) "\\axiom{factor(\\spad{x})} returns the decreasing factorization into Lyndon words.")) (|coerce| (((|Magma| |#1|) $) "\\axiom{coerce(\\spad{x})} returns the element of \\axiomType{Magma}(VarSet) corresponding to \\axiom{\\spad{x}}.") (((|OrderedFreeMonoid| |#1|) $) "\\axiom{coerce(\\spad{x})} returns the element of \\axiomType{OrderedFreeMonoid}(VarSet) corresponding to \\axiom{\\spad{x}}.")) (|lexico| (((|Boolean|) $ $) "\\axiom{lexico(\\spad{x},{}\\spad{y})} returns \\axiom{\\spad{true}} iff \\axiom{\\spad{x}} is smaller than \\axiom{\\spad{y}} \\spad{w}.\\spad{r}.\\spad{t}. the lexicographical ordering induced by \\axiom{VarSet}.")) (|length| (((|PositiveInteger|) $) "\\axiom{length(\\spad{x})} returns the number of entries in \\axiom{\\spad{x}}.")) (|right| (($ $) "\\axiom{right(\\spad{x})} returns right subtree of \\axiom{\\spad{x}} or error if retractable?(\\spad{x}) is \\spad{true}.")) (|left| (($ $) "\\axiom{left(\\spad{x})} returns left subtree of \\axiom{\\spad{x}} or error if retractable?(\\spad{x}) is \\spad{true}.")) (|retractable?| (((|Boolean|) $) "\\axiom{retractable?(\\spad{x})} tests if \\axiom{\\spad{x}} is a tree with only one entry."))) 
 NIL 
@@ -2595,7 +2595,7 @@ NIL
 (-666 R) 
 ((|constructor| (NIL "This domain represents three dimensional matrices over a general object type")) (|matrixDimensions| (((|Vector| (|NonNegativeInteger|)) $) "\\spad{matrixDimensions(x)} returns the dimensions of a matrix")) (|matrixConcat3D| (($ (|Symbol|) $ $) "\\spad{matrixConcat3D(s,{}x,{}y)} concatenates two 3-\\spad{D} matrices along a specified axis")) (|coerce| (((|PrimitiveArray| (|PrimitiveArray| (|PrimitiveArray| |#1|))) $) "\\spad{coerce(x)} moves from the domain to the representation type") (($ (|PrimitiveArray| (|PrimitiveArray| (|PrimitiveArray| |#1|)))) "\\spad{coerce(p)} moves from the representation type (PrimitiveArray PrimitiveArray PrimitiveArray \\spad{R}) to the domain")) (|setelt!| ((|#1| $ (|NonNegativeInteger|) (|NonNegativeInteger|) (|NonNegativeInteger|) |#1|) "\\spad{setelt!(x,{}i,{}j,{}k,{}s)} (or \\spad{x}.\\spad{i}.\\spad{j}.k:=s) sets a specific element of the array to some value of type \\spad{R}")) (|elt| ((|#1| $ (|NonNegativeInteger|) (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{elt(x,{}i,{}j,{}k)} extract an element from the matrix \\spad{x}")) (|construct| (($ (|List| (|List| (|List| |#1|)))) "\\spad{construct(lll)} creates a 3-\\spad{D} matrix from a List List List \\spad{R} \\spad{lll}")) (|plus| (($ $ $) "\\spad{plus(x,{}y)} adds two matrices,{} term by term we note that they must be the same size")) (|identityMatrix| (($ (|NonNegativeInteger|)) "\\spad{identityMatrix(n)} create an identity matrix we note that this must be square")) (|zeroMatrix| (($ (|NonNegativeInteger|) (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{zeroMatrix(i,{}j,{}k)} create a matrix with all zero terms"))) 
 NIL 
-((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (QUOTE (-1047))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1047)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
+((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (QUOTE (-1047))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1047)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
 (-667 |VarSet|) 
 ((|constructor| (NIL "This type is the basic representation of parenthesized words (binary trees over arbitrary symbols) useful in \\spadtype{LiePolynomial}.")) (|varList| (((|List| |#1|) $) "\\axiom{varList(\\spad{x})} returns the list of distinct entries of \\axiom{\\spad{x}}.")) (|right| (($ $) "\\axiom{right(\\spad{x})} returns right subtree of \\axiom{\\spad{x}} or error if retractable?(\\spad{x}) is \\spad{true}.")) (|retractable?| (((|Boolean|) $) "\\axiom{retractable?(\\spad{x})} tests if \\axiom{\\spad{x}} is a tree with only one entry.")) (|rest| (($ $) "\\axiom{rest(\\spad{x})} return \\axiom{\\spad{x}} without the first entry or error if retractable?(\\spad{x}) is \\spad{true}.")) (|mirror| (($ $) "\\axiom{mirror(\\spad{x})} returns the reversed word of \\axiom{\\spad{x}}. That is \\axiom{\\spad{x}} itself if retractable?(\\spad{x}) is \\spad{true} and \\axiom{mirror(\\spad{z}) * mirror(\\spad{y})} if \\axiom{\\spad{x}} is \\axiom{\\spad{y*z}}.")) (|lexico| (((|Boolean|) $ $) "\\axiom{lexico(\\spad{x},{}\\spad{y})} returns \\axiom{\\spad{true}} iff \\axiom{\\spad{x}} is smaller than \\axiom{\\spad{y}} \\spad{w}.\\spad{r}.\\spad{t}. the lexicographical ordering induced by \\axiom{VarSet}. \\spad{N}.\\spad{B}. This operation does not take into account the tree structure of its arguments. Thus this is not a total ordering.")) (|length| (((|PositiveInteger|) $) "\\axiom{length(\\spad{x})} returns the number of entries in \\axiom{\\spad{x}}.")) (|left| (($ $) "\\axiom{left(\\spad{x})} returns left subtree of \\axiom{\\spad{x}} or error if retractable?(\\spad{x}) is \\spad{true}.")) (|first| ((|#1| $) "\\axiom{first(\\spad{x})} returns the first entry of the tree \\axiom{\\spad{x}}.")) (|coerce| (((|OrderedFreeMonoid| |#1|) $) "\\indented{1}{\\axiom{coerce(\\spad{x})} returns the element of} \\axiomType{OrderedFreeMonoid}(VarSet) \\indented{1}{corresponding to \\axiom{\\spad{x}} by removing parentheses.}")) (* (($ $ $) "\\axiom{x*y} returns the tree \\axiom{[\\spad{x},{}\\spad{y}]}."))) 
 NIL 
@@ -2635,10 +2635,10 @@ NIL
 (-676 S R |Row| |Col|) 
 ((|constructor| (NIL "\\spadtype{MatrixCategory} is a general matrix category which allows different representations and indexing schemes. Rows and columns may be extracted with rows returned as objects of type Row and colums returned as objects of type Col. A domain belonging to this category will be shallowly mutable. The index of the 'first' row may be obtained by calling the function \\spadfun{minRowIndex}. The index of the 'first' column may be obtained by calling the function \\spadfun{minColIndex}. The index of the first element of a Row is the same as the index of the first column in a matrix and vice versa.")) (|inverse| (((|Union| $ "failed") $) "\\indented{1}{\\spad{inverse(m)} returns the inverse of the matrix \\spad{m}.} \\indented{1}{If the matrix is not invertible,{} \"failed\" is returned.} \\indented{1}{Error: if the matrix is not square.} \\blankline \\spad{X} inverse matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|pfaffian| ((|#2| $) "\\indented{1}{\\spad{pfaffian(m)} returns the Pfaffian of the matrix \\spad{m}.} \\indented{1}{Error if the matrix is not antisymmetric} \\blankline \\spad{X} pfaffian [[0,{}1,{}0,{}0],{}[\\spad{-1},{}0,{}0,{}0],{}[0,{}0,{}0,{}1],{}[0,{}0,{}\\spad{-1},{}0]]")) (|minordet| ((|#2| $) "\\indented{1}{\\spad{minordet(m)} computes the determinant of the matrix \\spad{m} using} \\indented{1}{minors. Error: if the matrix is not square.} \\blankline \\spad{X} minordet matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|determinant| ((|#2| $) "\\indented{1}{\\spad{determinant(m)} returns the determinant of the matrix \\spad{m}.} \\indented{1}{Error: if the matrix is not square.} \\blankline \\spad{X} determinant matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|nullSpace| (((|List| |#4|) $) "\\indented{1}{\\spad{nullSpace(m)} returns a basis for the null space of} \\indented{1}{the matrix \\spad{m}.} \\blankline \\spad{X} nullSpace matrix [[1,{}2,{}3],{}[4,{}5,{}6],{}[7,{}8,{}9]]")) (|nullity| (((|NonNegativeInteger|) $) "\\indented{1}{\\spad{nullity(m)} returns the nullity of the matrix \\spad{m}. This is} \\indented{1}{the dimension of the null space of the matrix \\spad{m}.} \\blankline \\spad{X} nullity matrix [[1,{}2,{}3],{}[4,{}5,{}6],{}[7,{}8,{}9]]")) (|rank| (((|NonNegativeInteger|) $) "\\indented{1}{\\spad{rank(m)} returns the rank of the matrix \\spad{m}.} \\blankline \\spad{X} rank matrix [[1,{}2,{}3],{}[4,{}5,{}6],{}[7,{}8,{}9]]")) (|columnSpace| (((|List| |#4|) $) "\\indented{1}{\\spad{columnSpace(m)} returns a sublist of columns of the matrix \\spad{m}} \\indented{1}{forming a basis of its column space} \\blankline \\spad{X} columnSpace matrix [[1,{}2,{}3],{}[4,{}5,{}6],{}[7,{}8,{}9],{}[1,{}1,{}1]]")) (|rowEchelon| (($ $) "\\indented{1}{\\spad{rowEchelon(m)} returns the row echelon form of the matrix \\spad{m}.} \\blankline \\spad{X} rowEchelon matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (/ (($ $ |#2|) "\\indented{1}{\\spad{m/r} divides the elements of \\spad{m} by \\spad{r}. Error: if \\spad{r = 0}.} \\blankline \\spad{X} m:=matrix [[2**i for \\spad{i} in 2..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m/4}")) (|exquo| (((|Union| $ "failed") $ |#2|) "\\indented{1}{\\spad{exquo(m,{}r)} computes the exact quotient of the elements} \\indented{1}{of \\spad{m} by \\spad{r},{} returning \\axiom{\"failed\"} if this is not possible.} \\blankline \\spad{X} m:=matrix [[2**i for \\spad{i} in 2..4] for \\spad{j} in 1..5] \\spad{X} exquo(\\spad{m},{}2)")) (** (($ $ (|Integer|)) "\\indented{1}{\\spad{m**n} computes an integral power of the matrix \\spad{m}.} \\indented{1}{Error: if matrix is not square or if the matrix} \\indented{1}{is square but not invertible.} \\blankline \\spad{X} (matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]) \\spad{**} 2") (($ $ (|NonNegativeInteger|)) "\\indented{1}{\\spad{x ** n} computes a non-negative integral power of the matrix \\spad{x}.} \\indented{1}{Error: if the matrix is not square.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m**3}")) (* ((|#3| |#3| $) "\\indented{1}{\\spad{r * x} is the product of the row vector \\spad{r} and the matrix \\spad{x}.} \\indented{1}{Error: if the dimensions are incompatible.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} r:=transpose([1,{}2,{}3,{}4,{}5])@Matrix(INT) \\spad{X} \\spad{r*m}") ((|#4| $ |#4|) "\\indented{1}{\\spad{x * c} is the product of the matrix \\spad{x} and the column vector \\spad{c}.} \\indented{1}{Error: if the dimensions are incompatible.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} c:=coerce([1,{}2,{}3,{}4,{}5])@Matrix(INT) \\spad{X} \\spad{m*c}") (($ (|Integer|) $) "\\indented{1}{\\spad{n * x} is an integer multiple.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} 3*m") (($ $ |#2|) "\\indented{1}{\\spad{x * r} is the right scalar multiple of the scalar \\spad{r} and the} \\indented{1}{matrix \\spad{x}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m*1/3}") (($ |#2| $) "\\indented{1}{\\spad{r*x} is the left scalar multiple of the scalar \\spad{r} and the} \\indented{1}{matrix \\spad{x}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} 1/3*m") (($ $ $) "\\indented{1}{\\spad{x * y} is the product of the matrices \\spad{x} and \\spad{y}.} \\indented{1}{Error: if the dimensions are incompatible.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m*m}")) (- (($ $) "\\indented{1}{\\spad{-x} returns the negative of the matrix \\spad{x}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{-m}") (($ $ $) "\\indented{1}{\\spad{x - y} is the difference of the matrices \\spad{x} and \\spad{y}.} \\indented{1}{Error: if the dimensions are incompatible.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m}-\\spad{m}")) (+ (($ $ $) "\\indented{1}{\\spad{x + y} is the sum of the matrices \\spad{x} and \\spad{y}.} \\indented{1}{Error: if the dimensions are incompatible.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m+m}")) (|setsubMatrix!| (($ $ (|Integer|) (|Integer|) $) "\\indented{1}{\\spad{setsubMatrix(x,{}i1,{}j1,{}y)} destructively alters the} \\indented{1}{matrix \\spad{x}. Here \\spad{x(i,{}j)} is set to \\spad{y(i-i1+1,{}j-j1+1)} for} \\indented{1}{\\spad{i = i1,{}...,{}i1-1+nrows y} and \\spad{j = j1,{}...,{}j1-1+ncols y}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} setsubMatrix!(\\spad{m},{}2,{}2,{}matrix [[3,{}3],{}[3,{}3]])")) (|subMatrix| (($ $ (|Integer|) (|Integer|) (|Integer|) (|Integer|)) "\\indented{1}{\\spad{subMatrix(x,{}i1,{}i2,{}j1,{}j2)} extracts the submatrix} \\indented{1}{\\spad{[x(i,{}j)]} where the index \\spad{i} ranges from \\spad{i1} to \\spad{i2}} \\indented{1}{and the index \\spad{j} ranges from \\spad{j1} to \\spad{j2}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} subMatrix(\\spad{m},{}1,{}3,{}2,{}4)")) (|swapColumns!| (($ $ (|Integer|) (|Integer|)) "\\indented{1}{\\spad{swapColumns!(m,{}i,{}j)} interchanges the \\spad{i}th and \\spad{j}th} \\indented{1}{columns of \\spad{m}. This destructively alters the matrix.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} swapColumns!(\\spad{m},{}2,{}4)")) (|swapRows!| (($ $ (|Integer|) (|Integer|)) "\\indented{1}{\\spad{swapRows!(m,{}i,{}j)} interchanges the \\spad{i}th and \\spad{j}th} \\indented{1}{rows of \\spad{m}. This destructively alters the matrix.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} swapRows!(\\spad{m},{}2,{}4)")) (|setelt| (($ $ (|List| (|Integer|)) (|List| (|Integer|)) $) "\\indented{1}{\\spad{setelt(x,{}rowList,{}colList,{}y)} destructively alters the matrix \\spad{x}.} \\indented{1}{If \\spad{y} is \\spad{m}-by-\\spad{n},{} \\spad{rowList = [i<1>,{}i<2>,{}...,{}i<m>]}} \\indented{1}{and \\spad{colList = [j<1>,{}j<2>,{}...,{}j<n>]},{} then \\spad{x(i<k>,{}j<l>)}} \\indented{1}{is set to \\spad{y(k,{}l)} for \\spad{k = 1,{}...,{}m} and \\spad{l = 1,{}...,{}n}} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} setelt(\\spad{m},{}3,{}3,{}10)")) (|elt| (($ $ (|List| (|Integer|)) (|List| (|Integer|))) "\\indented{1}{\\spad{elt(x,{}rowList,{}colList)} returns an \\spad{m}-by-\\spad{n} matrix consisting} \\indented{1}{of elements of \\spad{x},{} where \\spad{m = \\# rowList} and \\spad{n = \\# colList}} \\indented{1}{If \\spad{rowList = [i<1>,{}i<2>,{}...,{}i<m>]} and \\spad{colList =} \\indented{1}{[j<1>,{}j<2>,{}...,{}j<n>]},{} then the \\spad{(k,{}l)}th entry of} \\indented{1}{\\spad{elt(x,{}rowList,{}colList)} is \\spad{x(i<k>,{}j<l>)}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} elt(\\spad{m},{}3,{}3)")) (|listOfLists| (((|List| (|List| |#2|)) $) "\\indented{1}{\\spad{listOfLists(m)} returns the rows of the matrix \\spad{m} as a list} \\indented{1}{of lists.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} listOfLists \\spad{m}")) (|vertConcat| (($ $ $) "\\indented{1}{\\spad{vertConcat(x,{}y)} vertically concatenates two matrices with an} \\indented{1}{equal number of columns. The entries of \\spad{y} appear below} \\indented{1}{of the entries of \\spad{x}.\\space{2}Error: if the matrices} \\indented{1}{do not have the same number of columns.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} vertConcat(\\spad{m},{}\\spad{m})")) (|horizConcat| (($ $ $) "\\indented{1}{\\spad{horizConcat(x,{}y)} horizontally concatenates two matrices with} \\indented{1}{an equal number of rows. The entries of \\spad{y} appear to the right} \\indented{1}{of the entries of \\spad{x}.\\space{2}Error: if the matrices} \\indented{1}{do not have the same number of rows.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} horizConcat(\\spad{m},{}\\spad{m})")) (|squareTop| (($ $) "\\indented{1}{\\spad{squareTop(m)} returns an \\spad{n}-by-\\spad{n} matrix consisting of the first} \\indented{1}{\\spad{n} rows of the \\spad{m}-by-\\spad{n} matrix \\spad{m}. Error: if} \\indented{1}{\\spad{m < n}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..2] for \\spad{j} in 1..5] \\spad{X} squareTop \\spad{m}")) (|transpose| (($ $) "\\indented{1}{\\spad{transpose(m)} returns the transpose of the matrix \\spad{m}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} transpose \\spad{m}") (($ |#3|) "\\indented{1}{\\spad{transpose(r)} converts the row \\spad{r} to a row matrix.} \\blankline \\spad{X} transpose([1,{}2,{}3])@Matrix(INT)")) (|coerce| (($ |#4|) "\\indented{1}{\\spad{coerce(col)} converts the column col to a column matrix.} \\blankline \\spad{X} coerce([1,{}2,{}3])@Matrix(INT)")) (|diagonalMatrix| (($ (|List| $)) "\\indented{1}{\\spad{diagonalMatrix([m1,{}...,{}mk])} creates a block diagonal matrix} \\indented{1}{\\spad{M} with block matrices \\spad{m1},{}...,{}\\spad{mk} down the diagonal,{}} \\indented{1}{with 0 block matrices elsewhere.} \\indented{1}{More precisly: if \\spad{\\spad{ri} := nrows \\spad{mi}},{} \\spad{\\spad{ci} := ncols \\spad{mi}},{}} \\indented{1}{then \\spad{m} is an (\\spad{r1+}..\\spad{+rk}) by (\\spad{c1+}..\\spad{+ck}) - matrix\\space{2}with entries} \\indented{1}{\\spad{m.i.j = ml.(i-r1-..-r(l-1)).(j-n1-..-n(l-1))},{} if} \\indented{1}{\\spad{(r1+..+r(l-1)) < i <= r1+..+rl} and} \\indented{1}{\\spad{(c1+..+c(l-1)) < i <= c1+..+cl},{}} \\indented{1}{\\spad{m.i.j} = 0\\space{2}otherwise.} \\blankline \\spad{X} diagonalMatrix [matrix [[1,{}2],{}[3,{}4]],{} matrix [[4,{}5],{}[6,{}7]]]") (($ (|List| |#2|)) "\\indented{1}{\\spad{diagonalMatrix(l)} returns a diagonal matrix with the elements} \\indented{1}{of \\spad{l} on the diagonal.} \\blankline \\spad{X} diagonalMatrix [1,{}2,{}3]")) (|scalarMatrix| (($ (|NonNegativeInteger|) |#2|) "\\indented{1}{\\spad{scalarMatrix(n,{}r)} returns an \\spad{n}-by-\\spad{n} matrix with \\spad{r}\\spad{'s} on the} \\indented{1}{diagonal and zeroes elsewhere.} \\blankline \\spad{X} z:Matrix(INT):=scalarMatrix(3,{}5)")) (|matrix| (($ (|List| (|List| |#2|))) "\\indented{1}{\\spad{matrix(l)} converts the list of lists \\spad{l} to a matrix,{} where the} \\indented{1}{list of lists is viewed as a list of the rows of the matrix.} \\blankline \\spad{X} matrix [[1,{}2,{}3],{}[4,{}5,{}6],{}[7,{}8,{}9],{}[1,{}1,{}1]]")) (|zero| (($ (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\indented{1}{\\spad{zero(m,{}n)} returns an \\spad{m}-by-\\spad{n} zero matrix.} \\blankline \\spad{X} z:Matrix(INT):=zero(3,{}3)")) (|antisymmetric?| (((|Boolean|) $) "\\indented{1}{\\spad{antisymmetric?(m)} returns \\spad{true} if the matrix \\spad{m} is square and} \\indented{1}{antisymmetric (\\spadignore{i.e.} \\spad{m[i,{}j] = -m[j,{}i]} for all \\spad{i} and \\spad{j})} \\indented{1}{and \\spad{false} otherwise.} \\blankline \\spad{X} antisymmetric? matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|symmetric?| (((|Boolean|) $) "\\indented{1}{\\spad{symmetric?(m)} returns \\spad{true} if the matrix \\spad{m} is square and} \\indented{1}{symmetric (\\spadignore{i.e.} \\spad{m[i,{}j] = m[j,{}i]} for all \\spad{i} and \\spad{j}) and \\spad{false}} \\indented{1}{otherwise.} \\blankline \\spad{X} symmetric? matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|diagonal?| (((|Boolean|) $) "\\indented{1}{\\spad{diagonal?(m)} returns \\spad{true} if the matrix \\spad{m} is square and} \\indented{1}{diagonal (\\spadignore{i.e.} all entries of \\spad{m} not on the diagonal are zero) and} \\indented{1}{\\spad{false} otherwise.} \\blankline \\spad{X} diagonal? matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|square?| (((|Boolean|) $) "\\indented{1}{\\spad{square?(m)} returns \\spad{true} if \\spad{m} is a square matrix} \\indented{1}{(if \\spad{m} has the same number of rows as columns) and \\spad{false} otherwise.} \\blankline \\spad{X} square matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|finiteAggregate| ((|attribute|) "matrices are finite")) (|shallowlyMutable| ((|attribute|) "One may destructively alter matrices"))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-172))) (|HasAttribute| |#2| (QUOTE (-4521 "*"))) (|HasCategory| |#2| (QUOTE (-301))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-558)))) 
+((|HasCategory| |#2| (QUOTE (-172))) (|HasAttribute| |#2| (QUOTE (-4523 "*"))) (|HasCategory| |#2| (QUOTE (-301))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-558)))) 
 (-677 R |Row| |Col|) 
 ((|constructor| (NIL "\\spadtype{MatrixCategory} is a general matrix category which allows different representations and indexing schemes. Rows and columns may be extracted with rows returned as objects of type Row and colums returned as objects of type Col. A domain belonging to this category will be shallowly mutable. The index of the 'first' row may be obtained by calling the function \\spadfun{minRowIndex}. The index of the 'first' column may be obtained by calling the function \\spadfun{minColIndex}. The index of the first element of a Row is the same as the index of the first column in a matrix and vice versa.")) (|inverse| (((|Union| $ "failed") $) "\\indented{1}{\\spad{inverse(m)} returns the inverse of the matrix \\spad{m}.} \\indented{1}{If the matrix is not invertible,{} \"failed\" is returned.} \\indented{1}{Error: if the matrix is not square.} \\blankline \\spad{X} inverse matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|pfaffian| ((|#1| $) "\\indented{1}{\\spad{pfaffian(m)} returns the Pfaffian of the matrix \\spad{m}.} \\indented{1}{Error if the matrix is not antisymmetric} \\blankline \\spad{X} pfaffian [[0,{}1,{}0,{}0],{}[\\spad{-1},{}0,{}0,{}0],{}[0,{}0,{}0,{}1],{}[0,{}0,{}\\spad{-1},{}0]]")) (|minordet| ((|#1| $) "\\indented{1}{\\spad{minordet(m)} computes the determinant of the matrix \\spad{m} using} \\indented{1}{minors. Error: if the matrix is not square.} \\blankline \\spad{X} minordet matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|determinant| ((|#1| $) "\\indented{1}{\\spad{determinant(m)} returns the determinant of the matrix \\spad{m}.} \\indented{1}{Error: if the matrix is not square.} \\blankline \\spad{X} determinant matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|nullSpace| (((|List| |#3|) $) "\\indented{1}{\\spad{nullSpace(m)} returns a basis for the null space of} \\indented{1}{the matrix \\spad{m}.} \\blankline \\spad{X} nullSpace matrix [[1,{}2,{}3],{}[4,{}5,{}6],{}[7,{}8,{}9]]")) (|nullity| (((|NonNegativeInteger|) $) "\\indented{1}{\\spad{nullity(m)} returns the nullity of the matrix \\spad{m}. This is} \\indented{1}{the dimension of the null space of the matrix \\spad{m}.} \\blankline \\spad{X} nullity matrix [[1,{}2,{}3],{}[4,{}5,{}6],{}[7,{}8,{}9]]")) (|rank| (((|NonNegativeInteger|) $) "\\indented{1}{\\spad{rank(m)} returns the rank of the matrix \\spad{m}.} \\blankline \\spad{X} rank matrix [[1,{}2,{}3],{}[4,{}5,{}6],{}[7,{}8,{}9]]")) (|columnSpace| (((|List| |#3|) $) "\\indented{1}{\\spad{columnSpace(m)} returns a sublist of columns of the matrix \\spad{m}} \\indented{1}{forming a basis of its column space} \\blankline \\spad{X} columnSpace matrix [[1,{}2,{}3],{}[4,{}5,{}6],{}[7,{}8,{}9],{}[1,{}1,{}1]]")) (|rowEchelon| (($ $) "\\indented{1}{\\spad{rowEchelon(m)} returns the row echelon form of the matrix \\spad{m}.} \\blankline \\spad{X} rowEchelon matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (/ (($ $ |#1|) "\\indented{1}{\\spad{m/r} divides the elements of \\spad{m} by \\spad{r}. Error: if \\spad{r = 0}.} \\blankline \\spad{X} m:=matrix [[2**i for \\spad{i} in 2..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m/4}")) (|exquo| (((|Union| $ "failed") $ |#1|) "\\indented{1}{\\spad{exquo(m,{}r)} computes the exact quotient of the elements} \\indented{1}{of \\spad{m} by \\spad{r},{} returning \\axiom{\"failed\"} if this is not possible.} \\blankline \\spad{X} m:=matrix [[2**i for \\spad{i} in 2..4] for \\spad{j} in 1..5] \\spad{X} exquo(\\spad{m},{}2)")) (** (($ $ (|Integer|)) "\\indented{1}{\\spad{m**n} computes an integral power of the matrix \\spad{m}.} \\indented{1}{Error: if matrix is not square or if the matrix} \\indented{1}{is square but not invertible.} \\blankline \\spad{X} (matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]) \\spad{**} 2") (($ $ (|NonNegativeInteger|)) "\\indented{1}{\\spad{x ** n} computes a non-negative integral power of the matrix \\spad{x}.} \\indented{1}{Error: if the matrix is not square.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m**3}")) (* ((|#2| |#2| $) "\\indented{1}{\\spad{r * x} is the product of the row vector \\spad{r} and the matrix \\spad{x}.} \\indented{1}{Error: if the dimensions are incompatible.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} r:=transpose([1,{}2,{}3,{}4,{}5])@Matrix(INT) \\spad{X} \\spad{r*m}") ((|#3| $ |#3|) "\\indented{1}{\\spad{x * c} is the product of the matrix \\spad{x} and the column vector \\spad{c}.} \\indented{1}{Error: if the dimensions are incompatible.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} c:=coerce([1,{}2,{}3,{}4,{}5])@Matrix(INT) \\spad{X} \\spad{m*c}") (($ (|Integer|) $) "\\indented{1}{\\spad{n * x} is an integer multiple.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} 3*m") (($ $ |#1|) "\\indented{1}{\\spad{x * r} is the right scalar multiple of the scalar \\spad{r} and the} \\indented{1}{matrix \\spad{x}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m*1/3}") (($ |#1| $) "\\indented{1}{\\spad{r*x} is the left scalar multiple of the scalar \\spad{r} and the} \\indented{1}{matrix \\spad{x}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} 1/3*m") (($ $ $) "\\indented{1}{\\spad{x * y} is the product of the matrices \\spad{x} and \\spad{y}.} \\indented{1}{Error: if the dimensions are incompatible.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m*m}")) (- (($ $) "\\indented{1}{\\spad{-x} returns the negative of the matrix \\spad{x}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{-m}") (($ $ $) "\\indented{1}{\\spad{x - y} is the difference of the matrices \\spad{x} and \\spad{y}.} \\indented{1}{Error: if the dimensions are incompatible.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m}-\\spad{m}")) (+ (($ $ $) "\\indented{1}{\\spad{x + y} is the sum of the matrices \\spad{x} and \\spad{y}.} \\indented{1}{Error: if the dimensions are incompatible.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} \\spad{m+m}")) (|setsubMatrix!| (($ $ (|Integer|) (|Integer|) $) "\\indented{1}{\\spad{setsubMatrix(x,{}i1,{}j1,{}y)} destructively alters the} \\indented{1}{matrix \\spad{x}. Here \\spad{x(i,{}j)} is set to \\spad{y(i-i1+1,{}j-j1+1)} for} \\indented{1}{\\spad{i = i1,{}...,{}i1-1+nrows y} and \\spad{j = j1,{}...,{}j1-1+ncols y}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} setsubMatrix!(\\spad{m},{}2,{}2,{}matrix [[3,{}3],{}[3,{}3]])")) (|subMatrix| (($ $ (|Integer|) (|Integer|) (|Integer|) (|Integer|)) "\\indented{1}{\\spad{subMatrix(x,{}i1,{}i2,{}j1,{}j2)} extracts the submatrix} \\indented{1}{\\spad{[x(i,{}j)]} where the index \\spad{i} ranges from \\spad{i1} to \\spad{i2}} \\indented{1}{and the index \\spad{j} ranges from \\spad{j1} to \\spad{j2}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} subMatrix(\\spad{m},{}1,{}3,{}2,{}4)")) (|swapColumns!| (($ $ (|Integer|) (|Integer|)) "\\indented{1}{\\spad{swapColumns!(m,{}i,{}j)} interchanges the \\spad{i}th and \\spad{j}th} \\indented{1}{columns of \\spad{m}. This destructively alters the matrix.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} swapColumns!(\\spad{m},{}2,{}4)")) (|swapRows!| (($ $ (|Integer|) (|Integer|)) "\\indented{1}{\\spad{swapRows!(m,{}i,{}j)} interchanges the \\spad{i}th and \\spad{j}th} \\indented{1}{rows of \\spad{m}. This destructively alters the matrix.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} swapRows!(\\spad{m},{}2,{}4)")) (|setelt| (($ $ (|List| (|Integer|)) (|List| (|Integer|)) $) "\\indented{1}{\\spad{setelt(x,{}rowList,{}colList,{}y)} destructively alters the matrix \\spad{x}.} \\indented{1}{If \\spad{y} is \\spad{m}-by-\\spad{n},{} \\spad{rowList = [i<1>,{}i<2>,{}...,{}i<m>]}} \\indented{1}{and \\spad{colList = [j<1>,{}j<2>,{}...,{}j<n>]},{} then \\spad{x(i<k>,{}j<l>)}} \\indented{1}{is set to \\spad{y(k,{}l)} for \\spad{k = 1,{}...,{}m} and \\spad{l = 1,{}...,{}n}} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} setelt(\\spad{m},{}3,{}3,{}10)")) (|elt| (($ $ (|List| (|Integer|)) (|List| (|Integer|))) "\\indented{1}{\\spad{elt(x,{}rowList,{}colList)} returns an \\spad{m}-by-\\spad{n} matrix consisting} \\indented{1}{of elements of \\spad{x},{} where \\spad{m = \\# rowList} and \\spad{n = \\# colList}} \\indented{1}{If \\spad{rowList = [i<1>,{}i<2>,{}...,{}i<m>]} and \\spad{colList =} \\indented{1}{[j<1>,{}j<2>,{}...,{}j<n>]},{} then the \\spad{(k,{}l)}th entry of} \\indented{1}{\\spad{elt(x,{}rowList,{}colList)} is \\spad{x(i<k>,{}j<l>)}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} elt(\\spad{m},{}3,{}3)")) (|listOfLists| (((|List| (|List| |#1|)) $) "\\indented{1}{\\spad{listOfLists(m)} returns the rows of the matrix \\spad{m} as a list} \\indented{1}{of lists.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} listOfLists \\spad{m}")) (|vertConcat| (($ $ $) "\\indented{1}{\\spad{vertConcat(x,{}y)} vertically concatenates two matrices with an} \\indented{1}{equal number of columns. The entries of \\spad{y} appear below} \\indented{1}{of the entries of \\spad{x}.\\space{2}Error: if the matrices} \\indented{1}{do not have the same number of columns.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} vertConcat(\\spad{m},{}\\spad{m})")) (|horizConcat| (($ $ $) "\\indented{1}{\\spad{horizConcat(x,{}y)} horizontally concatenates two matrices with} \\indented{1}{an equal number of rows. The entries of \\spad{y} appear to the right} \\indented{1}{of the entries of \\spad{x}.\\space{2}Error: if the matrices} \\indented{1}{do not have the same number of rows.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} horizConcat(\\spad{m},{}\\spad{m})")) (|squareTop| (($ $) "\\indented{1}{\\spad{squareTop(m)} returns an \\spad{n}-by-\\spad{n} matrix consisting of the first} \\indented{1}{\\spad{n} rows of the \\spad{m}-by-\\spad{n} matrix \\spad{m}. Error: if} \\indented{1}{\\spad{m < n}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..2] for \\spad{j} in 1..5] \\spad{X} squareTop \\spad{m}")) (|transpose| (($ $) "\\indented{1}{\\spad{transpose(m)} returns the transpose of the matrix \\spad{m}.} \\blankline \\spad{X} m:=matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5] \\spad{X} transpose \\spad{m}") (($ |#2|) "\\indented{1}{\\spad{transpose(r)} converts the row \\spad{r} to a row matrix.} \\blankline \\spad{X} transpose([1,{}2,{}3])@Matrix(INT)")) (|coerce| (($ |#3|) "\\indented{1}{\\spad{coerce(col)} converts the column col to a column matrix.} \\blankline \\spad{X} coerce([1,{}2,{}3])@Matrix(INT)")) (|diagonalMatrix| (($ (|List| $)) "\\indented{1}{\\spad{diagonalMatrix([m1,{}...,{}mk])} creates a block diagonal matrix} \\indented{1}{\\spad{M} with block matrices \\spad{m1},{}...,{}\\spad{mk} down the diagonal,{}} \\indented{1}{with 0 block matrices elsewhere.} \\indented{1}{More precisly: if \\spad{\\spad{ri} := nrows \\spad{mi}},{} \\spad{\\spad{ci} := ncols \\spad{mi}},{}} \\indented{1}{then \\spad{m} is an (\\spad{r1+}..\\spad{+rk}) by (\\spad{c1+}..\\spad{+ck}) - matrix\\space{2}with entries} \\indented{1}{\\spad{m.i.j = ml.(i-r1-..-r(l-1)).(j-n1-..-n(l-1))},{} if} \\indented{1}{\\spad{(r1+..+r(l-1)) < i <= r1+..+rl} and} \\indented{1}{\\spad{(c1+..+c(l-1)) < i <= c1+..+cl},{}} \\indented{1}{\\spad{m.i.j} = 0\\space{2}otherwise.} \\blankline \\spad{X} diagonalMatrix [matrix [[1,{}2],{}[3,{}4]],{} matrix [[4,{}5],{}[6,{}7]]]") (($ (|List| |#1|)) "\\indented{1}{\\spad{diagonalMatrix(l)} returns a diagonal matrix with the elements} \\indented{1}{of \\spad{l} on the diagonal.} \\blankline \\spad{X} diagonalMatrix [1,{}2,{}3]")) (|scalarMatrix| (($ (|NonNegativeInteger|) |#1|) "\\indented{1}{\\spad{scalarMatrix(n,{}r)} returns an \\spad{n}-by-\\spad{n} matrix with \\spad{r}\\spad{'s} on the} \\indented{1}{diagonal and zeroes elsewhere.} \\blankline \\spad{X} z:Matrix(INT):=scalarMatrix(3,{}5)")) (|matrix| (($ (|List| (|List| |#1|))) "\\indented{1}{\\spad{matrix(l)} converts the list of lists \\spad{l} to a matrix,{} where the} \\indented{1}{list of lists is viewed as a list of the rows of the matrix.} \\blankline \\spad{X} matrix [[1,{}2,{}3],{}[4,{}5,{}6],{}[7,{}8,{}9],{}[1,{}1,{}1]]")) (|zero| (($ (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\indented{1}{\\spad{zero(m,{}n)} returns an \\spad{m}-by-\\spad{n} zero matrix.} \\blankline \\spad{X} z:Matrix(INT):=zero(3,{}3)")) (|antisymmetric?| (((|Boolean|) $) "\\indented{1}{\\spad{antisymmetric?(m)} returns \\spad{true} if the matrix \\spad{m} is square and} \\indented{1}{antisymmetric (\\spadignore{i.e.} \\spad{m[i,{}j] = -m[j,{}i]} for all \\spad{i} and \\spad{j})} \\indented{1}{and \\spad{false} otherwise.} \\blankline \\spad{X} antisymmetric? matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|symmetric?| (((|Boolean|) $) "\\indented{1}{\\spad{symmetric?(m)} returns \\spad{true} if the matrix \\spad{m} is square and} \\indented{1}{symmetric (\\spadignore{i.e.} \\spad{m[i,{}j] = m[j,{}i]} for all \\spad{i} and \\spad{j}) and \\spad{false}} \\indented{1}{otherwise.} \\blankline \\spad{X} symmetric? matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|diagonal?| (((|Boolean|) $) "\\indented{1}{\\spad{diagonal?(m)} returns \\spad{true} if the matrix \\spad{m} is square and} \\indented{1}{diagonal (\\spadignore{i.e.} all entries of \\spad{m} not on the diagonal are zero) and} \\indented{1}{\\spad{false} otherwise.} \\blankline \\spad{X} diagonal? matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|square?| (((|Boolean|) $) "\\indented{1}{\\spad{square?(m)} returns \\spad{true} if \\spad{m} is a square matrix} \\indented{1}{(if \\spad{m} has the same number of rows as columns) and \\spad{false} otherwise.} \\blankline \\spad{X} square matrix [[j**i for \\spad{i} in 0..4] for \\spad{j} in 1..5]")) (|finiteAggregate| ((|attribute|) "matrices are finite")) (|shallowlyMutable| ((|attribute|) "One may destructively alter matrices"))) 
-((-4519 . T) (-4520 . T) (-3973 . T)) 
+((-4521 . T) (-4522 . T) (-3973 . T)) 
 NIL 
 (-678 R |Row| |Col| M) 
 ((|constructor| (NIL "\\spadtype{MatrixLinearAlgebraFunctions} provides functions to compute inverses and canonical forms.")) (|inverse| (((|Union| |#4| "failed") |#4|) "\\spad{inverse(m)} returns the inverse of the matrix. If the matrix is not invertible,{} \"failed\" is returned. Error: if the matrix is not square.")) (|normalizedDivide| (((|Record| (|:| |quotient| |#1|) (|:| |remainder| |#1|)) |#1| |#1|) "\\spad{normalizedDivide(n,{}d)} returns a normalized quotient and remainder such that consistently unique representatives for the residue class are chosen,{} \\spadignore{e.g.} positive remainders")) (|rowEchelon| ((|#4| |#4|) "\\spad{rowEchelon(m)} returns the row echelon form of the matrix \\spad{m}.")) (|adjoint| (((|Record| (|:| |adjMat| |#4|) (|:| |detMat| |#1|)) |#4|) "\\spad{adjoint(m)} returns the ajoint matrix of \\spad{m} (\\spadignore{i.e.} the matrix \\spad{n} such that \\spad{m*n} = determinant(\\spad{m})*id) and the detrminant of \\spad{m}.")) (|invertIfCan| (((|Union| |#4| "failed") |#4|) "\\spad{invertIfCan(m)} returns the inverse of \\spad{m} over \\spad{R}")) (|fractionFreeGauss!| ((|#4| |#4|) "\\spad{fractionFreeGauss(m)} performs the fraction free gaussian elimination on the matrix \\spad{m}.")) (|nullSpace| (((|List| |#3|) |#4|) "\\spad{nullSpace(m)} returns a basis for the null space of the matrix \\spad{m}.")) (|nullity| (((|NonNegativeInteger|) |#4|) "\\spad{nullity(m)} returns the mullity of the matrix \\spad{m}. This is the dimension of the null space of the matrix \\spad{m}.")) (|rank| (((|NonNegativeInteger|) |#4|) "\\spad{rank(m)} returns the rank of the matrix \\spad{m}.")) (|elColumn2!| ((|#4| |#4| |#1| (|Integer|) (|Integer|)) "\\spad{elColumn2!(m,{}a,{}i,{}j)} adds to column \\spad{i} a*column(\\spad{m},{}\\spad{j}) : elementary operation of second kind. (\\spad{i} \\spad{^=j})")) (|elRow2!| ((|#4| |#4| |#1| (|Integer|) (|Integer|)) "\\spad{elRow2!(m,{}a,{}i,{}j)} adds to row \\spad{i} a*row(\\spad{m},{}\\spad{j}) : elementary operation of second kind. (\\spad{i} \\spad{^=j})")) (|elRow1!| ((|#4| |#4| (|Integer|) (|Integer|)) "\\spad{elRow1!(m,{}i,{}j)} swaps rows \\spad{i} and \\spad{j} of matrix \\spad{m} : elementary operation of first kind")) (|minordet| ((|#1| |#4|) "\\spad{minordet(m)} computes the determinant of the matrix \\spad{m} using minors. Error: if the matrix is not square.")) (|determinant| ((|#1| |#4|) "\\spad{determinant(m)} returns the determinant of the matrix \\spad{m}. an error message is returned if the matrix is not square."))) 
@@ -2646,8 +2646,8 @@ NIL
 ((|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-558)))) 
 (-679 R) 
 ((|constructor| (NIL "\\spadtype{Matrix} is a matrix domain where 1-based indexing is used for both rows and columns.")) (|inverse| (((|Union| $ "failed") $) "\\spad{inverse(m)} returns the inverse of the matrix \\spad{m}. If the matrix is not invertible,{} \"failed\" is returned. Error: if the matrix is not square.")) (|diagonalMatrix| (($ (|Vector| |#1|)) "\\spad{diagonalMatrix(v)} returns a diagonal matrix where the elements of \\spad{v} appear on the diagonal."))) 
-((-4519 . T) (-4520 . T)) 
-((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-558))) (|HasAttribute| |#1| (QUOTE (-4521 "*"))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
+((-4521 . T) (-4522 . T)) 
+((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-558))) (|HasAttribute| |#1| (QUOTE (-4523 "*"))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
 (-680 R) 
 ((|constructor| (NIL "This package provides standard arithmetic operations on matrices. The functions in this package store the results of computations in existing matrices,{} rather than creating new matrices. This package works only for matrices of type Matrix and uses the internal representation of this type.")) (** (((|Matrix| |#1|) (|Matrix| |#1|) (|NonNegativeInteger|)) "\\spad{x ** n} computes the \\spad{n}-th power of a square matrix. The power \\spad{n} is assumed greater than 1.")) (|power!| (((|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|) (|NonNegativeInteger|)) "\\spad{power!(a,{}b,{}c,{}m,{}n)} computes \\spad{m} \\spad{**} \\spad{n} and stores the result in \\spad{a}. The matrices \\spad{b} and \\spad{c} are used to store intermediate results. Error: if \\spad{a},{} \\spad{b},{} \\spad{c},{} and \\spad{m} are not square and of the same dimensions.")) (|times!| (((|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|)) "\\spad{times!(c,{}a,{}b)} computes the matrix product \\spad{a * b} and stores the result in the matrix \\spad{c}. Error: if \\spad{a},{} \\spad{b},{} and \\spad{c} do not have compatible dimensions.")) (|rightScalarTimes!| (((|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|) |#1|) "\\spad{rightScalarTimes!(c,{}a,{}r)} computes the scalar product \\spad{a * r} and stores the result in the matrix \\spad{c}. Error: if \\spad{a} and \\spad{c} do not have the same dimensions.")) (|leftScalarTimes!| (((|Matrix| |#1|) (|Matrix| |#1|) |#1| (|Matrix| |#1|)) "\\spad{leftScalarTimes!(c,{}r,{}a)} computes the scalar product \\spad{r * a} and stores the result in the matrix \\spad{c}. Error: if \\spad{a} and \\spad{c} do not have the same dimensions.")) (|minus!| (((|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|)) "\\spad{!minus!(c,{}a,{}b)} computes the matrix difference \\spad{a - b} and stores the result in the matrix \\spad{c}. Error: if \\spad{a},{} \\spad{b},{} and \\spad{c} do not have the same dimensions.") (((|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|)) "\\spad{minus!(c,{}a)} computes \\spad{-a} and stores the result in the matrix \\spad{c}. Error: if a and \\spad{c} do not have the same dimensions.")) (|plus!| (((|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|)) "\\spad{plus!(c,{}a,{}b)} computes the matrix sum \\spad{a + b} and stores the result in the matrix \\spad{c}. Error: if \\spad{a},{} \\spad{b},{} and \\spad{c} do not have the same dimensions.")) (|copy!| (((|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|)) "\\spad{copy!(c,{}a)} copies the matrix \\spad{a} into the matrix \\spad{c}. Error: if \\spad{a} and \\spad{c} do not have the same dimensions."))) 
 NIL 
@@ -2662,11 +2662,11 @@ NIL
 NIL 
 (-683) 
 ((|constructor| (NIL "A domain which models the complex number representation used by machines in the AXIOM-NAG link.")) (|coerce| (((|Complex| (|Float|)) $) "\\spad{coerce(u)} transforms \\spad{u} into a COmplex Float") (($ (|Complex| (|MachineInteger|))) "\\spad{coerce(u)} transforms \\spad{u} into a MachineComplex") (($ (|Complex| (|MachineFloat|))) "\\spad{coerce(u)} transforms \\spad{u} into a MachineComplex") (($ (|Complex| (|Integer|))) "\\spad{coerce(u)} transforms \\spad{u} into a MachineComplex") (($ (|Complex| (|Float|))) "\\spad{coerce(u)} transforms \\spad{u} into a MachineComplex"))) 
-((-4512 . T) (-4517 |has| (-688) (-365)) (-4511 |has| (-688) (-365)) (-4003 . T) (-4518 |has| (-688) (-6 -4518)) (-4515 |has| (-688) (-6 -4515)) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| (-688) (QUOTE (-150))) (|HasCategory| (-688) (QUOTE (-148))) (|HasCategory| (-688) (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| (-688) (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| (-688) (QUOTE (-370))) (|HasCategory| (-688) (QUOTE (-365))) (|HasCategory| (-688) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-688) (QUOTE (-225))) (|HasCategory| (-688) (QUOTE (-350))) (-2198 (|HasCategory| (-688) (QUOTE (-365))) (|HasCategory| (-688) (QUOTE (-350)))) (|HasCategory| (-688) (LIST (QUOTE -281) (QUOTE (-688)) (QUOTE (-688)))) (|HasCategory| (-688) (LIST (QUOTE -303) (QUOTE (-688)))) (|HasCategory| (-688) (LIST (QUOTE -523) (QUOTE (-1161)) (QUOTE (-688)))) (|HasCategory| (-688) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| (-688) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| (-688) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| (-688) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| (-688) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-688) (QUOTE (-1021))) (|HasCategory| (-688) (QUOTE (-1181))) (-12 (|HasCategory| (-688) (QUOTE (-1002))) (|HasCategory| (-688) (QUOTE (-1181)))) (|HasCategory| (-688) (QUOTE (-550))) (|HasCategory| (-688) (QUOTE (-1056))) (-12 (|HasCategory| (-688) (QUOTE (-1056))) (|HasCategory| (-688) (QUOTE (-1181)))) (-2198 (|HasCategory| (-688) (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| (-688) (QUOTE (-365)))) (|HasCategory| (-688) (QUOTE (-301))) (-2198 (|HasCategory| (-688) (QUOTE (-301))) (|HasCategory| (-688) (QUOTE (-365))) (|HasCategory| (-688) (QUOTE (-350)))) (|HasCategory| (-688) (QUOTE (-904))) (-12 (|HasCategory| (-688) (QUOTE (-225))) (|HasCategory| (-688) (QUOTE (-365)))) (-12 (|HasCategory| (-688) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-688) (QUOTE (-365)))) (|HasCategory| (-688) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| (-688) (QUOTE (-842))) (|HasCategory| (-688) (QUOTE (-558))) (|HasAttribute| (-688) (QUOTE -4518)) (|HasAttribute| (-688) (QUOTE -4515)) (-12 (|HasCategory| (-688) (QUOTE (-301))) (|HasCategory| (-688) (QUOTE (-904)))) (-2198 (-12 (|HasCategory| (-688) (QUOTE (-301))) (|HasCategory| (-688) (QUOTE (-904)))) (|HasCategory| (-688) (QUOTE (-365))) (-12 (|HasCategory| (-688) (QUOTE (-350))) (|HasCategory| (-688) (QUOTE (-904))))) (-2198 (-12 (|HasCategory| (-688) (QUOTE (-301))) (|HasCategory| (-688) (QUOTE (-904)))) (-12 (|HasCategory| (-688) (QUOTE (-365))) (|HasCategory| (-688) (QUOTE (-904)))) (-12 (|HasCategory| (-688) (QUOTE (-350))) (|HasCategory| (-688) (QUOTE (-904))))) (-2198 (-12 (|HasCategory| (-688) (QUOTE (-301))) (|HasCategory| (-688) (QUOTE (-904)))) (|HasCategory| (-688) (QUOTE (-365)))) (-2198 (-12 (|HasCategory| (-688) (QUOTE (-301))) (|HasCategory| (-688) (QUOTE (-904)))) (|HasCategory| (-688) (QUOTE (-558)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-688) (QUOTE (-301))) (|HasCategory| (-688) (QUOTE (-904)))) (|HasCategory| (-688) (QUOTE (-148)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-688) (QUOTE (-301))) (|HasCategory| (-688) (QUOTE (-904)))) (|HasCategory| (-688) (QUOTE (-350))))) 
+((-4514 . T) (-4519 |has| (-688) (-365)) (-4513 |has| (-688) (-365)) (-4005 . T) (-4520 |has| (-688) (-6 -4520)) (-4517 |has| (-688) (-6 -4517)) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| (-688) (QUOTE (-150))) (|HasCategory| (-688) (QUOTE (-148))) (|HasCategory| (-688) (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| (-688) (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| (-688) (QUOTE (-370))) (|HasCategory| (-688) (QUOTE (-365))) (|HasCategory| (-688) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-688) (QUOTE (-225))) (|HasCategory| (-688) (QUOTE (-350))) (-2199 (|HasCategory| (-688) (QUOTE (-365))) (|HasCategory| (-688) (QUOTE (-350)))) (|HasCategory| (-688) (LIST (QUOTE -281) (QUOTE (-688)) (QUOTE (-688)))) (|HasCategory| (-688) (LIST (QUOTE -303) (QUOTE (-688)))) (|HasCategory| (-688) (LIST (QUOTE -523) (QUOTE (-1161)) (QUOTE (-688)))) (|HasCategory| (-688) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| (-688) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| (-688) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| (-688) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| (-688) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-688) (QUOTE (-1021))) (|HasCategory| (-688) (QUOTE (-1181))) (-12 (|HasCategory| (-688) (QUOTE (-1002))) (|HasCategory| (-688) (QUOTE (-1181)))) (|HasCategory| (-688) (QUOTE (-550))) (|HasCategory| (-688) (QUOTE (-1056))) (-12 (|HasCategory| (-688) (QUOTE (-1056))) (|HasCategory| (-688) (QUOTE (-1181)))) (-2199 (|HasCategory| (-688) (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| (-688) (QUOTE (-365)))) (|HasCategory| (-688) (QUOTE (-301))) (-2199 (|HasCategory| (-688) (QUOTE (-301))) (|HasCategory| (-688) (QUOTE (-365))) (|HasCategory| (-688) (QUOTE (-350)))) (|HasCategory| (-688) (QUOTE (-904))) (-12 (|HasCategory| (-688) (QUOTE (-225))) (|HasCategory| (-688) (QUOTE (-365)))) (-12 (|HasCategory| (-688) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-688) (QUOTE (-365)))) (|HasCategory| (-688) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| (-688) (QUOTE (-842))) (|HasCategory| (-688) (QUOTE (-558))) (|HasAttribute| (-688) (QUOTE -4520)) (|HasAttribute| (-688) (QUOTE -4517)) (-12 (|HasCategory| (-688) (QUOTE (-301))) (|HasCategory| (-688) (QUOTE (-904)))) (-2199 (-12 (|HasCategory| (-688) (QUOTE (-301))) (|HasCategory| (-688) (QUOTE (-904)))) (|HasCategory| (-688) (QUOTE (-365))) (-12 (|HasCategory| (-688) (QUOTE (-350))) (|HasCategory| (-688) (QUOTE (-904))))) (-2199 (-12 (|HasCategory| (-688) (QUOTE (-301))) (|HasCategory| (-688) (QUOTE (-904)))) (-12 (|HasCategory| (-688) (QUOTE (-365))) (|HasCategory| (-688) (QUOTE (-904)))) (-12 (|HasCategory| (-688) (QUOTE (-350))) (|HasCategory| (-688) (QUOTE (-904))))) (-2199 (-12 (|HasCategory| (-688) (QUOTE (-301))) (|HasCategory| (-688) (QUOTE (-904)))) (|HasCategory| (-688) (QUOTE (-365)))) (-2199 (-12 (|HasCategory| (-688) (QUOTE (-301))) (|HasCategory| (-688) (QUOTE (-904)))) (|HasCategory| (-688) (QUOTE (-558)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-688) (QUOTE (-301))) (|HasCategory| (-688) (QUOTE (-904)))) (|HasCategory| (-688) (QUOTE (-148)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-688) (QUOTE (-301))) (|HasCategory| (-688) (QUOTE (-904)))) (|HasCategory| (-688) (QUOTE (-350))))) 
 (-684 S) 
 ((|constructor| (NIL "A multi-dictionary is a dictionary which may contain duplicates. As for any dictionary,{} its size is assumed large so that copying (non-destructive) operations are generally to be avoided.")) (|duplicates| (((|List| (|Record| (|:| |entry| |#1|) (|:| |count| (|NonNegativeInteger|)))) $) "\\spad{duplicates(d)} returns a list of values which have duplicates in \\spad{d}")) (|removeDuplicates!| (($ $) "\\spad{removeDuplicates!(d)} destructively removes any duplicate values in dictionary \\spad{d}.")) (|insert!| (($ |#1| $ (|NonNegativeInteger|)) "\\spad{insert!(x,{}d,{}n)} destructively inserts \\spad{n} copies of \\spad{x} into dictionary \\spad{d}."))) 
-((-4520 . T) (-3973 . T)) 
+((-4522 . T) (-3973 . T)) 
 NIL 
 (-685 U) 
 ((|constructor| (NIL "This package supports factorization and gcds of univariate polynomials over the integers modulo different primes. The inputs are given as polynomials over the integers with the prime passed explicitly as an extra argument.")) (|exptMod| ((|#1| |#1| (|Integer|) |#1| (|Integer|)) "\\spad{exptMod(f,{}n,{}g,{}p)} raises the univariate polynomial \\spad{f} to the \\spad{n}th power modulo the polynomial \\spad{g} and the prime \\spad{p}.")) (|separateFactors| (((|List| |#1|) (|List| (|Record| (|:| |factor| |#1|) (|:| |degree| (|Integer|)))) (|Integer|)) "\\spad{separateFactors(ddl,{} p)} refines the distinct degree factorization produced by ddFact to give a complete list of factors.")) (|ddFact| (((|List| (|Record| (|:| |factor| |#1|) (|:| |degree| (|Integer|)))) |#1| (|Integer|)) "\\spad{ddFact(f,{}p)} computes a distinct degree factorization of the polynomial \\spad{f} modulo the prime \\spad{p},{} \\spadignore{i.e.} such that each factor is a product of irreducibles of the same degrees. The input polynomial \\spad{f} is assumed to be square-free modulo \\spad{p}.")) (|factor| (((|List| |#1|) |#1| (|Integer|)) "\\spad{factor(f1,{}p)} returns the list of factors of the univariate polynomial \\spad{f1} modulo the integer prime \\spad{p}. Error: if \\spad{f1} is not square-free modulo \\spad{p}.")) (|linears| ((|#1| |#1| (|Integer|)) "\\spad{linears(f,{}p)} returns the product of all the linear factors of \\spad{f} modulo \\spad{p}. Potentially incorrect result if \\spad{f} is not square-free modulo \\spad{p}.")) (|gcd| ((|#1| |#1| |#1| (|Integer|)) "\\spad{gcd(f1,{}f2,{}p)} computes the \\spad{gcd} of the univariate polynomials \\spad{f1} and \\spad{f2} modulo the integer prime \\spad{p}."))) 
@@ -2682,7 +2682,7 @@ NIL
 NIL 
 (-688) 
 ((|constructor| (NIL "A domain which models the floating point representation used by machines in the AXIOM-NAG link.")) (|changeBase| (($ (|Integer|) (|Integer|) (|PositiveInteger|)) "\\spad{changeBase(exp,{}man,{}base)} is not documented")) (|exponent| (((|Integer|) $) "\\spad{exponent(u)} returns the exponent of \\spad{u}")) (|mantissa| (((|Integer|) $) "\\spad{mantissa(u)} returns the mantissa of \\spad{u}")) (|coerce| (($ (|MachineInteger|)) "\\spad{coerce(u)} transforms a MachineInteger into a MachineFloat") (((|Float|) $) "\\spad{coerce(u)} transforms a MachineFloat to a standard Float")) (|minimumExponent| (((|Integer|)) "\\spad{minimumExponent()} returns the minimum exponent in the model") (((|Integer|) (|Integer|)) "\\spad{minimumExponent(e)} sets the minimum exponent in the model to \\spad{e}")) (|maximumExponent| (((|Integer|)) "\\spad{maximumExponent()} returns the maximum exponent in the model") (((|Integer|) (|Integer|)) "\\spad{maximumExponent(e)} sets the maximum exponent in the model to \\spad{e}")) (|base| (((|PositiveInteger|)) "\\spad{base()} returns the base of the model") (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{base(b)} sets the base of the model to \\spad{b}")) (|precision| (((|PositiveInteger|)) "\\spad{precision()} returns the number of digits in the model") (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{precision(p)} sets the number of digits in the model to \\spad{p}"))) 
-((-3996 . T) (-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-3999 . T) (-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-689 R) 
 ((|constructor| (NIL "Modular hermitian row reduction.")) (|normalizedDivide| (((|Record| (|:| |quotient| |#1|) (|:| |remainder| |#1|)) |#1| |#1|) "\\spad{normalizedDivide(n,{}d)} returns a normalized quotient and remainder such that consistently unique representatives for the residue class are chosen,{} \\spadignore{e.g.} positive remainders")) (|rowEchelonLocal| (((|Matrix| |#1|) (|Matrix| |#1|) |#1| |#1|) "\\spad{rowEchelonLocal(m,{} d,{} p)} computes the row-echelon form of \\spad{m} concatenated with \\spad{d} times the identity matrix over a local ring where \\spad{p} is the only prime.")) (|rowEchLocal| (((|Matrix| |#1|) (|Matrix| |#1|) |#1|) "\\spad{rowEchLocal(m,{}p)} computes a modular row-echelon form of \\spad{m},{} finding an appropriate modulus over a local ring where \\spad{p} is the only prime.")) (|rowEchelon| (((|Matrix| |#1|) (|Matrix| |#1|) |#1|) "\\spad{rowEchelon(m,{} d)} computes a modular row-echelon form mod \\spad{d} of \\indented{3}{[\\spad{d}\\space{5}]} \\indented{3}{[\\space{2}\\spad{d}\\space{3}]} \\indented{3}{[\\space{4}. ]} \\indented{3}{[\\space{5}\\spad{d}]} \\indented{3}{[\\space{3}\\spad{M}\\space{2}]} where \\spad{M = m mod d}.")) (|rowEch| (((|Matrix| |#1|) (|Matrix| |#1|)) "\\spad{rowEch(m)} computes a modular row-echelon form of \\spad{m},{} finding an appropriate modulus."))) 
@@ -2690,7 +2690,7 @@ NIL
 NIL 
 (-690) 
 ((|constructor| (NIL "A domain which models the integer representation used by machines in the AXIOM-NAG link.")) (|coerce| (((|Expression| $) (|Expression| (|Integer|))) "\\spad{coerce(x)} returns \\spad{x} with coefficients in the domain")) (|maxint| (((|PositiveInteger|)) "\\spad{maxint()} returns the maximum integer in the model") (((|PositiveInteger|) (|PositiveInteger|)) "\\spad{maxint(u)} sets the maximum integer in the model to \\spad{u}"))) 
-((-4518 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4520 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-691 S D1 D2 I) 
 ((|constructor| (NIL "Tools and transforms for making compiled functions from top-level expressions")) (|compiledFunction| (((|Mapping| |#4| |#2| |#3|) |#1| (|Symbol|) (|Symbol|)) "\\spad{compiledFunction(expr,{}x,{}y)} returns a function \\spad{f: (D1,{} D2) -> I} defined by \\spad{f(x,{} y) == expr}. Function \\spad{f} is compiled and directly applicable to objects of type \\spad{(D1,{} D2)}")) (|binaryFunction| (((|Mapping| |#4| |#2| |#3|) (|Symbol|)) "\\spad{binaryFunction(s)} is a local function"))) 
@@ -2712,7 +2712,7 @@ NIL
 ((|constructor| (NIL "MakeRecord is used internally by the interpreter to create record types which are used for doing parallel iterations on streams.")) (|makeRecord| (((|Record| (|:| |part1| |#1|) (|:| |part2| |#2|)) |#1| |#2|) "\\spad{makeRecord(a,{}b)} creates a record object with type Record(part1:S,{} part2:R),{} where \\spad{part1} is \\spad{a} and \\spad{part2} is \\spad{b}."))) 
 NIL 
 NIL 
-(-696 S -3190 I) 
+(-696 S -3192 I) 
 ((|constructor| (NIL "Tools for making compiled functions from top-level expressions Transforms top-level objects into compiled functions.")) (|compiledFunction| (((|Mapping| |#3| |#2|) |#1| (|Symbol|)) "\\spad{compiledFunction(expr,{} x)} returns a function \\spad{f: D -> I} defined by \\spad{f(x) == expr}. Function \\spad{f} is compiled and directly applicable to objects of type \\spad{D}.")) (|unaryFunction| (((|Mapping| |#3| |#2|) (|Symbol|)) "\\spad{unaryFunction(a)} is a local function"))) 
 NIL 
 NIL 
@@ -2722,7 +2722,7 @@ NIL
 NIL 
 (-698 R) 
 ((|constructor| (NIL "This is the category of linear operator rings with one generator. The generator is not named by the category but can always be constructed as \\spad{monomial(1,{}1)}. \\blankline For convenience,{} call the generator \\spad{G}. Then each value is equal to \\spad{sum(a(i)*G**i,{} i = 0..n)} for some unique \\spad{n} and \\spad{a(i)} in \\spad{R}. \\blankline Note that multiplication is not necessarily commutative. In fact,{} if \\spad{a} is in \\spad{R},{} it is quite normal to have \\spad{a*G \\^= G*a}.")) (|monomial| (($ |#1| (|NonNegativeInteger|)) "\\spad{monomial(c,{}k)} produces \\spad{c} times the \\spad{k}-th power of the generating operator,{} \\spad{monomial(1,{}1)}.")) (|coefficient| ((|#1| $ (|NonNegativeInteger|)) "\\spad{coefficient(l,{}k)} is \\spad{a(k)} if \\indented{2}{\\spad{l = sum(monomial(a(i),{}i),{} i = 0..n)}.}")) (|reductum| (($ $) "\\spad{reductum(l)} is \\spad{l - monomial(a(n),{}n)} if \\indented{2}{\\spad{l = sum(monomial(a(i),{}i),{} i = 0..n)}.}")) (|leadingCoefficient| ((|#1| $) "\\spad{leadingCoefficient(l)} is \\spad{a(n)} if \\indented{2}{\\spad{l = sum(monomial(a(i),{}i),{} i = 0..n)}.}")) (|minimumDegree| (((|NonNegativeInteger|) $) "\\spad{minimumDegree(l)} is the smallest \\spad{k} such that \\spad{a(k) \\^= 0} if \\indented{2}{\\spad{l = sum(monomial(a(i),{}i),{} i = 0..n)}.}")) (|degree| (((|NonNegativeInteger|) $) "\\spad{degree(l)} is \\spad{n} if \\indented{2}{\\spad{l = sum(monomial(a(i),{}i),{} i = 0..n)}.}"))) 
-((-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-699 R1 UP1 UPUP1 R2 UP2 UPUP2) 
 ((|constructor| (NIL "Lifting of a map through 2 levels of polynomials.")) (|map| ((|#6| (|Mapping| |#4| |#1|) |#3|) "\\spad{map(f,{} p)} lifts \\spad{f} to the domain of \\spad{p} then applies it to \\spad{p}."))) 
@@ -2732,25 +2732,25 @@ NIL
 ((|constructor| (NIL "This package is based on the TeXFormat domain by Robert \\spad{S}. Sutor \\spadtype{MathMLFormat} provides a coercion from \\spadtype{OutputForm} to MathML format.")) (|display| (((|Void|) (|String|)) "prints the string returned by coerce,{} adding <math ...> tags.")) (|exprex| (((|String|) (|OutputForm|)) "coverts \\spadtype{OutputForm} to \\spadtype{String} with the structure preserved with braces. Actually this is not quite accurate. The function \\spadfun{precondition} is first applied to the \\spadtype{OutputForm} expression before \\spadfun{exprex}. The raw \\spadtype{OutputForm} and the nature of the \\spadfun{precondition} function is still obscure to me at the time of this writing (2007-02-14).")) (|coerceL| (((|String|) (|OutputForm|)) "coerceS(\\spad{o}) changes \\spad{o} in the standard output format to MathML format and displays result as one long string.")) (|coerceS| (((|String|) (|OutputForm|)) "\\spad{coerceS(o)} changes \\spad{o} in the standard output format to MathML format and displays formatted result.")) (|coerce| (((|String|) (|OutputForm|)) "coerceS(\\spad{o}) changes \\spad{o} in the standard output format to MathML format."))) 
 NIL 
 NIL 
-(-701 R |Mod| -3627 -1347 |exactQuo|) 
+(-701 R |Mod| -3121 -3645 |exactQuo|) 
 ((|constructor| (NIL "These domains are used for the factorization and gcds of univariate polynomials over the integers in order to work modulo different primes. See \\spadtype{ModularRing},{} \\spadtype{EuclideanModularRing}")) (|exQuo| (((|Union| $ "failed") $ $) "\\spad{exQuo(x,{}y)} is not documented")) (|reduce| (($ |#1| |#2|) "\\spad{reduce(r,{}m)} is not documented")) (|coerce| ((|#1| $) "\\spad{coerce(x)} is not documented")) (|modulus| ((|#2| $) "\\spad{modulus(x)} is not documented"))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-702 R |Rep|) 
 ((|constructor| (NIL "This package has not been documented")) (|frobenius| (($ $) "\\spad{frobenius(x)} is not documented")) (|computePowers| (((|PrimitiveArray| $)) "\\spad{computePowers()} is not documented")) (|pow| (((|PrimitiveArray| $)) "\\spad{pow()} is not documented")) (|An| (((|Vector| |#1|) $) "\\spad{An(x)} is not documented")) (|UnVectorise| (($ (|Vector| |#1|)) "\\spad{UnVectorise(v)} is not documented")) (|Vectorise| (((|Vector| |#1|) $) "\\spad{Vectorise(x)} is not documented")) (|coerce| (($ |#2|) "\\spad{coerce(x)} is not documented")) (|lift| ((|#2| $) "\\spad{lift(x)} is not documented")) (|reduce| (($ |#2|) "\\spad{reduce(x)} is not documented")) (|modulus| ((|#2|) "\\spad{modulus()} is not documented")) (|setPoly| ((|#2| |#2|) "\\spad{setPoly(x)} is not documented"))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4515 |has| |#1| (-365)) (-4517 |has| |#1| (-6 -4517)) (-4514 . T) (-4513 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-1136))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (QUOTE (-350))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasCategory| |#1| (QUOTE (-225))) (|HasAttribute| |#1| (QUOTE -4517)) (|HasCategory| |#1| (QUOTE (-453))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4517 |has| |#1| (-365)) (-4519 |has| |#1| (-6 -4519)) (-4516 . T) (-4515 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-1136))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (QUOTE (-350))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasCategory| |#1| (QUOTE (-225))) (|HasAttribute| |#1| (QUOTE -4519)) (|HasCategory| |#1| (QUOTE (-453))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))))) 
 (-703 IS E |ff|) 
 ((|constructor| (NIL "This package has no documentation")) (|construct| (($ |#1| |#2|) "\\spad{construct(i,{}e)} is not documented")) (|coerce| (((|Record| (|:| |index| |#1|) (|:| |exponent| |#2|)) $) "\\spad{coerce(x)} is not documented") (($ (|Record| (|:| |index| |#1|) (|:| |exponent| |#2|))) "\\spad{coerce(x)} is not documented")) (|index| ((|#1| $) "\\spad{index(x)} is not documented")) (|exponent| ((|#2| $) "\\spad{exponent(x)} is not documented"))) 
 NIL 
 NIL 
 (-704 R M) 
 ((|constructor| (NIL "Algebra of ADDITIVE operators on a module.")) (|makeop| (($ |#1| (|FreeGroup| (|BasicOperator|))) "\\spad{makeop should} be local but conditional")) (|opeval| ((|#2| (|BasicOperator|) |#2|) "\\spad{opeval should} be local but conditional")) (** (($ $ (|Integer|)) "\\spad{op**n} is not documented") (($ (|BasicOperator|) (|Integer|)) "\\spad{op**n} is not documented")) (|evaluateInverse| (($ $ (|Mapping| |#2| |#2|)) "\\spad{evaluateInverse(x,{}f)} is not documented")) (|evaluate| (($ $ (|Mapping| |#2| |#2|)) "\\spad{evaluate(f,{} u +-> g u)} attaches the map \\spad{g} to \\spad{f}. \\spad{f} must be a basic operator \\spad{g} MUST be additive,{} \\spadignore{i.e.} \\spad{g(a + b) = g(a) + g(b)} for any \\spad{a},{} \\spad{b} in \\spad{M}. This implies that \\spad{g(n a) = n g(a)} for any \\spad{a} in \\spad{M} and integer \\spad{n > 0}.")) (|conjug| ((|#1| |#1|) "\\spad{conjug(x)}should be local but conditional")) (|adjoint| (($ $ $) "\\spad{adjoint(op1,{} op2)} sets the adjoint of \\spad{op1} to be \\spad{op2}. \\spad{op1} must be a basic operator") (($ $) "\\spad{adjoint(op)} returns the adjoint of the operator \\spad{op}."))) 
-((-4514 |has| |#1| (-172)) (-4513 |has| |#1| (-172)) (-4516 . T)) 
+((-4516 |has| |#1| (-172)) (-4515 |has| |#1| (-172)) (-4518 . T)) 
 ((|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150)))) 
-(-705 R |Mod| -3627 -1347 |exactQuo|) 
+(-705 R |Mod| -3121 -3645 |exactQuo|) 
 ((|constructor| (NIL "These domains are used for the factorization and gcds of univariate polynomials over the integers in order to work modulo different primes. See \\spadtype{EuclideanModularRing} ,{}\\spadtype{ModularField}")) (|inv| (($ $) "\\spad{inv(x)} is not documented")) (|recip| (((|Union| $ "failed") $) "\\spad{recip(x)} is not documented")) (|exQuo| (((|Union| $ "failed") $ $) "\\spad{exQuo(x,{}y)} is not documented")) (|reduce| (($ |#1| |#2|) "\\spad{reduce(r,{}m)} is not documented")) (|coerce| ((|#1| $) "\\spad{coerce(x)} is not documented")) (|modulus| ((|#2| $) "\\spad{modulus(x)} is not documented"))) 
-((-4516 . T)) 
+((-4518 . T)) 
 NIL 
 (-706 S R) 
 ((|constructor| (NIL "The category of modules over a commutative ring. \\blankline Axioms\\spad{\\br} \\tab{5}\\spad{1*x = x}\\spad{\\br} \\tab{5}\\spad{(a*b)*x = a*(b*x)}\\spad{\\br} \\tab{5}\\spad{(a+b)*x = (a*x)+(b*x)}\\spad{\\br} \\tab{5}\\spad{a*(x+y) = (a*x)+(a*y)}"))) 
@@ -2758,11 +2758,11 @@ NIL
 NIL 
 (-707 R) 
 ((|constructor| (NIL "The category of modules over a commutative ring. \\blankline Axioms\\spad{\\br} \\tab{5}\\spad{1*x = x}\\spad{\\br} \\tab{5}\\spad{(a*b)*x = a*(b*x)}\\spad{\\br} \\tab{5}\\spad{(a+b)*x = (a*x)+(b*x)}\\spad{\\br} \\tab{5}\\spad{a*(x+y) = (a*x)+(a*y)}"))) 
-((-4514 . T) (-4513 . T)) 
+((-4516 . T) (-4515 . T)) 
 NIL 
 (-708 -1478) 
 ((|constructor| (NIL "MoebiusTransform(\\spad{F}) is the domain of fractional linear (Moebius) transformations over \\spad{F}. This a domain of 2-by-2 matrices acting on \\spad{P1}(\\spad{F}).")) (|eval| (((|OnePointCompletion| |#1|) $ (|OnePointCompletion| |#1|)) "\\spad{eval(m,{}x)} returns \\spad{(a*x + b)/(c*x + d)} where \\spad{m = moebius(a,{}b,{}c,{}d)} (see moebius from MoebiusTransform).") ((|#1| $ |#1|) "\\spad{eval(m,{}x)} returns \\spad{(a*x + b)/(c*x + d)} where \\spad{m = moebius(a,{}b,{}c,{}d)} (see moebius from MoebiusTransform).")) (|recip| (($ $) "\\spad{recip(m)} = recip() * \\spad{m}") (($) "\\spad{recip()} returns \\spad{matrix [[0,{}1],{}[1,{}0]]} representing the map \\spad{x -> 1 / x}.")) (|scale| (($ $ |#1|) "\\spad{scale(m,{}h)} returns \\spad{scale(h) * m} (see shift from MoebiusTransform).") (($ |#1|) "\\spad{scale(k)} returns \\spad{matrix [[k,{}0],{}[0,{}1]]} representing the map \\spad{x -> k * x}.")) (|shift| (($ $ |#1|) "\\spad{shift(m,{}h)} returns \\spad{shift(h) * m} (see shift from MoebiusTransform).") (($ |#1|) "\\spad{shift(k)} returns \\spad{matrix [[1,{}k],{}[0,{}1]]} representing the map \\spad{x -> x + k}.")) (|moebius| (($ |#1| |#1| |#1| |#1|) "\\spad{moebius(a,{}b,{}c,{}d)} returns \\spad{matrix [[a,{}b],{}[c,{}d]]}."))) 
-((-4516 . T)) 
+((-4518 . T)) 
 NIL 
 (-709 S) 
 ((|constructor| (NIL "Monad is the class of all multiplicative monads,{} \\spadignore{i.e.} sets with a binary operation.")) (** (($ $ (|PositiveInteger|)) "\\spad{a**n} returns the \\spad{n}\\spad{-}th power of \\spad{a},{} defined by repeated squaring.")) (|leftPower| (($ $ (|PositiveInteger|)) "\\spad{leftPower(a,{}n)} returns the \\spad{n}\\spad{-}th left power of \\spad{a},{} \\spadignore{i.e.} \\spad{leftPower(a,{}n) := a * leftPower(a,{}n-1)} and \\spad{leftPower(a,{}1) := a}.")) (|rightPower| (($ $ (|PositiveInteger|)) "\\spad{rightPower(a,{}n)} returns the \\spad{n}\\spad{-}th right power of \\spad{a},{} \\spadignore{i.e.} \\spad{rightPower(a,{}n) := rightPower(a,{}n-1) * a} and \\spad{rightPower(a,{}1) := a}.")) (* (($ $ $) "\\spad{a*b} is the product of \\spad{a} and \\spad{b} in a set with a binary operation."))) 
@@ -2786,7 +2786,7 @@ NIL
 ((|HasCategory| |#2| (QUOTE (-350))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-370)))) 
 (-714 R UP) 
 ((|constructor| (NIL "A \\spadtype{MonogenicAlgebra} is an algebra of finite rank which can be generated by a single element.")) (|derivationCoordinates| (((|Matrix| |#1|) (|Vector| $) (|Mapping| |#1| |#1|)) "\\spad{derivationCoordinates(b,{} ')} returns \\spad{M} such that \\spad{b' = M b}.")) (|lift| ((|#2| $) "\\spad{lift(z)} returns a minimal degree univariate polynomial up such that \\spad{z=reduce up}.")) (|convert| (($ |#2|) "\\spad{convert(up)} converts the univariate polynomial \\spad{up} to an algebra element,{} reducing by the \\spad{definingPolynomial()} if necessary.")) (|reduce| (((|Union| $ "failed") (|Fraction| |#2|)) "\\spad{reduce(frac)} converts the fraction \\spad{frac} to an algebra element.") (($ |#2|) "\\spad{reduce(up)} converts the univariate polynomial \\spad{up} to an algebra element,{} reducing by the \\spad{definingPolynomial()} if necessary.")) (|definingPolynomial| ((|#2|) "\\spad{definingPolynomial()} returns the minimal polynomial which \\spad{generator()} satisfies.")) (|generator| (($) "\\spad{generator()} returns the generator for this domain."))) 
-((-4512 |has| |#1| (-365)) (-4517 |has| |#1| (-365)) (-4511 |has| |#1| (-365)) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4514 |has| |#1| (-365)) (-4519 |has| |#1| (-365)) (-4513 |has| |#1| (-365)) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-715 S) 
 ((|constructor| (NIL "The class of multiplicative monoids,{} \\spadignore{i.e.} semigroups with a multiplicative identity element. \\blankline Axioms\\spad{\\br} \\tab{5}\\spad{leftIdentity(\"*\":(\\%,{}\\%)->\\%,{}1)}\\tab{5}\\spad{1*x=x}\\spad{\\br} \\tab{5}\\spad{rightIdentity(\"*\":(\\%,{}\\%)->\\%,{}1)}\\tab{4}\\spad{x*1=x} \\blankline Conditional attributes\\spad{\\br} \\tab{5}unitsKnown - \\spadfun{recip} only returns \"failed\" on non-units")) (|recip| (((|Union| $ "failed") $) "\\spad{recip(x)} tries to compute the multiplicative inverse for \\spad{x} or \"failed\" if it cannot find the inverse (see unitsKnown).")) (^ (($ $ (|NonNegativeInteger|)) "\\spad{x^n} returns the repeated product of \\spad{x} \\spad{n} times,{} \\spadignore{i.e.} exponentiation.")) (** (($ $ (|NonNegativeInteger|)) "\\spad{x**n} returns the repeated product of \\spad{x} \\spad{n} times,{} \\spadignore{i.e.} exponentiation.")) (|one?| (((|Boolean|) $) "\\spad{one?(x)} tests if \\spad{x} is equal to 1.")) (|sample| (($) "\\spad{sample yields} a value of type \\%")) ((|One|) (($) "1 is the multiplicative identity."))) 
@@ -2800,11 +2800,11 @@ NIL
 ((|constructor| (NIL "Tools for handling monomial extensions.")) (|decompose| (((|Record| (|:| |poly| |#2|) (|:| |normal| (|Fraction| |#2|)) (|:| |special| (|Fraction| |#2|))) (|Fraction| |#2|) (|Mapping| |#2| |#2|)) "\\spad{decompose(f,{} D)} returns \\spad{[p,{}n,{}s]} such that \\spad{f = p+n+s},{} all the squarefree factors of \\spad{denom(n)} are normal \\spad{w}.\\spad{r}.\\spad{t}. \\spad{D},{} \\spad{denom(s)} is special \\spad{w}.\\spad{r}.\\spad{t}. \\spad{D},{} and \\spad{n} and \\spad{s} are proper fractions (no pole at infinity). \\spad{D} is the derivation to use.")) (|normalDenom| ((|#2| (|Fraction| |#2|) (|Mapping| |#2| |#2|)) "\\spad{normalDenom(f,{} D)} returns the product of all the normal factors of \\spad{denom(f)}. \\spad{D} is the derivation to use.")) (|splitSquarefree| (((|Record| (|:| |normal| (|Factored| |#2|)) (|:| |special| (|Factored| |#2|))) |#2| (|Mapping| |#2| |#2|)) "\\spad{splitSquarefree(p,{} D)} returns \\spad{[n_1 n_2\\^2 ... n_m\\^m,{} s_1 s_2\\^2 ... s_q\\^q]} such that \\spad{p = n_1 n_2\\^2 ... n_m\\^m s_1 s_2\\^2 ... s_q\\^q},{} each \\spad{n_i} is normal \\spad{w}.\\spad{r}.\\spad{t}. \\spad{D} and each \\spad{s_i} is special \\spad{w}.\\spad{r}.\\spad{t} \\spad{D}. \\spad{D} is the derivation to use.")) (|split| (((|Record| (|:| |normal| |#2|) (|:| |special| |#2|)) |#2| (|Mapping| |#2| |#2|)) "\\spad{split(p,{} D)} returns \\spad{[n,{}s]} such that \\spad{p = n s},{} all the squarefree factors of \\spad{n} are normal \\spad{w}.\\spad{r}.\\spad{t}. \\spad{D},{} and \\spad{s} is special \\spad{w}.\\spad{r}.\\spad{t}. \\spad{D}. \\spad{D} is the derivation to use."))) 
 NIL 
 NIL 
-(-718 |VarSet| -1993 E2 R S PR PS) 
+(-718 |VarSet| -4464 E2 R S PR PS) 
 ((|constructor| (NIL "Utilities for MPolyCat")) (|reshape| ((|#7| (|List| |#5|) |#6|) "\\spad{reshape(l,{}p)} \\undocumented")) (|map| ((|#7| (|Mapping| |#5| |#4|) |#6|) "\\spad{map(f,{}p)} \\undocumented"))) 
 NIL 
 NIL 
-(-719 |Vars1| |Vars2| -1993 E2 R PR1 PR2) 
+(-719 |Vars1| |Vars2| -4464 E2 R PR1 PR2) 
 ((|constructor| (NIL "This package has no description")) (|map| ((|#7| (|Mapping| |#2| |#1|) |#6|) "\\spad{map(f,{}x)} \\undocumented"))) 
 NIL 
 NIL 
@@ -2814,8 +2814,8 @@ NIL
 NIL 
 (-721 |vl| R) 
 ((|constructor| (NIL "This type is the basic representation of sparse recursive multivariate polynomials whose variables are from a user specified list of symbols. The ordering is specified by the position of the variable in the list. The coefficient ring may be non commutative,{} but the variables are assumed to commute."))) 
-(((-4521 "*") |has| |#2| (-172)) (-4512 |has| |#2| (-558)) (-4517 |has| |#2| (-6 -4517)) (-4514 . T) (-4513 . T) (-4516 . T)) 
-((|HasCategory| |#2| (QUOTE (-904))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-172))) (-2198 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-558)))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#2| (QUOTE (-842))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-365))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#2| (QUOTE -4517)) (|HasCategory| |#2| (QUOTE (-453))) (-2198 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2198 (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2198 (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (|HasCategory| |#2| (QUOTE (-148))))) 
+(((-4523 "*") |has| |#2| (-172)) (-4514 |has| |#2| (-558)) (-4519 |has| |#2| (-6 -4519)) (-4516 . T) (-4515 . T) (-4518 . T)) 
+((|HasCategory| |#2| (QUOTE (-904))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-172))) (-2199 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-558)))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-852 |#1|) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#2| (QUOTE (-842))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-365))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#2| (QUOTE -4519)) (|HasCategory| |#2| (QUOTE (-453))) (-2199 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2199 (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2199 (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (|HasCategory| |#2| (QUOTE (-148))))) 
 (-722 E OV R PRF) 
 ((|constructor| (NIL "This package exports a factor operation for multivariate polynomials with coefficients which are rational functions over some ring \\spad{R} over which we can factor. It is used internally by packages such as primary decomposition which need to work with polynomials with rational function coefficients,{} \\spadignore{i.e.} themselves fractions of polynomials.")) (|factor| (((|Factored| |#4|) |#4|) "\\spad{factor(prf)} factors a polynomial with rational function coefficients.")) (|pushuconst| ((|#4| (|Fraction| (|Polynomial| |#3|)) |#2|) "\\spad{pushuconst(r,{}var)} takes a rational function and raises all occurances of the variable \\spad{var} to the polynomial level.")) (|pushucoef| ((|#4| (|SparseUnivariatePolynomial| (|Polynomial| |#3|)) |#2|) "\\spad{pushucoef(upoly,{}var)} converts the anonymous univariate polynomial \\spad{upoly} to a polynomial in \\spad{var} over rational functions.")) (|pushup| ((|#4| |#4| |#2|) "\\spad{pushup(prf,{}var)} raises all occurences of the variable \\spad{var} in the coefficients of the polynomial \\spad{prf} back to the polynomial level.")) (|pushdterm| ((|#4| (|SparseUnivariatePolynomial| |#4|) |#2|) "\\spad{pushdterm(monom,{}var)} pushes all top level occurences of the variable \\spad{var} into the coefficient domain for the monomial \\spad{monom}.")) (|pushdown| ((|#4| |#4| |#2|) "\\spad{pushdown(prf,{}var)} pushes all top level occurences of the variable \\spad{var} into the coefficient domain for the polynomial \\spad{prf}.")) (|totalfract| (((|Record| (|:| |sup| (|Polynomial| |#3|)) (|:| |inf| (|Polynomial| |#3|))) |#4|) "\\spad{totalfract(prf)} takes a polynomial whose coefficients are themselves fractions of polynomials and returns a record containing the numerator and denominator resulting from putting \\spad{prf} over a common denominator.")) (|convert| (((|Symbol|) $) "\\spad{convert(x)} converts \\spad{x} to a symbol"))) 
 NIL 
@@ -2830,15 +2830,15 @@ NIL
 NIL 
 (-725 R M) 
 ((|constructor| (NIL "\\spadtype{MonoidRing}(\\spad{R},{}\\spad{M}),{} implements the algebra of all maps from the monoid \\spad{M} to the commutative ring \\spad{R} with finite support. Multiplication of two maps \\spad{f} and \\spad{g} is defined to map an element \\spad{c} of \\spad{M} to the (convolution) sum over \\spad{f}(a)\\spad{g}(\\spad{b}) such that ab = \\spad{c}. Thus \\spad{M} can be identified with a canonical basis and the maps can also be considered as formal linear combinations of the elements in \\spad{M}. Scalar multiples of a basis element are called monomials. A prominent example is the class of polynomials where the monoid is a direct product of the natural numbers with pointwise addition. When \\spad{M} is \\spadtype{FreeMonoid Symbol},{} one gets polynomials in infinitely many non-commuting variables. Another application area is representation theory of finite groups \\spad{G},{} where modules over \\spadtype{MonoidRing}(\\spad{R},{}\\spad{G}) are studied.")) (|reductum| (($ $) "\\spad{reductum(f)} is \\spad{f} minus its leading monomial.")) (|leadingCoefficient| ((|#1| $) "\\spad{leadingCoefficient(f)} gives the coefficient of \\spad{f},{} whose corresponding monoid element is the greatest among all those with non-zero coefficients.")) (|leadingMonomial| ((|#2| $) "\\spad{leadingMonomial(f)} gives the monomial of \\spad{f} whose corresponding monoid element is the greatest among all those with non-zero coefficients.")) (|numberOfMonomials| (((|NonNegativeInteger|) $) "\\spad{numberOfMonomials(f)} is the number of non-zero coefficients with respect to the canonical basis.")) (|monomials| (((|List| $) $) "\\spad{monomials(f)} gives the list of all monomials whose sum is \\spad{f}.")) (|coefficients| (((|List| |#1|) $) "\\spad{coefficients(f)} lists all non-zero coefficients.")) (|monomial?| (((|Boolean|) $) "\\spad{monomial?(f)} tests if \\spad{f} is a single monomial.")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\spad{map(fn,{}u)} maps function \\spad{fn} onto the coefficients of the non-zero monomials of \\spad{u}.")) (|terms| (((|List| (|Record| (|:| |coef| |#1|) (|:| |monom| |#2|))) $) "\\spad{terms(f)} gives the list of non-zero coefficients combined with their corresponding basis element as records. This is the internal representation.")) (|coerce| (($ (|List| (|Record| (|:| |coef| |#1|) (|:| |monom| |#2|)))) "\\spad{coerce(lt)} converts a list of terms and coefficients to a member of the domain.")) (|coefficient| ((|#1| $ |#2|) "\\spad{coefficient(f,{}m)} extracts the coefficient of \\spad{m} in \\spad{f} with respect to the canonical basis \\spad{M}.")) (|monomial| (($ |#1| |#2|) "\\spad{monomial(r,{}m)} creates a scalar multiple of the basis element \\spad{m}."))) 
-((-4514 |has| |#1| (-172)) (-4513 |has| |#1| (-172)) (-4516 . T)) 
+((-4516 |has| |#1| (-172)) (-4515 |has| |#1| (-172)) (-4518 . T)) 
 ((-12 (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#2| (QUOTE (-370)))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#2| (QUOTE (-842)))) 
 (-726 S) 
 ((|constructor| (NIL "A multi-set aggregate is a set which keeps track of the multiplicity of its elements."))) 
-((-4509 . T) (-4520 . T) (-3973 . T)) 
+((-4511 . T) (-4522 . T) (-3973 . T)) 
 NIL 
 (-727 S) 
 ((|constructor| (NIL "A multiset is a set with multiplicities.")) (|remove!| (($ (|Mapping| (|Boolean|) |#1|) $ (|Integer|)) "\\spad{remove!(p,{}ms,{}number)} removes destructively at most \\spad{number} copies of elements \\spad{x} such that \\spad{p(x)} is \\spadfun{\\spad{true}} if \\spad{number} is positive,{} all of them if \\spad{number} equals zero,{} and all but at most \\spad{-number} if \\spad{number} is negative.") (($ |#1| $ (|Integer|)) "\\spad{remove!(x,{}ms,{}number)} removes destructively at most \\spad{number} copies of element \\spad{x} if \\spad{number} is positive,{} all of them if \\spad{number} equals zero,{} and all but at most \\spad{-number} if \\spad{number} is negative.")) (|remove| (($ (|Mapping| (|Boolean|) |#1|) $ (|Integer|)) "\\spad{remove(p,{}ms,{}number)} removes at most \\spad{number} copies of elements \\spad{x} such that \\spad{p(x)} is \\spadfun{\\spad{true}} if \\spad{number} is positive,{} all of them if \\spad{number} equals zero,{} and all but at most \\spad{-number} if \\spad{number} is negative.") (($ |#1| $ (|Integer|)) "\\spad{remove(x,{}ms,{}number)} removes at most \\spad{number} copies of element \\spad{x} if \\spad{number} is positive,{} all of them if \\spad{number} equals zero,{} and all but at most \\spad{-number} if \\spad{number} is negative.")) (|members| (((|List| |#1|) $) "\\spad{members(ms)} returns a list of the elements of \\spad{ms} without their multiplicity. See also \\spadfun{parts}.")) (|multiset| (($ (|List| |#1|)) "\\spad{multiset(ls)} creates a multiset with elements from \\spad{ls}.") (($ |#1|) "\\spad{multiset(s)} creates a multiset with singleton \\spad{s}.") (($) "\\spad{multiset()}\\$\\spad{D} creates an empty multiset of domain \\spad{D}."))) 
-((-4519 . T) (-4509 . T) (-4520 . T)) 
+((-4521 . T) (-4511 . T) (-4522 . T)) 
 ((|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090))))) 
 (-728) 
 ((|constructor| (NIL "\\spadtype{MoreSystemCommands} implements an interface with the system command facility. These are the commands that are issued from source files or the system interpreter and they start with a close parenthesis,{} \\spadignore{e.g.} the \"what\" commands.")) (|systemCommand| (((|Void|) (|String|)) "\\spad{systemCommand(cmd)} takes the string \\spadvar{\\spad{cmd}} and passes it to the runtime environment for execution as a system command. Although various things may be printed,{} no usable value is returned."))) 
@@ -2850,7 +2850,7 @@ NIL
 NIL 
 (-730 |Coef| |Var|) 
 ((|constructor| (NIL "\\spadtype{MultivariateTaylorSeriesCategory} is the most general multivariate Taylor series category.")) (|integrate| (($ $ |#2|) "\\spad{integrate(f,{}x)} returns the anti-derivative of the power series \\spad{f(x)} with respect to the variable \\spad{x} with constant coefficient 1. We may integrate a series when we can divide coefficients by integers.")) (|polynomial| (((|Polynomial| |#1|) $ (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{polynomial(f,{}k1,{}k2)} returns a polynomial consisting of the sum of all terms of \\spad{f} of degree \\spad{d} with \\spad{k1 <= d <= k2}.") (((|Polynomial| |#1|) $ (|NonNegativeInteger|)) "\\spad{polynomial(f,{}k)} returns a polynomial consisting of the sum of all terms of \\spad{f} of degree \\spad{<= k}.")) (|order| (((|NonNegativeInteger|) $ |#2| (|NonNegativeInteger|)) "\\spad{order(f,{}x,{}n)} returns \\spad{min(n,{}order(f,{}x))}.") (((|NonNegativeInteger|) $ |#2|) "\\spad{order(f,{}x)} returns the order of \\spad{f} viewed as a series in \\spad{x} may result in an infinite loop if \\spad{f} has no non-zero terms.")) (|monomial| (($ $ (|List| |#2|) (|List| (|NonNegativeInteger|))) "\\spad{monomial(a,{}[x1,{}x2,{}...,{}xk],{}[n1,{}n2,{}...,{}nk])} returns \\spad{a * x1^n1 * ... * xk^nk}.") (($ $ |#2| (|NonNegativeInteger|)) "\\spad{monomial(a,{}x,{}n)} returns \\spad{a*x^n}.")) (|extend| (($ $ (|NonNegativeInteger|)) "\\spad{extend(f,{}n)} causes all terms of \\spad{f} of degree \\spad{<= n} to be computed.")) (|coefficient| (($ $ (|List| |#2|) (|List| (|NonNegativeInteger|))) "\\spad{coefficient(f,{}[x1,{}x2,{}...,{}xk],{}[n1,{}n2,{}...,{}nk])} returns the coefficient of \\spad{x1^n1 * ... * xk^nk} in \\spad{f}.") (($ $ |#2| (|NonNegativeInteger|)) "\\spad{coefficient(f,{}x,{}n)} returns the coefficient of \\spad{x^n} in \\spad{f}."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4514 . T) (-4513 . T) (-4516 . T)) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4516 . T) (-4515 . T) (-4518 . T)) 
 NIL 
 (-731 OV E R P) 
 ((|constructor| (NIL "This is the top level package for doing multivariate factorization over basic domains like \\spadtype{Integer} or \\spadtype{Fraction Integer}.")) (|factor| (((|Factored| (|SparseUnivariatePolynomial| |#4|)) (|SparseUnivariatePolynomial| |#4|)) "\\spad{factor(p)} factors the multivariate polynomial \\spad{p} over its coefficient domain where \\spad{p} is represented as a univariate polynomial with multivariate coefficients") (((|Factored| |#4|) |#4|) "\\spad{factor(p)} factors the multivariate polynomial \\spad{p} over its coefficient domain"))) 
@@ -2862,19 +2862,19 @@ NIL
 NIL 
 (-733 |q| R) 
 ((|constructor| (NIL "This domain has no description"))) 
-((-4517 |has| |#2| (-558)) (-4511 |has| |#2| (-558)) (-4516 -2198 (|has| |#2| (-478)) (|has| |#2| (-1047))) (-4514 |has| |#2| (-172)) (-4513 |has| |#2| (-172)) ((-4521 "*") |has| |#2| (-558)) (-4512 |has| |#2| (-558))) 
-((|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (QUOTE (-1047))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-478))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (-2198 (|HasCategory| |#2| (QUOTE (-478))) (|HasCategory| |#2| (QUOTE (-558)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-2198 (|HasCategory| |#2| (QUOTE (-478))) (|HasCategory| |#2| (QUOTE (-1047)))) (|HasCategory| |#2| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-1102))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-558)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-558)))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-558))))) (|HasCategory| $ (QUOTE (-1047))) (|HasCategory| $ (LIST (QUOTE -1037) (QUOTE (-568))))) 
+((-4519 |has| |#2| (-558)) (-4513 |has| |#2| (-558)) (-4518 -2199 (|has| |#2| (-478)) (|has| |#2| (-1047))) (-4516 |has| |#2| (-172)) (-4515 |has| |#2| (-172)) ((-4523 "*") |has| |#2| (-558)) (-4514 |has| |#2| (-558))) 
+((|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (QUOTE (-1047))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-478))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (-2199 (|HasCategory| |#2| (QUOTE (-478))) (|HasCategory| |#2| (QUOTE (-558)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-2199 (|HasCategory| |#2| (QUOTE (-478))) (|HasCategory| |#2| (QUOTE (-1047)))) (|HasCategory| |#2| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-1102))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-558)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-558)))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-558))))) (|HasCategory| $ (QUOTE (-1047))) (|HasCategory| $ (LIST (QUOTE -1037) (QUOTE (-568))))) 
 (-734 |x| R) 
 ((|constructor| (NIL "This domain has no description")) (|fmecg| (($ $ (|NonNegativeInteger|) |#2| $) "\\spad{fmecg(p1,{}e,{}r,{}p2)} finds \\spad{x} : \\spad{p1} - \\spad{r} * x**e * \\spad{p2}")) (|coerce| (($ (|Variable| |#1|)) "\\spad{coerce(x)} converts the variable \\spad{x} to a univariate polynomial."))) 
-(((-4521 "*") |has| |#2| (-172)) (-4512 |has| |#2| (-558)) (-4515 |has| |#2| (-365)) (-4517 |has| |#2| (-6 -4517)) (-4514 . T) (-4513 . T) (-4516 . T)) 
-((|HasCategory| |#2| (QUOTE (-904))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-172))) (-2198 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-558)))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#2| (QUOTE (-842))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1136))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasCategory| |#2| (QUOTE (-225))) (|HasAttribute| |#2| (QUOTE -4517)) (|HasCategory| |#2| (QUOTE (-453))) (-2198 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2198 (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2198 (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (|HasCategory| |#2| (QUOTE (-148))))) 
+(((-4523 "*") |has| |#2| (-172)) (-4514 |has| |#2| (-558)) (-4517 |has| |#2| (-365)) (-4519 |has| |#2| (-6 -4519)) (-4516 . T) (-4515 . T) (-4518 . T)) 
+((|HasCategory| |#2| (QUOTE (-904))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-172))) (-2199 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-558)))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#2| (QUOTE (-842))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1136))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasCategory| |#2| (QUOTE (-225))) (|HasAttribute| |#2| (QUOTE -4519)) (|HasCategory| |#2| (QUOTE (-453))) (-2199 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2199 (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2199 (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (|HasCategory| |#2| (QUOTE (-148))))) 
 (-735 S R) 
 ((|constructor| (NIL "NonAssociativeAlgebra is the category of non associative algebras (modules which are themselves non associative rngs).\\spad{\\br} \\blankline Axioms\\spad{\\br} \\tab{5}\\spad{r*}(a*b) = (r*a)\\spad{*b} = a*(\\spad{r*b})")) (|plenaryPower| (($ $ (|PositiveInteger|)) "\\spad{plenaryPower(a,{}n)} is recursively defined to be \\spad{plenaryPower(a,{}n-1)*plenaryPower(a,{}n-1)} for \\spad{n>1} and \\spad{a} for \\spad{n=1}."))) 
 NIL 
 NIL 
 (-736 R) 
 ((|constructor| (NIL "NonAssociativeAlgebra is the category of non associative algebras (modules which are themselves non associative rngs).\\spad{\\br} \\blankline Axioms\\spad{\\br} \\tab{5}\\spad{r*}(a*b) = (r*a)\\spad{*b} = a*(\\spad{r*b})")) (|plenaryPower| (($ $ (|PositiveInteger|)) "\\spad{plenaryPower(a,{}n)} is recursively defined to be \\spad{plenaryPower(a,{}n-1)*plenaryPower(a,{}n-1)} for \\spad{n>1} and \\spad{a} for \\spad{n=1}."))) 
-((-4514 . T) (-4513 . T)) 
+((-4516 . T) (-4515 . T)) 
 NIL 
 (-737) 
 ((|constructor| (NIL "This package uses the NAG Library to compute the zeros of a polynomial with real or complex coefficients.")) (|c02agf| (((|Result|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Boolean|) (|Integer|)) "\\spad{c02agf(a,{}n,{}scale,{}ifail)} finds all the roots of a real polynomial equation,{} using a variant of Laguerre\\spad{'s} Method. See \\downlink{Manual Page}{manpageXXc02agf}.")) (|c02aff| (((|Result|) (|Matrix| (|DoubleFloat|)) (|Integer|) (|Boolean|) (|Integer|)) "\\spad{c02aff(a,{}n,{}scale,{}ifail)} finds all the roots of a complex polynomial equation,{} using a variant of Laguerre\\spad{'s} Method. See \\downlink{Manual Page}{manpageXXc02aff}."))) 
@@ -2982,7 +2982,7 @@ NIL
 NIL 
 (-763) 
 ((|constructor| (NIL "\\spadtype{NonNegativeInteger} provides functions for non-negative integers.")) (|commutative| ((|attribute| "*") "\\spad{commutative(\"*\")} means multiplication is commutative,{} that is,{} \\spad{x*y = y*x}.")) (|random| (($ $) "\\spad{random(n)} returns a random integer from 0 to \\spad{n-1}.")) (|shift| (($ $ (|Integer|)) "\\spad{shift(a,{}i)} shift \\spad{a} by \\spad{i} bits.")) (|exquo| (((|Union| $ "failed") $ $) "\\spad{exquo(a,{}b)} returns the quotient of \\spad{a} and \\spad{b},{} or \"failed\" if \\spad{b} is zero or \\spad{a} rem \\spad{b} is zero.")) (|divide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{divide(a,{}b)} returns a record containing both remainder and quotient.")) (|gcd| (($ $ $) "\\spad{gcd(a,{}b)} computes the greatest common divisor of two non negative integers \\spad{a} and \\spad{b}.")) (|rem| (($ $ $) "\\spad{a rem b} returns the remainder of \\spad{a} and \\spad{b}.")) (|quo| (($ $ $) "\\spad{a quo b} returns the quotient of \\spad{a} and \\spad{b},{} forgetting the remainder."))) 
-(((-4521 "*") . T)) 
+(((-4523 "*") . T)) 
 NIL 
 (-764 R -1478) 
 ((|constructor| (NIL "NonLinearFirstOrderODESolver provides a function for finding closed form first integrals of nonlinear ordinary differential equations of order 1.")) (|solve| (((|Union| |#2| "failed") |#2| |#2| (|BasicOperator|) (|Symbol|)) "\\spad{solve(M(x,{}y),{} N(x,{}y),{} y,{} x)} returns \\spad{F(x,{}y)} such that \\spad{F(x,{}y) = c} for a constant \\spad{c} is a first integral of the equation \\spad{M(x,{}y) dx + N(x,{}y) dy = 0},{} or \"failed\" if no first-integral can be found."))) 
@@ -3010,13 +3010,13 @@ NIL
 NIL 
 (-770 -1478) 
 ((|constructor| (NIL "This is an implmenentation of the Nottingham Group"))) 
-((-4516 . T)) 
+((-4518 . T)) 
 NIL 
 (-771 BP E OV R P) 
 ((|constructor| (NIL "Package for the determination of the coefficients in the lifting process. Used by \\spadtype{MultivariateLifting}. This package will work for every euclidean domain \\spad{R} which has property \\spad{F},{} \\spadignore{i.e.} there exists a factor operation in \\spad{R[x]}.")) (|listexp| (((|List| (|NonNegativeInteger|)) |#1|) "\\spad{listexp }\\undocumented")) (|npcoef| (((|Record| (|:| |deter| (|List| (|SparseUnivariatePolynomial| |#5|))) (|:| |dterm| (|List| (|List| (|Record| (|:| |expt| (|NonNegativeInteger|)) (|:| |pcoef| |#5|))))) (|:| |nfacts| (|List| |#1|)) (|:| |nlead| (|List| |#5|))) (|SparseUnivariatePolynomial| |#5|) (|List| |#1|) (|List| |#5|)) "\\spad{npcoef }\\undocumented"))) 
 NIL 
 NIL 
-(-772 K |PolyRing| E -2570) 
+(-772 K |PolyRing| E -1965) 
 ((|constructor| (NIL "The following is part of the PAFF package"))) 
 NIL 
 NIL 
@@ -3026,27 +3026,27 @@ NIL
 NIL 
 (-774 K) 
 ((|constructor| (NIL "This domain is part of the PAFF package"))) 
-(((-4521 "*") . T) (-4512 . T) (-4511 . T) (-4517 . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-1102))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-568)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-568)) (|devaluate| |#1|))))) (|HasCategory| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-568))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -2745) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| (-568) (QUOTE (-842))) (|HasCategory| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE |k|) (QUOTE (-568))) (LIST (QUOTE |:|) (QUOTE |c|) (|devaluate| |#1|))))) (|HasCategory| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568)))))) 
+(((-4523 "*") . T) (-4514 . T) (-4513 . T) (-4519 . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-1102))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-568)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-568)) (|devaluate| |#1|))))) (|HasCategory| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-568))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -2747) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| (-568) (QUOTE (-842))) (|HasCategory| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE |k|) (QUOTE (-568))) (LIST (QUOTE |:|) (QUOTE |c|) (|devaluate| |#1|))))) (|HasCategory| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568)))))) 
 (-775 R |VarSet|) 
 ((|constructor| (NIL "A post-facto extension for \\axiomType{\\spad{SMP}} in order to speed up operations related to pseudo-division and \\spad{gcd}. This domain is based on the \\axiomType{NSUP} constructor which is itself a post-facto extension of the \\axiomType{SUP} constructor."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-6 -4517)) (-4514 . T) (-4513 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-1161)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-1161))))) (|HasCategory| |#1| (QUOTE (-365))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-1161))))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-1161)))) (-3044 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-1161)))))) (-2198 (-12 (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-1161)))) (-3044 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568)))))) (-3044 (|HasCategory| |#1| (LIST (QUOTE -43) (QUOTE (-568)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-1161)))) (-3044 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568)))))) (-3044 (|HasCategory| |#1| (QUOTE (-550))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-1161)))) (-3044 (|HasCategory| |#1| (LIST (QUOTE -993) (QUOTE (-568))))))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#1| (QUOTE -4517)) (|HasCategory| |#1| (QUOTE (-453))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-6 -4519)) (-4516 . T) (-4515 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-1161)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-1161))))) (|HasCategory| |#1| (QUOTE (-365))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-1161))))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-1161)))) (-3046 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-1161)))))) (-2199 (-12 (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-1161)))) (-3046 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568)))))) (-3046 (|HasCategory| |#1| (LIST (QUOTE -43) (QUOTE (-568)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-1161)))) (-3046 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568)))))) (-3046 (|HasCategory| |#1| (QUOTE (-550))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-1161)))) (-3046 (|HasCategory| |#1| (LIST (QUOTE -993) (QUOTE (-568))))))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#1| (QUOTE -4519)) (|HasCategory| |#1| (QUOTE (-453))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))))) 
 (-776 R S) 
 ((|constructor| (NIL "This package lifts a mapping from coefficient rings \\spad{R} to \\spad{S} to a mapping from sparse univariate polynomial over \\spad{R} to a sparse univariate polynomial over \\spad{S}. Note that the mapping is assumed to send zero to zero,{} since it will only be applied to the non-zero coefficients of the polynomial.")) (|map| (((|NewSparseUnivariatePolynomial| |#2|) (|Mapping| |#2| |#1|) (|NewSparseUnivariatePolynomial| |#1|)) "\\axiom{map(func,{} poly)} creates a new polynomial by applying func to every non-zero coefficient of the polynomial poly."))) 
 NIL 
 NIL 
 (-777 R) 
 ((|constructor| (NIL "A post-facto extension for \\axiomType{SUP} in order to speed up operations related to pseudo-division and \\spad{gcd} for both \\axiomType{SUP} and,{} consequently,{} \\axiomType{NSMP}.")) (|halfExtendedResultant2| (((|Record| (|:| |resultant| |#1|) (|:| |coef2| $)) $ $) "\\axiom{\\spad{halfExtendedResultant2}(a,{}\\spad{b})} returns \\axiom{[\\spad{r},{}ca]} such that \\axiom{extendedResultant(a,{}\\spad{b})} returns \\axiom{[\\spad{r},{}ca,{} \\spad{cb}]}")) (|halfExtendedResultant1| (((|Record| (|:| |resultant| |#1|) (|:| |coef1| $)) $ $) "\\axiom{\\spad{halfExtendedResultant1}(a,{}\\spad{b})} returns \\axiom{[\\spad{r},{}ca]} such that \\axiom{extendedResultant(a,{}\\spad{b})} returns \\axiom{[\\spad{r},{}ca,{} \\spad{cb}]}")) (|extendedResultant| (((|Record| (|:| |resultant| |#1|) (|:| |coef1| $) (|:| |coef2| $)) $ $) "\\axiom{extendedResultant(a,{}\\spad{b})} returns \\axiom{[\\spad{r},{}ca,{}\\spad{cb}]} such that \\axiom{\\spad{r}} is the resultant of \\axiom{a} and \\axiom{\\spad{b}} and \\axiom{\\spad{r} = ca * a + \\spad{cb} * \\spad{b}}")) (|halfExtendedSubResultantGcd2| (((|Record| (|:| |gcd| $) (|:| |coef2| $)) $ $) "\\axiom{\\spad{halfExtendedSubResultantGcd2}(a,{}\\spad{b})} returns \\axiom{[\\spad{g},{}\\spad{cb}]} such that \\axiom{extendedSubResultantGcd(a,{}\\spad{b})} returns \\axiom{[\\spad{g},{}ca,{} \\spad{cb}]}")) (|halfExtendedSubResultantGcd1| (((|Record| (|:| |gcd| $) (|:| |coef1| $)) $ $) "\\axiom{\\spad{halfExtendedSubResultantGcd1}(a,{}\\spad{b})} returns \\axiom{[\\spad{g},{}ca]} such that \\axiom{extendedSubResultantGcd(a,{}\\spad{b})} returns \\axiom{[\\spad{g},{}ca,{} \\spad{cb}]}")) (|extendedSubResultantGcd| (((|Record| (|:| |gcd| $) (|:| |coef1| $) (|:| |coef2| $)) $ $) "\\axiom{extendedSubResultantGcd(a,{}\\spad{b})} returns \\axiom{[\\spad{g},{}ca,{} \\spad{cb}]} such that \\axiom{\\spad{g}} is a \\spad{gcd} of \\axiom{a} and \\axiom{\\spad{b}} in \\axiom{\\spad{R^}(\\spad{-1}) \\spad{P}} and \\axiom{\\spad{g} = ca * a + \\spad{cb} * \\spad{b}}")) (|lastSubResultant| (($ $ $) "\\axiom{lastSubResultant(a,{}\\spad{b})} returns \\axiom{resultant(a,{}\\spad{b})} if \\axiom{a} and \\axiom{\\spad{b}} has no non-trivial \\spad{gcd} in \\axiom{\\spad{R^}(\\spad{-1}) \\spad{P}} otherwise the non-zero sub-resultant with smallest index.")) (|subResultantsChain| (((|List| $) $ $) "\\axiom{subResultantsChain(a,{}\\spad{b})} returns the list of the non-zero sub-resultants of \\axiom{a} and \\axiom{\\spad{b}} sorted by increasing degree.")) (|lazyPseudoQuotient| (($ $ $) "\\axiom{lazyPseudoQuotient(a,{}\\spad{b})} returns \\axiom{\\spad{q}} if \\axiom{lazyPseudoDivide(a,{}\\spad{b})} returns \\axiom{[\\spad{c},{}\\spad{g},{}\\spad{q},{}\\spad{r}]}")) (|lazyPseudoDivide| (((|Record| (|:| |coef| |#1|) (|:| |gap| (|NonNegativeInteger|)) (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\axiom{lazyPseudoDivide(a,{}\\spad{b})} returns \\axiom{[\\spad{c},{}\\spad{g},{}\\spad{q},{}\\spad{r}]} such that \\axiom{\\spad{c^n} * a = \\spad{q*b} \\spad{+r}} and \\axiom{lazyResidueClass(a,{}\\spad{b})} returns \\axiom{[\\spad{r},{}\\spad{c},{}\\spad{n}]} where \\axiom{\\spad{n} + \\spad{g} = max(0,{} degree(\\spad{b}) - degree(a) + 1)}.")) (|lazyPseudoRemainder| (($ $ $) "\\axiom{lazyPseudoRemainder(a,{}\\spad{b})} returns \\axiom{\\spad{r}} if \\axiom{lazyResidueClass(a,{}\\spad{b})} returns \\axiom{[\\spad{r},{}\\spad{c},{}\\spad{n}]}. This lazy pseudo-remainder is computed by means of the fmecg from NewSparseUnivariatePolynomial operation.")) (|lazyResidueClass| (((|Record| (|:| |polnum| $) (|:| |polden| |#1|) (|:| |power| (|NonNegativeInteger|))) $ $) "\\axiom{lazyResidueClass(a,{}\\spad{b})} returns \\axiom{[\\spad{r},{}\\spad{c},{}\\spad{n}]} such that \\axiom{\\spad{r}} is reduced \\spad{w}.\\spad{r}.\\spad{t}. \\axiom{\\spad{b}} and \\axiom{\\spad{b}} divides \\axiom{\\spad{c^n} * a - \\spad{r}} where \\axiom{\\spad{c}} is \\axiom{leadingCoefficient(\\spad{b})} and \\axiom{\\spad{n}} is as small as possible with the previous properties.")) (|monicModulo| (($ $ $) "\\axiom{monicModulo(a,{}\\spad{b})} returns \\axiom{\\spad{r}} such that \\axiom{\\spad{r}} is reduced \\spad{w}.\\spad{r}.\\spad{t}. \\axiom{\\spad{b}} and \\axiom{\\spad{b}} divides \\axiom{a \\spad{-r}} where \\axiom{\\spad{b}} is monic.")) (|fmecg| (($ $ (|NonNegativeInteger|) |#1| $) "\\axiom{fmecg(\\spad{p1},{}\\spad{e},{}\\spad{r},{}\\spad{p2})} returns \\axiom{\\spad{p1} - \\spad{r} * x**e * \\spad{p2}} where \\axiom{\\spad{x}} is \\axiom{monomial(1,{}1)}"))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4515 |has| |#1| (-365)) (-4517 |has| |#1| (-6 -4517)) (-4514 . T) (-4513 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-1136))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasCategory| |#1| (QUOTE (-225))) (|HasAttribute| |#1| (QUOTE -4517)) (|HasCategory| |#1| (QUOTE (-453))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4517 |has| |#1| (-365)) (-4519 |has| |#1| (-6 -4519)) (-4516 . T) (-4515 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-1136))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasCategory| |#1| (QUOTE (-225))) (|HasAttribute| |#1| (QUOTE -4519)) (|HasCategory| |#1| (QUOTE (-453))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))))) 
 (-778 R) 
 ((|constructor| (NIL "This package provides polynomials as functions on a ring.")) (|eulerE| ((|#1| (|NonNegativeInteger|) |#1|) "\\spad{eulerE(n,{}r)} \\undocumented")) (|bernoulliB| ((|#1| (|NonNegativeInteger|) |#1|) "\\spad{bernoulliB(n,{}r)} \\undocumented")) (|cyclotomic| ((|#1| (|NonNegativeInteger|) |#1|) "\\spad{cyclotomic(n,{}r)} \\undocumented"))) 
 NIL 
 ((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568)))))) 
 (-779 R E V P) 
 ((|constructor| (NIL "The category of normalized triangular sets. A triangular set \\spad{ts} is said normalized if for every algebraic variable \\spad{v} of \\spad{ts} the polynomial \\spad{select(ts,{}v)} is normalized \\spad{w}.\\spad{r}.\\spad{t}. every polynomial in \\spad{collectUnder(ts,{}v)}. A polynomial \\spad{p} is said normalized \\spad{w}.\\spad{r}.\\spad{t}. a non-constant polynomial \\spad{q} if \\spad{p} is constant or \\spad{degree(p,{}mdeg(q)) = 0} and \\spad{init(p)} is normalized \\spad{w}.\\spad{r}.\\spad{t}. \\spad{q}. One of the important features of normalized triangular sets is that they are regular sets."))) 
-((-4520 . T) (-4519 . T) (-3973 . T)) 
+((-4522 . T) (-4521 . T) (-3973 . T)) 
 NIL 
 (-780 S) 
 ((|constructor| (NIL "Numeric provides real and complex numerical evaluation functions for various symbolic types.")) (|numericIfCan| (((|Union| (|Float|) "failed") (|Expression| |#1|) (|PositiveInteger|)) "\\spad{numericIfCan(x,{} n)} returns a real approximation of \\spad{x} up to \\spad{n} decimal places,{} or \"failed\" if \\axiom{\\spad{x}} is not a constant.") (((|Union| (|Float|) "failed") (|Expression| |#1|)) "\\spad{numericIfCan(x)} returns a real approximation of \\spad{x},{} or \"failed\" if \\axiom{\\spad{x}} is not a constant.") (((|Union| (|Float|) "failed") (|Fraction| (|Polynomial| |#1|)) (|PositiveInteger|)) "\\spad{numericIfCan(x,{}n)} returns a real approximation of \\spad{x} up to \\spad{n} decimal places,{} or \"failed\" if \\axiom{\\spad{x}} is not a constant.") (((|Union| (|Float|) "failed") (|Fraction| (|Polynomial| |#1|))) "\\spad{numericIfCan(x)} returns a real approximation of \\spad{x},{} or \"failed\" if \\axiom{\\spad{x}} is not a constant.") (((|Union| (|Float|) "failed") (|Polynomial| |#1|) (|PositiveInteger|)) "\\spad{numericIfCan(x,{}n)} returns a real approximation of \\spad{x} up to \\spad{n} decimal places,{} or \"failed\" if \\axiom{\\spad{x}} is not a constant.") (((|Union| (|Float|) "failed") (|Polynomial| |#1|)) "\\spad{numericIfCan(x)} returns a real approximation of \\spad{x},{} or \"failed\" if \\axiom{\\spad{x}} is not a constant.")) (|complexNumericIfCan| (((|Union| (|Complex| (|Float|)) "failed") (|Expression| (|Complex| |#1|)) (|PositiveInteger|)) "\\spad{complexNumericIfCan(x,{} n)} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places,{} or \"failed\" if \\axiom{\\spad{x}} is not a constant.") (((|Union| (|Complex| (|Float|)) "failed") (|Expression| (|Complex| |#1|))) "\\spad{complexNumericIfCan(x)} returns a complex approximation of \\spad{x},{} or \"failed\" if \\axiom{\\spad{x}} is not a constant.") (((|Union| (|Complex| (|Float|)) "failed") (|Expression| |#1|) (|PositiveInteger|)) "\\spad{complexNumericIfCan(x,{} n)} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places,{} or \"failed\" if \\axiom{\\spad{x}} is not a constant.") (((|Union| (|Complex| (|Float|)) "failed") (|Expression| |#1|)) "\\spad{complexNumericIfCan(x)} returns a complex approximation of \\spad{x},{} or \"failed\" if \\axiom{\\spad{x}} is not a constant.") (((|Union| (|Complex| (|Float|)) "failed") (|Fraction| (|Polynomial| (|Complex| |#1|))) (|PositiveInteger|)) "\\spad{complexNumericIfCan(x,{} n)} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places,{} or \"failed\" if \\axiom{\\spad{x}} is not a constant.") (((|Union| (|Complex| (|Float|)) "failed") (|Fraction| (|Polynomial| (|Complex| |#1|)))) "\\spad{complexNumericIfCan(x)} returns a complex approximation of \\spad{x},{} or \"failed\" if \\axiom{\\spad{x}} is not a constant.") (((|Union| (|Complex| (|Float|)) "failed") (|Fraction| (|Polynomial| |#1|)) (|PositiveInteger|)) "\\spad{complexNumericIfCan(x,{} n)} returns a complex approximation of \\spad{x},{} or \"failed\" if \\axiom{\\spad{x}} is not a constant.") (((|Union| (|Complex| (|Float|)) "failed") (|Fraction| (|Polynomial| |#1|))) "\\spad{complexNumericIfCan(x)} returns a complex approximation of \\spad{x},{} or \"failed\" if \\axiom{\\spad{x}} is not a constant.") (((|Union| (|Complex| (|Float|)) "failed") (|Polynomial| |#1|) (|PositiveInteger|)) "\\spad{complexNumericIfCan(x,{} n)} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places,{} or \"failed\" if \\axiom{\\spad{x}} is not a constant.") (((|Union| (|Complex| (|Float|)) "failed") (|Polynomial| |#1|)) "\\spad{complexNumericIfCan(x)} returns a complex approximation of \\spad{x},{} or \"failed\" if \\axiom{\\spad{x}} is not a constant.") (((|Union| (|Complex| (|Float|)) "failed") (|Polynomial| (|Complex| |#1|)) (|PositiveInteger|)) "\\spad{complexNumericIfCan(x,{} n)} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places,{} or \"failed\" if \\axiom{\\spad{x}} is not a constant.") (((|Union| (|Complex| (|Float|)) "failed") (|Polynomial| (|Complex| |#1|))) "\\spad{complexNumericIfCan(x)} returns a complex approximation of \\spad{x},{} or \"failed\" if \\axiom{\\spad{x}} is not constant.")) (|complexNumeric| (((|Complex| (|Float|)) (|Expression| (|Complex| |#1|)) (|PositiveInteger|)) "\\spad{complexNumeric(x,{} n)} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places.") (((|Complex| (|Float|)) (|Expression| (|Complex| |#1|))) "\\spad{complexNumeric(x)} returns a complex approximation of \\spad{x}.") (((|Complex| (|Float|)) (|Expression| |#1|) (|PositiveInteger|)) "\\spad{complexNumeric(x,{} n)} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places.") (((|Complex| (|Float|)) (|Expression| |#1|)) "\\spad{complexNumeric(x)} returns a complex approximation of \\spad{x}.") (((|Complex| (|Float|)) (|Fraction| (|Polynomial| (|Complex| |#1|))) (|PositiveInteger|)) "\\spad{complexNumeric(x,{} n)} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places.") (((|Complex| (|Float|)) (|Fraction| (|Polynomial| (|Complex| |#1|)))) "\\spad{complexNumeric(x)} returns a complex approximation of \\spad{x}.") (((|Complex| (|Float|)) (|Fraction| (|Polynomial| |#1|)) (|PositiveInteger|)) "\\spad{complexNumeric(x,{} n)} returns a complex approximation of \\spad{x}") (((|Complex| (|Float|)) (|Fraction| (|Polynomial| |#1|))) "\\spad{complexNumeric(x)} returns a complex approximation of \\spad{x}.") (((|Complex| (|Float|)) (|Polynomial| |#1|) (|PositiveInteger|)) "\\spad{complexNumeric(x,{} n)} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places.") (((|Complex| (|Float|)) (|Polynomial| |#1|)) "\\spad{complexNumeric(x)} returns a complex approximation of \\spad{x}.") (((|Complex| (|Float|)) (|Polynomial| (|Complex| |#1|)) (|PositiveInteger|)) "\\spad{complexNumeric(x,{} n)} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places.") (((|Complex| (|Float|)) (|Polynomial| (|Complex| |#1|))) "\\spad{complexNumeric(x)} returns a complex approximation of \\spad{x}.") (((|Complex| (|Float|)) (|Complex| |#1|) (|PositiveInteger|)) "\\spad{complexNumeric(x,{} n)} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places.") (((|Complex| (|Float|)) (|Complex| |#1|)) "\\spad{complexNumeric(x)} returns a complex approximation of \\spad{x}.") (((|Complex| (|Float|)) |#1| (|PositiveInteger|)) "\\spad{complexNumeric(x,{} n)} returns a complex approximation of \\spad{x} up to \\spad{n} decimal places.") (((|Complex| (|Float|)) |#1|) "\\spad{complexNumeric(x)} returns a complex approximation of \\spad{x}.")) (|numeric| (((|Float|) (|Expression| |#1|) (|PositiveInteger|)) "\\spad{numeric(x,{} n)} returns a real approximation of \\spad{x} up to \\spad{n} decimal places.") (((|Float|) (|Expression| |#1|)) "\\spad{numeric(x)} returns a real approximation of \\spad{x}.") (((|Float|) (|Fraction| (|Polynomial| |#1|)) (|PositiveInteger|)) "\\spad{numeric(x,{}n)} returns a real approximation of \\spad{x} up to \\spad{n} decimal places.") (((|Float|) (|Fraction| (|Polynomial| |#1|))) "\\spad{numeric(x)} returns a real approximation of \\spad{x}.") (((|Float|) (|Polynomial| |#1|) (|PositiveInteger|)) "\\spad{numeric(x,{}n)} returns a real approximation of \\spad{x} up to \\spad{n} decimal places.") (((|Float|) (|Polynomial| |#1|)) "\\spad{numeric(x)} returns a real approximation of \\spad{x}.") (((|Float|) |#1| (|PositiveInteger|)) "\\spad{numeric(x,{} n)} returns a real approximation of \\spad{x} up to \\spad{n} decimal places.") (((|Float|) |#1|) "\\spad{numeric(x)} returns a real approximation of \\spad{x}."))) 
@@ -3098,16 +3098,16 @@ NIL
 ((|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-550))) (|HasCategory| |#2| (QUOTE (-1056))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-370)))) 
 (-792 R) 
 ((|constructor| (NIL "OctonionCategory gives the categorial frame for the octonions,{} and eight-dimensional non-associative algebra,{} doubling the the quaternions in the same way as doubling the Complex numbers to get the quaternions.")) (|inv| (($ $) "\\spad{inv(o)} returns the inverse of \\spad{o} if it exists.")) (|rationalIfCan| (((|Union| (|Fraction| (|Integer|)) "failed") $) "\\spad{rationalIfCan(o)} returns the real part if all seven imaginary parts are 0,{} and \"failed\" otherwise.")) (|rational| (((|Fraction| (|Integer|)) $) "\\spad{rational(o)} returns the real part if all seven imaginary parts are 0. Error: if \\spad{o} is not rational.")) (|rational?| (((|Boolean|) $) "\\spad{rational?(o)} tests if \\spad{o} is rational,{} \\spadignore{i.e.} that all seven imaginary parts are 0.")) (|abs| ((|#1| $) "\\spad{abs(o)} computes the absolute value of an octonion,{} equal to the square root of the \\spadfunFrom{norm}{Octonion}.")) (|octon| (($ |#1| |#1| |#1| |#1| |#1| |#1| |#1| |#1|) "\\spad{octon(re,{}\\spad{ri},{}rj,{}rk,{}rE,{}rI,{}rJ,{}rK)} constructs an octonion from scalars.")) (|norm| ((|#1| $) "\\spad{norm(o)} returns the norm of an octonion,{} equal to the sum of the squares of its coefficients.")) (|imagK| ((|#1| $) "\\spad{imagK(o)} extracts the imaginary \\spad{K} part of octonion \\spad{o}.")) (|imagJ| ((|#1| $) "\\spad{imagJ(o)} extracts the imaginary \\spad{J} part of octonion \\spad{o}.")) (|imagI| ((|#1| $) "\\spad{imagI(o)} extracts the imaginary \\spad{I} part of octonion \\spad{o}.")) (|imagE| ((|#1| $) "\\spad{imagE(o)} extracts the imaginary \\spad{E} part of octonion \\spad{o}.")) (|imagk| ((|#1| $) "\\spad{imagk(o)} extracts the \\spad{k} part of octonion \\spad{o}.")) (|imagj| ((|#1| $) "\\spad{imagj(o)} extracts the \\spad{j} part of octonion \\spad{o}.")) (|imagi| ((|#1| $) "\\spad{imagi(o)} extracts the \\spad{i} part of octonion \\spad{o}.")) (|real| ((|#1| $) "\\spad{real(o)} extracts real part of octonion \\spad{o}.")) (|conjugate| (($ $) "\\spad{conjugate(o)} negates the imaginary parts \\spad{i},{}\\spad{j},{}\\spad{k},{}\\spad{E},{}\\spad{I},{}\\spad{J},{}\\spad{K} of octonian \\spad{o}."))) 
-((-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
-(-793 -2198 R OS S) 
+(-793 -2199 R OS S) 
 ((|constructor| (NIL "\\spad{OctonionCategoryFunctions2} implements functions between two octonion domains defined over different rings. The function map is used to coerce between octonion types.")) (|map| ((|#3| (|Mapping| |#4| |#2|) |#1|) "\\spad{map(f,{}u)} maps \\spad{f} onto the component parts of the octonion \\spad{u}."))) 
 NIL 
 NIL 
 (-794 R) 
 ((|constructor| (NIL "Octonion implements octonions (Cayley-Dixon algebra) over a commutative ring,{} an eight-dimensional non-associative algebra,{} doubling the quaternions in the same way as doubling the complex numbers to get the quaternions the main constructor function is octon which takes 8 arguments: the real part,{} the \\spad{i} imaginary part,{} the \\spad{j} imaginary part,{} the \\spad{k} imaginary part,{} (as with quaternions) and in addition the imaginary parts \\spad{E},{} \\spad{I},{} \\spad{J},{} \\spad{K}.")) (|octon| (($ (|Quaternion| |#1|) (|Quaternion| |#1|)) "\\spad{octon(qe,{}qE)} constructs an octonion from two quaternions using the relation \\spad{O} = \\spad{Q} + QE."))) 
-((-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (LIST (QUOTE -523) (QUOTE (-1161)) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -281) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1056))) (|HasCategory| |#1| (QUOTE (-550))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| (-999 |#1|) (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| (-999 |#1|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (-2198 (|HasCategory| (-999 |#1|) (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (-2198 (|HasCategory| (-999 |#1|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))))) 
+((-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (LIST (QUOTE -523) (QUOTE (-1161)) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -281) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1056))) (|HasCategory| |#1| (QUOTE (-550))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| (-999 |#1|) (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| (-999 |#1|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (-2199 (|HasCategory| (-999 |#1|) (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (-2199 (|HasCategory| (-999 |#1|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))))) 
 (-795) 
 ((|constructor| (NIL "\\axiomType{OrdinaryDifferentialEquationsSolverCategory} is the \\axiom{category} for describing the set of ODE solver \\axiom{domains} with \\axiomFun{measure} and \\axiomFun{ODEsolve}.")) (|ODESolve| (((|Result|) (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\spad{ODESolve(args)} performs the integration of the function given the strategy or method returned by \\axiomFun{measure}.")) (|measure| (((|Record| (|:| |measure| (|Float|)) (|:| |explanations| (|String|))) (|RoutinesTable|) (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) "\\spad{measure(R,{}args)} calculates an estimate of the ability of a particular method to solve a problem. \\blankline This method may be either a specific NAG routine or a strategy (such as transforming the function from one which is difficult to one which is easier to solve). \\blankline It will call whichever agents are needed to perform analysis on the problem in order to calculate the measure. There is a parameter,{} labelled \\axiom{sofar},{} which would contain the best compatibility found so far."))) 
 NIL 
@@ -3168,17 +3168,17 @@ NIL
 ((|constructor| (NIL "\\spad{ODETools} provides tools for the linear ODE solver.")) (|particularSolution| (((|Union| |#1| "failed") |#2| |#1| (|List| |#1|) (|Mapping| |#1| |#1|)) "\\spad{particularSolution(op,{} g,{} [f1,{}...,{}fm],{} I)} returns a particular solution \\spad{h} of the equation \\spad{op y = g} where \\spad{[f1,{}...,{}fm]} are linearly independent and \\spad{op(\\spad{fi})=0}. The value \"failed\" is returned if no particular solution is found. Note that the method of variations of parameters is used.")) (|variationOfParameters| (((|Union| (|Vector| |#1|) "failed") |#2| |#1| (|List| |#1|)) "\\spad{variationOfParameters(op,{} g,{} [f1,{}...,{}fm])} returns \\spad{[u1,{}...,{}um]} such that a particular solution of the equation \\spad{op y = g} is \\spad{f1 int(u1) + ... + fm int(um)} where \\spad{[f1,{}...,{}fm]} are linearly independent and \\spad{op(\\spad{fi})=0}. The value \"failed\" is returned if \\spad{m < n} and no particular solution is found.")) (|wronskianMatrix| (((|Matrix| |#1|) (|List| |#1|) (|NonNegativeInteger|)) "\\spad{wronskianMatrix([f1,{}...,{}fn],{} q,{} D)} returns the \\spad{q x n} matrix \\spad{m} whose i^th row is \\spad{[f1^(i-1),{}...,{}fn^(i-1)]}.") (((|Matrix| |#1|) (|List| |#1|)) "\\spad{wronskianMatrix([f1,{}...,{}fn])} returns the \\spad{n x n} matrix \\spad{m} whose i^th row is \\spad{[f1^(i-1),{}...,{}fn^(i-1)]}."))) 
 NIL 
 NIL 
-(-810 -2570 S |f|) 
+(-810 -1965 S |f|) 
 ((|constructor| (NIL "This type represents the finite direct or cartesian product of an underlying ordered component type. The ordering on the type is determined by its third argument which represents the less than function on vectors. This type is a suitable third argument for \\spadtype{GeneralDistributedMultivariatePolynomial}."))) 
-((-4513 |has| |#2| (-1047)) (-4514 |has| |#2| (-1047)) (-4516 |has| |#2| (-6 -4516)) ((-4521 "*") |has| |#2| (-172)) (-4519 . T)) 
-((|HasCategory| |#2| (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047))) (|HasCategory| |#2| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-840))) (-2198 (|HasCategory| |#2| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-840)))) (|HasCategory| |#2| (QUOTE (-716))) (|HasCategory| |#2| (QUOTE (-172))) (-2198 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (-2198 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-365)))) (-2198 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-1047)))) (|HasCategory| |#2| (QUOTE (-370))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-225))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-1047)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1090)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-1090)))) (|HasAttribute| |#2| (QUOTE -4516)) (|HasCategory| |#2| (QUOTE (-137))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (|HasCategory| |#2| (QUOTE (-25))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-370))) (|HasCategory| |#2| (QUOTE (-716))) (|HasCategory| |#2| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-840))) (|HasCategory| |#2| (QUOTE (-1047))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (-2198 (-12 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-172)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-365)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-370)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-716)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-788)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-840)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-1090))))) (-2198 (-12 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-172)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-365)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-370)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-716)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-788)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-840)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1090))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-172)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-365)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-370)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-716)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-788)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-840)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))))) 
+((-4515 |has| |#2| (-1047)) (-4516 |has| |#2| (-1047)) (-4518 |has| |#2| (-6 -4518)) ((-4523 "*") |has| |#2| (-172)) (-4521 . T)) 
+((|HasCategory| |#2| (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047))) (|HasCategory| |#2| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-840))) (-2199 (|HasCategory| |#2| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-840)))) (|HasCategory| |#2| (QUOTE (-716))) (|HasCategory| |#2| (QUOTE (-172))) (-2199 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (-2199 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-365)))) (-2199 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-1047)))) (|HasCategory| |#2| (QUOTE (-370))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-225))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-1047)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1090)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-1090)))) (|HasAttribute| |#2| (QUOTE -4518)) (|HasCategory| |#2| (QUOTE (-137))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (|HasCategory| |#2| (QUOTE (-25))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-370))) (|HasCategory| |#2| (QUOTE (-716))) (|HasCategory| |#2| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-840))) (|HasCategory| |#2| (QUOTE (-1047))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-25))) (|HasCategory| |#2| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1047)))) (-2199 (-12 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-172)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-365)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-370)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-716)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-788)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-840)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-1090))))) (-2199 (-12 (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-172)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-365)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-370)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-716)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-788)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-840)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1090))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-25)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-172)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-365)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-370)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-716)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-788)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-840)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1047)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))))) 
 (-811 R) 
 ((|constructor| (NIL "\\spadtype{OrderlyDifferentialPolynomial} implements an ordinary differential polynomial ring in arbitrary number of differential indeterminates,{} with coefficients in a ring. The ranking on the differential indeterminate is orderly. This is analogous to the domain \\spadtype{Polynomial}."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-6 -4517)) (-4514 . T) (-4513 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| (-813 (-1161)) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-813 (-1161)) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-813 (-1161)) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-813 (-1161)) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-813 (-1161)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-225))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#1| (QUOTE -4517)) (|HasCategory| |#1| (QUOTE (-453))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-6 -4519)) (-4516 . T) (-4515 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| (-813 (-1161)) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-813 (-1161)) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-813 (-1161)) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-813 (-1161)) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-813 (-1161)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-225))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#1| (QUOTE -4519)) (|HasCategory| |#1| (QUOTE (-453))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))))) 
 (-812 |Kernels| R |var|) 
 ((|constructor| (NIL "This constructor produces an ordinary differential ring from a partial differential ring by specifying a variable.")) (|coerce| ((|#2| $) "\\spad{coerce(p)} views \\spad{p} as a valie in the partial differential ring.") (($ |#2|) "\\spad{coerce(r)} views \\spad{r} as a value in the ordinary differential ring."))) 
-(((-4521 "*") |has| |#2| (-365)) (-4512 |has| |#2| (-365)) (-4517 |has| |#2| (-365)) (-4511 |has| |#2| (-365)) (-4516 . T) (-4514 . T) (-4513 . T)) 
+(((-4523 "*") |has| |#2| (-365)) (-4514 |has| |#2| (-365)) (-4519 |has| |#2| (-365)) (-4513 |has| |#2| (-365)) (-4518 . T) (-4516 . T) (-4515 . T)) 
 ((|HasCategory| |#2| (QUOTE (-365)))) 
 (-813 S) 
 ((|constructor| (NIL "\\spadtype{OrderlyDifferentialVariable} adds a commonly used orderly ranking to the set of derivatives of an ordered list of differential indeterminates. An orderly ranking is a ranking \\spadfun{<} of the derivatives with the property that for two derivatives \\spad{u} and \\spad{v},{} \\spad{u} \\spadfun{<} \\spad{v} if the \\spadfun{order} of \\spad{u} is less than that of \\spad{v}. This domain belongs to \\spadtype{DifferentialVariableCategory}. It defines \\spadfun{weight} to be just \\spadfun{order},{} and it defines an orderly ranking \\spadfun{<} on derivatives \\spad{u} via the lexicographic order on the pair (\\spadfun{order}(\\spad{u}),{} \\spadfun{variable}(\\spad{u}))."))) 
@@ -3190,7 +3190,7 @@ NIL
 NIL 
 (-815) 
 ((|constructor| (NIL "The category of ordered commutative integral domains,{} where ordering and the arithmetic operations are compatible"))) 
-((-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-816) 
 ((|constructor| (NIL "\\spadtype{OpenMathConnection} provides low-level functions for handling connections to and from \\spadtype{OpenMathDevice}\\spad{s}.")) (|OMbindTCP| (((|Boolean|) $ (|SingleInteger|)) "\\spad{OMbindTCP}")) (|OMconnectTCP| (((|Boolean|) $ (|String|) (|SingleInteger|)) "\\spad{OMconnectTCP}")) (|OMconnOutDevice| (((|OpenMathDevice|) $) "\\spad{OMconnOutDevice:}")) (|OMconnInDevice| (((|OpenMathDevice|) $) "\\spad{OMconnInDevice:}")) (|OMcloseConn| (((|Void|) $) "\\spad{OMcloseConn}")) (|OMmakeConn| (($ (|SingleInteger|)) "\\spad{OMmakeConn}"))) 
@@ -3218,7 +3218,7 @@ NIL
 NIL 
 (-822 P R) 
 ((|constructor| (NIL "This constructor creates the \\spadtype{MonogenicLinearOperator} domain which is ``opposite\\spad{''} in the ring sense to \\spad{P}. That is,{} as sets \\spad{P = \\$} but \\spad{a * b} in \\spad{\\$} is equal to \\spad{b * a} in \\spad{P}.")) (|po| ((|#1| $) "\\spad{po(q)} creates a value in \\spad{P} equal to \\spad{q} in \\$.")) (|op| (($ |#1|) "\\spad{op(p)} creates a value in \\$ equal to \\spad{p} in \\spad{P}."))) 
-((-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4515 . T) (-4516 . T) (-4518 . T)) 
 ((|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-225)))) 
 (-823) 
 ((|constructor| (NIL "\\spadtype{OpenMath} provides operations for exporting an object in OpenMath format.")) (|OMwrite| (((|Void|) (|OpenMathDevice|) $ (|Boolean|)) "\\spad{OMwrite(dev,{} u,{} true)} writes the OpenMath form of \\axiom{\\spad{u}} to the OpenMath device \\axiom{\\spad{dev}} as a complete OpenMath object; OMwrite(\\spad{dev},{} \\spad{u},{} \\spad{false}) writes the object as an OpenMath fragment.") (((|Void|) (|OpenMathDevice|) $) "\\spad{OMwrite(dev,{} u)} writes the OpenMath form of \\axiom{\\spad{u}} to the OpenMath device \\axiom{\\spad{dev}} as a complete OpenMath object.") (((|String|) $ (|Boolean|)) "\\spad{OMwrite(u,{} true)} returns the OpenMath \\spad{XML} encoding of \\axiom{\\spad{u}} as a complete OpenMath object; OMwrite(\\spad{u},{} \\spad{false}) returns the OpenMath \\spad{XML} encoding of \\axiom{\\spad{u}} as an OpenMath fragment.") (((|String|) $) "\\spad{OMwrite(u)} returns the OpenMath \\spad{XML} encoding of \\axiom{\\spad{u}} as a complete OpenMath object."))) 
@@ -3230,7 +3230,7 @@ NIL
 NIL 
 (-825 S) 
 ((|constructor| (NIL "to become an in order iterator")) (|min| ((|#1| $) "\\spad{min(u)} returns the smallest entry in the multiset aggregate \\spad{u}."))) 
-((-4519 . T) (-4509 . T) (-4520 . T) (-3973 . T)) 
+((-4521 . T) (-4511 . T) (-4522 . T) (-3973 . T)) 
 NIL 
 (-826) 
 ((|constructor| (NIL "\\spadtype{OpenMathServerPackage} provides the necessary operations to run AXIOM as an OpenMath server,{} reading/writing objects to/from a port. Please note the facilities available here are very basic. The idea is that a user calls \\spadignore{e.g.} \\axiom{Omserve(4000,{}60)} and then another process sends OpenMath objects to port 4000 and reads the result.")) (|OMserve| (((|Void|) (|SingleInteger|) (|SingleInteger|)) "\\spad{OMserve(portnum,{}timeout)} puts AXIOM into server mode on port number \\axiom{\\spad{portnum}}. The parameter \\axiom{\\spad{timeout}} specifies the \\spad{timeout} period for the connection.")) (|OMsend| (((|Void|) (|OpenMathConnection|) (|Any|)) "\\spad{OMsend(c,{}u)} attempts to output \\axiom{\\spad{u}} on \\axiom{\\spad{c}} in OpenMath.")) (|OMreceive| (((|Any|) (|OpenMathConnection|)) "\\spad{OMreceive(c)} reads an OpenMath object from connection \\axiom{\\spad{c}} and returns the appropriate AXIOM object."))) 
@@ -3242,11 +3242,11 @@ NIL
 NIL 
 (-828 R) 
 ((|constructor| (NIL "Completion with infinity. Adjunction of a complex infinity to a set.")) (|rationalIfCan| (((|Union| (|Fraction| (|Integer|)) "failed") $) "\\spad{rationalIfCan(x)} returns \\spad{x} as a finite rational number if it is one,{} \"failed\" otherwise.")) (|rational| (((|Fraction| (|Integer|)) $) "\\spad{rational(x)} returns \\spad{x} as a finite rational number. Error: if \\spad{x} is not a rational number.")) (|rational?| (((|Boolean|) $) "\\spad{rational?(x)} tests if \\spad{x} is a finite rational number.")) (|infinite?| (((|Boolean|) $) "\\spad{infinite?(x)} tests if \\spad{x} is infinite.")) (|finite?| (((|Boolean|) $) "\\spad{finite?(x)} tests if \\spad{x} is finite.")) (|infinity| (($) "\\spad{infinity()} returns infinity."))) 
-((-4516 |has| |#1| (-840))) 
-((|HasCategory| |#1| (QUOTE (-840))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-550))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-840)))) (|HasCategory| |#1| (QUOTE (-21))) (-2198 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-840))))) 
+((-4518 |has| |#1| (-840))) 
+((|HasCategory| |#1| (QUOTE (-840))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-550))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-840)))) (|HasCategory| |#1| (QUOTE (-21))) (-2199 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-840))))) 
 (-829 R) 
 ((|constructor| (NIL "Algebra of ADDITIVE operators over a ring."))) 
-((-4514 |has| |#1| (-172)) (-4513 |has| |#1| (-172)) (-4516 . T)) 
+((-4516 |has| |#1| (-172)) (-4515 |has| |#1| (-172)) (-4518 . T)) 
 ((|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150)))) 
 (-830) 
 ((|constructor| (NIL "This package exports tools to create AXIOM Library information databases.")) (|getDatabase| (((|Database| (|IndexCard|)) (|String|)) "\\spad{getDatabase(\"char\")} returns a list of appropriate entries in the browser database. The legal values for \\spad{\"char\"} are \"o\" (operations),{} \\spad{\"k\"} (constructors),{} \\spad{\"d\"} (domains),{} \\spad{\"c\"} (categories) or \\spad{\"p\"} (packages)."))) 
@@ -3270,13 +3270,13 @@ NIL
 NIL 
 (-835 R) 
 ((|constructor| (NIL "Completion with + and - infinity. Adjunction of two real infinites quantities to a set.")) (|rationalIfCan| (((|Union| (|Fraction| (|Integer|)) "failed") $) "\\spad{rationalIfCan(x)} returns \\spad{x} as a finite rational number if it is one and \"failed\" otherwise.")) (|rational| (((|Fraction| (|Integer|)) $) "\\spad{rational(x)} returns \\spad{x} as a finite rational number. Error: if \\spad{x} cannot be so converted.")) (|rational?| (((|Boolean|) $) "\\spad{rational?(x)} tests if \\spad{x} is a finite rational number.")) (|whatInfinity| (((|SingleInteger|) $) "\\spad{whatInfinity(x)} returns 0 if \\spad{x} is finite,{} 1 if \\spad{x} is +infinity,{} and \\spad{-1} if \\spad{x} is -infinity.")) (|infinite?| (((|Boolean|) $) "\\spad{infinite?(x)} tests if \\spad{x} is +infinity or -infinity,{}")) (|finite?| (((|Boolean|) $) "\\spad{finite?(x)} tests if \\spad{x} is finite.")) (|minusInfinity| (($) "\\spad{minusInfinity()} returns -infinity.")) (|plusInfinity| (($) "\\spad{plusInfinity()} returns +infinity."))) 
-((-4516 |has| |#1| (-840))) 
-((|HasCategory| |#1| (QUOTE (-840))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-550))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-840)))) (|HasCategory| |#1| (QUOTE (-21))) (-2198 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-840))))) 
+((-4518 |has| |#1| (-840))) 
+((|HasCategory| |#1| (QUOTE (-840))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-550))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-840)))) (|HasCategory| |#1| (QUOTE (-21))) (-2199 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-840))))) 
 (-836) 
 ((|constructor| (NIL "Ordered finite sets."))) 
 NIL 
 NIL 
-(-837 -2570 S) 
+(-837 -1965 S) 
 ((|constructor| (NIL "This package provides ordering functions on vectors which are suitable parameters for OrderedDirectProduct.")) (|reverseLex| (((|Boolean|) (|Vector| |#2|) (|Vector| |#2|)) "\\spad{reverseLex(v1,{}v2)} return \\spad{true} if the vector \\spad{v1} is less than the vector \\spad{v2} in the ordering which is total degree refined by the reverse lexicographic ordering.")) (|totalLex| (((|Boolean|) (|Vector| |#2|) (|Vector| |#2|)) "\\spad{totalLex(v1,{}v2)} return \\spad{true} if the vector \\spad{v1} is less than the vector \\spad{v2} in the ordering which is total degree refined by lexicographic ordering.")) (|pureLex| (((|Boolean|) (|Vector| |#2|) (|Vector| |#2|)) "\\spad{pureLex(v1,{}v2)} return \\spad{true} if the vector \\spad{v1} is less than the vector \\spad{v2} in the lexicographic ordering."))) 
 NIL 
 NIL 
@@ -3290,7 +3290,7 @@ NIL
 NIL 
 (-840) 
 ((|constructor| (NIL "Ordered sets which are also rings,{} that is,{} domains where the ring operations are compatible with the ordering. \\blankline Axiom\\spad{\\br} \\tab{5}\\spad{0<a and b<c => ab< ac}")) (|abs| (($ $) "\\spad{abs(x)} returns the absolute value of \\spad{x}.")) (|sign| (((|Integer|) $) "\\spad{sign(x)} is 1 if \\spad{x} is positive,{} \\spad{-1} if \\spad{x} is negative,{} 0 if \\spad{x} equals 0.")) (|negative?| (((|Boolean|) $) "\\spad{negative?(x)} tests whether \\spad{x} is strictly less than 0.")) (|positive?| (((|Boolean|) $) "\\spad{positive?(x)} tests whether \\spad{x} is strictly greater than 0."))) 
-((-4516 . T)) 
+((-4518 . T)) 
 NIL 
 (-841 S) 
 ((|constructor| (NIL "The class of totally ordered sets,{} that is,{} sets such that for each pair of elements \\spad{(a,{}b)} exactly one of the following relations holds \\spad{a<b or a=b or b<a} and the relation is transitive,{} \\spadignore{i.e.} \\spad{a<b and b<c => a<c}.")) (|min| (($ $ $) "\\spad{min(x,{}y)} returns the minimum of \\spad{x} and \\spad{y} relative to \\spad{\"<\"}.")) (|max| (($ $ $) "\\spad{max(x,{}y)} returns the maximum of \\spad{x} and \\spad{y} relative to \\spad{\"<\"}.")) (<= (((|Boolean|) $ $) "\\spad{x <= y} is a less than or equal test.")) (>= (((|Boolean|) $ $) "\\spad{x >= y} is a greater than or equal test.")) (> (((|Boolean|) $ $) "\\spad{x > y} is a greater than test.")) (< (((|Boolean|) $ $) "\\spad{x < y} is a strict total ordering on the elements of the set."))) 
@@ -3306,19 +3306,19 @@ NIL
 ((|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-172)))) 
 (-844 R) 
 ((|constructor| (NIL "This is the category of univariate skew polynomials over an Ore coefficient ring. The multiplication is given by \\spad{x a = \\sigma(a) x + \\delta a}. This category is an evolution of the types MonogenicLinearOperator,{} OppositeMonogenicLinearOperator,{} and NonCommutativeOperatorDivision")) (|leftLcm| (($ $ $) "\\spad{leftLcm(a,{}b)} computes the value \\spad{m} of lowest degree such that \\spad{m = aa*a = bb*b} for some values \\spad{aa} and \\spad{bb}. The value \\spad{m} is computed using right-division.")) (|rightExtendedGcd| (((|Record| (|:| |coef1| $) (|:| |coef2| $) (|:| |generator| $)) $ $) "\\spad{rightExtendedGcd(a,{}b)} returns \\spad{[c,{}d]} such that \\spad{g = c * a + d * b = rightGcd(a,{} b)}.")) (|rightGcd| (($ $ $) "\\spad{rightGcd(a,{}b)} computes the value \\spad{g} of highest degree such that \\indented{3}{\\spad{a = aa*g}} \\indented{3}{\\spad{b = bb*g}} for some values \\spad{aa} and \\spad{bb}. The value \\spad{g} is computed using right-division.")) (|rightExactQuotient| (((|Union| $ "failed") $ $) "\\spad{rightExactQuotient(a,{}b)} computes the value \\spad{q},{} if it exists such that \\spad{a = q*b}.")) (|rightRemainder| (($ $ $) "\\spad{rightRemainder(a,{}b)} computes the pair \\spad{[q,{}r]} such that \\spad{a = q*b + r} and the degree of \\spad{r} is less than the degree of \\spad{b}. The value \\spad{r} is returned.")) (|rightQuotient| (($ $ $) "\\spad{rightQuotient(a,{}b)} computes the pair \\spad{[q,{}r]} such that \\spad{a = q*b + r} and the degree of \\spad{r} is less than the degree of \\spad{b}. The value \\spad{q} is returned.")) (|rightDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{rightDivide(a,{}b)} returns the pair \\spad{[q,{}r]} such that \\spad{a = q*b + r} and the degree of \\spad{r} is less than the degree of \\spad{b}. This process is called ``right division\\spad{''}.")) (|rightLcm| (($ $ $) "\\spad{rightLcm(a,{}b)} computes the value \\spad{m} of lowest degree such that \\spad{m = a*aa = b*bb} for some values \\spad{aa} and \\spad{bb}. The value \\spad{m} is computed using left-division.")) (|leftExtendedGcd| (((|Record| (|:| |coef1| $) (|:| |coef2| $) (|:| |generator| $)) $ $) "\\spad{leftExtendedGcd(a,{}b)} returns \\spad{[c,{}d]} such that \\spad{g = a * c + b * d = leftGcd(a,{} b)}.")) (|leftGcd| (($ $ $) "\\spad{leftGcd(a,{}b)} computes the value \\spad{g} of highest degree such that \\indented{3}{\\spad{a = g*aa}} \\indented{3}{\\spad{b = g*bb}} for some values \\spad{aa} and \\spad{bb}. The value \\spad{g} is computed using left-division.")) (|leftExactQuotient| (((|Union| $ "failed") $ $) "\\spad{leftExactQuotient(a,{}b)} computes the value \\spad{q},{} if it exists,{} \\indented{1}{such that \\spad{a = b*q}.}")) (|leftRemainder| (($ $ $) "\\spad{leftRemainder(a,{}b)} computes the pair \\spad{[q,{}r]} such that \\spad{a = b*q + r} and the degree of \\spad{r} is less than the degree of \\spad{b}. The value \\spad{r} is returned.")) (|leftQuotient| (($ $ $) "\\spad{leftQuotient(a,{}b)} computes the pair \\spad{[q,{}r]} such that \\spad{a = b*q + r} and the degree of \\spad{r} is less than the degree of \\spad{b}. The value \\spad{q} is returned.")) (|leftDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{leftDivide(a,{}b)} returns the pair \\spad{[q,{}r]} such that \\spad{a = b*q + r} and the degree of \\spad{r} is less than the degree of \\spad{b}. This process is called ``left division\\spad{''}.")) (|primitivePart| (($ $) "\\spad{primitivePart(l)} returns \\spad{l0} such that \\spad{l = a * l0} for some a in \\spad{R},{} and \\spad{content(l0) = 1}.")) (|content| ((|#1| $) "\\spad{content(l)} returns the \\spad{gcd} of all the coefficients of \\spad{l}.")) (|monicRightDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{monicRightDivide(a,{}b)} returns the pair \\spad{[q,{}r]} such that \\spad{a = q*b + r} and the degree of \\spad{r} is less than the degree of \\spad{b}. \\spad{b} must be monic. This process is called ``right division\\spad{''}.")) (|monicLeftDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{monicLeftDivide(a,{}b)} returns the pair \\spad{[q,{}r]} such that \\spad{a = b*q + r} and the degree of \\spad{r} is less than the degree of \\spad{b}. \\spad{b} must be monic. This process is called ``left division\\spad{''}.")) (|exquo| (((|Union| $ "failed") $ |#1|) "\\spad{exquo(l,{} a)} returns the exact quotient of \\spad{l} by a,{} returning \\axiom{\"failed\"} if this is not possible.")) (|apply| ((|#1| $ |#1| |#1|) "\\spad{apply(p,{} c,{} m)} returns \\spad{p(m)} where the action is given by \\spad{x m = c sigma(m) + delta(m)}.")) (|coefficients| (((|List| |#1|) $) "\\spad{coefficients(l)} returns the list of all the nonzero coefficients of \\spad{l}.")) (|monomial| (($ |#1| (|NonNegativeInteger|)) "\\spad{monomial(c,{}k)} produces \\spad{c} times the \\spad{k}-th power of the generating operator,{} \\spad{monomial(1,{}1)}.")) (|coefficient| ((|#1| $ (|NonNegativeInteger|)) "\\spad{coefficient(l,{}k)} is \\spad{a(k)} if \\indented{2}{\\spad{l = sum(monomial(a(i),{}i),{} i = 0..n)}.}")) (|reductum| (($ $) "\\spad{reductum(l)} is \\spad{l - monomial(a(n),{}n)} if \\indented{2}{\\spad{l = sum(monomial(a(i),{}i),{} i = 0..n)}.}")) (|leadingCoefficient| ((|#1| $) "\\spad{leadingCoefficient(l)} is \\spad{a(n)} if \\indented{2}{\\spad{l = sum(monomial(a(i),{}i),{} i = 0..n)}.}")) (|minimumDegree| (((|NonNegativeInteger|) $) "\\spad{minimumDegree(l)} is the smallest \\spad{k} such that \\spad{a(k) ^= 0} if \\indented{2}{\\spad{l = sum(monomial(a(i),{}i),{} i = 0..n)}.}")) (|degree| (((|NonNegativeInteger|) $) "\\spad{degree(l)} is \\spad{n} if \\indented{2}{\\spad{l = sum(monomial(a(i),{}i),{} i = 0..n)}.}"))) 
-((-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-845 R C) 
 ((|constructor| (NIL "\\spad{UnivariateSkewPolynomialCategoryOps} provides products and divisions of univariate skew polynomials.")) (|rightDivide| (((|Record| (|:| |quotient| |#2|) (|:| |remainder| |#2|)) |#2| |#2| (|Automorphism| |#1|)) "\\spad{rightDivide(a,{} b,{} sigma)} returns the pair \\spad{[q,{}r]} such that \\spad{a = q*b + r} and the degree of \\spad{r} is less than the degree of \\spad{b}. This process is called ``right division\\spad{''}. \\spad{\\sigma} is the morphism to use.")) (|leftDivide| (((|Record| (|:| |quotient| |#2|) (|:| |remainder| |#2|)) |#2| |#2| (|Automorphism| |#1|)) "\\spad{leftDivide(a,{} b,{} sigma)} returns the pair \\spad{[q,{}r]} such that \\spad{a = b*q + r} and the degree of \\spad{r} is less than the degree of \\spad{b}. This process is called ``left division\\spad{''}. \\spad{\\sigma} is the morphism to use.")) (|monicRightDivide| (((|Record| (|:| |quotient| |#2|) (|:| |remainder| |#2|)) |#2| |#2| (|Automorphism| |#1|)) "\\spad{monicRightDivide(a,{} b,{} sigma)} returns the pair \\spad{[q,{}r]} such that \\spad{a = q*b + r} and the degree of \\spad{r} is less than the degree of \\spad{b}. \\spad{b} must be monic. This process is called ``right division\\spad{''}. \\spad{\\sigma} is the morphism to use.")) (|monicLeftDivide| (((|Record| (|:| |quotient| |#2|) (|:| |remainder| |#2|)) |#2| |#2| (|Automorphism| |#1|)) "\\spad{monicLeftDivide(a,{} b,{} sigma)} returns the pair \\spad{[q,{}r]} such that \\spad{a = b*q + r} and the degree of \\spad{r} is less than the degree of \\spad{b}. \\spad{b} must be monic. This process is called ``left division\\spad{''}. \\spad{\\sigma} is the morphism to use.")) (|apply| ((|#1| |#2| |#1| |#1| (|Automorphism| |#1|) (|Mapping| |#1| |#1|)) "\\spad{apply(p,{} c,{} m,{} sigma,{} delta)} returns \\spad{p(m)} where the action is given by \\spad{x m = c sigma(m) + delta(m)}.")) (|times| ((|#2| |#2| |#2| (|Automorphism| |#1|) (|Mapping| |#1| |#1|)) "\\spad{times(p,{} q,{} sigma,{} delta)} returns \\spad{p * q}. \\spad{\\sigma} and \\spad{\\delta} are the maps to use."))) 
 NIL 
 ((|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) 
-(-846 R |sigma| -1325) 
+(-846 R |sigma| -3488) 
 ((|constructor| (NIL "This is the domain of sparse univariate skew polynomials over an Ore coefficient field. The multiplication is given by \\spad{x a = \\sigma(a) x + \\delta a}.")) (|outputForm| (((|OutputForm|) $ (|OutputForm|)) "\\spad{outputForm(p,{} x)} returns the output form of \\spad{p} using \\spad{x} for the otherwise anonymous variable."))) 
-((-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4515 . T) (-4516 . T) (-4518 . T)) 
 ((|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-365)))) 
-(-847 |x| R |sigma| -1325) 
+(-847 |x| R |sigma| -3488) 
 ((|constructor| (NIL "This is the domain of univariate skew polynomials over an Ore coefficient field in a named variable. The multiplication is given by \\spad{x a = \\sigma(a) x + \\delta a}.")) (|coerce| (($ (|Variable| |#1|)) "\\spad{coerce(x)} returns \\spad{x} as a skew-polynomial."))) 
-((-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4515 . T) (-4516 . T) (-4518 . T)) 
 ((|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-365)))) 
 (-848 R) 
 ((|constructor| (NIL "This package provides orthogonal polynomials as functions on a ring.")) (|legendreP| ((|#1| (|NonNegativeInteger|) |#1|) "\\spad{legendreP(n,{}x)} is the \\spad{n}-th Legendre polynomial,{} \\spad{P[n](x)}. These are defined by \\spad{1/sqrt(1-2*x*t+t**2) = sum(P[n](x)*t**n,{} n = 0..)}.")) (|laguerreL| ((|#1| (|NonNegativeInteger|) (|NonNegativeInteger|) |#1|) "\\spad{laguerreL(m,{}n,{}x)} is the associated Laguerre polynomial,{} \\spad{L<m>[n](x)}. This is the \\spad{m}-th derivative of \\spad{L[n](x)}.") ((|#1| (|NonNegativeInteger|) |#1|) "\\spad{laguerreL(n,{}x)} is the \\spad{n}-th Laguerre polynomial,{} \\spad{L[n](x)}. These are defined by \\spad{exp(-t*x/(1-t))/(1-t) = sum(L[n](x)*t**n/n!,{} n = 0..)}.")) (|hermiteH| ((|#1| (|NonNegativeInteger|) |#1|) "\\spad{hermiteH(n,{}x)} is the \\spad{n}-th Hermite polynomial,{} \\spad{H[n](x)}. These are defined by \\spad{exp(2*t*x-t**2) = sum(H[n](x)*t**n/n!,{} n = 0..)}.")) (|chebyshevU| ((|#1| (|NonNegativeInteger|) |#1|) "\\spad{chebyshevU(n,{}x)} is the \\spad{n}-th Chebyshev polynomial of the second kind,{} \\spad{U[n](x)}. These are defined by \\spad{1/(1-2*t*x+t**2) = sum(T[n](x) *t**n,{} n = 0..)}.")) (|chebyshevT| ((|#1| (|NonNegativeInteger|) |#1|) "\\spad{chebyshevT(n,{}x)} is the \\spad{n}-th Chebyshev polynomial of the first kind,{} \\spad{T[n](x)}. These are defined by \\spad{(1-t*x)/(1-2*t*x+t**2) = sum(T[n](x) *t**n,{} n = 0..)}."))) 
@@ -3342,36 +3342,36 @@ NIL
 NIL 
 (-853 R |vl| |wl| |wtlevel|) 
 ((|constructor| (NIL "This domain represents truncated weighted polynomials over the \"Polynomial\" type. The variables must be specified,{} as must the weights. The representation is sparse in the sense that only non-zero terms are represented.")) (|changeWeightLevel| (((|Void|) (|NonNegativeInteger|)) "\\spad{changeWeightLevel(n)} This changes the weight level to the new value given: \\spad{NB:} previously calculated terms are not affected")) (/ (((|Union| $ "failed") $ $) "\\spad{x/y} division (only works if minimum weight of divisor is zero,{} and if \\spad{R} is a Field)")) (|coerce| (($ (|Polynomial| |#1|)) "\\spad{coerce(p)} coerces a Polynomial(\\spad{R}) into Weighted form,{} applying weights and ignoring terms") (((|Polynomial| |#1|) $) "\\spad{coerce(p)} converts back into a Polynomial(\\spad{R}),{} ignoring weights"))) 
-((-4514 |has| |#1| (-172)) (-4513 |has| |#1| (-172)) (-4516 . T)) 
+((-4516 |has| |#1| (-172)) (-4515 |has| |#1| (-172)) (-4518 . T)) 
 ((|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365)))) 
 (-854) 
 ((|constructor| (NIL "This category exports the function for the domain PseudoAlgebraicClosureOfAlgExtOfRationalNumber which implement dynamic extension using the simple notion of tower extensions. A tower extension \\spad{T} of the ground field \\spad{K} is any sequence of field extension (\\spad{T} : \\spad{K_0},{} \\spad{K_1},{} ...,{} K_i...,{}\\spad{K_n}) where \\spad{K_0} = \\spad{K} and for \\spad{i} \\spad{=1},{}2,{}...,{}\\spad{n},{} K_i is an extension of \\spad{K_}{\\spad{i}-1} of degree > 1 and defined by an irreducible polynomial \\spad{p}(\\spad{Z}) in \\spad{K_}{\\spad{i}-1}. Two towers (T_1: \\spad{K_01},{} \\spad{K_11},{}...,{}\\spad{K_i1},{}...,{}\\spad{K_n1}) and (T_2: \\spad{K_02},{} \\spad{K_12},{}...,{}\\spad{K_i2},{}...,{}\\spad{K_n2}) are said to be related if \\spad{T_1} \\spad{<=} \\spad{T_2} (or \\spad{T_1} \\spad{>=} \\spad{T_2}),{} that is if \\spad{K_i1} = \\spad{K_i2} for \\spad{i=1},{}2,{}...,{}\\spad{n1} (or \\spad{i=1},{}2,{}...,{}\\spad{n2}). Any algebraic operations defined for several elements are only defined if all of the concerned elements are comming from a set of related tour extensions."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-855 |downLevel|) 
 ((|constructor| (NIL "This domain implement dynamic extension over the PseudoAlgebraicClosureOfRationalNumber. A tower extension \\spad{T} of the ground field \\spad{K} is any sequence of field extension (\\spad{T} : \\spad{K_0},{} \\spad{K_1},{} ...,{} K_i...,{}\\spad{K_n}) where \\spad{K_0} = \\spad{K} and for \\spad{i} \\spad{=1},{}2,{}...,{}\\spad{n},{} K_i is an extension of \\spad{K_}{\\spad{i}-1} of degree > 1 and defined by an irreducible polynomial \\spad{p}(\\spad{Z}) in \\spad{K_}{\\spad{i}-1}. Two towers (T_1: \\spad{K_01},{} \\spad{K_11},{}...,{}\\spad{K_i1},{}...,{}\\spad{K_n1}) and (T_2: \\spad{K_02},{} \\spad{K_12},{}...,{}\\spad{K_i2},{}...,{}\\spad{K_n2}) are said to be related if \\spad{T_1} \\spad{<=} \\spad{T_2} (or \\spad{T_1} \\spad{>=} \\spad{T_2}),{} that is if \\spad{K_i1} = \\spad{K_i2} for \\spad{i=1},{}2,{}...,{}\\spad{n1} (or \\spad{i=1},{}2,{}...,{}\\spad{n2}). Any algebraic operations defined for several elements are only defined if all of the concerned elements are comming from a set of related tour extensions."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| (-860) (QUOTE (-150))) (|HasCategory| (-860) (QUOTE (-148))) (|HasCategory| (-860) (QUOTE (-370))) (|HasCategory| (-409 (-568)) (QUOTE (-150))) (|HasCategory| (-409 (-568)) (QUOTE (-148))) (|HasCategory| (-409 (-568)) (QUOTE (-370))) (-2198 (|HasCategory| (-409 (-568)) (QUOTE (-148))) (|HasCategory| (-409 (-568)) (QUOTE (-370))) (|HasCategory| (-860) (QUOTE (-148))) (|HasCategory| (-860) (QUOTE (-370)))) (-2198 (|HasCategory| (-409 (-568)) (QUOTE (-370))) (|HasCategory| (-860) (QUOTE (-370))))) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| (-860) (QUOTE (-150))) (|HasCategory| (-860) (QUOTE (-148))) (|HasCategory| (-860) (QUOTE (-370))) (|HasCategory| (-409 (-568)) (QUOTE (-150))) (|HasCategory| (-409 (-568)) (QUOTE (-148))) (|HasCategory| (-409 (-568)) (QUOTE (-370))) (-2199 (|HasCategory| (-409 (-568)) (QUOTE (-148))) (|HasCategory| (-409 (-568)) (QUOTE (-370))) (|HasCategory| (-860) (QUOTE (-148))) (|HasCategory| (-860) (QUOTE (-370)))) (-2199 (|HasCategory| (-409 (-568)) (QUOTE (-370))) (|HasCategory| (-860) (QUOTE (-370))))) 
 (-856) 
 ((|constructor| (NIL "This category exports the function for the domain PseudoAlgebraicClosureOfFiniteField which implement dynamic extension using the simple notion of tower extensions. A tower extension \\spad{T} of the ground field \\spad{K} is any sequence of field extension (\\spad{T} : \\spad{K_0},{} \\spad{K_1},{} ...,{} K_i...,{}\\spad{K_n}) where \\spad{K_0} = \\spad{K} and for \\spad{i} \\spad{=1},{}2,{}...,{}\\spad{n},{} K_i is an extension of \\spad{K_}{\\spad{i}-1} of degree > 1 and defined by an irreducible polynomial \\spad{p}(\\spad{Z}) in \\spad{K_}{\\spad{i}-1}. Two towers (T_1: \\spad{K_01},{} \\spad{K_11},{}...,{}\\spad{K_i1},{}...,{}\\spad{K_n1}) and (T_2: \\spad{K_02},{} \\spad{K_12},{}...,{}\\spad{K_i2},{}...,{}\\spad{K_n2}) are said to be related if \\spad{T_1} \\spad{<=} \\spad{T_2} (or \\spad{T_1} \\spad{>=} \\spad{T_2}),{} that is if \\spad{K_i1} = \\spad{K_i2} for \\spad{i=1},{}2,{}...,{}\\spad{n1} (or \\spad{i=1},{}2,{}...,{}\\spad{n2}). Any algebraic operations defined for several elements are only defined if all of the concerned elements are comming from a set of related tour extensions."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-857 K) 
 ((|constructor| (NIL "This domain implement dynamic extension using the simple notion of tower extensions. A tower extension \\spad{T} of the ground field \\spad{K} is any sequence of field extension (\\spad{T} : \\spad{K_0},{} \\spad{K_1},{} ...,{} K_i...,{}\\spad{K_n}) where \\spad{K_0} = \\spad{K} and for \\spad{i} \\spad{=1},{}2,{}...,{}\\spad{n},{} K_i is an extension of \\spad{K_}{\\spad{i}-1} of degree > 1 and defined by an irreducible polynomial \\spad{p}(\\spad{Z}) in \\spad{K_}{\\spad{i}-1}. Two towers (T_1: \\spad{K_01},{} \\spad{K_11},{}...,{}\\spad{K_i1},{}...,{}\\spad{K_n1}) and (T_2: \\spad{K_02},{} \\spad{K_12},{}...,{}\\spad{K_i2},{}...,{}\\spad{K_n2}) are said to be related if \\spad{T_1} \\spad{<=} \\spad{T_2} (or \\spad{T_1} \\spad{>=} \\spad{T_2}),{} that is if \\spad{K_i1} = \\spad{K_i2} for \\spad{i=1},{}2,{}...,{}\\spad{n1} (or \\spad{i=1},{}2,{}...,{}\\spad{n2}). Any algebraic operations defined for several elements are only defined if all of the concerned elements are comming from a set of related tour extensions."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 ((|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-370)))) 
 (-858) 
 ((|constructor| (NIL "This category exports the function for domains which implement dynamic extension using the simple notion of tower extensions. \\spad{++} A tower extension \\spad{T} of the ground field \\spad{K} is any sequence of field extension (\\spad{T} : \\spad{K_0},{} \\spad{K_1},{} ...,{} K_i...,{}\\spad{K_n}) where \\spad{K_0} = \\spad{K} and for \\spad{i} \\spad{=1},{}2,{}...,{}\\spad{n},{} K_i is an extension of \\spad{K_}{\\spad{i}-1} of degree > 1 and defined by an irreducible polynomial \\spad{p}(\\spad{Z}) in \\spad{K_}{\\spad{i}-1}. Two towers (T_1: \\spad{K_01},{} \\spad{K_11},{}...,{}\\spad{K_i1},{}...,{}\\spad{K_n1}) and (T_2: \\spad{K_02},{} \\spad{K_12},{}...,{}\\spad{K_i2},{}...,{}\\spad{K_n2}) are said to be related if \\spad{T_1} \\spad{<=} \\spad{T_2} (or \\spad{T_1} \\spad{>=} \\spad{T_2}),{} that is if \\spad{K_i1} = \\spad{K_i2} for \\spad{i=1},{}2,{}...,{}\\spad{n1} (or \\spad{i=1},{}2,{}...,{}\\spad{n2}). Any algebraic operations defined for several elements are only defined if all of the concerned elements are comming from a set of related tour extensions.")) (|previousTower| (($ $) "\\spad{previousTower(a)} returns the previous tower extension over which the element a is defined.")) (|extDegree| (((|PositiveInteger|) $) "\\spad{extDegree(a)} returns the extension degree of the extension tower over which the element is defined.")) (|maxTower| (($ (|List| $)) "\\spad{maxTower(l)} returns the tower in the list having the maximal extension degree over the ground field. It has no meaning if the towers are not related.")) (|distinguishedRootsOf| (((|List| $) (|SparseUnivariatePolynomial| $) $) "\\spad{distinguishedRootsOf(p,{}a)} returns a (distinguised) root for each irreducible factor of the polynomial \\spad{p} (factored over the field defined by the element a)."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-859) 
 ((|constructor| (NIL "This category exports the function for the domain PseudoAlgebraicClosureOfRationalNumber which implement dynamic extension using the simple notion of tower extensions. A tower extension \\spad{T} of the ground field \\spad{K} is any sequence of field extension (\\spad{T} : \\spad{K_0},{} \\spad{K_1},{} ...,{} K_i...,{}\\spad{K_n}) where \\spad{K_0} = \\spad{K} and for \\spad{i} \\spad{=1},{}2,{}...,{}\\spad{n},{} K_i is an extension of \\spad{K_}{\\spad{i}-1} of degree > 1 and defined by an irreducible polynomial \\spad{p}(\\spad{Z}) in \\spad{K_}{\\spad{i}-1}. Two towers (T_1: \\spad{K_01},{} \\spad{K_11},{}...,{}\\spad{K_i1},{}...,{}\\spad{K_n1}) and (T_2: \\spad{K_02},{} \\spad{K_12},{}...,{}\\spad{K_i2},{}...,{}\\spad{K_n2}) are said to be related if \\spad{T_1} \\spad{<=} \\spad{T_2} (or \\spad{T_1} \\spad{>=} \\spad{T_2}),{} that is if \\spad{K_i1} = \\spad{K_i2} for \\spad{i=1},{}2,{}...,{}\\spad{n1} (or \\spad{i=1},{}2,{}...,{}\\spad{n2}). Any algebraic operations defined for several elements are only defined if all of the concerned elements are comming from a set of related tour extensions."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-860) 
 ((|constructor| (NIL "This domain implements dynamic extension using the simple notion of tower extensions. A tower extension \\spad{T} of the ground field \\spad{K} is any sequence of field extension (\\spad{T} : \\spad{K_0},{} \\spad{K_1},{} ...,{} K_i...,{}\\spad{K_n}) where \\spad{K_0} = \\spad{K} and for \\spad{i} \\spad{=1},{}2,{}...,{}\\spad{n},{} K_i is an extension of \\spad{K_}{\\spad{i}-1} of degree > 1 and defined by an irreducible polynomial \\spad{p}(\\spad{Z}) in \\spad{K_}{\\spad{i}-1}. Two towers (T_1: \\spad{K_01},{} \\spad{K_11},{}...,{}\\spad{K_i1},{}...,{}\\spad{K_n1}) and (T_2: \\spad{K_02},{} \\spad{K_12},{}...,{}\\spad{K_i2},{}...,{}\\spad{K_n2}) are said to be related if \\spad{T_1} \\spad{<=} \\spad{T_2} (or \\spad{T_1} \\spad{>=} \\spad{T_2}),{} that is if \\spad{K_i1} = \\spad{K_i2} for \\spad{i=1},{}2,{}...,{}\\spad{n1} (or \\spad{i=1},{}2,{}...,{}\\spad{n2}). Any algebraic operations defined for several elements are only defined if all of the concerned elements are comming from a set of related tour extensions."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| (-409 (-568)) (QUOTE (-150))) (|HasCategory| (-409 (-568)) (QUOTE (-148))) (|HasCategory| (-409 (-568)) (QUOTE (-370))) (-2198 (|HasCategory| (-409 (-568)) (QUOTE (-148))) (|HasCategory| (-409 (-568)) (QUOTE (-370))))) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| (-409 (-568)) (QUOTE (-150))) (|HasCategory| (-409 (-568)) (QUOTE (-148))) (|HasCategory| (-409 (-568)) (QUOTE (-370))) (-2199 (|HasCategory| (-409 (-568)) (QUOTE (-148))) (|HasCategory| (-409 (-568)) (QUOTE (-370))))) 
 (-861 R PS UP) 
 ((|constructor| (NIL "This package computes reliable Pad&ea. approximants using a generalized Viskovatov continued fraction algorithm.")) (|padecf| (((|Union| (|ContinuedFraction| |#3|) "failed") (|NonNegativeInteger|) (|NonNegativeInteger|) |#2| |#2|) "\\spad{padecf(nd,{}dd,{}ns,{}ds)} computes the approximant as a continued fraction of polynomials (if it exists) for arguments \\spad{nd} (numerator degree of approximant),{} \\spad{dd} (denominator degree of approximant),{} \\spad{ns} (numerator series of function),{} and \\spad{ds} (denominator series of function).")) (|pade| (((|Union| (|Fraction| |#3|) "failed") (|NonNegativeInteger|) (|NonNegativeInteger|) |#2| |#2|) "\\spad{pade(nd,{}dd,{}ns,{}ds)} computes the approximant as a quotient of polynomials (if it exists) for arguments \\spad{nd} (numerator degree of approximant),{} \\spad{dd} (denominator degree of approximant),{} \\spad{ns} (numerator series of function),{} and \\spad{ds} (denominator series of function)."))) 
 NIL 
@@ -3382,20 +3382,20 @@ NIL
 NIL 
 (-863 |p|) 
 ((|constructor| (NIL "This is the category of stream-based representations of the \\spad{p}-adic integers.")) (|root| (($ (|SparseUnivariatePolynomial| (|Integer|)) (|Integer|)) "\\spad{root(f,{}a)} returns a root of the polynomial \\spad{f}. Argument \\spad{a} must be a root of \\spad{f} \\spad{(mod p)}.")) (|sqrt| (($ $ (|Integer|)) "\\spad{sqrt(b,{}a)} returns a square root of \\spad{b}. Argument \\spad{a} is a square root of \\spad{b} \\spad{(mod p)}.")) (|approximate| (((|Integer|) $ (|Integer|)) "\\spad{approximate(x,{}n)} returns an integer \\spad{y} such that \\spad{y = x (mod p^n)} when \\spad{n} is positive,{} and 0 otherwise.")) (|quotientByP| (($ $) "\\spad{quotientByP(x)} returns \\spad{b},{} where \\spad{x = a + b p}.")) (|moduloP| (((|Integer|) $) "\\spad{modulo(x)} returns a,{} where \\spad{x = a + b p}.")) (|modulus| (((|Integer|)) "\\spad{modulus()} returns the value of \\spad{p}.")) (|complete| (($ $) "\\spad{complete(x)} forces the computation of all digits.")) (|extend| (($ $ (|Integer|)) "\\spad{extend(x,{}n)} forces the computation of digits up to order \\spad{n}.")) (|order| (((|NonNegativeInteger|) $) "\\spad{order(x)} returns the exponent of the highest power of \\spad{p} dividing \\spad{x}.")) (|digits| (((|Stream| (|Integer|)) $) "\\spad{digits(x)} returns a stream of \\spad{p}-adic digits of \\spad{x}."))) 
-((-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-864 |p|) 
 ((|constructor| (NIL "Stream-based implementation of \\spad{Zp:} \\spad{p}-adic numbers are represented as sum(\\spad{i} = 0..,{} a[\\spad{i}] * p^i),{} where the a[\\spad{i}] lie in 0,{}1,{}...,{}(\\spad{p} - 1)."))) 
-((-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-865 |p|) 
 ((|constructor| (NIL "Stream-based implementation of \\spad{Qp:} numbers are represented as sum(\\spad{i} = \\spad{k}..,{} a[\\spad{i}] * p^i) where the a[\\spad{i}] lie in 0,{}1,{}...,{}(\\spad{p} - 1)."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| (-864 |#1|) (QUOTE (-904))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| (-864 |#1|) (QUOTE (-148))) (|HasCategory| (-864 |#1|) (QUOTE (-150))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-864 |#1|) (QUOTE (-1021))) (|HasCategory| (-864 |#1|) (QUOTE (-815))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| (-864 |#1|) (QUOTE (-1136))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| (-864 |#1|) (QUOTE (-225))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -523) (QUOTE (-1161)) (LIST (QUOTE -864) (|devaluate| |#1|)))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -303) (LIST (QUOTE -864) (|devaluate| |#1|)))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -281) (LIST (QUOTE -864) (|devaluate| |#1|)) (LIST (QUOTE -864) (|devaluate| |#1|)))) (|HasCategory| (-864 |#1|) (QUOTE (-301))) (|HasCategory| (-864 |#1|) (QUOTE (-550))) (|HasCategory| (-864 |#1|) (QUOTE (-842))) (-2198 (|HasCategory| (-864 |#1|) (QUOTE (-815))) (|HasCategory| (-864 |#1|) (QUOTE (-842)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-864 |#1|) (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-864 |#1|) (QUOTE (-904)))) (|HasCategory| (-864 |#1|) (QUOTE (-148))))) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| (-864 |#1|) (QUOTE (-904))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| (-864 |#1|) (QUOTE (-148))) (|HasCategory| (-864 |#1|) (QUOTE (-150))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-864 |#1|) (QUOTE (-1021))) (|HasCategory| (-864 |#1|) (QUOTE (-815))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| (-864 |#1|) (QUOTE (-1136))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| (-864 |#1|) (QUOTE (-225))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -523) (QUOTE (-1161)) (LIST (QUOTE -864) (|devaluate| |#1|)))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -303) (LIST (QUOTE -864) (|devaluate| |#1|)))) (|HasCategory| (-864 |#1|) (LIST (QUOTE -281) (LIST (QUOTE -864) (|devaluate| |#1|)) (LIST (QUOTE -864) (|devaluate| |#1|)))) (|HasCategory| (-864 |#1|) (QUOTE (-301))) (|HasCategory| (-864 |#1|) (QUOTE (-550))) (|HasCategory| (-864 |#1|) (QUOTE (-842))) (-2199 (|HasCategory| (-864 |#1|) (QUOTE (-815))) (|HasCategory| (-864 |#1|) (QUOTE (-842)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-864 |#1|) (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-864 |#1|) (QUOTE (-904)))) (|HasCategory| (-864 |#1|) (QUOTE (-148))))) 
 (-866 |p| PADIC) 
 ((|constructor| (NIL "This is the category of stream-based representations of \\spad{Qp}.")) (|removeZeroes| (($ (|Integer|) $) "\\spad{removeZeroes(n,{}x)} removes up to \\spad{n} leading zeroes from the \\spad{p}-adic rational \\spad{x}.") (($ $) "\\spad{removeZeroes(x)} removes leading zeroes from the representation of the \\spad{p}-adic rational \\spad{x}. A \\spad{p}-adic rational is represented by (1) an exponent and (2) a \\spad{p}-adic integer which may have leading zero digits. When the \\spad{p}-adic integer has a leading zero digit,{} a 'leading zero' is removed from the \\spad{p}-adic rational as follows: the number is rewritten by increasing the exponent by 1 and dividing the \\spad{p}-adic integer by \\spad{p}. Note: \\spad{removeZeroes(f)} removes all leading zeroes from \\spad{f}.")) (|continuedFraction| (((|ContinuedFraction| (|Fraction| (|Integer|))) $) "\\spad{continuedFraction(x)} converts the \\spad{p}-adic rational number \\spad{x} to a continued fraction.")) (|approximate| (((|Fraction| (|Integer|)) $ (|Integer|)) "\\spad{approximate(x,{}n)} returns a rational number \\spad{y} such that \\spad{y = x (mod p^n)}."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#2| (QUOTE (-904))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (QUOTE (-1021))) (|HasCategory| |#2| (QUOTE (-815))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1136))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (LIST (QUOTE -523) (QUOTE (-1161)) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -281) (|devaluate| |#2|) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-301))) (|HasCategory| |#2| (QUOTE (-550))) (|HasCategory| |#2| (QUOTE (-842))) (-2198 (|HasCategory| |#2| (QUOTE (-815))) (|HasCategory| |#2| (QUOTE (-842)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (|HasCategory| |#2| (QUOTE (-148))))) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#2| (QUOTE (-904))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (QUOTE (-1021))) (|HasCategory| |#2| (QUOTE (-815))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1136))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-225))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (LIST (QUOTE -523) (QUOTE (-1161)) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -281) (|devaluate| |#2|) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-301))) (|HasCategory| |#2| (QUOTE (-550))) (|HasCategory| |#2| (QUOTE (-842))) (-2199 (|HasCategory| |#2| (QUOTE (-815))) (|HasCategory| |#2| (QUOTE (-842)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (|HasCategory| |#2| (QUOTE (-148))))) 
 (-867 K |symb| BLMET) 
 ((|constructor| (NIL "A package that implements the Brill-Noether algorithm. Part of the PAFF package")) (|ZetaFunction| (((|UnivariateTaylorSeriesCZero| (|Integer|) |t|) (|PositiveInteger|)) "Returns the Zeta function of the curve in constant field extension. Calculated by using the \\spad{L}-Polynomial") (((|UnivariateTaylorSeriesCZero| (|Integer|) |t|)) "Returns the Zeta function of the curve. Calculated by using the \\spad{L}-Polynomial")) (|numberPlacesDegExtDeg| (((|Integer|) (|PositiveInteger|) (|PositiveInteger|)) "numberRatPlacesExtDegExtDeg(\\spad{d},{} \\spad{n}) returns the number of places of degree \\spad{d} in the constant field extension of degree \\spad{n}")) (|numberRatPlacesExtDeg| (((|Integer|) (|PositiveInteger|)) "\\spad{numberRatPlacesExtDeg(n)} returns the number of rational places in the constant field extenstion of degree \\spad{n}")) (|numberOfPlacesOfDegree| (((|Integer|) (|PositiveInteger|)) "returns the number of places of the given degree")) (|placesOfDegree| (((|List| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|)) (|PositiveInteger|)) "\\spad{placesOfDegree(d)} returns all places of degree \\spad{d} of the curve.")) (|classNumber| (((|Integer|)) "Returns the class number of the curve.")) (|LPolynomial| (((|SparseUnivariatePolynomial| (|Integer|)) (|PositiveInteger|)) "\\spad{LPolynomial(d)} returns the \\spad{L}-Polynomial of the curve in constant field extension of degree \\spad{d}.") (((|SparseUnivariatePolynomial| (|Integer|))) "Returns the \\spad{L}-Polynomial of the curve.")) (|adjunctionDivisor| (((|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|))) "\\spad{adjunctionDivisor computes} the adjunction divisor of the plane curve given by the polynomial defined by setCurve.")) (|intersectionDivisor| (((|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|)) (|DistributedMultivariatePolynomial| |#2| |#1|)) "\\spad{intersectionDivisor(pol)} compute the intersection divisor of the form \\spad{pol} with the curve. (If \\spad{pol} is not homogeneous an error message is issued).")) (|evalIfCan| (((|Union| |#1| "failed") (|Fraction| (|DistributedMultivariatePolynomial| |#2| |#1|)) (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|)) "\\spad{evalIfCan(u,{}pl)} evaluate the function \\spad{u} at the place \\spad{pl} (returns \"failed\" if it is a pole).") (((|Union| |#1| "failed") (|DistributedMultivariatePolynomial| |#2| |#1|) (|DistributedMultivariatePolynomial| |#2| |#1|) (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|)) "\\spad{evalIfCan(f,{}g,{}pl)} evaluate the function \\spad{f/g} at the place \\spad{pl} (returns \"failed\" if it is a pole).") (((|Union| |#1| "failed") (|DistributedMultivariatePolynomial| |#2| |#1|) (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|)) "\\spad{evalIfCan(f,{}pl)} evaluate \\spad{f} at the place \\spad{pl} (returns \"failed\" if it is a pole).")) (|eval| ((|#1| (|Fraction| (|DistributedMultivariatePolynomial| |#2| |#1|)) (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|)) "\\spad{eval(u,{}pl)} evaluate the function \\spad{u} at the place \\spad{pl}.") ((|#1| (|DistributedMultivariatePolynomial| |#2| |#1|) (|DistributedMultivariatePolynomial| |#2| |#1|) (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|)) "\\spad{eval(f,{}g,{}pl)} evaluate the function \\spad{f/g} at the place \\spad{pl}.") ((|#1| (|DistributedMultivariatePolynomial| |#2| |#1|) (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|)) "\\spad{eval(f,{}pl)} evaluate \\spad{f} at the place \\spad{pl}.")) (|interpolateForms| (((|List| (|DistributedMultivariatePolynomial| |#2| |#1|)) (|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|)) (|NonNegativeInteger|)) "\\spad{interpolateForms(d,{}n)} returns a basis of the interpolate forms of degree \\spad{n} of the divisor \\spad{d}.")) (|lBasis| (((|Record| (|:| |num| (|List| (|DistributedMultivariatePolynomial| |#2| |#1|))) (|:| |den| (|DistributedMultivariatePolynomial| |#2| |#1|))) (|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|))) "\\spad{lBasis computes} a basis associated to the specified divisor")) (|parametrize| (((|NeitherSparseOrDensePowerSeries| (|PseudoAlgebraicClosureOfFiniteField| |#1|)) (|DistributedMultivariatePolynomial| |#2| |#1|) (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|)) "\\spad{parametrize(f,{}pl)} returns a local parametrization of \\spad{f} at the place \\spad{pl}.")) (|singularPoints| (((|List| (|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |#1|))) "rationalPoints() returns the singular points of the curve defined by the polynomial given to the package. If the singular points lie in an extension of the specified ground field an error message is issued specifying the extension degree needed to find all singular points.")) (|desingTree| (((|List| (|DesingTree| (|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |#1| |#2| |#3|)))) "\\spad{desingTree returns} the desingularisation trees at all singular points of the curve defined by the polynomial given to the package.")) (|desingTreeWoFullParam| (((|List| (|DesingTree| (|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |#1| |#2| |#3|)))) "\\spad{desingTreeWoFullParam returns} the desingularisation trees at all singular points of the curve defined by the polynomial given to the package. The local parametrizations are not computed.")) (|genus| (((|NonNegativeInteger|)) "\\spad{genus returns} the genus of the curve defined by the polynomial given to the package.")) (|theCurve| (((|DistributedMultivariatePolynomial| |#2| |#1|)) "\\spad{theCurve returns} the specified polynomial for the package.")) (|rationalPlaces| (((|List| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|))) "\\spad{rationalPlaces returns} all the rational places of the curve defined by the polynomial given to the package.")) (|pointDominateBy| (((|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |#1|) (|PlacesOverPseudoAlgebraicClosureOfFiniteField| |#1|)) "\\spad{pointDominateBy(pl)} returns the projective point dominated by the place \\spad{pl}."))) 
 NIL 
@@ -3459,7 +3459,7 @@ NIL
 (-882 |Base| |Subject| |Pat|) 
 ((|constructor| (NIL "This package provides the top-level pattern macthing functions.")) (|Is| (((|PatternMatchResult| |#1| |#2|) |#2| |#3|) "\\spad{Is(expr,{} pat)} matches the pattern pat on the expression \\spad{expr} and returns a match of the form \\spad{[v1 = e1,{}...,{}vn = en]}; returns an empty match if \\spad{expr} is exactly equal to pat. returns a \\spadfun{failed} match if pat does not match \\spad{expr}.") (((|List| (|Equation| (|Polynomial| |#2|))) |#2| |#3|) "\\spad{Is(expr,{} pat)} matches the pattern pat on the expression \\spad{expr} and returns a list of matches \\spad{[v1 = e1,{}...,{}vn = en]}; returns an empty list if either \\spad{expr} is exactly equal to pat or if pat does not match \\spad{expr}.") (((|List| (|Equation| |#2|)) |#2| |#3|) "\\spad{Is(expr,{} pat)} matches the pattern pat on the expression \\spad{expr} and returns a list of matches \\spad{[v1 = e1,{}...,{}vn = en]}; returns an empty list if either \\spad{expr} is exactly equal to pat or if pat does not match \\spad{expr}.") (((|PatternMatchListResult| |#1| |#2| (|List| |#2|)) (|List| |#2|) |#3|) "\\spad{Is([e1,{}...,{}en],{} pat)} matches the pattern pat on the list of expressions \\spad{[e1,{}...,{}en]} and returns the result.")) (|is?| (((|Boolean|) (|List| |#2|) |#3|) "\\spad{is?([e1,{}...,{}en],{} pat)} tests if the list of expressions \\spad{[e1,{}...,{}en]} matches the pattern pat.") (((|Boolean|) |#2| |#3|) "\\spad{is?(expr,{} pat)} tests if the expression \\spad{expr} matches the pattern pat."))) 
 NIL 
-((|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-1161)))) (-12 (-3044 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-1161))))) (-3044 (|HasCategory| |#2| (QUOTE (-1047))))) (-12 (|HasCategory| |#2| (QUOTE (-1047))) (-3044 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-1161))))))) 
+((|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-1161)))) (-12 (-3046 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-1161))))) (-3046 (|HasCategory| |#2| (QUOTE (-1047))))) (-12 (|HasCategory| |#2| (QUOTE (-1047))) (-3046 (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-1161))))))) 
 (-883 R A B) 
 ((|constructor| (NIL "Lifts maps to pattern matching results.")) (|map| (((|PatternMatchResult| |#1| |#3|) (|Mapping| |#3| |#2|) (|PatternMatchResult| |#1| |#2|)) "\\spad{map(f,{} [(v1,{}a1),{}...,{}(vn,{}an)])} returns the matching result [(\\spad{v1},{}\\spad{f}(\\spad{a1})),{}...,{}(\\spad{vn},{}\\spad{f}(an))]."))) 
 NIL 
@@ -3468,7 +3468,7 @@ NIL
 ((|constructor| (NIL "A PatternMatchResult is an object internally returned by the pattern matcher; It is either a failed match,{} or a list of matches of the form (var,{} expr) meaning that the variable var matches the expression expr.")) (|satisfy?| (((|Union| (|Boolean|) "failed") $ (|Pattern| |#1|)) "\\spad{satisfy?(r,{} p)} returns \\spad{true} if the matches satisfy the top-level predicate of \\spad{p},{} \\spad{false} if they don\\spad{'t},{} and \"failed\" if not enough variables of \\spad{p} are matched in \\spad{r} to decide.")) (|construct| (($ (|List| (|Record| (|:| |key| (|Symbol|)) (|:| |entry| |#2|)))) "\\spad{construct([v1,{}e1],{}...,{}[vn,{}en])} returns the match result containing the matches (\\spad{v1},{}\\spad{e1}),{}...,{}(\\spad{vn},{}en).")) (|destruct| (((|List| (|Record| (|:| |key| (|Symbol|)) (|:| |entry| |#2|))) $) "\\spad{destruct(r)} returns the list of matches (var,{} expr) in \\spad{r}. Error: if \\spad{r} is a failed match.")) (|addMatchRestricted| (($ (|Pattern| |#1|) |#2| $ |#2|) "\\spad{addMatchRestricted(var,{} expr,{} r,{} val)} adds the match (\\spad{var},{} \\spad{expr}) in \\spad{r},{} provided that \\spad{expr} satisfies the predicates attached to \\spad{var},{} that \\spad{var} is not matched to another expression already,{} and that either \\spad{var} is an optional pattern variable or that \\spad{expr} is not equal to val (usually an identity).")) (|insertMatch| (($ (|Pattern| |#1|) |#2| $) "\\spad{insertMatch(var,{} expr,{} r)} adds the match (\\spad{var},{} \\spad{expr}) in \\spad{r},{} without checking predicates or previous matches for \\spad{var}.")) (|addMatch| (($ (|Pattern| |#1|) |#2| $) "\\spad{addMatch(var,{} expr,{} r)} adds the match (\\spad{var},{} \\spad{expr}) in \\spad{r},{} provided that \\spad{expr} satisfies the predicates attached to \\spad{var},{} and that \\spad{var} is not matched to another expression already.")) (|getMatch| (((|Union| |#2| "failed") (|Pattern| |#1|) $) "\\spad{getMatch(var,{} r)} returns the expression that \\spad{var} matches in the result \\spad{r},{} and \"failed\" if \\spad{var} is not matched in \\spad{r}.")) (|union| (($ $ $) "\\spad{union(a,{} b)} makes the set-union of two match results.")) (|new| (($) "\\spad{new()} returns a new empty match result.")) (|failed| (($) "\\spad{failed()} returns a failed match.")) (|failed?| (((|Boolean|) $) "\\spad{failed?(r)} tests if \\spad{r} is a failed match."))) 
 NIL 
 NIL 
-(-885 R -3190) 
+(-885 R -3192) 
 ((|constructor| (NIL "Utilities for handling patterns")) (|badValues| (((|List| |#2|) (|Pattern| |#1|)) "\\spad{badValues(p)} returns the list of \"bad values\" for \\spad{p}; \\spad{p} is not allowed to match any of its \"bad values\".")) (|addBadValue| (((|Pattern| |#1|) (|Pattern| |#1|) |#2|) "\\spad{addBadValue(p,{} v)} adds \\spad{v} to the list of \"bad values\" for \\spad{p}; \\spad{p} is not allowed to match any of its \"bad values\".")) (|satisfy?| (((|Boolean|) (|List| |#2|) (|Pattern| |#1|)) "\\spad{satisfy?([v1,{}...,{}vn],{} p)} returns \\spad{f(v1,{}...,{}vn)} where \\spad{f} is the top-level predicate attached to \\spad{p}.") (((|Boolean|) |#2| (|Pattern| |#1|)) "\\spad{satisfy?(v,{} p)} returns \\spad{f}(\\spad{v}) where \\spad{f} is the predicate attached to \\spad{p}.")) (|predicate| (((|Mapping| (|Boolean|) |#2|) (|Pattern| |#1|)) "\\spad{predicate(p)} returns the predicate attached to \\spad{p},{} the constant function \\spad{true} if \\spad{p} has no predicates attached to it.")) (|suchThat| (((|Pattern| |#1|) (|Pattern| |#1|) (|List| (|Symbol|)) (|Mapping| (|Boolean|) (|List| |#2|))) "\\spad{suchThat(p,{} [a1,{}...,{}an],{} f)} returns a copy of \\spad{p} with the top-level predicate set to \\spad{f(a1,{}...,{}an)}.") (((|Pattern| |#1|) (|Pattern| |#1|) (|List| (|Mapping| (|Boolean|) |#2|))) "\\spad{suchThat(p,{} [f1,{}...,{}fn])} makes a copy of \\spad{p} and adds the predicate \\spad{f1} and ... and \\spad{fn} to the copy,{} which is returned.") (((|Pattern| |#1|) (|Pattern| |#1|) (|Mapping| (|Boolean|) |#2|)) "\\spad{suchThat(p,{} f)} makes a copy of \\spad{p} and adds the predicate \\spad{f} to the copy,{} which is returned."))) 
 NIL 
 NIL 
@@ -3510,7 +3510,7 @@ NIL
 NIL 
 (-895 S) 
 ((|constructor| (NIL "A partial differential ring with differentiations indexed by a parameter type \\spad{S}. \\blankline Axioms\\spad{\\br} \\tab{5}\\spad{differentiate(x+y,{}e)=differentiate(x,{}e)+differentiate(y,{}e)}\\spad{\\br} \\tab{5}\\spad{differentiate(x*y,{}e)=x*differentiate(y,{}e)+differentiate(x,{}e)*y}")) (D (($ $ (|List| |#1|) (|List| (|NonNegativeInteger|))) "\\spad{D(x,{} [s1,{}...,{}sn],{} [n1,{}...,{}nn])} computes multiple partial derivatives,{} \\spadignore{i.e.} \\spad{D(...D(x,{} s1,{} n1)...,{} sn,{} nn)}.") (($ $ |#1| (|NonNegativeInteger|)) "\\spad{D(x,{} s,{} n)} computes multiple partial derivatives,{} \\spadignore{i.e.} \\spad{n}-th derivative of \\spad{x} with respect to \\spad{s}.") (($ $ (|List| |#1|)) "\\spad{D(x,{}[s1,{}...sn])} computes successive partial derivatives,{} \\spadignore{i.e.} \\spad{D(...D(x,{} s1)...,{} sn)}.") (($ $ |#1|) "\\spad{D(x,{}v)} computes the partial derivative of \\spad{x} with respect to \\spad{v}.")) (|differentiate| (($ $ (|List| |#1|) (|List| (|NonNegativeInteger|))) "\\spad{differentiate(x,{} [s1,{}...,{}sn],{} [n1,{}...,{}nn])} computes multiple partial derivatives,{} \\spadignore{i.e.}") (($ $ |#1| (|NonNegativeInteger|)) "\\spad{differentiate(x,{} s,{} n)} computes multiple partial derivatives,{} \\spadignore{i.e.} \\spad{n}-th derivative of \\spad{x} with respect to \\spad{s}.") (($ $ (|List| |#1|)) "\\spad{differentiate(x,{}[s1,{}...sn])} computes successive partial derivatives,{} \\spadignore{i.e.} \\spad{differentiate(...differentiate(x,{} s1)...,{} sn)}.") (($ $ |#1|) "\\spad{differentiate(x,{}v)} computes the partial derivative of \\spad{x} with respect to \\spad{v}."))) 
-((-4516 . T)) 
+((-4518 . T)) 
 NIL 
 (-896 S) 
 ((|constructor| (NIL "This domain has no description")) (|coerce| (((|Tree| |#1|) $) "\\indented{1}{coerce(\\spad{x}) is not documented} \\blankline \\spad{X} t1:=ptree([1,{}2,{}3]) \\spad{X} t2:=ptree(\\spad{t1},{}ptree([1,{}2,{}3])) \\spad{X} t2::Tree List PositiveInteger")) (|ptree| (($ $ $) "\\indented{1}{ptree(\\spad{x},{}\\spad{y}) is not documented} \\blankline \\spad{X} t1:=ptree([1,{}2,{}3]) \\spad{X} ptree(\\spad{t1},{}ptree([1,{}2,{}3]))") (($ |#1|) "\\indented{1}{ptree(\\spad{s}) is a leaf? pendant tree} \\blankline \\spad{X} t1:=ptree([1,{}2,{}3])"))) 
@@ -3522,7 +3522,7 @@ NIL
 NIL 
 (-898 S) 
 ((|constructor| (NIL "PermutationCategory provides a categorial environment for subgroups of bijections of a set (\\spadignore{i.e.} permutations)")) (< (((|Boolean|) $ $) "\\spad{p < q} is an order relation on permutations. Note that this order is only total if and only if \\spad{S} is totally ordered or \\spad{S} is finite.")) (|orbit| (((|Set| |#1|) $ |#1|) "\\spad{orbit(p,{} el)} returns the orbit of el under the permutation \\spad{p},{} \\spadignore{i.e.} the set which is given by applications of the powers of \\spad{p} to el.")) (|elt| ((|#1| $ |#1|) "\\spad{elt(p,{} el)} returns the image of el under the permutation \\spad{p}.")) (|eval| ((|#1| $ |#1|) "\\spad{eval(p,{} el)} returns the image of el under the permutation \\spad{p}.")) (|cycles| (($ (|List| (|List| |#1|))) "\\spad{cycles(lls)} coerces a list list of cycles \\spad{lls} to a permutation,{} each cycle being a list with not repetitions,{} is coerced to the permutation,{} which maps \\spad{ls}.\\spad{i} to \\spad{ls}.\\spad{i+1},{} indices modulo the length of the list,{} then these permutations are mutiplied. Error: if repetitions occur in one cycle.")) (|cycle| (($ (|List| |#1|)) "\\spad{cycle(ls)} coerces a cycle \\spad{ls},{} \\spadignore{i.e.} a list with not repetitions to a permutation,{} which maps \\spad{ls}.\\spad{i} to \\spad{ls}.\\spad{i+1},{} indices modulo the length of the list. Error: if repetitions occur."))) 
-((-4516 . T)) 
+((-4518 . T)) 
 NIL 
 (-899 S) 
 ((|constructor| (NIL "PermutationGroup implements permutation groups acting on a set \\spad{S},{} \\spadignore{i.e.} all subgroups of the symmetric group of \\spad{S},{} represented as a list of permutations (generators). Note that therefore the objects are not members of the \\Language category \\spadtype{Group}. Using the idea of base and strong generators by Sims,{} basic routines and algorithms are implemented so that the word problem for permutation groups can be solved.")) (|initializeGroupForWordProblem| (((|Void|) $ (|Integer|) (|Integer|)) "\\spad{initializeGroupForWordProblem(gp,{}m,{}n)} initializes the group \\spad{gp} for the word problem. Notes: (1) with a small integer you get shorter words,{} but the routine takes longer than the standard routine for longer words. (2) be careful: invoking this routine will destroy the possibly stored information about your group (but will recompute it again). (3) users need not call this function normally for the soultion of the word problem.") (((|Void|) $) "\\spad{initializeGroupForWordProblem(gp)} initializes the group \\spad{gp} for the word problem. Notes: it calls the other function of this name with parameters 0 and 1: initializeGroupForWordProblem(\\spad{gp},{}0,{}1). Notes: (1) be careful: invoking this routine will destroy the possibly information about your group (but will recompute it again) (2) users need not call this function normally for the soultion of the word problem.")) (<= (((|Boolean|) $ $) "\\spad{gp1 <= gp2} returns \\spad{true} if and only if \\spad{gp1} is a subgroup of \\spad{gp2}. Note: because of a bug in the parser you have to call this function explicitly by \\spad{gp1} \\spad{<=}\\$(PERMGRP \\spad{S}) \\spad{gp2}.")) (< (((|Boolean|) $ $) "\\spad{gp1 < gp2} returns \\spad{true} if and only if \\spad{gp1} is a proper subgroup of \\spad{gp2}.")) (|movedPoints| (((|Set| |#1|) $) "\\spad{movedPoints(gp)} returns the points moved by the group \\spad{gp}.")) (|wordInGenerators| (((|List| (|NonNegativeInteger|)) (|Permutation| |#1|) $) "\\spad{wordInGenerators(p,{}gp)} returns the word for the permutation \\spad{p} in the original generators of the group \\spad{gp},{} represented by the indices of the list,{} given by generators.")) (|wordInStrongGenerators| (((|List| (|NonNegativeInteger|)) (|Permutation| |#1|) $) "\\spad{wordInStrongGenerators(p,{}gp)} returns the word for the permutation \\spad{p} in the strong generators of the group \\spad{gp},{} represented by the indices of the list,{} given by strongGenerators.")) (|member?| (((|Boolean|) (|Permutation| |#1|) $) "\\spad{member?(pp,{}gp)} answers the question,{} whether the permutation \\spad{pp} is in the group \\spad{gp} or not.")) (|orbits| (((|Set| (|Set| |#1|)) $) "\\spad{orbits(gp)} returns the orbits of the group \\spad{gp},{} \\spadignore{i.e.} it partitions the (finite) of all moved points.")) (|orbit| (((|Set| (|List| |#1|)) $ (|List| |#1|)) "\\spad{orbit(gp,{}ls)} returns the orbit of the ordered list \\spad{ls} under the group \\spad{gp}. Note: return type is \\spad{L} \\spad{L} \\spad{S} temporarily because FSET \\spad{L} \\spad{S} has an error.") (((|Set| (|Set| |#1|)) $ (|Set| |#1|)) "\\spad{orbit(gp,{}els)} returns the orbit of the unordered set \\spad{els} under the group \\spad{gp}.") (((|Set| |#1|) $ |#1|) "\\spad{orbit(gp,{}el)} returns the orbit of the element \\spad{el} under the group \\spad{gp},{} \\spadignore{i.e.} the set of all points gained by applying each group element to \\spad{el}.")) (|permutationGroup| (($ (|List| (|Permutation| |#1|))) "\\spad{permutationGroup(ls)} coerces a list of permutations \\spad{ls} to the group generated by this list.")) (|wordsForStrongGenerators| (((|List| (|List| (|NonNegativeInteger|))) $) "\\spad{wordsForStrongGenerators(gp)} returns the words for the strong generators of the group \\spad{gp} in the original generators of \\spad{gp},{} represented by their indices in the list,{} given by generators.")) (|strongGenerators| (((|List| (|Permutation| |#1|)) $) "\\spad{strongGenerators(gp)} returns strong generators for the group \\spad{gp}.")) (|base| (((|List| |#1|) $) "\\spad{base(gp)} returns a base for the group \\spad{gp}.")) (|degree| (((|NonNegativeInteger|) $) "\\spad{degree(gp)} returns the number of points moved by all permutations of the group \\spad{gp}.")) (|order| (((|NonNegativeInteger|) $) "\\spad{order(gp)} returns the order of the group \\spad{gp}.")) (|random| (((|Permutation| |#1|) $) "\\spad{random(gp)} returns a random product of maximal 20 generators of the group \\spad{gp}. Note: random(\\spad{gp})=random(\\spad{gp},{}20).") (((|Permutation| |#1|) $ (|Integer|)) "\\spad{random(gp,{}i)} returns a random product of maximal \\spad{i} generators of the group \\spad{gp}.")) (|elt| (((|Permutation| |#1|) $ (|NonNegativeInteger|)) "\\spad{elt(gp,{}i)} returns the \\spad{i}-th generator of the group \\spad{gp}.")) (|generators| (((|List| (|Permutation| |#1|)) $) "\\spad{generators(gp)} returns the generators of the group \\spad{gp}.")) (|coerce| (($ (|List| (|Permutation| |#1|))) "\\spad{coerce(ls)} coerces a list of permutations \\spad{ls} to the group generated by this list.") (((|List| (|Permutation| |#1|)) $) "\\spad{coerce(gp)} returns the generators of the group \\spad{gp}."))) 
@@ -3530,8 +3530,8 @@ NIL
 NIL 
 (-900 S) 
 ((|constructor| (NIL "Permutation(\\spad{S}) implements the group of all bijections on a set \\spad{S},{} which move only a finite number of points. A permutation is considered as a map from \\spad{S} into \\spad{S}. In particular multiplication is defined as composition of maps:\\spad{\\br} \\spad{pi1} * \\spad{pi2} = \\spad{pi1} \\spad{o} \\spad{pi2}.\\spad{\\br} The internal representation of permuatations are two lists of equal length representing preimages and images.")) (|coerceImages| (($ (|List| |#1|)) "\\spad{coerceImages(ls)} coerces the list \\spad{ls} to a permutation whose image is given by \\spad{ls} and the preimage is fixed to be [1,{}...,{}\\spad{n}]. Note: {coerceImages(\\spad{ls})=coercePreimagesImages([1,{}...,{}\\spad{n}],{}\\spad{ls})}. We assume that both preimage and image do not contain repetitions.")) (|fixedPoints| (((|Set| |#1|) $) "\\indented{1}{fixedPoints(\\spad{p}) returns the points fixed by the permutation \\spad{p}.} \\spad{X} \\spad{p} \\spad{:=} coercePreimagesImages([[0,{}1,{}2,{}3],{}[3,{}0,{}2,{}1]])\\$PERM ZMOD 4 \\spad{X} fixedPoints \\spad{p}")) (|sort| (((|List| $) (|List| $)) "\\spad{sort(lp)} sorts a list of permutations \\spad{lp} according to cycle structure first according to length of cycles,{} second,{} if \\spad{S} has \\spadtype{Finite} or \\spad{S} has \\spadtype{OrderedSet} according to lexicographical order of entries in cycles of equal length.")) (|odd?| (((|Boolean|) $) "\\spad{odd?(p)} returns \\spad{true} if and only if \\spad{p} is an odd permutation \\spadignore{i.e.} sign(\\spad{p}) is \\spad{-1}.")) (|even?| (((|Boolean|) $) "\\indented{1}{even?(\\spad{p}) returns \\spad{true} if and only if \\spad{p} is an even permutation,{}} \\indented{1}{\\spadignore{i.e.} sign(\\spad{p}) is 1.} \\blankline \\spad{X} \\spad{p} \\spad{:=} coercePreimagesImages([[1,{}2,{}3],{}[1,{}2,{}3]]) \\spad{X} even? \\spad{p}")) (|sign| (((|Integer|) $) "\\spad{sign(p)} returns the signum of the permutation \\spad{p},{} \\spad{+1} or \\spad{-1}.")) (|numberOfCycles| (((|NonNegativeInteger|) $) "\\spad{numberOfCycles(p)} returns the number of non-trivial cycles of the permutation \\spad{p}.")) (|order| (((|NonNegativeInteger|) $) "\\spad{order(p)} returns the order of a permutation \\spad{p} as a group element.")) (|cyclePartition| (((|Partition|) $) "\\spad{cyclePartition(p)} returns the cycle structure of a permutation \\spad{p} including cycles of length 1 only if \\spad{S} is finite.")) (|movedPoints| (((|Set| |#1|) $) "\\indented{1}{movedPoints(\\spad{p}) returns the set of points moved by the permutation \\spad{p}.} \\blankline \\spad{X} \\spad{p} \\spad{:=} coercePreimagesImages([[1,{}2,{}3],{}[1,{}2,{}3]]) \\spad{X} movedPoints \\spad{p}")) (|degree| (((|NonNegativeInteger|) $) "\\spad{degree(p)} retuns the number of points moved by the permutation \\spad{p}.")) (|coerceListOfPairs| (($ (|List| (|List| |#1|))) "\\spad{coerceListOfPairs(lls)} coerces a list of pairs \\spad{lls} to a permutation. Error: if not consistent,{} \\spadignore{i.e.} the set of the first elements coincides with the set of second elements. coerce(\\spad{p}) generates output of the permutation \\spad{p} with domain OutputForm.")) (|coerce| (($ (|List| |#1|)) "\\spad{coerce(ls)} coerces a cycle \\spad{ls},{} \\spadignore{i.e.} a list with not repetitions to a permutation,{} which maps \\spad{ls}.\\spad{i} to \\spad{ls}.\\spad{i+1},{} indices modulo the length of the list. Error: if repetitions occur.") (($ (|List| (|List| |#1|))) "\\spad{coerce(lls)} coerces a list of cycles \\spad{lls} to a permutation,{} each cycle being a list with no repetitions,{} is coerced to the permutation,{} which maps \\spad{ls}.\\spad{i} to \\spad{ls}.\\spad{i+1},{} indices modulo the length of the list,{} then these permutations are mutiplied. Error: if repetitions occur in one cycle.")) (|coercePreimagesImages| (($ (|List| (|List| |#1|))) "\\indented{1}{coercePreimagesImages(\\spad{lls}) coerces the representation \\spad{lls}} \\indented{1}{of a permutation as a list of preimages and images to a permutation.} \\indented{1}{We assume that both preimage and image do not contain repetitions.} \\blankline \\spad{X} \\spad{p} \\spad{:=} coercePreimagesImages([[1,{}2,{}3],{}[1,{}2,{}3]]) \\spad{X} \\spad{q} \\spad{:=} coercePreimagesImages([[0,{}1,{}2,{}3],{}[3,{}0,{}2,{}1]])\\$PERM ZMOD 4")) (|listRepresentation| (((|Record| (|:| |preimage| (|List| |#1|)) (|:| |image| (|List| |#1|))) $) "\\spad{listRepresentation(p)} produces a representation rep of the permutation \\spad{p} as a list of preimages and images,{} \\spad{i}.\\spad{e} \\spad{p} maps (rep.preimage).\\spad{k} to (rep.image).\\spad{k} for all indices \\spad{k}. Elements of \\spad{S} not in (rep.preimage).\\spad{k} are fixed points,{} and these are the only fixed points of the permutation."))) 
-((-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (QUOTE (-842))) (-2198 (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (QUOTE (-842))))) 
+((-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (QUOTE (-842))) (-2199 (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (QUOTE (-842))))) 
 (-901 R E |VarSet| S) 
 ((|constructor| (NIL "PolynomialFactorizationByRecursion(\\spad{R},{}\\spad{E},{}\\spad{VarSet},{}\\spad{S}) is used for factorization of sparse univariate polynomials over a domain \\spad{S} of multivariate polynomials over \\spad{R}.")) (|factorSFBRlcUnit| (((|Factored| (|SparseUnivariatePolynomial| |#4|)) (|List| |#3|) (|SparseUnivariatePolynomial| |#4|)) "\\spad{factorSFBRlcUnit(p)} returns the square free factorization of polynomial \\spad{p} (see \\spadfun{factorSquareFreeByRecursion}{PolynomialFactorizationByRecursionUnivariate}) in the case where the leading coefficient of \\spad{p} is a unit.")) (|bivariateSLPEBR| (((|Union| (|List| (|SparseUnivariatePolynomial| |#4|)) "failed") (|List| (|SparseUnivariatePolynomial| |#4|)) (|SparseUnivariatePolynomial| |#4|) |#3|) "\\spad{bivariateSLPEBR(lp,{}p,{}v)} implements the bivariate case of solveLinearPolynomialEquationByRecursion its implementation depends on \\spad{R}")) (|randomR| ((|#1|) "\\spad{randomR produces} a random element of \\spad{R}")) (|factorSquareFreeByRecursion| (((|Factored| (|SparseUnivariatePolynomial| |#4|)) (|SparseUnivariatePolynomial| |#4|)) "\\spad{factorSquareFreeByRecursion(p)} returns the square free factorization of \\spad{p}. This functions performs the recursion step for factorSquareFreePolynomial,{} as defined in \\spadfun{PolynomialFactorizationExplicit} category (see \\spadfun{factorSquareFreePolynomial}).")) (|factorByRecursion| (((|Factored| (|SparseUnivariatePolynomial| |#4|)) (|SparseUnivariatePolynomial| |#4|)) "\\spad{factorByRecursion(p)} factors polynomial \\spad{p}. This function performs the recursion step for factorPolynomial,{} as defined in \\spadfun{PolynomialFactorizationExplicit} category (see \\spadfun{factorPolynomial})")) (|solveLinearPolynomialEquationByRecursion| (((|Union| (|List| (|SparseUnivariatePolynomial| |#4|)) "failed") (|List| (|SparseUnivariatePolynomial| |#4|)) (|SparseUnivariatePolynomial| |#4|)) "\\spad{solveLinearPolynomialEquationByRecursion([p1,{}...,{}pn],{}p)} returns the list of polynomials \\spad{[q1,{}...,{}qn]} such that \\spad{sum qi/pi = p / prod \\spad{pi}},{} a recursion step for solveLinearPolynomialEquation as defined in \\spadfun{PolynomialFactorizationExplicit} category (see \\spadfun{solveLinearPolynomialEquation}). If no such list of \\spad{qi} exists,{} then \"failed\" is returned."))) 
 NIL 
@@ -3546,11 +3546,11 @@ NIL
 ((|HasCategory| |#1| (QUOTE (-148)))) 
 (-904) 
 ((|constructor| (NIL "This is the category of domains that know \"enough\" about themselves in order to factor univariate polynomials over themselves. This will be used in future releases for supporting factorization over finitely generated coefficient fields,{} it is not yet available in the current release of axiom.")) (|charthRoot| (((|Union| $ "failed") $) "\\spad{charthRoot(r)} returns the \\spad{p}\\spad{-}th root of \\spad{r},{} or \"failed\" if none exists in the domain.")) (|conditionP| (((|Union| (|Vector| $) "failed") (|Matrix| $)) "\\spad{conditionP(m)} returns a vector of elements,{} not all zero,{} whose \\spad{p}\\spad{-}th powers (\\spad{p} is the characteristic of the domain) are a solution of the homogenous linear system represented by \\spad{m},{} or \"failed\" is there is no such vector.")) (|solveLinearPolynomialEquation| (((|Union| (|List| (|SparseUnivariatePolynomial| $)) "failed") (|List| (|SparseUnivariatePolynomial| $)) (|SparseUnivariatePolynomial| $)) "\\spad{solveLinearPolynomialEquation([f1,{} ...,{} fn],{} g)} (where the \\spad{fi} are relatively prime to each other) returns a list of \\spad{ai} such that \\spad{g/prod \\spad{fi} = sum ai/fi} or returns \"failed\" if no such list of \\spad{ai}\\spad{'s} exists.")) (|gcdPolynomial| (((|SparseUnivariatePolynomial| $) (|SparseUnivariatePolynomial| $) (|SparseUnivariatePolynomial| $)) "\\spad{gcdPolynomial(p,{}q)} returns the \\spad{gcd} of the univariate polynomials \\spad{p} \\spad{qnd} \\spad{q}.")) (|factorSquareFreePolynomial| (((|Factored| (|SparseUnivariatePolynomial| $)) (|SparseUnivariatePolynomial| $)) "\\spad{factorSquareFreePolynomial(p)} factors the univariate polynomial \\spad{p} into irreducibles where \\spad{p} is known to be square free and primitive with respect to its main variable.")) (|factorPolynomial| (((|Factored| (|SparseUnivariatePolynomial| $)) (|SparseUnivariatePolynomial| $)) "\\spad{factorPolynomial(p)} returns the factorization into irreducibles of the univariate polynomial \\spad{p}.")) (|squareFreePolynomial| (((|Factored| (|SparseUnivariatePolynomial| $)) (|SparseUnivariatePolynomial| $)) "\\spad{squareFreePolynomial(p)} returns the square-free factorization of the univariate polynomial \\spad{p}."))) 
-((-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-905 |p|) 
 ((|constructor| (NIL "PrimeField(\\spad{p}) implements the field with \\spad{p} elements if \\spad{p} is a prime number."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 ((|HasCategory| $ (QUOTE (-150))) (|HasCategory| $ (QUOTE (-148))) (|HasCategory| $ (QUOTE (-370)))) 
 (-906 R0 -1478 UP UPUP R) 
 ((|constructor| (NIL "This package provides function for testing whether a divisor on a curve is a torsion divisor.")) (|torsionIfCan| (((|Union| (|Record| (|:| |order| (|NonNegativeInteger|)) (|:| |function| |#5|)) "failed") (|FiniteDivisor| |#2| |#3| |#4| |#5|)) "\\spad{torsionIfCan(f)}\\\\ undocumented")) (|torsion?| (((|Boolean|) (|FiniteDivisor| |#2| |#3| |#4| |#5|)) "\\spad{torsion?(f)} \\undocumented")) (|order| (((|Union| (|NonNegativeInteger|) "failed") (|FiniteDivisor| |#2| |#3| |#4| |#5|)) "\\spad{order(f)} \\undocumented"))) 
@@ -3560,7 +3560,7 @@ NIL
 ((|constructor| (NIL "This package provides function for testing whether a divisor on a curve is a torsion divisor.")) (|torsionIfCan| (((|Union| (|Record| (|:| |order| (|NonNegativeInteger|)) (|:| |function| |#3|)) "failed") (|FiniteDivisor| (|Fraction| (|Integer|)) |#1| |#2| |#3|)) "\\spad{torsionIfCan(f)} \\undocumented")) (|torsion?| (((|Boolean|) (|FiniteDivisor| (|Fraction| (|Integer|)) |#1| |#2| |#3|)) "\\spad{torsion?(f)} \\undocumented")) (|order| (((|Union| (|NonNegativeInteger|) "failed") (|FiniteDivisor| (|Fraction| (|Integer|)) |#1| |#2| |#3|)) "\\spad{order(f)} \\undocumented"))) 
 NIL 
 NIL 
-(-908 R |PolyRing| E -2570) 
+(-908 R |PolyRing| E -1965) 
 ((|constructor| (NIL "The following is part of the PAFF package")) (|degreeOfMinimalForm| (((|NonNegativeInteger|) |#2|) "\\spad{degreeOfMinimalForm does} what it says")) (|listAllMono| (((|List| |#2|) (|NonNegativeInteger|)) "\\spad{listAllMono(l)} returns all the monomials of degree \\spad{l}")) (|listAllMonoExp| (((|List| |#3|) (|Integer|)) "\\spad{listAllMonoExp(l)} returns all the exponents of degree \\spad{l}")) (|homogenize| ((|#2| |#2| (|Integer|)) "\\spad{homogenize(pol,{}n)} returns the homogenized polynomial of \\spad{pol} with respect to the \\spad{n}-th variable.")) (|constant| ((|#1| |#2|) "\\spad{constant(pol)} returns the constant term of the polynomial.")) (|degOneCoef| ((|#1| |#2| (|PositiveInteger|)) "\\spad{degOneCoef(pol,{}n)} returns the coefficient in front of the monomial specified by the positive integer.")) (|translate| ((|#2| |#2| (|List| |#1|)) "\\spad{translate(pol,{}[a,{}b,{}c])} apply to \\spad{pol} the linear change of coordinates,{} \\spad{x}->x+a,{} \\spad{y}->y+b,{} \\spad{z}->z+c") ((|#2| |#2| (|List| |#1|) (|Integer|)) "\\spad{translate(pol,{}[a,{}b,{}c],{}3)} apply to \\spad{pol} the linear change of coordinates,{} \\spad{x}->x+a,{} \\spad{y}->y+b,{} \\spad{z}-\\spad{>1}.")) (|replaceVarByOne| ((|#2| |#2| (|Integer|)) "\\spad{replaceVarByOne(pol,{}a)} evaluate to one the variable in \\spad{pol} specified by the integer a.")) (|replaceVarByZero| ((|#2| |#2| (|Integer|)) "\\spad{replaceVarByZero(pol,{}a)} evaluate to zero the variable in \\spad{pol} specified by the integer a.")) (|firstExponent| ((|#3| |#2|) "\\spad{firstExponent(pol)} returns the exponent of the first term in the representation of \\spad{pol}. Not to be confused with the leadingExponent \\indented{1}{which is the highest exponent according to the order} over the monomial.")) (|minimalForm| ((|#2| |#2|) "\\spad{minimalForm(pol)} returns the minimal forms of the polynomial \\spad{pol}."))) 
 NIL 
 NIL 
@@ -3570,7 +3570,7 @@ NIL
 NIL 
 (-910 R) 
 ((|constructor| (NIL "The domain \\spadtype{PartialFraction} implements partial fractions over a euclidean domain \\spad{R}. This requirement on the argument domain allows us to normalize the fractions. Of particular interest are the 2 forms for these fractions. The ``compact\\spad{''} form has only one fractional term per prime in the denominator,{} while the \\spad{``p}-adic\\spad{''} form expands each numerator \\spad{p}-adically via the prime \\spad{p} in the denominator. For computational efficiency,{} the compact form is used,{} though the \\spad{p}-adic form may be gotten by calling the function padicFraction}. For a general euclidean domain,{} it is not known how to factor the denominator. Thus the function partialFraction takes as its second argument an element of \\spadtype{Factored(R)}.")) (|wholePart| ((|#1| $) "\\indented{1}{wholePart(\\spad{p}) extracts the whole part of the partial fraction} \\indented{1}{\\spad{p}.} \\blankline \\spad{X} a:=(74/13)::PFR(INT) \\spad{X} wholePart(a)")) (|partialFraction| (($ |#1| (|Factored| |#1|)) "\\indented{1}{partialFraction(numer,{}denom) is the main function for} \\indented{1}{constructing partial fractions. The second argument is the} \\indented{1}{denominator and should be factored.} \\blankline \\spad{X} partialFraction(1,{}factorial 10)")) (|padicFraction| (($ $) "\\indented{1}{padicFraction(\\spad{q}) expands the fraction \\spad{p}-adically in the primes} \\indented{1}{\\spad{p} in the denominator of \\spad{q}. For example,{}} \\indented{1}{\\spad{padicFraction(3/(2**2)) = 1/2 + 1/(2**2)}.} \\indented{1}{Use compactFraction from PartialFraction to} \\indented{1}{return to compact form.} \\blankline \\spad{X} a:=partialFraction(1,{}factorial 10) \\spad{X} padicFraction(a)")) (|padicallyExpand| (((|SparseUnivariatePolynomial| |#1|) |#1| |#1|) "\\spad{padicallyExpand(p,{}x)} is a utility function that expands the second argument \\spad{x} \\spad{``p}-adically\\spad{''} in the first.")) (|numberOfFractionalTerms| (((|Integer|) $) "\\indented{1}{numberOfFractionalTerms(\\spad{p}) computes the number of fractional} \\indented{1}{terms in \\spad{p}. This returns 0 if there is no fractional} \\indented{1}{part.} \\blankline \\spad{X} a:=partialFraction(1,{}factorial 10) \\spad{X} b:=padicFraction(a) \\spad{X} numberOfFractionalTerms(\\spad{b})")) (|nthFractionalTerm| (($ $ (|Integer|)) "\\indented{1}{nthFractionalTerm(\\spad{p},{}\\spad{n}) extracts the \\spad{n}th fractional term from} \\indented{1}{the partial fraction \\spad{p}.\\space{2}This returns 0 if the index} \\indented{1}{\\spad{n} is out of range.} \\blankline \\spad{X} a:=partialFraction(1,{}factorial 10) \\spad{X} b:=padicFraction(a) \\spad{X} nthFractionalTerm(\\spad{b},{}3)")) (|firstNumer| ((|#1| $) "\\indented{1}{firstNumer(\\spad{p}) extracts the numerator of the first fractional} \\indented{1}{term. This returns 0 if there is no fractional part (use} \\indented{1}{wholePart from PartialFraction to get the whole part).} \\blankline \\spad{X} a:=partialFraction(1,{}factorial 10) \\spad{X} firstNumer(a)")) (|firstDenom| (((|Factored| |#1|) $) "\\indented{1}{firstDenom(\\spad{p}) extracts the denominator of the first fractional} \\indented{1}{term. This returns 1 if there is no fractional part (use} \\indented{1}{wholePart from PartialFraction to get the whole part).} \\blankline \\spad{X} a:=partialFraction(1,{}factorial 10) \\spad{X} firstDenom(a)")) (|compactFraction| (($ $) "\\indented{1}{compactFraction(\\spad{p}) normalizes the partial fraction \\spad{p}} \\indented{1}{to the compact representation. In this form,{} the partial} \\indented{1}{fraction has only one fractional term per prime in the} \\indented{1}{denominator.} \\blankline \\spad{X} a:=partialFraction(1,{}factorial 10) \\spad{X} b:=padicFraction(a) \\spad{X} compactFraction(\\spad{b})")) (|coerce| (($ (|Fraction| (|Factored| |#1|))) "\\indented{1}{coerce(\\spad{f}) takes a fraction with numerator and denominator in} \\indented{1}{factored form and creates a partial fraction.\\space{2}It is} \\indented{1}{necessary for the parts to be factored because it is not} \\indented{1}{known in general how to factor elements of \\spad{R} and} \\indented{1}{this is needed to decompose into partial fractions.} \\blankline \\spad{X} (13/74)::PFR(INT)") (((|Fraction| |#1|) $) "\\indented{1}{coerce(\\spad{p}) sums up the components of the partial fraction and} \\indented{1}{returns a single fraction.} \\blankline \\spad{X} a:=(13/74)::PFR(INT) \\spad{X} a::FRAC(INT)"))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-911 R) 
 ((|constructor| (NIL "The package \\spadtype{PartialFractionPackage} gives an easier to use interfact the domain \\spadtype{PartialFraction}. The user gives a fraction of polynomials,{} and a variable and the package converts it to the proper datatype for the \\spadtype{PartialFraction} domain.")) (|partialFraction| (((|Any|) (|Polynomial| |#1|) (|Factored| (|Polynomial| |#1|)) (|Symbol|)) "\\spad{partialFraction(num,{} facdenom,{} var)} returns the partial fraction decomposition of the rational function whose numerator is \\spad{num} and whose factored denominator is \\spad{facdenom} with respect to the variable var.") (((|Any|) (|Fraction| (|Polynomial| |#1|)) (|Symbol|)) "\\indented{1}{partialFraction(\\spad{rf},{} var) returns the partial fraction decomposition} \\indented{1}{of the rational function \\spad{rf} with respect to the variable var.} \\blankline \\spad{X} a:=x+1/(\\spad{y+1}) \\spad{X} partialFraction(a,{}\\spad{y})\\$PFRPAC(INT)"))) 
@@ -3594,11 +3594,11 @@ NIL
 NIL 
 (-916) 
 ((|constructor| (NIL "The category of constructive principal ideal domains,{} \\spadignore{i.e.} where a single generator can be constructively found for any ideal given by a finite set of generators. Note that this constructive definition only implies that finitely generated ideals are principal. It is not clear what we would mean by an infinitely generated ideal.")) (|expressIdealMember| (((|Union| (|List| $) "failed") (|List| $) $) "\\spad{expressIdealMember([f1,{}...,{}fn],{}h)} returns a representation of \\spad{h} as a linear combination of the \\spad{fi} or \"failed\" if \\spad{h} is not in the ideal generated by the \\spad{fi}.")) (|principalIdeal| (((|Record| (|:| |coef| (|List| $)) (|:| |generator| $)) (|List| $)) "\\spad{principalIdeal([f1,{}...,{}fn])} returns a record whose generator component is a generator of the ideal generated by \\spad{[f1,{}...,{}fn]} whose coef component satisfies \\spad{generator = sum (input.i * coef.i)}"))) 
-((-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-917) 
 ((|constructor| (NIL "\\spadtype{PositiveInteger} provides functions for positive integers.")) (|commutative| ((|attribute| "*") "\\spad{commutative(\"*\")} means multiplication is commutative : x*y = \\spad{y*x}")) (|gcd| (($ $ $) "\\spad{gcd(a,{}b)} computes the greatest common divisor of two positive integers \\spad{a} and \\spad{b}."))) 
-(((-4521 "*") . T)) 
+(((-4523 "*") . T)) 
 NIL 
 (-918 -1478 P) 
 ((|constructor| (NIL "This package exports interpolation algorithms")) (|LagrangeInterpolation| ((|#2| (|List| |#1|) (|List| |#1|)) "\\spad{LagrangeInterpolation(l1,{}l2)} \\undocumented"))) 
@@ -3644,7 +3644,7 @@ NIL
 ((|constructor| (NIL "This package exports plotting tools")) (|calcRanges| (((|List| (|Segment| (|DoubleFloat|))) (|List| (|List| (|Point| (|DoubleFloat|))))) "\\spad{calcRanges(l)} \\undocumented"))) 
 NIL 
 NIL 
-(-929 K |PolyRing| E -2570 |ProjPt|) 
+(-929 K |PolyRing| E -1965 |ProjPt|) 
 ((|constructor| (NIL "The following is part of the PAFF package")) (|multiplicity| (((|NonNegativeInteger|) |#2| |#5| (|Integer|)) "\\spad{multiplicity returns} the multiplicity of the polynomial at given point.") (((|NonNegativeInteger|) |#2| |#5|) "\\spad{multiplicity returns} the multiplicity of the polynomial at given point.")) (|minimalForm| ((|#2| |#2| |#5| (|Integer|)) "\\spad{minimalForm returns} the minimal form after translation to the origin.") ((|#2| |#2| |#5|) "\\spad{minimalForm returns} the minimal form after translation to the origin.")) (|translateToOrigin| ((|#2| |#2| |#5|) "\\spad{translateToOrigin translate} the polynomial from the given point to the origin") ((|#2| |#2| |#5| (|Integer|)) "\\spad{translateToOrigin translate} the polynomial from the given point to the origin")) (|eval| ((|#1| |#2| |#5|) "\\spad{eval returns} the value at given point.")) (|pointInIdeal?| (((|Boolean|) (|List| |#2|) |#5|) "\\spad{pointInIdeal? test} if the given point is in the algebraic set defined by the given list of polynomials."))) 
 NIL 
 NIL 
@@ -3680,11 +3680,11 @@ NIL
 ((|constructor| (NIL "This package provides pattern matching functions on polynomials.")) (|patternMatch| (((|PatternMatchResult| |#1| |#5|) |#5| (|Pattern| |#1|) (|PatternMatchResult| |#1| |#5|)) "\\spad{patternMatch(p,{} pat,{} res)} matches the pattern \\spad{pat} to the polynomial \\spad{p}; res contains the variables of \\spad{pat} which are already matched and their matches.") (((|PatternMatchResult| |#1| |#5|) |#5| (|Pattern| |#1|) (|PatternMatchResult| |#1| |#5|) (|Mapping| (|PatternMatchResult| |#1| |#5|) |#3| (|Pattern| |#1|) (|PatternMatchResult| |#1| |#5|))) "\\spad{patternMatch(p,{} pat,{} res,{} vmatch)} matches the pattern \\spad{pat} to the polynomial \\spad{p}. \\spad{res} contains the variables of \\spad{pat} which are already matched and their matches; vmatch is the matching function to use on the variables."))) 
 NIL 
 ((|HasCategory| |#3| (LIST (QUOTE -881) (|devaluate| |#1|)))) 
-(-938 R -1478 -3190) 
+(-938 R -1478 -3192) 
 ((|constructor| (NIL "Attaching predicates to symbols for pattern matching.")) (|suchThat| ((|#2| |#2| (|List| (|Mapping| (|Boolean|) |#3|))) "\\spad{suchThat(x,{} [f1,{} f2,{} ...,{} fn])} attaches the predicate \\spad{f1} and \\spad{f2} and ... and \\spad{fn} to \\spad{x}. Error: if \\spad{x} is not a symbol.") ((|#2| |#2| (|Mapping| (|Boolean|) |#3|)) "\\spad{suchThat(x,{} foo)} attaches the predicate foo to \\spad{x}; error if \\spad{x} is not a symbol."))) 
 NIL 
 NIL 
-(-939 -3190) 
+(-939 -3192) 
 ((|constructor| (NIL "Attaching predicates to symbols for pattern matching.")) (|suchThat| (((|Expression| (|Integer|)) (|Symbol|) (|List| (|Mapping| (|Boolean|) |#1|))) "\\spad{suchThat(x,{} [f1,{} f2,{} ...,{} fn])} attaches the predicate \\spad{f1} and \\spad{f2} and ... and \\spad{fn} to \\spad{x}.") (((|Expression| (|Integer|)) (|Symbol|) (|Mapping| (|Boolean|) |#1|)) "\\spad{suchThat(x,{} foo)} attaches the predicate foo to \\spad{x}."))) 
 NIL 
 NIL 
@@ -3706,8 +3706,8 @@ NIL
 NIL 
 (-944 R) 
 ((|constructor| (NIL "This domain implements points in coordinate space"))) 
-((-4520 . T) (-4519 . T)) 
-((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (-2198 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-716))) (|HasCategory| |#1| (QUOTE (-1047))) (-12 (|HasCategory| |#1| (QUOTE (-1002))) (|HasCategory| |#1| (QUOTE (-1047)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
+((-4522 . T) (-4521 . T)) 
+((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (-2199 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-716))) (|HasCategory| |#1| (QUOTE (-1047))) (-12 (|HasCategory| |#1| (QUOTE (-1002))) (|HasCategory| |#1| (QUOTE (-1047)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
 (-945 |lv| R) 
 ((|constructor| (NIL "Package with the conversion functions among different kind of polynomials")) (|pToDmp| (((|DistributedMultivariatePolynomial| |#1| |#2|) (|Polynomial| |#2|)) "\\spad{pToDmp(p)} converts \\spad{p} from a \\spadtype{POLY} to a \\spadtype{DMP}.")) (|dmpToP| (((|Polynomial| |#2|) (|DistributedMultivariatePolynomial| |#1| |#2|)) "\\spad{dmpToP(p)} converts \\spad{p} from a \\spadtype{DMP} to a \\spadtype{POLY}.")) (|hdmpToP| (((|Polynomial| |#2|) (|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|)) "\\spad{hdmpToP(p)} converts \\spad{p} from a \\spadtype{HDMP} to a \\spadtype{POLY}.")) (|pToHdmp| (((|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|) (|Polynomial| |#2|)) "\\spad{pToHdmp(p)} converts \\spad{p} from a \\spadtype{POLY} to a \\spadtype{HDMP}.")) (|hdmpToDmp| (((|DistributedMultivariatePolynomial| |#1| |#2|) (|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|)) "\\spad{hdmpToDmp(p)} converts \\spad{p} from a \\spadtype{HDMP} to a \\spadtype{DMP}.")) (|dmpToHdmp| (((|HomogeneousDistributedMultivariatePolynomial| |#1| |#2|) (|DistributedMultivariatePolynomial| |#1| |#2|)) "\\spad{dmpToHdmp(p)} converts \\spad{p} from a \\spadtype{DMP} to a \\spadtype{HDMP}."))) 
 NIL 
@@ -3727,10 +3727,10 @@ NIL
 (-949 S R E |VarSet|) 
 ((|constructor| (NIL "The category for general multi-variate polynomials over a ring \\spad{R},{} in variables from VarSet,{} with exponents from the \\spadtype{OrderedAbelianMonoidSup}.")) (|canonicalUnitNormal| ((|attribute|) "we can choose a unique representative for each associate class. This normalization is chosen to be normalization of leading coefficient (by default).")) (|squareFreePart| (($ $) "\\spad{squareFreePart(p)} returns product of all the irreducible factors of polynomial \\spad{p} each taken with multiplicity one.")) (|squareFree| (((|Factored| $) $) "\\spad{squareFree(p)} returns the square free factorization of the polynomial \\spad{p}.")) (|primitivePart| (($ $ |#4|) "\\spad{primitivePart(p,{}v)} returns the unitCanonical associate of the polynomial \\spad{p} with its content with respect to the variable \\spad{v} divided out.") (($ $) "\\spad{primitivePart(p)} returns the unitCanonical associate of the polynomial \\spad{p} with its content divided out.")) (|content| (($ $ |#4|) "\\spad{content(p,{}v)} is the \\spad{gcd} of the coefficients of the polynomial \\spad{p} when \\spad{p} is viewed as a univariate polynomial with respect to the variable \\spad{v}. Thus,{} for polynomial 7*x**2*y + 14*x*y**2,{} the \\spad{gcd} of the coefficients with respect to \\spad{x} is 7*y.")) (|discriminant| (($ $ |#4|) "\\spad{discriminant(p,{}v)} returns the disriminant of the polynomial \\spad{p} with respect to the variable \\spad{v}.")) (|resultant| (($ $ $ |#4|) "\\spad{resultant(p,{}q,{}v)} returns the resultant of the polynomials \\spad{p} and \\spad{q} with respect to the variable \\spad{v}.")) (|primitiveMonomials| (((|List| $) $) "\\spad{primitiveMonomials(p)} gives the list of monomials of the polynomial \\spad{p} with their coefficients removed. Note that \\spad{primitiveMonomials(sum(a_(i) X^(i))) = [X^(1),{}...,{}X^(n)]}.")) (|variables| (((|List| |#4|) $) "\\spad{variables(p)} returns the list of those variables actually appearing in the polynomial \\spad{p}.")) (|totalDegree| (((|NonNegativeInteger|) $ (|List| |#4|)) "\\spad{totalDegree(p,{} lv)} returns the maximum sum (over all monomials of polynomial \\spad{p}) of the variables in the list \\spad{lv}.") (((|NonNegativeInteger|) $) "\\spad{totalDegree(p)} returns the largest sum over all monomials of all exponents of a monomial.")) (|isExpt| (((|Union| (|Record| (|:| |var| |#4|) (|:| |exponent| (|NonNegativeInteger|))) "failed") $) "\\spad{isExpt(p)} returns \\spad{[x,{} n]} if polynomial \\spad{p} has the form \\spad{x**n} and \\spad{n > 0}.")) (|isTimes| (((|Union| (|List| $) "failed") $) "\\spad{isTimes(p)} returns \\spad{[a1,{}...,{}an]} if polynomial \\spad{p = a1 ... an} and \\spad{n >= 2},{} and,{} for each \\spad{i},{} \\spad{ai} is either a nontrivial constant in \\spad{R} or else of the form \\spad{x**e},{} where \\spad{e > 0} is an integer and \\spad{x} in a member of VarSet.")) (|isPlus| (((|Union| (|List| $) "failed") $) "\\spad{isPlus(p)} returns \\spad{[m1,{}...,{}mn]} if polynomial \\spad{p = m1 + ... + mn} and \\spad{n >= 2} and each \\spad{mi} is a nonzero monomial.")) (|multivariate| (($ (|SparseUnivariatePolynomial| $) |#4|) "\\spad{multivariate(sup,{}v)} converts an anonymous univariable polynomial \\spad{sup} to a polynomial in the variable \\spad{v}.") (($ (|SparseUnivariatePolynomial| |#2|) |#4|) "\\spad{multivariate(sup,{}v)} converts an anonymous univariable polynomial \\spad{sup} to a polynomial in the variable \\spad{v}.")) (|monomial| (($ $ (|List| |#4|) (|List| (|NonNegativeInteger|))) "\\spad{monomial(a,{}[v1..vn],{}[e1..en])} returns \\spad{a*prod(vi**ei)}.") (($ $ |#4| (|NonNegativeInteger|)) "\\spad{monomial(a,{}x,{}n)} creates the monomial \\spad{a*x**n} where \\spad{a} is a polynomial,{} \\spad{x} is a variable and \\spad{n} is a nonnegative integer.")) (|monicDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $ |#4|) "\\spad{monicDivide(a,{}b,{}v)} divides the polynomial a by the polynomial \\spad{b},{} with each viewed as a univariate polynomial in \\spad{v} returning both the quotient and remainder. Error: if \\spad{b} is not monic with respect to \\spad{v}.")) (|minimumDegree| (((|List| (|NonNegativeInteger|)) $ (|List| |#4|)) "\\spad{minimumDegree(p,{} lv)} gives the list of minimum degrees of the polynomial \\spad{p} with respect to each of the variables in the list \\spad{lv}") (((|NonNegativeInteger|) $ |#4|) "\\spad{minimumDegree(p,{}v)} gives the minimum degree of polynomial \\spad{p} with respect to \\spad{v},{} \\spadignore{i.e.} viewed a univariate polynomial in \\spad{v}")) (|mainVariable| (((|Union| |#4| "failed") $) "\\spad{mainVariable(p)} returns the biggest variable which actually occurs in the polynomial \\spad{p},{} or \"failed\" if no variables are present. fails precisely if polynomial satisfies ground?")) (|univariate| (((|SparseUnivariatePolynomial| |#2|) $) "\\spad{univariate(p)} converts the multivariate polynomial \\spad{p},{} which should actually involve only one variable,{} into a univariate polynomial in that variable,{} whose coefficients are in the ground ring. Error: if polynomial is genuinely multivariate") (((|SparseUnivariatePolynomial| $) $ |#4|) "\\spad{univariate(p,{}v)} converts the multivariate polynomial \\spad{p} into a univariate polynomial in \\spad{v},{} whose coefficients are still multivariate polynomials (in all the other variables).")) (|monomials| (((|List| $) $) "\\spad{monomials(p)} returns the list of non-zero monomials of polynomial \\spad{p},{} \\spadignore{i.e.} \\spad{monomials(sum(a_(i) X^(i))) = [a_(1) X^(1),{}...,{}a_(n) X^(n)]}.")) (|coefficient| (($ $ (|List| |#4|) (|List| (|NonNegativeInteger|))) "\\spad{coefficient(p,{} lv,{} ln)} views the polynomial \\spad{p} as a polynomial in the variables of \\spad{lv} and returns the coefficient of the term \\spad{lv**ln},{} \\spadignore{i.e.} \\spad{prod(lv_i ** ln_i)}.") (($ $ |#4| (|NonNegativeInteger|)) "\\spad{coefficient(p,{}v,{}n)} views the polynomial \\spad{p} as a univariate polynomial in \\spad{v} and returns the coefficient of the \\spad{v**n} term.")) (|degree| (((|List| (|NonNegativeInteger|)) $ (|List| |#4|)) "\\spad{degree(p,{}lv)} gives the list of degrees of polynomial \\spad{p} with respect to each of the variables in the list \\spad{lv}.") (((|NonNegativeInteger|) $ |#4|) "\\spad{degree(p,{}v)} gives the degree of polynomial \\spad{p} with respect to the variable \\spad{v}."))) 
 NIL 
-((|HasCategory| |#2| (QUOTE (-904))) (|HasAttribute| |#2| (QUOTE -4517)) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#4| (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#4| (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#4| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#4| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#4| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (QUOTE (-842)))) 
+((|HasCategory| |#2| (QUOTE (-904))) (|HasAttribute| |#2| (QUOTE -4519)) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#4| (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#4| (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#4| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#4| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#4| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (QUOTE (-842)))) 
 (-950 R E |VarSet|) 
 ((|constructor| (NIL "The category for general multi-variate polynomials over a ring \\spad{R},{} in variables from VarSet,{} with exponents from the \\spadtype{OrderedAbelianMonoidSup}.")) (|canonicalUnitNormal| ((|attribute|) "we can choose a unique representative for each associate class. This normalization is chosen to be normalization of leading coefficient (by default).")) (|squareFreePart| (($ $) "\\spad{squareFreePart(p)} returns product of all the irreducible factors of polynomial \\spad{p} each taken with multiplicity one.")) (|squareFree| (((|Factored| $) $) "\\spad{squareFree(p)} returns the square free factorization of the polynomial \\spad{p}.")) (|primitivePart| (($ $ |#3|) "\\spad{primitivePart(p,{}v)} returns the unitCanonical associate of the polynomial \\spad{p} with its content with respect to the variable \\spad{v} divided out.") (($ $) "\\spad{primitivePart(p)} returns the unitCanonical associate of the polynomial \\spad{p} with its content divided out.")) (|content| (($ $ |#3|) "\\spad{content(p,{}v)} is the \\spad{gcd} of the coefficients of the polynomial \\spad{p} when \\spad{p} is viewed as a univariate polynomial with respect to the variable \\spad{v}. Thus,{} for polynomial 7*x**2*y + 14*x*y**2,{} the \\spad{gcd} of the coefficients with respect to \\spad{x} is 7*y.")) (|discriminant| (($ $ |#3|) "\\spad{discriminant(p,{}v)} returns the disriminant of the polynomial \\spad{p} with respect to the variable \\spad{v}.")) (|resultant| (($ $ $ |#3|) "\\spad{resultant(p,{}q,{}v)} returns the resultant of the polynomials \\spad{p} and \\spad{q} with respect to the variable \\spad{v}.")) (|primitiveMonomials| (((|List| $) $) "\\spad{primitiveMonomials(p)} gives the list of monomials of the polynomial \\spad{p} with their coefficients removed. Note that \\spad{primitiveMonomials(sum(a_(i) X^(i))) = [X^(1),{}...,{}X^(n)]}.")) (|variables| (((|List| |#3|) $) "\\spad{variables(p)} returns the list of those variables actually appearing in the polynomial \\spad{p}.")) (|totalDegree| (((|NonNegativeInteger|) $ (|List| |#3|)) "\\spad{totalDegree(p,{} lv)} returns the maximum sum (over all monomials of polynomial \\spad{p}) of the variables in the list \\spad{lv}.") (((|NonNegativeInteger|) $) "\\spad{totalDegree(p)} returns the largest sum over all monomials of all exponents of a monomial.")) (|isExpt| (((|Union| (|Record| (|:| |var| |#3|) (|:| |exponent| (|NonNegativeInteger|))) "failed") $) "\\spad{isExpt(p)} returns \\spad{[x,{} n]} if polynomial \\spad{p} has the form \\spad{x**n} and \\spad{n > 0}.")) (|isTimes| (((|Union| (|List| $) "failed") $) "\\spad{isTimes(p)} returns \\spad{[a1,{}...,{}an]} if polynomial \\spad{p = a1 ... an} and \\spad{n >= 2},{} and,{} for each \\spad{i},{} \\spad{ai} is either a nontrivial constant in \\spad{R} or else of the form \\spad{x**e},{} where \\spad{e > 0} is an integer and \\spad{x} in a member of VarSet.")) (|isPlus| (((|Union| (|List| $) "failed") $) "\\spad{isPlus(p)} returns \\spad{[m1,{}...,{}mn]} if polynomial \\spad{p = m1 + ... + mn} and \\spad{n >= 2} and each \\spad{mi} is a nonzero monomial.")) (|multivariate| (($ (|SparseUnivariatePolynomial| $) |#3|) "\\spad{multivariate(sup,{}v)} converts an anonymous univariable polynomial \\spad{sup} to a polynomial in the variable \\spad{v}.") (($ (|SparseUnivariatePolynomial| |#1|) |#3|) "\\spad{multivariate(sup,{}v)} converts an anonymous univariable polynomial \\spad{sup} to a polynomial in the variable \\spad{v}.")) (|monomial| (($ $ (|List| |#3|) (|List| (|NonNegativeInteger|))) "\\spad{monomial(a,{}[v1..vn],{}[e1..en])} returns \\spad{a*prod(vi**ei)}.") (($ $ |#3| (|NonNegativeInteger|)) "\\spad{monomial(a,{}x,{}n)} creates the monomial \\spad{a*x**n} where \\spad{a} is a polynomial,{} \\spad{x} is a variable and \\spad{n} is a nonnegative integer.")) (|monicDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $ |#3|) "\\spad{monicDivide(a,{}b,{}v)} divides the polynomial a by the polynomial \\spad{b},{} with each viewed as a univariate polynomial in \\spad{v} returning both the quotient and remainder. Error: if \\spad{b} is not monic with respect to \\spad{v}.")) (|minimumDegree| (((|List| (|NonNegativeInteger|)) $ (|List| |#3|)) "\\spad{minimumDegree(p,{} lv)} gives the list of minimum degrees of the polynomial \\spad{p} with respect to each of the variables in the list \\spad{lv}") (((|NonNegativeInteger|) $ |#3|) "\\spad{minimumDegree(p,{}v)} gives the minimum degree of polynomial \\spad{p} with respect to \\spad{v},{} \\spadignore{i.e.} viewed a univariate polynomial in \\spad{v}")) (|mainVariable| (((|Union| |#3| "failed") $) "\\spad{mainVariable(p)} returns the biggest variable which actually occurs in the polynomial \\spad{p},{} or \"failed\" if no variables are present. fails precisely if polynomial satisfies ground?")) (|univariate| (((|SparseUnivariatePolynomial| |#1|) $) "\\spad{univariate(p)} converts the multivariate polynomial \\spad{p},{} which should actually involve only one variable,{} into a univariate polynomial in that variable,{} whose coefficients are in the ground ring. Error: if polynomial is genuinely multivariate") (((|SparseUnivariatePolynomial| $) $ |#3|) "\\spad{univariate(p,{}v)} converts the multivariate polynomial \\spad{p} into a univariate polynomial in \\spad{v},{} whose coefficients are still multivariate polynomials (in all the other variables).")) (|monomials| (((|List| $) $) "\\spad{monomials(p)} returns the list of non-zero monomials of polynomial \\spad{p},{} \\spadignore{i.e.} \\spad{monomials(sum(a_(i) X^(i))) = [a_(1) X^(1),{}...,{}a_(n) X^(n)]}.")) (|coefficient| (($ $ (|List| |#3|) (|List| (|NonNegativeInteger|))) "\\spad{coefficient(p,{} lv,{} ln)} views the polynomial \\spad{p} as a polynomial in the variables of \\spad{lv} and returns the coefficient of the term \\spad{lv**ln},{} \\spadignore{i.e.} \\spad{prod(lv_i ** ln_i)}.") (($ $ |#3| (|NonNegativeInteger|)) "\\spad{coefficient(p,{}v,{}n)} views the polynomial \\spad{p} as a univariate polynomial in \\spad{v} and returns the coefficient of the \\spad{v**n} term.")) (|degree| (((|List| (|NonNegativeInteger|)) $ (|List| |#3|)) "\\spad{degree(p,{}lv)} gives the list of degrees of polynomial \\spad{p} with respect to each of the variables in the list \\spad{lv}.") (((|NonNegativeInteger|) $ |#3|) "\\spad{degree(p,{}v)} gives the degree of polynomial \\spad{p} with respect to the variable \\spad{v}."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-6 -4517)) (-4514 . T) (-4513 . T) (-4516 . T)) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-6 -4519)) (-4516 . T) (-4515 . T) (-4518 . T)) 
 NIL 
 (-951 E V R P -1478) 
 ((|constructor| (NIL "Manipulations on polynomial quotients This package transforms multivariate polynomials or fractions into univariate polynomials or fractions,{} and back.")) (|isPower| (((|Union| (|Record| (|:| |val| |#5|) (|:| |exponent| (|Integer|))) "failed") |#5|) "\\spad{isPower(p)} returns \\spad{[x,{} n]} if \\spad{p = x**n} and \\spad{n <> 0},{} \"failed\" otherwise.")) (|isExpt| (((|Union| (|Record| (|:| |var| |#2|) (|:| |exponent| (|Integer|))) "failed") |#5|) "\\spad{isExpt(p)} returns \\spad{[x,{} n]} if \\spad{p = x**n} and \\spad{n <> 0},{} \"failed\" otherwise.")) (|isTimes| (((|Union| (|List| |#5|) "failed") |#5|) "\\spad{isTimes(p)} returns \\spad{[a1,{}...,{}an]} if \\spad{p = a1 ... an} and \\spad{n > 1},{} \"failed\" otherwise.")) (|isPlus| (((|Union| (|List| |#5|) "failed") |#5|) "\\spad{isPlus(p)} returns [\\spad{m1},{}...,{}\\spad{mn}] if \\spad{p = m1 + ... + mn} and \\spad{n > 1},{} \"failed\" otherwise.")) (|multivariate| ((|#5| (|Fraction| (|SparseUnivariatePolynomial| |#5|)) |#2|) "\\spad{multivariate(f,{} v)} applies both the numerator and denominator of \\spad{f} to \\spad{v}.")) (|univariate| (((|SparseUnivariatePolynomial| |#5|) |#5| |#2| (|SparseUnivariatePolynomial| |#5|)) "\\spad{univariate(f,{} x,{} p)} returns \\spad{f} viewed as a univariate polynomial in \\spad{x},{} using the side-condition \\spad{p(x) = 0}.") (((|Fraction| (|SparseUnivariatePolynomial| |#5|)) |#5| |#2|) "\\spad{univariate(f,{} v)} returns \\spad{f} viewed as a univariate rational function in \\spad{v}.")) (|mainVariable| (((|Union| |#2| "failed") |#5|) "\\spad{mainVariable(f)} returns the highest variable appearing in the numerator or the denominator of \\spad{f},{} \"failed\" if \\spad{f} has no variables.")) (|variables| (((|List| |#2|) |#5|) "\\spad{variables(f)} returns the list of variables appearing in the numerator or the denominator of \\spad{f}."))) 
@@ -3742,8 +3742,8 @@ NIL
 NIL 
 (-953 R) 
 ((|constructor| (NIL "This type is the basic representation of sparse recursive multivariate polynomials whose variables are arbitrary symbols. The ordering is alphabetic determined by the Symbol type. The coefficient ring may be non commutative,{} but the variables are assumed to commute.")) (|integrate| (($ $ (|Symbol|)) "\\spad{integrate(p,{}x)} computes the integral of \\spad{p*dx},{} \\spadignore{i.e.} integrates the polynomial \\spad{p} with respect to the variable \\spad{x}."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-6 -4517)) (-4514 . T) (-4513 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| (-1161) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-1161) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-1161) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-1161) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-1161) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#1| (QUOTE -4517)) (|HasCategory| |#1| (QUOTE (-453))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-6 -4519)) (-4516 . T) (-4515 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| (-1161) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-1161) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-1161) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-1161) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-1161) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#1| (QUOTE -4519)) (|HasCategory| |#1| (QUOTE (-453))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))))) 
 (-954 E V R P -1478) 
 ((|constructor| (NIL "Computes \\spad{n}-th roots of quotients of multivariate polynomials")) (|nthr| (((|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| |#4|) (|:| |radicand| (|List| |#4|))) |#4| (|NonNegativeInteger|)) "\\spad{nthr(p,{}n)} should be local but conditional")) (|froot| (((|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| |#5|) (|:| |radicand| |#5|)) |#5| (|NonNegativeInteger|)) "\\spad{froot(f,{} n)} returns \\spad{[m,{}c,{}r]} such that \\spad{f**(1/n) = c * r**(1/m)}.")) (|qroot| (((|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| |#5|) (|:| |radicand| |#5|)) (|Fraction| (|Integer|)) (|NonNegativeInteger|)) "\\spad{qroot(f,{} n)} returns \\spad{[m,{}c,{}r]} such that \\spad{f**(1/n) = c * r**(1/m)}.")) (|rroot| (((|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| |#5|) (|:| |radicand| |#5|)) |#3| (|NonNegativeInteger|)) "\\spad{rroot(f,{} n)} returns \\spad{[m,{}c,{}r]} such that \\spad{f**(1/n) = c * r**(1/m)}.")) (|coerce| (($ |#4|) "\\spad{coerce(p)} \\undocumented")) (|denom| ((|#4| $) "\\spad{denom(x)} \\undocumented")) (|numer| ((|#4| $) "\\spad{numer(x)} \\undocumented"))) 
 NIL 
@@ -3762,8 +3762,8 @@ NIL
 NIL 
 (-958 S) 
 ((|constructor| (NIL "This provides a fast array type with no bound checking on elt\\spad{'s}. Minimum index is 0 in this type,{} cannot be changed"))) 
-((-4520 . T) (-4519 . T)) 
-((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (-2198 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
+((-4522 . T) (-4521 . T)) 
+((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (-2199 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
 (-959) 
 ((|constructor| (NIL "Category for the functions defined by integrals.")) (|integral| (($ $ (|SegmentBinding| $)) "\\spad{integral(f,{} x = a..b)} returns the formal definite integral of \\spad{f} \\spad{dx} for \\spad{x} between \\spad{a} and \\spad{b}.") (($ $ (|Symbol|)) "\\spad{integral(f,{} x)} returns the formal integral of \\spad{f} \\spad{dx}."))) 
 NIL 
@@ -3786,12 +3786,12 @@ NIL
 NIL 
 (-964 R E) 
 ((|constructor| (NIL "This domain represents generalized polynomials with coefficients (from a not necessarily commutative ring),{} and terms indexed by their exponents (from an arbitrary ordered abelian monoid). This type is used,{} for example,{} by the \\spadtype{DistributedMultivariatePolynomial} domain where the exponent domain is a direct product of non negative integers.")) (|canonicalUnitNormal| ((|attribute|) "canonicalUnitNormal guarantees that the function unitCanonical returns the same representative for all associates of any particular element.")) (|fmecg| (($ $ |#2| |#1| $) "\\spad{fmecg(p1,{}e,{}r,{}p2)} finds \\spad{x} : \\spad{p1} - \\spad{r} * x**e * \\spad{p2}"))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-6 -4517)) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (-12 (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-137)))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#1| (QUOTE -4517))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-6 -4519)) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (-12 (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-137)))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#1| (QUOTE -4519))) 
 (-965 A B) 
 ((|constructor| (NIL "This domain implements cartesian product")) (|selectsecond| ((|#2| $) "\\spad{selectsecond(x)} is not documented")) (|selectfirst| ((|#1| $) "\\spad{selectfirst(x)} is not documented")) (|makeprod| (($ |#1| |#2|) "\\indented{1}{makeprod(a,{}\\spad{b}) computes the product of two functions} \\blankline \\spad{X} \\spad{f:=}(x:INT):INT +-> 3*x \\spad{X} \\spad{g:=}(x:INT):INT +-> \\spad{x^3} \\spad{X} \\spad{h}(x:INT):Product(INT,{}INT) \\spad{==} makeprod(\\spad{f} \\spad{x},{} \\spad{g} \\spad{x}) \\spad{X} \\spad{h}(3)"))) 
-((-4516 -12 (|has| |#2| (-478)) (|has| |#1| (-478)))) 
-((-12 (|HasCategory| |#1| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-788)))) (-12 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-21)))) (-12 (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#2| (QUOTE (-478)))) (-12 (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#2| (QUOTE (-370)))) (-12 (|HasCategory| |#1| (QUOTE (-716))) (|HasCategory| |#2| (QUOTE (-716)))) (-2198 (-12 (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#2| (QUOTE (-478)))) (-12 (|HasCategory| |#1| (QUOTE (-716))) (|HasCategory| |#2| (QUOTE (-716))))) (-12 (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#2| (QUOTE (-23)))) (-12 (|HasCategory| |#1| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-137)))) (-2198 (-12 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-21)))) (-12 (|HasCategory| |#1| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#1| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-788))))) (-2198 (-12 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-21)))) (-12 (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#2| (QUOTE (-23)))) (-12 (|HasCategory| |#1| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#1| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-788))))) (-2198 (-12 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-21)))) (-12 (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#2| (QUOTE (-23)))) (-12 (|HasCategory| |#1| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#2| (QUOTE (-478)))) (-12 (|HasCategory| |#1| (QUOTE (-716))) (|HasCategory| |#2| (QUOTE (-716)))) (-12 (|HasCategory| |#1| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-788))))) (-12 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-842)))) (-2198 (-12 (|HasCategory| |#1| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-788)))) (-12 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-842)))))) 
+((-4518 -12 (|has| |#2| (-478)) (|has| |#1| (-478)))) 
+((-12 (|HasCategory| |#1| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-788)))) (-12 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-21)))) (-12 (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#2| (QUOTE (-478)))) (-12 (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#2| (QUOTE (-370)))) (-12 (|HasCategory| |#1| (QUOTE (-716))) (|HasCategory| |#2| (QUOTE (-716)))) (-2199 (-12 (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#2| (QUOTE (-478)))) (-12 (|HasCategory| |#1| (QUOTE (-716))) (|HasCategory| |#2| (QUOTE (-716))))) (-12 (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#2| (QUOTE (-23)))) (-12 (|HasCategory| |#1| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-137)))) (-2199 (-12 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-21)))) (-12 (|HasCategory| |#1| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#1| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-788))))) (-2199 (-12 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-21)))) (-12 (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#2| (QUOTE (-23)))) (-12 (|HasCategory| |#1| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#1| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-788))))) (-2199 (-12 (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-21)))) (-12 (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#2| (QUOTE (-23)))) (-12 (|HasCategory| |#1| (QUOTE (-137))) (|HasCategory| |#2| (QUOTE (-137)))) (-12 (|HasCategory| |#1| (QUOTE (-478))) (|HasCategory| |#2| (QUOTE (-478)))) (-12 (|HasCategory| |#1| (QUOTE (-716))) (|HasCategory| |#2| (QUOTE (-716)))) (-12 (|HasCategory| |#1| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-788))))) (-12 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-842)))) (-2199 (-12 (|HasCategory| |#1| (QUOTE (-788))) (|HasCategory| |#2| (QUOTE (-788)))) (-12 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-842)))))) 
 (-966 K) 
 ((|constructor| (NIL "This is part of the PAFF package,{} related to projective space."))) 
 NIL 
@@ -3800,13 +3800,13 @@ NIL
 ((|constructor| (NIL "This is part of the PAFF package,{} related to projective space."))) 
 NIL 
 NIL 
-(-968 -2570 K) 
+(-968 -1965 K) 
 ((|constructor| (NIL "This is part of the PAFF package,{} related to projective space."))) 
 NIL 
 NIL 
 (-969 S) 
 ((|constructor| (NIL "A priority queue is a bag of items from an ordered set where the item extracted is always the maximum element.")) (|merge!| (($ $ $) "\\spad{merge!(q,{}q1)} destructively changes priority queue \\spad{q} to include the values from priority queue \\spad{q1}.")) (|merge| (($ $ $) "\\spad{merge(q1,{}q2)} returns combines priority queues \\spad{q1} and \\spad{q2} to return a single priority queue \\spad{q}.")) (|max| ((|#1| $) "\\spad{max(q)} returns the maximum element of priority queue \\spad{q}."))) 
-((-4519 . T) (-4520 . T) (-3973 . T)) 
+((-4521 . T) (-4522 . T) (-3973 . T)) 
 NIL 
 (-970 R |polR|) 
 ((|constructor| (NIL "This package contains some functions: discriminant,{} resultant,{} subResultantGcd,{} chainSubResultants,{} degreeSubResultant,{} lastSubResultant,{} resultantEuclidean,{} subResultantGcdEuclidean,{} \\spad{semiSubResultantGcdEuclidean1},{} \\spad{semiSubResultantGcdEuclidean2}\\spad{\\br} These procedures come from improvements of the subresultants algorithm.")) (|semiResultantEuclideannaif| (((|Record| (|:| |coef2| |#2|) (|:| |resultant| |#1|)) |#2| |#2|) "\\axiom{resultantEuclidean_naif(\\spad{P},{}\\spad{Q})} returns the semi-extended resultant of \\axiom{\\spad{P}} and \\axiom{\\spad{Q}} computed by means of the naive algorithm.")) (|resultantEuclideannaif| (((|Record| (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |resultant| |#1|)) |#2| |#2|) "\\axiom{resultantEuclidean_naif(\\spad{P},{}\\spad{Q})} returns the extended resultant of \\axiom{\\spad{P}} and \\axiom{\\spad{Q}} computed by means of the naive algorithm.")) (|resultantnaif| ((|#1| |#2| |#2|) "\\axiom{resultantEuclidean_naif(\\spad{P},{}\\spad{Q})} returns the resultant of \\axiom{\\spad{P}} and \\axiom{\\spad{Q}} computed by means of the naive algorithm.")) (|nextsousResultant2| ((|#2| |#2| |#2| |#2| |#1|) "\\axiom{\\spad{nextsousResultant2}(\\spad{P},{} \\spad{Q},{} \\spad{Z},{} \\spad{s})} returns the subresultant \\axiom{\\spad{S_}{\\spad{e}-1}} where \\axiom{\\spad{P} ~ \\spad{S_d},{} \\spad{Q} = \\spad{S_}{\\spad{d}-1},{} \\spad{Z} = S_e,{} \\spad{s} = \\spad{lc}(\\spad{S_d})}")) (|Lazard2| ((|#2| |#2| |#1| |#1| (|NonNegativeInteger|)) "\\axiom{\\spad{Lazard2}(\\spad{F},{} \\spad{x},{} \\spad{y},{} \\spad{n})} computes \\axiom{(x/y)\\spad{**}(\\spad{n}-1) * \\spad{F}}")) (|Lazard| ((|#1| |#1| |#1| (|NonNegativeInteger|)) "\\axiom{Lazard(\\spad{x},{} \\spad{y},{} \\spad{n})} computes \\axiom{x**n/y**(\\spad{n}-1)}")) (|divide| (((|Record| (|:| |quotient| |#2|) (|:| |remainder| |#2|)) |#2| |#2|) "\\axiom{divide(\\spad{F},{}\\spad{G})} computes quotient and rest of the exact euclidean division of \\axiom{\\spad{F}} by \\axiom{\\spad{G}}.")) (|pseudoDivide| (((|Record| (|:| |coef| |#1|) (|:| |quotient| |#2|) (|:| |remainder| |#2|)) |#2| |#2|) "\\axiom{pseudoDivide(\\spad{P},{}\\spad{Q})} computes the pseudoDivide of \\axiom{\\spad{P}} by \\axiom{\\spad{Q}}.")) (|exquo| (((|Vector| |#2|) (|Vector| |#2|) |#1|) "\\axiom{\\spad{v} exquo \\spad{r}} computes the exact quotient of \\axiom{\\spad{v}} by \\axiom{\\spad{r}}")) (* (((|Vector| |#2|) |#1| (|Vector| |#2|)) "\\axiom{\\spad{r} * \\spad{v}} computes the product of \\axiom{\\spad{r}} and \\axiom{\\spad{v}}")) (|gcd| ((|#2| |#2| |#2|) "\\axiom{\\spad{gcd}(\\spad{P},{} \\spad{Q})} returns the \\spad{gcd} of \\axiom{\\spad{P}} and \\axiom{\\spad{Q}}.")) (|semiResultantReduitEuclidean| (((|Record| (|:| |coef2| |#2|) (|:| |resultantReduit| |#1|)) |#2| |#2|) "\\axiom{semiResultantReduitEuclidean(\\spad{P},{}\\spad{Q})} returns the \"reduce resultant\" and carries out the equality \\axiom{...\\spad{P} + coef2*Q = resultantReduit(\\spad{P},{}\\spad{Q})}.")) (|resultantReduitEuclidean| (((|Record| (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |resultantReduit| |#1|)) |#2| |#2|) "\\axiom{resultantReduitEuclidean(\\spad{P},{}\\spad{Q})} returns the \"reduce resultant\" and carries out the equality \\axiom{coef1*P + coef2*Q = resultantReduit(\\spad{P},{}\\spad{Q})}.")) (|resultantReduit| ((|#1| |#2| |#2|) "\\axiom{resultantReduit(\\spad{P},{}\\spad{Q})} returns the \"reduce resultant\" of \\axiom{\\spad{P}} and \\axiom{\\spad{Q}}.")) (|schema| (((|List| (|NonNegativeInteger|)) |#2| |#2|) "\\axiom{schema(\\spad{P},{}\\spad{Q})} returns the list of degrees of non zero subresultants of \\axiom{\\spad{P}} and \\axiom{\\spad{Q}}.")) (|chainSubResultants| (((|List| |#2|) |#2| |#2|) "\\axiom{chainSubResultants(\\spad{P},{} \\spad{Q})} computes the list of non zero subresultants of \\axiom{\\spad{P}} and \\axiom{\\spad{Q}}.")) (|semiDiscriminantEuclidean| (((|Record| (|:| |coef2| |#2|) (|:| |discriminant| |#1|)) |#2|) "\\axiom{discriminantEuclidean(\\spad{P})} carries out the equality \\axiom{...\\spad{P} + \\spad{coef2} * \\spad{D}(\\spad{P}) = discriminant(\\spad{P})}. Warning. \\axiom{degree(\\spad{P}) \\spad{>=} degree(\\spad{Q})}.")) (|discriminantEuclidean| (((|Record| (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |discriminant| |#1|)) |#2|) "\\axiom{discriminantEuclidean(\\spad{P})} carries out the equality \\axiom{\\spad{coef1} * \\spad{P} + \\spad{coef2} * \\spad{D}(\\spad{P}) = discriminant(\\spad{P})}.")) (|discriminant| ((|#1| |#2|) "\\axiom{discriminant(\\spad{P},{} \\spad{Q})} returns the discriminant of \\axiom{\\spad{P}} and \\axiom{\\spad{Q}}.")) (|semiSubResultantGcdEuclidean1| (((|Record| (|:| |coef1| |#2|) (|:| |gcd| |#2|)) |#2| |#2|) "\\axiom{\\spad{semiSubResultantGcdEuclidean1}(\\spad{P},{}\\spad{Q})} carries out the equality \\axiom{coef1*P + ? \\spad{Q} = \\spad{+/-} S_i(\\spad{P},{}\\spad{Q})} where the degree (not the indice) of the subresultant \\axiom{S_i(\\spad{P},{}\\spad{Q})} is the smaller as possible.")) (|semiSubResultantGcdEuclidean2| (((|Record| (|:| |coef2| |#2|) (|:| |gcd| |#2|)) |#2| |#2|) "\\axiom{\\spad{semiSubResultantGcdEuclidean2}(\\spad{P},{}\\spad{Q})} carries out the equality \\axiom{...\\spad{P} + coef2*Q = \\spad{+/-} S_i(\\spad{P},{}\\spad{Q})} where the degree (not the indice) of the subresultant \\axiom{S_i(\\spad{P},{}\\spad{Q})} is the smaller as possible. Warning. \\axiom{degree(\\spad{P}) \\spad{>=} degree(\\spad{Q})}.")) (|subResultantGcdEuclidean| (((|Record| (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |gcd| |#2|)) |#2| |#2|) "\\axiom{subResultantGcdEuclidean(\\spad{P},{}\\spad{Q})} carries out the equality \\axiom{coef1*P + coef2*Q = \\spad{+/-} S_i(\\spad{P},{}\\spad{Q})} where the degree (not the indice) of the subresultant \\axiom{S_i(\\spad{P},{}\\spad{Q})} is the smaller as possible.")) (|subResultantGcd| ((|#2| |#2| |#2|) "\\axiom{subResultantGcd(\\spad{P},{} \\spad{Q})} returns the \\spad{gcd} of two primitive polynomials \\axiom{\\spad{P}} and \\axiom{\\spad{Q}}.")) (|semiLastSubResultantEuclidean| (((|Record| (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|) "\\axiom{semiLastSubResultantEuclidean(\\spad{P},{} \\spad{Q})} computes the last non zero subresultant \\axiom{\\spad{S}} and carries out the equality \\axiom{...\\spad{P} + coef2*Q = \\spad{S}}. Warning. \\axiom{degree(\\spad{P}) \\spad{>=} degree(\\spad{Q})}.")) (|lastSubResultantEuclidean| (((|Record| (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|) "\\axiom{lastSubResultantEuclidean(\\spad{P},{} \\spad{Q})} computes the last non zero subresultant \\axiom{\\spad{S}} and carries out the equality \\axiom{coef1*P + coef2*Q = \\spad{S}}.")) (|lastSubResultant| ((|#2| |#2| |#2|) "\\axiom{lastSubResultant(\\spad{P},{} \\spad{Q})} computes the last non zero subresultant of \\axiom{\\spad{P}} and \\axiom{\\spad{Q}}")) (|semiDegreeSubResultantEuclidean| (((|Record| (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (|NonNegativeInteger|)) "\\axiom{indiceSubResultant(\\spad{P},{} \\spad{Q},{} \\spad{i})} returns a subresultant \\axiom{\\spad{S}} of degree \\axiom{\\spad{d}} and carries out the equality \\axiom{...\\spad{P} + coef2*Q = S_i}. Warning. \\axiom{degree(\\spad{P}) \\spad{>=} degree(\\spad{Q})}.")) (|degreeSubResultantEuclidean| (((|Record| (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (|NonNegativeInteger|)) "\\axiom{indiceSubResultant(\\spad{P},{} \\spad{Q},{} \\spad{i})} returns a subresultant \\axiom{\\spad{S}} of degree \\axiom{\\spad{d}} and carries out the equality \\axiom{coef1*P + coef2*Q = S_i}.")) (|degreeSubResultant| ((|#2| |#2| |#2| (|NonNegativeInteger|)) "\\axiom{degreeSubResultant(\\spad{P},{} \\spad{Q},{} \\spad{d})} computes a subresultant of degree \\axiom{\\spad{d}}.")) (|semiIndiceSubResultantEuclidean| (((|Record| (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (|NonNegativeInteger|)) "\\axiom{semiIndiceSubResultantEuclidean(\\spad{P},{} \\spad{Q},{} \\spad{i})} returns the subresultant \\axiom{S_i(\\spad{P},{}\\spad{Q})} and carries out the equality \\axiom{...\\spad{P} + coef2*Q = S_i(\\spad{P},{}\\spad{Q})} Warning. \\axiom{degree(\\spad{P}) \\spad{>=} degree(\\spad{Q})}.")) (|indiceSubResultantEuclidean| (((|Record| (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (|NonNegativeInteger|)) "\\axiom{indiceSubResultant(\\spad{P},{} \\spad{Q},{} \\spad{i})} returns the subresultant \\axiom{S_i(\\spad{P},{}\\spad{Q})} and carries out the equality \\axiom{coef1*P + coef2*Q = S_i(\\spad{P},{}\\spad{Q})}")) (|indiceSubResultant| ((|#2| |#2| |#2| (|NonNegativeInteger|)) "\\axiom{indiceSubResultant(\\spad{P},{} \\spad{Q},{} \\spad{i})} returns the subresultant of indice \\axiom{\\spad{i}}")) (|semiResultantEuclidean1| (((|Record| (|:| |coef1| |#2|) (|:| |resultant| |#1|)) |#2| |#2|) "\\axiom{\\spad{semiResultantEuclidean1}(\\spad{P},{}\\spad{Q})} carries out the equality \\axiom{\\spad{coef1}.\\spad{P} + ? \\spad{Q} = resultant(\\spad{P},{}\\spad{Q})}.")) (|semiResultantEuclidean2| (((|Record| (|:| |coef2| |#2|) (|:| |resultant| |#1|)) |#2| |#2|) "\\axiom{\\spad{semiResultantEuclidean2}(\\spad{P},{}\\spad{Q})} carries out the equality \\axiom{...\\spad{P} + coef2*Q = resultant(\\spad{P},{}\\spad{Q})}. Warning. \\axiom{degree(\\spad{P}) \\spad{>=} degree(\\spad{Q})}.")) (|resultantEuclidean| (((|Record| (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |resultant| |#1|)) |#2| |#2|) "\\axiom{resultantEuclidean(\\spad{P},{}\\spad{Q})} carries out the equality \\axiom{coef1*P + coef2*Q = resultant(\\spad{P},{}\\spad{Q})}")) (|resultant| ((|#1| |#2| |#2|) "\\axiom{resultant(\\spad{P},{} \\spad{Q})} returns the resultant of \\axiom{\\spad{P}} and \\axiom{\\spad{Q}}"))) 
@@ -3826,7 +3826,7 @@ NIL
 NIL 
 (-974 |Coef| |Expon| |Var|) 
 ((|constructor| (NIL "\\spadtype{PowerSeriesCategory} is the most general power series category with exponents in an ordered abelian monoid.")) (|complete| (($ $) "\\spad{complete(f)} causes all terms of \\spad{f} to be computed. Note that this results in an infinite loop if \\spad{f} has infinitely many terms.")) (|pole?| (((|Boolean|) $) "\\spad{pole?(f)} determines if the power series \\spad{f} has a pole.")) (|variables| (((|List| |#3|) $) "\\spad{variables(f)} returns a list of the variables occuring in the power series \\spad{f}.")) (|degree| ((|#2| $) "\\spad{degree(f)} returns the exponent of the lowest order term of \\spad{f}.")) (|leadingCoefficient| ((|#1| $) "\\spad{leadingCoefficient(f)} returns the coefficient of the lowest order term of \\spad{f}")) (|leadingMonomial| (($ $) "\\spad{leadingMonomial(f)} returns the monomial of \\spad{f} of lowest order.")) (|monomial| (($ $ (|List| |#3|) (|List| |#2|)) "\\spad{monomial(a,{}[x1,{}..,{}xk],{}[n1,{}..,{}nk])} computes \\spad{a * x1**n1 * .. * xk**nk}.") (($ $ |#3| |#2|) "\\spad{monomial(a,{}x,{}n)} computes \\spad{a*x**n}."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4513 . T) (-4514 . T) (-4516 . T)) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-975) 
 ((|constructor| (NIL "PlottableSpaceCurveCategory is the category of curves in 3-space which may be plotted via the graphics facilities. Functions are provided for obtaining lists of lists of points,{} representing the branches of the curve,{} and for determining the ranges of the \\spad{x-},{} \\spad{y-},{} and \\spad{z}-coordinates of the points on the curve.")) (|zRange| (((|Segment| (|DoubleFloat|)) $) "\\spad{zRange(c)} returns the range of the \\spad{z}-coordinates of the points on the curve \\spad{c}.")) (|yRange| (((|Segment| (|DoubleFloat|)) $) "\\spad{yRange(c)} returns the range of the \\spad{y}-coordinates of the points on the curve \\spad{c}.")) (|xRange| (((|Segment| (|DoubleFloat|)) $) "\\spad{xRange(c)} returns the range of the \\spad{x}-coordinates of the points on the curve \\spad{c}.")) (|listBranches| (((|List| (|List| (|Point| (|DoubleFloat|)))) $) "\\spad{listBranches(c)} returns a list of lists of points,{} representing the branches of the curve \\spad{c}."))) 
@@ -3838,7 +3838,7 @@ NIL
 ((|HasCategory| |#2| (QUOTE (-558)))) 
 (-977 R E |VarSet| P) 
 ((|constructor| (NIL "A category for finite subsets of a polynomial ring. Such a set is only regarded as a set of polynomials and not identified to the ideal it generates. So two distinct sets may generate the same the ideal. Furthermore,{} for \\spad{R} being an integral domain,{} a set of polynomials may be viewed as a representation of the ideal it generates in the polynomial ring \\spad{(R)^(-1) P},{} or the set of its zeros (described for instance by the radical of the previous ideal,{} or a split of the associated affine variety) and so on. So this category provides operations about those different notions.")) (|triangular?| (((|Boolean|) $) "\\axiom{triangular?(\\spad{ps})} returns \\spad{true} iff \\axiom{\\spad{ps}} is a triangular set,{} \\spadignore{i.e.} two distinct polynomials have distinct main variables and no constant lies in \\axiom{\\spad{ps}}.")) (|rewriteIdealWithRemainder| (((|List| |#4|) (|List| |#4|) $) "\\axiom{rewriteIdealWithRemainder(\\spad{lp},{}\\spad{cs})} returns \\axiom{\\spad{lr}} such that every polynomial in \\axiom{\\spad{lr}} is fully reduced in the sense of Groebner bases \\spad{w}.\\spad{r}.\\spad{t}. \\axiom{\\spad{cs}} and \\axiom{(\\spad{lp},{}\\spad{cs})} and \\axiom{(\\spad{lr},{}\\spad{cs})} generate the same ideal in \\axiom{(\\spad{R})^(\\spad{-1}) \\spad{P}}.")) (|rewriteIdealWithHeadRemainder| (((|List| |#4|) (|List| |#4|) $) "\\axiom{rewriteIdealWithHeadRemainder(\\spad{lp},{}\\spad{cs})} returns \\axiom{\\spad{lr}} such that the leading monomial of every polynomial in \\axiom{\\spad{lr}} is reduced in the sense of Groebner bases \\spad{w}.\\spad{r}.\\spad{t}. \\axiom{\\spad{cs}} and \\axiom{(\\spad{lp},{}\\spad{cs})} and \\axiom{(\\spad{lr},{}\\spad{cs})} generate the same ideal in \\axiom{(\\spad{R})^(\\spad{-1}) \\spad{P}}.")) (|remainder| (((|Record| (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) "\\axiom{remainder(a,{}\\spad{ps})} returns \\axiom{[\\spad{c},{}\\spad{b},{}\\spad{r}]} such that \\axiom{\\spad{b}} is fully reduced in the sense of Groebner bases \\spad{w}.\\spad{r}.\\spad{t}. \\axiom{\\spad{ps}},{} \\axiom{r*a - \\spad{c*b}} lies in the ideal generated by \\axiom{\\spad{ps}}. Furthermore,{} if \\axiom{\\spad{R}} is a \\spad{gcd}-domain,{} \\axiom{\\spad{b}} is primitive.")) (|headRemainder| (((|Record| (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) "\\axiom{headRemainder(a,{}\\spad{ps})} returns \\axiom{[\\spad{b},{}\\spad{r}]} such that the leading monomial of \\axiom{\\spad{b}} is reduced in the sense of Groebner bases \\spad{w}.\\spad{r}.\\spad{t}. \\axiom{\\spad{ps}} and \\axiom{r*a - \\spad{b}} lies in the ideal generated by \\axiom{\\spad{ps}}.")) (|roughUnitIdeal?| (((|Boolean|) $) "\\axiom{roughUnitIdeal?(\\spad{ps})} returns \\spad{true} iff \\axiom{\\spad{ps}} contains \\indented{1}{some non null element lying in the base ring \\axiom{\\spad{R}}.}")) (|roughEqualIdeals?| (((|Boolean|) $ $) "\\axiom{roughEqualIdeals?(\\spad{ps1},{}\\spad{ps2})} returns \\spad{true} iff it can proved that \\axiom{\\spad{ps1}} and \\axiom{\\spad{ps2}} generate the same ideal in \\axiom{(\\spad{R})^(\\spad{-1}) \\spad{P}} without computing Groebner bases.")) (|roughSubIdeal?| (((|Boolean|) $ $) "\\axiom{roughSubIdeal?(\\spad{ps1},{}\\spad{ps2})} returns \\spad{true} iff it can proved that all polynomials in \\axiom{\\spad{ps1}} lie in the ideal generated by \\axiom{\\spad{ps2}} in \\axiom{\\axiom{(\\spad{R})^(\\spad{-1}) \\spad{P}}} without computing Groebner bases.")) (|roughBase?| (((|Boolean|) $) "\\axiom{roughBase?(\\spad{ps})} returns \\spad{true} iff for every pair \\axiom{{\\spad{p},{}\\spad{q}}} of polynomials in \\axiom{\\spad{ps}} their leading monomials are relatively prime.")) (|trivialIdeal?| (((|Boolean|) $) "\\axiom{trivialIdeal?(\\spad{ps})} returns \\spad{true} iff \\axiom{\\spad{ps}} does not contain non-zero elements.")) (|sort| (((|Record| (|:| |under| $) (|:| |floor| $) (|:| |upper| $)) $ |#3|) "\\axiom{sort(\\spad{v},{}\\spad{ps})} returns \\axiom{us,{}\\spad{vs},{}\\spad{ws}} such that \\axiom{us} is \\axiom{collectUnder(\\spad{ps},{}\\spad{v})},{} \\axiom{\\spad{vs}} is \\axiom{collect(\\spad{ps},{}\\spad{v})} and \\axiom{\\spad{ws}} is \\axiom{collectUpper(\\spad{ps},{}\\spad{v})}.")) (|collectUpper| (($ $ |#3|) "\\axiom{collectUpper(\\spad{ps},{}\\spad{v})} returns the set consisting of the polynomials of \\axiom{\\spad{ps}} with main variable greater than \\axiom{\\spad{v}}.")) (|collect| (($ $ |#3|) "\\axiom{collect(\\spad{ps},{}\\spad{v})} returns the set consisting of the polynomials of \\axiom{\\spad{ps}} with \\axiom{\\spad{v}} as main variable.")) (|collectUnder| (($ $ |#3|) "\\axiom{collectUnder(\\spad{ps},{}\\spad{v})} returns the set consisting of the polynomials of \\axiom{\\spad{ps}} with main variable less than \\axiom{\\spad{v}}.")) (|mainVariable?| (((|Boolean|) |#3| $) "\\axiom{mainVariable?(\\spad{v},{}\\spad{ps})} returns \\spad{true} iff \\axiom{\\spad{v}} is the main variable of some polynomial in \\axiom{\\spad{ps}}.")) (|mainVariables| (((|List| |#3|) $) "\\axiom{mainVariables(\\spad{ps})} returns the decreasingly sorted list of the variables which are main variables of some polynomial in \\axiom{\\spad{ps}}.")) (|variables| (((|List| |#3|) $) "\\axiom{variables(\\spad{ps})} returns the decreasingly sorted list of the variables which are variables of some polynomial in \\axiom{\\spad{ps}}.")) (|mvar| ((|#3| $) "\\axiom{mvar(\\spad{ps})} returns the main variable of the non constant polynomial with the greatest main variable,{} if any,{} else an error is returned.")) (|retract| (($ (|List| |#4|)) "\\axiom{retract(\\spad{lp})} returns an element of the domain whose elements are the members of \\axiom{\\spad{lp}} if such an element exists,{} otherwise an error is produced.")) (|retractIfCan| (((|Union| $ "failed") (|List| |#4|)) "\\axiom{retractIfCan(\\spad{lp})} returns an element of the domain whose elements are the members of \\axiom{\\spad{lp}} if such an element exists,{} otherwise \\axiom{\"failed\"} is returned."))) 
-((-4519 . T) (-3973 . T)) 
+((-4521 . T) (-3973 . T)) 
 NIL 
 (-978 R E V P) 
 ((|constructor| (NIL "This package provides modest routines for polynomial system solving. The aim of many of the operations of this package is to remove certain factors in some polynomials in order to avoid unnecessary computations in algorithms involving splitting techniques by partial factorization.")) (|removeIrreducibleRedundantFactors| (((|List| |#4|) (|List| |#4|) (|List| |#4|)) "\\axiom{removeIrreducibleRedundantFactors(\\spad{lp},{}\\spad{lq})} returns the same as \\axiom{irreducibleFactors(concat(\\spad{lp},{}\\spad{lq}))} assuming that \\axiom{irreducibleFactors(\\spad{lp})} returns \\axiom{\\spad{lp}} up to replacing some polynomial \\axiom{\\spad{pj}} in \\axiom{\\spad{lp}} by some polynomial \\axiom{\\spad{qj}} associated to \\axiom{\\spad{pj}}.")) (|lazyIrreducibleFactors| (((|List| |#4|) (|List| |#4|)) "\\axiom{lazyIrreducibleFactors(\\spad{lp})} returns \\axiom{\\spad{lf}} such that if \\axiom{\\spad{lp} = [\\spad{p1},{}...,{}\\spad{pn}]} and \\axiom{\\spad{lf} = [\\spad{f1},{}...,{}\\spad{fm}]} then \\axiom{p1*p2*...\\spad{*pn=0}} means \\axiom{f1*f2*...\\spad{*fm=0}},{} and the \\axiom{\\spad{fi}} are irreducible over \\axiom{\\spad{R}} and are pairwise distinct. The algorithm tries to avoid factorization into irreducible factors as far as possible and makes previously use of \\spad{gcd} techniques over \\axiom{\\spad{R}}.")) (|irreducibleFactors| (((|List| |#4|) (|List| |#4|)) "\\axiom{irreducibleFactors(\\spad{lp})} returns \\axiom{\\spad{lf}} such that if \\axiom{\\spad{lp} = [\\spad{p1},{}...,{}\\spad{pn}]} and \\axiom{\\spad{lf} = [\\spad{f1},{}...,{}\\spad{fm}]} then \\axiom{p1*p2*...\\spad{*pn=0}} means \\axiom{f1*f2*...\\spad{*fm=0}},{} and the \\axiom{\\spad{fi}} are irreducible over \\axiom{\\spad{R}} and are pairwise distinct.")) (|removeRedundantFactorsInPols| (((|List| |#4|) (|List| |#4|) (|List| |#4|)) "\\axiom{removeRedundantFactorsInPols(\\spad{lp},{}\\spad{lf})} returns \\axiom{newlp} where \\axiom{newlp} is obtained from \\axiom{\\spad{lp}} by removing in every polynomial \\axiom{\\spad{p}} of \\axiom{\\spad{lp}} any non trivial factor of any polynomial \\axiom{\\spad{f}} in \\axiom{\\spad{lf}}. Moreover,{} squares over \\axiom{\\spad{R}} are first removed in every polynomial \\axiom{\\spad{lp}}.")) (|removeRedundantFactorsInContents| (((|List| |#4|) (|List| |#4|) (|List| |#4|)) "\\axiom{removeRedundantFactorsInContents(\\spad{lp},{}\\spad{lf})} returns \\axiom{newlp} where \\axiom{newlp} is obtained from \\axiom{\\spad{lp}} by removing in the content of every polynomial of \\axiom{\\spad{lp}} any non trivial factor of any polynomial \\axiom{\\spad{f}} in \\axiom{\\spad{lf}}. Moreover,{} squares over \\axiom{\\spad{R}} are first removed in the content of every polynomial of \\axiom{\\spad{lp}}.")) (|removeRoughlyRedundantFactorsInContents| (((|List| |#4|) (|List| |#4|) (|List| |#4|)) "\\axiom{removeRoughlyRedundantFactorsInContents(\\spad{lp},{}\\spad{lf})} returns \\axiom{newlp}where \\axiom{newlp} is obtained from \\axiom{\\spad{lp}} by removing in the content of every polynomial of \\axiom{\\spad{lp}} any occurence of a polynomial \\axiom{\\spad{f}} in \\axiom{\\spad{lf}}. Moreover,{} squares over \\axiom{\\spad{R}} are first removed in the content of every polynomial of \\axiom{\\spad{lp}}.")) (|univariatePolynomialsGcds| (((|List| |#4|) (|List| |#4|) (|Boolean|)) "\\axiom{univariatePolynomialsGcds(\\spad{lp},{}opt)} returns the same as \\axiom{univariatePolynomialsGcds(\\spad{lp})} if \\axiom{opt} is \\axiom{\\spad{false}} and if the previous operation does not return any non null and constant polynomial,{} else return \\axiom{[1]}.") (((|List| |#4|) (|List| |#4|)) "\\axiom{univariatePolynomialsGcds(\\spad{lp})} returns \\axiom{\\spad{lg}} where \\axiom{\\spad{lg}} is a list of the gcds of every pair in \\axiom{\\spad{lp}} of univariate polynomials in the same main variable.")) (|squareFreeFactors| (((|List| |#4|) |#4|) "\\axiom{squareFreeFactors(\\spad{p})} returns the square-free factors of \\axiom{\\spad{p}} over \\axiom{\\spad{R}}")) (|rewriteIdealWithQuasiMonicGenerators| (((|List| |#4|) (|List| |#4|) (|Mapping| (|Boolean|) |#4| |#4|) (|Mapping| |#4| |#4| |#4|)) "\\axiom{rewriteIdealWithQuasiMonicGenerators(\\spad{lp},{}redOp?,{}redOp)} returns \\axiom{\\spad{lq}} where \\axiom{\\spad{lq}} and \\axiom{\\spad{lp}} generate the same ideal in \\axiom{\\spad{R^}(\\spad{-1}) \\spad{P}} and \\axiom{\\spad{lq}} has rank not higher than the one of \\axiom{\\spad{lp}}. Moreover,{} \\axiom{\\spad{lq}} is computed by reducing \\axiom{\\spad{lp}} \\spad{w}.\\spad{r}.\\spad{t}. some basic set of the ideal generated by the quasi-monic polynomials in \\axiom{\\spad{lp}}.")) (|rewriteSetByReducingWithParticularGenerators| (((|List| |#4|) (|List| |#4|) (|Mapping| (|Boolean|) |#4|) (|Mapping| (|Boolean|) |#4| |#4|) (|Mapping| |#4| |#4| |#4|)) "\\axiom{rewriteSetByReducingWithParticularGenerators(\\spad{lp},{}pred?,{}redOp?,{}redOp)} returns \\axiom{\\spad{lq}} where \\axiom{\\spad{lq}} is computed by the following algorithm. Chose a basic set \\spad{w}.\\spad{r}.\\spad{t}. the reduction-test \\axiom{redOp?} among the polynomials satisfying property \\axiom{pred?},{} if it is empty then leave,{} else reduce the other polynomials by this basic set \\spad{w}.\\spad{r}.\\spad{t}. the reduction-operation \\axiom{redOp}. Repeat while another basic set with smaller rank can be computed. See code. If \\axiom{pred?} is \\axiom{quasiMonic?} the ideal is unchanged.")) (|crushedSet| (((|List| |#4|) (|List| |#4|)) "\\axiom{crushedSet(\\spad{lp})} returns \\axiom{\\spad{lq}} such that \\axiom{\\spad{lp}} and and \\axiom{\\spad{lq}} generate the same ideal and no rough basic sets reduce (in the sense of Groebner bases) the other polynomials in \\axiom{\\spad{lq}}.")) (|roughBasicSet| (((|Union| (|Record| (|:| |bas| (|GeneralTriangularSet| |#1| |#2| |#3| |#4|)) (|:| |top| (|List| |#4|))) "failed") (|List| |#4|)) "\\axiom{roughBasicSet(\\spad{lp})} returns the smallest (with Ritt-Wu ordering) triangular set contained in \\axiom{\\spad{lp}}.")) (|interReduce| (((|List| |#4|) (|List| |#4|)) "\\axiom{interReduce(\\spad{lp})} returns \\axiom{\\spad{lq}} such that \\axiom{\\spad{lp}} and \\axiom{\\spad{lq}} generate the same ideal and no polynomial in \\axiom{\\spad{lq}} is reducuble by the others in the sense of Groebner bases. Since no assumptions are required the result may depend on the ordering the reductions are performed.")) (|removeRoughlyRedundantFactorsInPol| ((|#4| |#4| (|List| |#4|)) "\\axiom{removeRoughlyRedundantFactorsInPol(\\spad{p},{}\\spad{lf})} returns the same as removeRoughlyRedundantFactorsInPols([\\spad{p}],{}\\spad{lf},{}\\spad{true})")) (|removeRoughlyRedundantFactorsInPols| (((|List| |#4|) (|List| |#4|) (|List| |#4|) (|Boolean|)) "\\axiom{removeRoughlyRedundantFactorsInPols(\\spad{lp},{}\\spad{lf},{}opt)} returns the same as \\axiom{removeRoughlyRedundantFactorsInPols(\\spad{lp},{}\\spad{lf})} if \\axiom{opt} is \\axiom{\\spad{false}} and if the previous operation does not return any non null and constant polynomial,{} else return \\axiom{[1]}.") (((|List| |#4|) (|List| |#4|) (|List| |#4|)) "\\axiom{removeRoughlyRedundantFactorsInPols(\\spad{lp},{}\\spad{lf})} returns \\axiom{newlp}where \\axiom{newlp} is obtained from \\axiom{\\spad{lp}} by removing in every polynomial \\axiom{\\spad{p}} of \\axiom{\\spad{lp}} any occurence of a polynomial \\axiom{\\spad{f}} in \\axiom{\\spad{lf}}. This may involve a lot of exact-quotients computations.")) (|bivariatePolynomials| (((|Record| (|:| |goodPols| (|List| |#4|)) (|:| |badPols| (|List| |#4|))) (|List| |#4|)) "\\axiom{bivariatePolynomials(\\spad{lp})} returns \\axiom{\\spad{bps},{}nbps} where \\axiom{\\spad{bps}} is a list of the bivariate polynomials,{} and \\axiom{nbps} are the other ones.")) (|bivariate?| (((|Boolean|) |#4|) "\\axiom{bivariate?(\\spad{p})} returns \\spad{true} iff \\axiom{\\spad{p}} involves two and only two variables.")) (|linearPolynomials| (((|Record| (|:| |goodPols| (|List| |#4|)) (|:| |badPols| (|List| |#4|))) (|List| |#4|)) "\\axiom{linearPolynomials(\\spad{lp})} returns \\axiom{\\spad{lps},{}nlps} where \\axiom{\\spad{lps}} is a list of the linear polynomials in \\spad{lp},{} and \\axiom{nlps} are the other ones.")) (|linear?| (((|Boolean|) |#4|) "\\axiom{linear?(\\spad{p})} returns \\spad{true} iff \\axiom{\\spad{p}} does not lie in the base ring \\axiom{\\spad{R}} and has main degree \\axiom{1}.")) (|univariatePolynomials| (((|Record| (|:| |goodPols| (|List| |#4|)) (|:| |badPols| (|List| |#4|))) (|List| |#4|)) "\\axiom{univariatePolynomials(\\spad{lp})} returns \\axiom{ups,{}nups} where \\axiom{ups} is a list of the univariate polynomials,{} and \\axiom{nups} are the other ones.")) (|univariate?| (((|Boolean|) |#4|) "\\axiom{univariate?(\\spad{p})} returns \\spad{true} iff \\axiom{\\spad{p}} involves one and only one variable.")) (|quasiMonicPolynomials| (((|Record| (|:| |goodPols| (|List| |#4|)) (|:| |badPols| (|List| |#4|))) (|List| |#4|)) "\\axiom{quasiMonicPolynomials(\\spad{lp})} returns \\axiom{qmps,{}nqmps} where \\axiom{qmps} is a list of the quasi-monic polynomials in \\axiom{\\spad{lp}} and \\axiom{nqmps} are the other ones.")) (|selectAndPolynomials| (((|Record| (|:| |goodPols| (|List| |#4|)) (|:| |badPols| (|List| |#4|))) (|List| (|Mapping| (|Boolean|) |#4|)) (|List| |#4|)) "\\axiom{selectAndPolynomials(lpred?,{}\\spad{ps})} returns \\axiom{\\spad{gps},{}\\spad{bps}} where \\axiom{\\spad{gps}} is a list of the polynomial \\axiom{\\spad{p}} in \\axiom{\\spad{ps}} such that \\axiom{pred?(\\spad{p})} holds for every \\axiom{pred?} in \\axiom{lpred?} and \\axiom{\\spad{bps}} are the other ones.")) (|selectOrPolynomials| (((|Record| (|:| |goodPols| (|List| |#4|)) (|:| |badPols| (|List| |#4|))) (|List| (|Mapping| (|Boolean|) |#4|)) (|List| |#4|)) "\\axiom{selectOrPolynomials(lpred?,{}\\spad{ps})} returns \\axiom{\\spad{gps},{}\\spad{bps}} where \\axiom{\\spad{gps}} is a list of the polynomial \\axiom{\\spad{p}} in \\axiom{\\spad{ps}} such that \\axiom{pred?(\\spad{p})} holds for some \\axiom{pred?} in \\axiom{lpred?} and \\axiom{\\spad{bps}} are the other ones.")) (|selectPolynomials| (((|Record| (|:| |goodPols| (|List| |#4|)) (|:| |badPols| (|List| |#4|))) (|Mapping| (|Boolean|) |#4|) (|List| |#4|)) "\\axiom{selectPolynomials(pred?,{}\\spad{ps})} returns \\axiom{\\spad{gps},{}\\spad{bps}} where \\axiom{\\spad{gps}} is a list of the polynomial \\axiom{\\spad{p}} in \\axiom{\\spad{ps}} such that \\axiom{pred?(\\spad{p})} holds and \\axiom{\\spad{bps}} are the other ones.")) (|probablyZeroDim?| (((|Boolean|) (|List| |#4|)) "\\axiom{probablyZeroDim?(\\spad{lp})} returns \\spad{true} iff the number of polynomials in \\axiom{\\spad{lp}} is not smaller than the number of variables occurring in these polynomials.")) (|possiblyNewVariety?| (((|Boolean|) (|List| |#4|) (|List| (|List| |#4|))) "\\axiom{possiblyNewVariety?(newlp,{}\\spad{llp})} returns \\spad{true} iff for every \\axiom{\\spad{lp}} in \\axiom{\\spad{llp}} certainlySubVariety?(newlp,{}\\spad{lp}) does not hold.")) (|certainlySubVariety?| (((|Boolean|) (|List| |#4|) (|List| |#4|)) "\\axiom{certainlySubVariety?(newlp,{}\\spad{lp})} returns \\spad{true} iff for every \\axiom{\\spad{p}} in \\axiom{\\spad{lp}} the remainder of \\axiom{\\spad{p}} by \\axiom{newlp} using the division algorithm of Groebner techniques is zero.")) (|unprotectedRemoveRedundantFactors| (((|List| |#4|) |#4| |#4|) "\\axiom{unprotectedRemoveRedundantFactors(\\spad{p},{}\\spad{q})} returns the same as \\axiom{removeRedundantFactors(\\spad{p},{}\\spad{q})} but does assume that neither \\axiom{\\spad{p}} nor \\axiom{\\spad{q}} lie in the base ring \\axiom{\\spad{R}} and assumes that \\axiom{infRittWu?(\\spad{p},{}\\spad{q})} holds. Moreover,{} if \\axiom{\\spad{R}} is \\spad{gcd}-domain,{} then \\axiom{\\spad{p}} and \\axiom{\\spad{q}} are assumed to be square free.")) (|removeSquaresIfCan| (((|List| |#4|) (|List| |#4|)) "\\axiom{removeSquaresIfCan(\\spad{lp})} returns \\axiom{removeDuplicates [squareFreePart(\\spad{p})\\$\\spad{P} for \\spad{p} in \\spad{lp}]} if \\axiom{\\spad{R}} is \\spad{gcd}-domain else returns \\axiom{\\spad{lp}}.")) (|removeRedundantFactors| (((|List| |#4|) (|List| |#4|) (|List| |#4|) (|Mapping| (|List| |#4|) (|List| |#4|))) "\\axiom{removeRedundantFactors(\\spad{lp},{}\\spad{lq},{}remOp)} returns the same as \\axiom{concat(remOp(removeRoughlyRedundantFactorsInPols(\\spad{lp},{}\\spad{lq})),{}\\spad{lq})} assuming that \\axiom{remOp(\\spad{lq})} returns \\axiom{\\spad{lq}} up to similarity.") (((|List| |#4|) (|List| |#4|) (|List| |#4|)) "\\axiom{removeRedundantFactors(\\spad{lp},{}\\spad{lq})} returns the same as \\axiom{removeRedundantFactors(concat(\\spad{lp},{}\\spad{lq}))} assuming that \\axiom{removeRedundantFactors(\\spad{lp})} returns \\axiom{\\spad{lp}} up to replacing some polynomial \\axiom{\\spad{pj}} in \\axiom{\\spad{lp}} by some polynomial \\axiom{\\spad{qj}} associated to \\axiom{\\spad{pj}}.") (((|List| |#4|) (|List| |#4|) |#4|) "\\axiom{removeRedundantFactors(\\spad{lp},{}\\spad{q})} returns the same as \\axiom{removeRedundantFactors(cons(\\spad{q},{}\\spad{lp}))} assuming that \\axiom{removeRedundantFactors(\\spad{lp})} returns \\axiom{\\spad{lp}} up to replacing some polynomial \\axiom{\\spad{pj}} in \\axiom{\\spad{lp}} by some some polynomial \\axiom{\\spad{qj}} associated to \\axiom{\\spad{pj}}.") (((|List| |#4|) |#4| |#4|) "\\axiom{removeRedundantFactors(\\spad{p},{}\\spad{q})} returns the same as \\axiom{removeRedundantFactors([\\spad{p},{}\\spad{q}])}") (((|List| |#4|) (|List| |#4|)) "\\axiom{removeRedundantFactors(\\spad{lp})} returns \\axiom{\\spad{lq}} such that if \\axiom{\\spad{lp} = [\\spad{p1},{}...,{}\\spad{pn}]} and \\axiom{\\spad{lq} = [\\spad{q1},{}...,{}\\spad{qm}]} then the product \\axiom{p1*p2*...\\spad{*pn}} vanishes iff the product \\axiom{q1*q2*...\\spad{*qm}} vanishes,{} and the product of degrees of the \\axiom{\\spad{qi}} is not greater than the one of the \\axiom{\\spad{pj}},{} and no polynomial in \\axiom{\\spad{lq}} divides another polynomial in \\axiom{\\spad{lq}}. In particular,{} polynomials lying in the base ring \\axiom{\\spad{R}} are removed. Moreover,{} \\axiom{\\spad{lq}} is sorted \\spad{w}.\\spad{r}.\\spad{t} \\axiom{infRittWu?}. Furthermore,{} if \\spad{R} is \\spad{gcd}-domain,{} the polynomials in \\axiom{\\spad{lq}} are pairwise without common non trivial factor."))) 
@@ -3854,7 +3854,7 @@ NIL
 NIL 
 (-981 R) 
 ((|constructor| (NIL "PointCategory is the category of points in space which may be plotted via the graphics facilities. Functions are provided for defining points and handling elements of points.")) (|extend| (($ $ (|List| |#1|)) "\\spad{extend(x,{}l,{}r)} \\undocumented")) (|cross| (($ $ $) "\\spad{cross(p,{}q)} computes the cross product of the two points \\spad{p} and \\spad{q}. Error if the \\spad{p} and \\spad{q} are not 3 dimensional")) (|convert| (($ (|List| |#1|)) "\\spad{convert(l)} takes a list of elements,{} \\spad{l},{} from the domain Ring and returns the form of point category.")) (|dimension| (((|PositiveInteger|) $) "\\spad{dimension(s)} returns the dimension of the point category \\spad{s}.")) (|point| (($ (|List| |#1|)) "\\spad{point(l)} returns a point category defined by a list \\spad{l} of elements from the domain \\spad{R}."))) 
-((-4520 . T) (-4519 . T) (-3973 . T)) 
+((-4522 . T) (-4521 . T) (-3973 . T)) 
 NIL 
 (-982 R1 R2) 
 ((|constructor| (NIL "This package has no description")) (|map| (((|Point| |#2|) (|Mapping| |#2| |#1|) (|Point| |#1|)) "\\spad{map(f,{}p)} \\undocumented"))) 
@@ -3902,7 +3902,7 @@ NIL
 ((|HasCategory| |#2| (QUOTE (-904))) (|HasCategory| |#2| (QUOTE (-550))) (|HasCategory| |#2| (QUOTE (-301))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (QUOTE (-1021))) (|HasCategory| |#2| (QUOTE (-815))) (|HasCategory| |#2| (QUOTE (-842))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-1136)))) 
 (-993 S) 
 ((|constructor| (NIL "QuotientField(\\spad{S}) is the category of fractions of an Integral Domain \\spad{S}.")) (|floor| ((|#1| $) "\\spad{floor(x)} returns the largest integral element below \\spad{x}.")) (|ceiling| ((|#1| $) "\\spad{ceiling(x)} returns the smallest integral element above \\spad{x}.")) (|random| (($) "\\spad{random()} returns a random fraction.")) (|fractionPart| (($ $) "\\spad{fractionPart(x)} returns the fractional part of \\spad{x}. \\spad{x} = wholePart(\\spad{x}) + fractionPart(\\spad{x})")) (|wholePart| ((|#1| $) "\\spad{wholePart(x)} returns the whole part of the fraction \\spad{x} \\spadignore{i.e.} the truncated quotient of the numerator by the denominator.")) (|denominator| (($ $) "\\spad{denominator(x)} is the denominator of the fraction \\spad{x} converted to \\%.")) (|numerator| (($ $) "\\spad{numerator(x)} is the numerator of the fraction \\spad{x} converted to \\%.")) (|denom| ((|#1| $) "\\spad{denom(x)} returns the denominator of the fraction \\spad{x}.")) (|numer| ((|#1| $) "\\spad{numer(x)} returns the numerator of the fraction \\spad{x}.")) (/ (($ |#1| |#1|) "\\spad{d1 / d2} returns the fraction \\spad{d1} divided by \\spad{d2}."))) 
-((-3973 . T) (-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-3973 . T) (-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-994 |n| K) 
 ((|constructor| (NIL "This domain provides modest support for quadratic forms.")) (|elt| ((|#2| $ (|DirectProduct| |#1| |#2|)) "\\spad{elt(qf,{}v)} evaluates the quadratic form \\spad{qf} on the vector \\spad{v},{} producing a scalar.")) (|matrix| (((|SquareMatrix| |#1| |#2|) $) "\\spad{matrix(qf)} creates a square matrix from the quadratic form \\spad{qf}.")) (|quadraticForm| (($ (|SquareMatrix| |#1| |#2|)) "\\spad{quadraticForm(m)} creates a quadratic form from a symmetric,{} square matrix \\spad{m}."))) 
@@ -3910,7 +3910,7 @@ NIL
 NIL 
 (-995 S) 
 ((|constructor| (NIL "A queue is a bag where the first item inserted is the first item extracted.")) (|back| ((|#1| $) "\\spad{back(q)} returns the element at the back of the queue. The queue \\spad{q} is unchanged by this operation. Error: if \\spad{q} is empty.")) (|front| ((|#1| $) "\\spad{front(q)} returns the element at the front of the queue. The queue \\spad{q} is unchanged by this operation. Error: if \\spad{q} is empty.")) (|length| (((|NonNegativeInteger|) $) "\\spad{length(q)} returns the number of elements in the queue. Note that \\axiom{length(\\spad{q}) = \\spad{#q}}.")) (|rotate!| (($ $) "\\spad{rotate! q} rotates queue \\spad{q} so that the element at the front of the queue goes to the back of the queue. Note that rotate! \\spad{q} is equivalent to enqueue!(dequeue!(\\spad{q})).")) (|dequeue!| ((|#1| $) "\\spad{dequeue! s} destructively extracts the first (top) element from queue \\spad{q}. The element previously second in the queue becomes the first element. Error: if \\spad{q} is empty.")) (|enqueue!| ((|#1| |#1| $) "\\spad{enqueue!(x,{}q)} inserts \\spad{x} into the queue \\spad{q} at the back end."))) 
-((-4519 . T) (-4520 . T) (-3973 . T)) 
+((-4521 . T) (-4522 . T) (-3973 . T)) 
 NIL 
 (-996 S R) 
 ((|constructor| (NIL "\\spadtype{QuaternionCategory} describes the category of quaternions and implements functions that are not representation specific.")) (|rationalIfCan| (((|Union| (|Fraction| (|Integer|)) "failed") $) "\\spad{rationalIfCan(q)} returns \\spad{q} as a rational number,{} or \"failed\" if this is not possible. Note that if \\spad{rational?(q)} is \\spad{true},{} the conversion can be done and the rational number will be returned.")) (|rational| (((|Fraction| (|Integer|)) $) "\\spad{rational(q)} tries to convert \\spad{q} into a rational number. Error: if this is not possible. If \\spad{rational?(q)} is \\spad{true},{} the conversion will be done and the rational number returned.")) (|rational?| (((|Boolean|) $) "\\spad{rational?(q)} returns {\\it \\spad{true}} if all the imaginary parts of \\spad{q} are zero and the real part can be converted into a rational number,{} and {\\it \\spad{false}} otherwise.")) (|abs| ((|#2| $) "\\spad{abs(q)} computes the absolute value of quaternion \\spad{q} (sqrt of norm).")) (|real| ((|#2| $) "\\spad{real(q)} extracts the real part of quaternion \\spad{q}.")) (|quatern| (($ |#2| |#2| |#2| |#2|) "\\spad{quatern(r,{}i,{}j,{}k)} constructs a quaternion from scalars.")) (|norm| ((|#2| $) "\\spad{norm(q)} computes the norm of \\spad{q} (the sum of the squares of the components).")) (|imagK| ((|#2| $) "\\spad{imagK(q)} extracts the imaginary \\spad{k} part of quaternion \\spad{q}.")) (|imagJ| ((|#2| $) "\\spad{imagJ(q)} extracts the imaginary \\spad{j} part of quaternion \\spad{q}.")) (|imagI| ((|#2| $) "\\spad{imagI(q)} extracts the imaginary \\spad{i} part of quaternion \\spad{q}.")) (|conjugate| (($ $) "\\spad{conjugate(q)} negates the imaginary parts of quaternion \\spad{q}."))) 
@@ -3918,7 +3918,7 @@ NIL
 ((|HasCategory| |#2| (QUOTE (-550))) (|HasCategory| |#2| (QUOTE (-1056))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-285)))) 
 (-997 R) 
 ((|constructor| (NIL "\\spadtype{QuaternionCategory} describes the category of quaternions and implements functions that are not representation specific.")) (|rationalIfCan| (((|Union| (|Fraction| (|Integer|)) "failed") $) "\\spad{rationalIfCan(q)} returns \\spad{q} as a rational number,{} or \"failed\" if this is not possible. Note that if \\spad{rational?(q)} is \\spad{true},{} the conversion can be done and the rational number will be returned.")) (|rational| (((|Fraction| (|Integer|)) $) "\\spad{rational(q)} tries to convert \\spad{q} into a rational number. Error: if this is not possible. If \\spad{rational?(q)} is \\spad{true},{} the conversion will be done and the rational number returned.")) (|rational?| (((|Boolean|) $) "\\spad{rational?(q)} returns {\\it \\spad{true}} if all the imaginary parts of \\spad{q} are zero and the real part can be converted into a rational number,{} and {\\it \\spad{false}} otherwise.")) (|abs| ((|#1| $) "\\spad{abs(q)} computes the absolute value of quaternion \\spad{q} (sqrt of norm).")) (|real| ((|#1| $) "\\spad{real(q)} extracts the real part of quaternion \\spad{q}.")) (|quatern| (($ |#1| |#1| |#1| |#1|) "\\spad{quatern(r,{}i,{}j,{}k)} constructs a quaternion from scalars.")) (|norm| ((|#1| $) "\\spad{norm(q)} computes the norm of \\spad{q} (the sum of the squares of the components).")) (|imagK| ((|#1| $) "\\spad{imagK(q)} extracts the imaginary \\spad{k} part of quaternion \\spad{q}.")) (|imagJ| ((|#1| $) "\\spad{imagJ(q)} extracts the imaginary \\spad{j} part of quaternion \\spad{q}.")) (|imagI| ((|#1| $) "\\spad{imagI(q)} extracts the imaginary \\spad{i} part of quaternion \\spad{q}.")) (|conjugate| (($ $) "\\spad{conjugate(q)} negates the imaginary parts of quaternion \\spad{q}."))) 
-((-4512 |has| |#1| (-285)) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4514 |has| |#1| (-285)) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-998 QR R QS S) 
 ((|constructor| (NIL "\\spadtype{QuaternionCategoryFunctions2} implements functions between two quaternion domains. The function \\spadfun{map} is used by the system interpreter to coerce between quaternion types.")) (|map| ((|#3| (|Mapping| |#4| |#2|) |#1|) "\\indented{1}{map(\\spad{f},{}\\spad{u}) maps \\spad{f} onto the component parts of the quaternion \\spad{u}.} \\indented{1}{to convert an expression in Quaterion(\\spad{R}) to Quaternion(\\spad{S})} \\blankline \\spad{X} \\spad{f}(a:FRAC(INT)):COMPLEX(FRAC(INT)) \\spad{==} a::COMPLEX(FRAC(INT)) \\spad{X} q:=quatern(2/11,{}\\spad{-8},{}3/4,{}1) \\spad{X} map(\\spad{f},{}\\spad{q})"))) 
@@ -3926,11 +3926,11 @@ NIL
 NIL 
 (-999 R) 
 ((|constructor| (NIL "\\spadtype{Quaternion} implements quaternions over a commutative ring. The main constructor function is \\spadfun{quatern} which takes 4 arguments: the real part,{} the \\spad{i} imaginary part,{} the \\spad{j} imaginary part and the \\spad{k} imaginary part."))) 
-((-4512 |has| |#1| (-285)) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-285))) (-2198 (|HasCategory| |#1| (QUOTE (-285))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -523) (QUOTE (-1161)) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -281) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-225))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-1056))) (|HasCategory| |#1| (QUOTE (-550))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365))))) 
+((-4514 |has| |#1| (-285)) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-285))) (-2199 (|HasCategory| |#1| (QUOTE (-285))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -523) (QUOTE (-1161)) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (LIST (QUOTE -281) (|devaluate| |#1|) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-225))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-1056))) (|HasCategory| |#1| (QUOTE (-550))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365))))) 
 (-1000 S) 
 ((|constructor| (NIL "Linked List implementation of a Queue")) (|member?| (((|Boolean|) |#1| $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} member?(3,{}a)")) (|members| (((|List| |#1|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} members a")) (|parts| (((|List| |#1|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} parts a")) (|#| (((|NonNegativeInteger|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} \\#a")) (|count| (((|NonNegativeInteger|) |#1| $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} count(4,{}a)") (((|NonNegativeInteger|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} count(\\spad{x+}->(\\spad{x>2}),{}a)")) (|any?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} any?(\\spad{x+}->(\\spad{x=4}),{}a)")) (|every?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} every?(\\spad{x+}->(\\spad{x=4}),{}a)")) (~= (((|Boolean|) $ $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} b:=copy a \\spad{X} (a~=b)")) (= (((|Boolean|) $ $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} b:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} (a=b)@Boolean")) (|coerce| (((|OutputForm|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} coerce a")) (|hash| (((|SingleInteger|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} hash a")) (|latex| (((|String|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} latex a")) (|map!| (($ (|Mapping| |#1| |#1|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} map!(\\spad{x+}-\\spad{>x+10},{}a) \\spad{X} a")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} map(\\spad{x+}-\\spad{>x+10},{}a) \\spad{X} a")) (|eq?| (((|Boolean|) $ $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} b:=copy a \\spad{X} eq?(a,{}\\spad{b})")) (|copy| (($ $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} copy a")) (|sample| (($) "\\blankline \\spad{X} sample()\\$Queue(INT)")) (|empty| (($) "\\blankline \\spad{X} b:=empty()\\$(Queue INT)")) (|empty?| (((|Boolean|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} empty? a")) (|bag| (($ (|List| |#1|)) "\\blankline \\spad{X} bag([1,{}2,{}3,{}4,{}5])\\$Queue(INT)")) (|size?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} size?(a,{}5)")) (|more?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} more?(a,{}9)")) (|less?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} less?(a,{}9)")) (|length| (((|NonNegativeInteger|) $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} length a")) (|rotate!| (($ $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} rotate! a")) (|back| ((|#1| $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} back a")) (|front| ((|#1| $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} front a")) (|inspect| ((|#1| $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} inspect a")) (|insert!| (($ |#1| $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} insert! (8,{}a) \\spad{X} a")) (|enqueue!| ((|#1| |#1| $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} enqueue! (9,{}a) \\spad{X} a")) (|extract!| ((|#1| $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} extract! a \\spad{X} a")) (|dequeue!| ((|#1| $) "\\blankline \\spad{X} a:Queue INT:= queue [1,{}2,{}3,{}4,{}5] \\spad{X} dequeue! a \\spad{X} a")) (|queue| (($ (|List| |#1|)) "\\indented{1}{queue([\\spad{x},{}\\spad{y},{}...,{}\\spad{z}]) creates a queue with first (top)} \\indented{1}{element \\spad{x},{} second element \\spad{y},{}...,{}and last (bottom) element \\spad{z}.} \\blankline \\spad{E} e:Queue INT:= queue [1,{}2,{}3,{}4,{}5]"))) 
-((-4519 . T) (-4520 . T)) 
+((-4521 . T) (-4522 . T)) 
 ((|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090))))) 
 (-1001 S) 
 ((|constructor| (NIL "The \\spad{RadicalCategory} is a model for the rational numbers.")) (** (($ $ (|Fraction| (|Integer|))) "\\spad{x ** y} is the rational exponentiation of \\spad{x} by the power \\spad{y}.")) (|nthRoot| (($ $ (|Integer|)) "\\spad{nthRoot(x,{}n)} returns the \\spad{n}th root of \\spad{x}.")) (|sqrt| (($ $) "\\spad{sqrt(x)} returns the square root of \\spad{x}."))) 
@@ -3942,12 +3942,12 @@ NIL
 NIL 
 (-1003 -1478 UP UPUP |radicnd| |n|) 
 ((|constructor| (NIL "Function field defined by y**n = \\spad{f}(\\spad{x})."))) 
-((-4512 |has| (-409 |#2|) (-365)) (-4517 |has| (-409 |#2|) (-365)) (-4511 |has| (-409 |#2|) (-365)) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| (-409 |#2|) (QUOTE (-148))) (|HasCategory| (-409 |#2|) (QUOTE (-150))) (|HasCategory| (-409 |#2|) (QUOTE (-350))) (|HasCategory| (-409 |#2|) (QUOTE (-365))) (-2198 (|HasCategory| (-409 |#2|) (QUOTE (-365))) (|HasCategory| (-409 |#2|) (QUOTE (-350)))) (|HasCategory| (-409 |#2|) (QUOTE (-370))) (|HasCategory| (-409 |#2|) (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| (-409 |#2|) (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| (-409 |#2|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-370))) (-2198 (|HasCategory| (-409 |#2|) (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| (-409 |#2|) (QUOTE (-365)))) (-12 (|HasCategory| (-409 |#2|) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-409 |#2|) (QUOTE (-365)))) (-2198 (-12 (|HasCategory| (-409 |#2|) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-409 |#2|) (QUOTE (-365)))) (-12 (|HasCategory| (-409 |#2|) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-409 |#2|) (QUOTE (-350))))) (-12 (|HasCategory| (-409 |#2|) (QUOTE (-225))) (|HasCategory| (-409 |#2|) (QUOTE (-365)))) (-2198 (-12 (|HasCategory| (-409 |#2|) (QUOTE (-225))) (|HasCategory| (-409 |#2|) (QUOTE (-365)))) (|HasCategory| (-409 |#2|) (QUOTE (-350))))) 
+((-4514 |has| (-409 |#2|) (-365)) (-4519 |has| (-409 |#2|) (-365)) (-4513 |has| (-409 |#2|) (-365)) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| (-409 |#2|) (QUOTE (-148))) (|HasCategory| (-409 |#2|) (QUOTE (-150))) (|HasCategory| (-409 |#2|) (QUOTE (-350))) (|HasCategory| (-409 |#2|) (QUOTE (-365))) (-2199 (|HasCategory| (-409 |#2|) (QUOTE (-365))) (|HasCategory| (-409 |#2|) (QUOTE (-350)))) (|HasCategory| (-409 |#2|) (QUOTE (-370))) (|HasCategory| (-409 |#2|) (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| (-409 |#2|) (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| (-409 |#2|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-370))) (-2199 (|HasCategory| (-409 |#2|) (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| (-409 |#2|) (QUOTE (-365)))) (-12 (|HasCategory| (-409 |#2|) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-409 |#2|) (QUOTE (-365)))) (-2199 (-12 (|HasCategory| (-409 |#2|) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-409 |#2|) (QUOTE (-365)))) (-12 (|HasCategory| (-409 |#2|) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-409 |#2|) (QUOTE (-350))))) (-12 (|HasCategory| (-409 |#2|) (QUOTE (-225))) (|HasCategory| (-409 |#2|) (QUOTE (-365)))) (-2199 (-12 (|HasCategory| (-409 |#2|) (QUOTE (-225))) (|HasCategory| (-409 |#2|) (QUOTE (-365)))) (|HasCategory| (-409 |#2|) (QUOTE (-350))))) 
 (-1004 |bb|) 
 ((|constructor| (NIL "This domain allows rational numbers to be presented as repeating decimal expansions or more generally as repeating expansions in any base.")) (|fractRadix| (($ (|List| (|Integer|)) (|List| (|Integer|))) "\\spad{fractRadix(pre,{}cyc)} creates a fractional radix expansion from a list of prefix ragits and a list of cyclic ragits. \\spadignore{e.g.} \\spad{fractRadix([1],{}[6])} will return \\spad{0.16666666...}.")) (|wholeRadix| (($ (|List| (|Integer|))) "\\spad{wholeRadix(l)} creates an integral radix expansion from a list of ragits. For example,{} \\spad{wholeRadix([1,{}3,{}4])} will return \\spad{134}.")) (|cycleRagits| (((|List| (|Integer|)) $) "\\spad{cycleRagits(rx)} returns the cyclic part of the ragits of the fractional part of a radix expansion. For example,{} if \\spad{x = 3/28 = 0.10 714285 714285 ...},{} then \\spad{cycleRagits(x) = [7,{}1,{}4,{}2,{}8,{}5]}.")) (|prefixRagits| (((|List| (|Integer|)) $) "\\spad{prefixRagits(rx)} returns the non-cyclic part of the ragits of the fractional part of a radix expansion. For example,{} if \\spad{x = 3/28 = 0.10 714285 714285 ...},{} then \\spad{prefixRagits(x)=[1,{}0]}.")) (|fractRagits| (((|Stream| (|Integer|)) $) "\\spad{fractRagits(rx)} returns the ragits of the fractional part of a radix expansion.")) (|wholeRagits| (((|List| (|Integer|)) $) "\\spad{wholeRagits(rx)} returns the ragits of the integer part of a radix expansion.")) (|fractionPart| (((|Fraction| (|Integer|)) $) "\\spad{fractionPart(rx)} returns the fractional part of a radix expansion.")) (|coerce| (((|Fraction| (|Integer|)) $) "\\spad{coerce(rx)} converts a radix expansion to a rational number."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| (-568) (QUOTE (-904))) (|HasCategory| (-568) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| (-568) (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-150))) (|HasCategory| (-568) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-568) (QUOTE (-1021))) (|HasCategory| (-568) (QUOTE (-815))) (|HasCategory| (-568) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| (-568) (QUOTE (-1136))) (|HasCategory| (-568) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| (-568) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| (-568) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| (-568) (QUOTE (-225))) (|HasCategory| (-568) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-568) (LIST (QUOTE -523) (QUOTE (-1161)) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -303) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -281) (QUOTE (-568)) (QUOTE (-568)))) (|HasCategory| (-568) (QUOTE (-301))) (|HasCategory| (-568) (QUOTE (-550))) (|HasCategory| (-568) (QUOTE (-842))) (-2198 (|HasCategory| (-568) (QUOTE (-815))) (|HasCategory| (-568) (QUOTE (-842)))) (|HasCategory| (-568) (LIST (QUOTE -630) (QUOTE (-568)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-904)))) (|HasCategory| (-568) (QUOTE (-148))))) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| (-568) (QUOTE (-904))) (|HasCategory| (-568) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| (-568) (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-150))) (|HasCategory| (-568) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-568) (QUOTE (-1021))) (|HasCategory| (-568) (QUOTE (-815))) (|HasCategory| (-568) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| (-568) (QUOTE (-1136))) (|HasCategory| (-568) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| (-568) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| (-568) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| (-568) (QUOTE (-225))) (|HasCategory| (-568) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| (-568) (LIST (QUOTE -523) (QUOTE (-1161)) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -303) (QUOTE (-568)))) (|HasCategory| (-568) (LIST (QUOTE -281) (QUOTE (-568)) (QUOTE (-568)))) (|HasCategory| (-568) (QUOTE (-301))) (|HasCategory| (-568) (QUOTE (-550))) (|HasCategory| (-568) (QUOTE (-842))) (-2199 (|HasCategory| (-568) (QUOTE (-815))) (|HasCategory| (-568) (QUOTE (-842)))) (|HasCategory| (-568) (LIST (QUOTE -630) (QUOTE (-568)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-568) (QUOTE (-904)))) (|HasCategory| (-568) (QUOTE (-148))))) 
 (-1005) 
 ((|constructor| (NIL "This package provides tools for creating radix expansions.")) (|radix| (((|Any|) (|Fraction| (|Integer|)) (|Integer|)) "\\spad{radix(x,{}b)} converts \\spad{x} to a radix expansion in base \\spad{b}."))) 
 NIL 
@@ -3967,7 +3967,7 @@ NIL
 (-1009 A S) 
 ((|constructor| (NIL "A recursive aggregate over a type \\spad{S} is a model for a a directed graph containing values of type \\spad{S}. Recursively,{} a recursive aggregate is a node consisting of a \\spadfun{value} from \\spad{S} and 0 or more \\spadfun{children} which are recursive aggregates. A node with no children is called a \\spadfun{leaf} node. A recursive aggregate may be cyclic for which some operations as noted may go into an infinite loop.")) (|setvalue!| ((|#2| $ |#2|) "\\spad{setvalue!(u,{}x)} sets the value of node \\spad{u} to \\spad{x}.")) (|setelt| ((|#2| $ "value" |#2|) "\\spad{setelt(a,{}\"value\",{}x)} (also written \\axiom{a . value \\spad{:=} \\spad{x}}) is equivalent to \\axiom{setvalue!(a,{}\\spad{x})}")) (|setchildren!| (($ $ (|List| $)) "\\spad{setchildren!(u,{}v)} replaces the current children of node \\spad{u} with the members of \\spad{v} in left-to-right order.")) (|node?| (((|Boolean|) $ $) "\\spad{node?(u,{}v)} tests if node \\spad{u} is contained in node \\spad{v} (either as a child,{} a child of a child,{} etc.).")) (|child?| (((|Boolean|) $ $) "\\spad{child?(u,{}v)} tests if node \\spad{u} is a child of node \\spad{v}.")) (|distance| (((|Integer|) $ $) "\\spad{distance(u,{}v)} returns the path length (an integer) from node \\spad{u} to \\spad{v}.")) (|leaves| (((|List| |#2|) $) "\\spad{leaves(t)} returns the list of values in obtained by visiting the nodes of tree \\axiom{\\spad{t}} in left-to-right order.")) (|cyclic?| (((|Boolean|) $) "\\spad{cyclic?(u)} tests if \\spad{u} has a cycle.")) (|elt| ((|#2| $ "value") "\\spad{elt(u,{}\"value\")} (also written: \\axiom{a. value}) is equivalent to \\axiom{value(a)}.")) (|value| ((|#2| $) "\\spad{value(u)} returns the value of the node \\spad{u}.")) (|leaf?| (((|Boolean|) $) "\\spad{leaf?(u)} tests if \\spad{u} is a terminal node.")) (|nodes| (((|List| $) $) "\\spad{nodes(u)} returns a list of all of the nodes of aggregate \\spad{u}.")) (|children| (((|List| $) $) "\\spad{children(u)} returns a list of the children of aggregate \\spad{u}."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE -4520)) (|HasCategory| |#2| (QUOTE (-1090)))) 
+((|HasAttribute| |#1| (QUOTE -4522)) (|HasCategory| |#2| (QUOTE (-1090)))) 
 (-1010 S) 
 ((|constructor| (NIL "A recursive aggregate over a type \\spad{S} is a model for a a directed graph containing values of type \\spad{S}. Recursively,{} a recursive aggregate is a node consisting of a \\spadfun{value} from \\spad{S} and 0 or more \\spadfun{children} which are recursive aggregates. A node with no children is called a \\spadfun{leaf} node. A recursive aggregate may be cyclic for which some operations as noted may go into an infinite loop.")) (|setvalue!| ((|#1| $ |#1|) "\\spad{setvalue!(u,{}x)} sets the value of node \\spad{u} to \\spad{x}.")) (|setelt| ((|#1| $ "value" |#1|) "\\spad{setelt(a,{}\"value\",{}x)} (also written \\axiom{a . value \\spad{:=} \\spad{x}}) is equivalent to \\axiom{setvalue!(a,{}\\spad{x})}")) (|setchildren!| (($ $ (|List| $)) "\\spad{setchildren!(u,{}v)} replaces the current children of node \\spad{u} with the members of \\spad{v} in left-to-right order.")) (|node?| (((|Boolean|) $ $) "\\spad{node?(u,{}v)} tests if node \\spad{u} is contained in node \\spad{v} (either as a child,{} a child of a child,{} etc.).")) (|child?| (((|Boolean|) $ $) "\\spad{child?(u,{}v)} tests if node \\spad{u} is a child of node \\spad{v}.")) (|distance| (((|Integer|) $ $) "\\spad{distance(u,{}v)} returns the path length (an integer) from node \\spad{u} to \\spad{v}.")) (|leaves| (((|List| |#1|) $) "\\spad{leaves(t)} returns the list of values in obtained by visiting the nodes of tree \\axiom{\\spad{t}} in left-to-right order.")) (|cyclic?| (((|Boolean|) $) "\\spad{cyclic?(u)} tests if \\spad{u} has a cycle.")) (|elt| ((|#1| $ "value") "\\spad{elt(u,{}\"value\")} (also written: \\axiom{a. value}) is equivalent to \\axiom{value(a)}.")) (|value| ((|#1| $) "\\spad{value(u)} returns the value of the node \\spad{u}.")) (|leaf?| (((|Boolean|) $) "\\spad{leaf?(u)} tests if \\spad{u} is a terminal node.")) (|nodes| (((|List| $) $) "\\spad{nodes(u)} returns a list of all of the nodes of aggregate \\spad{u}.")) (|children| (((|List| $) $) "\\spad{children(u)} returns a list of the children of aggregate \\spad{u}."))) 
 ((-3973 . T)) 
@@ -3978,7 +3978,7 @@ NIL
 NIL 
 (-1012) 
 ((|constructor| (NIL "\\axiomType{RealClosedField} provides common acces functions for all real closed fields.")) (|approximate| (((|Fraction| (|Integer|)) $ $) "\\axiom{approximate(\\spad{n},{}\\spad{p})} gives an approximation of \\axiom{\\spad{n}} that has precision \\axiom{\\spad{p}}")) (|rename| (($ $ (|OutputForm|)) "\\axiom{rename(\\spad{x},{}name)} gives a new number that prints as name")) (|rename!| (($ $ (|OutputForm|)) "\\axiom{rename!(\\spad{x},{}name)} changes the way \\axiom{\\spad{x}} is printed")) (|sqrt| (($ (|Integer|)) "\\axiom{sqrt(\\spad{x})} is \\axiom{\\spad{x} \\spad{**} (1/2)}") (($ (|Fraction| (|Integer|))) "\\axiom{sqrt(\\spad{x})} is \\axiom{\\spad{x} \\spad{**} (1/2)}") (($ $) "\\axiom{sqrt(\\spad{x})} is \\axiom{\\spad{x} \\spad{**} (1/2)}") (($ $ (|NonNegativeInteger|)) "\\axiom{sqrt(\\spad{x},{}\\spad{n})} is \\axiom{\\spad{x} \\spad{**} (1/n)}")) (|allRootsOf| (((|List| $) (|Polynomial| (|Integer|))) "\\axiom{allRootsOf(pol)} creates all the roots of \\axiom{pol} naming each uniquely") (((|List| $) (|Polynomial| (|Fraction| (|Integer|)))) "\\axiom{allRootsOf(pol)} creates all the roots of \\axiom{pol} naming each uniquely") (((|List| $) (|Polynomial| $)) "\\axiom{allRootsOf(pol)} creates all the roots of \\axiom{pol} naming each uniquely") (((|List| $) (|SparseUnivariatePolynomial| (|Integer|))) "\\axiom{allRootsOf(pol)} creates all the roots of \\axiom{pol} naming each uniquely") (((|List| $) (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))) "\\axiom{allRootsOf(pol)} creates all the roots of \\axiom{pol} naming each uniquely") (((|List| $) (|SparseUnivariatePolynomial| $)) "\\axiom{allRootsOf(pol)} creates all the roots of \\axiom{pol} naming each uniquely")) (|rootOf| (((|Union| $ "failed") (|SparseUnivariatePolynomial| $) (|PositiveInteger|)) "\\axiom{rootOf(pol,{}\\spad{n})} creates the \\spad{n}th root for the order of \\axiom{pol} and gives it unique name") (((|Union| $ "failed") (|SparseUnivariatePolynomial| $) (|PositiveInteger|) (|OutputForm|)) "\\axiom{rootOf(pol,{}\\spad{n},{}name)} creates the \\spad{n}th root for the order of \\axiom{pol} and names it \\axiom{name}")) (|mainValue| (((|Union| (|SparseUnivariatePolynomial| $) "failed") $) "\\axiom{mainValue(\\spad{x})} is the expression of \\axiom{\\spad{x}} in terms of \\axiom{SparseUnivariatePolynomial(\\$)}")) (|mainDefiningPolynomial| (((|Union| (|SparseUnivariatePolynomial| $) "failed") $) "\\axiom{mainDefiningPolynomial(\\spad{x})} is the defining polynomial for the main algebraic quantity of \\axiom{\\spad{x}}")) (|mainForm| (((|Union| (|OutputForm|) "failed") $) "\\axiom{mainForm(\\spad{x})} is the main algebraic quantity name of \\axiom{\\spad{x}}"))) 
-((-4512 . T) (-4517 . T) (-4511 . T) (-4514 . T) (-4513 . T) ((-4521 "*") . T) (-4516 . T)) 
+((-4514 . T) (-4519 . T) (-4513 . T) (-4516 . T) (-4515 . T) ((-4523 "*") . T) (-4518 . T)) 
 NIL 
 (-1013 R -1478) 
 ((|constructor| (NIL "Risch differential equation,{} elementary case.")) (|rischDE| (((|Record| (|:| |ans| |#2|) (|:| |right| |#2|) (|:| |sol?| (|Boolean|))) (|Integer|) |#2| |#2| (|Symbol|) (|Mapping| (|Union| (|Record| (|:| |mainpart| |#2|) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (|List| |#2|)) (|Mapping| (|Union| (|Record| (|:| |ratpart| |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)) "\\spad{rischDE(n,{} f,{} g,{} x,{} lim,{} ext)} returns \\spad{[y,{} h,{} b]} such that \\spad{dy/dx + n df/dx y = h} and \\spad{b := h = g}. The equation \\spad{dy/dx + n df/dx y = g} has no solution if \\spad{h \\~~= g} (\\spad{y} is a partial solution in that case). Notes: \\spad{lim} is a limited integration function,{} and ext is an extended integration function."))) 
@@ -4022,8 +4022,8 @@ NIL
 NIL 
 (-1023 |TheField|) 
 ((|constructor| (NIL "This domain implements the real closure of an ordered field.")) (|relativeApprox| (((|Fraction| (|Integer|)) $ $) "\\axiom{relativeApprox(\\spad{n},{}\\spad{p})} gives a relative approximation of \\axiom{\\spad{n}} that has precision \\axiom{\\spad{p}}")) (|mainCharacterization| (((|Union| (|RightOpenIntervalRootCharacterization| $ (|SparseUnivariatePolynomial| $)) "failed") $) "\\axiom{mainCharacterization(\\spad{x})} is the main algebraic quantity of \\axiom{\\spad{x}} (\\axiom{SEG})")) (|algebraicOf| (($ (|RightOpenIntervalRootCharacterization| $ (|SparseUnivariatePolynomial| $)) (|OutputForm|)) "\\axiom{algebraicOf(char)} is the external number"))) 
-((-4512 . T) (-4517 . T) (-4511 . T) (-4514 . T) (-4513 . T) ((-4521 "*") . T) (-4516 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| (-409 (-568)) (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| (-409 (-568)) (LIST (QUOTE -1037) (QUOTE (-568)))) (-2198 (|HasCategory| (-409 (-568)) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))))) 
+((-4514 . T) (-4519 . T) (-4513 . T) (-4516 . T) (-4515 . T) ((-4523 "*") . T) (-4518 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| (-409 (-568)) (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| (-409 (-568)) (LIST (QUOTE -1037) (QUOTE (-568)))) (-2199 (|HasCategory| (-409 (-568)) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))))) 
 (-1024 R -1478) 
 ((|constructor| (NIL "This package provides an operator for the \\spad{n}-th term of a recurrence and an operator for the coefficient of \\spad{x^n} in a function specified by a functional equation.")) (|getOp| (((|BasicOperator|) |#2|) "\\spad{getOp f},{} if \\spad{f} represents the coefficient of a recurrence or ADE,{} returns the operator representing the solution")) (|getEq| ((|#2| |#2|) "\\spad{getEq f} returns the defining equation,{} if \\spad{f} represents the coefficient of an ADE or a recurrence.")) (|evalADE| ((|#2| (|BasicOperator|) (|Symbol|) |#2| |#2| |#2| (|List| |#2|)) "\\spad{evalADE(f,{} dummy,{} x,{} n,{} eq,{} values)} creates an expression that stands for the coefficient of \\spad{x^n} in the Taylor expansion of \\spad{f}(\\spad{x}),{} where \\spad{f}(\\spad{x}) is given by the functional equation \\spad{eq}. However,{} for technical reasons the variable \\spad{x} has to be replaced by a \\spad{dummy} variable \\spad{dummy} in \\spad{eq}. The argument values specifies the first few Taylor coefficients.")) (|evalRec| ((|#2| (|BasicOperator|) (|Symbol|) |#2| |#2| |#2| (|List| |#2|)) "\\spad{evalRec(u,{} dummy,{} n,{} n0,{} eq,{} values)} creates an expression that stands for \\spad{u}(\\spad{n0}),{} where \\spad{u}(\\spad{n}) is given by the equation \\spad{eq}. However,{} for technical reasons the variable \\spad{n} has to be replaced by a \\spad{dummy} variable \\spad{dummy} in \\spad{eq}. The argument values specifies the initial values of the recurrence \\spad{u}(0),{} \\spad{u}(1),{}... For the moment we don\\spad{'t} allow recursions that contain \\spad{u} inside of another operator."))) 
 NIL 
@@ -4038,12 +4038,12 @@ NIL
 ((|HasCategory| |#1| (QUOTE (-1090)))) 
 (-1027 R E V P) 
 ((|constructor| (NIL "This domain provides an implementation of regular chains. Moreover,{} the operation zeroSetSplit is an implementation of a new algorithm for solving polynomial systems by means of regular chains.")) (|preprocess| (((|Record| (|:| |val| (|List| |#4|)) (|:| |towers| (|List| $))) (|List| |#4|) (|Boolean|) (|Boolean|)) "\\axiom{pre_process(\\spad{lp},{}\\spad{b1},{}\\spad{b2})} is an internal subroutine,{} exported only for developement.")) (|internalZeroSetSplit| (((|List| $) (|List| |#4|) (|Boolean|) (|Boolean|) (|Boolean|)) "\\axiom{internalZeroSetSplit(\\spad{lp},{}\\spad{b1},{}\\spad{b2},{}\\spad{b3})} is an internal subroutine,{} exported only for developement.")) (|zeroSetSplit| (((|List| $) (|List| |#4|) (|Boolean|) (|Boolean|) (|Boolean|) (|Boolean|)) "\\axiom{zeroSetSplit(\\spad{lp},{}\\spad{b1},{}\\spad{b2}.\\spad{b3},{}\\spad{b4})} is an internal subroutine,{} exported only for developement.") (((|List| $) (|List| |#4|) (|Boolean|) (|Boolean|)) "\\axiom{zeroSetSplit(\\spad{lp},{}clos?,{}info?)} has the same specifications as zeroSetSplit from RegularTriangularSetCategory. Moreover,{} if \\axiom{clos?} then solves in the sense of the Zariski closure else solves in the sense of the regular zeros. If \\axiom{info?} then do print messages during the computations.")) (|internalAugment| (((|List| $) |#4| $ (|Boolean|) (|Boolean|) (|Boolean|) (|Boolean|) (|Boolean|)) "\\axiom{internalAugment(\\spad{p},{}\\spad{ts},{}\\spad{b1},{}\\spad{b2},{}\\spad{b3},{}\\spad{b4},{}\\spad{b5})} is an internal subroutine,{} exported only for developement."))) 
-((-4520 . T) (-4519 . T)) 
+((-4522 . T) (-4521 . T)) 
 ((|HasCategory| |#4| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#4| (QUOTE (-1090))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#3| (QUOTE (-370)))) 
 (-1028 R) 
 ((|constructor| (NIL "\\spad{RepresentationPackage1} provides functions for representation theory for finite groups and algebras. The package creates permutation representations and uses tensor products and its symmetric and antisymmetric components to create new representations of larger degree from given ones. Note that instead of having parameters from \\spadtype{Permutation} this package allows list notation of permutations as well: \\spadignore{e.g.} \\spad{[1,{}4,{}3,{}2]} denotes permutes 2 and 4 and fixes 1 and 3.")) (|permutationRepresentation| (((|List| (|Matrix| (|Integer|))) (|List| (|List| (|Integer|)))) "\\spad{permutationRepresentation([pi1,{}...,{}pik],{}n)} returns the list of matrices [(deltai,{}\\spad{pi1}(\\spad{i})),{}...,{}(deltai,{}pik(\\spad{i}))] if the permutations \\spad{pi1},{}...,{}pik are in list notation and are permuting {1,{}2,{}...,{}\\spad{n}}.") (((|List| (|Matrix| (|Integer|))) (|List| (|Permutation| (|Integer|))) (|Integer|)) "\\spad{permutationRepresentation([pi1,{}...,{}pik],{}n)} returns the list of matrices [(deltai,{}\\spad{pi1}(\\spad{i})),{}...,{}(deltai,{}pik(\\spad{i}))] (Kronecker delta) for the permutations \\spad{pi1},{}...,{}pik of {1,{}2,{}...,{}\\spad{n}}.") (((|Matrix| (|Integer|)) (|List| (|Integer|))) "\\spad{permutationRepresentation(\\spad{pi},{}n)} returns the matrix (deltai,{}\\spad{pi}(\\spad{i})) (Kronecker delta) if the permutation \\spad{pi} is in list notation and permutes {1,{}2,{}...,{}\\spad{n}}.") (((|Matrix| (|Integer|)) (|Permutation| (|Integer|)) (|Integer|)) "\\spad{permutationRepresentation(\\spad{pi},{}n)} returns the matrix (deltai,{}\\spad{pi}(\\spad{i})) (Kronecker delta) for a permutation \\spad{pi} of {1,{}2,{}...,{}\\spad{n}}.")) (|tensorProduct| (((|List| (|Matrix| |#1|)) (|List| (|Matrix| |#1|))) "\\spad{tensorProduct([a1,{}...ak])} calculates the list of Kronecker products of each matrix \\spad{ai} with itself for {1 \\spad{<=} \\spad{i} \\spad{<=} \\spad{k}}. Note that if the list of matrices corresponds to a group representation (repr. of generators) of one group,{} then these matrices correspond to the tensor product of the representation with itself.") (((|Matrix| |#1|) (|Matrix| |#1|)) "\\spad{tensorProduct(a)} calculates the Kronecker product of the matrix a with itself.") (((|List| (|Matrix| |#1|)) (|List| (|Matrix| |#1|)) (|List| (|Matrix| |#1|))) "\\spad{tensorProduct([a1,{}...,{}ak],{}[b1,{}...,{}bk])} calculates the list of Kronecker products of the matrices \\spad{ai} and \\spad{bi} for {1 \\spad{<=} \\spad{i} \\spad{<=} \\spad{k}}. Note that if each list of matrices corresponds to a group representation (repr. of generators) of one group,{} then these matrices correspond to the tensor product of the two representations.") (((|Matrix| |#1|) (|Matrix| |#1|) (|Matrix| |#1|)) "\\spad{tensorProduct(a,{}b)} calculates the Kronecker product of the matrices a and \\spad{b}. Note that if each matrix corresponds to a group representation (repr. of generators) of one group,{} then these matrices correspond to the tensor product of the two representations.")) (|symmetricTensors| (((|List| (|Matrix| |#1|)) (|List| (|Matrix| |#1|)) (|PositiveInteger|)) "\\spad{symmetricTensors(la,{}n)} applies to each \\spad{m}-by-\\spad{m} square matrix in the list \\spad{la} the irreducible,{} polynomial representation of the general linear group \\spad{GLm} which corresponds to the partition (\\spad{n},{}0,{}...,{}0) of \\spad{n}. Error: if the matrices in \\spad{la} are not square matrices. Note that this corresponds to the symmetrization of the representation with the trivial representation of the symmetric group \\spad{Sn}. The carrier spaces of the representation are the symmetric tensors of the \\spad{n}-fold tensor product.") (((|Matrix| |#1|) (|Matrix| |#1|) (|PositiveInteger|)) "\\spad{symmetricTensors(a,{}n)} applies to the \\spad{m}-by-\\spad{m} square matrix a the irreducible,{} polynomial representation of the general linear group \\spad{GLm} which corresponds to the partition (\\spad{n},{}0,{}...,{}0) of \\spad{n}. Error: if a is not a square matrix. Note that this corresponds to the symmetrization of the representation with the trivial representation of the symmetric group \\spad{Sn}. The carrier spaces of the representation are the symmetric tensors of the \\spad{n}-fold tensor product.")) (|createGenericMatrix| (((|Matrix| (|Polynomial| |#1|)) (|NonNegativeInteger|)) "\\spad{createGenericMatrix(m)} creates a square matrix of dimension \\spad{k} whose entry at the \\spad{i}-th row and \\spad{j}-th column is the indeterminate \\spad{x}[\\spad{i},{}\\spad{j}] (double subscripted).")) (|antisymmetricTensors| (((|List| (|Matrix| |#1|)) (|List| (|Matrix| |#1|)) (|PositiveInteger|)) "\\spad{antisymmetricTensors(la,{}n)} applies to each \\spad{m}-by-\\spad{m} square matrix in the list \\spad{la} the irreducible,{} polynomial representation of the general linear group \\spad{GLm} which corresponds to the partition (1,{}1,{}...,{}1,{}0,{}0,{}...,{}0) of \\spad{n}. Error: if \\spad{n} is greater than \\spad{m}. Note that this corresponds to the symmetrization of the representation with the sign representation of the symmetric group \\spad{Sn}. The carrier spaces of the representation are the antisymmetric tensors of the \\spad{n}-fold tensor product.") (((|Matrix| |#1|) (|Matrix| |#1|) (|PositiveInteger|)) "\\spad{antisymmetricTensors(a,{}n)} applies to the square matrix a the irreducible,{} polynomial representation of the general linear group \\spad{GLm},{} where \\spad{m} is the number of rows of a,{} which corresponds to the partition (1,{}1,{}...,{}1,{}0,{}0,{}...,{}0) of \\spad{n}. Error: if \\spad{n} is greater than \\spad{m}. Note that this corresponds to the symmetrization of the representation with the sign representation of the symmetric group \\spad{Sn}. The carrier spaces of the representation are the antisymmetric tensors of the \\spad{n}-fold tensor product."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE (-4521 "*")))) 
+((|HasAttribute| |#1| (QUOTE (-4523 "*")))) 
 (-1029 R) 
 ((|constructor| (NIL "\\spad{RepresentationPackage2} provides functions for working with modular representations of finite groups and algebra. The routines in this package are created,{} using ideas of \\spad{R}. Parker,{} (the meat-Axe) to get smaller representations from bigger ones,{} \\spadignore{i.e.} finding sub- and factormodules,{} or to show,{} that such the representations are irreducible. Note that most functions are randomized functions of Las Vegas type \\spadignore{i.e.} every answer is correct,{} but with small probability the algorithm fails to get an answer.")) (|scanOneDimSubspaces| (((|Vector| |#1|) (|List| (|Vector| |#1|)) (|Integer|)) "\\spad{scanOneDimSubspaces(basis,{}n)} gives a canonical representative of the \\spad{n}-th one-dimensional subspace of the vector space generated by the elements of \\spad{basis},{} all from R**n. The coefficients of the representative are of shape (0,{}...,{}0,{}1,{}*,{}...,{}*),{} * in \\spad{R}. If the size of \\spad{R} is \\spad{q},{} then there are (q**n-1)/(\\spad{q}-1) of them. We first reduce \\spad{n} modulo this number,{} then find the largest \\spad{i} such that \\spad{+/}[q**i for \\spad{i} in 0..\\spad{i}-1] \\spad{<=} \\spad{n}. Subtracting this sum of powers from \\spad{n} results in an \\spad{i}-digit number to \\spad{basis} \\spad{q}. This fills the positions of the stars.")) (|meatAxe| (((|List| (|List| (|Matrix| |#1|))) (|List| (|Matrix| |#1|)) (|PositiveInteger|)) "\\spad{meatAxe(aG,{} numberOfTries)} calls meatAxe(\\spad{aG},{}\\spad{true},{}numberOfTries,{}7). Notes: 7 covers the case of three-dimensional kernels over the field with 2 elements.") (((|List| (|List| (|Matrix| |#1|))) (|List| (|Matrix| |#1|)) (|Boolean|)) "\\spad{meatAxe(aG,{} randomElements)} calls meatAxe(\\spad{aG},{}\\spad{false},{}6,{}7),{} only using Parker\\spad{'s} fingerprints,{} if randomElemnts is \\spad{false}. If it is \\spad{true},{} it calls meatAxe(\\spad{aG},{}\\spad{true},{}25,{}7),{} only using random elements. Note that the choice of 25 was rather arbitrary. Also,{} 7 covers the case of three-dimensional kernels over the field with 2 elements.") (((|List| (|List| (|Matrix| |#1|))) (|List| (|Matrix| |#1|))) "\\spad{meatAxe(aG)} calls meatAxe(\\spad{aG},{}\\spad{false},{}25,{}7) returns a 2-list of representations as follows. All matrices of argument \\spad{aG} are assumed to be square and of equal size. Then \\spad{aG} generates a subalgebra,{} say \\spad{A},{} of the algebra of all square matrices of dimension \\spad{n}. \\spad{V} \\spad{R} is an A-module in the usual way. meatAxe(\\spad{aG}) creates at most 25 random elements of the algebra,{} tests them for singularity. If singular,{} it tries at most 7 elements of its kernel to generate a proper submodule. If successful a list which contains first the list of the representations of the submodule,{} then a list of the representations of the factor module is returned. Otherwise,{} if we know that all the kernel is already scanned,{} Norton\\spad{'s} irreducibility test can be used either to prove irreducibility or to find the splitting. Notes: the first 6 tries use Parker\\spad{'s} fingerprints. Also,{} 7 covers the case of three-dimensional kernels over the field with 2 elements.") (((|List| (|List| (|Matrix| |#1|))) (|List| (|Matrix| |#1|)) (|Boolean|) (|Integer|) (|Integer|)) "\\spad{meatAxe(aG,{}randomElements,{}numberOfTries,{} maxTests)} returns a 2-list of representations as follows. All matrices of argument \\spad{aG} are assumed to be square and of equal size. Then \\spad{aG} generates a subalgebra,{} say \\spad{A},{} of the algebra of all square matrices of dimension \\spad{n}. \\spad{V} \\spad{R} is an A-module in the usual way. meatAxe(\\spad{aG},{}\\spad{numberOfTries},{} maxTests) creates at most \\spad{numberOfTries} random elements of the algebra,{} tests them for singularity. If singular,{} it tries at most maxTests elements of its kernel to generate a proper submodule. If successful,{} a 2-list is returned: first,{} a list containing first the list of the representations of the submodule,{} then a list of the representations of the factor module. Otherwise,{} if we know that all the kernel is already scanned,{} Norton\\spad{'s} irreducibility test can be used either to prove irreducibility or to find the splitting. If \\spad{randomElements} is \\spad{false},{} the first 6 tries use Parker\\spad{'s} fingerprints.")) (|split| (((|List| (|List| (|Matrix| |#1|))) (|List| (|Matrix| |#1|)) (|Vector| (|Vector| |#1|))) "\\spad{split(aG,{}submodule)} uses a proper \\spad{submodule} of R**n to create the representations of the \\spad{submodule} and of the factor module.") (((|List| (|List| (|Matrix| |#1|))) (|List| (|Matrix| |#1|)) (|Vector| |#1|)) "\\spad{split(aG,{} vector)} returns a subalgebra \\spad{A} of all square matrix of dimension \\spad{n} as a list of list of matrices,{} generated by the list of matrices \\spad{aG},{} where \\spad{n} denotes both the size of vector as well as the dimension of each of the square matrices. \\spad{V} \\spad{R} is an A-module in the natural way. split(\\spad{aG},{} vector) then checks whether the cyclic submodule generated by vector is a proper submodule of \\spad{V} \\spad{R}. If successful,{} it returns a two-element list,{} which contains first the list of the representations of the submodule,{} then the list of the representations of the factor module. If the vector generates the whole module,{} a one-element list of the old representation is given. Note that a later version this should call the other split.")) (|isAbsolutelyIrreducible?| (((|Boolean|) (|List| (|Matrix| |#1|))) "\\spad{isAbsolutelyIrreducible?(aG)} calls isAbsolutelyIrreducible?(\\spad{aG},{}25). Note that the choice of 25 was rather arbitrary.") (((|Boolean|) (|List| (|Matrix| |#1|)) (|Integer|)) "\\spad{isAbsolutelyIrreducible?(aG,{} numberOfTries)} uses Norton\\spad{'s} irreducibility test to check for absolute irreduciblity,{} assuming if a one-dimensional kernel is found. As no field extension changes create \"new\" elements in a one-dimensional space,{} the criterium stays \\spad{true} for every extension. The method looks for one-dimensionals only by creating random elements (no fingerprints) since a run of meatAxe would have proved absolute irreducibility anyway.")) (|areEquivalent?| (((|Matrix| |#1|) (|List| (|Matrix| |#1|)) (|List| (|Matrix| |#1|)) (|Integer|)) "\\spad{areEquivalent?(aG0,{}aG1,{}numberOfTries)} calls areEquivalent?(\\spad{aG0},{}\\spad{aG1},{}\\spad{true},{}25). Note that the choice of 25 was rather arbitrary.") (((|Matrix| |#1|) (|List| (|Matrix| |#1|)) (|List| (|Matrix| |#1|))) "\\spad{areEquivalent?(aG0,{}aG1)} calls areEquivalent?(\\spad{aG0},{}\\spad{aG1},{}\\spad{true},{}25). Note that the choice of 25 was rather arbitrary.") (((|Matrix| |#1|) (|List| (|Matrix| |#1|)) (|List| (|Matrix| |#1|)) (|Boolean|) (|Integer|)) "\\spad{areEquivalent?(aG0,{}aG1,{}randomelements,{}numberOfTries)} tests whether the two lists of matrices,{} all assumed of same square shape,{} can be simultaneously conjugated by a non-singular matrix. If these matrices represent the same group generators,{} the representations are equivalent. The algorithm tries \\spad{numberOfTries} times to create elements in the generated algebras in the same fashion. If their ranks differ,{} they are not equivalent. If an isomorphism is assumed,{} then the kernel of an element of the first algebra is mapped to the kernel of the corresponding element in the second algebra. Now consider the one-dimensional ones. If they generate the whole space (\\spadignore{e.g.} irreducibility !) we use standardBasisOfCyclicSubmodule to create the only possible transition matrix. The method checks whether the matrix conjugates all corresponding matrices from aGi. The way to choose the singular matrices is as in meatAxe. If the two representations are equivalent,{} this routine returns the transformation matrix \\spad{TM} with \\spad{aG0}.\\spad{i} * \\spad{TM} = \\spad{TM} * \\spad{aG1}.\\spad{i} for all \\spad{i}. If the representations are not equivalent,{} a small 0-matrix is returned. Note that the case with different sets of group generators cannot be handled.")) (|standardBasisOfCyclicSubmodule| (((|Matrix| |#1|) (|List| (|Matrix| |#1|)) (|Vector| |#1|)) "\\spad{standardBasisOfCyclicSubmodule(lm,{}v)} returns a matrix as follows. It is assumed that the size \\spad{n} of the vector equals the number of rows and columns of the matrices. Then the matrices generate a subalgebra,{} say \\spad{A},{} of the algebra of all square matrices of dimension \\spad{n}. \\spad{V} \\spad{R} is an \\spad{A}-module in the natural way. standardBasisOfCyclicSubmodule(\\spad{lm},{}\\spad{v}) calculates a matrix whose non-zero column vectors are the \\spad{R}-Basis of Av achieved in the way as described in section 6 of \\spad{R}. A. Parker\\spad{'s} \"The Meat-Axe\". Note that in contrast to cyclicSubmodule,{} the result is not in echelon form.")) (|cyclicSubmodule| (((|Vector| (|Vector| |#1|)) (|List| (|Matrix| |#1|)) (|Vector| |#1|)) "\\spad{cyclicSubmodule(lm,{}v)} generates a basis as follows. It is assumed that the size \\spad{n} of the vector equals the number of rows and columns of the matrices. Then the matrices generate a subalgebra,{} say \\spad{A},{} of the algebra of all square matrices of dimension \\spad{n}. \\spad{V} \\spad{R} is an \\spad{A}-module in the natural way. cyclicSubmodule(\\spad{lm},{}\\spad{v}) generates the \\spad{R}-Basis of Av as described in section 6 of \\spad{R}. A. Parker\\spad{'s} \"The Meat-Axe\". Note that in contrast to the description in \"The Meat-Axe\" and to standardBasisOfCyclicSubmodule the result is in echelon form.")) (|createRandomElement| (((|Matrix| |#1|) (|List| (|Matrix| |#1|)) (|Matrix| |#1|)) "\\spad{createRandomElement(aG,{}x)} creates a random element of the group algebra generated by \\spad{aG}.")) (|completeEchelonBasis| (((|Matrix| |#1|) (|Vector| (|Vector| |#1|))) "\\spad{completeEchelonBasis(lv)} completes the basis \\spad{lv} assumed to be in echelon form of a subspace of R**n (\\spad{n} the length of all the vectors in \\spad{lv} with unit vectors to a basis of R**n. It is assumed that the argument is not an empty vector and that it is not the basis of the 0-subspace. Note that the rows of the result correspond to the vectors of the basis."))) 
 NIL 
@@ -4066,12 +4066,12 @@ NIL
 NIL 
 (-1034 -1478 |Expon| |VarSet| |FPol| |LFPol|) 
 ((|constructor| (NIL "ResidueRing is the quotient of a polynomial ring by an ideal. The ideal is given as a list of generators. The elements of the domain are equivalence classes expressed in terms of reduced elements")) (|lift| ((|#4| $) "\\spad{lift(x)} return the canonical representative of the equivalence class \\spad{x}")) (|coerce| (($ |#4|) "\\spad{coerce(f)} produces the equivalence class of \\spad{f} in the residue ring")) (|reduce| (($ |#4|) "\\spad{reduce(f)} produces the equivalence class of \\spad{f} in the residue ring"))) 
-(((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+(((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-1035) 
 ((|constructor| (NIL "A domain used to return the results from a call to the NAG Library. It prints as a list of names and types,{} though the user may choose to display values automatically if he or she wishes.")) (|showArrayValues| (((|Boolean|) (|Boolean|)) "\\spad{showArrayValues(true)} forces the values of array components to be \\indented{1}{displayed rather than just their types.}")) (|showScalarValues| (((|Boolean|) (|Boolean|)) "\\spad{showScalarValues(true)} forces the values of scalar components to be \\indented{1}{displayed rather than just their types.}"))) 
-((-4519 . T) (-4520 . T)) 
-((|HasCategory| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3649) (QUOTE (-1161))) (LIST (QUOTE |:|) (QUOTE -4083) (QUOTE (-57)))))) (|HasCategory| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (QUOTE (-1090)))) (|HasCategory| (-1161) (QUOTE (-842))) (|HasCategory| (-57) (QUOTE (-1090))) (-2198 (|HasCategory| (-57) (QUOTE (-1090))) (|HasCategory| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (QUOTE (-1090)))) (-12 (|HasCategory| (-57) (LIST (QUOTE -303) (QUOTE (-57)))) (|HasCategory| (-57) (QUOTE (-1090))))) 
+((-4521 . T) (-4522 . T)) 
+((|HasCategory| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3651) (QUOTE (-1161))) (LIST (QUOTE |:|) (QUOTE -4085) (QUOTE (-57)))))) (|HasCategory| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (QUOTE (-1090)))) (|HasCategory| (-1161) (QUOTE (-842))) (|HasCategory| (-57) (QUOTE (-1090))) (-2199 (|HasCategory| (-57) (QUOTE (-1090))) (|HasCategory| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (QUOTE (-1090)))) (-12 (|HasCategory| (-57) (LIST (QUOTE -303) (QUOTE (-57)))) (|HasCategory| (-57) (QUOTE (-1090))))) 
 (-1036 A S) 
 ((|constructor| (NIL "A is retractable to \\spad{B} means that some elementsif A can be converted into elements of \\spad{B} and any element of \\spad{B} can be converted into an element of A.")) (|retract| ((|#2| $) "\\spad{retract(a)} transforms a into an element of \\spad{S} if possible. Error: if a cannot be made into an element of \\spad{S}.")) (|retractIfCan| (((|Union| |#2| "failed") $) "\\spad{retractIfCan(a)} transforms a into an element of \\spad{S} if possible. Returns \"failed\" if a cannot be made into an element of \\spad{S}.")) (|coerce| (($ |#2|) "\\spad{coerce(a)} transforms a into an element of \\%."))) 
 NIL 
@@ -4106,7 +4106,7 @@ NIL
 NIL 
 (-1044 R |ls|) 
 ((|constructor| (NIL "A domain for regular chains (\\spadignore{i.e.} regular triangular sets) over a \\spad{Gcd}-Domain and with a fix list of variables. This is just a front-end for the \\spadtype{RegularTriangularSet} domain constructor.")) (|zeroSetSplit| (((|List| $) (|List| (|NewSparseMultivariatePolynomial| |#1| (|OrderedVariableList| |#2|))) (|Boolean|) (|Boolean|)) "\\spad{zeroSetSplit(lp,{}clos?,{}info?)} returns a list \\spad{lts} of regular chains such that the union of the closures of their regular zero sets equals the affine variety associated with \\spad{lp}. Moreover,{} if \\spad{clos?} is \\spad{false} then the union of the regular zero set of the \\spad{ts} (for \\spad{ts} in \\spad{lts}) equals this variety. If \\spad{info?} is \\spad{true} then some information is displayed during the computations. See zeroSetSplit from RegularTriangularSet."))) 
-((-4520 . T) (-4519 . T)) 
+((-4522 . T) (-4521 . T)) 
 ((|HasCategory| (-775 |#1| (-852 |#2|)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-775 |#1| (-852 |#2|)) (QUOTE (-1090))) (-12 (|HasCategory| (-775 |#1| (-852 |#2|)) (LIST (QUOTE -303) (LIST (QUOTE -775) (|devaluate| |#1|) (LIST (QUOTE -852) (|devaluate| |#2|))))) (|HasCategory| (-775 |#1| (-852 |#2|)) (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| (-852 |#2|) (QUOTE (-370)))) 
 (-1045) 
 ((|constructor| (NIL "This package exports integer distributions")) (|ridHack1| (((|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Integer|)) "\\spad{ridHack1(i,{}j,{}k,{}l)} \\undocumented")) (|geometric| (((|Mapping| (|Integer|)) |RationalNumber|) "\\spad{geometric(f)} \\undocumented")) (|poisson| (((|Mapping| (|Integer|)) |RationalNumber|) "\\spad{poisson(f)} \\undocumented")) (|binomial| (((|Mapping| (|Integer|)) (|Integer|) |RationalNumber|) "\\spad{binomial(n,{}f)} \\undocumented")) (|uniform| (((|Mapping| (|Integer|)) (|Segment| (|Integer|))) "\\spad{uniform(s)} as \\indented{4}{\\spad{l} + \\spad{u0} + \\spad{w*u1} + \\spad{w**2*u2} +...+ \\spad{w**}(\\spad{n}-1)*u-1 + w**n*m} where \\indented{4}{\\spad{s} = a..\\spad{b}} \\indented{4}{\\spad{l} = min(a,{}\\spad{b})} \\indented{4}{\\spad{m} = abs(\\spad{b}-a) + 1} \\indented{4}{w**n < \\spad{m} < \\spad{w**}(\\spad{n+1})} \\indented{4}{\\spad{u0},{}...,{}un-1\\space{2}are uniform on\\space{2}0..\\spad{w}-1} \\indented{4}{\\spad{m}\\space{12}is\\space{2}uniform on\\space{2}0..(\\spad{m} quo w**n)\\spad{-1}}"))) 
@@ -4118,7 +4118,7 @@ NIL
 NIL 
 (-1047) 
 ((|constructor| (NIL "The category of rings with unity,{} always associative,{} but not necessarily commutative.")) (|unitsKnown| ((|attribute|) "recip truly yields reciprocal or \"failed\" if not a unit. Note that \\spad{recip(0) = \"failed\"}.")) (|coerce| (($ (|Integer|)) "\\spad{coerce(i)} converts the integer \\spad{i} to a member of the given domain.")) (|characteristic| (((|NonNegativeInteger|)) "\\spad{characteristic()} returns the characteristic of the ring this is the smallest positive integer \\spad{n} such that \\spad{n*x=0} for all \\spad{x} in the ring,{} or zero if no such \\spad{n} exists."))) 
-((-4516 . T)) 
+((-4518 . T)) 
 NIL 
 (-1048 |xx| -1478) 
 ((|constructor| (NIL "This package exports rational interpolation algorithms"))) 
@@ -4130,12 +4130,12 @@ NIL
 ((|HasCategory| |#4| (QUOTE (-301))) (|HasCategory| |#4| (QUOTE (-365))) (|HasCategory| |#4| (QUOTE (-558))) (|HasCategory| |#4| (QUOTE (-172)))) 
 (-1050 |m| |n| R |Row| |Col|) 
 ((|constructor| (NIL "\\spadtype{RectangularMatrixCategory} is a category of matrices of fixed dimensions. The dimensions of the matrix will be parameters of the domain. Domains in this category will be \\spad{R}-modules and will be non-mutable.")) (|nullSpace| (((|List| |#5|) $) "\\spad{nullSpace(m)}+ returns a basis for the null space of the matrix \\spad{m}.")) (|nullity| (((|NonNegativeInteger|) $) "\\spad{nullity(m)} returns the nullity of the matrix \\spad{m}. This is the dimension of the null space of the matrix \\spad{m}.")) (|rank| (((|NonNegativeInteger|) $) "\\spad{rank(m)} returns the rank of the matrix \\spad{m}.")) (|rowEchelon| (($ $) "\\spad{rowEchelon(m)} returns the row echelon form of the matrix \\spad{m}.")) (/ (($ $ |#3|) "\\spad{m/r} divides the elements of \\spad{m} by \\spad{r}. Error: if \\spad{r = 0}.")) (|exquo| (((|Union| $ "failed") $ |#3|) "\\spad{exquo(m,{}r)} computes the exact quotient of the elements of \\spad{m} by \\spad{r},{} returning \\axiom{\"failed\"} if this is not possible.")) (|map| (($ (|Mapping| |#3| |#3| |#3|) $ $) "\\spad{map(f,{}a,{}b)} returns \\spad{c},{} where \\spad{c} is such that \\spad{c(i,{}j) = f(a(i,{}j),{}b(i,{}j))} for all \\spad{i},{} \\spad{j}.") (($ (|Mapping| |#3| |#3|) $) "\\spad{map(f,{}a)} returns \\spad{b},{} where \\spad{b(i,{}j) = a(i,{}j)} for all \\spad{i},{} \\spad{j}.")) (|column| ((|#5| $ (|Integer|)) "\\spad{column(m,{}j)} returns the \\spad{j}th column of the matrix \\spad{m}. Error: if the index outside the proper range.")) (|row| ((|#4| $ (|Integer|)) "\\spad{row(m,{}i)} returns the \\spad{i}th row of the matrix \\spad{m}. Error: if the index is outside the proper range.")) (|qelt| ((|#3| $ (|Integer|) (|Integer|)) "\\spad{qelt(m,{}i,{}j)} returns the element in the \\spad{i}th row and \\spad{j}th column of the matrix \\spad{m}. Note that there is NO error check to determine if indices are in the proper ranges.")) (|elt| ((|#3| $ (|Integer|) (|Integer|) |#3|) "\\spad{elt(m,{}i,{}j,{}r)} returns the element in the \\spad{i}th row and \\spad{j}th column of the matrix \\spad{m},{} if \\spad{m} has an \\spad{i}th row and a \\spad{j}th column,{} and returns \\spad{r} otherwise.") ((|#3| $ (|Integer|) (|Integer|)) "\\spad{elt(m,{}i,{}j)} returns the element in the \\spad{i}th row and \\spad{j}th column of the matrix \\spad{m}. Error: if indices are outside the proper ranges.")) (|listOfLists| (((|List| (|List| |#3|)) $) "\\spad{listOfLists(m)} returns the rows of the matrix \\spad{m} as a list of lists.")) (|ncols| (((|NonNegativeInteger|) $) "\\spad{ncols(m)} returns the number of columns in the matrix \\spad{m}.")) (|nrows| (((|NonNegativeInteger|) $) "\\spad{nrows(m)} returns the number of rows in the matrix \\spad{m}.")) (|maxColIndex| (((|Integer|) $) "\\spad{maxColIndex(m)} returns the index of the 'last' column of the matrix \\spad{m}.")) (|minColIndex| (((|Integer|) $) "\\spad{minColIndex(m)} returns the index of the 'first' column of the matrix \\spad{m}.")) (|maxRowIndex| (((|Integer|) $) "\\spad{maxRowIndex(m)} returns the index of the 'last' row of the matrix \\spad{m}.")) (|minRowIndex| (((|Integer|) $) "\\spad{minRowIndex(m)} returns the index of the 'first' row of the matrix \\spad{m}.")) (|antisymmetric?| (((|Boolean|) $) "\\spad{antisymmetric?(m)} returns \\spad{true} if the matrix \\spad{m} is square and antisymmetric (\\spadignore{i.e.} \\spad{m[i,{}j] = -m[j,{}i]} for all \\spad{i} and \\spad{j}) and \\spad{false} otherwise.")) (|symmetric?| (((|Boolean|) $) "\\spad{symmetric?(m)} returns \\spad{true} if the matrix \\spad{m} is square and symmetric (\\spadignore{i.e.} \\spad{m[i,{}j] = m[j,{}i]} for all \\spad{i} and \\spad{j}) and \\spad{false} otherwise.")) (|diagonal?| (((|Boolean|) $) "\\spad{diagonal?(m)} returns \\spad{true} if the matrix \\spad{m} is square and diagonal (\\spadignore{i.e.} all entries of \\spad{m} not on the diagonal are zero) and \\spad{false} otherwise.")) (|square?| (((|Boolean|) $) "\\spad{square?(m)} returns \\spad{true} if \\spad{m} is a square matrix (\\spadignore{i.e.} if \\spad{m} has the same number of rows as columns) and \\spad{false} otherwise.")) (|matrix| (($ (|List| (|List| |#3|))) "\\spad{matrix(l)} converts the list of lists \\spad{l} to a matrix,{} where the list of lists is viewed as a list of the rows of the matrix.")) (|finiteAggregate| ((|attribute|) "matrices are finite"))) 
-((-4519 . T) (-3973 . T) (-4514 . T) (-4513 . T)) 
+((-4521 . T) (-3973 . T) (-4516 . T) (-4515 . T)) 
 NIL 
 (-1051 |m| |n| R) 
 ((|constructor| (NIL "\\spadtype{RectangularMatrix} is a matrix domain where the number of rows and the number of columns are parameters of the domain.")) (|coerce| (((|Matrix| |#3|) $) "\\spad{coerce(m)} converts a matrix of type \\spadtype{RectangularMatrix} to a matrix of type \\spad{Matrix}.")) (|rectangularMatrix| (($ (|Matrix| |#3|)) "\\spad{rectangularMatrix(m)} converts a matrix of type \\spadtype{Matrix} to a matrix of type \\spad{RectangularMatrix}."))) 
-((-4519 . T) (-4514 . T) (-4513 . T)) 
-((|HasCategory| |#3| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#3| (QUOTE (-365))) (|HasCategory| |#3| (QUOTE (-1090))) (|HasCategory| |#3| (QUOTE (-301))) (|HasCategory| |#3| (QUOTE (-558))) (|HasCategory| |#3| (QUOTE (-172))) (-2198 (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-365)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-172)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-365)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1090)))))) 
+((-4521 . T) (-4516 . T) (-4515 . T)) 
+((|HasCategory| |#3| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#3| (QUOTE (-365))) (|HasCategory| |#3| (QUOTE (-1090))) (|HasCategory| |#3| (QUOTE (-301))) (|HasCategory| |#3| (QUOTE (-558))) (|HasCategory| |#3| (QUOTE (-172))) (-2199 (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-365)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-172)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-365)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1090)))))) 
 (-1052 |m| |n| R1 |Row1| |Col1| M1 R2 |Row2| |Col2| M2) 
 ((|constructor| (NIL "\\spadtype{RectangularMatrixCategoryFunctions2} provides functions between two matrix domains. The functions provided are \\spadfun{map} and \\spadfun{reduce}.")) (|reduce| ((|#7| (|Mapping| |#7| |#3| |#7|) |#6| |#7|) "\\spad{reduce(f,{}m,{}r)} returns a matrix \\spad{n} where \\spad{n[i,{}j] = f(m[i,{}j],{}r)} for all indices spad{\\spad{i}} and \\spad{j}.")) (|map| ((|#10| (|Mapping| |#7| |#3|) |#6|) "\\spad{map(f,{}m)} applies the function \\spad{f} to the elements of the matrix \\spad{m}."))) 
 NIL 
@@ -4154,7 +4154,7 @@ NIL
 NIL 
 (-1056) 
 ((|constructor| (NIL "The real number system category is intended as a model for the real numbers. The real numbers form an ordered normed field. Note that we have purposely not included \\spadtype{DifferentialRing} or the elementary functions (see \\spadtype{TranscendentalFunctionCategory}) in the definition.")) (|abs| (($ $) "\\spad{abs x} returns the absolute value of \\spad{x}.")) (|round| (($ $) "\\spad{round x} computes the integer closest to \\spad{x}.")) (|truncate| (($ $) "\\spad{truncate x} returns the integer between \\spad{x} and 0 closest to \\spad{x}.")) (|fractionPart| (($ $) "\\spad{fractionPart x} returns the fractional part of \\spad{x}.")) (|wholePart| (((|Integer|) $) "\\spad{wholePart x} returns the integer part of \\spad{x}.")) (|floor| (($ $) "\\spad{floor x} returns the largest integer \\spad{<= x}.")) (|ceiling| (($ $) "\\spad{ceiling x} returns the small integer \\spad{>= x}.")) (|norm| (($ $) "\\spad{norm x} returns the same as absolute value."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-1057 |TheField| |ThePolDom|) 
 ((|constructor| (NIL "\\axiomType{RightOpenIntervalRootCharacterization} provides work with interval root coding.")) (|relativeApprox| ((|#1| |#2| $ |#1|) "\\axiom{relativeApprox(exp,{}\\spad{c},{}\\spad{p}) = a} is relatively close to exp as a polynomial in \\spad{c} ip to precision \\spad{p}")) (|mightHaveRoots| (((|Boolean|) |#2| $) "\\axiom{mightHaveRoots(\\spad{p},{}\\spad{r})} is \\spad{false} if \\axiom{\\spad{p}.\\spad{r}} is not 0")) (|refine| (($ $) "\\axiom{refine(rootChar)} shrinks isolating interval around \\axiom{rootChar}")) (|middle| ((|#1| $) "\\axiom{middle(rootChar)} is the middle of the isolating interval")) (|size| ((|#1| $) "The size of the isolating interval")) (|right| ((|#1| $) "\\axiom{right(rootChar)} is the right bound of the isolating interval")) (|left| ((|#1| $) "\\axiom{left(rootChar)} is the left bound of the isolating interval"))) 
@@ -4162,19 +4162,19 @@ NIL
 NIL 
 (-1058) 
 ((|constructor| (NIL "\\spadtype{RomanNumeral} provides functions for converting integers to roman numerals.")) (|roman| (($ (|Integer|)) "\\spad{roman(n)} creates a roman numeral for \\spad{n}.") (($ (|Symbol|)) "\\spad{roman(n)} creates a roman numeral for symbol \\spad{n}.")) (|convert| (($ (|Symbol|)) "\\spad{convert(n)} creates a roman numeral for symbol \\spad{n}.")) (|noetherian| ((|attribute|) "ascending chain condition on ideals.")) (|canonicalsClosed| ((|attribute|) "two positives multiply to give positive.")) (|canonical| ((|attribute|) "mathematical equality is data structure equality."))) 
-((-4507 . T) (-4511 . T) (-4506 . T) (-4517 . T) (-4518 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4509 . T) (-4513 . T) (-4508 . T) (-4519 . T) (-4520 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-1059) 
 ((|constructor| (NIL "\\axiomType{RoutinesTable} implements a database and associated tuning mechanisms for a set of known NAG routines")) (|recoverAfterFail| (((|Union| (|String|) "failed") $ (|String|) (|Integer|)) "\\spad{recoverAfterFail(routs,{}routineName,{}ifailValue)} acts on the instructions given by the ifail list")) (|showTheRoutinesTable| (($) "\\spad{showTheRoutinesTable()} returns the current table of NAG routines.")) (|deleteRoutine!| (($ $ (|Symbol|)) "\\spad{deleteRoutine!(R,{}s)} destructively deletes the given routine from the current database of NAG routines")) (|getExplanations| (((|List| (|String|)) $ (|String|)) "\\spad{getExplanations(R,{}s)} gets the explanations of the output parameters for the given NAG routine.")) (|getMeasure| (((|Float|) $ (|Symbol|)) "\\spad{getMeasure(R,{}s)} gets the current value of the maximum measure for the given NAG routine.")) (|changeMeasure| (($ $ (|Symbol|) (|Float|)) "\\spad{changeMeasure(R,{}s,{}newValue)} changes the maximum value for a measure of the given NAG routine.")) (|changeThreshhold| (($ $ (|Symbol|) (|Float|)) "\\spad{changeThreshhold(R,{}s,{}newValue)} changes the value below which,{} given a NAG routine generating a higher measure,{} the routines will make no attempt to generate a measure.")) (|selectMultiDimensionalRoutines| (($ $) "\\spad{selectMultiDimensionalRoutines(R)} chooses only those routines from the database which are designed for use with multi-dimensional expressions")) (|selectNonFiniteRoutines| (($ $) "\\spad{selectNonFiniteRoutines(R)} chooses only those routines from the database which are designed for use with non-finite expressions.")) (|selectSumOfSquaresRoutines| (($ $) "\\spad{selectSumOfSquaresRoutines(R)} chooses only those routines from the database which are designed for use with sums of squares")) (|selectFiniteRoutines| (($ $) "\\spad{selectFiniteRoutines(R)} chooses only those routines from the database which are designed for use with finite expressions")) (|selectODEIVPRoutines| (($ $) "\\spad{selectODEIVPRoutines(R)} chooses only those routines from the database which are for the solution of ODE\\spad{'s}")) (|selectPDERoutines| (($ $) "\\spad{selectPDERoutines(R)} chooses only those routines from the database which are for the solution of PDE\\spad{'s}")) (|selectOptimizationRoutines| (($ $) "\\spad{selectOptimizationRoutines(R)} chooses only those routines from the database which are for integration")) (|selectIntegrationRoutines| (($ $) "\\spad{selectIntegrationRoutines(R)} chooses only those routines from the database which are for integration")) (|routines| (($) "\\spad{routines()} initialises a database of known NAG routines")) (|concat| (($ $ $) "\\spad{concat(x,{}y)} merges two tables \\spad{x} and \\spad{y}"))) 
-((-4519 . T) (-4520 . T)) 
-((|HasCategory| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3649) (QUOTE (-1161))) (LIST (QUOTE |:|) (QUOTE -4083) (QUOTE (-57)))))) (|HasCategory| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (QUOTE (-1090)))) (|HasCategory| (-1161) (QUOTE (-842))) (|HasCategory| (-57) (QUOTE (-1090))) (-2198 (|HasCategory| (-57) (QUOTE (-1090))) (|HasCategory| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (QUOTE (-1090)))) (-12 (|HasCategory| (-57) (LIST (QUOTE -303) (QUOTE (-57)))) (|HasCategory| (-57) (QUOTE (-1090))))) 
+((-4521 . T) (-4522 . T)) 
+((|HasCategory| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3651) (QUOTE (-1161))) (LIST (QUOTE |:|) (QUOTE -4085) (QUOTE (-57)))))) (|HasCategory| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (QUOTE (-1090)))) (|HasCategory| (-1161) (QUOTE (-842))) (|HasCategory| (-57) (QUOTE (-1090))) (-2199 (|HasCategory| (-57) (QUOTE (-1090))) (|HasCategory| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (QUOTE (-1090)))) (-12 (|HasCategory| (-57) (LIST (QUOTE -303) (QUOTE (-57)))) (|HasCategory| (-57) (QUOTE (-1090))))) 
 (-1060 S R E V) 
 ((|constructor| (NIL "A category for general multi-variate polynomials with coefficients in a ring,{} variables in an ordered set,{} and exponents from an ordered abelian monoid,{} with a \\axiomOp{sup} operation. When not constant,{} such a polynomial is viewed as a univariate polynomial in its main variable \\spad{w}. \\spad{r}. \\spad{t}. to the total ordering on the elements in the ordered set,{} so that some operations usually defined for univariate polynomials make sense here.")) (|mainSquareFreePart| (($ $) "\\axiom{mainSquareFreePart(\\spad{p})} returns the square free part of \\axiom{\\spad{p}} viewed as a univariate polynomial in its main variable and with coefficients in the polynomial ring generated by its other variables over \\axiom{\\spad{R}}.")) (|mainPrimitivePart| (($ $) "\\axiom{mainPrimitivePart(\\spad{p})} returns the primitive part of \\axiom{\\spad{p}} viewed as a univariate polynomial in its main variable and with coefficients in the polynomial ring generated by its other variables over \\axiom{\\spad{R}}.")) (|mainContent| (($ $) "\\axiom{mainContent(\\spad{p})} returns the content of \\axiom{\\spad{p}} viewed as a univariate polynomial in its main variable and with coefficients in the polynomial ring generated by its other variables over \\axiom{\\spad{R}}.")) (|primitivePart!| (($ $) "\\axiom{primitivePart!(\\spad{p})} replaces \\axiom{\\spad{p}} by its primitive part.")) (|gcd| ((|#2| |#2| $) "\\axiom{\\spad{gcd}(\\spad{r},{}\\spad{p})} returns the \\spad{gcd} of \\axiom{\\spad{r}} and the content of \\axiom{\\spad{p}}.")) (|nextsubResultant2| (($ $ $ $ $) "\\axiom{\\spad{nextsubResultant2}(\\spad{p},{}\\spad{q},{}\\spad{z},{}\\spad{s})} is the multivariate version of the operation \\spad{next_sousResultant2} from PseudoRemainderSequence from the \\axiomType{PseudoRemainderSequence} constructor.")) (|LazardQuotient2| (($ $ $ $ (|NonNegativeInteger|)) "\\axiom{\\spad{LazardQuotient2}(\\spad{p},{}a,{}\\spad{b},{}\\spad{n})} returns \\axiom{(a**(\\spad{n}-1) * \\spad{p}) exquo \\spad{b**}(\\spad{n}-1)} assuming that this quotient does not fail.")) (|LazardQuotient| (($ $ $ (|NonNegativeInteger|)) "\\axiom{LazardQuotient(a,{}\\spad{b},{}\\spad{n})} returns \\axiom{a**n exquo \\spad{b**}(\\spad{n}-1)} assuming that this quotient does not fail.")) (|lastSubResultant| (($ $ $) "\\axiom{lastSubResultant(a,{}\\spad{b})} returns the last non-zero subresultant of \\axiom{a} and \\axiom{\\spad{b}} where \\axiom{a} and \\axiom{\\spad{b}} are assumed to have the same main variable \\axiom{\\spad{v}} and are viewed as univariate polynomials in \\axiom{\\spad{v}}.")) (|subResultantChain| (((|List| $) $ $) "\\axiom{subResultantChain(a,{}\\spad{b})},{} where \\axiom{a} and \\axiom{\\spad{b}} are not contant polynomials with the same main variable,{} returns the subresultant chain of \\axiom{a} and \\axiom{\\spad{b}}.")) (|resultant| (($ $ $) "\\axiom{resultant(a,{}\\spad{b})} computes the resultant of \\axiom{a} and \\axiom{\\spad{b}} where \\axiom{a} and \\axiom{\\spad{b}} are assumed to have the same main variable \\axiom{\\spad{v}} and are viewed as univariate polynomials in \\axiom{\\spad{v}}.")) (|halfExtendedSubResultantGcd2| (((|Record| (|:| |gcd| $) (|:| |coef2| $)) $ $) "\\axiom{\\spad{halfExtendedSubResultantGcd2}(a,{}\\spad{b})} returns \\axiom{[\\spad{g},{}\\spad{cb}]} if \\axiom{extendedSubResultantGcd(a,{}\\spad{b})} returns \\axiom{[\\spad{g},{}ca,{}\\spad{cb}]} otherwise produces an error.")) (|halfExtendedSubResultantGcd1| (((|Record| (|:| |gcd| $) (|:| |coef1| $)) $ $) "\\axiom{\\spad{halfExtendedSubResultantGcd1}(a,{}\\spad{b})} returns \\axiom{[\\spad{g},{}ca]} if \\axiom{extendedSubResultantGcd(a,{}\\spad{b})} returns \\axiom{[\\spad{g},{}ca,{}\\spad{cb}]} otherwise produces an error.")) (|extendedSubResultantGcd| (((|Record| (|:| |gcd| $) (|:| |coef1| $) (|:| |coef2| $)) $ $) "\\axiom{extendedSubResultantGcd(a,{}\\spad{b})} returns \\axiom{[ca,{}\\spad{cb},{}\\spad{r}]} such that \\axiom{\\spad{r}} is \\axiom{subResultantGcd(a,{}\\spad{b})} and we have \\axiom{ca * a + \\spad{cb} * \\spad{cb} = \\spad{r}} .")) (|subResultantGcd| (($ $ $) "\\axiom{subResultantGcd(a,{}\\spad{b})} computes a \\spad{gcd} of \\axiom{a} and \\axiom{\\spad{b}} where \\axiom{a} and \\axiom{\\spad{b}} are assumed to have the same main variable \\axiom{\\spad{v}} and are viewed as univariate polynomials in \\axiom{\\spad{v}} with coefficients in the fraction field of the polynomial ring generated by their other variables over \\axiom{\\spad{R}}.")) (|exactQuotient!| (($ $ $) "\\axiom{exactQuotient!(a,{}\\spad{b})} replaces \\axiom{a} by \\axiom{exactQuotient(a,{}\\spad{b})}") (($ $ |#2|) "\\axiom{exactQuotient!(\\spad{p},{}\\spad{r})} replaces \\axiom{\\spad{p}} by \\axiom{exactQuotient(\\spad{p},{}\\spad{r})}.")) (|exactQuotient| (($ $ $) "\\axiom{exactQuotient(a,{}\\spad{b})} computes the exact quotient of \\axiom{a} by \\axiom{\\spad{b}},{} which is assumed to be a divisor of \\axiom{a}. No error is returned if this exact quotient fails!") (($ $ |#2|) "\\axiom{exactQuotient(\\spad{p},{}\\spad{r})} computes the exact quotient of \\axiom{\\spad{p}} by \\axiom{\\spad{r}},{} which is assumed to be a divisor of \\axiom{\\spad{p}}. No error is returned if this exact quotient fails!")) (|primPartElseUnitCanonical!| (($ $) "\\axiom{primPartElseUnitCanonical!(\\spad{p})} replaces \\axiom{\\spad{p}} by \\axiom{primPartElseUnitCanonical(\\spad{p})}.")) (|primPartElseUnitCanonical| (($ $) "\\axiom{primPartElseUnitCanonical(\\spad{p})} returns \\axiom{primitivePart(\\spad{p})} if \\axiom{\\spad{R}} is a \\spad{gcd}-domain,{} otherwise \\axiom{unitCanonical(\\spad{p})}.")) (|convert| (($ (|Polynomial| |#2|)) "\\axiom{convert(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if all its variables belong to \\axiom{\\spad{V}},{} otherwise an error is produced.") (($ (|Polynomial| (|Integer|))) "\\axiom{convert(\\spad{p})} returns the same as \\axiom{retract(\\spad{p})}.") (($ (|Polynomial| (|Integer|))) "\\axiom{convert(\\spad{p})} returns the same as \\axiom{retract(\\spad{p})}") (($ (|Polynomial| (|Fraction| (|Integer|)))) "\\axiom{convert(\\spad{p})} returns the same as \\axiom{retract(\\spad{p})}.")) (|retract| (($ (|Polynomial| |#2|)) "\\axiom{retract(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if \\axiom{retractIfCan(\\spad{p})} does not return \"failed\",{} otherwise an error is produced.") (($ (|Polynomial| |#2|)) "\\axiom{retract(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if \\axiom{retractIfCan(\\spad{p})} does not return \"failed\",{} otherwise an error is produced.") (($ (|Polynomial| (|Integer|))) "\\axiom{retract(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if \\axiom{retractIfCan(\\spad{p})} does not return \"failed\",{} otherwise an error is produced.") (($ (|Polynomial| |#2|)) "\\axiom{retract(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if \\axiom{retractIfCan(\\spad{p})} does not return \"failed\",{} otherwise an error is produced.") (($ (|Polynomial| (|Integer|))) "\\axiom{retract(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if \\axiom{retractIfCan(\\spad{p})} does not return \"failed\",{} otherwise an error is produced.") (($ (|Polynomial| (|Fraction| (|Integer|)))) "\\axiom{retract(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if \\axiom{retractIfCan(\\spad{p})} does not return \"failed\",{} otherwise an error is produced.")) (|retractIfCan| (((|Union| $ "failed") (|Polynomial| |#2|)) "\\axiom{retractIfCan(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if all its variables belong to \\axiom{\\spad{V}}.") (((|Union| $ "failed") (|Polynomial| |#2|)) "\\axiom{retractIfCan(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if all its variables belong to \\axiom{\\spad{V}}.") (((|Union| $ "failed") (|Polynomial| (|Integer|))) "\\axiom{retractIfCan(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if all its variables belong to \\axiom{\\spad{V}}.") (((|Union| $ "failed") (|Polynomial| |#2|)) "\\axiom{retractIfCan(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if all its variables belong to \\axiom{\\spad{V}}.") (((|Union| $ "failed") (|Polynomial| (|Integer|))) "\\axiom{retractIfCan(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if all its variables belong to \\axiom{\\spad{V}}.") (((|Union| $ "failed") (|Polynomial| (|Fraction| (|Integer|)))) "\\axiom{retractIfCan(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if all its variables belong to \\axiom{\\spad{V}}.")) (|initiallyReduce| (($ $ $) "\\axiom{initiallyReduce(a,{}\\spad{b})} returns a polynomial \\axiom{\\spad{r}} such that \\axiom{initiallyReduced?(\\spad{r},{}\\spad{b})} holds and there exists an integer \\axiom{\\spad{e}} such that \\axiom{init(\\spad{b})^e a - \\spad{r}} is zero modulo \\axiom{\\spad{b}}.")) (|headReduce| (($ $ $) "\\axiom{headReduce(a,{}\\spad{b})} returns a polynomial \\axiom{\\spad{r}} such that \\axiom{headReduced?(\\spad{r},{}\\spad{b})} holds and there exists an integer \\axiom{\\spad{e}} such that \\axiom{init(\\spad{b})^e a - \\spad{r}} is zero modulo \\axiom{\\spad{b}}.")) (|lazyResidueClass| (((|Record| (|:| |polnum| $) (|:| |polden| $) (|:| |power| (|NonNegativeInteger|))) $ $) "\\axiom{lazyResidueClass(a,{}\\spad{b})} returns \\axiom{[\\spad{p},{}\\spad{q},{}\\spad{n}]} where \\axiom{\\spad{p} / q**n} represents the residue class of \\axiom{a} modulo \\axiom{\\spad{b}} and \\axiom{\\spad{p}} is reduced \\spad{w}.\\spad{r}.\\spad{t}. \\axiom{\\spad{b}} and \\axiom{\\spad{q}} is \\axiom{init(\\spad{b})}.")) (|monicModulo| (($ $ $) "\\axiom{monicModulo(a,{}\\spad{b})} computes \\axiom{a mod \\spad{b}},{} if \\axiom{\\spad{b}} is monic as univariate polynomial in its main variable.")) (|pseudoDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\axiom{pseudoDivide(a,{}\\spad{b})} computes \\axiom{[pquo(a,{}\\spad{b}),{}prem(a,{}\\spad{b})]},{} both polynomials viewed as univariate polynomials in the main variable of \\axiom{\\spad{b}},{} if \\axiom{\\spad{b}} is not a constant polynomial.")) (|lazyPseudoDivide| (((|Record| (|:| |coef| $) (|:| |gap| (|NonNegativeInteger|)) (|:| |quotient| $) (|:| |remainder| $)) $ $ |#4|) "\\axiom{lazyPseudoDivide(a,{}\\spad{b},{}\\spad{v})} returns \\axiom{[\\spad{c},{}\\spad{g},{}\\spad{q},{}\\spad{r}]} such that \\axiom{\\spad{r} = lazyPrem(a,{}\\spad{b},{}\\spad{v})},{} \\axiom{(c**g)\\spad{*r} = prem(a,{}\\spad{b},{}\\spad{v})} and \\axiom{\\spad{q}} is the pseudo-quotient computed in this lazy pseudo-division.") (((|Record| (|:| |coef| $) (|:| |gap| (|NonNegativeInteger|)) (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\axiom{lazyPseudoDivide(a,{}\\spad{b})} returns \\axiom{[\\spad{c},{}\\spad{g},{}\\spad{q},{}\\spad{r}]} such that \\axiom{[\\spad{c},{}\\spad{g},{}\\spad{r}] = lazyPremWithDefault(a,{}\\spad{b})} and \\axiom{\\spad{q}} is the pseudo-quotient computed in this lazy pseudo-division.")) (|lazyPremWithDefault| (((|Record| (|:| |coef| $) (|:| |gap| (|NonNegativeInteger|)) (|:| |remainder| $)) $ $ |#4|) "\\axiom{lazyPremWithDefault(a,{}\\spad{b},{}\\spad{v})} returns \\axiom{[\\spad{c},{}\\spad{g},{}\\spad{r}]} such that \\axiom{\\spad{r} = lazyPrem(a,{}\\spad{b},{}\\spad{v})} and \\axiom{(c**g)\\spad{*r} = prem(a,{}\\spad{b},{}\\spad{v})}.") (((|Record| (|:| |coef| $) (|:| |gap| (|NonNegativeInteger|)) (|:| |remainder| $)) $ $) "\\axiom{lazyPremWithDefault(a,{}\\spad{b})} returns \\axiom{[\\spad{c},{}\\spad{g},{}\\spad{r}]} such that \\axiom{\\spad{r} = lazyPrem(a,{}\\spad{b})} and \\axiom{(c**g)\\spad{*r} = prem(a,{}\\spad{b})}.")) (|lazyPquo| (($ $ $ |#4|) "\\axiom{lazyPquo(a,{}\\spad{b},{}\\spad{v})} returns the polynomial \\axiom{\\spad{q}} such that \\axiom{lazyPseudoDivide(a,{}\\spad{b},{}\\spad{v})} returns \\axiom{[\\spad{c},{}\\spad{g},{}\\spad{q},{}\\spad{r}]}.") (($ $ $) "\\axiom{lazyPquo(a,{}\\spad{b})} returns the polynomial \\axiom{\\spad{q}} such that \\axiom{lazyPseudoDivide(a,{}\\spad{b})} returns \\axiom{[\\spad{c},{}\\spad{g},{}\\spad{q},{}\\spad{r}]}.")) (|lazyPrem| (($ $ $ |#4|) "\\axiom{lazyPrem(a,{}\\spad{b},{}\\spad{v})} returns the polynomial \\axiom{\\spad{r}} reduced \\spad{w}.\\spad{r}.\\spad{t}. \\axiom{\\spad{b}} viewed as univariate polynomials in the variable \\axiom{\\spad{v}} such that \\axiom{\\spad{b}} divides \\axiom{init(\\spad{b})^e a - \\spad{r}} where \\axiom{\\spad{e}} is the number of steps of this pseudo-division.") (($ $ $) "\\axiom{lazyPrem(a,{}\\spad{b})} returns the polynomial \\axiom{\\spad{r}} reduced \\spad{w}.\\spad{r}.\\spad{t}. \\axiom{\\spad{b}} and such that \\axiom{\\spad{b}} divides \\axiom{init(\\spad{b})^e a - \\spad{r}} where \\axiom{\\spad{e}} is the number of steps of this pseudo-division.")) (|pquo| (($ $ $ |#4|) "\\axiom{pquo(a,{}\\spad{b},{}\\spad{v})} computes the pseudo-quotient of \\axiom{a} by \\axiom{\\spad{b}},{} both viewed as univariate polynomials in \\axiom{\\spad{v}}.") (($ $ $) "\\axiom{pquo(a,{}\\spad{b})} computes the pseudo-quotient of \\axiom{a} by \\axiom{\\spad{b}},{} both viewed as univariate polynomials in the main variable of \\axiom{\\spad{b}}.")) (|prem| (($ $ $ |#4|) "\\axiom{prem(a,{}\\spad{b},{}\\spad{v})} computes the pseudo-remainder of \\axiom{a} by \\axiom{\\spad{b}},{} both viewed as univariate polynomials in \\axiom{\\spad{v}}.") (($ $ $) "\\axiom{prem(a,{}\\spad{b})} computes the pseudo-remainder of \\axiom{a} by \\axiom{\\spad{b}},{} both viewed as univariate polynomials in the main variable of \\axiom{\\spad{b}}.")) (|normalized?| (((|Boolean|) $ (|List| $)) "\\axiom{normalized?(\\spad{q},{}\\spad{lp})} returns \\spad{true} iff \\axiom{normalized?(\\spad{q},{}\\spad{p})} holds for every \\axiom{\\spad{p}} in \\axiom{\\spad{lp}}.") (((|Boolean|) $ $) "\\axiom{normalized?(a,{}\\spad{b})} returns \\spad{true} iff \\axiom{a} and its iterated initials have degree zero \\spad{w}.\\spad{r}.\\spad{t}. the main variable of \\axiom{\\spad{b}}")) (|initiallyReduced?| (((|Boolean|) $ (|List| $)) "\\axiom{initiallyReduced?(\\spad{q},{}\\spad{lp})} returns \\spad{true} iff \\axiom{initiallyReduced?(\\spad{q},{}\\spad{p})} holds for every \\axiom{\\spad{p}} in \\axiom{\\spad{lp}}.") (((|Boolean|) $ $) "\\axiom{initiallyReduced?(a,{}\\spad{b})} returns \\spad{false} iff there exists an iterated initial of \\axiom{a} which is not reduced \\spad{w}.\\spad{r}.\\spad{t} \\axiom{\\spad{b}}.")) (|headReduced?| (((|Boolean|) $ (|List| $)) "\\axiom{headReduced?(\\spad{q},{}\\spad{lp})} returns \\spad{true} iff \\axiom{headReduced?(\\spad{q},{}\\spad{p})} holds for every \\axiom{\\spad{p}} in \\axiom{\\spad{lp}}.") (((|Boolean|) $ $) "\\axiom{headReduced?(a,{}\\spad{b})} returns \\spad{true} iff \\axiom{degree(head(a),{}mvar(\\spad{b})) < mdeg(\\spad{b})}.")) (|reduced?| (((|Boolean|) $ (|List| $)) "\\axiom{reduced?(\\spad{q},{}\\spad{lp})} returns \\spad{true} iff \\axiom{reduced?(\\spad{q},{}\\spad{p})} holds for every \\axiom{\\spad{p}} in \\axiom{\\spad{lp}}.") (((|Boolean|) $ $) "\\axiom{reduced?(a,{}\\spad{b})} returns \\spad{true} iff \\axiom{degree(a,{}mvar(\\spad{b})) < mdeg(\\spad{b})}.")) (|supRittWu?| (((|Boolean|) $ $) "\\axiom{supRittWu?(a,{}\\spad{b})} returns \\spad{true} if \\axiom{a} is greater than \\axiom{\\spad{b}} \\spad{w}.\\spad{r}.\\spad{t}. the Ritt and Wu Wen Tsun ordering using the refinement of Lazard.")) (|infRittWu?| (((|Boolean|) $ $) "\\axiom{infRittWu?(a,{}\\spad{b})} returns \\spad{true} if \\axiom{a} is less than \\axiom{\\spad{b}} \\spad{w}.\\spad{r}.\\spad{t}. the Ritt and Wu Wen Tsun ordering using the refinement of Lazard.")) (|RittWuCompare| (((|Union| (|Boolean|) "failed") $ $) "\\axiom{RittWuCompare(a,{}\\spad{b})} returns \\axiom{\"failed\"} if \\axiom{a} and \\axiom{\\spad{b}} have same rank \\spad{w}.\\spad{r}.\\spad{t}. Ritt and Wu Wen Tsun ordering using the refinement of Lazard,{} otherwise returns \\axiom{infRittWu?(a,{}\\spad{b})}.")) (|mainMonomials| (((|List| $) $) "\\axiom{mainMonomials(\\spad{p})} returns an error if \\axiom{\\spad{p}} is \\axiom{\\spad{O}},{} otherwise,{} if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}} returns [1],{} otherwise returns the list of the monomials of \\axiom{\\spad{p}},{} where \\axiom{\\spad{p}} is viewed as a univariate polynomial in its main variable.")) (|mainCoefficients| (((|List| $) $) "\\axiom{mainCoefficients(\\spad{p})} returns an error if \\axiom{\\spad{p}} is \\axiom{\\spad{O}},{} otherwise,{} if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}} returns [\\spad{p}],{} otherwise returns the list of the coefficients of \\axiom{\\spad{p}},{} where \\axiom{\\spad{p}} is viewed as a univariate polynomial in its main variable.")) (|leastMonomial| (($ $) "\\axiom{leastMonomial(\\spad{p})} returns an error if \\axiom{\\spad{p}} is \\axiom{\\spad{O}},{} otherwise,{} if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}} returns \\axiom{1},{} otherwise,{} the monomial of \\axiom{\\spad{p}} with lowest degree,{} where \\axiom{\\spad{p}} is viewed as a univariate polynomial in its main variable.")) (|mainMonomial| (($ $) "\\axiom{mainMonomial(\\spad{p})} returns an error if \\axiom{\\spad{p}} is \\axiom{\\spad{O}},{} otherwise,{} if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}} returns \\axiom{1},{} otherwise,{} \\axiom{mvar(\\spad{p})} raised to the power \\axiom{mdeg(\\spad{p})}.")) (|quasiMonic?| (((|Boolean|) $) "\\axiom{quasiMonic?(\\spad{p})} returns \\spad{false} if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}},{} otherwise returns \\spad{true} iff the initial of \\axiom{\\spad{p}} lies in the base ring \\axiom{\\spad{R}}.")) (|monic?| (((|Boolean|) $) "\\axiom{monic?(\\spad{p})} returns \\spad{false} if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}},{} otherwise returns \\spad{true} iff \\axiom{\\spad{p}} is monic as a univariate polynomial in its main variable.")) (|reductum| (($ $ |#4|) "\\axiom{reductum(\\spad{p},{}\\spad{v})} returns the reductum of \\axiom{\\spad{p}},{} where \\axiom{\\spad{p}} is viewed as a univariate polynomial in \\axiom{\\spad{v}}.")) (|leadingCoefficient| (($ $ |#4|) "\\axiom{leadingCoefficient(\\spad{p},{}\\spad{v})} returns the leading coefficient of \\axiom{\\spad{p}},{} where \\axiom{\\spad{p}} is viewed as A univariate polynomial in \\axiom{\\spad{v}}.")) (|deepestInitial| (($ $) "\\axiom{deepestInitial(\\spad{p})} returns an error if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}},{} otherwise returns the last term of \\axiom{iteratedInitials(\\spad{p})}.")) (|iteratedInitials| (((|List| $) $) "\\axiom{iteratedInitials(\\spad{p})} returns \\axiom{[]} if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}},{} otherwise returns the list of the iterated initials of \\axiom{\\spad{p}}.")) (|deepestTail| (($ $) "\\axiom{deepestTail(\\spad{p})} returns \\axiom{0} if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}},{} otherwise returns tail(\\spad{p}),{} if \\axiom{tail(\\spad{p})} belongs to \\axiom{\\spad{R}} or \\axiom{mvar(tail(\\spad{p})) < mvar(\\spad{p})},{} otherwise returns \\axiom{deepestTail(tail(\\spad{p}))}.")) (|tail| (($ $) "\\axiom{tail(\\spad{p})} returns its reductum,{} where \\axiom{\\spad{p}} is viewed as a univariate polynomial in its main variable.")) (|head| (($ $) "\\axiom{head(\\spad{p})} returns \\axiom{\\spad{p}} if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}},{} otherwise returns its leading term (monomial in the AXIOM sense),{} where \\axiom{\\spad{p}} is viewed as a univariate polynomial \\indented{1}{in its main variable.}")) (|init| (($ $) "\\axiom{init(\\spad{p})} returns an error if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}},{} otherwise returns its leading coefficient,{} where \\axiom{\\spad{p}} is viewed as a univariate polynomial in its main variable.")) (|mdeg| (((|NonNegativeInteger|) $) "\\axiom{mdeg(\\spad{p})} returns an error if \\axiom{\\spad{p}} is \\axiom{0},{} otherwise,{} if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}} returns \\axiom{0},{} otherwise,{} returns the degree of \\axiom{\\spad{p}} in its main variable.")) (|mvar| ((|#4| $) "\\axiom{mvar(\\spad{p})} returns an error if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}},{} otherwise returns its main variable \\spad{w}. \\spad{r}. \\spad{t}. to the total ordering on the elements in \\axiom{\\spad{V}}."))) 
 NIL 
 ((|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-550))) (|HasCategory| |#2| (LIST (QUOTE -43) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -993) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#4| (LIST (QUOTE -609) (QUOTE (-1161))))) 
 (-1061 R E V) 
 ((|constructor| (NIL "A category for general multi-variate polynomials with coefficients in a ring,{} variables in an ordered set,{} and exponents from an ordered abelian monoid,{} with a \\axiomOp{sup} operation. When not constant,{} such a polynomial is viewed as a univariate polynomial in its main variable \\spad{w}. \\spad{r}. \\spad{t}. to the total ordering on the elements in the ordered set,{} so that some operations usually defined for univariate polynomials make sense here.")) (|mainSquareFreePart| (($ $) "\\axiom{mainSquareFreePart(\\spad{p})} returns the square free part of \\axiom{\\spad{p}} viewed as a univariate polynomial in its main variable and with coefficients in the polynomial ring generated by its other variables over \\axiom{\\spad{R}}.")) (|mainPrimitivePart| (($ $) "\\axiom{mainPrimitivePart(\\spad{p})} returns the primitive part of \\axiom{\\spad{p}} viewed as a univariate polynomial in its main variable and with coefficients in the polynomial ring generated by its other variables over \\axiom{\\spad{R}}.")) (|mainContent| (($ $) "\\axiom{mainContent(\\spad{p})} returns the content of \\axiom{\\spad{p}} viewed as a univariate polynomial in its main variable and with coefficients in the polynomial ring generated by its other variables over \\axiom{\\spad{R}}.")) (|primitivePart!| (($ $) "\\axiom{primitivePart!(\\spad{p})} replaces \\axiom{\\spad{p}} by its primitive part.")) (|gcd| ((|#1| |#1| $) "\\axiom{\\spad{gcd}(\\spad{r},{}\\spad{p})} returns the \\spad{gcd} of \\axiom{\\spad{r}} and the content of \\axiom{\\spad{p}}.")) (|nextsubResultant2| (($ $ $ $ $) "\\axiom{\\spad{nextsubResultant2}(\\spad{p},{}\\spad{q},{}\\spad{z},{}\\spad{s})} is the multivariate version of the operation \\spad{next_sousResultant2} from PseudoRemainderSequence from the \\axiomType{PseudoRemainderSequence} constructor.")) (|LazardQuotient2| (($ $ $ $ (|NonNegativeInteger|)) "\\axiom{\\spad{LazardQuotient2}(\\spad{p},{}a,{}\\spad{b},{}\\spad{n})} returns \\axiom{(a**(\\spad{n}-1) * \\spad{p}) exquo \\spad{b**}(\\spad{n}-1)} assuming that this quotient does not fail.")) (|LazardQuotient| (($ $ $ (|NonNegativeInteger|)) "\\axiom{LazardQuotient(a,{}\\spad{b},{}\\spad{n})} returns \\axiom{a**n exquo \\spad{b**}(\\spad{n}-1)} assuming that this quotient does not fail.")) (|lastSubResultant| (($ $ $) "\\axiom{lastSubResultant(a,{}\\spad{b})} returns the last non-zero subresultant of \\axiom{a} and \\axiom{\\spad{b}} where \\axiom{a} and \\axiom{\\spad{b}} are assumed to have the same main variable \\axiom{\\spad{v}} and are viewed as univariate polynomials in \\axiom{\\spad{v}}.")) (|subResultantChain| (((|List| $) $ $) "\\axiom{subResultantChain(a,{}\\spad{b})},{} where \\axiom{a} and \\axiom{\\spad{b}} are not contant polynomials with the same main variable,{} returns the subresultant chain of \\axiom{a} and \\axiom{\\spad{b}}.")) (|resultant| (($ $ $) "\\axiom{resultant(a,{}\\spad{b})} computes the resultant of \\axiom{a} and \\axiom{\\spad{b}} where \\axiom{a} and \\axiom{\\spad{b}} are assumed to have the same main variable \\axiom{\\spad{v}} and are viewed as univariate polynomials in \\axiom{\\spad{v}}.")) (|halfExtendedSubResultantGcd2| (((|Record| (|:| |gcd| $) (|:| |coef2| $)) $ $) "\\axiom{\\spad{halfExtendedSubResultantGcd2}(a,{}\\spad{b})} returns \\axiom{[\\spad{g},{}\\spad{cb}]} if \\axiom{extendedSubResultantGcd(a,{}\\spad{b})} returns \\axiom{[\\spad{g},{}ca,{}\\spad{cb}]} otherwise produces an error.")) (|halfExtendedSubResultantGcd1| (((|Record| (|:| |gcd| $) (|:| |coef1| $)) $ $) "\\axiom{\\spad{halfExtendedSubResultantGcd1}(a,{}\\spad{b})} returns \\axiom{[\\spad{g},{}ca]} if \\axiom{extendedSubResultantGcd(a,{}\\spad{b})} returns \\axiom{[\\spad{g},{}ca,{}\\spad{cb}]} otherwise produces an error.")) (|extendedSubResultantGcd| (((|Record| (|:| |gcd| $) (|:| |coef1| $) (|:| |coef2| $)) $ $) "\\axiom{extendedSubResultantGcd(a,{}\\spad{b})} returns \\axiom{[ca,{}\\spad{cb},{}\\spad{r}]} such that \\axiom{\\spad{r}} is \\axiom{subResultantGcd(a,{}\\spad{b})} and we have \\axiom{ca * a + \\spad{cb} * \\spad{cb} = \\spad{r}} .")) (|subResultantGcd| (($ $ $) "\\axiom{subResultantGcd(a,{}\\spad{b})} computes a \\spad{gcd} of \\axiom{a} and \\axiom{\\spad{b}} where \\axiom{a} and \\axiom{\\spad{b}} are assumed to have the same main variable \\axiom{\\spad{v}} and are viewed as univariate polynomials in \\axiom{\\spad{v}} with coefficients in the fraction field of the polynomial ring generated by their other variables over \\axiom{\\spad{R}}.")) (|exactQuotient!| (($ $ $) "\\axiom{exactQuotient!(a,{}\\spad{b})} replaces \\axiom{a} by \\axiom{exactQuotient(a,{}\\spad{b})}") (($ $ |#1|) "\\axiom{exactQuotient!(\\spad{p},{}\\spad{r})} replaces \\axiom{\\spad{p}} by \\axiom{exactQuotient(\\spad{p},{}\\spad{r})}.")) (|exactQuotient| (($ $ $) "\\axiom{exactQuotient(a,{}\\spad{b})} computes the exact quotient of \\axiom{a} by \\axiom{\\spad{b}},{} which is assumed to be a divisor of \\axiom{a}. No error is returned if this exact quotient fails!") (($ $ |#1|) "\\axiom{exactQuotient(\\spad{p},{}\\spad{r})} computes the exact quotient of \\axiom{\\spad{p}} by \\axiom{\\spad{r}},{} which is assumed to be a divisor of \\axiom{\\spad{p}}. No error is returned if this exact quotient fails!")) (|primPartElseUnitCanonical!| (($ $) "\\axiom{primPartElseUnitCanonical!(\\spad{p})} replaces \\axiom{\\spad{p}} by \\axiom{primPartElseUnitCanonical(\\spad{p})}.")) (|primPartElseUnitCanonical| (($ $) "\\axiom{primPartElseUnitCanonical(\\spad{p})} returns \\axiom{primitivePart(\\spad{p})} if \\axiom{\\spad{R}} is a \\spad{gcd}-domain,{} otherwise \\axiom{unitCanonical(\\spad{p})}.")) (|convert| (($ (|Polynomial| |#1|)) "\\axiom{convert(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if all its variables belong to \\axiom{\\spad{V}},{} otherwise an error is produced.") (($ (|Polynomial| (|Integer|))) "\\axiom{convert(\\spad{p})} returns the same as \\axiom{retract(\\spad{p})}.") (($ (|Polynomial| (|Integer|))) "\\axiom{convert(\\spad{p})} returns the same as \\axiom{retract(\\spad{p})}") (($ (|Polynomial| (|Fraction| (|Integer|)))) "\\axiom{convert(\\spad{p})} returns the same as \\axiom{retract(\\spad{p})}.")) (|retract| (($ (|Polynomial| |#1|)) "\\axiom{retract(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if \\axiom{retractIfCan(\\spad{p})} does not return \"failed\",{} otherwise an error is produced.") (($ (|Polynomial| |#1|)) "\\axiom{retract(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if \\axiom{retractIfCan(\\spad{p})} does not return \"failed\",{} otherwise an error is produced.") (($ (|Polynomial| (|Integer|))) "\\axiom{retract(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if \\axiom{retractIfCan(\\spad{p})} does not return \"failed\",{} otherwise an error is produced.") (($ (|Polynomial| |#1|)) "\\axiom{retract(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if \\axiom{retractIfCan(\\spad{p})} does not return \"failed\",{} otherwise an error is produced.") (($ (|Polynomial| (|Integer|))) "\\axiom{retract(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if \\axiom{retractIfCan(\\spad{p})} does not return \"failed\",{} otherwise an error is produced.") (($ (|Polynomial| (|Fraction| (|Integer|)))) "\\axiom{retract(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if \\axiom{retractIfCan(\\spad{p})} does not return \"failed\",{} otherwise an error is produced.")) (|retractIfCan| (((|Union| $ "failed") (|Polynomial| |#1|)) "\\axiom{retractIfCan(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if all its variables belong to \\axiom{\\spad{V}}.") (((|Union| $ "failed") (|Polynomial| |#1|)) "\\axiom{retractIfCan(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if all its variables belong to \\axiom{\\spad{V}}.") (((|Union| $ "failed") (|Polynomial| (|Integer|))) "\\axiom{retractIfCan(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if all its variables belong to \\axiom{\\spad{V}}.") (((|Union| $ "failed") (|Polynomial| |#1|)) "\\axiom{retractIfCan(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if all its variables belong to \\axiom{\\spad{V}}.") (((|Union| $ "failed") (|Polynomial| (|Integer|))) "\\axiom{retractIfCan(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if all its variables belong to \\axiom{\\spad{V}}.") (((|Union| $ "failed") (|Polynomial| (|Fraction| (|Integer|)))) "\\axiom{retractIfCan(\\spad{p})} returns \\axiom{\\spad{p}} as an element of the current domain if all its variables belong to \\axiom{\\spad{V}}.")) (|initiallyReduce| (($ $ $) "\\axiom{initiallyReduce(a,{}\\spad{b})} returns a polynomial \\axiom{\\spad{r}} such that \\axiom{initiallyReduced?(\\spad{r},{}\\spad{b})} holds and there exists an integer \\axiom{\\spad{e}} such that \\axiom{init(\\spad{b})^e a - \\spad{r}} is zero modulo \\axiom{\\spad{b}}.")) (|headReduce| (($ $ $) "\\axiom{headReduce(a,{}\\spad{b})} returns a polynomial \\axiom{\\spad{r}} such that \\axiom{headReduced?(\\spad{r},{}\\spad{b})} holds and there exists an integer \\axiom{\\spad{e}} such that \\axiom{init(\\spad{b})^e a - \\spad{r}} is zero modulo \\axiom{\\spad{b}}.")) (|lazyResidueClass| (((|Record| (|:| |polnum| $) (|:| |polden| $) (|:| |power| (|NonNegativeInteger|))) $ $) "\\axiom{lazyResidueClass(a,{}\\spad{b})} returns \\axiom{[\\spad{p},{}\\spad{q},{}\\spad{n}]} where \\axiom{\\spad{p} / q**n} represents the residue class of \\axiom{a} modulo \\axiom{\\spad{b}} and \\axiom{\\spad{p}} is reduced \\spad{w}.\\spad{r}.\\spad{t}. \\axiom{\\spad{b}} and \\axiom{\\spad{q}} is \\axiom{init(\\spad{b})}.")) (|monicModulo| (($ $ $) "\\axiom{monicModulo(a,{}\\spad{b})} computes \\axiom{a mod \\spad{b}},{} if \\axiom{\\spad{b}} is monic as univariate polynomial in its main variable.")) (|pseudoDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\axiom{pseudoDivide(a,{}\\spad{b})} computes \\axiom{[pquo(a,{}\\spad{b}),{}prem(a,{}\\spad{b})]},{} both polynomials viewed as univariate polynomials in the main variable of \\axiom{\\spad{b}},{} if \\axiom{\\spad{b}} is not a constant polynomial.")) (|lazyPseudoDivide| (((|Record| (|:| |coef| $) (|:| |gap| (|NonNegativeInteger|)) (|:| |quotient| $) (|:| |remainder| $)) $ $ |#3|) "\\axiom{lazyPseudoDivide(a,{}\\spad{b},{}\\spad{v})} returns \\axiom{[\\spad{c},{}\\spad{g},{}\\spad{q},{}\\spad{r}]} such that \\axiom{\\spad{r} = lazyPrem(a,{}\\spad{b},{}\\spad{v})},{} \\axiom{(c**g)\\spad{*r} = prem(a,{}\\spad{b},{}\\spad{v})} and \\axiom{\\spad{q}} is the pseudo-quotient computed in this lazy pseudo-division.") (((|Record| (|:| |coef| $) (|:| |gap| (|NonNegativeInteger|)) (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\axiom{lazyPseudoDivide(a,{}\\spad{b})} returns \\axiom{[\\spad{c},{}\\spad{g},{}\\spad{q},{}\\spad{r}]} such that \\axiom{[\\spad{c},{}\\spad{g},{}\\spad{r}] = lazyPremWithDefault(a,{}\\spad{b})} and \\axiom{\\spad{q}} is the pseudo-quotient computed in this lazy pseudo-division.")) (|lazyPremWithDefault| (((|Record| (|:| |coef| $) (|:| |gap| (|NonNegativeInteger|)) (|:| |remainder| $)) $ $ |#3|) "\\axiom{lazyPremWithDefault(a,{}\\spad{b},{}\\spad{v})} returns \\axiom{[\\spad{c},{}\\spad{g},{}\\spad{r}]} such that \\axiom{\\spad{r} = lazyPrem(a,{}\\spad{b},{}\\spad{v})} and \\axiom{(c**g)\\spad{*r} = prem(a,{}\\spad{b},{}\\spad{v})}.") (((|Record| (|:| |coef| $) (|:| |gap| (|NonNegativeInteger|)) (|:| |remainder| $)) $ $) "\\axiom{lazyPremWithDefault(a,{}\\spad{b})} returns \\axiom{[\\spad{c},{}\\spad{g},{}\\spad{r}]} such that \\axiom{\\spad{r} = lazyPrem(a,{}\\spad{b})} and \\axiom{(c**g)\\spad{*r} = prem(a,{}\\spad{b})}.")) (|lazyPquo| (($ $ $ |#3|) "\\axiom{lazyPquo(a,{}\\spad{b},{}\\spad{v})} returns the polynomial \\axiom{\\spad{q}} such that \\axiom{lazyPseudoDivide(a,{}\\spad{b},{}\\spad{v})} returns \\axiom{[\\spad{c},{}\\spad{g},{}\\spad{q},{}\\spad{r}]}.") (($ $ $) "\\axiom{lazyPquo(a,{}\\spad{b})} returns the polynomial \\axiom{\\spad{q}} such that \\axiom{lazyPseudoDivide(a,{}\\spad{b})} returns \\axiom{[\\spad{c},{}\\spad{g},{}\\spad{q},{}\\spad{r}]}.")) (|lazyPrem| (($ $ $ |#3|) "\\axiom{lazyPrem(a,{}\\spad{b},{}\\spad{v})} returns the polynomial \\axiom{\\spad{r}} reduced \\spad{w}.\\spad{r}.\\spad{t}. \\axiom{\\spad{b}} viewed as univariate polynomials in the variable \\axiom{\\spad{v}} such that \\axiom{\\spad{b}} divides \\axiom{init(\\spad{b})^e a - \\spad{r}} where \\axiom{\\spad{e}} is the number of steps of this pseudo-division.") (($ $ $) "\\axiom{lazyPrem(a,{}\\spad{b})} returns the polynomial \\axiom{\\spad{r}} reduced \\spad{w}.\\spad{r}.\\spad{t}. \\axiom{\\spad{b}} and such that \\axiom{\\spad{b}} divides \\axiom{init(\\spad{b})^e a - \\spad{r}} where \\axiom{\\spad{e}} is the number of steps of this pseudo-division.")) (|pquo| (($ $ $ |#3|) "\\axiom{pquo(a,{}\\spad{b},{}\\spad{v})} computes the pseudo-quotient of \\axiom{a} by \\axiom{\\spad{b}},{} both viewed as univariate polynomials in \\axiom{\\spad{v}}.") (($ $ $) "\\axiom{pquo(a,{}\\spad{b})} computes the pseudo-quotient of \\axiom{a} by \\axiom{\\spad{b}},{} both viewed as univariate polynomials in the main variable of \\axiom{\\spad{b}}.")) (|prem| (($ $ $ |#3|) "\\axiom{prem(a,{}\\spad{b},{}\\spad{v})} computes the pseudo-remainder of \\axiom{a} by \\axiom{\\spad{b}},{} both viewed as univariate polynomials in \\axiom{\\spad{v}}.") (($ $ $) "\\axiom{prem(a,{}\\spad{b})} computes the pseudo-remainder of \\axiom{a} by \\axiom{\\spad{b}},{} both viewed as univariate polynomials in the main variable of \\axiom{\\spad{b}}.")) (|normalized?| (((|Boolean|) $ (|List| $)) "\\axiom{normalized?(\\spad{q},{}\\spad{lp})} returns \\spad{true} iff \\axiom{normalized?(\\spad{q},{}\\spad{p})} holds for every \\axiom{\\spad{p}} in \\axiom{\\spad{lp}}.") (((|Boolean|) $ $) "\\axiom{normalized?(a,{}\\spad{b})} returns \\spad{true} iff \\axiom{a} and its iterated initials have degree zero \\spad{w}.\\spad{r}.\\spad{t}. the main variable of \\axiom{\\spad{b}}")) (|initiallyReduced?| (((|Boolean|) $ (|List| $)) "\\axiom{initiallyReduced?(\\spad{q},{}\\spad{lp})} returns \\spad{true} iff \\axiom{initiallyReduced?(\\spad{q},{}\\spad{p})} holds for every \\axiom{\\spad{p}} in \\axiom{\\spad{lp}}.") (((|Boolean|) $ $) "\\axiom{initiallyReduced?(a,{}\\spad{b})} returns \\spad{false} iff there exists an iterated initial of \\axiom{a} which is not reduced \\spad{w}.\\spad{r}.\\spad{t} \\axiom{\\spad{b}}.")) (|headReduced?| (((|Boolean|) $ (|List| $)) "\\axiom{headReduced?(\\spad{q},{}\\spad{lp})} returns \\spad{true} iff \\axiom{headReduced?(\\spad{q},{}\\spad{p})} holds for every \\axiom{\\spad{p}} in \\axiom{\\spad{lp}}.") (((|Boolean|) $ $) "\\axiom{headReduced?(a,{}\\spad{b})} returns \\spad{true} iff \\axiom{degree(head(a),{}mvar(\\spad{b})) < mdeg(\\spad{b})}.")) (|reduced?| (((|Boolean|) $ (|List| $)) "\\axiom{reduced?(\\spad{q},{}\\spad{lp})} returns \\spad{true} iff \\axiom{reduced?(\\spad{q},{}\\spad{p})} holds for every \\axiom{\\spad{p}} in \\axiom{\\spad{lp}}.") (((|Boolean|) $ $) "\\axiom{reduced?(a,{}\\spad{b})} returns \\spad{true} iff \\axiom{degree(a,{}mvar(\\spad{b})) < mdeg(\\spad{b})}.")) (|supRittWu?| (((|Boolean|) $ $) "\\axiom{supRittWu?(a,{}\\spad{b})} returns \\spad{true} if \\axiom{a} is greater than \\axiom{\\spad{b}} \\spad{w}.\\spad{r}.\\spad{t}. the Ritt and Wu Wen Tsun ordering using the refinement of Lazard.")) (|infRittWu?| (((|Boolean|) $ $) "\\axiom{infRittWu?(a,{}\\spad{b})} returns \\spad{true} if \\axiom{a} is less than \\axiom{\\spad{b}} \\spad{w}.\\spad{r}.\\spad{t}. the Ritt and Wu Wen Tsun ordering using the refinement of Lazard.")) (|RittWuCompare| (((|Union| (|Boolean|) "failed") $ $) "\\axiom{RittWuCompare(a,{}\\spad{b})} returns \\axiom{\"failed\"} if \\axiom{a} and \\axiom{\\spad{b}} have same rank \\spad{w}.\\spad{r}.\\spad{t}. Ritt and Wu Wen Tsun ordering using the refinement of Lazard,{} otherwise returns \\axiom{infRittWu?(a,{}\\spad{b})}.")) (|mainMonomials| (((|List| $) $) "\\axiom{mainMonomials(\\spad{p})} returns an error if \\axiom{\\spad{p}} is \\axiom{\\spad{O}},{} otherwise,{} if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}} returns [1],{} otherwise returns the list of the monomials of \\axiom{\\spad{p}},{} where \\axiom{\\spad{p}} is viewed as a univariate polynomial in its main variable.")) (|mainCoefficients| (((|List| $) $) "\\axiom{mainCoefficients(\\spad{p})} returns an error if \\axiom{\\spad{p}} is \\axiom{\\spad{O}},{} otherwise,{} if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}} returns [\\spad{p}],{} otherwise returns the list of the coefficients of \\axiom{\\spad{p}},{} where \\axiom{\\spad{p}} is viewed as a univariate polynomial in its main variable.")) (|leastMonomial| (($ $) "\\axiom{leastMonomial(\\spad{p})} returns an error if \\axiom{\\spad{p}} is \\axiom{\\spad{O}},{} otherwise,{} if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}} returns \\axiom{1},{} otherwise,{} the monomial of \\axiom{\\spad{p}} with lowest degree,{} where \\axiom{\\spad{p}} is viewed as a univariate polynomial in its main variable.")) (|mainMonomial| (($ $) "\\axiom{mainMonomial(\\spad{p})} returns an error if \\axiom{\\spad{p}} is \\axiom{\\spad{O}},{} otherwise,{} if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}} returns \\axiom{1},{} otherwise,{} \\axiom{mvar(\\spad{p})} raised to the power \\axiom{mdeg(\\spad{p})}.")) (|quasiMonic?| (((|Boolean|) $) "\\axiom{quasiMonic?(\\spad{p})} returns \\spad{false} if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}},{} otherwise returns \\spad{true} iff the initial of \\axiom{\\spad{p}} lies in the base ring \\axiom{\\spad{R}}.")) (|monic?| (((|Boolean|) $) "\\axiom{monic?(\\spad{p})} returns \\spad{false} if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}},{} otherwise returns \\spad{true} iff \\axiom{\\spad{p}} is monic as a univariate polynomial in its main variable.")) (|reductum| (($ $ |#3|) "\\axiom{reductum(\\spad{p},{}\\spad{v})} returns the reductum of \\axiom{\\spad{p}},{} where \\axiom{\\spad{p}} is viewed as a univariate polynomial in \\axiom{\\spad{v}}.")) (|leadingCoefficient| (($ $ |#3|) "\\axiom{leadingCoefficient(\\spad{p},{}\\spad{v})} returns the leading coefficient of \\axiom{\\spad{p}},{} where \\axiom{\\spad{p}} is viewed as A univariate polynomial in \\axiom{\\spad{v}}.")) (|deepestInitial| (($ $) "\\axiom{deepestInitial(\\spad{p})} returns an error if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}},{} otherwise returns the last term of \\axiom{iteratedInitials(\\spad{p})}.")) (|iteratedInitials| (((|List| $) $) "\\axiom{iteratedInitials(\\spad{p})} returns \\axiom{[]} if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}},{} otherwise returns the list of the iterated initials of \\axiom{\\spad{p}}.")) (|deepestTail| (($ $) "\\axiom{deepestTail(\\spad{p})} returns \\axiom{0} if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}},{} otherwise returns tail(\\spad{p}),{} if \\axiom{tail(\\spad{p})} belongs to \\axiom{\\spad{R}} or \\axiom{mvar(tail(\\spad{p})) < mvar(\\spad{p})},{} otherwise returns \\axiom{deepestTail(tail(\\spad{p}))}.")) (|tail| (($ $) "\\axiom{tail(\\spad{p})} returns its reductum,{} where \\axiom{\\spad{p}} is viewed as a univariate polynomial in its main variable.")) (|head| (($ $) "\\axiom{head(\\spad{p})} returns \\axiom{\\spad{p}} if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}},{} otherwise returns its leading term (monomial in the AXIOM sense),{} where \\axiom{\\spad{p}} is viewed as a univariate polynomial \\indented{1}{in its main variable.}")) (|init| (($ $) "\\axiom{init(\\spad{p})} returns an error if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}},{} otherwise returns its leading coefficient,{} where \\axiom{\\spad{p}} is viewed as a univariate polynomial in its main variable.")) (|mdeg| (((|NonNegativeInteger|) $) "\\axiom{mdeg(\\spad{p})} returns an error if \\axiom{\\spad{p}} is \\axiom{0},{} otherwise,{} if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}} returns \\axiom{0},{} otherwise,{} returns the degree of \\axiom{\\spad{p}} in its main variable.")) (|mvar| ((|#3| $) "\\axiom{mvar(\\spad{p})} returns an error if \\axiom{\\spad{p}} belongs to \\axiom{\\spad{R}},{} otherwise returns its main variable \\spad{w}. \\spad{r}. \\spad{t}. to the total ordering on the elements in \\axiom{\\spad{V}}."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-6 -4517)) (-4514 . T) (-4513 . T) (-4516 . T)) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-6 -4519)) (-4516 . T) (-4515 . T) (-4518 . T)) 
 NIL 
 (-1062 S |TheField| |ThePols|) 
 ((|constructor| (NIL "\\axiomType{RealRootCharacterizationCategory} provides common acces functions for all real root codings.")) (|relativeApprox| ((|#2| |#3| $ |#2|) "\\axiom{approximate(term,{}root,{}prec)} gives an approximation of \\axiom{term} over \\axiom{root} with precision \\axiom{prec}")) (|approximate| ((|#2| |#3| $ |#2|) "\\axiom{approximate(term,{}root,{}prec)} gives an approximation of \\axiom{term} over \\axiom{root} with precision \\axiom{prec}")) (|rootOf| (((|Union| $ "failed") |#3| (|PositiveInteger|)) "\\axiom{rootOf(pol,{}\\spad{n})} gives the \\spad{n}th root for the order of the Real Closure")) (|allRootsOf| (((|List| $) |#3|) "\\axiom{allRootsOf(pol)} creates all the roots of \\axiom{pol} in the Real Closure,{} assumed in order.")) (|definingPolynomial| ((|#3| $) "\\axiom{definingPolynomial(aRoot)} gives a polynomial such that \\axiom{definingPolynomial(aRoot).aRoot = 0}")) (|recip| (((|Union| |#3| "failed") |#3| $) "\\axiom{recip(pol,{}aRoot)} tries to inverse \\axiom{pol} interpreted as \\axiom{aRoot}")) (|positive?| (((|Boolean|) |#3| $) "\\axiom{positive?(pol,{}aRoot)} answers if \\axiom{pol} interpreted as \\axiom{aRoot} is positive")) (|negative?| (((|Boolean|) |#3| $) "\\axiom{negative?(pol,{}aRoot)} answers if \\axiom{pol} interpreted as \\axiom{aRoot} is negative")) (|zero?| (((|Boolean|) |#3| $) "\\axiom{zero?(pol,{}aRoot)} answers if \\axiom{pol} interpreted as \\axiom{aRoot} is \\axiom{0}")) (|sign| (((|Integer|) |#3| $) "\\axiom{sign(pol,{}aRoot)} gives the sign of \\axiom{pol} interpreted as \\axiom{aRoot}"))) 
@@ -4194,7 +4194,7 @@ NIL
 NIL 
 (-1066 R E V P) 
 ((|constructor| (NIL "The category of regular triangular sets,{} introduced under the name regular chains in [1] (and other papers). In [3] it is proved that regular triangular sets and towers of simple extensions of a field are equivalent notions. In the following definitions,{} all polynomials and ideals are taken from the polynomial ring \\spad{k[x1,{}...,{}xn]} where \\spad{k} is the fraction field of \\spad{R}. The triangular set \\spad{[t1,{}...,{}tm]} is regular iff for every \\spad{i} the initial of \\spad{ti+1} is invertible in the tower of simple extensions associated with \\spad{[t1,{}...,{}\\spad{ti}]}. A family \\spad{[T1,{}...,{}Ts]} of regular triangular sets is a split of Kalkbrener of a given ideal \\spad{I} iff the radical of \\spad{I} is equal to the intersection of the radical ideals generated by the saturated ideals of the \\spad{[T1,{}...,{}\\spad{Ti}]}. A family \\spad{[T1,{}...,{}Ts]} of regular triangular sets is a split of Kalkbrener of a given triangular set \\spad{T} iff it is a split of Kalkbrener of the saturated ideal of \\spad{T}. Let \\spad{K} be an algebraic closure of \\spad{k}. Assume that \\spad{V} is finite with cardinality \\spad{n} and let \\spad{A} be the affine space \\spad{K^n}. For a regular triangular set \\spad{T} let denote by \\spad{W(T)} the set of regular zeros of \\spad{T}. A family \\spad{[T1,{}...,{}Ts]} of regular triangular sets is a split of Lazard of a given subset \\spad{S} of \\spad{A} iff the union of the \\spad{W(\\spad{Ti})} contains \\spad{S} and is contained in the closure of \\spad{S} (\\spad{w}.\\spad{r}.\\spad{t}. Zariski topology). A family \\spad{[T1,{}...,{}Ts]} of regular triangular sets is a split of Lazard of a given triangular set \\spad{T} if it is a split of Lazard of \\spad{W(T)}. Note that if \\spad{[T1,{}...,{}Ts]} is a split of Lazard of \\spad{T} then it is also a split of Kalkbrener of \\spad{T}. The converse is \\spad{false}. This category provides operations related to both kinds of splits,{} the former being related to ideals decomposition whereas the latter deals with varieties decomposition. See the example illustrating the RegularTriangularSet constructor for more explanations about decompositions by means of regular triangular sets.")) (|zeroSetSplit| (((|List| $) (|List| |#4|) (|Boolean|)) "\\spad{zeroSetSplit(lp,{}clos?)} returns \\spad{lts} a split of Kalkbrener of the radical ideal associated with \\spad{lp}. If \\spad{clos?} is \\spad{false},{} it is also a decomposition of the variety associated with \\spad{lp} into the regular zero set of the \\spad{ts} in \\spad{lts} (or,{} in other words,{} a split of Lazard of this variety). See the example illustrating the \\spadtype{RegularTriangularSet} constructor for more explanations about decompositions by means of regular triangular sets.")) (|extend| (((|List| $) (|List| |#4|) (|List| $)) "\\spad{extend(lp,{}lts)} returns the same as \\spad{concat([extend(lp,{}ts) for ts in lts])|}") (((|List| $) (|List| |#4|) $) "\\spad{extend(lp,{}ts)} returns \\spad{ts} if \\spad{empty? lp} \\spad{extend(p,{}ts)} if \\spad{lp = [p]} else \\spad{extend(first lp,{} extend(rest lp,{} ts))}") (((|List| $) |#4| (|List| $)) "\\spad{extend(p,{}lts)} returns the same as \\spad{concat([extend(p,{}ts) for ts in lts])|}") (((|List| $) |#4| $) "\\spad{extend(p,{}ts)} assumes that \\spad{p} is a non-constant polynomial whose main variable is greater than any variable of \\spad{ts}. Then it returns a split of Kalkbrener of \\spad{ts+p}. This may not be \\spad{ts+p} itself,{} if for instance \\spad{ts+p} is not a regular triangular set.")) (|internalAugment| (($ (|List| |#4|) $) "\\spad{internalAugment(lp,{}ts)} returns \\spad{ts} if \\spad{lp} is empty otherwise returns \\spad{internalAugment(rest lp,{} internalAugment(first lp,{} ts))}") (($ |#4| $) "\\spad{internalAugment(p,{}ts)} assumes that \\spad{augment(p,{}ts)} returns a singleton and returns it.")) (|augment| (((|List| $) (|List| |#4|) (|List| $)) "\\spad{augment(lp,{}lts)} returns the same as \\spad{concat([augment(lp,{}ts) for ts in lts])}") (((|List| $) (|List| |#4|) $) "\\spad{augment(lp,{}ts)} returns \\spad{ts} if \\spad{empty? lp},{} \\spad{augment(p,{}ts)} if \\spad{lp = [p]},{} otherwise \\spad{augment(first lp,{} augment(rest lp,{} ts))}") (((|List| $) |#4| (|List| $)) "\\spad{augment(p,{}lts)} returns the same as \\spad{concat([augment(p,{}ts) for ts in lts])}") (((|List| $) |#4| $) "\\spad{augment(p,{}ts)} assumes that \\spad{p} is a non-constant polynomial whose main variable is greater than any variable of \\spad{ts}. This operation assumes also that if \\spad{p} is added to \\spad{ts} the resulting set,{} say \\spad{ts+p},{} is a regular triangular set. Then it returns a split of Kalkbrener of \\spad{ts+p}. This may not be \\spad{ts+p} itself,{} if for instance \\spad{ts+p} is required to be square-free.")) (|intersect| (((|List| $) |#4| (|List| $)) "\\spad{intersect(p,{}lts)} returns the same as \\spad{intersect([p],{}lts)}") (((|List| $) (|List| |#4|) (|List| $)) "\\spad{intersect(lp,{}lts)} returns the same as \\spad{concat([intersect(lp,{}ts) for ts in lts])|}") (((|List| $) (|List| |#4|) $) "\\spad{intersect(lp,{}ts)} returns \\spad{lts} a split of Lazard of the intersection of the affine variety associated with \\spad{lp} and the regular zero set of \\spad{ts}.") (((|List| $) |#4| $) "\\spad{intersect(p,{}ts)} returns the same as \\spad{intersect([p],{}ts)}")) (|squareFreePart| (((|List| (|Record| (|:| |val| |#4|) (|:| |tower| $))) |#4| $) "\\spad{squareFreePart(p,{}ts)} returns \\spad{lpwt} such that \\spad{lpwt.i.val} is a square-free polynomial \\spad{w}.\\spad{r}.\\spad{t}. \\spad{lpwt.i.tower},{} this polynomial being associated with \\spad{p} modulo \\spad{lpwt.i.tower},{} for every \\spad{i}. Moreover,{} the list of the \\spad{lpwt.i.tower} is a split of Kalkbrener of \\spad{ts}. WARNING: This assumes that \\spad{p} is a non-constant polynomial such that if \\spad{p} is added to \\spad{ts},{} then the resulting set is a regular triangular set.")) (|lastSubResultant| (((|List| (|Record| (|:| |val| |#4|) (|:| |tower| $))) |#4| |#4| $) "\\spad{lastSubResultant(p1,{}p2,{}ts)} returns \\spad{lpwt} such that \\spad{lpwt.i.val} is a quasi-monic \\spad{gcd} of \\spad{p1} and \\spad{p2} \\spad{w}.\\spad{r}.\\spad{t}. \\spad{lpwt.i.tower},{} for every \\spad{i},{} and such that the list of the \\spad{lpwt.i.tower} is a split of Kalkbrener of \\spad{ts}. Moreover,{} if \\spad{p1} and \\spad{p2} do not have a non-trivial \\spad{gcd} \\spad{w}.\\spad{r}.\\spad{t}. \\spad{lpwt.i.tower} then \\spad{lpwt.i.val} is the resultant of these polynomials \\spad{w}.\\spad{r}.\\spad{t}. \\spad{lpwt.i.tower}. This assumes that \\spad{p1} and \\spad{p2} have the same main variable and that this variable is greater that any variable occurring in \\spad{ts}.")) (|lastSubResultantElseSplit| (((|Union| |#4| (|List| $)) |#4| |#4| $) "\\spad{lastSubResultantElseSplit(p1,{}p2,{}ts)} returns either \\spad{g} a quasi-monic \\spad{gcd} of \\spad{p1} and \\spad{p2} \\spad{w}.\\spad{r}.\\spad{t}. the \\spad{ts} or a split of Kalkbrener of \\spad{ts}. This assumes that \\spad{p1} and \\spad{p2} have the same maim variable and that this variable is greater that any variable occurring in \\spad{ts}.")) (|invertibleSet| (((|List| $) |#4| $) "\\spad{invertibleSet(p,{}ts)} returns a split of Kalkbrener of the quotient ideal of the ideal \\axiom{\\spad{I}} by \\spad{p} where \\spad{I} is the radical of saturated of \\spad{ts}.")) (|invertible?| (((|Boolean|) |#4| $) "\\spad{invertible?(p,{}ts)} returns \\spad{true} iff \\spad{p} is invertible in the tower associated with \\spad{ts}.") (((|List| (|Record| (|:| |val| (|Boolean|)) (|:| |tower| $))) |#4| $) "\\spad{invertible?(p,{}ts)} returns \\spad{lbwt} where \\spad{lbwt.i} is the result of \\spad{invertibleElseSplit?(p,{}lbwt.i.tower)} and the list of the \\spad{(lqrwt.i).tower} is a split of Kalkbrener of \\spad{ts}.")) (|invertibleElseSplit?| (((|Union| (|Boolean|) (|List| $)) |#4| $) "\\spad{invertibleElseSplit?(p,{}ts)} returns \\spad{true} (resp. \\spad{false}) if \\spad{p} is invertible in the tower associated with \\spad{ts} or returns a split of Kalkbrener of \\spad{ts}.")) (|purelyAlgebraicLeadingMonomial?| (((|Boolean|) |#4| $) "\\spad{purelyAlgebraicLeadingMonomial?(p,{}ts)} returns \\spad{true} iff the main variable of any non-constant iterarted initial of \\spad{p} is algebraic \\spad{w}.\\spad{r}.\\spad{t}. \\spad{ts}.")) (|algebraicCoefficients?| (((|Boolean|) |#4| $) "\\spad{algebraicCoefficients?(p,{}ts)} returns \\spad{true} iff every variable of \\spad{p} which is not the main one of \\spad{p} is algebraic \\spad{w}.\\spad{r}.\\spad{t}. \\spad{ts}.")) (|purelyTranscendental?| (((|Boolean|) |#4| $) "\\spad{purelyTranscendental?(p,{}ts)} returns \\spad{true} iff every variable of \\spad{p} is not algebraic \\spad{w}.\\spad{r}.\\spad{t}. \\spad{ts}")) (|purelyAlgebraic?| (((|Boolean|) $) "\\spad{purelyAlgebraic?(ts)} returns \\spad{true} iff for every algebraic variable \\spad{v} of \\spad{ts} we have \\spad{algebraicCoefficients?(t_v,{}ts_v_-)} where \\spad{ts_v} is select from TriangularSetCategory(\\spad{ts},{}\\spad{v}) and \\spad{ts_v_-} is collectUnder from TriangularSetCategory(\\spad{ts},{}\\spad{v}).") (((|Boolean|) |#4| $) "\\spad{purelyAlgebraic?(p,{}ts)} returns \\spad{true} iff every variable of \\spad{p} is algebraic \\spad{w}.\\spad{r}.\\spad{t}. \\spad{ts}."))) 
-((-4520 . T) (-4519 . T) (-3973 . T)) 
+((-4522 . T) (-4521 . T) (-3973 . T)) 
 NIL 
 (-1067 R E V P TS) 
 ((|constructor| (NIL "An internal package for computing gcds and resultants of univariate polynomials with coefficients in a tower of simple extensions of a field.")) (|toseSquareFreePart| (((|List| (|Record| (|:| |val| |#4|) (|:| |tower| |#5|))) |#4| |#5|) "\\axiom{toseSquareFreePart(\\spad{p},{}\\spad{ts})} has the same specifications as squareFreePart from RegularTriangularSetCategory.")) (|toseInvertibleSet| (((|List| |#5|) |#4| |#5|) "\\axiom{toseInvertibleSet(\\spad{p1},{}\\spad{p2},{}\\spad{ts})} has the same specifications as invertibleSet from RegularTriangularSetCategory.")) (|toseInvertible?| (((|List| (|Record| (|:| |val| (|Boolean|)) (|:| |tower| |#5|))) |#4| |#5|) "\\axiom{toseInvertible?(\\spad{p1},{}\\spad{p2},{}\\spad{ts})} has the same specifications as invertible? from RegularTriangularSetCategory.") (((|Boolean|) |#4| |#5|) "\\axiom{toseInvertible?(\\spad{p1},{}\\spad{p2},{}\\spad{ts})} has the same specifications as invertible? from RegularTriangularSetCategory.")) (|toseLastSubResultant| (((|List| (|Record| (|:| |val| |#4|) (|:| |tower| |#5|))) |#4| |#4| |#5|) "\\axiom{toseLastSubResultant(\\spad{p1},{}\\spad{p2},{}\\spad{ts})} has the same specifications as lastSubResultant from RegularTriangularSetCategory.")) (|integralLastSubResultant| (((|List| (|Record| (|:| |val| |#4|) (|:| |tower| |#5|))) |#4| |#4| |#5|) "\\axiom{integralLastSubResultant(\\spad{p1},{}\\spad{p2},{}\\spad{ts})} is an internal subroutine,{} exported only for developement.")) (|internalLastSubResultant| (((|List| (|Record| (|:| |val| |#4|) (|:| |tower| |#5|))) (|List| (|Record| (|:| |val| (|List| |#4|)) (|:| |tower| |#5|))) |#3| (|Boolean|)) "\\axiom{internalLastSubResultant(lpwt,{}\\spad{v},{}flag)} is an internal subroutine,{} exported only for developement.") (((|List| (|Record| (|:| |val| |#4|) (|:| |tower| |#5|))) |#4| |#4| |#5| (|Boolean|) (|Boolean|)) "\\axiom{internalLastSubResultant(\\spad{p1},{}\\spad{p2},{}\\spad{ts},{}inv?,{}break?)} is an internal subroutine,{} exported only for developement.")) (|prepareSubResAlgo| (((|List| (|Record| (|:| |val| (|List| |#4|)) (|:| |tower| |#5|))) |#4| |#4| |#5|) "\\axiom{prepareSubResAlgo(\\spad{p1},{}\\spad{p2},{}\\spad{ts})} is an internal subroutine,{} exported only for developement.")) (|stopTableInvSet!| (((|Void|)) "\\axiom{stopTableInvSet!()} is an internal subroutine,{} exported only for developement.")) (|startTableInvSet!| (((|Void|) (|String|) (|String|) (|String|)) "\\axiom{startTableInvSet!(\\spad{s1},{}\\spad{s2},{}\\spad{s3})} is an internal subroutine,{} exported only for developement.")) (|stopTableGcd!| (((|Void|)) "\\axiom{stopTableGcd!()} is an internal subroutine,{} exported only for developement.")) (|startTableGcd!| (((|Void|) (|String|) (|String|) (|String|)) "\\axiom{startTableGcd!(\\spad{s1},{}\\spad{s2},{}\\spad{s3})} is an internal subroutine,{} exported only for developement."))) 
@@ -4222,8 +4222,8 @@ NIL
 NIL 
 (-1073 R UP M) 
 ((|constructor| (NIL "Algebraic extension of a ring by a single polynomial. Domain which represents simple algebraic extensions of arbitrary rings. The first argument to the domain,{} \\spad{R},{} is the underlying ring,{} the second argument is a domain of univariate polynomials over \\spad{K},{} while the last argument specifies the defining minimal polynomial. The elements of the domain are canonically represented as polynomials of degree less than that of the minimal polynomial with coefficients in \\spad{R}. The second argument is both the type of the third argument and the underlying representation used by \\spadtype{SAE} itself."))) 
-((-4512 |has| |#1| (-365)) (-4517 |has| |#1| (-365)) (-4511 |has| |#1| (-365)) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-350))) (|HasCategory| |#1| (QUOTE (-365))) (-2198 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-350)))) (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365)))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-350))))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| |#1| (QUOTE (-225))) (|HasCategory| |#1| (QUOTE (-365)))) (-2198 (-12 (|HasCategory| |#1| (QUOTE (-225))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-350))))) 
+((-4514 |has| |#1| (-365)) (-4519 |has| |#1| (-365)) (-4513 |has| |#1| (-365)) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-350))) (|HasCategory| |#1| (QUOTE (-365))) (-2199 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-350)))) (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365)))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-350))))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| |#1| (QUOTE (-225))) (|HasCategory| |#1| (QUOTE (-365)))) (-2199 (-12 (|HasCategory| |#1| (QUOTE (-225))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-350))))) 
 (-1074 UP SAE UPA) 
 ((|constructor| (NIL "Factorization of univariate polynomials with coefficients in an algebraic extension of \\spadtype{Fraction Polynomial Integer}.")) (|factor| (((|Factored| |#3|) |#3|) "\\spad{factor(p)} returns a prime factorisation of \\spad{p}."))) 
 NIL 
@@ -4242,8 +4242,8 @@ NIL
 NIL 
 (-1078 R) 
 ((|constructor| (NIL "\\spadtype{SequentialDifferentialPolynomial} implements an ordinary differential polynomial ring in arbitrary number of differential indeterminates,{} with coefficients in a ring. The ranking on the differential indeterminate is sequential."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-6 -4517)) (-4514 . T) (-4513 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| (-1079 (-1161)) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-1079 (-1161)) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-1079 (-1161)) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-1079 (-1161)) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-1079 (-1161)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-225))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#1| (QUOTE -4517)) (|HasCategory| |#1| (QUOTE (-453))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-6 -4519)) (-4516 . T) (-4515 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| (-1079 (-1161)) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-1079 (-1161)) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-1079 (-1161)) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-1079 (-1161)) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-1079 (-1161)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-225))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#1| (QUOTE -4519)) (|HasCategory| |#1| (QUOTE (-453))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))))) 
 (-1079 S) 
 ((|constructor| (NIL "\\spadtype{OrderlyDifferentialVariable} adds a commonly used sequential ranking to the set of derivatives of an ordered list of differential indeterminates. A sequential ranking is a ranking \\spadfun{<} of the derivatives with the property that for any derivative \\spad{v},{} there are only a finite number of derivatives \\spad{u} with \\spad{u} \\spadfun{<} \\spad{v}. This domain belongs to \\spadtype{DifferentialVariableCategory}. It defines \\spadfun{weight} to be just \\spadfun{order},{} and it defines a sequential ranking \\spadfun{<} on derivatives \\spad{u} by the lexicographic order on the pair (\\spadfun{variable}(\\spad{u}),{} \\spadfun{order}(\\spad{u}))."))) 
 NIL 
@@ -4278,7 +4278,7 @@ NIL
 NIL 
 (-1087 S) 
 ((|constructor| (NIL "A set category lists a collection of set-theoretic operations useful for both finite sets and multisets. Note however that finite sets are distinct from multisets. Although the operations defined for set categories are common to both,{} the relationship between the two cannot be described by inclusion or inheritance.")) (|union| (($ |#1| $) "\\spad{union(x,{}u)} returns the set aggregate \\spad{u} with the element \\spad{x} added. If \\spad{u} already contains \\spad{x},{} \\axiom{union(\\spad{x},{}\\spad{u})} returns a copy of \\spad{u}.") (($ $ |#1|) "\\spad{union(u,{}x)} returns the set aggregate \\spad{u} with the element \\spad{x} added. If \\spad{u} already contains \\spad{x},{} \\axiom{union(\\spad{u},{}\\spad{x})} returns a copy of \\spad{u}.") (($ $ $) "\\spad{union(u,{}v)} returns the set aggregate of elements which are members of either set aggregate \\spad{u} or \\spad{v}.")) (|subset?| (((|Boolean|) $ $) "\\spad{subset?(u,{}v)} tests if \\spad{u} is a subset of \\spad{v}. Note that equivalent to \\axiom{reduce(and,{}{member?(\\spad{x},{}\\spad{v}) for \\spad{x} in \\spad{u}},{}\\spad{true},{}\\spad{false})}.")) (|symmetricDifference| (($ $ $) "\\spad{symmetricDifference(u,{}v)} returns the set aggregate of elements \\spad{x} which are members of set aggregate \\spad{u} or set aggregate \\spad{v} but not both. If \\spad{u} and \\spad{v} have no elements in common,{} \\axiom{symmetricDifference(\\spad{u},{}\\spad{v})} returns a copy of \\spad{u}. Note that \\axiom{symmetricDifference(\\spad{u},{}\\spad{v}) = \\indented{1}{union(difference(\\spad{u},{}\\spad{v}),{}difference(\\spad{v},{}\\spad{u}))}}")) (|difference| (($ $ |#1|) "\\spad{difference(u,{}x)} returns the set aggregate \\spad{u} with element \\spad{x} removed. If \\spad{u} does not contain \\spad{x},{} a copy of \\spad{u} is returned. Note that \\axiom{difference(\\spad{s},{} \\spad{x}) = difference(\\spad{s},{} {\\spad{x}})}.") (($ $ $) "\\spad{difference(u,{}v)} returns the set aggregate \\spad{w} consisting of elements in set aggregate \\spad{u} but not in set aggregate \\spad{v}. If \\spad{u} and \\spad{v} have no elements in common,{} \\axiom{difference(\\spad{u},{}\\spad{v})} returns a copy of \\spad{u}. Note that equivalent to the notation (not currently supported) \\axiom{{\\spad{x} for \\spad{x} in \\spad{u} | not member?(\\spad{x},{}\\spad{v})}}.")) (|intersect| (($ $ $) "\\spad{intersect(u,{}v)} returns the set aggregate \\spad{w} consisting of elements common to both set aggregates \\spad{u} and \\spad{v}. Note that equivalent to the notation (not currently supported) {\\spad{x} for \\spad{x} in \\spad{u} | member?(\\spad{x},{}\\spad{v})}.")) (|set| (($ (|List| |#1|)) "\\spad{set([x,{}y,{}...,{}z])} creates a set aggregate containing items \\spad{x},{}\\spad{y},{}...,{}\\spad{z}.") (($) "\\spad{set()}\\$\\spad{D} creates an empty set aggregate of type \\spad{D}.")) (|brace| (($ (|List| |#1|)) "\\spad{brace([x,{}y,{}...,{}z])} creates a set aggregate containing items \\spad{x},{}\\spad{y},{}...,{}\\spad{z}. This form is considered obsolete. Use \\axiomFun{set} instead.") (($) "\\spad{brace()}\\$\\spad{D} (otherwise written {}\\$\\spad{D}) creates an empty set aggregate of type \\spad{D}. This form is considered obsolete. Use \\axiomFun{set} instead.")) (< (((|Boolean|) $ $) "\\spad{s < t} returns \\spad{true} if all elements of set aggregate \\spad{s} are also elements of set aggregate \\spad{t}."))) 
-((-4509 . T) (-3973 . T)) 
+((-4511 . T) (-3973 . T)) 
 NIL 
 (-1088) 
 ((|constructor| (NIL "This is part of the PAFF package,{} related to projective space."))) 
@@ -4298,8 +4298,8 @@ NIL
 NIL 
 (-1092 S) 
 ((|constructor| (NIL "A set over a domain \\spad{D} models the usual mathematical notion of a finite set of elements from \\spad{D}. Sets are unordered collections of distinct elements (that is,{} order and duplication does not matter). The notation \\spad{set [a,{}b,{}c]} can be used to create a set and the usual operations such as union and intersection are available to form new sets. In our implementation,{} \\Language{} maintains the entries in sorted order. Specifically,{} the parts function returns the entries as a list in ascending order and the extract operation returns the maximum entry. Given two sets \\spad{s} and \\spad{t} where \\spad{\\#s = m} and \\spad{\\#t = n},{} the complexity of\\spad{\\br} \\tab{5}\\spad{s = t} is \\spad{O(min(n,{}m))}\\spad{\\br} \\tab{5}\\spad{s < t} is \\spad{O(max(n,{}m))}\\spad{\\br} \\tab{5}\\spad{union(s,{}t)},{} \\spad{intersect(s,{}t)},{} \\spad{minus(s,{}t)},{}\\spad{\\br} \\tab{10 \\spad{symmetricDifference(s,{}t)} is \\spad{O(max(n,{}m))}\\spad{\\br} \\tab{5}\\spad{member(x,{}t)} is \\spad{O(n log n)}\\spad{\\br} \\tab{5}\\spad{insert(x,{}t)} and \\spad{remove(x,{}t)} is \\spad{O(n)}"))) 
-((-4519 . T) (-4509 . T) (-4520 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (QUOTE (-842))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-370)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
+((-4521 . T) (-4511 . T) (-4522 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-370))) (|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (QUOTE (-842))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-370)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
 (-1093 |Str| |Sym| |Int| |Flt| |Expr|) 
 ((|constructor| (NIL "This category allows the manipulation of Lisp values while keeping the grunge fairly localized.")) (|elt| (($ $ (|List| (|Integer|))) "\\spad{elt((a1,{}...,{}an),{} [i1,{}...,{}im])} returns \\spad{(a_i1,{}...,{}a_im)}.") (($ $ (|Integer|)) "\\spad{elt((a1,{}...,{}an),{} i)} returns \\spad{\\spad{ai}}.")) (|#| (((|Integer|) $) "\\spad{\\#((a1,{}...,{}an))} returns \\spad{n}.")) (|cdr| (($ $) "\\spad{cdr((a1,{}...,{}an))} returns \\spad{(a2,{}...,{}an)}.")) (|car| (($ $) "\\spad{car((a1,{}...,{}an))} returns \\spad{a1}.")) (|convert| (($ |#5|) "\\spad{convert(x)} returns the Lisp atom \\spad{x}.") (($ |#4|) "\\spad{convert(x)} returns the Lisp atom \\spad{x}.") (($ |#3|) "\\spad{convert(x)} returns the Lisp atom \\spad{x}.") (($ |#2|) "\\spad{convert(x)} returns the Lisp atom \\spad{x}.") (($ |#1|) "\\spad{convert(x)} returns the Lisp atom \\spad{x}.") (($ (|List| $)) "\\spad{convert([a1,{}...,{}an])} returns an \\spad{S}-expression \\spad{(a1,{}...,{}an)}.")) (|expr| ((|#5| $) "\\spad{expr(s)} returns \\spad{s} as an element of Expr; Error: if \\spad{s} is not an atom that also belongs to Expr.")) (|float| ((|#4| $) "\\spad{float(s)} returns \\spad{s} as an element of \\spad{Flt}; Error: if \\spad{s} is not an atom that also belongs to \\spad{Flt}.")) (|integer| ((|#3| $) "\\spad{integer(s)} returns \\spad{s} as an element of Int. Error: if \\spad{s} is not an atom that also belongs to Int.")) (|symbol| ((|#2| $) "\\spad{symbol(s)} returns \\spad{s} as an element of \\spad{Sym}. Error: if \\spad{s} is not an atom that also belongs to \\spad{Sym}.")) (|string| ((|#1| $) "\\spad{string(s)} returns \\spad{s} as an element of \\spad{Str}. Error: if \\spad{s} is not an atom that also belongs to \\spad{Str}.")) (|destruct| (((|List| $) $) "\\spad{destruct((a1,{}...,{}an))} returns the list [\\spad{a1},{}...,{}an].")) (|float?| (((|Boolean|) $) "\\spad{float?(s)} is \\spad{true} if \\spad{s} is an atom and belong to \\spad{Flt}.")) (|integer?| (((|Boolean|) $) "\\spad{integer?(s)} is \\spad{true} if \\spad{s} is an atom and belong to Int.")) (|symbol?| (((|Boolean|) $) "\\spad{symbol?(s)} is \\spad{true} if \\spad{s} is an atom and belong to \\spad{Sym}.")) (|string?| (((|Boolean|) $) "\\spad{string?(s)} is \\spad{true} if \\spad{s} is an atom and belong to \\spad{Str}.")) (|list?| (((|Boolean|) $) "\\spad{list?(s)} is \\spad{true} if \\spad{s} is a Lisp list,{} possibly ().")) (|pair?| (((|Boolean|) $) "\\spad{pair?(s)} is \\spad{true} if \\spad{s} has is a non-null Lisp list.")) (|atom?| (((|Boolean|) $) "\\spad{atom?(s)} is \\spad{true} if \\spad{s} is a Lisp atom.")) (|null?| (((|Boolean|) $) "\\spad{null?(s)} is \\spad{true} if \\spad{s} is the \\spad{S}-expression ().")) (|eq| (((|Boolean|) $ $) "\\spad{eq(s,{} t)} is \\spad{true} if EQ(\\spad{s},{}\\spad{t}) is \\spad{true} in Lisp."))) 
 NIL 
@@ -4326,7 +4326,7 @@ NIL
 NIL 
 (-1099 R E V P) 
 ((|constructor| (NIL "The category of square-free regular triangular sets. A regular triangular set \\spad{ts} is square-free if the \\spad{gcd} of any polynomial \\spad{p} in \\spad{ts} and differentiate(\\spad{p},{}mvar(\\spad{p})) \\spad{w}.\\spad{r}.\\spad{t}. collectUnder(\\spad{ts},{}mvar(\\spad{p})) has degree zero \\spad{w}.\\spad{r}.\\spad{t}. \\spad{mvar(p)}. Thus any square-free regular set defines a tower of square-free simple extensions."))) 
-((-4520 . T) (-4519 . T) (-3973 . T)) 
+((-4522 . T) (-4521 . T) (-3973 . T)) 
 NIL 
 (-1100) 
 ((|constructor| (NIL "SymmetricGroupCombinatoricFunctions contains combinatoric functions concerning symmetric groups and representation theory: list young tableaus,{} improper partitions,{} subsets bijection of Coleman.")) (|unrankImproperPartitions1| (((|List| (|Integer|)) (|Integer|) (|Integer|) (|Integer|)) "\\spad{unrankImproperPartitions1(n,{}m,{}k)} computes the \\spad{k}-th improper partition of nonnegative \\spad{n} in at most \\spad{m} nonnegative parts ordered as follows: first,{} in reverse lexicographically according to their non-zero parts,{} then according to their positions (\\spadignore{i.e.} lexicographical order using subSet: [3,{}0,{}0] < [0,{}3,{}0] < [0,{}0,{}3] < [2,{}1,{}0] < [2,{}0,{}1] < [0,{}2,{}1] < [1,{}2,{}0] < [1,{}0,{}2] < [0,{}1,{}2] < [1,{}1,{}1]. Note that counting of subtrees is done by numberOfImproperPartitionsInternal.")) (|unrankImproperPartitions0| (((|List| (|Integer|)) (|Integer|) (|Integer|) (|Integer|)) "\\spad{unrankImproperPartitions0(n,{}m,{}k)} computes the \\spad{k}-th improper partition of nonnegative \\spad{n} in \\spad{m} nonnegative parts in reverse lexicographical order. Example: [0,{}0,{}3] < [0,{}1,{}2] < [0,{}2,{}1] < [0,{}3,{}0] < [1,{}0,{}2] < [1,{}1,{}1] < [1,{}2,{}0] < [2,{}0,{}1] < [2,{}1,{}0] < [3,{}0,{}0]. Error: if \\spad{k} is negative or too big. Note that counting of subtrees is done by numberOfImproperPartitions")) (|subSet| (((|List| (|Integer|)) (|Integer|) (|Integer|) (|Integer|)) "\\spad{subSet(n,{}m,{}k)} calculates the \\spad{k}-th \\spad{m}-subset of the set 0,{}1,{}...,{}(\\spad{n}-1) in the lexicographic order considered as a decreasing map from 0,{}...,{}(\\spad{m}-1) into 0,{}...,{}(\\spad{n}-1). See \\spad{S}.\\spad{G}. Williamson: Theorem 1.60. Error: if not (0 \\spad{<=} \\spad{m} \\spad{<=} \\spad{n} and 0 < = \\spad{k} < (\\spad{n} choose \\spad{m})).")) (|numberOfImproperPartitions| (((|Integer|) (|Integer|) (|Integer|)) "\\spad{numberOfImproperPartitions(n,{}m)} computes the number of partitions of the nonnegative integer \\spad{n} in \\spad{m} nonnegative parts with regarding the order (improper partitions). Example: numberOfImproperPartitions (3,{}3) is 10,{} since [0,{}0,{}3],{} [0,{}1,{}2],{} [0,{}2,{}1],{} [0,{}3,{}0],{} [1,{}0,{}2],{} [1,{}1,{}1],{} [1,{}2,{}0],{} [2,{}0,{}1],{} [2,{}1,{}0],{} [3,{}0,{}0] are the possibilities. Note that this operation has a recursive implementation.")) (|nextPartition| (((|Vector| (|Integer|)) (|List| (|Integer|)) (|Vector| (|Integer|)) (|Integer|)) "\\spad{nextPartition(gamma,{}part,{}number)} generates the partition of \\spad{number} which follows \\spad{part} according to the right-to-left lexicographical order. The partition has the property that its components do not exceed the corresponding components of \\spad{gamma}. the first partition is achieved by part=[]. Also,{} [] indicates that \\spad{part} is the last partition.") (((|Vector| (|Integer|)) (|Vector| (|Integer|)) (|Vector| (|Integer|)) (|Integer|)) "\\spad{nextPartition(gamma,{}part,{}number)} generates the partition of \\spad{number} which follows \\spad{part} according to the right-to-left lexicographical order. The partition has the property that its components do not exceed the corresponding components of \\spad{gamma}. The first partition is achieved by part=[]. Also,{} [] indicates that \\spad{part} is the last partition.")) (|nextLatticePermutation| (((|List| (|Integer|)) (|List| (|Integer|)) (|List| (|Integer|)) (|Boolean|)) "\\spad{nextLatticePermutation(lambda,{}lattP,{}constructNotFirst)} generates the lattice permutation according to the proper partition \\spad{lambda} succeeding the lattice permutation \\spad{lattP} in lexicographical order as long as \\spad{constructNotFirst} is \\spad{true}. If \\spad{constructNotFirst} is \\spad{false},{} the first lattice permutation is returned. The result nil indicates that \\spad{lattP} has no successor.")) (|nextColeman| (((|Matrix| (|Integer|)) (|List| (|Integer|)) (|List| (|Integer|)) (|Matrix| (|Integer|))) "\\spad{nextColeman(alpha,{}beta,{}C)} generates the next Coleman matrix of column sums \\spad{alpha} and row sums \\spad{beta} according to the lexicographical order from bottom-to-top. The first Coleman matrix is achieved by C=new(1,{}1,{}0). Also,{} new(1,{}1,{}0) indicates that \\spad{C} is the last Coleman matrix.")) (|makeYoungTableau| (((|Matrix| (|Integer|)) (|List| (|Integer|)) (|List| (|Integer|))) "\\spad{makeYoungTableau(lambda,{}gitter)} computes for a given lattice permutation \\spad{gitter} and for an improper partition \\spad{lambda} the corresponding standard tableau of shape \\spad{lambda}. Notes: see listYoungTableaus. The entries are from 0,{}...,{}\\spad{n}-1.")) (|listYoungTableaus| (((|List| (|Matrix| (|Integer|))) (|List| (|Integer|))) "\\spad{listYoungTableaus(lambda)} where \\spad{lambda} is a proper partition generates the list of all standard tableaus of shape \\spad{lambda} by means of lattice permutations. The numbers of the lattice permutation are interpreted as column labels. Hence the contents of these lattice permutations are the conjugate of \\spad{lambda}. Notes: the functions nextLatticePermutation and makeYoungTableau are used. The entries are from 0,{}...,{}\\spad{n}-1.")) (|inverseColeman| (((|List| (|Integer|)) (|List| (|Integer|)) (|List| (|Integer|)) (|Matrix| (|Integer|))) "\\spad{inverseColeman(alpha,{}beta,{}C)}: there is a bijection from the set of matrices having nonnegative entries and row sums \\spad{alpha},{} column sums \\spad{beta} to the set of Salpha - Sbeta double cosets of the symmetric group \\spad{Sn}. (Salpha is the Young subgroup corresponding to the improper partition \\spad{alpha}). For such a matrix \\spad{C},{} inverseColeman(\\spad{alpha},{}\\spad{beta},{}\\spad{C}) calculates the lexicographical smallest \\spad{pi} in the corresponding double coset. Note that the resulting permutation \\spad{pi} of {1,{}2,{}...,{}\\spad{n}} is given in list form. Notes: the inverse of this map is coleman. For details,{} see James/Kerber.")) (|coleman| (((|Matrix| (|Integer|)) (|List| (|Integer|)) (|List| (|Integer|)) (|List| (|Integer|))) "\\spad{coleman(alpha,{}beta,{}\\spad{pi})}: there is a bijection from the set of matrices having nonnegative entries and row sums \\spad{alpha},{} column sums \\spad{beta} to the set of Salpha - Sbeta double cosets of the symmetric group \\spad{Sn}. (Salpha is the Young subgroup corresponding to the improper partition \\spad{alpha}). For a representing element \\spad{pi} of such a double coset,{} coleman(\\spad{alpha},{}\\spad{beta},{}\\spad{pi}) generates the Coleman-matrix corresponding to \\spad{alpha},{} \\spad{beta},{} \\spad{pi}. Note that The permutation \\spad{pi} of {1,{}2,{}...,{}\\spad{n}} has to be given in list form. Note that the inverse of this map is inverseColeman (if \\spad{pi} is the lexicographical smallest permutation in the coset). For details see James/Kerber."))) 
@@ -4342,8 +4342,8 @@ NIL
 NIL 
 (-1103 |dimtot| |dim1| S) 
 ((|constructor| (NIL "This type represents the finite direct or cartesian product of an underlying ordered component type. The vectors are ordered as if they were split into two blocks. The \\spad{dim1} parameter specifies the length of the first block. The ordering is lexicographic between the blocks but acts like \\spadtype{HomogeneousDirectProduct} within each block. This type is a suitable third argument for \\spadtype{GeneralDistributedMultivariatePolynomial}."))) 
-((-4513 |has| |#3| (-1047)) (-4514 |has| |#3| (-1047)) (-4516 |has| |#3| (-6 -4516)) ((-4521 "*") |has| |#3| (-172)) (-4519 . T)) 
-((|HasCategory| |#3| (QUOTE (-1090))) (|HasCategory| |#3| (QUOTE (-365))) (|HasCategory| |#3| (QUOTE (-1047))) (|HasCategory| |#3| (QUOTE (-788))) (|HasCategory| |#3| (QUOTE (-840))) (-2198 (|HasCategory| |#3| (QUOTE (-788))) (|HasCategory| |#3| (QUOTE (-840)))) (|HasCategory| |#3| (QUOTE (-716))) (|HasCategory| |#3| (QUOTE (-172))) (-2198 (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-365))) (|HasCategory| |#3| (QUOTE (-1047)))) (-2198 (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-365)))) (-2198 (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-1047)))) (|HasCategory| |#3| (QUOTE (-370))) (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-225))) (-2198 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-225))) (|HasCategory| |#3| (QUOTE (-365))) (|HasCategory| |#3| (QUOTE (-1047)))) (-2198 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-225))) (|HasCategory| |#3| (QUOTE (-1047)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (QUOTE (-225))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1090)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-1090)))) (|HasAttribute| |#3| (QUOTE -4516)) (|HasCategory| |#3| (QUOTE (-137))) (-2198 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-137))) (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-225))) (|HasCategory| |#3| (QUOTE (-365))) (|HasCategory| |#3| (QUOTE (-1047)))) (|HasCategory| |#3| (QUOTE (-25))) (-2198 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-25))) (|HasCategory| |#3| (QUOTE (-137))) (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-225))) (|HasCategory| |#3| (QUOTE (-365))) (|HasCategory| |#3| (QUOTE (-370))) (|HasCategory| |#3| (QUOTE (-716))) (|HasCategory| |#3| (QUOTE (-788))) (|HasCategory| |#3| (QUOTE (-840))) (|HasCategory| |#3| (QUOTE (-1047))) (|HasCategory| |#3| (QUOTE (-1090)))) (-2198 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-25))) (|HasCategory| |#3| (QUOTE (-137))) (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-225))) (|HasCategory| |#3| (QUOTE (-365))) (|HasCategory| |#3| (QUOTE (-1047)))) (-2198 (-12 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-25)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-137)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-172)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-225)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-365)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-370)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-716)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-788)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-840)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-1090))))) (-2198 (-12 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-25)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-137)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-172)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-225)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-365)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-370)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-716)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-788)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-840)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1090))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-25)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-137)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-172)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-225)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-365)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-370)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-716)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-788)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-840)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1090)))))) 
+((-4515 |has| |#3| (-1047)) (-4516 |has| |#3| (-1047)) (-4518 |has| |#3| (-6 -4518)) ((-4523 "*") |has| |#3| (-172)) (-4521 . T)) 
+((|HasCategory| |#3| (QUOTE (-1090))) (|HasCategory| |#3| (QUOTE (-365))) (|HasCategory| |#3| (QUOTE (-1047))) (|HasCategory| |#3| (QUOTE (-788))) (|HasCategory| |#3| (QUOTE (-840))) (-2199 (|HasCategory| |#3| (QUOTE (-788))) (|HasCategory| |#3| (QUOTE (-840)))) (|HasCategory| |#3| (QUOTE (-716))) (|HasCategory| |#3| (QUOTE (-172))) (-2199 (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-365))) (|HasCategory| |#3| (QUOTE (-1047)))) (-2199 (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-365)))) (-2199 (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-1047)))) (|HasCategory| |#3| (QUOTE (-370))) (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-225))) (-2199 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-225))) (|HasCategory| |#3| (QUOTE (-365))) (|HasCategory| |#3| (QUOTE (-1047)))) (-2199 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-225))) (|HasCategory| |#3| (QUOTE (-1047)))) (|HasCategory| (-568) (QUOTE (-842))) (-12 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (QUOTE (-225))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1090)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-1090)))) (|HasAttribute| |#3| (QUOTE -4518)) (|HasCategory| |#3| (QUOTE (-137))) (-2199 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-137))) (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-225))) (|HasCategory| |#3| (QUOTE (-365))) (|HasCategory| |#3| (QUOTE (-1047)))) (|HasCategory| |#3| (QUOTE (-25))) (-2199 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-25))) (|HasCategory| |#3| (QUOTE (-137))) (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-225))) (|HasCategory| |#3| (QUOTE (-365))) (|HasCategory| |#3| (QUOTE (-370))) (|HasCategory| |#3| (QUOTE (-716))) (|HasCategory| |#3| (QUOTE (-788))) (|HasCategory| |#3| (QUOTE (-840))) (|HasCategory| |#3| (QUOTE (-1047))) (|HasCategory| |#3| (QUOTE (-1090)))) (-2199 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (QUOTE (-25))) (|HasCategory| |#3| (QUOTE (-137))) (|HasCategory| |#3| (QUOTE (-172))) (|HasCategory| |#3| (QUOTE (-225))) (|HasCategory| |#3| (QUOTE (-365))) (|HasCategory| |#3| (QUOTE (-1047)))) (-2199 (-12 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-25)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-137)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-172)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-225)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-365)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-370)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-716)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-788)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-840)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#3| (QUOTE (-1090))))) (-2199 (-12 (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-25)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-137)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-172)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-225)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-365)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-370)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-716)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-788)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-840)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#3| (QUOTE (-1090))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (LIST (QUOTE -630) (QUOTE (-568))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (LIST (QUOTE -895) (QUOTE (-1161))))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-25)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-137)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-172)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-225)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-365)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-370)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-716)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-788)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-840)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1047)))) (-12 (|HasCategory| |#3| (LIST (QUOTE -303) (|devaluate| |#3|))) (|HasCategory| |#3| (QUOTE (-1090)))))) 
 (-1104 R |x|) 
 ((|constructor| (NIL "This package produces functions for counting etc. real roots of univariate polynomials in \\spad{x} over \\spad{R},{} which must be an OrderedIntegralDomain")) (|countRealRootsMultiple| (((|Integer|) (|UnivariatePolynomial| |#2| |#1|)) "\\spad{countRealRootsMultiple(p)} says how many real roots \\spad{p} has,{} counted with multiplicity")) (|SturmHabichtMultiple| (((|Integer|) (|UnivariatePolynomial| |#2| |#1|) (|UnivariatePolynomial| |#2| |#1|)) "\\spad{SturmHabichtMultiple(p1,{}p2)} computes \\spad{c_}{+}\\spad{-c_}{-} where \\spad{c_}{+} is the number of real roots of \\spad{p1} with \\spad{p2>0} and \\spad{c_}{-} is the number of real roots of \\spad{p1} with \\spad{p2<0}. If \\spad{p2=1} what you get is the number of real roots of \\spad{p1}.")) (|countRealRoots| (((|Integer|) (|UnivariatePolynomial| |#2| |#1|)) "\\spad{countRealRoots(p)} says how many real roots \\spad{p} has")) (|SturmHabicht| (((|Integer|) (|UnivariatePolynomial| |#2| |#1|) (|UnivariatePolynomial| |#2| |#1|)) "\\spad{SturmHabicht(p1,{}p2)} computes \\spad{c_}{+}\\spad{-c_}{-} where \\spad{c_}{+} is the number of real roots of \\spad{p1} with \\spad{p2>0} and \\spad{c_}{-} is the number of real roots of \\spad{p1} with \\spad{p2<0}. If \\spad{p2=1} what you get is the number of real roots of \\spad{p1}.")) (|SturmHabichtCoefficients| (((|List| |#1|) (|UnivariatePolynomial| |#2| |#1|) (|UnivariatePolynomial| |#2| |#1|)) "\\spad{SturmHabichtCoefficients(p1,{}p2)} computes the principal Sturm-Habicht coefficients of \\spad{p1} and \\spad{p2}")) (|SturmHabichtSequence| (((|List| (|UnivariatePolynomial| |#2| |#1|)) (|UnivariatePolynomial| |#2| |#1|) (|UnivariatePolynomial| |#2| |#1|)) "\\spad{SturmHabichtSequence(p1,{}p2)} computes the Sturm-Habicht sequence of \\spad{p1} and \\spad{p2}")) (|subresultantSequence| (((|List| (|UnivariatePolynomial| |#2| |#1|)) (|UnivariatePolynomial| |#2| |#1|) (|UnivariatePolynomial| |#2| |#1|)) "\\spad{subresultantSequence(p1,{}p2)} computes the (standard) subresultant sequence of \\spad{p1} and \\spad{p2}"))) 
 NIL 
@@ -4362,19 +4362,19 @@ NIL
 NIL 
 (-1108) 
 ((|constructor| (NIL "SingleInteger is intended to support machine integer arithmetic.")) (|Or| (($ $ $) "\\spad{Or(n,{}m)} returns the bit-by-bit logical or of the single integers \\spad{n} and \\spad{m}.")) (|And| (($ $ $) "\\spad{And(n,{}m)} returns the bit-by-bit logical and of the single integers \\spad{n} and \\spad{m}.")) (|Not| (($ $) "\\spad{Not(n)} returns the bit-by-bit logical not of the single integer \\spad{n}.")) (|xor| (($ $ $) "\\spad{xor(n,{}m)} returns the bit-by-bit logical xor of the single integers \\spad{n} and \\spad{m}.")) (|\\/| (($ $ $) "\\spad{n} \\spad{\\/} \\spad{m} returns the bit-by-bit logical or of the single integers \\spad{n} and \\spad{m}.")) (|/\\| (($ $ $) "\\spad{n} \\spad{/\\} \\spad{m} returns the bit-by-bit logical and of the single integers \\spad{n} and \\spad{m}.")) (~ (($ $) "\\spad{~ n} returns the bit-by-bit logical not of the single integer \\spad{n}.")) (|not| (($ $) "\\spad{not(n)} returns the bit-by-bit logical not of the single integer \\spad{n}.")) (|min| (($) "\\spad{min()} returns the smallest single integer.")) (|max| (($) "\\spad{max()} returns the largest single integer.")) (|noetherian| ((|attribute|) "\\spad{noetherian} all ideals are finitely generated (in fact principal).")) (|canonicalsClosed| ((|attribute|) "\\spad{canonicalClosed} means two positives multiply to give positive.")) (|canonical| ((|attribute|) "\\spad{canonical} means that mathematical equality is implied by data structure equality."))) 
-((-4507 . T) (-4511 . T) (-4506 . T) (-4517 . T) (-4518 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4509 . T) (-4513 . T) (-4508 . T) (-4519 . T) (-4520 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-1109 S) 
 ((|constructor| (NIL "A stack is a bag where the last item inserted is the first item extracted.")) (|depth| (((|NonNegativeInteger|) $) "\\indented{1}{depth(\\spad{s}) returns the number of elements of stack \\spad{s}.} \\indented{1}{Note that \\axiom{depth(\\spad{s}) = \\spad{#s}}.} \\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} depth a")) (|top| ((|#1| $) "\\indented{1}{top(\\spad{s}) returns the top element \\spad{x} from \\spad{s}; \\spad{s} remains unchanged.} \\indented{1}{Note that Use \\axiom{pop!(\\spad{s})} to obtain \\spad{x} and remove it from \\spad{s}.} \\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} top a")) (|pop!| ((|#1| $) "\\indented{1}{pop!(\\spad{s}) returns the top element \\spad{x},{} destructively removing \\spad{x} from \\spad{s}.} \\indented{1}{Note that Use \\axiom{top(\\spad{s})} to obtain \\spad{x} without removing it from \\spad{s}.} \\indented{1}{Error: if \\spad{s} is empty.} \\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} pop! a \\spad{X} a")) (|push!| ((|#1| |#1| $) "\\indented{1}{push!(\\spad{x},{}\\spad{s}) pushes \\spad{x} onto stack \\spad{s},{} \\spadignore{i.e.} destructively changing \\spad{s}} \\indented{1}{so as to have a new first (top) element \\spad{x}.} \\indented{1}{Afterwards,{} pop!(\\spad{s}) produces \\spad{x} and pop!(\\spad{s}) produces the original \\spad{s}.} \\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} push! a \\spad{X} a"))) 
-((-4519 . T) (-4520 . T) (-3973 . T)) 
+((-4521 . T) (-4522 . T) (-3973 . T)) 
 NIL 
 (-1110 S |ndim| R |Row| |Col|) 
 ((|constructor| (NIL "\\spadtype{SquareMatrixCategory} is a general square matrix category which allows different representations and indexing schemes. Rows and columns may be extracted with rows returned as objects of type Row and colums returned as objects of type Col.")) (** (($ $ (|Integer|)) "\\spad{m**n} computes an integral power of the matrix \\spad{m}. Error: if the matrix is not invertible.")) (|inverse| (((|Union| $ "failed") $) "\\spad{inverse(m)} returns the inverse of the matrix \\spad{m},{} if that matrix is invertible and returns \"failed\" otherwise.")) (|minordet| ((|#3| $) "\\spad{minordet(m)} computes the determinant of the matrix \\spad{m} using minors.")) (|determinant| ((|#3| $) "\\spad{determinant(m)} returns the determinant of the matrix \\spad{m}.")) (* ((|#4| |#4| $) "\\spad{r * x} is the product of the row vector \\spad{r} and the matrix \\spad{x}. Error: if the dimensions are incompatible.") ((|#5| $ |#5|) "\\spad{x * c} is the product of the matrix \\spad{x} and the column vector \\spad{c}. Error: if the dimensions are incompatible.")) (|diagonalProduct| ((|#3| $) "\\spad{diagonalProduct(m)} returns the product of the elements on the diagonal of the matrix \\spad{m}.")) (|trace| ((|#3| $) "\\spad{trace(m)} returns the trace of the matrix \\spad{m}. this is the sum of the elements on the diagonal of the matrix \\spad{m}.")) (|diagonal| ((|#4| $) "\\spad{diagonal(m)} returns a row consisting of the elements on the diagonal of the matrix \\spad{m}.")) (|diagonalMatrix| (($ (|List| |#3|)) "\\spad{diagonalMatrix(l)} returns a diagonal matrix with the elements of \\spad{l} on the diagonal.")) (|scalarMatrix| (($ |#3|) "\\spad{scalarMatrix(r)} returns an \\spad{n}-by-\\spad{n} matrix with \\spad{r}\\spad{'s} on the diagonal and zeroes elsewhere."))) 
 NIL 
-((|HasCategory| |#3| (QUOTE (-365))) (|HasAttribute| |#3| (QUOTE (-4521 "*"))) (|HasCategory| |#3| (QUOTE (-172)))) 
+((|HasCategory| |#3| (QUOTE (-365))) (|HasAttribute| |#3| (QUOTE (-4523 "*"))) (|HasCategory| |#3| (QUOTE (-172)))) 
 (-1111 |ndim| R |Row| |Col|) 
 ((|constructor| (NIL "\\spadtype{SquareMatrixCategory} is a general square matrix category which allows different representations and indexing schemes. Rows and columns may be extracted with rows returned as objects of type Row and colums returned as objects of type Col.")) (** (($ $ (|Integer|)) "\\spad{m**n} computes an integral power of the matrix \\spad{m}. Error: if the matrix is not invertible.")) (|inverse| (((|Union| $ "failed") $) "\\spad{inverse(m)} returns the inverse of the matrix \\spad{m},{} if that matrix is invertible and returns \"failed\" otherwise.")) (|minordet| ((|#2| $) "\\spad{minordet(m)} computes the determinant of the matrix \\spad{m} using minors.")) (|determinant| ((|#2| $) "\\spad{determinant(m)} returns the determinant of the matrix \\spad{m}.")) (* ((|#3| |#3| $) "\\spad{r * x} is the product of the row vector \\spad{r} and the matrix \\spad{x}. Error: if the dimensions are incompatible.") ((|#4| $ |#4|) "\\spad{x * c} is the product of the matrix \\spad{x} and the column vector \\spad{c}. Error: if the dimensions are incompatible.")) (|diagonalProduct| ((|#2| $) "\\spad{diagonalProduct(m)} returns the product of the elements on the diagonal of the matrix \\spad{m}.")) (|trace| ((|#2| $) "\\spad{trace(m)} returns the trace of the matrix \\spad{m}. this is the sum of the elements on the diagonal of the matrix \\spad{m}.")) (|diagonal| ((|#3| $) "\\spad{diagonal(m)} returns a row consisting of the elements on the diagonal of the matrix \\spad{m}.")) (|diagonalMatrix| (($ (|List| |#2|)) "\\spad{diagonalMatrix(l)} returns a diagonal matrix with the elements of \\spad{l} on the diagonal.")) (|scalarMatrix| (($ |#2|) "\\spad{scalarMatrix(r)} returns an \\spad{n}-by-\\spad{n} matrix with \\spad{r}\\spad{'s} on the diagonal and zeroes elsewhere."))) 
-((-3973 . T) (-4519 . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-3973 . T) (-4521 . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-1112 R |Row| |Col| M) 
 ((|constructor| (NIL "\\spadtype{SmithNormalForm} is a package which provides some standard canonical forms for matrices.")) (|diophantineSystem| (((|Record| (|:| |particular| (|Union| |#3| "failed")) (|:| |basis| (|List| |#3|))) |#4| |#3|) "\\spad{diophantineSystem(A,{}B)} returns a particular integer solution and an integer basis of the equation \\spad{AX = B}.")) (|completeSmith| (((|Record| (|:| |Smith| |#4|) (|:| |leftEqMat| |#4|) (|:| |rightEqMat| |#4|)) |#4|) "\\spad{completeSmith} returns a record that contains the Smith normal form \\spad{H} of the matrix and the left and right equivalence matrices \\spad{U} and \\spad{V} such that U*m*v = \\spad{H}")) (|smith| ((|#4| |#4|) "\\spad{smith(m)} returns the Smith Normal form of the matrix \\spad{m}.")) (|completeHermite| (((|Record| (|:| |Hermite| |#4|) (|:| |eqMat| |#4|)) |#4|) "\\spad{completeHermite} returns a record that contains the Hermite normal form \\spad{H} of the matrix and the equivalence matrix \\spad{U} such that U*m = \\spad{H}")) (|hermite| ((|#4| |#4|) "\\spad{hermite(m)} returns the Hermite normal form of the matrix \\spad{m}."))) 
@@ -4382,15 +4382,15 @@ NIL
 NIL 
 (-1113 R |VarSet|) 
 ((|constructor| (NIL "This type is the basic representation of sparse recursive multivariate polynomials. It is parameterized by the coefficient ring and the variable set which may be infinite. The variable ordering is determined by the variable set parameter. The coefficient ring may be non-commutative,{} but the variables are assumed to commute."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-6 -4517)) (-4514 . T) (-4513 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#1| (QUOTE -4517)) (|HasCategory| |#1| (QUOTE (-453))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-6 -4519)) (-4516 . T) (-4515 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#1| (QUOTE -4519)) (|HasCategory| |#1| (QUOTE (-453))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))))) 
 (-1114 |Coef| |Var| SMP) 
 ((|constructor| (NIL "This domain provides multivariate Taylor series with variables from an arbitrary ordered set. A Taylor series is represented by a stream of polynomials from the polynomial domain \\spad{SMP}. The \\spad{n}th element of the stream is a form of degree \\spad{n}. SMTS is an internal domain.")) (|fintegrate| (($ (|Mapping| $) |#2| |#1|) "\\spad{fintegrate(f,{}v,{}c)} is the integral of \\spad{f()} with respect \\indented{1}{to \\spad{v} and having \\spad{c} as the constant of integration.} \\indented{1}{The evaluation of \\spad{f()} is delayed.}")) (|integrate| (($ $ |#2| |#1|) "\\spad{integrate(s,{}v,{}c)} is the integral of \\spad{s} with respect \\indented{1}{to \\spad{v} and having \\spad{c} as the constant of integration.}")) (|csubst| (((|Mapping| (|Stream| |#3|) |#3|) (|List| |#2|) (|List| (|Stream| |#3|))) "\\spad{csubst(a,{}b)} is for internal use only")) (* (($ |#3| $) "\\spad{smp*ts} multiplies a TaylorSeries by a monomial \\spad{SMP}.")) (|coerce| (($ |#3|) "\\spad{coerce(poly)} regroups the terms by total degree and forms a series.") (($ |#2|) "\\spad{coerce(var)} converts a variable to a Taylor series")) (|coefficient| ((|#3| $ (|NonNegativeInteger|)) "\\indented{1}{\\spad{coefficient(s,{} n)} gives the terms of total degree \\spad{n}.} \\blankline \\spad{X} xts:=x::TaylorSeries Fraction Integer \\spad{X} t1:=sin(\\spad{xts}) \\spad{X} coefficient(\\spad{t1},{}3)"))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4514 . T) (-4513 . T) (-4516 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-558))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-365)))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4516 . T) (-4515 . T) (-4518 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-558))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-365)))) 
 (-1115 R E V P) 
 ((|constructor| (NIL "The category of square-free and normalized triangular sets. Thus,{} up to the primitivity axiom of [1],{} these sets are Lazard triangular sets."))) 
-((-4520 . T) (-4519 . T) (-3973 . T)) 
+((-4522 . T) (-4521 . T) (-3973 . T)) 
 NIL 
 (-1116 UP -1478) 
 ((|constructor| (NIL "This package factors the formulas out of the general solve code,{} allowing their recursive use over different domains. Care is taken to introduce few radicals so that radical extension domains can more easily simplify the results.")) (|aQuartic| ((|#2| |#2| |#2| |#2| |#2| |#2|) "\\spad{aQuartic(f,{}g,{}h,{}i,{}k)} \\undocumented")) (|aCubic| ((|#2| |#2| |#2| |#2| |#2|) "\\spad{aCubic(f,{}g,{}h,{}j)} \\undocumented")) (|aQuadratic| ((|#2| |#2| |#2| |#2|) "\\spad{aQuadratic(f,{}g,{}h)} \\undocumented")) (|aLinear| ((|#2| |#2| |#2|) "\\spad{aLinear(f,{}g)} \\undocumented")) (|quartic| (((|List| |#2|) |#2| |#2| |#2| |#2| |#2|) "\\spad{quartic(f,{}g,{}h,{}i,{}j)} \\undocumented") (((|List| |#2|) |#1|) "\\spad{quartic(u)} \\undocumented")) (|cubic| (((|List| |#2|) |#2| |#2| |#2| |#2|) "\\spad{cubic(f,{}g,{}h,{}i)} \\undocumented") (((|List| |#2|) |#1|) "\\spad{cubic(u)} \\undocumented")) (|quadratic| (((|List| |#2|) |#2| |#2| |#2|) "\\spad{quadratic(f,{}g,{}h)} \\undocumented") (((|List| |#2|) |#1|) "\\spad{quadratic(u)} \\undocumented")) (|linear| (((|List| |#2|) |#2| |#2|) "\\spad{linear(f,{}g)} \\undocumented") (((|List| |#2|) |#1|) "\\spad{linear(u)} \\undocumented")) (|mapSolve| (((|Record| (|:| |solns| (|List| |#2|)) (|:| |maps| (|List| (|Record| (|:| |arg| |#2|) (|:| |res| |#2|))))) |#1| (|Mapping| |#2| |#2|)) "\\spad{mapSolve(u,{}f)} \\undocumented")) (|particularSolution| ((|#2| |#1|) "\\spad{particularSolution(u)} \\undocumented")) (|solve| (((|List| |#2|) |#1|) "\\spad{solve(u)} \\undocumented"))) 
@@ -4434,19 +4434,19 @@ NIL
 NIL 
 (-1126 V C) 
 ((|constructor| (NIL "This domain exports a modest implementation of splitting trees. Spliiting trees are needed when the evaluation of some quantity under some hypothesis requires to split the hypothesis into sub-cases. For instance by adding some new hypothesis on one hand and its negation on another hand. The computations are terminated is a splitting tree \\axiom{a} when \\axiom{status(value(a))} is \\axiom{\\spad{true}}. Thus,{} if for the splitting tree \\axiom{a} the flag \\axiom{status(value(a))} is \\axiom{\\spad{true}},{} then \\axiom{status(value(\\spad{d}))} is \\axiom{\\spad{true}} for any subtree \\axiom{\\spad{d}} of \\axiom{a}. This property of splitting trees is called the termination condition. If no vertex in a splitting tree \\axiom{a} is equal to another,{} \\axiom{a} is said to satisfy the no-duplicates condition. The splitting tree \\axiom{a} will satisfy this condition if nodes are added to \\axiom{a} by mean of \\axiom{splitNodeOf!} and if \\axiom{construct} is only used to create the root of \\axiom{a} with no children.")) (|splitNodeOf!| (($ $ $ (|List| (|SplittingNode| |#1| |#2|)) (|Mapping| (|Boolean|) |#2| |#2|)) "\\axiom{splitNodeOf!(\\spad{l},{}a,{}\\spad{ls},{}sub?)} returns \\axiom{a} where the children list of \\axiom{\\spad{l}} has been set to \\axiom{[[\\spad{s}]\\$\\% for \\spad{s} in \\spad{ls} | not subNodeOf?(\\spad{s},{}a,{}sub?)]}. Thus,{} if \\axiom{\\spad{l}} is not a node of \\axiom{a},{} this latter splitting tree is unchanged.") (($ $ $ (|List| (|SplittingNode| |#1| |#2|))) "\\axiom{splitNodeOf!(\\spad{l},{}a,{}\\spad{ls})} returns \\axiom{a} where the children list of \\axiom{\\spad{l}} has been set to \\axiom{[[\\spad{s}]\\$\\% for \\spad{s} in \\spad{ls} | not nodeOf?(\\spad{s},{}a)]}. Thus,{} if \\axiom{\\spad{l}} is not a node of \\axiom{a},{} this latter splitting tree is unchanged.")) (|remove!| (($ (|SplittingNode| |#1| |#2|) $) "\\axiom{remove!(\\spad{s},{}a)} replaces a by remove(\\spad{s},{}a)")) (|remove| (($ (|SplittingNode| |#1| |#2|) $) "\\axiom{remove(\\spad{s},{}a)} returns the splitting tree obtained from a by removing every sub-tree \\axiom{\\spad{b}} such that \\axiom{value(\\spad{b})} and \\axiom{\\spad{s}} have the same value,{} condition and status.")) (|subNodeOf?| (((|Boolean|) (|SplittingNode| |#1| |#2|) $ (|Mapping| (|Boolean|) |#2| |#2|)) "\\axiom{subNodeOf?(\\spad{s},{}a,{}sub?)} returns \\spad{true} iff for some node \\axiom{\\spad{n}} in \\axiom{a} we have \\axiom{\\spad{s} = \\spad{n}} or \\axiom{status(\\spad{n})} and \\axiom{subNode?(\\spad{s},{}\\spad{n},{}sub?)}.")) (|nodeOf?| (((|Boolean|) (|SplittingNode| |#1| |#2|) $) "\\axiom{nodeOf?(\\spad{s},{}a)} returns \\spad{true} iff some node of \\axiom{a} is equal to \\axiom{\\spad{s}}")) (|result| (((|List| (|Record| (|:| |val| |#1|) (|:| |tower| |#2|))) $) "\\axiom{result(a)} where \\axiom{\\spad{ls}} is the leaves list of \\axiom{a} returns \\axiom{[[value(\\spad{s}),{}condition(\\spad{s})]\\$\\spad{VT} for \\spad{s} in \\spad{ls}]} if the computations are terminated in \\axiom{a} else an error is produced.")) (|conditions| (((|List| |#2|) $) "\\axiom{conditions(a)} returns the list of the conditions of the leaves of a")) (|construct| (($ |#1| |#2| |#1| (|List| |#2|)) "\\axiom{construct(\\spad{v1},{}\\spad{t},{}\\spad{v2},{}\\spad{lt})} creates a splitting tree with value (\\spadignore{i.e.} root vertex) given by \\axiom{[\\spad{v},{}\\spad{t}]\\$\\spad{S}} and with children list given by \\axiom{[[[\\spad{v},{}\\spad{t}]\\$\\spad{S}]\\$\\% for \\spad{s} in \\spad{ls}]}.") (($ |#1| |#2| (|List| (|SplittingNode| |#1| |#2|))) "\\axiom{construct(\\spad{v},{}\\spad{t},{}\\spad{ls})} creates a splitting tree with value (\\spadignore{i.e.} root vertex) given by \\axiom{[\\spad{v},{}\\spad{t}]\\$\\spad{S}} and with children list given by \\axiom{[[\\spad{s}]\\$\\% for \\spad{s} in \\spad{ls}]}.") (($ |#1| |#2| (|List| $)) "\\axiom{construct(\\spad{v},{}\\spad{t},{}la)} creates a splitting tree with value (\\spadignore{i.e.} root vertex) given by \\axiom{[\\spad{v},{}\\spad{t}]\\$\\spad{S}} and with \\axiom{la} as children list.") (($ (|SplittingNode| |#1| |#2|)) "\\axiom{construct(\\spad{s})} creates a splitting tree with value (\\spadignore{i.e.} root vertex) given by \\axiom{\\spad{s}} and no children. Thus,{} if the status of \\axiom{\\spad{s}} is \\spad{false},{} \\axiom{[\\spad{s}]} represents the starting point of the evaluation \\axiom{value(\\spad{s})} under the hypothesis \\axiom{condition(\\spad{s})}.")) (|updateStatus!| (($ $) "\\axiom{updateStatus!(a)} returns a where the status of the vertices are updated to satisfy the \"termination condition\".")) (|extractSplittingLeaf| (((|Union| $ "failed") $) "\\axiom{extractSplittingLeaf(a)} returns the left most leaf (as a tree) whose status is \\spad{false} if any,{} else \"failed\" is returned."))) 
-((-4519 . T) (-4520 . T)) 
+((-4521 . T) (-4522 . T)) 
 ((|HasCategory| (-1125 |#1| |#2|) (QUOTE (-1090))) (-12 (|HasCategory| (-1125 |#1| |#2|) (LIST (QUOTE -303) (LIST (QUOTE -1125) (|devaluate| |#1|) (|devaluate| |#2|)))) (|HasCategory| (-1125 |#1| |#2|) (QUOTE (-1090))))) 
 (-1127 |ndim| R) 
 ((|constructor| (NIL "\\spadtype{SquareMatrix} is a matrix domain of square matrices,{} where the number of rows (= number of columns) is a parameter of the type.")) (|unitsKnown| ((|attribute|) "the invertible matrices are simply the matrices whose determinants are units in the Ring \\spad{R}.")) (|central| ((|attribute|) "the elements of the Ring \\spad{R},{} viewed as diagonal matrices,{} commute with all matrices and,{} indeed,{} are the only matrices which commute with all matrices.")) (|coerce| (((|Matrix| |#2|) $) "\\spad{coerce(m)} converts a matrix of type \\spadtype{SquareMatrix} to a matrix of type \\spadtype{Matrix}.")) (|squareMatrix| (($ (|Matrix| |#2|)) "\\spad{squareMatrix(m)} converts a matrix of type \\spadtype{Matrix} to a matrix of type \\spadtype{SquareMatrix}.")) (|transpose| (($ $) "\\spad{transpose(m)} returns the transpose of the matrix \\spad{m}."))) 
-((-4516 . T) (-4508 |has| |#2| (-6 (-4521 "*"))) (-4519 . T) (-4513 . T) (-4514 . T)) 
-((|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-225))) (|HasAttribute| |#2| (QUOTE (-4521 "*"))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (QUOTE (-301))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-365))) (-2198 (|HasAttribute| |#2| (QUOTE (-4521 "*"))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090))))) (|HasCategory| |#2| (QUOTE (-172)))) 
+((-4518 . T) (-4510 |has| |#2| (-6 (-4523 "*"))) (-4521 . T) (-4515 . T) (-4516 . T)) 
+((|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-225))) (|HasAttribute| |#2| (QUOTE (-4523 "*"))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (QUOTE (-301))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-365))) (-2199 (|HasAttribute| |#2| (QUOTE (-4523 "*"))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161))))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-225)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090))))) (|HasCategory| |#2| (QUOTE (-172)))) 
 (-1128 S) 
 ((|constructor| (NIL "A string aggregate is a category for strings,{} that is,{} one dimensional arrays of characters.")) (|elt| (($ $ $) "\\spad{elt(s,{}t)} returns the concatenation of \\spad{s} and \\spad{t}. It is provided to allow juxtaposition of strings to work as concatenation. For example,{} \\axiom{\"smoo\" \"shed\"} returns \\axiom{\"smooshed\"}.")) (|rightTrim| (($ $ (|CharacterClass|)) "\\spad{rightTrim(s,{}cc)} returns \\spad{s} with all trailing occurences of characters in \\spad{cc} deleted. For example,{} \\axiom{rightTrim(\"(abc)\",{} charClass \"()\")} returns \\axiom{\"(abc\"}.") (($ $ (|Character|)) "\\spad{rightTrim(s,{}c)} returns \\spad{s} with all trailing occurrences of \\spad{c} deleted. For example,{} \\axiom{rightTrim(\" abc \",{} char \" \")} returns \\axiom{\" abc\"}.")) (|leftTrim| (($ $ (|CharacterClass|)) "\\spad{leftTrim(s,{}cc)} returns \\spad{s} with all leading characters in \\spad{cc} deleted. For example,{} \\axiom{leftTrim(\"(abc)\",{} charClass \"()\")} returns \\axiom{\"abc)\"}.") (($ $ (|Character|)) "\\spad{leftTrim(s,{}c)} returns \\spad{s} with all leading characters \\spad{c} deleted. For example,{} \\axiom{leftTrim(\" abc \",{} char \" \")} returns \\axiom{\"abc \"}.")) (|trim| (($ $ (|CharacterClass|)) "\\spad{trim(s,{}cc)} returns \\spad{s} with all characters in \\spad{cc} deleted from right and left ends. For example,{} \\axiom{trim(\"(abc)\",{} charClass \"()\")} returns \\axiom{\"abc\"}.") (($ $ (|Character|)) "\\spad{trim(s,{}c)} returns \\spad{s} with all characters \\spad{c} deleted from right and left ends. For example,{} \\axiom{trim(\" abc \",{} char \" \")} returns \\axiom{\"abc\"}.")) (|split| (((|List| $) $ (|CharacterClass|)) "\\spad{split(s,{}cc)} returns a list of substrings delimited by characters in \\spad{cc}.") (((|List| $) $ (|Character|)) "\\spad{split(s,{}c)} returns a list of substrings delimited by character \\spad{c}.")) (|coerce| (($ (|Character|)) "\\spad{coerce(c)} returns \\spad{c} as a string \\spad{s} with the character \\spad{c}.")) (|position| (((|Integer|) (|CharacterClass|) $ (|Integer|)) "\\spad{position(cc,{}t,{}i)} returns the position \\axiom{\\spad{j} \\spad{>=} \\spad{i}} in \\spad{t} of the first character belonging to \\spad{cc}.") (((|Integer|) $ $ (|Integer|)) "\\spad{position(s,{}t,{}i)} returns the position \\spad{j} of the substring \\spad{s} in string \\spad{t},{} where \\axiom{\\spad{j} \\spad{>=} \\spad{i}} is required.")) (|replace| (($ $ (|UniversalSegment| (|Integer|)) $) "\\spad{replace(s,{}i..j,{}t)} replaces the substring \\axiom{\\spad{s}(\\spad{i}..\\spad{j})} of \\spad{s} by string \\spad{t}.")) (|match?| (((|Boolean|) $ $ (|Character|)) "\\spad{match?(s,{}t,{}c)} tests if \\spad{s} matches \\spad{t} except perhaps for multiple and consecutive occurrences of character \\spad{c}. Typically \\spad{c} is the blank character.")) (|match| (((|NonNegativeInteger|) $ $ (|Character|)) "\\spad{match(p,{}s,{}wc)} tests if pattern \\axiom{\\spad{p}} matches subject \\axiom{\\spad{s}} where \\axiom{\\spad{wc}} is a wild card character. If no match occurs,{} the index \\axiom{0} is returned; otheriwse,{} the value returned is the first index of the first character in the subject matching the subject (excluding that matched by an initial wild-card). For example,{} \\axiom{match(\"*to*\",{}\"yorktown\",{}\\spad{\"*\"})} returns \\axiom{5} indicating a successful match starting at index \\axiom{5} of \\axiom{\"yorktown\"}.")) (|substring?| (((|Boolean|) $ $ (|Integer|)) "\\spad{substring?(s,{}t,{}i)} tests if \\spad{s} is a substring of \\spad{t} beginning at index \\spad{i}. Note that \\axiom{substring?(\\spad{s},{}\\spad{t},{}0) = prefix?(\\spad{s},{}\\spad{t})}.")) (|suffix?| (((|Boolean|) $ $) "\\spad{suffix?(s,{}t)} tests if the string \\spad{s} is the final substring of \\spad{t}. Note that \\axiom{suffix?(\\spad{s},{}\\spad{t}) \\spad{==} \\indented{1}{reduce(and,{}[\\spad{s}.\\spad{i} = \\spad{t}.(\\spad{n} - \\spad{m} + \\spad{i}) for \\spad{i} in 0..maxIndex \\spad{s}])}} where \\spad{m} and \\spad{n} denote the maxIndex of \\spad{s} and \\spad{t} respectively.")) (|prefix?| (((|Boolean|) $ $) "\\spad{prefix?(s,{}t)} tests if the string \\spad{s} is the initial substring of \\spad{t}. Note that \\axiom{prefix?(\\spad{s},{}\\spad{t}) \\spad{==} \\indented{2}{reduce(and,{}[\\spad{s}.\\spad{i} = \\spad{t}.\\spad{i} for \\spad{i} in 0..maxIndex \\spad{s}])}.}")) (|upperCase!| (($ $) "\\spad{upperCase!(s)} destructively replaces the alphabetic characters in \\spad{s} by upper case characters.")) (|upperCase| (($ $) "\\spad{upperCase(s)} returns the string with all characters in upper case.")) (|lowerCase!| (($ $) "\\spad{lowerCase!(s)} destructively replaces the alphabetic characters in \\spad{s} by lower case.")) (|lowerCase| (($ $) "\\spad{lowerCase(s)} returns the string with all characters in lower case."))) 
 NIL 
 NIL 
 (-1129) 
 ((|constructor| (NIL "A string aggregate is a category for strings,{} that is,{} one dimensional arrays of characters.")) (|elt| (($ $ $) "\\spad{elt(s,{}t)} returns the concatenation of \\spad{s} and \\spad{t}. It is provided to allow juxtaposition of strings to work as concatenation. For example,{} \\axiom{\"smoo\" \"shed\"} returns \\axiom{\"smooshed\"}.")) (|rightTrim| (($ $ (|CharacterClass|)) "\\spad{rightTrim(s,{}cc)} returns \\spad{s} with all trailing occurences of characters in \\spad{cc} deleted. For example,{} \\axiom{rightTrim(\"(abc)\",{} charClass \"()\")} returns \\axiom{\"(abc\"}.") (($ $ (|Character|)) "\\spad{rightTrim(s,{}c)} returns \\spad{s} with all trailing occurrences of \\spad{c} deleted. For example,{} \\axiom{rightTrim(\" abc \",{} char \" \")} returns \\axiom{\" abc\"}.")) (|leftTrim| (($ $ (|CharacterClass|)) "\\spad{leftTrim(s,{}cc)} returns \\spad{s} with all leading characters in \\spad{cc} deleted. For example,{} \\axiom{leftTrim(\"(abc)\",{} charClass \"()\")} returns \\axiom{\"abc)\"}.") (($ $ (|Character|)) "\\spad{leftTrim(s,{}c)} returns \\spad{s} with all leading characters \\spad{c} deleted. For example,{} \\axiom{leftTrim(\" abc \",{} char \" \")} returns \\axiom{\"abc \"}.")) (|trim| (($ $ (|CharacterClass|)) "\\spad{trim(s,{}cc)} returns \\spad{s} with all characters in \\spad{cc} deleted from right and left ends. For example,{} \\axiom{trim(\"(abc)\",{} charClass \"()\")} returns \\axiom{\"abc\"}.") (($ $ (|Character|)) "\\spad{trim(s,{}c)} returns \\spad{s} with all characters \\spad{c} deleted from right and left ends. For example,{} \\axiom{trim(\" abc \",{} char \" \")} returns \\axiom{\"abc\"}.")) (|split| (((|List| $) $ (|CharacterClass|)) "\\spad{split(s,{}cc)} returns a list of substrings delimited by characters in \\spad{cc}.") (((|List| $) $ (|Character|)) "\\spad{split(s,{}c)} returns a list of substrings delimited by character \\spad{c}.")) (|coerce| (($ (|Character|)) "\\spad{coerce(c)} returns \\spad{c} as a string \\spad{s} with the character \\spad{c}.")) (|position| (((|Integer|) (|CharacterClass|) $ (|Integer|)) "\\spad{position(cc,{}t,{}i)} returns the position \\axiom{\\spad{j} \\spad{>=} \\spad{i}} in \\spad{t} of the first character belonging to \\spad{cc}.") (((|Integer|) $ $ (|Integer|)) "\\spad{position(s,{}t,{}i)} returns the position \\spad{j} of the substring \\spad{s} in string \\spad{t},{} where \\axiom{\\spad{j} \\spad{>=} \\spad{i}} is required.")) (|replace| (($ $ (|UniversalSegment| (|Integer|)) $) "\\spad{replace(s,{}i..j,{}t)} replaces the substring \\axiom{\\spad{s}(\\spad{i}..\\spad{j})} of \\spad{s} by string \\spad{t}.")) (|match?| (((|Boolean|) $ $ (|Character|)) "\\spad{match?(s,{}t,{}c)} tests if \\spad{s} matches \\spad{t} except perhaps for multiple and consecutive occurrences of character \\spad{c}. Typically \\spad{c} is the blank character.")) (|match| (((|NonNegativeInteger|) $ $ (|Character|)) "\\spad{match(p,{}s,{}wc)} tests if pattern \\axiom{\\spad{p}} matches subject \\axiom{\\spad{s}} where \\axiom{\\spad{wc}} is a wild card character. If no match occurs,{} the index \\axiom{0} is returned; otheriwse,{} the value returned is the first index of the first character in the subject matching the subject (excluding that matched by an initial wild-card). For example,{} \\axiom{match(\"*to*\",{}\"yorktown\",{}\\spad{\"*\"})} returns \\axiom{5} indicating a successful match starting at index \\axiom{5} of \\axiom{\"yorktown\"}.")) (|substring?| (((|Boolean|) $ $ (|Integer|)) "\\spad{substring?(s,{}t,{}i)} tests if \\spad{s} is a substring of \\spad{t} beginning at index \\spad{i}. Note that \\axiom{substring?(\\spad{s},{}\\spad{t},{}0) = prefix?(\\spad{s},{}\\spad{t})}.")) (|suffix?| (((|Boolean|) $ $) "\\spad{suffix?(s,{}t)} tests if the string \\spad{s} is the final substring of \\spad{t}. Note that \\axiom{suffix?(\\spad{s},{}\\spad{t}) \\spad{==} \\indented{1}{reduce(and,{}[\\spad{s}.\\spad{i} = \\spad{t}.(\\spad{n} - \\spad{m} + \\spad{i}) for \\spad{i} in 0..maxIndex \\spad{s}])}} where \\spad{m} and \\spad{n} denote the maxIndex of \\spad{s} and \\spad{t} respectively.")) (|prefix?| (((|Boolean|) $ $) "\\spad{prefix?(s,{}t)} tests if the string \\spad{s} is the initial substring of \\spad{t}. Note that \\axiom{prefix?(\\spad{s},{}\\spad{t}) \\spad{==} \\indented{2}{reduce(and,{}[\\spad{s}.\\spad{i} = \\spad{t}.\\spad{i} for \\spad{i} in 0..maxIndex \\spad{s}])}.}")) (|upperCase!| (($ $) "\\spad{upperCase!(s)} destructively replaces the alphabetic characters in \\spad{s} by upper case characters.")) (|upperCase| (($ $) "\\spad{upperCase(s)} returns the string with all characters in upper case.")) (|lowerCase!| (($ $) "\\spad{lowerCase!(s)} destructively replaces the alphabetic characters in \\spad{s} by lower case.")) (|lowerCase| (($ $) "\\spad{lowerCase(s)} returns the string with all characters in lower case."))) 
-((-4520 . T) (-4519 . T) (-3973 . T)) 
+((-4522 . T) (-4521 . T) (-3973 . T)) 
 NIL 
 (-1130 R E V P TS) 
 ((|constructor| (NIL "A package providing a new algorithm for solving polynomial systems by means of regular chains. Two ways of solving are provided: in the sense of Zariski closure (like in Kalkbrener\\spad{'s} algorithm) or in the sense of the regular zeros (like in Wu,{} Wang or Lazard- Moreno methods). This algorithm is valid for nay type of regular set. It does not care about the way a polynomial is added in an regular set,{} or how two quasi-components are compared (by an inclusion-test),{} or how the invertibility test is made in the tower of simple extensions associated with a regular set. These operations are realized respectively by the domain \\spad{TS} and the packages \\spad{QCMPPK(R,{}E,{}V,{}P,{}TS)} and \\spad{RSETGCD(R,{}E,{}V,{}P,{}TS)}. The same way it does not care about the way univariate polynomial gcds (with coefficients in the tower of simple extensions associated with a regular set) are computed. The only requirement is that these gcds need to have invertible initials (normalized or not). WARNING. There is no need for a user to call diectly any operation of this package since they can be accessed by the domain \\axiomType{\\spad{TS}}. Thus,{} the operations of this package are not documented."))) 
@@ -4454,11 +4454,11 @@ NIL
 NIL 
 (-1131 R E V P) 
 ((|constructor| (NIL "This domain provides an implementation of square-free regular chains. Moreover,{} the operation zeroSetSplit is an implementation of a new algorithm for solving polynomial systems by means of regular chains.")) (|preprocess| (((|Record| (|:| |val| (|List| |#4|)) (|:| |towers| (|List| $))) (|List| |#4|) (|Boolean|) (|Boolean|)) "\\axiom{pre_process(\\spad{lp},{}\\spad{b1},{}\\spad{b2})} is an internal subroutine,{} exported only for developement.")) (|internalZeroSetSplit| (((|List| $) (|List| |#4|) (|Boolean|) (|Boolean|) (|Boolean|)) "\\axiom{internalZeroSetSplit(\\spad{lp},{}\\spad{b1},{}\\spad{b2},{}\\spad{b3})} is an internal subroutine,{} exported only for developement.")) (|zeroSetSplit| (((|List| $) (|List| |#4|) (|Boolean|) (|Boolean|) (|Boolean|) (|Boolean|)) "\\axiom{zeroSetSplit(\\spad{lp},{}\\spad{b1},{}\\spad{b2}.\\spad{b3},{}\\spad{b4})} is an internal subroutine,{} exported only for developement.") (((|List| $) (|List| |#4|) (|Boolean|) (|Boolean|)) "\\axiom{zeroSetSplit(\\spad{lp},{}clos?,{}info?)} has the same specifications as zeroSetSplit from RegularTriangularSetCategory from \\spadtype{RegularTriangularSetCategory} Moreover,{} if clos? then solves in the sense of the Zariski closure else solves in the sense of the regular zeros. If \\axiom{info?} then do print messages during the computations.")) (|internalAugment| (((|List| $) |#4| $ (|Boolean|) (|Boolean|) (|Boolean|) (|Boolean|) (|Boolean|)) "\\axiom{internalAugment(\\spad{p},{}\\spad{ts},{}\\spad{b1},{}\\spad{b2},{}\\spad{b3},{}\\spad{b4},{}\\spad{b5})} is an internal subroutine,{} exported only for developement."))) 
-((-4520 . T) (-4519 . T)) 
+((-4522 . T) (-4521 . T)) 
 ((|HasCategory| |#4| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#4| (QUOTE (-1090))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#3| (QUOTE (-370)))) 
 (-1132 S) 
 ((|constructor| (NIL "Linked List implementation of a Stack")) (|member?| (((|Boolean|) |#1| $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} member?(3,{}a)")) (|members| (((|List| |#1|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} members a")) (|parts| (((|List| |#1|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} parts a")) (|#| (((|NonNegativeInteger|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} \\#a")) (|count| (((|NonNegativeInteger|) |#1| $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} count(4,{}a)") (((|NonNegativeInteger|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} count(\\spad{x+}->(\\spad{x>2}),{}a)")) (|any?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} any?(\\spad{x+}->(\\spad{x=4}),{}a)")) (|every?| (((|Boolean|) (|Mapping| (|Boolean|) |#1|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} every?(\\spad{x+}->(\\spad{x=4}),{}a)")) (~= (((|Boolean|) $ $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} b:=copy a \\spad{X} (a~=b)")) (= (((|Boolean|) $ $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} b:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} (a=b)@Boolean")) (|coerce| (((|OutputForm|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} coerce a")) (|hash| (((|SingleInteger|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} hash a")) (|latex| (((|String|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} latex a")) (|map!| (($ (|Mapping| |#1| |#1|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} map!(\\spad{x+}-\\spad{>x+10},{}a) \\spad{X} a")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} map(\\spad{x+}-\\spad{>x+10},{}a) \\spad{X} a")) (|eq?| (((|Boolean|) $ $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} b:=copy a \\spad{X} eq?(a,{}\\spad{b})")) (|copy| (($ $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} copy a")) (|sample| (($) "\\blankline \\spad{X} sample()\\$Stack(INT)")) (|empty| (($) "\\blankline \\spad{X} b:=empty()\\$(Stack INT)")) (|empty?| (((|Boolean|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} empty? a")) (|bag| (($ (|List| |#1|)) "\\blankline \\spad{X} bag([1,{}2,{}3,{}4,{}5])\\$Stack(INT)")) (|size?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} size?(a,{}5)")) (|more?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} more?(a,{}9)")) (|less?| (((|Boolean|) $ (|NonNegativeInteger|)) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} less?(a,{}9)")) (|depth| (((|NonNegativeInteger|) $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} depth a")) (|top| ((|#1| $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} top a")) (|inspect| ((|#1| $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} inspect a")) (|insert!| (($ |#1| $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} insert!(8,{}a) \\spad{X} a")) (|push!| ((|#1| |#1| $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} push!(9,{}a) \\spad{X} a")) (|extract!| ((|#1| $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} extract! a \\spad{X} a")) (|pop!| ((|#1| $) "\\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5] \\spad{X} pop! a \\spad{X} a")) (|stack| (($ (|List| |#1|)) "\\indented{1}{stack([\\spad{x},{}\\spad{y},{}...,{}\\spad{z}]) creates a stack with first (top)} \\indented{1}{element \\spad{x},{} second element \\spad{y},{}...,{}and last element \\spad{z}.} \\blankline \\spad{X} a:Stack INT:= stack [1,{}2,{}3,{}4,{}5]"))) 
-((-4519 . T) (-4520 . T)) 
+((-4521 . T) (-4522 . T)) 
 ((|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090))))) 
 (-1133 A S) 
 ((|constructor| (NIL "A stream aggregate is a linear aggregate which possibly has an infinite number of elements. A basic domain constructor which builds stream aggregates is \\spadtype{Stream}. From streams,{} a number of infinite structures such power series can be built. A stream aggregate may also be infinite since it may be cyclic. For example,{} see \\spadtype{DecimalExpansion}.")) (|possiblyInfinite?| (((|Boolean|) $) "\\spad{possiblyInfinite?(s)} tests if the stream \\spad{s} could possibly have an infinite number of elements. Note that for many datatypes,{} \\axiom{possiblyInfinite?(\\spad{s}) = not explictlyFinite?(\\spad{s})}.")) (|explicitlyFinite?| (((|Boolean|) $) "\\spad{explicitlyFinite?(s)} tests if the stream has a finite number of elements,{} and \\spad{false} otherwise. Note that for many datatypes,{} \\axiom{explicitlyFinite?(\\spad{s}) = not possiblyInfinite?(\\spad{s})}."))) 
@@ -4470,8 +4470,8 @@ NIL
 NIL 
 (-1135 |Key| |Ent| |dent|) 
 ((|constructor| (NIL "A sparse table has a default entry,{} which is returned if no other value has been explicitly stored for a key."))) 
-((-4520 . T)) 
-((|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-1090))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))) (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3649) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4083) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090)))) (-2198 (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-1090))))) 
+((-4522 . T)) 
+((|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-1090))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090)))) (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3651) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4085) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090)))) (-2199 (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-1090))))) 
 (-1136) 
 ((|constructor| (NIL "A class of objects which can be 'stepped through'. Repeated applications of \\spadfun{nextItem} is guaranteed never to return duplicate items and only return \"failed\" after exhausting all elements of the domain. This assumes that the sequence starts with \\spad{init()}. For infinite domains,{} repeated application of \\spadfun{nextItem} is not required to reach all possible domain elements starting from any initial element. \\blankline Conditional attributes\\spad{\\br} \\tab{5}infinite\\tab{5}repeated nextItem\\spad{'s} are never \"failed\".")) (|nextItem| (((|Union| $ "failed") $) "\\spad{nextItem(x)} returns the next item,{} or \"failed\" if domain is exhausted.")) (|init| (($) "\\spad{init()} chooses an initial object for stepping."))) 
 NIL 
@@ -4494,20 +4494,20 @@ NIL
 NIL 
 (-1141 S) 
 ((|constructor| (NIL "A stream is an implementation of an infinite sequence using a list of terms that have been computed and a function closure to compute additional terms when needed.")) (|filterUntil| (($ (|Mapping| (|Boolean|) |#1|) $) "\\indented{1}{filterUntil(\\spad{p},{}\\spad{s}) returns \\spad{[x0,{}x1,{}...,{}x(n)]} where} \\indented{1}{\\spad{s = [x0,{}x1,{}x2,{}..]} and} \\indented{1}{\\spad{n} is the smallest index such that \\spad{p(xn) = true}.} \\blankline \\spad{X} \\spad{m:=}[\\spad{i} for \\spad{i} in 1..] \\spad{X} \\spad{f}(x:PositiveInteger):Boolean \\spad{==} \\spad{x} < 5 \\spad{X} filterUntil(\\spad{f},{}\\spad{m})")) (|filterWhile| (($ (|Mapping| (|Boolean|) |#1|) $) "\\indented{1}{filterWhile(\\spad{p},{}\\spad{s}) returns \\spad{[x0,{}x1,{}...,{}x(n-1)]} where} \\indented{1}{\\spad{s = [x0,{}x1,{}x2,{}..]} and} \\indented{1}{\\spad{n} is the smallest index such that \\spad{p(xn) = false}.} \\blankline \\spad{X} \\spad{m:=}[\\spad{i} for \\spad{i} in 1..] \\spad{X} \\spad{f}(x:PositiveInteger):Boolean \\spad{==} \\spad{x} < 5 \\spad{X} filterWhile(\\spad{f},{}\\spad{m})")) (|generate| (($ (|Mapping| |#1| |#1|) |#1|) "\\indented{1}{generate(\\spad{f},{}\\spad{x}) creates an infinite stream whose first element is} \\indented{1}{\\spad{x} and whose \\spad{n}th element (\\spad{n > 1}) is \\spad{f} applied to the previous} \\indented{1}{element. Note: \\spad{generate(f,{}x) = [x,{}f(x),{}f(f(x)),{}...]}.} \\blankline \\spad{X} \\spad{f}(x:Integer):Integer \\spad{==} \\spad{x+10} \\spad{X} generate(\\spad{f},{}10)") (($ (|Mapping| |#1|)) "\\indented{1}{generate(\\spad{f}) creates an infinite stream all of whose elements are} \\indented{1}{equal to \\spad{f()}.} \\indented{1}{Note: \\spad{generate(f) = [f(),{}f(),{}f(),{}...]}.} \\blankline \\spad{X} \\spad{f}():Integer \\spad{==} 1 \\spad{X} generate(\\spad{f})")) (|setrest!| (($ $ (|Integer|) $) "\\indented{1}{setrest!(\\spad{x},{}\\spad{n},{}\\spad{y}) sets rest(\\spad{x},{}\\spad{n}) to \\spad{y}. The function will expand} \\indented{1}{cycles if necessary.} \\blankline \\spad{X} \\spad{p:=}[\\spad{i} for \\spad{i} in 1..] \\spad{X} \\spad{q:=}[\\spad{i} for \\spad{i} in 9..] \\spad{X} setrest!(\\spad{p},{}4,{}\\spad{q}) \\spad{X} \\spad{p}")) (|showAll?| (((|Boolean|)) "\\spad{showAll?()} returns \\spad{true} if all computed entries of streams will be displayed.")) (|showAllElements| (((|OutputForm|) $) "\\indented{1}{showAllElements(\\spad{s}) creates an output form which displays all} \\indented{1}{computed elements.} \\blankline \\spad{X} \\spad{m:=}[1,{}2,{}3,{}4,{}5,{}6,{}7,{}8,{}9,{}10,{}11,{}12] \\spad{X} n:=m::Stream(PositiveInteger) \\spad{X} showAllElements \\spad{n}")) (|output| (((|Void|) (|Integer|) $) "\\indented{1}{output(\\spad{n},{}st) computes and displays the first \\spad{n} entries} \\indented{1}{of st.} \\blankline \\spad{X} \\spad{m:=}[1,{}2,{}3] \\spad{X} n:=repeating(\\spad{m}) \\spad{X} output(5,{}\\spad{n})")) (|cons| (($ |#1| $) "\\indented{1}{cons(a,{}\\spad{s}) returns a stream whose \\spad{first} is \\spad{a}} \\indented{1}{and whose \\spad{rest} is \\spad{s}.} \\indented{1}{Note: \\spad{cons(a,{}s) = concat(a,{}s)}.} \\blankline \\spad{X} \\spad{m:=}[1,{}2,{}3] \\spad{X} n:=repeating(\\spad{m}) \\spad{X} cons(4,{}\\spad{n})")) (|delay| (($ (|Mapping| $)) "\\spad{delay(f)} creates a stream with a lazy evaluation defined by function \\spad{f}. Caution: This function can only be called in compiled code.")) (|findCycle| (((|Record| (|:| |cycle?| (|Boolean|)) (|:| |prefix| (|NonNegativeInteger|)) (|:| |period| (|NonNegativeInteger|))) (|NonNegativeInteger|) $) "\\indented{1}{findCycle(\\spad{n},{}st) determines if st is periodic within \\spad{n}.} \\blankline \\spad{X} \\spad{m:=}[1,{}2,{}3] \\spad{X} n:=repeating(\\spad{m}) \\spad{X} findCycle(3,{}\\spad{n}) \\spad{X} findCycle(2,{}\\spad{n})")) (|repeating?| (((|Boolean|) (|List| |#1|) $) "\\indented{1}{repeating?(\\spad{l},{}\\spad{s}) returns \\spad{true} if a stream \\spad{s} is periodic} \\indented{1}{with period \\spad{l},{} and \\spad{false} otherwise.} \\blankline \\spad{X} \\spad{m:=}[1,{}2,{}3] \\spad{X} n:=repeating(\\spad{m}) \\spad{X} repeating?(\\spad{m},{}\\spad{n})")) (|repeating| (($ (|List| |#1|)) "\\indented{1}{repeating(\\spad{l}) is a repeating stream whose period is the list \\spad{l}.} \\blankline \\spad{X} m:=repeating([\\spad{-1},{}0,{}1,{}2,{}3])")) (|coerce| (($ (|List| |#1|)) "\\indented{1}{coerce(\\spad{l}) converts a list \\spad{l} to a stream.} \\blankline \\spad{X} \\spad{m:=}[1,{}2,{}3,{}4,{}5,{}6,{}7,{}8,{}9,{}10,{}11,{}12] \\spad{X} coerce(\\spad{m})@Stream(Integer) \\spad{X} m::Stream(Integer)")) (|shallowlyMutable| ((|attribute|) "one may destructively alter a stream by assigning new values to its entries."))) 
-((-4520 . T)) 
+((-4522 . T)) 
 ((|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-568) (QUOTE (-842)))) 
 (-1142) 
 ((|constructor| (NIL "A category for string-like objects")) (|string| (($ (|Integer|)) "\\spad{string(i)} returns the decimal representation of \\spad{i} in a string"))) 
-((-4520 . T) (-4519 . T) (-3973 . T)) 
+((-4522 . T) (-4521 . T) (-3973 . T)) 
 NIL 
 (-1143) 
 ((|constructor| (NIL "This is the domain of character strings. Strings are 1 based."))) 
-((-4520 . T) (-4519 . T)) 
-((|HasCategory| (-147) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-147) (QUOTE (-842))) (|HasCategory| (-568) (QUOTE (-842))) (|HasCategory| (-147) (QUOTE (-1090))) (-12 (|HasCategory| (-147) (LIST (QUOTE -303) (QUOTE (-147)))) (|HasCategory| (-147) (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| (-147) (LIST (QUOTE -303) (QUOTE (-147)))) (|HasCategory| (-147) (QUOTE (-842)))) (-12 (|HasCategory| (-147) (LIST (QUOTE -303) (QUOTE (-147)))) (|HasCategory| (-147) (QUOTE (-1090)))))) 
+((-4522 . T) (-4521 . T)) 
+((|HasCategory| (-147) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-147) (QUOTE (-842))) (|HasCategory| (-568) (QUOTE (-842))) (|HasCategory| (-147) (QUOTE (-1090))) (-12 (|HasCategory| (-147) (LIST (QUOTE -303) (QUOTE (-147)))) (|HasCategory| (-147) (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| (-147) (LIST (QUOTE -303) (QUOTE (-147)))) (|HasCategory| (-147) (QUOTE (-842)))) (-12 (|HasCategory| (-147) (LIST (QUOTE -303) (QUOTE (-147)))) (|HasCategory| (-147) (QUOTE (-1090)))))) 
 (-1144 |Entry|) 
 ((|constructor| (NIL "This domain provides tables where the keys are strings. A specialized hash function for strings is used."))) 
-((-4519 . T) (-4520 . T)) 
-((|HasCategory| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3649) (QUOTE (-1143))) (LIST (QUOTE |:|) (QUOTE -4083) (|devaluate| |#1|))))) (|HasCategory| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (QUOTE (-1090)))) (|HasCategory| (-1143) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090))) (-2198 (|HasCategory| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (QUOTE (-1090))) (|HasCategory| |#1| (QUOTE (-1090)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090))))) 
+((-4521 . T) (-4522 . T)) 
+((|HasCategory| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3651) (QUOTE (-1143))) (LIST (QUOTE |:|) (QUOTE -4085) (|devaluate| |#1|))))) (|HasCategory| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (QUOTE (-1090)))) (|HasCategory| (-1143) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090))) (-2199 (|HasCategory| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (QUOTE (-1090))) (|HasCategory| |#1| (QUOTE (-1090)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090))))) 
 (-1145 A) 
 ((|constructor| (NIL "StreamTaylorSeriesOperations implements Taylor series arithmetic,{} where a Taylor series is represented by a stream of its coefficients.")) (|power| (((|Stream| |#1|) |#1| (|Stream| |#1|)) "\\spad{power(a,{}f)} returns the power series \\spad{f} raised to the power \\spad{a}.")) (|lazyGintegrate| (((|Stream| |#1|) (|Mapping| |#1| (|Integer|)) |#1| (|Mapping| (|Stream| |#1|))) "\\spad{lazyGintegrate(f,{}r,{}g)} is used for fixed point computations.")) (|mapdiv| (((|Stream| |#1|) (|Stream| |#1|) (|Stream| |#1|)) "\\spad{mapdiv([a0,{}a1,{}..],{}[b0,{}b1,{}..])} returns \\spad{[a0/b0,{}a1/b1,{}..]}.")) (|powern| (((|Stream| |#1|) (|Fraction| (|Integer|)) (|Stream| |#1|)) "\\spad{powern(r,{}f)} raises power series \\spad{f} to the power \\spad{r}.")) (|nlde| (((|Stream| |#1|) (|Stream| (|Stream| |#1|))) "\\spad{nlde(u)} solves a first order non-linear differential equation described by \\spad{u} of the form \\spad{[[b<0,{}0>,{}b<0,{}1>,{}...],{}[b<1,{}0>,{}b<1,{}1>,{}.],{}...]}. the differential equation has the form \\spad{y'=sum(i=0 to infinity,{}j=0 to infinity,{}b<i,{}j>*(x**i)*(y**j))}.")) (|lazyIntegrate| (((|Stream| |#1|) |#1| (|Mapping| (|Stream| |#1|))) "\\spad{lazyIntegrate(r,{}f)} is a local function used for fixed point computations.")) (|integrate| (((|Stream| |#1|) |#1| (|Stream| |#1|)) "\\spad{integrate(r,{}a)} returns the integral of the power series \\spad{a} with respect to the power series variableintegration where \\spad{r} denotes the constant of integration. Thus \\spad{integrate(a,{}[a0,{}a1,{}a2,{}...]) = [a,{}a0,{}a1/2,{}a2/3,{}...]}.")) (|invmultisect| (((|Stream| |#1|) (|Integer|) (|Integer|) (|Stream| |#1|)) "\\spad{invmultisect(a,{}b,{}st)} substitutes \\spad{x**((a+b)*n)} for \\spad{x**n} and multiplies by \\spad{x**b}.")) (|multisect| (((|Stream| |#1|) (|Integer|) (|Integer|) (|Stream| |#1|)) "\\spad{multisect(a,{}b,{}st)} selects the coefficients of \\spad{x**((a+b)*n+a)},{} and changes them to \\spad{x**n}.")) (|generalLambert| (((|Stream| |#1|) (|Stream| |#1|) (|Integer|) (|Integer|)) "\\spad{generalLambert(f(x),{}a,{}d)} returns \\spad{f(x**a) + f(x**(a + d)) + f(x**(a + 2 d)) + ...}. \\spad{f(x)} should have zero constant coefficient and \\spad{a} and \\spad{d} should be positive.")) (|evenlambert| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{evenlambert(st)} computes \\spad{f(x**2) + f(x**4) + f(x**6) + ...} if \\spad{st} is a stream representing \\spad{f(x)}. This function is used for computing infinite products. If \\spad{f(x)} is a power series with constant coefficient 1,{} then \\spad{prod(f(x**(2*n)),{}n=1..infinity) = exp(evenlambert(log(f(x))))}.")) (|oddlambert| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{oddlambert(st)} computes \\spad{f(x) + f(x**3) + f(x**5) + ...} if \\spad{st} is a stream representing \\spad{f(x)}. This function is used for computing infinite products. If \\spad{f}(\\spad{x}) is a power series with constant coefficient 1 then \\spad{prod(f(x**(2*n-1)),{}n=1..infinity) = exp(oddlambert(log(f(x))))}.")) (|lambert| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{lambert(st)} computes \\spad{f(x) + f(x**2) + f(x**3) + ...} if \\spad{st} is a stream representing \\spad{f(x)}. This function is used for computing infinite products. If \\spad{f(x)} is a power series with constant coefficient 1 then \\spad{prod(f(x**n),{}n = 1..infinity) = exp(lambert(log(f(x))))}.")) (|addiag| (((|Stream| |#1|) (|Stream| (|Stream| |#1|))) "\\spad{addiag(x)} performs diagonal addition of a stream of streams. if \\spad{x} = \\spad{[[a<0,{}0>,{}a<0,{}1>,{}..],{}[a<1,{}0>,{}a<1,{}1>,{}..],{}[a<2,{}0>,{}a<2,{}1>,{}..],{}..]} and \\spad{addiag(x) = [b<0,{}b<1>,{}...],{} then b<k> = sum(i+j=k,{}a<i,{}j>)}.")) (|revert| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{revert(a)} computes the inverse of a power series \\spad{a} with respect to composition. the series should have constant coefficient 0 and first order coefficient 1.")) (|lagrange| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{lagrange(g)} produces the power series for \\spad{f} where \\spad{f} is implicitly defined as \\spad{f(z) = z*g(f(z))}.")) (|compose| (((|Stream| |#1|) (|Stream| |#1|) (|Stream| |#1|)) "\\spad{compose(a,{}b)} composes the power series \\spad{a} with the power series \\spad{b}.")) (|eval| (((|Stream| |#1|) (|Stream| |#1|) |#1|) "\\spad{eval(a,{}r)} returns a stream of partial sums of the power series \\spad{a} evaluated at the power series variable equal to \\spad{r}.")) (|coerce| (((|Stream| |#1|) |#1|) "\\spad{coerce(r)} converts a ring element \\spad{r} to a stream with one element.")) (|gderiv| (((|Stream| |#1|) (|Mapping| |#1| (|Integer|)) (|Stream| |#1|)) "\\spad{gderiv(f,{}[a0,{}a1,{}a2,{}..])} returns \\spad{[f(0)*a0,{}f(1)*a1,{}f(2)*a2,{}..]}.")) (|deriv| (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{deriv(a)} returns the derivative of the power series with respect to the power series variable. Thus \\spad{deriv([a0,{}a1,{}a2,{}...])} returns \\spad{[a1,{}2 a2,{}3 a3,{}...]}.")) (|mapmult| (((|Stream| |#1|) (|Stream| |#1|) (|Stream| |#1|)) "\\spad{mapmult([a0,{}a1,{}..],{}[b0,{}b1,{}..])} returns \\spad{[a0*b0,{}a1*b1,{}..]}.")) (|int| (((|Stream| |#1|) |#1|) "\\spad{int(r)} returns [\\spad{r},{}\\spad{r+1},{}\\spad{r+2},{}...],{} where \\spad{r} is a ring element.")) (|oddintegers| (((|Stream| (|Integer|)) (|Integer|)) "\\spad{oddintegers(n)} returns \\spad{[n,{}n+2,{}n+4,{}...]}.")) (|integers| (((|Stream| (|Integer|)) (|Integer|)) "\\spad{integers(n)} returns \\spad{[n,{}n+1,{}n+2,{}...]}.")) (|monom| (((|Stream| |#1|) |#1| (|Integer|)) "\\spad{monom(deg,{}coef)} is a monomial of degree \\spad{deg} with coefficient \\spad{coef}.")) (|recip| (((|Union| (|Stream| |#1|) "failed") (|Stream| |#1|)) "\\spad{recip(a)} returns the power series reciprocal of \\spad{a},{} or \"failed\" if not possible.")) (/ (((|Stream| |#1|) (|Stream| |#1|) (|Stream| |#1|)) "\\spad{a / b} returns the power series quotient of \\spad{a} by \\spad{b}. An error message is returned if \\spad{b} is not invertible. This function is used in fixed point computations.")) (|exquo| (((|Union| (|Stream| |#1|) "failed") (|Stream| |#1|) (|Stream| |#1|)) "\\spad{exquo(a,{}b)} returns the power series quotient of \\spad{a} by \\spad{b},{} if the quotient exists,{} and \"failed\" otherwise")) (* (((|Stream| |#1|) (|Stream| |#1|) |#1|) "\\spad{a * r} returns the power series scalar multiplication of \\spad{a} by \\spad{r:} \\spad{[a0,{}a1,{}...] * r = [a0 * r,{}a1 * r,{}...]}") (((|Stream| |#1|) |#1| (|Stream| |#1|)) "\\spad{r * a} returns the power series scalar multiplication of \\spad{r} by \\spad{a}: \\spad{r * [a0,{}a1,{}...] = [r * a0,{}r * a1,{}...]}") (((|Stream| |#1|) (|Stream| |#1|) (|Stream| |#1|)) "\\spad{a * b} returns the power series (Cauchy) product of \\spad{a} and \\spad{b:} \\spad{[a0,{}a1,{}...] * [b0,{}b1,{}...] = [c0,{}c1,{}...]} where \\spad{ck = sum(i + j = k,{}\\spad{ai} * bk)}.")) (- (((|Stream| |#1|) (|Stream| |#1|)) "\\spad{- a} returns the power series negative of \\spad{a}: \\spad{- [a0,{}a1,{}...] = [- a0,{}- a1,{}...]}") (((|Stream| |#1|) (|Stream| |#1|) (|Stream| |#1|)) "\\spad{a - b} returns the power series difference of \\spad{a} and \\spad{b}: \\spad{[a0,{}a1,{}..] - [b0,{}b1,{}..] = [a0 - b0,{}a1 - b1,{}..]}")) (+ (((|Stream| |#1|) (|Stream| |#1|) (|Stream| |#1|)) "\\spad{a + b} returns the power series sum of \\spad{a} and \\spad{b}: \\spad{[a0,{}a1,{}..] + [b0,{}b1,{}..] = [a0 + b0,{}a1 + b1,{}..]}"))) 
 NIL 
@@ -4534,8 +4534,8 @@ NIL
 NIL 
 (-1151 |Coef| |var| |cen|) 
 ((|constructor| (NIL "Sparse Laurent series in one variable \\spadtype{SparseUnivariateLaurentSeries} is a domain representing Laurent series in one variable with coefficients in an arbitrary ring. The parameters of the type specify the coefficient ring,{} the power series variable,{} and the center of the power series expansion. For example,{} \\spad{SparseUnivariateLaurentSeries(Integer,{}x,{}3)} represents Laurent series in \\spad{(x - 3)} with integer coefficients.")) (|integrate| (($ $ (|Variable| |#2|)) "\\spad{integrate(f(x))} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 0. We may integrate a series when we can divide coefficients by integers.")) (|differentiate| (($ $ (|Variable| |#2|)) "\\spad{differentiate(f(x),{}x)} returns the derivative of \\spad{f(x)} with respect to \\spad{x}.")) (|coerce| (($ (|Variable| |#2|)) "\\spad{coerce(var)} converts the series variable \\spad{var} into a Laurent series."))) 
-(((-4521 "*") -2198 (-2139 (|has| |#1| (-365)) (|has| (-1159 |#1| |#2| |#3|) (-815))) (|has| |#1| (-172)) (-2139 (|has| |#1| (-365)) (|has| (-1159 |#1| |#2| |#3|) (-904)))) (-4512 -2198 (-2139 (|has| |#1| (-365)) (|has| (-1159 |#1| |#2| |#3|) (-815))) (|has| |#1| (-558)) (-2139 (|has| |#1| (-365)) (|has| (-1159 |#1| |#2| |#3|) (-904)))) (-4517 |has| |#1| (-365)) (-4511 |has| |#1| (-365)) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| (-568) (QUOTE (-1102))) (|HasCategory| |#1| (QUOTE (-365))) (-2198 (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-150)))) (-2198 (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-568)) (|devaluate| |#1|)))))) (-2198 (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-225))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-568)) (|devaluate| |#1|))))) (-2198 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-1021))) (|HasCategory| |#1| (QUOTE (-365)))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-1136))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -281) (LIST (QUOTE -1159) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)) (LIST (QUOTE -1159) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -303) (LIST (QUOTE -1159) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -523) (QUOTE (-1161)) (LIST (QUOTE -1159) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-568))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -2745) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-550))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-904))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-148))) (-2198 (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-148)))) (-2198 (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-558)))) (-2198 (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-172)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-365)))) (-2198 (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-365))))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (-2198 (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -281) (LIST (QUOTE -1159) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)) (LIST (QUOTE -1159) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -303) (LIST (QUOTE -1159) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -523) (QUOTE (-1161)) (LIST (QUOTE -1159) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-1021))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-1136))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568)))))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -3837) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2055) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|)))))) (-2198 (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-148))))) 
+(((-4523 "*") -2199 (-2141 (|has| |#1| (-365)) (|has| (-1159 |#1| |#2| |#3|) (-815))) (|has| |#1| (-172)) (-2141 (|has| |#1| (-365)) (|has| (-1159 |#1| |#2| |#3|) (-904)))) (-4514 -2199 (-2141 (|has| |#1| (-365)) (|has| (-1159 |#1| |#2| |#3|) (-815))) (|has| |#1| (-558)) (-2141 (|has| |#1| (-365)) (|has| (-1159 |#1| |#2| |#3|) (-904)))) (-4519 |has| |#1| (-365)) (-4513 |has| |#1| (-365)) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| (-568) (QUOTE (-1102))) (|HasCategory| |#1| (QUOTE (-365))) (-2199 (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-150)))) (-2199 (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-568)) (|devaluate| |#1|)))))) (-2199 (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-225))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-568)) (|devaluate| |#1|))))) (-2199 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-1021))) (|HasCategory| |#1| (QUOTE (-365)))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-1136))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -281) (LIST (QUOTE -1159) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)) (LIST (QUOTE -1159) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -303) (LIST (QUOTE -1159) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -523) (QUOTE (-1161)) (LIST (QUOTE -1159) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-568))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -2747) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-550))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-904))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-148))) (-2199 (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-148)))) (-2199 (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-558)))) (-2199 (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-172)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-365)))) (-2199 (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-365))))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (-2199 (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -281) (LIST (QUOTE -1159) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)) (LIST (QUOTE -1159) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -303) (LIST (QUOTE -1159) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -523) (QUOTE (-1161)) (LIST (QUOTE -1159) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-1021))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-1136))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568)))))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -1845) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2057) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|)))))) (-2199 (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1159 |#1| |#2| |#3|) (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-148))))) 
 (-1152 R -1478) 
 ((|constructor| (NIL "Computes sums of top-level expressions")) (|sum| ((|#2| |#2| (|SegmentBinding| |#2|)) "\\spad{sum(f(n),{} n = a..b)} returns \\spad{f}(a) + \\spad{f}(\\spad{a+1}) + ... + \\spad{f}(\\spad{b}).") ((|#2| |#2| (|Symbol|)) "\\spad{sum(a(n),{} n)} returns A(\\spad{n}) such that A(\\spad{n+1}) - A(\\spad{n}) = a(\\spad{n})."))) 
 NIL 
@@ -4550,24 +4550,24 @@ NIL
 NIL 
 (-1155 R) 
 ((|constructor| (NIL "This domain has no description"))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4515 |has| |#1| (-365)) (-4517 |has| |#1| (-6 -4517)) (-4514 . T) (-4513 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-1136))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-1181))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasCategory| |#1| (QUOTE (-225))) (|HasAttribute| |#1| (QUOTE -4517)) (|HasCategory| |#1| (QUOTE (-453))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4517 |has| |#1| (-365)) (-4519 |has| |#1| (-6 -4519)) (-4516 . T) (-4515 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-1136))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-1181))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasCategory| |#1| (QUOTE (-225))) (|HasAttribute| |#1| (QUOTE -4519)) (|HasCategory| |#1| (QUOTE (-453))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))))) 
 (-1156 E OV R P) 
 ((|constructor| (NIL "SupFractionFactorize contains the factor function for univariate polynomials over the quotient field of a ring \\spad{S} such that the package MultivariateFactorize works for \\spad{S}")) (|squareFree| (((|Factored| (|SparseUnivariatePolynomial| (|Fraction| |#4|))) (|SparseUnivariatePolynomial| (|Fraction| |#4|))) "\\spad{squareFree(p)} returns the square-free factorization of the univariate polynomial \\spad{p} with coefficients which are fractions of polynomials over \\spad{R}. Each factor has no repeated roots and the factors are pairwise relatively prime.")) (|factor| (((|Factored| (|SparseUnivariatePolynomial| (|Fraction| |#4|))) (|SparseUnivariatePolynomial| (|Fraction| |#4|))) "\\spad{factor(p)} factors the univariate polynomial \\spad{p} with coefficients which are fractions of polynomials over \\spad{R}."))) 
 NIL 
 NIL 
 (-1157 R) 
 ((|constructor| (NIL "This domain represents univariate polynomials over arbitrary (not necessarily commutative) coefficient rings. The variable is unspecified so that the variable displays as \\spad{?} on output. If it is necessary to specify the variable name,{} use type \\spadtype{UnivariatePolynomial}. The representation is sparse in the sense that only non-zero terms are represented. Note that if the coefficient ring is a field,{} this domain forms a euclidean domain.")) (|fmecg| (($ $ (|NonNegativeInteger|) |#1| $) "\\spad{fmecg(p1,{}e,{}r,{}p2)} finds \\spad{x} : \\spad{p1} - \\spad{r} * x**e * \\spad{p2}")) (|outputForm| (((|OutputForm|) $ (|OutputForm|)) "\\spad{outputForm(p,{}var)} converts the SparseUnivariatePolynomial \\spad{p} to an output form (see \\spadtype{OutputForm}) printed as a polynomial in the output form variable."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4515 |has| |#1| (-365)) (-4517 |has| |#1| (-6 -4517)) (-4514 . T) (-4513 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-1136))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasCategory| |#1| (QUOTE (-225))) (|HasAttribute| |#1| (QUOTE -4517)) (|HasCategory| |#1| (QUOTE (-453))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4517 |has| |#1| (-365)) (-4519 |has| |#1| (-6 -4519)) (-4516 . T) (-4515 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-1136))) (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasCategory| |#1| (QUOTE (-225))) (|HasAttribute| |#1| (QUOTE -4519)) (|HasCategory| |#1| (QUOTE (-453))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (|HasCategory| |#1| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))))) 
 (-1158 |Coef| |var| |cen|) 
 ((|constructor| (NIL "Sparse Puiseux series in one variable \\spadtype{SparseUnivariatePuiseuxSeries} is a domain representing Puiseux series in one variable with coefficients in an arbitrary ring. The parameters of the type specify the coefficient ring,{} the power series variable,{} and the center of the power series expansion. For example,{} \\spad{SparseUnivariatePuiseuxSeries(Integer,{}x,{}3)} represents Puiseux series in \\spad{(x - 3)} with \\spadtype{Integer} coefficients.")) (|integrate| (($ $ (|Variable| |#2|)) "\\spad{integrate(f(x))} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 0. We may integrate a series when we can divide coefficients by integers.")) (|differentiate| (($ $ (|Variable| |#2|)) "\\spad{differentiate(f(x),{}x)} returns the derivative of \\spad{f(x)} with respect to \\spad{x}.")) (|coerce| (($ (|Variable| |#2|)) "\\spad{coerce(var)} converts the series variable \\spad{var} into a Puiseux series."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-365)) (-4511 |has| |#1| (-365)) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568))) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568))) (|devaluate| |#1|))))) (|HasCategory| (-409 (-568)) (QUOTE (-1102))) (|HasCategory| |#1| (QUOTE (-365))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (-2198 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasSignature| |#1| (LIST (QUOTE -2745) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -3837) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2055) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|))))))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-365)) (-4513 |has| |#1| (-365)) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568))) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568))) (|devaluate| |#1|))))) (|HasCategory| (-409 (-568)) (QUOTE (-1102))) (|HasCategory| |#1| (QUOTE (-365))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (-2199 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasSignature| |#1| (LIST (QUOTE -2747) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -1845) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2057) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|))))))) 
 (-1159 |Coef| |var| |cen|) 
 ((|constructor| (NIL "Sparse Taylor series in one variable \\spadtype{SparseUnivariateTaylorSeries} is a domain representing Taylor series in one variable with coefficients in an arbitrary ring. The parameters of the type specify the coefficient ring,{} the power series variable,{} and the center of the power series expansion. For example,{} \\spadtype{SparseUnivariateTaylorSeries}(Integer,{}\\spad{x},{}3) represents Taylor series in \\spad{(x - 3)} with \\spadtype{Integer} coefficients.")) (|integrate| (($ $ (|Variable| |#2|)) "\\spad{integrate(f(x),{}x)} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 0. We may integrate a series when we can divide coefficients by integers.")) (|differentiate| (($ $ (|Variable| |#2|)) "\\spad{differentiate(f(x),{}x)} computes the derivative of \\spad{f(x)} with respect to \\spad{x}.")) (|univariatePolynomial| (((|UnivariatePolynomial| |#2| |#1|) $ (|NonNegativeInteger|)) "\\spad{univariatePolynomial(f,{}k)} returns a univariate polynomial \\indented{1}{consisting of the sum of all terms of \\spad{f} of degree \\spad{<= k}.}")) (|coerce| (($ (|Variable| |#2|)) "\\spad{coerce(var)} converts the series variable \\spad{var} into a \\indented{1}{Taylor series.}") (($ (|UnivariatePolynomial| |#2| |#1|)) "\\spad{coerce(p)} converts a univariate polynomial \\spad{p} in the variable \\spad{var} to a univariate Taylor series in \\spad{var}."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-763)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-763)) (|devaluate| |#1|))))) (|HasCategory| (-763) (QUOTE (-1102))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-763))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-763))))) (|HasSignature| |#1| (LIST (QUOTE -2745) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (|HasCategory| |#1| (QUOTE (-365))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -3837) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2055) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|))))))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-763)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-763)) (|devaluate| |#1|))))) (|HasCategory| (-763) (QUOTE (-1102))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-763))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-763))))) (|HasSignature| |#1| (LIST (QUOTE -2747) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (|HasCategory| |#1| (QUOTE (-365))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -1845) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2057) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|))))))) 
 (-1160) 
 ((|constructor| (NIL "This domain builds representations of boolean expressions for use with the \\axiomType{FortranCode} domain.")) (NOT (($ $) "\\spad{NOT(x)} returns the \\axiomType{Switch} expression representing \\spad{\\~~x}.") (($ (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $))) "\\spad{NOT(x)} returns the \\axiomType{Switch} expression representing \\spad{\\~~x}.")) (AND (($ (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $)) (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $))) "\\spad{AND(x,{}y)} returns the \\axiomType{Switch} expression representing \\spad{x and y}.")) (EQ (($ (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $)) (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $))) "\\spad{EQ(x,{}y)} returns the \\axiomType{Switch} expression representing \\spad{x = y}.")) (OR (($ (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $)) (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $))) "\\spad{OR(x,{}y)} returns the \\axiomType{Switch} expression representing \\spad{x or y}.")) (GE (($ (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $)) (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $))) "\\spad{GE(x,{}y)} returns the \\axiomType{Switch} expression representing \\spad{x>=y}.")) (LE (($ (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $)) (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $))) "\\spad{LE(x,{}y)} returns the \\axiomType{Switch} expression representing \\spad{x<=y}.")) (GT (($ (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $)) (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $))) "\\spad{GT(x,{}y)} returns the \\axiomType{Switch} expression representing \\spad{x>y}.")) (LT (($ (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $)) (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| $))) "\\spad{LT(x,{}y)} returns the \\axiomType{Switch} expression representing \\spad{x<y}.")) (|coerce| (($ (|Symbol|)) "\\spad{coerce(s)} is not documented"))) 
 NIL 
@@ -4582,8 +4582,8 @@ NIL
 NIL 
 (-1163 R) 
 ((|constructor| (NIL "This domain implements symmetric polynomial"))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-6 -4517)) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (-12 (|HasCategory| (-972) (QUOTE (-137))) (|HasCategory| |#1| (QUOTE (-558)))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#1| (QUOTE -4517))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-6 -4519)) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-453))) (-12 (|HasCategory| (-972) (QUOTE (-137))) (|HasCategory| |#1| (QUOTE (-558)))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasAttribute| |#1| (QUOTE -4519))) 
 (-1164) 
 ((|constructor| (NIL "Creates and manipulates one global symbol table for FORTRAN code generation,{} containing details of types,{} dimensions,{} and argument lists.")) (|symbolTableOf| (((|SymbolTable|) (|Symbol|) $) "\\spad{symbolTableOf(f,{}tab)} returns the symbol table of \\spad{f}")) (|argumentListOf| (((|List| (|Symbol|)) (|Symbol|) $) "\\spad{argumentListOf(f,{}tab)} returns the argument list of \\spad{f}")) (|returnTypeOf| (((|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void")) (|Symbol|) $) "\\spad{returnTypeOf(f,{}tab)} returns the type of the object returned by \\spad{f}")) (|empty| (($) "\\spad{empty()} creates a new,{} empty symbol table.")) (|printTypes| (((|Void|) (|Symbol|)) "\\spad{printTypes(tab)} produces FORTRAN type declarations from \\spad{tab},{} on the current FORTRAN output stream")) (|printHeader| (((|Void|)) "\\spad{printHeader()} produces the FORTRAN header for the current subprogram in the global symbol table on the current FORTRAN output stream.") (((|Void|) (|Symbol|)) "\\spad{printHeader(f)} produces the FORTRAN header for subprogram \\spad{f} in the global symbol table on the current FORTRAN output stream.") (((|Void|) (|Symbol|) $) "\\spad{printHeader(f,{}tab)} produces the FORTRAN header for subprogram \\spad{f} in symbol table \\spad{tab} on the current FORTRAN output stream.")) (|returnType!| (((|Void|) (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) "\\spad{returnType!(t)} declares that the return type of he current subprogram in the global symbol table is \\spad{t}.") (((|Void|) (|Symbol|) (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) "\\spad{returnType!(f,{}t)} declares that the return type of subprogram \\spad{f} in the global symbol table is \\spad{t}.") (((|Void|) (|Symbol|) (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void")) $) "\\spad{returnType!(f,{}t,{}tab)} declares that the return type of subprogram \\spad{f} in symbol table \\spad{tab} is \\spad{t}.")) (|argumentList!| (((|Void|) (|List| (|Symbol|))) "\\spad{argumentList!(l)} declares that the argument list for the current subprogram in the global symbol table is \\spad{l}.") (((|Void|) (|Symbol|) (|List| (|Symbol|))) "\\spad{argumentList!(f,{}l)} declares that the argument list for subprogram \\spad{f} in the global symbol table is \\spad{l}.") (((|Void|) (|Symbol|) (|List| (|Symbol|)) $) "\\spad{argumentList!(f,{}l,{}tab)} declares that the argument list for subprogram \\spad{f} in symbol table \\spad{tab} is \\spad{l}.")) (|endSubProgram| (((|Symbol|)) "\\spad{endSubProgram()} asserts that we are no longer processing the current subprogram.")) (|currentSubProgram| (((|Symbol|)) "\\spad{currentSubProgram()} returns the name of the current subprogram being processed")) (|newSubProgram| (((|Void|) (|Symbol|)) "\\spad{newSubProgram(f)} asserts that from now on type declarations are part of subprogram \\spad{f}.")) (|declare!| (((|FortranType|) (|Symbol|) (|FortranType|) (|Symbol|)) "\\spad{declare!(u,{}t,{}asp)} declares the parameter \\spad{u} to have type \\spad{t} in \\spad{asp}.") (((|FortranType|) (|Symbol|) (|FortranType|)) "\\spad{declare!(u,{}t)} declares the parameter \\spad{u} to have type \\spad{t} in the current level of the symbol table.") (((|FortranType|) (|List| (|Symbol|)) (|FortranType|) (|Symbol|) $) "\\spad{declare!(u,{}t,{}asp,{}tab)} declares the parameters \\spad{u} of subprogram \\spad{asp} to have type \\spad{t} in symbol table \\spad{tab}.") (((|FortranType|) (|Symbol|) (|FortranType|) (|Symbol|) $) "\\spad{declare!(u,{}t,{}asp,{}tab)} declares the parameter \\spad{u} of subprogram \\spad{asp} to have type \\spad{t} in symbol table \\spad{tab}.")) (|clearTheSymbolTable| (((|Void|) (|Symbol|)) "\\spad{clearTheSymbolTable(x)} removes the symbol \\spad{x} from the table") (((|Void|)) "\\spad{clearTheSymbolTable()} clears the current symbol table.")) (|showTheSymbolTable| (($) "\\spad{showTheSymbolTable()} returns the current symbol table."))) 
 NIL 
@@ -4606,8 +4606,8 @@ NIL
 NIL 
 (-1169 |Key| |Entry|) 
 ((|constructor| (NIL "This is the general purpose table type. The keys are hashed to look up the entries. This creates a \\spadtype{HashTable} if equal for the Key domain is consistent with Lisp EQUAL otherwise an \\spadtype{AssociationList}"))) 
-((-4519 . T) (-4520 . T)) 
-((|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3649) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4083) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-1090))) (-2198 (|HasCategory| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-1090)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090))))) 
+((-4521 . T) (-4522 . T)) 
+((|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090))) (-12 (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (LIST (QUOTE -303) (LIST (QUOTE -2) (LIST (QUOTE |:|) (QUOTE -3651) (|devaluate| |#1|)) (LIST (QUOTE |:|) (QUOTE -4085) (|devaluate| |#2|))))) (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#2| (QUOTE (-1090))) (-2199 (|HasCategory| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (QUOTE (-1090))) (|HasCategory| |#2| (QUOTE (-1090)))) (-12 (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|))) (|HasCategory| |#2| (QUOTE (-1090))))) 
 (-1170 R) 
 ((|constructor| (NIL "Expands tangents of sums and scalar products.")) (|tanNa| ((|#1| |#1| (|Integer|)) "\\spad{tanNa(a,{} n)} returns \\spad{f(a)} such that if \\spad{a = tan(u)} then \\spad{f(a) = tan(n * u)}.")) (|tanAn| (((|SparseUnivariatePolynomial| |#1|) |#1| (|PositiveInteger|)) "\\spad{tanAn(a,{} n)} returns \\spad{P(x)} such that if \\spad{a = tan(u)} then \\spad{P(tan(u/n)) = 0}.")) (|tanSum| ((|#1| (|List| |#1|)) "\\spad{tanSum([a1,{}...,{}an])} returns \\spad{f(a1,{}...,{}an)} such that if \\spad{\\spad{ai} = tan(\\spad{ui})} then \\spad{f(a1,{}...,{}an) = tan(u1 + ... + un)}."))) 
 NIL 
@@ -4618,7 +4618,7 @@ NIL
 NIL 
 (-1172 |Key| |Entry|) 
 ((|constructor| (NIL "A table aggregate is a model of a table,{} \\spadignore{i.e.} a discrete many-to-one mapping from keys to entries.")) (|map| (($ (|Mapping| |#2| |#2| |#2|) $ $) "\\spad{map(fn,{}t1,{}t2)} creates a new table \\spad{t} from given tables \\spad{t1} and \\spad{t2} with elements \\spad{fn}(\\spad{x},{}\\spad{y}) where \\spad{x} and \\spad{y} are corresponding elements from \\spad{t1} and \\spad{t2} respectively.")) (|table| (($ (|List| (|Record| (|:| |key| |#1|) (|:| |entry| |#2|)))) "\\spad{table([x,{}y,{}...,{}z])} creates a table consisting of entries \\axiom{\\spad{x},{}\\spad{y},{}...,{}\\spad{z}}.") (($) "\\indented{1}{table()\\$\\spad{T} creates an empty table of type \\spad{T}.} \\blankline \\spad{E} Data:=Record(age:Integer,{}gender:String) \\spad{E} a1:AssociationList(String,{}Data):=table() \\spad{E} \\spad{a1}.\"tim\":=[55,{}\"male\"]\\$Data")) (|setelt| ((|#2| $ |#1| |#2|) "\\spad{setelt(t,{}k,{}e)} (also written \\axiom{\\spad{t}.\\spad{k} \\spad{:=} \\spad{e}}) is equivalent to \\axiom{(insert([\\spad{k},{}\\spad{e}],{}\\spad{t}); \\spad{e})}."))) 
-((-4520 . T) (-3973 . T)) 
+((-4522 . T) (-3973 . T)) 
 NIL 
 (-1173 |Key| |Entry|) 
 ((|constructor| (NIL "\\axiom{TabulatedComputationPackage(Key ,{}Entry)} provides some modest support for dealing with operations with type \\axiom{Key \\spad{->} Entry}. The result of such operations can be stored and retrieved with this package by using a hash-table. The user does not need to worry about the management of this hash-table. However,{} onnly one hash-table is built by calling \\axiom{TabulatedComputationPackage(Key ,{}Entry)}.")) (|insert!| (((|Void|) |#1| |#2|) "\\axiom{insert!(\\spad{x},{}\\spad{y})} stores the item whose key is \\axiom{\\spad{x}} and whose entry is \\axiom{\\spad{y}}.")) (|extractIfCan| (((|Union| |#2| "failed") |#1|) "\\axiom{extractIfCan(\\spad{x})} searches the item whose key is \\axiom{\\spad{x}}.")) (|makingStats?| (((|Boolean|)) "\\axiom{makingStats?()} returns \\spad{true} iff the statisitics process is running.")) (|printingInfo?| (((|Boolean|)) "\\axiom{printingInfo?()} returns \\spad{true} iff messages are printed when manipulating items from the hash-table.")) (|usingTable?| (((|Boolean|)) "\\axiom{usingTable?()} returns \\spad{true} iff the hash-table is used")) (|clearTable!| (((|Void|)) "\\axiom{clearTable!()} clears the hash-table and assumes that it will no longer be used.")) (|printStats!| (((|Void|)) "\\axiom{printStats!()} prints the statistics.")) (|startStats!| (((|Void|) (|String|)) "\\axiom{startStats!(\\spad{x})} initializes the statisitics process and sets the comments to display when statistics are printed")) (|printInfo!| (((|Void|) (|String|) (|String|)) "\\axiom{printInfo!(\\spad{x},{}\\spad{y})} initializes the mesages to be printed when manipulating items from the hash-table. If a key is retrieved then \\axiom{\\spad{x}} is displayed. If an item is stored then \\axiom{\\spad{y}} is displayed.")) (|initTable!| (((|Void|)) "\\axiom{initTable!()} initializes the hash-table."))) 
@@ -4658,7 +4658,7 @@ NIL
 NIL 
 (-1182 S) 
 ((|constructor| (NIL "\\spadtype{Tree(S)} is a basic domains of tree structures. Each tree is either empty or else is a node consisting of a value and a list of (sub)trees.")) (|cyclicParents| (((|List| $) $) "\\indented{1}{cyclicParents(\\spad{t}) returns a list of cycles that are parents of \\spad{t}.} \\blankline \\spad{X} t1:=tree [1,{}2,{}3,{}4] \\spad{X} cyclicParents \\spad{t1}")) (|cyclicEqual?| (((|Boolean|) $ $) "\\indented{1}{cyclicEqual?(\\spad{t1},{} \\spad{t2}) tests of two cyclic trees have} \\indented{1}{the same structure.} \\blankline \\spad{X} t1:=tree [1,{}2,{}3,{}4] \\spad{X} t2:=tree [1,{}2,{}3,{}4] \\spad{X} cyclicEqual?(\\spad{t1},{}\\spad{t2})")) (|cyclicEntries| (((|List| $) $) "\\indented{1}{cyclicEntries(\\spad{t}) returns a list of top-level cycles in tree \\spad{t}.} \\blankline \\spad{X} t1:=tree [1,{}2,{}3,{}4] \\spad{X} cyclicEntries \\spad{t1}")) (|cyclicCopy| (($ $) "\\indented{1}{cyclicCopy(\\spad{l}) makes a copy of a (possibly) cyclic tree \\spad{l}.} \\blankline \\spad{X} t1:=tree [1,{}2,{}3,{}4] \\spad{X} cyclicCopy \\spad{t1}")) (|cyclic?| (((|Boolean|) $) "\\indented{1}{cyclic?(\\spad{t}) tests if \\spad{t} is a cyclic tree.} \\blankline \\spad{X} t1:=tree [1,{}2,{}3,{}4] \\spad{X} cyclic? \\spad{t1}")) (|tree| (($ |#1|) "\\indented{1}{tree(\\spad{nd}) creates a tree with value \\spad{nd},{} and no children} \\blankline \\spad{X} tree 6") (($ (|List| |#1|)) "\\indented{1}{tree(\\spad{ls}) creates a tree from a list of elements of \\spad{s}.} \\blankline \\spad{X} tree [1,{}2,{}3,{}4]") (($ |#1| (|List| $)) "\\indented{1}{tree(\\spad{nd},{}\\spad{ls}) creates a tree with value \\spad{nd},{} and children \\spad{ls}.} \\blankline \\spad{X} t1:=tree [1,{}2,{}3,{}4] \\spad{X} tree(5,{}[\\spad{t1}])"))) 
-((-4520 . T) (-4519 . T)) 
+((-4522 . T) (-4521 . T)) 
 ((|HasCategory| |#1| (QUOTE (-1090))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090))))) 
 (-1183 S) 
 ((|constructor| (NIL "Category for the trigonometric functions.")) (|tan| (($ $) "\\spad{tan(x)} returns the tangent of \\spad{x}.")) (|sin| (($ $) "\\spad{sin(x)} returns the sine of \\spad{x}.")) (|sec| (($ $) "\\spad{sec(x)} returns the secant of \\spad{x}.")) (|csc| (($ $) "\\spad{csc(x)} returns the cosecant of \\spad{x}.")) (|cot| (($ $) "\\spad{cot(x)} returns the cotangent of \\spad{x}.")) (|cos| (($ $) "\\spad{cos(x)} returns the cosine of \\spad{x}."))) 
@@ -4686,12 +4686,12 @@ NIL
 ((|HasCategory| |#4| (QUOTE (-370)))) 
 (-1189 R E V P) 
 ((|constructor| (NIL "The category of triangular sets of multivariate polynomials with coefficients in an integral domain. Let \\axiom{\\spad{R}} be an integral domain and \\axiom{\\spad{V}} a finite ordered set of variables,{} say \\axiom{\\spad{X1} < \\spad{X2} < ... < \\spad{Xn}}. A set \\axiom{\\spad{S}} of polynomials in \\axiom{\\spad{R}[\\spad{X1},{}\\spad{X2},{}...,{}\\spad{Xn}]} is triangular if no elements of \\axiom{\\spad{S}} lies in \\axiom{\\spad{R}},{} and if two distinct elements of \\axiom{\\spad{S}} have distinct main variables. Note that the empty set is a triangular set. A triangular set is not necessarily a (lexicographical) Groebner basis and the notion of reduction related to triangular sets is based on the recursive view of polynomials. We recall this notion here and refer to [1] for more details. A polynomial \\axiom{\\spad{P}} is reduced \\spad{w}.\\spad{r}.\\spad{t} a non-constant polynomial \\axiom{\\spad{Q}} if the degree of \\axiom{\\spad{P}} in the main variable of \\axiom{\\spad{Q}} is less than the main degree of \\axiom{\\spad{Q}}. A polynomial \\axiom{\\spad{P}} is reduced \\spad{w}.\\spad{r}.\\spad{t} a triangular set \\axiom{\\spad{T}} if it is reduced \\spad{w}.\\spad{r}.\\spad{t}. every polynomial of \\axiom{\\spad{T}}.")) (|coHeight| (((|NonNegativeInteger|) $) "\\axiom{coHeight(\\spad{ts})} returns \\axiom{size()\\spad{\\$}\\spad{V}} minus \\axiom{\\spad{\\#}\\spad{ts}}.")) (|extend| (($ $ |#4|) "\\axiom{extend(\\spad{ts},{}\\spad{p})} returns a triangular set which encodes the simple extension by \\axiom{\\spad{p}} of the extension of the base field defined by \\axiom{\\spad{ts}},{} according to the properties of triangular sets of the current category. If the required properties do not hold an error is returned.")) (|extendIfCan| (((|Union| $ "failed") $ |#4|) "\\axiom{extendIfCan(\\spad{ts},{}\\spad{p})} returns a triangular set which encodes the simple extension by \\axiom{\\spad{p}} of the extension of the base field defined by \\axiom{\\spad{ts}},{} according to the properties of triangular sets of the current domain. If the required properties do not hold then \"failed\" is returned. This operation encodes in some sense the properties of the triangular sets of the current category. Is is used to implement the \\axiom{construct} operation to guarantee that every triangular set build from a list of polynomials has the required properties.")) (|select| (((|Union| |#4| "failed") $ |#3|) "\\axiom{select(\\spad{ts},{}\\spad{v})} returns the polynomial of \\axiom{\\spad{ts}} with \\axiom{\\spad{v}} as main variable,{} if any.")) (|algebraic?| (((|Boolean|) |#3| $) "\\axiom{algebraic?(\\spad{v},{}\\spad{ts})} returns \\spad{true} iff \\axiom{\\spad{v}} is the main variable of some polynomial in \\axiom{\\spad{ts}}.")) (|algebraicVariables| (((|List| |#3|) $) "\\axiom{algebraicVariables(\\spad{ts})} returns the decreasingly sorted list of the main variables of the polynomials of \\axiom{\\spad{ts}}.")) (|rest| (((|Union| $ "failed") $) "\\axiom{rest(\\spad{ts})} returns the polynomials of \\axiom{\\spad{ts}} with smaller main variable than \\axiom{mvar(\\spad{ts})} if \\axiom{\\spad{ts}} is not empty,{} otherwise returns \"failed\"")) (|last| (((|Union| |#4| "failed") $) "\\axiom{last(\\spad{ts})} returns the polynomial of \\axiom{\\spad{ts}} with smallest main variable if \\axiom{\\spad{ts}} is not empty,{} otherwise returns \\axiom{\"failed\"}.")) (|first| (((|Union| |#4| "failed") $) "\\axiom{first(\\spad{ts})} returns the polynomial of \\axiom{\\spad{ts}} with greatest main variable if \\axiom{\\spad{ts}} is not empty,{} otherwise returns \\axiom{\"failed\"}.")) (|zeroSetSplitIntoTriangularSystems| (((|List| (|Record| (|:| |close| $) (|:| |open| (|List| |#4|)))) (|List| |#4|)) "\\axiom{zeroSetSplitIntoTriangularSystems(\\spad{lp})} returns a list of triangular systems \\axiom{[[\\spad{ts1},{}\\spad{qs1}],{}...,{}[\\spad{tsn},{}\\spad{qsn}]]} such that the zero set of \\axiom{\\spad{lp}} is the union of the closures of the \\axiom{W_i} where \\axiom{W_i} consists of the zeros of \\axiom{\\spad{ts}} which do not cancel any polynomial in \\axiom{qsi}.")) (|zeroSetSplit| (((|List| $) (|List| |#4|)) "\\axiom{zeroSetSplit(\\spad{lp})} returns a list \\axiom{\\spad{lts}} of triangular sets such that the zero set of \\axiom{\\spad{lp}} is the union of the closures of the regular zero sets of the members of \\axiom{\\spad{lts}}.")) (|reduceByQuasiMonic| ((|#4| |#4| $) "\\axiom{reduceByQuasiMonic(\\spad{p},{}\\spad{ts})} returns the same as \\axiom{remainder(\\spad{p},{}collectQuasiMonic(\\spad{ts})).polnum}.")) (|collectQuasiMonic| (($ $) "\\axiom{collectQuasiMonic(\\spad{ts})} returns the subset of \\axiom{\\spad{ts}} consisting of the polynomials with initial in \\axiom{\\spad{R}}.")) (|removeZero| ((|#4| |#4| $) "\\axiom{removeZero(\\spad{p},{}\\spad{ts})} returns \\axiom{0} if \\axiom{\\spad{p}} reduces to \\axiom{0} by pseudo-division \\spad{w}.\\spad{r}.\\spad{t} \\axiom{\\spad{ts}} otherwise returns a polynomial \\axiom{\\spad{q}} computed from \\axiom{\\spad{p}} by removing any coefficient in \\axiom{\\spad{p}} reducing to \\axiom{0}.")) (|initiallyReduce| ((|#4| |#4| $) "\\axiom{initiallyReduce(\\spad{p},{}\\spad{ts})} returns a polynomial \\axiom{\\spad{r}} such that \\axiom{initiallyReduced?(\\spad{r},{}\\spad{ts})} holds and there exists some product \\axiom{\\spad{h}} of \\axiom{initials(\\spad{ts})} such that \\axiom{\\spad{h*p} - \\spad{r}} lies in the ideal generated by \\axiom{\\spad{ts}}.")) (|headReduce| ((|#4| |#4| $) "\\axiom{headReduce(\\spad{p},{}\\spad{ts})} returns a polynomial \\axiom{\\spad{r}} such that \\axiom{headReduce?(\\spad{r},{}\\spad{ts})} holds and there exists some product \\axiom{\\spad{h}} of \\axiom{initials(\\spad{ts})} such that \\axiom{\\spad{h*p} - \\spad{r}} lies in the ideal generated by \\axiom{\\spad{ts}}.")) (|stronglyReduce| ((|#4| |#4| $) "\\axiom{stronglyReduce(\\spad{p},{}\\spad{ts})} returns a polynomial \\axiom{\\spad{r}} such that \\axiom{stronglyReduced?(\\spad{r},{}\\spad{ts})} holds and there exists some product \\axiom{\\spad{h}} of \\axiom{initials(\\spad{ts})} such that \\axiom{\\spad{h*p} - \\spad{r}} lies in the ideal generated by \\axiom{\\spad{ts}}.")) (|rewriteSetWithReduction| (((|List| |#4|) (|List| |#4|) $ (|Mapping| |#4| |#4| |#4|) (|Mapping| (|Boolean|) |#4| |#4|)) "\\axiom{rewriteSetWithReduction(\\spad{lp},{}\\spad{ts},{}redOp,{}redOp?)} returns a list \\axiom{\\spad{lq}} of polynomials such that \\axiom{[reduce(\\spad{p},{}\\spad{ts},{}redOp,{}redOp?) for \\spad{p} in \\spad{lp}]} and \\axiom{\\spad{lp}} have the same zeros inside the regular zero set of \\axiom{\\spad{ts}}. Moreover,{} for every polynomial \\axiom{\\spad{q}} in \\axiom{\\spad{lq}} and every polynomial \\axiom{\\spad{t}} in \\axiom{\\spad{ts}} \\axiom{redOp?(\\spad{q},{}\\spad{t})} holds and there exists a polynomial \\axiom{\\spad{p}} in the ideal generated by \\axiom{\\spad{lp}} and a product \\axiom{\\spad{h}} of \\axiom{initials(\\spad{ts})} such that \\axiom{\\spad{h*p} - \\spad{r}} lies in the ideal generated by \\axiom{\\spad{ts}}. The operation \\axiom{redOp} must satisfy the following conditions. For every \\axiom{\\spad{p}} and \\axiom{\\spad{q}} we have \\axiom{redOp?(redOp(\\spad{p},{}\\spad{q}),{}\\spad{q})} and there exists an integer \\axiom{\\spad{e}} and a polynomial \\axiom{\\spad{f}} such that \\axiom{init(\\spad{q})^e*p = \\spad{f*q} + redOp(\\spad{p},{}\\spad{q})}.")) (|reduce| ((|#4| |#4| $ (|Mapping| |#4| |#4| |#4|) (|Mapping| (|Boolean|) |#4| |#4|)) "\\axiom{reduce(\\spad{p},{}\\spad{ts},{}redOp,{}redOp?)} returns a polynomial \\axiom{\\spad{r}} such that \\axiom{redOp?(\\spad{r},{}\\spad{p})} holds for every \\axiom{\\spad{p}} of \\axiom{\\spad{ts}} and there exists some product \\axiom{\\spad{h}} of the initials of the members of \\axiom{\\spad{ts}} such that \\axiom{\\spad{h*p} - \\spad{r}} lies in the ideal generated by \\axiom{\\spad{ts}}. The operation \\axiom{redOp} must satisfy the following conditions. For every \\axiom{\\spad{p}} and \\axiom{\\spad{q}} we have \\axiom{redOp?(redOp(\\spad{p},{}\\spad{q}),{}\\spad{q})} and there exists an integer \\axiom{\\spad{e}} and a polynomial \\axiom{\\spad{f}} such that \\axiom{init(\\spad{q})^e*p = \\spad{f*q} + redOp(\\spad{p},{}\\spad{q})}.")) (|autoReduced?| (((|Boolean|) $ (|Mapping| (|Boolean|) |#4| (|List| |#4|))) "\\axiom{autoReduced?(\\spad{ts},{}redOp?)} returns \\spad{true} iff every element of \\axiom{\\spad{ts}} is reduced \\spad{w}.\\spad{r}.\\spad{t} to every other in the sense of \\axiom{redOp?}")) (|initiallyReduced?| (((|Boolean|) $) "\\spad{initiallyReduced?(ts)} returns \\spad{true} iff for every element \\axiom{\\spad{p}} of \\axiom{\\spad{ts}}. \\axiom{\\spad{p}} and all its iterated initials are reduced \\spad{w}.\\spad{r}.\\spad{t}. to the other elements of \\axiom{\\spad{ts}} with the same main variable.") (((|Boolean|) |#4| $) "\\axiom{initiallyReduced?(\\spad{p},{}\\spad{ts})} returns \\spad{true} iff \\axiom{\\spad{p}} and all its iterated initials are reduced \\spad{w}.\\spad{r}.\\spad{t}. to the elements of \\axiom{\\spad{ts}} with the same main variable.")) (|headReduced?| (((|Boolean|) $) "\\spad{headReduced?(ts)} returns \\spad{true} iff the head of every element of \\axiom{\\spad{ts}} is reduced \\spad{w}.\\spad{r}.\\spad{t} to any other element of \\axiom{\\spad{ts}}.") (((|Boolean|) |#4| $) "\\axiom{headReduced?(\\spad{p},{}\\spad{ts})} returns \\spad{true} iff the head of \\axiom{\\spad{p}} is reduced \\spad{w}.\\spad{r}.\\spad{t}. \\axiom{\\spad{ts}}.")) (|stronglyReduced?| (((|Boolean|) $) "\\axiom{stronglyReduced?(\\spad{ts})} returns \\spad{true} iff every element of \\axiom{\\spad{ts}} is reduced \\spad{w}.\\spad{r}.\\spad{t} to any other element of \\axiom{\\spad{ts}}.") (((|Boolean|) |#4| $) "\\axiom{stronglyReduced?(\\spad{p},{}\\spad{ts})} returns \\spad{true} iff \\axiom{\\spad{p}} is reduced \\spad{w}.\\spad{r}.\\spad{t}. \\axiom{\\spad{ts}}.")) (|reduced?| (((|Boolean|) |#4| $ (|Mapping| (|Boolean|) |#4| |#4|)) "\\axiom{reduced?(\\spad{p},{}\\spad{ts},{}redOp?)} returns \\spad{true} iff \\axiom{\\spad{p}} is reduced \\spad{w}.\\spad{r}.\\spad{t}.in the sense of the operation \\axiom{redOp?},{} that is if for every \\axiom{\\spad{t}} in \\axiom{\\spad{ts}} \\axiom{redOp?(\\spad{p},{}\\spad{t})} holds.")) (|normalized?| (((|Boolean|) $) "\\axiom{normalized?(\\spad{ts})} returns \\spad{true} iff for every axiom{\\spad{p}} in \\axiom{\\spad{ts}} we have \\axiom{normalized?(\\spad{p},{}us)} where \\axiom{us} is \\axiom{collectUnder(\\spad{ts},{}mvar(\\spad{p}))}.") (((|Boolean|) |#4| $) "\\axiom{normalized?(\\spad{p},{}\\spad{ts})} returns \\spad{true} iff \\axiom{\\spad{p}} and all its iterated initials have degree zero \\spad{w}.\\spad{r}.\\spad{t}. the main variables of the polynomials of \\axiom{\\spad{ts}}")) (|quasiComponent| (((|Record| (|:| |close| (|List| |#4|)) (|:| |open| (|List| |#4|))) $) "\\axiom{quasiComponent(\\spad{ts})} returns \\axiom{[\\spad{lp},{}\\spad{lq}]} where \\axiom{\\spad{lp}} is the list of the members of \\axiom{\\spad{ts}} and \\axiom{\\spad{lq}}is \\axiom{initials(\\spad{ts})}.")) (|degree| (((|NonNegativeInteger|) $) "\\axiom{degree(\\spad{ts})} returns the product of main degrees of the members of \\axiom{\\spad{ts}}.")) (|initials| (((|List| |#4|) $) "\\axiom{initials(\\spad{ts})} returns the list of the non-constant initials of the members of \\axiom{\\spad{ts}}.")) (|basicSet| (((|Union| (|Record| (|:| |bas| $) (|:| |top| (|List| |#4|))) "failed") (|List| |#4|) (|Mapping| (|Boolean|) |#4|) (|Mapping| (|Boolean|) |#4| |#4|)) "\\axiom{basicSet(\\spad{ps},{}pred?,{}redOp?)} returns the same as \\axiom{basicSet(\\spad{qs},{}redOp?)} where \\axiom{\\spad{qs}} consists of the polynomials of \\axiom{\\spad{ps}} satisfying property \\axiom{pred?}.") (((|Union| (|Record| (|:| |bas| $) (|:| |top| (|List| |#4|))) "failed") (|List| |#4|) (|Mapping| (|Boolean|) |#4| |#4|)) "\\axiom{basicSet(\\spad{ps},{}redOp?)} returns \\axiom{[\\spad{bs},{}\\spad{ts}]} where \\axiom{concat(\\spad{bs},{}\\spad{ts})} is \\axiom{\\spad{ps}} and \\axiom{\\spad{bs}} is a basic set in Wu Wen Tsun sense of \\axiom{\\spad{ps}} \\spad{w}.\\spad{r}.\\spad{t} the reduction-test \\axiom{redOp?},{} if no non-zero constant polynomial lie in \\axiom{\\spad{ps}},{} otherwise \\axiom{\"failed\"} is returned.")) (|infRittWu?| (((|Boolean|) $ $) "\\axiom{infRittWu?(\\spad{ts1},{}\\spad{ts2})} returns \\spad{true} iff \\axiom{\\spad{ts2}} has higher rank than \\axiom{\\spad{ts1}} in Wu Wen Tsun sense."))) 
-((-4520 . T) (-4519 . T) (-3973 . T)) 
+((-4522 . T) (-4521 . T) (-3973 . T)) 
 NIL 
 (-1190 |Coef|) 
 ((|constructor| (NIL "\\spadtype{TaylorSeries} is a general multivariate Taylor series domain over the ring Coef and with variables of type Symbol.")) (|fintegrate| (($ (|Mapping| $) (|Symbol|) |#1|) "\\spad{fintegrate(f,{}v,{}c)} is the integral of \\spad{f()} with respect \\indented{1}{to \\spad{v} and having \\spad{c} as the constant of integration.} \\indented{1}{The evaluation of \\spad{f()} is delayed.}")) (|integrate| (($ $ (|Symbol|) |#1|) "\\spad{integrate(s,{}v,{}c)} is the integral of \\spad{s} with respect \\indented{1}{to \\spad{v} and having \\spad{c} as the constant of integration.}")) (|coerce| (($ (|Polynomial| |#1|)) "\\spad{coerce(s)} regroups terms of \\spad{s} by total degree \\indented{1}{and forms a series.}") (($ (|Symbol|)) "\\spad{coerce(s)} converts a variable to a Taylor series")) (|coefficient| (((|Polynomial| |#1|) $ (|NonNegativeInteger|)) "\\spad{coefficient(s,{} n)} gives the terms of total degree \\spad{n}."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4514 . T) (-4513 . T) (-4516 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-558))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-365)))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4516 . T) (-4515 . T) (-4518 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-558))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-365)))) 
 (-1191 |Curve|) 
 ((|constructor| (NIL "Package for constructing tubes around 3-dimensional parametric curves. Domain of tubes around 3-dimensional parametric curves.")) (|tube| (($ |#1| (|List| (|List| (|Point| (|DoubleFloat|)))) (|Boolean|)) "\\spad{tube(c,{}ll,{}b)} creates a tube of the domain \\spadtype{TubePlot} from a space curve \\spad{c} of the category \\spadtype{PlottableSpaceCurveCategory},{} a list of lists of points (loops) \\spad{ll} and a boolean \\spad{b} which if \\spad{true} indicates a closed tube,{} or if \\spad{false} an open tube.")) (|setClosed| (((|Boolean|) $ (|Boolean|)) "\\spad{setClosed(t,{}b)} declares the given tube plot \\spad{t} to be closed if \\spad{b} is \\spad{true},{} or if \\spad{b} is \\spad{false},{} \\spad{t} is set to be open.")) (|open?| (((|Boolean|) $) "\\spad{open?(t)} tests whether the given tube plot \\spad{t} is open.")) (|closed?| (((|Boolean|) $) "\\spad{closed?(t)} tests whether the given tube plot \\spad{t} is closed.")) (|listLoops| (((|List| (|List| (|Point| (|DoubleFloat|)))) $) "\\spad{listLoops(t)} returns the list of lists of points,{} or the 'loops',{} of the given tube plot \\spad{t}.")) (|getCurve| ((|#1| $) "\\spad{getCurve(t)} returns the \\spadtype{PlottableSpaceCurveCategory} representing the parametric curve of the given tube plot \\spad{t}."))) 
 NIL 
@@ -4726,7 +4726,7 @@ NIL
 NIL 
 (-1199) 
 ((|constructor| (NIL "A constructive unique factorization domain,{} \\spadignore{i.e.} where we can constructively factor members into a product of a finite number of irreducible elements.")) (|factor| (((|Factored| $) $) "\\spad{factor(x)} returns the factorization of \\spad{x} into irreducibles.")) (|squareFreePart| (($ $) "\\spad{squareFreePart(x)} returns a product of prime factors of \\spad{x} each taken with multiplicity one.")) (|squareFree| (((|Factored| $) $) "\\spad{squareFree(x)} returns the square-free factorization of \\spad{x} \\spadignore{i.e.} such that the factors are pairwise relatively prime and each has multiple prime factors.")) (|prime?| (((|Boolean|) $) "\\spad{prime?(x)} tests if \\spad{x} can never be written as the product of two non-units of the ring,{} \\spadignore{i.e.} \\spad{x} is an irreducible element."))) 
-((-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-1200 |Coef|) 
 ((|constructor| (NIL "This package has no description"))) 
@@ -4734,15 +4734,15 @@ NIL
 NIL 
 (-1201 |Coef|) 
 ((|constructor| (NIL "This domain has no description"))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-763)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-763)) (|devaluate| |#1|))))) (|HasCategory| (-763) (QUOTE (-1102))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-763))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-763))))) (|HasSignature| |#1| (LIST (QUOTE -2745) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (|HasCategory| |#1| (QUOTE (-365))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -3837) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2055) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|))))))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-763)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-763)) (|devaluate| |#1|))))) (|HasCategory| (-763) (QUOTE (-1102))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-763))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-763))))) (|HasSignature| |#1| (LIST (QUOTE -2747) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (|HasCategory| |#1| (QUOTE (-365))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -1845) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2057) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|))))))) 
 (-1202 |Coef1| |Coef2| |var1| |var2| |cen1| |cen2|) 
 ((|constructor| (NIL "Mapping package for univariate Laurent series This package allows one to apply a function to the coefficients of a univariate Laurent series.")) (|map| (((|UnivariateLaurentSeries| |#2| |#4| |#6|) (|Mapping| |#2| |#1|) (|UnivariateLaurentSeries| |#1| |#3| |#5|)) "\\spad{map(f,{}g(x))} applies the map \\spad{f} to the coefficients of the Laurent series \\spad{g(x)}."))) 
 NIL 
 NIL 
 (-1203 |Coef|) 
 ((|constructor| (NIL "\\spadtype{UnivariateLaurentSeriesCategory} is the category of Laurent series in one variable.")) (|integrate| (($ $ (|Symbol|)) "\\spad{integrate(f(x),{}y)} returns an anti-derivative of the power series \\spad{f(x)} with respect to the variable \\spad{y}.") (($ $ (|Symbol|)) "\\spad{integrate(f(x),{}y)} returns an anti-derivative of the power series \\spad{f(x)} with respect to the variable \\spad{y}.") (($ $) "\\spad{integrate(f(x))} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 1. We may integrate a series when we can divide coefficients by integers.")) (|rationalFunction| (((|Fraction| (|Polynomial| |#1|)) $ (|Integer|) (|Integer|)) "\\spad{rationalFunction(f,{}k1,{}k2)} returns a rational function consisting of the sum of all terms of \\spad{f} of degree \\spad{d} with \\spad{k1 <= d <= k2}.") (((|Fraction| (|Polynomial| |#1|)) $ (|Integer|)) "\\spad{rationalFunction(f,{}k)} returns a rational function consisting of the sum of all terms of \\spad{f} of degree \\spad{<=} \\spad{k}.")) (|multiplyCoefficients| (($ (|Mapping| |#1| (|Integer|)) $) "\\spad{multiplyCoefficients(f,{}sum(n = n0..infinity,{}a[n] * x**n)) = sum(n = 0..infinity,{}f(n) * a[n] * x**n)}. This function is used when Puiseux series are represented by a Laurent series and an exponent.")) (|series| (($ (|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| |#1|)))) "\\spad{series(st)} creates a series from a stream of non-zero terms,{} where a term is an exponent-coefficient pair. The terms in the stream should be ordered by increasing order of exponents."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-365)) (-4511 |has| |#1| (-365)) (-4513 . T) (-4514 . T) (-4516 . T)) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-365)) (-4513 |has| |#1| (-365)) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-1204 S |Coef| UTS) 
 ((|constructor| (NIL "This is a category of univariate Laurent series constructed from univariate Taylor series. A Laurent series is represented by a pair \\spad{[n,{}f(x)]},{} where \\spad{n} is an arbitrary integer and \\spad{f(x)} is a Taylor series. This pair represents the Laurent series \\spad{x**n * f(x)}.")) (|taylorIfCan| (((|Union| |#3| "failed") $) "\\spad{taylorIfCan(f(x))} converts the Laurent series \\spad{f(x)} to a Taylor series,{} if possible. If this is not possible,{} \"failed\" is returned.")) (|taylor| ((|#3| $) "\\spad{taylor(f(x))} converts the Laurent series \\spad{f}(\\spad{x}) to a Taylor series,{} if possible. Error: if this is not possible.")) (|coerce| (($ |#3|) "\\spad{coerce(f(x))} converts the Taylor series \\spad{f(x)} to a Laurent series.")) (|removeZeroes| (($ (|Integer|) $) "\\spad{removeZeroes(n,{}f(x))} removes up to \\spad{n} leading zeroes from the Laurent series \\spad{f(x)}. A Laurent series is represented by (1) an exponent and (2) a Taylor series which may have leading zero coefficients. When the Taylor series has a leading zero coefficient,{} the 'leading zero' is removed from the Laurent series as follows: the series is rewritten by increasing the exponent by 1 and dividing the Taylor series by its variable.") (($ $) "\\spad{removeZeroes(f(x))} removes leading zeroes from the representation of the Laurent series \\spad{f(x)}. A Laurent series is represented by (1) an exponent and (2) a Taylor series which may have leading zero coefficients. When the Taylor series has a leading zero coefficient,{} the 'leading zero' is removed from the Laurent series as follows: the series is rewritten by increasing the exponent by 1 and dividing the Taylor series by its variable. Note that \\spad{removeZeroes(f)} removes all leading zeroes from \\spad{f}")) (|taylorRep| ((|#3| $) "\\spad{taylorRep(f(x))} returns \\spad{g(x)},{} where \\spad{f = x**n * g(x)} is represented by \\spad{[n,{}g(x)]}.")) (|degree| (((|Integer|) $) "\\spad{degree(f(x))} returns the degree of the lowest order term of \\spad{f(x)},{} which may have zero as a coefficient.")) (|laurent| (($ (|Integer|) |#3|) "\\spad{laurent(n,{}f(x))} returns \\spad{x**n * f(x)}."))) 
@@ -4750,16 +4750,16 @@ NIL
 ((|HasCategory| |#2| (QUOTE (-365)))) 
 (-1205 |Coef| UTS) 
 ((|constructor| (NIL "This is a category of univariate Laurent series constructed from univariate Taylor series. A Laurent series is represented by a pair \\spad{[n,{}f(x)]},{} where \\spad{n} is an arbitrary integer and \\spad{f(x)} is a Taylor series. This pair represents the Laurent series \\spad{x**n * f(x)}.")) (|taylorIfCan| (((|Union| |#2| "failed") $) "\\spad{taylorIfCan(f(x))} converts the Laurent series \\spad{f(x)} to a Taylor series,{} if possible. If this is not possible,{} \"failed\" is returned.")) (|taylor| ((|#2| $) "\\spad{taylor(f(x))} converts the Laurent series \\spad{f}(\\spad{x}) to a Taylor series,{} if possible. Error: if this is not possible.")) (|coerce| (($ |#2|) "\\spad{coerce(f(x))} converts the Taylor series \\spad{f(x)} to a Laurent series.")) (|removeZeroes| (($ (|Integer|) $) "\\spad{removeZeroes(n,{}f(x))} removes up to \\spad{n} leading zeroes from the Laurent series \\spad{f(x)}. A Laurent series is represented by (1) an exponent and (2) a Taylor series which may have leading zero coefficients. When the Taylor series has a leading zero coefficient,{} the 'leading zero' is removed from the Laurent series as follows: the series is rewritten by increasing the exponent by 1 and dividing the Taylor series by its variable.") (($ $) "\\spad{removeZeroes(f(x))} removes leading zeroes from the representation of the Laurent series \\spad{f(x)}. A Laurent series is represented by (1) an exponent and (2) a Taylor series which may have leading zero coefficients. When the Taylor series has a leading zero coefficient,{} the 'leading zero' is removed from the Laurent series as follows: the series is rewritten by increasing the exponent by 1 and dividing the Taylor series by its variable. Note that \\spad{removeZeroes(f)} removes all leading zeroes from \\spad{f}")) (|taylorRep| ((|#2| $) "\\spad{taylorRep(f(x))} returns \\spad{g(x)},{} where \\spad{f = x**n * g(x)} is represented by \\spad{[n,{}g(x)]}.")) (|degree| (((|Integer|) $) "\\spad{degree(f(x))} returns the degree of the lowest order term of \\spad{f(x)},{} which may have zero as a coefficient.")) (|laurent| (($ (|Integer|) |#2|) "\\spad{laurent(n,{}f(x))} returns \\spad{x**n * f(x)}."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-365)) (-4511 |has| |#1| (-365)) (-3973 |has| |#1| (-365)) (-4513 . T) (-4514 . T) (-4516 . T)) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-365)) (-4513 |has| |#1| (-365)) (-3973 |has| |#1| (-365)) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-1206 |Coef| UTS) 
 ((|constructor| (NIL "This package enables one to construct a univariate Laurent series domain from a univariate Taylor series domain. Univariate Laurent series are represented by a pair \\spad{[n,{}f(x)]},{} where \\spad{n} is an arbitrary integer and \\spad{f(x)} is a Taylor series. This pair represents the Laurent series \\spad{x**n * f(x)}."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-365)) (-4511 |has| |#1| (-365)) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| (-568) (QUOTE (-1102))) (|HasCategory| |#1| (QUOTE (-365))) (-2198 (|HasCategory| |#1| (QUOTE (-150))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-150))))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-568)) (|devaluate| |#1|))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))))) (-2198 (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-225)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-568)) (|devaluate| |#1|))))) (-2198 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-1161))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1021)))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-815)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1136)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -281) (|devaluate| |#2|) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -523) (QUOTE (-1161)) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381))))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-568))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -2745) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-842)))) (-2198 (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-815)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-842))))) (|HasCategory| |#2| (QUOTE (-904))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-904)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-550)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-301)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-148))) (-2198 (|HasCategory| |#1| (QUOTE (-148))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-148))))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (-2198 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -281) (|devaluate| |#2|) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -523) (QUOTE (-1161)) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-1161))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-815)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-904)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1021)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1136))))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -3837) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2055) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|)))))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-148)))))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-365)) (-4513 |has| |#1| (-365)) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| (-568) (QUOTE (-1102))) (|HasCategory| |#1| (QUOTE (-365))) (-2199 (|HasCategory| |#1| (QUOTE (-150))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-150))))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-568)) (|devaluate| |#1|))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))))) (-2199 (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-225)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-568)) (|devaluate| |#1|))))) (-2199 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-1161))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1021)))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-815)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1136)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -281) (|devaluate| |#2|) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -523) (QUOTE (-1161)) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381))))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-568))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -2747) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-842)))) (-2199 (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-815)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-842))))) (|HasCategory| |#2| (QUOTE (-904))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-904)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-550)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-301)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-148))) (-2199 (|HasCategory| |#1| (QUOTE (-148))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-148))))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (-2199 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -281) (|devaluate| |#2|) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -303) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -523) (QUOTE (-1161)) (|devaluate| |#2|)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-1161))))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-815)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-904)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1021)))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1136))))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -1845) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2057) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|)))))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-904)))) (|HasCategory| |#1| (QUOTE (-148))) (-12 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-148)))))) 
 (-1207 |Coef| |var| |cen|) 
 ((|constructor| (NIL "Dense Laurent series in one variable \\spadtype{UnivariateLaurentSeries} is a domain representing Laurent series in one variable with coefficients in an arbitrary ring. The parameters of the type specify the coefficient ring,{} the power series variable,{} and the center of the power series expansion. For example,{} \\spad{UnivariateLaurentSeries(Integer,{}x,{}3)} represents Laurent series in \\spad{(x - 3)} with integer coefficients.")) (|integrate| (($ $ (|Variable| |#2|)) "\\spad{integrate(f(x))} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 0. We may integrate a series when we can divide coefficients by integers.")) (|differentiate| (($ $ (|Variable| |#2|)) "\\spad{differentiate(f(x),{}x)} returns the derivative of \\spad{f(x)} with respect to \\spad{x}.")) (|coerce| (($ (|Variable| |#2|)) "\\spad{coerce(var)} converts the series variable \\spad{var} into a Laurent series."))) 
-(((-4521 "*") -2198 (-2139 (|has| |#1| (-365)) (|has| (-1235 |#1| |#2| |#3|) (-815))) (|has| |#1| (-172)) (-2139 (|has| |#1| (-365)) (|has| (-1235 |#1| |#2| |#3|) (-904)))) (-4512 -2198 (-2139 (|has| |#1| (-365)) (|has| (-1235 |#1| |#2| |#3|) (-815))) (|has| |#1| (-558)) (-2139 (|has| |#1| (-365)) (|has| (-1235 |#1| |#2| |#3|) (-904)))) (-4517 |has| |#1| (-365)) (-4511 |has| |#1| (-365)) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| (-568) (QUOTE (-1102))) (|HasCategory| |#1| (QUOTE (-365))) (-2198 (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-150)))) (-2198 (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-568)) (|devaluate| |#1|)))))) (-2198 (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-225))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-568)) (|devaluate| |#1|))))) (-2198 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-1021))) (|HasCategory| |#1| (QUOTE (-365)))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-1136))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -281) (LIST (QUOTE -1235) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)) (LIST (QUOTE -1235) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -303) (LIST (QUOTE -1235) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -523) (QUOTE (-1161)) (LIST (QUOTE -1235) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-568))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -2745) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-550))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-904))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-148))) (-2198 (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-148)))) (-2198 (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-558)))) (-2198 (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-172)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-365)))) (-2198 (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-365))))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (-2198 (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -281) (LIST (QUOTE -1235) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)) (LIST (QUOTE -1235) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -303) (LIST (QUOTE -1235) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -523) (QUOTE (-1161)) (LIST (QUOTE -1235) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-1021))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-1136))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568)))))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -3837) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2055) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|)))))) (-2198 (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-148))))) 
+(((-4523 "*") -2199 (-2141 (|has| |#1| (-365)) (|has| (-1235 |#1| |#2| |#3|) (-815))) (|has| |#1| (-172)) (-2141 (|has| |#1| (-365)) (|has| (-1235 |#1| |#2| |#3|) (-904)))) (-4514 -2199 (-2141 (|has| |#1| (-365)) (|has| (-1235 |#1| |#2| |#3|) (-815))) (|has| |#1| (-558)) (-2141 (|has| |#1| (-365)) (|has| (-1235 |#1| |#2| |#3|) (-904)))) (-4519 |has| |#1| (-365)) (-4513 |has| |#1| (-365)) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| (-568) (QUOTE (-1102))) (|HasCategory| |#1| (QUOTE (-365))) (-2199 (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-150))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-150)))) (-2199 (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-568)) (|devaluate| |#1|)))))) (-2199 (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-225))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-568)) (|devaluate| |#1|))))) (-2199 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-1021))) (|HasCategory| |#1| (QUOTE (-365)))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-1136))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -281) (LIST (QUOTE -1235) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)) (LIST (QUOTE -1235) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -303) (LIST (QUOTE -1235) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -523) (QUOTE (-1161)) (LIST (QUOTE -1235) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-568))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -2747) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-550))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-301))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-904))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-148))) (-2199 (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-148)))) (-2199 (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-558)))) (-2199 (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-172)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-365)))) (-2199 (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-365))))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (-2199 (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -281) (LIST (QUOTE -1235) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)) (LIST (QUOTE -1235) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -303) (LIST (QUOTE -1235) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -523) (QUOTE (-1161)) (LIST (QUOTE -1235) (|devaluate| |#1|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -1037) (QUOTE (-1161)))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-815))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-1021))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-1136))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568)))))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -1845) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2057) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|)))))) (-2199 (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-904))) (|HasCategory| |#1| (QUOTE (-365)))) (-12 (|HasCategory| (-1235 |#1| |#2| |#3|) (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-365)))) (|HasCategory| |#1| (QUOTE (-148))))) 
 (-1208 ZP) 
 ((|constructor| (NIL "Package for the factorization of univariate polynomials with integer coefficients. The factorization is done by \"lifting\" (HENSEL) the factorization over a finite field.")) (|henselFact| (((|Record| (|:| |contp| (|Integer|)) (|:| |factors| (|List| (|Record| (|:| |irr| |#1|) (|:| |pow| (|Integer|)))))) |#1| (|Boolean|)) "\\spad{henselFact(m,{}flag)} returns the factorization of \\spad{m},{} FinalFact is a Record \\spad{s}.\\spad{t}. FinalFact.contp=content \\spad{m},{} FinalFact.factors=List of irreducible factors of \\spad{m} with exponent ,{} if \\spad{flag} =true the polynomial is assumed square free.")) (|factorSquareFree| (((|Factored| |#1|) |#1|) "\\spad{factorSquareFree(m)} returns the factorization of \\spad{m} square free polynomial")) (|factor| (((|Factored| |#1|) |#1|) "\\spad{factor(m)} returns the factorization of \\spad{m}"))) 
 NIL 
@@ -4794,8 +4794,8 @@ NIL
 NIL 
 (-1216 |x| R) 
 ((|constructor| (NIL "This domain represents univariate polynomials in some symbol over arbitrary (not necessarily commutative) coefficient rings. The representation is sparse in the sense that only non-zero terms are represented. Note that if the coefficient ring is a field,{} then this domain forms a euclidean domain.")) (|fmecg| (($ $ (|NonNegativeInteger|) |#2| $) "\\spad{fmecg(p1,{}e,{}r,{}p2)} finds \\spad{x} : \\spad{p1} - \\spad{r} * x**e * \\spad{p2}")) (|coerce| (($ (|Variable| |#1|)) "\\spad{coerce(x)} converts the variable \\spad{x} to a univariate polynomial."))) 
-(((-4521 "*") |has| |#2| (-172)) (-4512 |has| |#2| (-558)) (-4515 |has| |#2| (-365)) (-4517 |has| |#2| (-6 -4517)) (-4514 . T) (-4513 . T) (-4516 . T)) 
-((|HasCategory| |#2| (QUOTE (-904))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-172))) (-2198 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-558)))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#2| (QUOTE (-842))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1136))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (-2198 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasCategory| |#2| (QUOTE (-225))) (|HasAttribute| |#2| (QUOTE -4517)) (|HasCategory| |#2| (QUOTE (-453))) (-2198 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2198 (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2198 (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (-2198 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (|HasCategory| |#2| (QUOTE (-148))))) 
+(((-4523 "*") |has| |#2| (-172)) (-4514 |has| |#2| (-558)) (-4517 |has| |#2| (-365)) (-4519 |has| |#2| (-6 -4519)) (-4516 . T) (-4515 . T) (-4518 . T)) 
+((|HasCategory| |#2| (QUOTE (-904))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-172))) (-2199 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-558)))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-381)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-381))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -881) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -881) (QUOTE (-568))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-381)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -609) (LIST (QUOTE -887) (QUOTE (-568)))))) (-12 (|HasCategory| (-1075) (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#2| (LIST (QUOTE -609) (QUOTE (-541))))) (|HasCategory| |#2| (QUOTE (-842))) (|HasCategory| |#2| (LIST (QUOTE -630) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-150))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-1136))) (|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (-2199 (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasCategory| |#2| (QUOTE (-225))) (|HasAttribute| |#2| (QUOTE -4519)) (|HasCategory| |#2| (QUOTE (-453))) (-2199 (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2199 (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-904)))) (-2199 (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-904)))) (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (-2199 (-12 (|HasCategory| $ (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-904)))) (|HasCategory| |#2| (QUOTE (-148))))) 
 (-1217 R PR S PS) 
 ((|constructor| (NIL "Mapping from polynomials over \\spad{R} to polynomials over \\spad{S} given a map from \\spad{R} to \\spad{S} assumed to send zero to zero.")) (|map| ((|#4| (|Mapping| |#3| |#1|) |#2|) "\\spad{map(f,{} p)} takes a function \\spad{f} from \\spad{R} to \\spad{S},{} and applies it to each (non-zero) coefficient of a polynomial \\spad{p} over \\spad{R},{} getting a new polynomial over \\spad{S}. Note that since the map is not applied to zero elements,{} it may map zero to zero."))) 
 NIL 
@@ -4806,15 +4806,15 @@ NIL
 ((|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-365))) (|HasCategory| |#2| (QUOTE (-453))) (|HasCategory| |#2| (QUOTE (-558))) (|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (QUOTE (-1136)))) 
 (-1219 R) 
 ((|constructor| (NIL "The category of univariate polynomials over a ring \\spad{R}. No particular model is assumed - implementations can be either sparse or dense.")) (|integrate| (($ $) "\\spad{integrate(p)} integrates the univariate polynomial \\spad{p} with respect to its distinguished variable.")) (|additiveValuation| ((|attribute|) "euclideanSize(a*b) = euclideanSize(a) + euclideanSize(\\spad{b})")) (|separate| (((|Record| (|:| |primePart| $) (|:| |commonPart| $)) $ $) "\\spad{separate(p,{} q)} returns \\spad{[a,{} b]} such that polynomial \\spad{p = a b} and \\spad{a} is relatively prime to \\spad{q}.")) (|pseudoDivide| (((|Record| (|:| |coef| |#1|) (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{pseudoDivide(p,{}q)} returns \\spad{[c,{} q,{} r]},{} when \\spad{p' := p*lc(q)**(deg p - deg q + 1) = c * p} is pseudo right-divided by \\spad{q},{} \\spadignore{i.e.} \\spad{p' = s q + r}.")) (|pseudoQuotient| (($ $ $) "\\spad{pseudoQuotient(p,{}q)} returns \\spad{r},{} the quotient when \\spad{p' := p*lc(q)**(deg p - deg q + 1)} is pseudo right-divided by \\spad{q},{} \\spadignore{i.e.} \\spad{p' = s q + r}.")) (|composite| (((|Union| (|Fraction| $) "failed") (|Fraction| $) $) "\\spad{composite(f,{} q)} returns \\spad{h} if \\spad{f} = \\spad{h}(\\spad{q}),{} and \"failed\" is no such \\spad{h} exists.") (((|Union| $ "failed") $ $) "\\spad{composite(p,{} q)} returns \\spad{h} if \\spad{p = h(q)},{} and \"failed\" no such \\spad{h} exists.")) (|subResultantGcd| (($ $ $) "\\spad{subResultantGcd(p,{}q)} computes the \\spad{gcd} of the polynomials \\spad{p} and \\spad{q} using the SubResultant \\spad{GCD} algorithm.")) (|order| (((|NonNegativeInteger|) $ $) "\\spad{order(p,{} q)} returns the largest \\spad{n} such that \\spad{q**n} divides polynomial \\spad{p} \\spadignore{i.e.} the order of \\spad{p(x)} at \\spad{q(x)=0}.")) (|elt| ((|#1| (|Fraction| $) |#1|) "\\spad{elt(a,{}r)} evaluates the fraction of univariate polynomials \\spad{a} with the distinguished variable replaced by the constant \\spad{r}.") (((|Fraction| $) (|Fraction| $) (|Fraction| $)) "\\spad{elt(a,{}b)} evaluates the fraction of univariate polynomials \\spad{a} with the distinguished variable replaced by \\spad{b}.")) (|resultant| ((|#1| $ $) "\\spad{resultant(p,{}q)} returns the resultant of the polynomials \\spad{p} and \\spad{q}.")) (|discriminant| ((|#1| $) "\\spad{discriminant(p)} returns the discriminant of the polynomial \\spad{p}.")) (|differentiate| (($ $ (|Mapping| |#1| |#1|) $) "\\spad{differentiate(p,{} d,{} x')} extends the \\spad{R}-derivation \\spad{d} to an extension \\spad{D} in \\spad{R[x]} where \\spad{Dx} is given by \\spad{x'},{} and returns \\spad{Dp}.")) (|pseudoRemainder| (($ $ $) "\\spad{pseudoRemainder(p,{}q)} = \\spad{r},{} for polynomials \\spad{p} and \\spad{q},{} returns the remainder when \\spad{p' := p*lc(q)**(deg p - deg q + 1)} is pseudo right-divided by \\spad{q},{} \\spadignore{i.e.} \\spad{p' = s q + r}.")) (|shiftLeft| (($ $ (|NonNegativeInteger|)) "\\spad{shiftLeft(p,{}n)} returns \\spad{p * monomial(1,{}n)}")) (|shiftRight| (($ $ (|NonNegativeInteger|)) "\\spad{shiftRight(p,{}n)} returns \\spad{monicDivide(p,{}monomial(1,{}n)).quotient}")) (|karatsubaDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ (|NonNegativeInteger|)) "\\spad{karatsubaDivide(p,{}n)} returns the same as \\spad{monicDivide(p,{}monomial(1,{}n))}")) (|monicDivide| (((|Record| (|:| |quotient| $) (|:| |remainder| $)) $ $) "\\spad{monicDivide(p,{}q)} divide the polynomial \\spad{p} by the monic polynomial \\spad{q},{} returning the pair \\spad{[quotient,{} remainder]}. Error: if \\spad{q} isn\\spad{'t} monic.")) (|divideExponents| (((|Union| $ "failed") $ (|NonNegativeInteger|)) "\\spad{divideExponents(p,{}n)} returns a new polynomial resulting from dividing all exponents of the polynomial \\spad{p} by the non negative integer \\spad{n},{} or \"failed\" if some exponent is not exactly divisible by \\spad{n}.")) (|multiplyExponents| (($ $ (|NonNegativeInteger|)) "\\spad{multiplyExponents(p,{}n)} returns a new polynomial resulting from multiplying all exponents of the polynomial \\spad{p} by the non negative integer \\spad{n}.")) (|unmakeSUP| (($ (|SparseUnivariatePolynomial| |#1|)) "\\spad{unmakeSUP(sup)} converts \\spad{sup} of type \\spadtype{SparseUnivariatePolynomial(R)} to be a member of the given type. Note that converse of makeSUP.")) (|makeSUP| (((|SparseUnivariatePolynomial| |#1|) $) "\\spad{makeSUP(p)} converts the polynomial \\spad{p} to be of type SparseUnivariatePolynomial over the same coefficients.")) (|vectorise| (((|Vector| |#1|) $ (|NonNegativeInteger|)) "\\spad{vectorise(p,{} n)} returns \\spad{[a0,{}...,{}a(n-1)]} where \\spad{p = a0 + a1*x + ... + a(n-1)*x**(n-1)} + higher order terms. The degree of polynomial \\spad{p} can be different from \\spad{n-1}."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4515 |has| |#1| (-365)) (-4517 |has| |#1| (-6 -4517)) (-4514 . T) (-4513 . T) (-4516 . T)) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4517 |has| |#1| (-365)) (-4519 |has| |#1| (-6 -4519)) (-4516 . T) (-4515 . T) (-4518 . T)) 
 NIL 
 (-1220 S |Coef| |Expon|) 
 ((|constructor| (NIL "\\spadtype{UnivariatePowerSeriesCategory} is the most general univariate power series category with exponents in an ordered abelian monoid. Note that this category exports a substitution function if it is possible to multiply exponents. Also note that this category exports a derivative operation if it is possible to multiply coefficients by exponents.")) (|eval| (((|Stream| |#2|) $ |#2|) "\\spad{eval(f,{}a)} evaluates a power series at a value in the ground ring by returning a stream of partial sums.")) (|extend| (($ $ |#3|) "\\spad{extend(f,{}n)} causes all terms of \\spad{f} of degree \\spad{<=} \\spad{n} to be computed.")) (|approximate| ((|#2| $ |#3|) "\\spad{approximate(f)} returns a truncated power series with the series variable viewed as an element of the coefficient domain.")) (|truncate| (($ $ |#3| |#3|) "\\spad{truncate(f,{}k1,{}k2)} returns a (finite) power series consisting of the sum of all terms of \\spad{f} of degree \\spad{d} with \\spad{k1 <= d <= k2}.") (($ $ |#3|) "\\spad{truncate(f,{}k)} returns a (finite) power series consisting of the sum of all terms of \\spad{f} of degree \\spad{<= k}.")) (|order| ((|#3| $ |#3|) "\\spad{order(f,{}n) = min(m,{}n)},{} where \\spad{m} is the degree of the lowest order non-zero term in \\spad{f}.") ((|#3| $) "\\spad{order(f)} is the degree of the lowest order non-zero term in \\spad{f}. This will result in an infinite loop if \\spad{f} has no non-zero terms.")) (|multiplyExponents| (($ $ (|PositiveInteger|)) "\\spad{multiplyExponents(f,{}n)} multiplies all exponents of the power series \\spad{f} by the positive integer \\spad{n}.")) (|center| ((|#2| $) "\\spad{center(f)} returns the point about which the series \\spad{f} is expanded.")) (|variable| (((|Symbol|) $) "\\spad{variable(f)} returns the (unique) power series variable of the power series \\spad{f}.")) (|elt| ((|#2| $ |#3|) "\\spad{elt(f(x),{}r)} returns the coefficient of the term of degree \\spad{r} in \\spad{f(x)}. This is the same as the function \\spadfun{coefficient}.")) (|terms| (((|Stream| (|Record| (|:| |k| |#3|) (|:| |c| |#2|))) $) "\\spad{terms(f(x))} returns a stream of non-zero terms,{} where a a term is an exponent-coefficient pair. The terms in the stream are ordered by increasing order of exponents."))) 
 NIL 
-((|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#2| (LIST (QUOTE *) (LIST (|devaluate| |#2|) (|devaluate| |#3|) (|devaluate| |#2|)))) (|HasCategory| |#3| (QUOTE (-1102))) (|HasSignature| |#2| (LIST (QUOTE **) (LIST (|devaluate| |#2|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasSignature| |#2| (LIST (QUOTE -2745) (LIST (|devaluate| |#2|) (QUOTE (-1161)))))) 
+((|HasCategory| |#2| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#2| (LIST (QUOTE *) (LIST (|devaluate| |#2|) (|devaluate| |#3|) (|devaluate| |#2|)))) (|HasCategory| |#3| (QUOTE (-1102))) (|HasSignature| |#2| (LIST (QUOTE **) (LIST (|devaluate| |#2|) (|devaluate| |#2|) (|devaluate| |#3|)))) (|HasSignature| |#2| (LIST (QUOTE -2747) (LIST (|devaluate| |#2|) (QUOTE (-1161)))))) 
 (-1221 |Coef| |Expon|) 
 ((|constructor| (NIL "\\spadtype{UnivariatePowerSeriesCategory} is the most general univariate power series category with exponents in an ordered abelian monoid. Note that this category exports a substitution function if it is possible to multiply exponents. Also note that this category exports a derivative operation if it is possible to multiply coefficients by exponents.")) (|eval| (((|Stream| |#1|) $ |#1|) "\\spad{eval(f,{}a)} evaluates a power series at a value in the ground ring by returning a stream of partial sums.")) (|extend| (($ $ |#2|) "\\spad{extend(f,{}n)} causes all terms of \\spad{f} of degree \\spad{<=} \\spad{n} to be computed.")) (|approximate| ((|#1| $ |#2|) "\\spad{approximate(f)} returns a truncated power series with the series variable viewed as an element of the coefficient domain.")) (|truncate| (($ $ |#2| |#2|) "\\spad{truncate(f,{}k1,{}k2)} returns a (finite) power series consisting of the sum of all terms of \\spad{f} of degree \\spad{d} with \\spad{k1 <= d <= k2}.") (($ $ |#2|) "\\spad{truncate(f,{}k)} returns a (finite) power series consisting of the sum of all terms of \\spad{f} of degree \\spad{<= k}.")) (|order| ((|#2| $ |#2|) "\\spad{order(f,{}n) = min(m,{}n)},{} where \\spad{m} is the degree of the lowest order non-zero term in \\spad{f}.") ((|#2| $) "\\spad{order(f)} is the degree of the lowest order non-zero term in \\spad{f}. This will result in an infinite loop if \\spad{f} has no non-zero terms.")) (|multiplyExponents| (($ $ (|PositiveInteger|)) "\\spad{multiplyExponents(f,{}n)} multiplies all exponents of the power series \\spad{f} by the positive integer \\spad{n}.")) (|center| ((|#1| $) "\\spad{center(f)} returns the point about which the series \\spad{f} is expanded.")) (|variable| (((|Symbol|) $) "\\spad{variable(f)} returns the (unique) power series variable of the power series \\spad{f}.")) (|elt| ((|#1| $ |#2|) "\\spad{elt(f(x),{}r)} returns the coefficient of the term of degree \\spad{r} in \\spad{f(x)}. This is the same as the function \\spadfun{coefficient}.")) (|terms| (((|Stream| (|Record| (|:| |k| |#2|) (|:| |c| |#1|))) $) "\\spad{terms(f(x))} returns a stream of non-zero terms,{} where a a term is an exponent-coefficient pair. The terms in the stream are ordered by increasing order of exponents."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4513 . T) (-4514 . T) (-4516 . T)) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-1222 RC P) 
 ((|constructor| (NIL "This package provides for square-free decomposition of univariate polynomials over arbitrary rings,{} \\spadignore{i.e.} a partial factorization such that each factor is a product of irreducibles with multiplicity one and the factors are pairwise relatively prime. If the ring has characteristic zero,{} the result is guaranteed to satisfy this condition. If the ring is an infinite ring of finite characteristic,{} then it may not be possible to decide when polynomials contain factors which are \\spad{p}th powers. In this case,{} the flag associated with that polynomial is set to \"nil\" (meaning that that polynomials are not guaranteed to be square-free).")) (|BumInSepFFE| (((|Record| (|:| |flg| (|Union| "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (|Integer|))) (|Record| (|:| |flg| (|Union| "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (|Integer|)))) "\\spad{BumInSepFFE(f)} is a local function,{} exported only because it has multiple conditional definitions.")) (|squareFreePart| ((|#2| |#2|) "\\spad{squareFreePart(p)} returns a polynomial which has the same irreducible factors as the univariate polynomial \\spad{p},{} but each factor has multiplicity one.")) (|squareFree| (((|Factored| |#2|) |#2|) "\\spad{squareFree(p)} computes the square-free factorization of the univariate polynomial \\spad{p}. Each factor has no repeated roots,{} and the factors are pairwise relatively prime.")) (|gcd| (($ $ $) "\\spad{gcd(p,{}q)} computes the greatest-common-divisor of \\spad{p} and \\spad{q}."))) 
@@ -4826,7 +4826,7 @@ NIL
 NIL 
 (-1224 |Coef|) 
 ((|constructor| (NIL "\\spadtype{UnivariatePuiseuxSeriesCategory} is the category of Puiseux series in one variable.")) (|integrate| (($ $ (|Symbol|)) "\\spad{integrate(f(x),{}y)} returns an anti-derivative of the power series \\spad{f(x)} with respect to the variable \\spad{y}.") (($ $ (|Symbol|)) "\\spad{integrate(f(x),{}var)} returns an anti-derivative of the power series \\spad{f(x)} with respect to the variable \\spad{var}.") (($ $) "\\spad{integrate(f(x))} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 1. We may integrate a series when we can divide coefficients by rational numbers.")) (|multiplyExponents| (($ $ (|Fraction| (|Integer|))) "\\spad{multiplyExponents(f,{}r)} multiplies all exponents of the power series \\spad{f} by the positive rational number \\spad{r}.")) (|series| (($ (|NonNegativeInteger|) (|Stream| (|Record| (|:| |k| (|Fraction| (|Integer|))) (|:| |c| |#1|)))) "\\spad{series(n,{}st)} creates a series from a common denomiator and a stream of non-zero terms,{} where a term is an exponent-coefficient pair. The terms in the stream should be ordered by increasing order of exponents and \\spad{n} should be a common denominator for the exponents in the stream of terms."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-365)) (-4511 |has| |#1| (-365)) (-4513 . T) (-4514 . T) (-4516 . T)) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-365)) (-4513 |has| |#1| (-365)) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-1225 S |Coef| ULS) 
 ((|constructor| (NIL "This is a category of univariate Puiseux series constructed from univariate Laurent series. A Puiseux series is represented by a pair \\spad{[r,{}f(x)]},{} where \\spad{r} is a positive rational number and \\spad{f(x)} is a Laurent series. This pair represents the Puiseux series \\spad{f(x^r)}.")) (|laurentIfCan| (((|Union| |#3| "failed") $) "\\spad{laurentIfCan(f(x))} converts the Puiseux series \\spad{f(x)} to a Laurent series if possible. If this is not possible,{} \"failed\" is returned.")) (|laurent| ((|#3| $) "\\spad{laurent(f(x))} converts the Puiseux series \\spad{f(x)} to a Laurent series if possible. Error: if this is not possible.")) (|coerce| (($ |#3|) "\\spad{coerce(f(x))} converts the Laurent series \\spad{f(x)} to a Puiseux series.")) (|degree| (((|Fraction| (|Integer|)) $) "\\spad{degree(f(x))} returns the degree of the leading term of the Puiseux series \\spad{f(x)},{} which may have zero as a coefficient.")) (|laurentRep| ((|#3| $) "\\spad{laurentRep(f(x))} returns \\spad{g(x)} where the Puiseux series \\spad{f(x) = g(x^r)} is represented by \\spad{[r,{}g(x)]}.")) (|rationalPower| (((|Fraction| (|Integer|)) $) "\\spad{rationalPower(f(x))} returns \\spad{r} where the Puiseux series \\spad{f(x) = g(x^r)}.")) (|puiseux| (($ (|Fraction| (|Integer|)) |#3|) "\\spad{puiseux(r,{}f(x))} returns \\spad{f(x^r)}."))) 
@@ -4834,24 +4834,24 @@ NIL
 NIL 
 (-1226 |Coef| ULS) 
 ((|constructor| (NIL "This is a category of univariate Puiseux series constructed from univariate Laurent series. A Puiseux series is represented by a pair \\spad{[r,{}f(x)]},{} where \\spad{r} is a positive rational number and \\spad{f(x)} is a Laurent series. This pair represents the Puiseux series \\spad{f(x^r)}.")) (|laurentIfCan| (((|Union| |#2| "failed") $) "\\spad{laurentIfCan(f(x))} converts the Puiseux series \\spad{f(x)} to a Laurent series if possible. If this is not possible,{} \"failed\" is returned.")) (|laurent| ((|#2| $) "\\spad{laurent(f(x))} converts the Puiseux series \\spad{f(x)} to a Laurent series if possible. Error: if this is not possible.")) (|coerce| (($ |#2|) "\\spad{coerce(f(x))} converts the Laurent series \\spad{f(x)} to a Puiseux series.")) (|degree| (((|Fraction| (|Integer|)) $) "\\spad{degree(f(x))} returns the degree of the leading term of the Puiseux series \\spad{f(x)},{} which may have zero as a coefficient.")) (|laurentRep| ((|#2| $) "\\spad{laurentRep(f(x))} returns \\spad{g(x)} where the Puiseux series \\spad{f(x) = g(x^r)} is represented by \\spad{[r,{}g(x)]}.")) (|rationalPower| (((|Fraction| (|Integer|)) $) "\\spad{rationalPower(f(x))} returns \\spad{r} where the Puiseux series \\spad{f(x) = g(x^r)}.")) (|puiseux| (($ (|Fraction| (|Integer|)) |#2|) "\\spad{puiseux(r,{}f(x))} returns \\spad{f(x^r)}."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-365)) (-4511 |has| |#1| (-365)) (-4513 . T) (-4514 . T) (-4516 . T)) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-365)) (-4513 |has| |#1| (-365)) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-1227 |Coef| ULS) 
 ((|constructor| (NIL "This package enables one to construct a univariate Puiseux series domain from a univariate Laurent series domain. Univariate Puiseux series are represented by a pair \\spad{[r,{}f(x)]},{} where \\spad{r} is a positive rational number and \\spad{f(x)} is a Laurent series. This pair represents the Puiseux series \\spad{f(x^r)}."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-365)) (-4511 |has| |#1| (-365)) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568))) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568))) (|devaluate| |#1|))))) (|HasCategory| (-409 (-568)) (QUOTE (-1102))) (|HasCategory| |#1| (QUOTE (-365))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (-2198 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasSignature| |#1| (LIST (QUOTE -2745) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -3837) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2055) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|))))))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-365)) (-4513 |has| |#1| (-365)) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568))) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568))) (|devaluate| |#1|))))) (|HasCategory| (-409 (-568)) (QUOTE (-1102))) (|HasCategory| |#1| (QUOTE (-365))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (-2199 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasSignature| |#1| (LIST (QUOTE -2747) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -1845) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2057) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|))))))) 
 (-1228 |Coef| |var| |cen|) 
 ((|constructor| (NIL "Dense Puiseux series in one variable \\spadtype{UnivariatePuiseuxSeries} is a domain representing Puiseux series in one variable with coefficients in an arbitrary ring. The parameters of the type specify the coefficient ring,{} the power series variable,{} and the center of the power series expansion. For example,{} \\spad{UnivariatePuiseuxSeries(Integer,{}x,{}3)} represents Puiseux series in \\spad{(x - 3)} with \\spadtype{Integer} coefficients.")) (|integrate| (($ $ (|Variable| |#2|)) "\\spad{integrate(f(x))} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 0. We may integrate a series when we can divide coefficients by integers.")) (|differentiate| (($ $ (|Variable| |#2|)) "\\spad{differentiate(f(x),{}x)} returns the derivative of \\spad{f(x)} with respect to \\spad{x}.")) (|coerce| (($ (|Variable| |#2|)) "\\spad{coerce(var)} converts the series variable \\spad{var} into a Puiseux series."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4517 |has| |#1| (-365)) (-4511 |has| |#1| (-365)) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568))) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568))) (|devaluate| |#1|))))) (|HasCategory| (-409 (-568)) (QUOTE (-1102))) (|HasCategory| |#1| (QUOTE (-365))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (-2198 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasSignature| |#1| (LIST (QUOTE -2745) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -3837) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2055) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|))))))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4519 |has| |#1| (-365)) (-4513 |has| |#1| (-365)) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568))) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568))) (|devaluate| |#1|))))) (|HasCategory| (-409 (-568)) (QUOTE (-1102))) (|HasCategory| |#1| (QUOTE (-365))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (-2199 (|HasCategory| |#1| (QUOTE (-365))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568)))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasSignature| |#1| (LIST (QUOTE -2747) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -1845) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2057) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|))))))) 
 (-1229 R FE |var| |cen|) 
 ((|constructor| (NIL "UnivariatePuiseuxSeriesWithExponentialSingularity is a domain used to represent functions with essential singularities. Objects in this domain are sums,{} where each term in the sum is a univariate Puiseux series times the exponential of a univariate Puiseux series. Thus,{} the elements of this domain are sums of expressions of the form \\spad{g(x) * exp(f(x))},{} where \\spad{g}(\\spad{x}) is a univariate Puiseux series and \\spad{f}(\\spad{x}) is a univariate Puiseux series with no terms of non-negative degree.")) (|dominantTerm| (((|Union| (|Record| (|:| |%term| (|Record| (|:| |%coef| (|UnivariatePuiseuxSeries| |#2| |#3| |#4|)) (|:| |%expon| (|ExponentialOfUnivariatePuiseuxSeries| |#2| |#3| |#4|)) (|:| |%expTerms| (|List| (|Record| (|:| |k| (|Fraction| (|Integer|))) (|:| |c| |#2|)))))) (|:| |%type| (|String|))) "failed") $) "\\spad{dominantTerm(f(var))} returns the term that dominates the limiting behavior of \\spad{f(var)} as \\spad{var -> cen+} together with a \\spadtype{String} which briefly describes that behavior. The value of the \\spadtype{String} will be \\spad{\"zero\"} (resp. \\spad{\"infinity\"}) if the term tends to zero (resp. infinity) exponentially and will \\spad{\"series\"} if the term is a Puiseux series.")) (|limitPlus| (((|Union| (|OrderedCompletion| |#2|) "failed") $) "\\spad{limitPlus(f(var))} returns \\spad{limit(var -> cen+,{}f(var))}."))) 
-(((-4521 "*") |has| (-1228 |#2| |#3| |#4|) (-172)) (-4512 |has| (-1228 |#2| |#3| |#4|) (-558)) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| (-1228 |#2| |#3| |#4|) (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| (-1228 |#2| |#3| |#4|) (QUOTE (-148))) (|HasCategory| (-1228 |#2| |#3| |#4|) (QUOTE (-150))) (|HasCategory| (-1228 |#2| |#3| |#4|) (QUOTE (-172))) (|HasCategory| (-1228 |#2| |#3| |#4|) (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| (-1228 |#2| |#3| |#4|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| (-1228 |#2| |#3| |#4|) (QUOTE (-365))) (|HasCategory| (-1228 |#2| |#3| |#4|) (QUOTE (-453))) (-2198 (|HasCategory| (-1228 |#2| |#3| |#4|) (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| (-1228 |#2| |#3| |#4|) (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasCategory| (-1228 |#2| |#3| |#4|) (QUOTE (-558)))) 
+(((-4523 "*") |has| (-1228 |#2| |#3| |#4|) (-172)) (-4514 |has| (-1228 |#2| |#3| |#4|) (-558)) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| (-1228 |#2| |#3| |#4|) (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| (-1228 |#2| |#3| |#4|) (QUOTE (-148))) (|HasCategory| (-1228 |#2| |#3| |#4|) (QUOTE (-150))) (|HasCategory| (-1228 |#2| |#3| |#4|) (QUOTE (-172))) (|HasCategory| (-1228 |#2| |#3| |#4|) (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| (-1228 |#2| |#3| |#4|) (LIST (QUOTE -1037) (QUOTE (-568)))) (|HasCategory| (-1228 |#2| |#3| |#4|) (QUOTE (-365))) (|HasCategory| (-1228 |#2| |#3| |#4|) (QUOTE (-453))) (-2199 (|HasCategory| (-1228 |#2| |#3| |#4|) (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| (-1228 |#2| |#3| |#4|) (LIST (QUOTE -1037) (LIST (QUOTE -409) (QUOTE (-568)))))) (|HasCategory| (-1228 |#2| |#3| |#4|) (QUOTE (-558)))) 
 (-1230 A S) 
 ((|constructor| (NIL "A unary-recursive aggregate is a one where nodes may have either 0 or 1 children. This aggregate models,{} though not precisely,{} a linked list possibly with a single cycle. A node with one children models a non-empty list,{} with the \\spadfun{value} of the list designating the head,{} or \\spadfun{first},{} of the list,{} and the child designating the tail,{} or \\spadfun{rest},{} of the list. A node with no child then designates the empty list. Since these aggregates are recursive aggregates,{} they may be cyclic.")) (|split!| (($ $ (|Integer|)) "\\spad{split!(u,{}n)} splits \\spad{u} into two aggregates: \\axiom{\\spad{v} = rest(\\spad{u},{}\\spad{n})} and \\axiom{\\spad{w} = first(\\spad{u},{}\\spad{n})},{} returning \\axiom{\\spad{v}}. Note that afterwards \\axiom{rest(\\spad{u},{}\\spad{n})} returns \\axiom{empty()}.")) (|setlast!| ((|#2| $ |#2|) "\\spad{setlast!(u,{}x)} destructively changes the last element of \\spad{u} to \\spad{x}.")) (|setrest!| (($ $ $) "\\spad{setrest!(u,{}v)} destructively changes the rest of \\spad{u} to \\spad{v}.")) (|setelt| ((|#2| $ "last" |#2|) "\\spad{setelt(u,{}\"last\",{}x)} (also written: \\axiom{\\spad{u}.last \\spad{:=} \\spad{b}}) is equivalent to \\axiom{setlast!(\\spad{u},{}\\spad{v})}.") (($ $ "rest" $) "\\spad{setelt(u,{}\"rest\",{}v)} (also written: \\axiom{\\spad{u}.rest \\spad{:=} \\spad{v}}) is equivalent to \\axiom{setrest!(\\spad{u},{}\\spad{v})}.") ((|#2| $ "first" |#2|) "\\spad{setelt(u,{}\"first\",{}x)} (also written: \\axiom{\\spad{u}.first \\spad{:=} \\spad{x}}) is equivalent to \\axiom{setfirst!(\\spad{u},{}\\spad{x})}.")) (|setfirst!| ((|#2| $ |#2|) "\\spad{setfirst!(u,{}x)} destructively changes the first element of a to \\spad{x}.")) (|cycleSplit!| (($ $) "\\spad{cycleSplit!(u)} splits the aggregate by dropping off the cycle. The value returned is the cycle entry,{} or nil if none exists. For example,{} if \\axiom{\\spad{w} = concat(\\spad{u},{}\\spad{v})} is the cyclic list where \\spad{v} is the head of the cycle,{} \\axiom{cycleSplit!(\\spad{w})} will drop \\spad{v} off \\spad{w} thus destructively changing \\spad{w} to \\spad{u},{} and returning \\spad{v}.")) (|concat!| (($ $ |#2|) "\\spad{concat!(u,{}x)} destructively adds element \\spad{x} to the end of \\spad{u}. Note that \\axiom{concat!(a,{}\\spad{x}) = setlast!(a,{}[\\spad{x}])}.") (($ $ $) "\\spad{concat!(u,{}v)} destructively concatenates \\spad{v} to the end of \\spad{u}. Note that \\axiom{concat!(\\spad{u},{}\\spad{v}) = setlast_!(\\spad{u},{}\\spad{v})}.")) (|cycleTail| (($ $) "\\spad{cycleTail(u)} returns the last node in the cycle,{} or empty if none exists.")) (|cycleLength| (((|NonNegativeInteger|) $) "\\spad{cycleLength(u)} returns the length of a top-level cycle contained in aggregate \\spad{u},{} or 0 is \\spad{u} has no such cycle.")) (|cycleEntry| (($ $) "\\spad{cycleEntry(u)} returns the head of a top-level cycle contained in aggregate \\spad{u},{} or \\axiom{empty()} if none exists.")) (|third| ((|#2| $) "\\spad{third(u)} returns the third element of \\spad{u}. Note that \\axiom{third(\\spad{u}) = first(rest(rest(\\spad{u})))}.")) (|second| ((|#2| $) "\\spad{second(u)} returns the second element of \\spad{u}. Note that \\axiom{second(\\spad{u}) = first(rest(\\spad{u}))}.")) (|tail| (($ $) "\\spad{tail(u)} returns the last node of \\spad{u}. Note that if \\spad{u} is \\axiom{shallowlyMutable},{} \\axiom{setrest(tail(\\spad{u}),{}\\spad{v}) = concat(\\spad{u},{}\\spad{v})}.")) (|last| (($ $ (|NonNegativeInteger|)) "\\spad{last(u,{}n)} returns a copy of the last \\spad{n} (\\axiom{\\spad{n} \\spad{>=} 0}) nodes of \\spad{u}. Note that \\axiom{last(\\spad{u},{}\\spad{n})} is a list of \\spad{n} elements.") ((|#2| $) "\\spad{last(u)} resturn the last element of \\spad{u}. Note that for lists,{} \\axiom{last(\\spad{u})=u . (maxIndex \\spad{u})=u . (\\# \\spad{u} - 1)}.")) (|rest| (($ $ (|NonNegativeInteger|)) "\\spad{rest(u,{}n)} returns the \\axiom{\\spad{n}}th (\\spad{n} \\spad{>=} 0) node of \\spad{u}. Note that \\axiom{rest(\\spad{u},{}0) = \\spad{u}}.") (($ $) "\\spad{rest(u)} returns an aggregate consisting of all but the first element of \\spad{u} (equivalently,{} the next node of \\spad{u}).")) (|elt| ((|#2| $ "last") "\\spad{elt(u,{}\"last\")} (also written: \\axiom{\\spad{u} . last}) is equivalent to last \\spad{u}.") (($ $ "rest") "\\spad{elt(\\%,{}\"rest\")} (also written: \\axiom{\\spad{u}.rest}) is equivalent to \\axiom{rest \\spad{u}}.") ((|#2| $ "first") "\\spad{elt(u,{}\"first\")} (also written: \\axiom{\\spad{u} . first}) is equivalent to first \\spad{u}.")) (|first| (($ $ (|NonNegativeInteger|)) "\\spad{first(u,{}n)} returns a copy of the first \\spad{n} (\\axiom{\\spad{n} \\spad{>=} 0}) elements of \\spad{u}.") ((|#2| $) "\\spad{first(u)} returns the first element of \\spad{u} (equivalently,{} the value at the current node).")) (|concat| (($ |#2| $) "\\spad{concat(x,{}u)} returns aggregate consisting of \\spad{x} followed by the elements of \\spad{u}. Note that if \\axiom{\\spad{v} = concat(\\spad{x},{}\\spad{u})} then \\axiom{\\spad{x} = first \\spad{v}} and \\axiom{\\spad{u} = rest \\spad{v}}.") (($ $ $) "\\spad{concat(u,{}v)} returns an aggregate \\spad{w} consisting of the elements of \\spad{u} followed by the elements of \\spad{v}. Note that \\axiom{\\spad{v} = rest(\\spad{w},{}\\#a)}."))) 
 NIL 
-((|HasAttribute| |#1| (QUOTE -4520))) 
+((|HasAttribute| |#1| (QUOTE -4522))) 
 (-1231 S) 
 ((|constructor| (NIL "A unary-recursive aggregate is a one where nodes may have either 0 or 1 children. This aggregate models,{} though not precisely,{} a linked list possibly with a single cycle. A node with one children models a non-empty list,{} with the \\spadfun{value} of the list designating the head,{} or \\spadfun{first},{} of the list,{} and the child designating the tail,{} or \\spadfun{rest},{} of the list. A node with no child then designates the empty list. Since these aggregates are recursive aggregates,{} they may be cyclic.")) (|split!| (($ $ (|Integer|)) "\\spad{split!(u,{}n)} splits \\spad{u} into two aggregates: \\axiom{\\spad{v} = rest(\\spad{u},{}\\spad{n})} and \\axiom{\\spad{w} = first(\\spad{u},{}\\spad{n})},{} returning \\axiom{\\spad{v}}. Note that afterwards \\axiom{rest(\\spad{u},{}\\spad{n})} returns \\axiom{empty()}.")) (|setlast!| ((|#1| $ |#1|) "\\spad{setlast!(u,{}x)} destructively changes the last element of \\spad{u} to \\spad{x}.")) (|setrest!| (($ $ $) "\\spad{setrest!(u,{}v)} destructively changes the rest of \\spad{u} to \\spad{v}.")) (|setelt| ((|#1| $ "last" |#1|) "\\spad{setelt(u,{}\"last\",{}x)} (also written: \\axiom{\\spad{u}.last \\spad{:=} \\spad{b}}) is equivalent to \\axiom{setlast!(\\spad{u},{}\\spad{v})}.") (($ $ "rest" $) "\\spad{setelt(u,{}\"rest\",{}v)} (also written: \\axiom{\\spad{u}.rest \\spad{:=} \\spad{v}}) is equivalent to \\axiom{setrest!(\\spad{u},{}\\spad{v})}.") ((|#1| $ "first" |#1|) "\\spad{setelt(u,{}\"first\",{}x)} (also written: \\axiom{\\spad{u}.first \\spad{:=} \\spad{x}}) is equivalent to \\axiom{setfirst!(\\spad{u},{}\\spad{x})}.")) (|setfirst!| ((|#1| $ |#1|) "\\spad{setfirst!(u,{}x)} destructively changes the first element of a to \\spad{x}.")) (|cycleSplit!| (($ $) "\\spad{cycleSplit!(u)} splits the aggregate by dropping off the cycle. The value returned is the cycle entry,{} or nil if none exists. For example,{} if \\axiom{\\spad{w} = concat(\\spad{u},{}\\spad{v})} is the cyclic list where \\spad{v} is the head of the cycle,{} \\axiom{cycleSplit!(\\spad{w})} will drop \\spad{v} off \\spad{w} thus destructively changing \\spad{w} to \\spad{u},{} and returning \\spad{v}.")) (|concat!| (($ $ |#1|) "\\spad{concat!(u,{}x)} destructively adds element \\spad{x} to the end of \\spad{u}. Note that \\axiom{concat!(a,{}\\spad{x}) = setlast!(a,{}[\\spad{x}])}.") (($ $ $) "\\spad{concat!(u,{}v)} destructively concatenates \\spad{v} to the end of \\spad{u}. Note that \\axiom{concat!(\\spad{u},{}\\spad{v}) = setlast_!(\\spad{u},{}\\spad{v})}.")) (|cycleTail| (($ $) "\\spad{cycleTail(u)} returns the last node in the cycle,{} or empty if none exists.")) (|cycleLength| (((|NonNegativeInteger|) $) "\\spad{cycleLength(u)} returns the length of a top-level cycle contained in aggregate \\spad{u},{} or 0 is \\spad{u} has no such cycle.")) (|cycleEntry| (($ $) "\\spad{cycleEntry(u)} returns the head of a top-level cycle contained in aggregate \\spad{u},{} or \\axiom{empty()} if none exists.")) (|third| ((|#1| $) "\\spad{third(u)} returns the third element of \\spad{u}. Note that \\axiom{third(\\spad{u}) = first(rest(rest(\\spad{u})))}.")) (|second| ((|#1| $) "\\spad{second(u)} returns the second element of \\spad{u}. Note that \\axiom{second(\\spad{u}) = first(rest(\\spad{u}))}.")) (|tail| (($ $) "\\spad{tail(u)} returns the last node of \\spad{u}. Note that if \\spad{u} is \\axiom{shallowlyMutable},{} \\axiom{setrest(tail(\\spad{u}),{}\\spad{v}) = concat(\\spad{u},{}\\spad{v})}.")) (|last| (($ $ (|NonNegativeInteger|)) "\\spad{last(u,{}n)} returns a copy of the last \\spad{n} (\\axiom{\\spad{n} \\spad{>=} 0}) nodes of \\spad{u}. Note that \\axiom{last(\\spad{u},{}\\spad{n})} is a list of \\spad{n} elements.") ((|#1| $) "\\spad{last(u)} resturn the last element of \\spad{u}. Note that for lists,{} \\axiom{last(\\spad{u})=u . (maxIndex \\spad{u})=u . (\\# \\spad{u} - 1)}.")) (|rest| (($ $ (|NonNegativeInteger|)) "\\spad{rest(u,{}n)} returns the \\axiom{\\spad{n}}th (\\spad{n} \\spad{>=} 0) node of \\spad{u}. Note that \\axiom{rest(\\spad{u},{}0) = \\spad{u}}.") (($ $) "\\spad{rest(u)} returns an aggregate consisting of all but the first element of \\spad{u} (equivalently,{} the next node of \\spad{u}).")) (|elt| ((|#1| $ "last") "\\spad{elt(u,{}\"last\")} (also written: \\axiom{\\spad{u} . last}) is equivalent to last \\spad{u}.") (($ $ "rest") "\\spad{elt(\\%,{}\"rest\")} (also written: \\axiom{\\spad{u}.rest}) is equivalent to \\axiom{rest \\spad{u}}.") ((|#1| $ "first") "\\spad{elt(u,{}\"first\")} (also written: \\axiom{\\spad{u} . first}) is equivalent to first \\spad{u}.")) (|first| (($ $ (|NonNegativeInteger|)) "\\spad{first(u,{}n)} returns a copy of the first \\spad{n} (\\axiom{\\spad{n} \\spad{>=} 0}) elements of \\spad{u}.") ((|#1| $) "\\spad{first(u)} returns the first element of \\spad{u} (equivalently,{} the value at the current node).")) (|concat| (($ |#1| $) "\\spad{concat(x,{}u)} returns aggregate consisting of \\spad{x} followed by the elements of \\spad{u}. Note that if \\axiom{\\spad{v} = concat(\\spad{x},{}\\spad{u})} then \\axiom{\\spad{x} = first \\spad{v}} and \\axiom{\\spad{u} = rest \\spad{v}}.") (($ $ $) "\\spad{concat(u,{}v)} returns an aggregate \\spad{w} consisting of the elements of \\spad{u} followed by the elements of \\spad{v}. Note that \\axiom{\\spad{v} = rest(\\spad{w},{}\\#a)}."))) 
 ((-3973 . T)) 
@@ -4863,15 +4863,15 @@ NIL
 (-1233 S |Coef|) 
 ((|constructor| (NIL "\\spadtype{UnivariateTaylorSeriesCategory} is the category of Taylor series in one variable.")) (|integrate| (($ $ (|Symbol|)) "\\spad{integrate(f(x),{}y)} returns an anti-derivative of the power series \\spad{f(x)} with respect to the variable \\spad{y}.") (($ $ (|Symbol|)) "\\spad{integrate(f(x),{}y)} returns an anti-derivative of the power series \\spad{f(x)} with respect to the variable \\spad{y}.") (($ $) "\\spad{integrate(f(x))} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 0. We may integrate a series when we can divide coefficients by integers.")) (** (($ $ |#2|) "\\spad{f(x) ** a} computes a power of a power series. When the coefficient ring is a field,{} we may raise a series to an exponent from the coefficient ring provided that the constant coefficient of the series is 1.")) (|polynomial| (((|Polynomial| |#2|) $ (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{polynomial(f,{}k1,{}k2)} returns a polynomial consisting of the sum of all terms of \\spad{f} of degree \\spad{d} with \\spad{k1 <= d <= k2}.") (((|Polynomial| |#2|) $ (|NonNegativeInteger|)) "\\spad{polynomial(f,{}k)} returns a polynomial consisting of the sum of all terms of \\spad{f} of degree \\spad{<= k}.")) (|multiplyCoefficients| (($ (|Mapping| |#2| (|Integer|)) $) "\\spad{multiplyCoefficients(f,{}sum(n = 0..infinity,{}a[n] * x**n))} returns \\spad{sum(n = 0..infinity,{}f(n) * a[n] * x**n)}. This function is used when Laurent series are represented by a Taylor series and an order.")) (|quoByVar| (($ $) "\\spad{quoByVar(a0 + a1 x + a2 x**2 + ...)} returns \\spad{a1 + a2 x + a3 x**2 + ...} Thus,{} this function substracts the constant term and divides by the series variable. This function is used when Laurent series are represented by a Taylor series and an order.")) (|coefficients| (((|Stream| |#2|) $) "\\spad{coefficients(a0 + a1 x + a2 x**2 + ...)} returns a stream of coefficients: \\spad{[a0,{}a1,{}a2,{}...]}. The entries of the stream may be zero.")) (|series| (($ (|Stream| |#2|)) "\\spad{series([a0,{}a1,{}a2,{}...])} is the Taylor series \\spad{a0 + a1 x + a2 x**2 + ...}.") (($ (|Stream| (|Record| (|:| |k| (|NonNegativeInteger|)) (|:| |c| |#2|)))) "\\spad{series(st)} creates a series from a stream of non-zero terms,{} where a term is an exponent-coefficient pair. The terms in the stream should be ordered by increasing order of exponents."))) 
 NIL 
-((|HasCategory| |#2| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-959))) (|HasCategory| |#2| (QUOTE (-1181))) (|HasSignature| |#2| (LIST (QUOTE -2055) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#2|)))) (|HasSignature| |#2| (LIST (QUOTE -3837) (LIST (|devaluate| |#2|) (|devaluate| |#2|) (QUOTE (-1161))))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-365)))) 
+((|HasCategory| |#2| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#2| (QUOTE (-959))) (|HasCategory| |#2| (QUOTE (-1181))) (|HasSignature| |#2| (LIST (QUOTE -2057) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#2|)))) (|HasSignature| |#2| (LIST (QUOTE -1845) (LIST (|devaluate| |#2|) (|devaluate| |#2|) (QUOTE (-1161))))) (|HasCategory| |#2| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#2| (QUOTE (-365)))) 
 (-1234 |Coef|) 
 ((|constructor| (NIL "\\spadtype{UnivariateTaylorSeriesCategory} is the category of Taylor series in one variable.")) (|integrate| (($ $ (|Symbol|)) "\\spad{integrate(f(x),{}y)} returns an anti-derivative of the power series \\spad{f(x)} with respect to the variable \\spad{y}.") (($ $ (|Symbol|)) "\\spad{integrate(f(x),{}y)} returns an anti-derivative of the power series \\spad{f(x)} with respect to the variable \\spad{y}.") (($ $) "\\spad{integrate(f(x))} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 0. We may integrate a series when we can divide coefficients by integers.")) (** (($ $ |#1|) "\\spad{f(x) ** a} computes a power of a power series. When the coefficient ring is a field,{} we may raise a series to an exponent from the coefficient ring provided that the constant coefficient of the series is 1.")) (|polynomial| (((|Polynomial| |#1|) $ (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{polynomial(f,{}k1,{}k2)} returns a polynomial consisting of the sum of all terms of \\spad{f} of degree \\spad{d} with \\spad{k1 <= d <= k2}.") (((|Polynomial| |#1|) $ (|NonNegativeInteger|)) "\\spad{polynomial(f,{}k)} returns a polynomial consisting of the sum of all terms of \\spad{f} of degree \\spad{<= k}.")) (|multiplyCoefficients| (($ (|Mapping| |#1| (|Integer|)) $) "\\spad{multiplyCoefficients(f,{}sum(n = 0..infinity,{}a[n] * x**n))} returns \\spad{sum(n = 0..infinity,{}f(n) * a[n] * x**n)}. This function is used when Laurent series are represented by a Taylor series and an order.")) (|quoByVar| (($ $) "\\spad{quoByVar(a0 + a1 x + a2 x**2 + ...)} returns \\spad{a1 + a2 x + a3 x**2 + ...} Thus,{} this function substracts the constant term and divides by the series variable. This function is used when Laurent series are represented by a Taylor series and an order.")) (|coefficients| (((|Stream| |#1|) $) "\\spad{coefficients(a0 + a1 x + a2 x**2 + ...)} returns a stream of coefficients: \\spad{[a0,{}a1,{}a2,{}...]}. The entries of the stream may be zero.")) (|series| (($ (|Stream| |#1|)) "\\spad{series([a0,{}a1,{}a2,{}...])} is the Taylor series \\spad{a0 + a1 x + a2 x**2 + ...}.") (($ (|Stream| (|Record| (|:| |k| (|NonNegativeInteger|)) (|:| |c| |#1|)))) "\\spad{series(st)} creates a series from a stream of non-zero terms,{} where a term is an exponent-coefficient pair. The terms in the stream should be ordered by increasing order of exponents."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4513 . T) (-4514 . T) (-4516 . T)) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-1235 |Coef| |var| |cen|) 
 ((|constructor| (NIL "Dense Taylor series in one variable \\spadtype{UnivariateTaylorSeries} is a domain representing Taylor series in one variable with coefficients in an arbitrary ring. The parameters of the type specify the coefficient ring,{} the power series variable,{} and the center of the power series expansion. For example,{} \\spadtype{UnivariateTaylorSeries}(Integer,{}\\spad{x},{}3) represents Taylor series in \\spad{(x - 3)} with \\spadtype{Integer} coefficients.")) (|integrate| (($ $ (|Variable| |#2|)) "\\spad{integrate(f(x),{}x)} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 0. We may integrate a series when we can divide coefficients by integers.")) (|invmultisect| (($ (|Integer|) (|Integer|) $) "\\spad{invmultisect(a,{}b,{}f(x))} substitutes \\spad{x^((a+b)*n)} \\indented{1}{for \\spad{x^n} and multiples by \\spad{x^b}.}")) (|multisect| (($ (|Integer|) (|Integer|) $) "\\spad{multisect(a,{}b,{}f(x))} selects the coefficients of \\indented{1}{\\spad{x^((a+b)*n+a)},{} and changes this monomial to \\spad{x^n}.}")) (|revert| (($ $) "\\spad{revert(f(x))} returns a Taylor series \\spad{g(x)} such that \\spad{f(g(x)) = g(f(x)) = x}. Series \\spad{f(x)} should have constant coefficient 0 and 1st order coefficient 1.")) (|generalLambert| (($ $ (|Integer|) (|Integer|)) "\\spad{generalLambert(f(x),{}a,{}d)} returns \\spad{f(x^a) + f(x^(a + d)) + \\indented{1}{f(x^(a + 2 d)) + ... }. \\spad{f(x)} should have zero constant} \\indented{1}{coefficient and \\spad{a} and \\spad{d} should be positive.}")) (|evenlambert| (($ $) "\\spad{evenlambert(f(x))} returns \\spad{f(x^2) + f(x^4) + f(x^6) + ...}. \\indented{1}{\\spad{f(x)} should have a zero constant coefficient.} \\indented{1}{This function is used for computing infinite products.} \\indented{1}{If \\spad{f(x)} is a Taylor series with constant term 1,{} then} \\indented{1}{\\spad{product(n=1..infinity,{}f(x^(2*n))) = exp(log(evenlambert(f(x))))}.}")) (|oddlambert| (($ $) "\\spad{oddlambert(f(x))} returns \\spad{f(x) + f(x^3) + f(x^5) + ...}. \\indented{1}{\\spad{f(x)} should have a zero constant coefficient.} \\indented{1}{This function is used for computing infinite products.} \\indented{1}{If \\spad{f(x)} is a Taylor series with constant term 1,{} then} \\indented{1}{\\spad{product(n=1..infinity,{}f(x^(2*n-1)))=exp(log(oddlambert(f(x))))}.}")) (|lambert| (($ $) "\\spad{lambert(f(x))} returns \\spad{f(x) + f(x^2) + f(x^3) + ...}. \\indented{1}{This function is used for computing infinite products.} \\indented{1}{\\spad{f(x)} should have zero constant coefficient.} \\indented{1}{If \\spad{f(x)} is a Taylor series with constant term 1,{} then} \\indented{1}{\\spad{product(n = 1..infinity,{}f(x^n)) = exp(log(lambert(f(x))))}.}")) (|lagrange| (($ $) "\\spad{lagrange(g(x))} produces the Taylor series for \\spad{f(x)} \\indented{1}{where \\spad{f(x)} is implicitly defined as \\spad{f(x) = x*g(f(x))}.}")) (|differentiate| (($ $ (|Variable| |#2|)) "\\spad{differentiate(f(x),{}x)} computes the derivative of \\spad{f(x)} with respect to \\spad{x}.")) (|univariatePolynomial| (((|UnivariatePolynomial| |#2| |#1|) $ (|NonNegativeInteger|)) "\\spad{univariatePolynomial(f,{}k)} returns a univariate polynomial \\indented{1}{consisting of the sum of all terms of \\spad{f} of degree \\spad{<= k}.}")) (|coerce| (($ (|Variable| |#2|)) "\\spad{coerce(var)} converts the series variable \\spad{var} into a \\indented{1}{Taylor series.}") (($ (|UnivariatePolynomial| |#2| |#1|)) "\\spad{coerce(p)} converts a univariate polynomial \\spad{p} in the variable \\spad{var} to a univariate Taylor series in \\spad{var}."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-763)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-763)) (|devaluate| |#1|))))) (|HasCategory| (-763) (QUOTE (-1102))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-763))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-763))))) (|HasSignature| |#1| (LIST (QUOTE -2745) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (|HasCategory| |#1| (QUOTE (-365))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -3837) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2055) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|))))))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-763)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-763)) (|devaluate| |#1|))))) (|HasCategory| (-763) (QUOTE (-1102))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-763))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-763))))) (|HasSignature| |#1| (LIST (QUOTE -2747) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (|HasCategory| |#1| (QUOTE (-365))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -1845) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2057) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|))))))) 
 (-1236 |Coef| UTS) 
 ((|constructor| (NIL "Taylor series solutions of explicit ODE\\spad{'s}. This package provides Taylor series solutions to regular linear or non-linear ordinary differential equations of arbitrary order.")) (|mpsode| (((|List| |#2|) (|List| |#1|) (|List| (|Mapping| |#2| (|List| |#2|)))) "\\spad{mpsode(r,{}f)} solves the system of differential equations \\spad{dy[i]/dx =f[i] [x,{}y[1],{}y[2],{}...,{}y[n]]},{} \\spad{y[i](a) = r[i]} for \\spad{i} in 1..\\spad{n}.")) (|ode| ((|#2| (|Mapping| |#2| (|List| |#2|)) (|List| |#1|)) "\\spad{ode(f,{}cl)} is the solution to \\spad{y<n>=f(y,{}y',{}..,{}y<n-1>)} such that \\spad{y<i>(a) = cl.i} for \\spad{i} in 1..\\spad{n}.")) (|ode2| ((|#2| (|Mapping| |#2| |#2| |#2|) |#1| |#1|) "\\spad{ode2(f,{}c0,{}c1)} is the solution to \\spad{y'' = f(y,{}y')} such that \\spad{y(a) = c0} and \\spad{y'(a) = c1}.")) (|ode1| ((|#2| (|Mapping| |#2| |#2|) |#1|) "\\spad{ode1(f,{}c)} is the solution to \\spad{y' = f(y)} such that \\spad{y(a) = c}.")) (|fixedPointExquo| ((|#2| |#2| |#2|) "\\spad{fixedPointExquo(f,{}g)} computes the exact quotient of \\spad{f} and \\spad{g} using a fixed point computation.")) (|stFuncN| (((|Mapping| (|Stream| |#1|) (|List| (|Stream| |#1|))) (|Mapping| |#2| (|List| |#2|))) "\\spad{stFuncN(f)} is a local function xported due to compiler problem. This function is of no interest to the top-level user.")) (|stFunc2| (((|Mapping| (|Stream| |#1|) (|Stream| |#1|) (|Stream| |#1|)) (|Mapping| |#2| |#2| |#2|)) "\\spad{stFunc2(f)} is a local function exported due to compiler problem. This function is of no interest to the top-level user.")) (|stFunc1| (((|Mapping| (|Stream| |#1|) (|Stream| |#1|)) (|Mapping| |#2| |#2|)) "\\spad{stFunc1(f)} is a local function exported due to compiler problem. This function is of no interest to the top-level user."))) 
 NIL 
@@ -4886,8 +4886,8 @@ NIL
 NIL 
 (-1239 |Coef| |var|) 
 ((|constructor| (NIL "Part of the Package for Algebraic Function Fields in one variable PAFF")) (|integrate| (($ $ (|Variable| |#2|)) "\\spad{integrate(f(x),{}x)} returns an anti-derivative of the power series \\spad{f(x)} with constant coefficient 0. We may integrate a series when we can divide coefficients by integers.")) (|invmultisect| (($ (|Integer|) (|Integer|) $) "\\spad{invmultisect(a,{}b,{}f(x))} substitutes \\spad{x^((a+b)*n)} \\indented{1}{for \\spad{x^n} and multiples by \\spad{x^b}.}")) (|multisect| (($ (|Integer|) (|Integer|) $) "\\spad{multisect(a,{}b,{}f(x))} selects the coefficients of \\indented{1}{\\spad{x^((a+b)*n+a)},{} and changes this monomial to \\spad{x^n}.}")) (|revert| (($ $) "\\spad{revert(f(x))} returns a Taylor series \\spad{g(x)} such that \\spad{f(g(x)) = g(f(x)) = x}. Series \\spad{f(x)} should have constant coefficient 0 and 1st order coefficient 1.")) (|generalLambert| (($ $ (|Integer|) (|Integer|)) "\\spad{generalLambert(f(x),{}a,{}d)} returns \\spad{f(x^a) + f(x^(a + d)) + \\indented{1}{f(x^(a + 2 d)) + ... }. \\spad{f(x)} should have zero constant} \\indented{1}{coefficient and \\spad{a} and \\spad{d} should be positive.}")) (|evenlambert| (($ $) "\\spad{evenlambert(f(x))} returns \\spad{f(x^2) + f(x^4) + f(x^6) + ...}. \\indented{1}{\\spad{f(x)} should have a zero constant coefficient.} \\indented{1}{This function is used for computing infinite products.} \\indented{1}{If \\spad{f(x)} is a Taylor series with constant term 1,{} then} \\indented{1}{\\spad{product(n=1..infinity,{}f(x^(2*n)))=exp(log(evenlambert(f(x))))}.}")) (|oddlambert| (($ $) "\\spad{oddlambert(f(x))} returns \\spad{f(x) + f(x^3) + f(x^5) + ...}. \\indented{1}{\\spad{f(x)} should have a zero constant coefficient.} \\indented{1}{This function is used for computing infinite products.} \\indented{1}{If \\spad{f(x)} is a Taylor series with constant term 1,{} then} \\indented{1}{\\spad{product(n=1..infinity,{}f(x^(2*n-1)))=exp(log(oddlambert(f(x))))}.}")) (|lambert| (($ $) "\\spad{lambert(f(x))} returns \\spad{f(x) + f(x^2) + f(x^3) + ...}. \\indented{1}{This function is used for computing infinite products.} \\indented{1}{\\spad{f(x)} should have zero constant coefficient.} \\indented{1}{If \\spad{f(x)} is a Taylor series with constant term 1,{} then} \\indented{1}{\\spad{product(n = 1..infinity,{}f(x^n)) = exp(log(lambert(f(x))))}.}")) (|lagrange| (($ $) "\\spad{lagrange(g(x))} produces the Taylor series for \\spad{f(x)} \\indented{1}{where \\spad{f(x)} is implicitly defined as \\spad{f(x) = x*g(f(x))}.}")) (|differentiate| (($ $ (|Variable| |#2|)) "\\spad{differentiate(f(x),{}x)} computes the derivative of \\spad{f(x)} with respect to \\spad{x}.")) (|univariatePolynomial| (((|UnivariatePolynomial| |#2| |#1|) $ (|NonNegativeInteger|)) "\\spad{univariatePolynomial(f,{}k)} returns a univariate polynomial \\indented{1}{consisting of the sum of all terms of \\spad{f} of degree \\spad{<= k}.}")) (|coerce| (($ (|Variable| |#2|)) "\\spad{coerce(var)} converts the series variable \\spad{var} into a \\indented{1}{Taylor series.}") (($ (|UnivariatePolynomial| |#2| |#1|)) "\\spad{coerce(p)} converts a univariate polynomial \\spad{p} in the variable \\spad{var} to a univariate Taylor series in \\spad{var}."))) 
-(((-4521 "*") |has| |#1| (-172)) (-4512 |has| |#1| (-558)) (-4513 . T) (-4514 . T) (-4516 . T)) 
-((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2198 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-763)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-763)) (|devaluate| |#1|))))) (|HasCategory| (-763) (QUOTE (-1102))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-763))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-763))))) (|HasSignature| |#1| (LIST (QUOTE -2745) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (|HasCategory| |#1| (QUOTE (-365))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -3837) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2055) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|))))))) 
+(((-4523 "*") |has| |#1| (-172)) (-4514 |has| |#1| (-558)) (-4515 . T) (-4516 . T) (-4518 . T)) 
+((|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#1| (QUOTE (-172))) (-2199 (|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-558)))) (|HasCategory| |#1| (QUOTE (-148))) (|HasCategory| |#1| (QUOTE (-150))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-763)) (|devaluate| |#1|)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -895) (QUOTE (-1161)))) (|HasSignature| |#1| (LIST (QUOTE *) (LIST (|devaluate| |#1|) (QUOTE (-763)) (|devaluate| |#1|))))) (|HasCategory| (-763) (QUOTE (-1102))) (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-763))))) (-12 (|HasSignature| |#1| (LIST (QUOTE **) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-763))))) (|HasSignature| |#1| (LIST (QUOTE -2747) (LIST (|devaluate| |#1|) (QUOTE (-1161)))))) (|HasCategory| |#1| (QUOTE (-365))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -29) (QUOTE (-568)))) (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasCategory| |#1| (QUOTE (-959))) (|HasCategory| |#1| (QUOTE (-1181)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -43) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasSignature| |#1| (LIST (QUOTE -1845) (LIST (|devaluate| |#1|) (|devaluate| |#1|) (QUOTE (-1161))))) (|HasSignature| |#1| (LIST (QUOTE -2057) (LIST (LIST (QUOTE -634) (QUOTE (-1161))) (|devaluate| |#1|))))))) 
 (-1240 |sym|) 
 ((|constructor| (NIL "This domain implements variables")) (|variable| (((|Symbol|)) "\\spad{variable()} returns the symbol")) (|coerce| (((|Symbol|) $) "\\spad{coerce(x)} returns the symbol"))) 
 NIL 
@@ -4898,7 +4898,7 @@ NIL
 ((|HasCategory| |#2| (QUOTE (-1002))) (|HasCategory| |#2| (QUOTE (-1047))) (|HasCategory| |#2| (QUOTE (-716))) (|HasCategory| |#2| (QUOTE (-21))) (|HasCategory| |#2| (QUOTE (-23))) (|HasCategory| |#2| (QUOTE (-25)))) 
 (-1242 R) 
 ((|constructor| (NIL "\\spadtype{VectorCategory} represents the type of vector like objects,{} \\spadignore{i.e.} finite sequences indexed by some finite segment of the integers. The operations available on vectors depend on the structure of the underlying components. Many operations from the component domain are defined for vectors componentwise. It can by assumed that extraction or updating components can be done in constant time.")) (|magnitude| ((|#1| $) "\\spad{magnitude(v)} computes the sqrt(dot(\\spad{v},{}\\spad{v})),{} \\spadignore{i.e.} the length")) (|length| ((|#1| $) "\\spad{length(v)} computes the sqrt(dot(\\spad{v},{}\\spad{v})),{} \\spadignore{i.e.} the magnitude")) (|cross| (($ $ $) "vectorProduct(\\spad{u},{}\\spad{v}) constructs the cross product of \\spad{u} and \\spad{v}. Error: if \\spad{u} and \\spad{v} are not of length 3.")) (|outerProduct| (((|Matrix| |#1|) $ $) "\\spad{outerProduct(u,{}v)} constructs the matrix whose (\\spad{i},{}\\spad{j})\\spad{'}th element is \\spad{u}(\\spad{i})\\spad{*v}(\\spad{j}).")) (|dot| ((|#1| $ $) "\\spad{dot(x,{}y)} computes the inner product of the two vectors \\spad{x} and \\spad{y}. Error: if \\spad{x} and \\spad{y} are not of the same length.")) (* (($ $ |#1|) "\\spad{y * r} multiplies each component of the vector \\spad{y} by the element \\spad{r}.") (($ |#1| $) "\\spad{r * y} multiplies the element \\spad{r} times each component of the vector \\spad{y}.") (($ (|Integer|) $) "\\spad{n * y} multiplies each component of the vector \\spad{y} by the integer \\spad{n}.")) (- (($ $ $) "\\spad{x - y} returns the component-wise difference of the vectors \\spad{x} and \\spad{y}. Error: if \\spad{x} and \\spad{y} are not of the same length.") (($ $) "\\spad{-x} negates all components of the vector \\spad{x}.")) (|zero| (($ (|NonNegativeInteger|)) "\\spad{zero(n)} creates a zero vector of length \\spad{n}.")) (+ (($ $ $) "\\spad{x + y} returns the component-wise sum of the vectors \\spad{x} and \\spad{y}. Error: if \\spad{x} and \\spad{y} are not of the same length."))) 
-((-4520 . T) (-4519 . T) (-3973 . T)) 
+((-4522 . T) (-4521 . T) (-3973 . T)) 
 NIL 
 (-1243 A B) 
 ((|constructor| (NIL "This package provides operations which all take as arguments vectors of elements of some type \\spad{A} and functions from \\spad{A} to another of type \\spad{B}. The operations all iterate over their vector argument and either return a value of type \\spad{B} or a vector over \\spad{B}.")) (|map| (((|Union| (|Vector| |#2|) "failed") (|Mapping| (|Union| |#2| "failed") |#1|) (|Vector| |#1|)) "\\spad{map(f,{} v)} applies the function \\spad{f} to every element of the vector \\spad{v} producing a new vector containing the values or \\spad{\"failed\"}.") (((|Vector| |#2|) (|Mapping| |#2| |#1|) (|Vector| |#1|)) "\\spad{map(f,{} v)} applies the function \\spad{f} to every element of the vector \\spad{v} producing a new vector containing the values.")) (|reduce| ((|#2| (|Mapping| |#2| |#1| |#2|) (|Vector| |#1|) |#2|) "\\spad{reduce(func,{}vec,{}ident)} combines the elements in \\spad{vec} using the binary function \\spad{func}. Argument \\spad{ident} is returned if \\spad{vec} is empty.")) (|scan| (((|Vector| |#2|) (|Mapping| |#2| |#1| |#2|) (|Vector| |#1|) |#2|) "\\spad{scan(func,{}vec,{}ident)} creates a new vector whose elements are the result of applying reduce to the binary function \\spad{func},{} increasing initial subsequences of the vector \\spad{vec},{} and the element \\spad{ident}."))) 
@@ -4906,8 +4906,8 @@ NIL
 NIL 
 (-1244 R) 
 ((|constructor| (NIL "This type represents vector like objects with varying lengths and indexed by a finite segment of integers starting at 1.")) (|vector| (($ (|List| |#1|)) "\\spad{vector(l)} converts the list \\spad{l} to a vector."))) 
-((-4520 . T) (-4519 . T)) 
-((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (-2198 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-716))) (|HasCategory| |#1| (QUOTE (-1047))) (-12 (|HasCategory| |#1| (QUOTE (-1002))) (|HasCategory| |#1| (QUOTE (-1047)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2198 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
+((-4522 . T) (-4521 . T)) 
+((|HasCategory| |#1| (QUOTE (-1090))) (|HasCategory| |#1| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#1| (QUOTE (-842))) (-2199 (|HasCategory| |#1| (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-1090)))) (|HasCategory| (-568) (QUOTE (-842))) (|HasCategory| |#1| (QUOTE (-25))) (|HasCategory| |#1| (QUOTE (-23))) (|HasCategory| |#1| (QUOTE (-21))) (|HasCategory| |#1| (QUOTE (-716))) (|HasCategory| |#1| (QUOTE (-1047))) (-12 (|HasCategory| |#1| (QUOTE (-1002))) (|HasCategory| |#1| (QUOTE (-1047)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))) (-2199 (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-842)))) (-12 (|HasCategory| |#1| (LIST (QUOTE -303) (|devaluate| |#1|))) (|HasCategory| |#1| (QUOTE (-1090)))))) 
 (-1245) 
 ((|constructor| (NIL "TwoDimensionalViewport creates viewports to display graphs.")) (|coerce| (((|OutputForm|) $) "\\spad{coerce(v)} returns the given two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport} as output of the domain \\spadtype{OutputForm}.")) (|key| (((|Integer|) $) "\\spad{key(v)} returns the process ID number of the given two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport}.")) (|reset| (((|Void|) $) "\\spad{reset(v)} sets the current state of the graph characteristics of the given two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport},{} back to their initial settings.")) (|write| (((|String|) $ (|String|) (|List| (|String|))) "\\spad{write(v,{}s,{}lf)} takes the given two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport},{} and creates a directory indicated by \\spad{s},{} which contains the graph data files for \\spad{v} and the optional file types indicated by the list \\spad{lf}.") (((|String|) $ (|String|) (|String|)) "\\spad{write(v,{}s,{}f)} takes the given two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport},{} and creates a directory indicated by \\spad{s},{} which contains the graph data files for \\spad{v} and an optional file type \\spad{f}.") (((|String|) $ (|String|)) "\\spad{write(v,{}s)} takes the given two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport},{} and creates a directory indicated by \\spad{s},{} which contains the graph data files for \\spad{v}.")) (|resize| (((|Void|) $ (|PositiveInteger|) (|PositiveInteger|)) "\\spad{resize(v,{}w,{}h)} displays the two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport},{} with a width of \\spad{w} and a height of \\spad{h},{} keeping the upper left-hand corner position unchanged.")) (|update| (((|Void|) $ (|GraphImage|) (|PositiveInteger|)) "\\spad{update(v,{}gr,{}n)} drops the graph \\spad{gr} in slot \\spad{n} of viewport \\spad{v}. The graph \\spad{gr} must have been transmitted already and acquired an integer key.")) (|move| (((|Void|) $ (|NonNegativeInteger|) (|NonNegativeInteger|)) "\\spad{move(v,{}x,{}y)} displays the two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport},{} with the upper left-hand corner of the viewport window at the screen coordinate position \\spad{x},{} \\spad{y}.")) (|show| (((|Void|) $ (|PositiveInteger|) (|String|)) "\\spad{show(v,{}n,{}s)} displays the graph in field \\spad{n} of the given two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport},{} if \\spad{s} is \"on\",{} or does not display the graph if \\spad{s} is \"off\".")) (|translate| (((|Void|) $ (|PositiveInteger|) (|Float|) (|Float|)) "\\spad{translate(v,{}n,{}dx,{}dy)} displays the graph in field \\spad{n} of the given two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport},{} translated by \\spad{dx} in the \\spad{x}-coordinate direction from the center of the viewport,{} and by \\spad{dy} in the \\spad{y}-coordinate direction from the center. Setting \\spad{dx} and \\spad{dy} to \\spad{0} places the center of the graph at the center of the viewport.")) (|scale| (((|Void|) $ (|PositiveInteger|) (|Float|) (|Float|)) "\\spad{scale(v,{}n,{}sx,{}sy)} displays the graph in field \\spad{n} of the given two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport},{} scaled by the factor \\spad{sx} in the \\spad{x}-coordinate direction and by the factor \\spad{sy} in the \\spad{y}-coordinate direction.")) (|dimensions| (((|Void|) $ (|NonNegativeInteger|) (|NonNegativeInteger|) (|PositiveInteger|) (|PositiveInteger|)) "\\spad{dimensions(v,{}x,{}y,{}width,{}height)} sets the position of the upper left-hand corner of the two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport},{} to the window coordinate \\spad{x},{} \\spad{y},{} and sets the dimensions of the window to that of \\spad{width},{} \\spad{height}. The new dimensions are not displayed until the function \\spadfun{makeViewport2D} is executed again for \\spad{v}.")) (|close| (((|Void|) $) "\\spad{close(v)} closes the viewport window of the given two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport},{} and terminates the corresponding process ID.")) (|controlPanel| (((|Void|) $ (|String|)) "\\spad{controlPanel(v,{}s)} displays the control panel of the given two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport},{} if \\spad{s} is \"on\",{} or hides the control panel if \\spad{s} is \"off\".")) (|connect| (((|Void|) $ (|PositiveInteger|) (|String|)) "\\spad{connect(v,{}n,{}s)} displays the lines connecting the graph points in field \\spad{n} of the given two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport},{} if \\spad{s} is \"on\",{} or does not display the lines if \\spad{s} is \"off\".")) (|region| (((|Void|) $ (|PositiveInteger|) (|String|)) "\\spad{region(v,{}n,{}s)} displays the bounding box of the graph in field \\spad{n} of the given two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport},{} if \\spad{s} is \"on\",{} or does not display the bounding box if \\spad{s} is \"off\".")) (|points| (((|Void|) $ (|PositiveInteger|) (|String|)) "\\spad{points(v,{}n,{}s)} displays the points of the graph in field \\spad{n} of the given two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport},{} if \\spad{s} is \"on\",{} or does not display the points if \\spad{s} is \"off\".")) (|units| (((|Void|) $ (|PositiveInteger|) (|Palette|)) "\\spad{units(v,{}n,{}c)} displays the units of the graph in field \\spad{n} of the given two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport},{} with the units color set to the given palette color \\spad{c}.") (((|Void|) $ (|PositiveInteger|) (|String|)) "\\spad{units(v,{}n,{}s)} displays the units of the graph in field \\spad{n} of the given two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport},{} if \\spad{s} is \"on\",{} or does not display the units if \\spad{s} is \"off\".")) (|axes| (((|Void|) $ (|PositiveInteger|) (|Palette|)) "\\spad{axes(v,{}n,{}c)} displays the axes of the graph in field \\spad{n} of the given two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport},{} with the axes color set to the given palette color \\spad{c}.") (((|Void|) $ (|PositiveInteger|) (|String|)) "\\spad{axes(v,{}n,{}s)} displays the axes of the graph in field \\spad{n} of the given two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport},{} if \\spad{s} is \"on\",{} or does not display the axes if \\spad{s} is \"off\".")) (|getGraph| (((|GraphImage|) $ (|PositiveInteger|)) "\\spad{getGraph(v,{}n)} returns the graph which is of the domain \\spadtype{GraphImage} which is located in graph field \\spad{n} of the given two-dimensional viewport,{} \\spad{v},{} which is of the domain \\spadtype{TwoDimensionalViewport}.")) (|putGraph| (((|Void|) $ (|GraphImage|) (|PositiveInteger|)) "\\spad{putGraph(v,{}\\spad{gi},{}n)} sets the graph field indicated by \\spad{n},{} of the indicated two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport},{} to be the graph,{} \\spad{\\spad{gi}} of domain \\spadtype{GraphImage}. The contents of viewport,{} \\spad{v},{} will contain \\spad{\\spad{gi}} when the function \\spadfun{makeViewport2D} is called to create the an updated viewport \\spad{v}.")) (|title| (((|Void|) $ (|String|)) "\\spad{title(v,{}s)} changes the title which is shown in the two-dimensional viewport window,{} \\spad{v} of domain \\spadtype{TwoDimensionalViewport}.")) (|graphs| (((|Vector| (|Union| (|GraphImage|) "undefined")) $) "\\spad{graphs(v)} returns a vector,{} or list,{} which is a union of all the graphs,{} of the domain \\spadtype{GraphImage},{} which are allocated for the two-dimensional viewport,{} \\spad{v},{} of domain \\spadtype{TwoDimensionalViewport}. Those graphs which have no data are labeled \"undefined\",{} otherwise their contents are shown.")) (|graphStates| (((|Vector| (|Record| (|:| |scaleX| (|DoubleFloat|)) (|:| |scaleY| (|DoubleFloat|)) (|:| |deltaX| (|DoubleFloat|)) (|:| |deltaY| (|DoubleFloat|)) (|:| |points| (|Integer|)) (|:| |connect| (|Integer|)) (|:| |spline| (|Integer|)) (|:| |axes| (|Integer|)) (|:| |axesColor| (|Palette|)) (|:| |units| (|Integer|)) (|:| |unitsColor| (|Palette|)) (|:| |showing| (|Integer|)))) $) "\\spad{graphStates(v)} returns and shows a listing of a record containing the current state of the characteristics of each of the ten graph records in the given two-dimensional viewport,{} \\spad{v},{} which is of domain \\spadtype{TwoDimensionalViewport}.")) (|graphState| (((|Void|) $ (|PositiveInteger|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|Integer|) (|Integer|) (|Integer|) (|Integer|) (|Palette|) (|Integer|) (|Palette|) (|Integer|)) "\\spad{graphState(v,{}num,{}sX,{}sY,{}dX,{}dY,{}pts,{}lns,{}box,{}axes,{}axesC,{}un,{}unC,{}cP)} sets the state of the characteristics for the graph indicated by \\spad{num} in the given two-dimensional viewport \\spad{v},{} of domain \\spadtype{TwoDimensionalViewport},{} to the values given as parameters. The scaling of the graph in the \\spad{x} and \\spad{y} component directions is set to be \\spad{sX} and \\spad{sY}; the window translation in the \\spad{x} and \\spad{y} component directions is set to be \\spad{dX} and \\spad{dY}; The graph points,{} lines,{} bounding \\spad{box},{} \\spad{axes},{} or units will be shown in the viewport if their given parameters \\spad{pts},{} \\spad{lns},{} \\spad{box},{} \\spad{axes} or \\spad{un} are set to be \\spad{1},{} but will not be shown if they are set to \\spad{0}. The color of the \\spad{axes} and the color of the units are indicated by the palette colors \\spad{axesC} and \\spad{unC} respectively. To display the control panel when the viewport window is displayed,{} set \\spad{cP} to \\spad{1},{} otherwise set it to \\spad{0}.")) (|options| (($ $ (|List| (|DrawOption|))) "\\spad{options(v,{}lopt)} takes the given two-dimensional viewport,{} \\spad{v},{} of the domain \\spadtype{TwoDimensionalViewport} and returns \\spad{v} with it\\spad{'s} draw options modified to be those which are indicated in the given list,{} \\spad{lopt} of domain \\spadtype{DrawOption}.") (((|List| (|DrawOption|)) $) "\\spad{options(v)} takes the given two-dimensional viewport,{} \\spad{v},{} of the domain \\spadtype{TwoDimensionalViewport} and returns a list containing the draw options from the domain \\spadtype{DrawOption} for \\spad{v}.")) (|makeViewport2D| (($ (|GraphImage|) (|List| (|DrawOption|))) "\\spad{makeViewport2D(\\spad{gi},{}lopt)} creates and displays a viewport window of the domain \\spadtype{TwoDimensionalViewport} whose graph field is assigned to be the given graph,{} \\spad{\\spad{gi}},{} of domain \\spadtype{GraphImage},{} and whose options field is set to be the list of options,{} \\spad{lopt} of domain \\spadtype{DrawOption}.") (($ $) "\\spad{makeViewport2D(v)} takes the given two-dimensional viewport,{} \\spad{v},{} of the domain \\spadtype{TwoDimensionalViewport} and displays a viewport window on the screen which contains the contents of \\spad{v}.")) (|viewport2D| (($) "\\spad{viewport2D()} returns an undefined two-dimensional viewport of the domain \\spadtype{TwoDimensionalViewport} whose contents are empty.")) (|getPickedPoints| (((|List| (|Point| (|DoubleFloat|))) $) "\\spad{getPickedPoints(x)} returns a list of small floats for the points the user interactively picked on the viewport for full integration into the system,{} some design issues need to be addressed: \\spadignore{e.g.} how to go through the GraphImage interface,{} how to default to graphs,{} etc."))) 
 NIL 
@@ -4934,7 +4934,7 @@ NIL
 NIL 
 (-1251 S) 
 ((|constructor| (NIL "Vector Spaces (not necessarily finite dimensional) over a field.")) (|dimension| (((|CardinalNumber|)) "\\spad{dimension()} returns the dimensionality of the vector space.")) (/ (($ $ |#1|) "\\spad{x/y} divides the vector \\spad{x} by the scalar \\spad{y}."))) 
-((-4514 . T) (-4513 . T)) 
+((-4516 . T) (-4515 . T)) 
 NIL 
 (-1252 R) 
 ((|constructor| (NIL "This package implements the Weierstrass preparation theorem \\spad{f} or multivariate power series. weierstrass(\\spad{v},{}\\spad{p}) where \\spad{v} is a variable,{} and \\spad{p} is a TaylorSeries(\\spad{R}) in which the terms of lowest degree \\spad{s} must include c*v**s where \\spad{c} is a constant,{}\\spad{s>0},{} is a list of TaylorSeries coefficients A[\\spad{i}] of the equivalent polynomial A = A[0] + A[1]\\spad{*v} + A[2]\\spad{*v**2} + ... + A[\\spad{s}-1]*v**(\\spad{s}-1) + v**s such that p=A*B ,{} \\spad{B} being a TaylorSeries of minimum degree 0")) (|qqq| (((|Mapping| (|Stream| (|TaylorSeries| |#1|)) (|Stream| (|TaylorSeries| |#1|))) (|NonNegativeInteger|) (|TaylorSeries| |#1|) (|Stream| (|TaylorSeries| |#1|))) "\\spad{qqq(n,{}s,{}st)} is used internally.")) (|weierstrass| (((|List| (|TaylorSeries| |#1|)) (|Symbol|) (|TaylorSeries| |#1|)) "\\spad{weierstrass(v,{}ts)} where \\spad{v} is a variable and \\spad{ts} is \\indented{1}{a TaylorSeries,{} impements the Weierstrass Preparation} \\indented{1}{Theorem. The result is a list of TaylorSeries that} \\indented{1}{are the coefficients of the equivalent series.}")) (|clikeUniv| (((|Mapping| (|SparseUnivariatePolynomial| (|Polynomial| |#1|)) (|Polynomial| |#1|)) (|Symbol|)) "\\spad{clikeUniv(v)} is used internally.")) (|sts2stst| (((|Stream| (|Stream| (|Polynomial| |#1|))) (|Symbol|) (|Stream| (|Polynomial| |#1|))) "\\spad{sts2stst(v,{}s)} is used internally.")) (|cfirst| (((|Mapping| (|Stream| (|Polynomial| |#1|)) (|Stream| (|Polynomial| |#1|))) (|NonNegativeInteger|)) "\\spad{cfirst n} is used internally.")) (|crest| (((|Mapping| (|Stream| (|Polynomial| |#1|)) (|Stream| (|Polynomial| |#1|))) (|NonNegativeInteger|)) "\\spad{crest n} is used internally."))) 
@@ -4946,27 +4946,27 @@ NIL
 NIL 
 (-1254 R |VarSet| E P |vl| |wl| |wtlevel|) 
 ((|constructor| (NIL "This domain represents truncated weighted polynomials over a general (not necessarily commutative) polynomial type. The variables must be specified,{} as must the weights. The representation is sparse in the sense that only non-zero terms are represented.")) (|changeWeightLevel| (((|Void|) (|NonNegativeInteger|)) "\\spad{changeWeightLevel(n)} changes the weight level to the new value given: \\spad{NB:} previously calculated terms are not affected")) (/ (((|Union| $ "failed") $ $) "\\spad{x/y} division (only works if minimum weight of divisor is zero,{} and if \\spad{R} is a Field)")) (|coerce| (($ |#4|) "\\spad{coerce(p)} coerces \\spad{p} into Weighted form,{} applying weights and ignoring terms") ((|#4| $) "convert back into a \\spad{\"P\"},{} ignoring weights"))) 
-((-4514 |has| |#1| (-172)) (-4513 |has| |#1| (-172)) (-4516 . T)) 
+((-4516 |has| |#1| (-172)) (-4515 |has| |#1| (-172)) (-4518 . T)) 
 ((|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365)))) 
 (-1255 R E V P) 
 ((|constructor| (NIL "A domain constructor of the category \\axiomType{GeneralTriangularSet}. The only requirement for a list of polynomials to be a member of such a domain is the following: no polynomial is constant and two distinct polynomials have distinct main variables. Such a triangular set may not be auto-reduced or consistent. The construct operation does not check the previous requirement. Triangular sets are stored as sorted lists \\spad{w}.\\spad{r}.\\spad{t}. the main variables of their members. Furthermore,{} this domain exports operations dealing with the characteristic set method of Wu Wen Tsun and some optimizations mainly proposed by Dong Ming Wang.")) (|characteristicSerie| (((|List| $) (|List| |#4|)) "\\axiom{characteristicSerie(\\spad{ps})} returns the same as \\axiom{characteristicSerie(\\spad{ps},{}initiallyReduced?,{}initiallyReduce)}.") (((|List| $) (|List| |#4|) (|Mapping| (|Boolean|) |#4| |#4|) (|Mapping| |#4| |#4| |#4|)) "\\axiom{characteristicSerie(\\spad{ps},{}redOp?,{}redOp)} returns a list \\axiom{\\spad{lts}} of triangular sets such that the zero set of \\axiom{\\spad{ps}} is the union of the regular zero sets of the members of \\axiom{\\spad{lts}}. This is made by the Ritt and Wu Wen Tsun process applying the operation \\axiom{characteristicSet(\\spad{ps},{}redOp?,{}redOp)} to compute characteristic sets in Wu Wen Tsun sense.")) (|characteristicSet| (((|Union| $ "failed") (|List| |#4|)) "\\axiom{characteristicSet(\\spad{ps})} returns the same as \\axiom{characteristicSet(\\spad{ps},{}initiallyReduced?,{}initiallyReduce)}.") (((|Union| $ "failed") (|List| |#4|) (|Mapping| (|Boolean|) |#4| |#4|) (|Mapping| |#4| |#4| |#4|)) "\\axiom{characteristicSet(\\spad{ps},{}redOp?,{}redOp)} returns a non-contradictory characteristic set of \\axiom{\\spad{ps}} in Wu Wen Tsun sense \\spad{w}.\\spad{r}.\\spad{t} the reduction-test \\axiom{redOp?} (using \\axiom{redOp} to reduce polynomials \\spad{w}.\\spad{r}.\\spad{t} a \\axiom{redOp?} basic set),{} if no non-zero constant polynomial appear during those reductions,{} else \\axiom{\"failed\"} is returned. The operations \\axiom{redOp} and \\axiom{redOp?} must satisfy the following conditions: \\axiom{redOp?(redOp(\\spad{p},{}\\spad{q}),{}\\spad{q})} holds for every polynomials \\axiom{\\spad{p},{}\\spad{q}} and there exists an integer \\axiom{\\spad{e}} and a polynomial \\axiom{\\spad{f}} such that we have \\axiom{init(\\spad{q})^e*p = \\spad{f*q} + redOp(\\spad{p},{}\\spad{q})}.")) (|medialSet| (((|Union| $ "failed") (|List| |#4|)) "\\axiom{medial(\\spad{ps})} returns the same as \\axiom{medialSet(\\spad{ps},{}initiallyReduced?,{}initiallyReduce)}.") (((|Union| $ "failed") (|List| |#4|) (|Mapping| (|Boolean|) |#4| |#4|) (|Mapping| |#4| |#4| |#4|)) "\\axiom{medialSet(\\spad{ps},{}redOp?,{}redOp)} returns \\axiom{\\spad{bs}} a basic set (in Wu Wen Tsun sense \\spad{w}.\\spad{r}.\\spad{t} the reduction-test \\axiom{redOp?}) of some set generating the same ideal as \\axiom{\\spad{ps}} (with rank not higher than any basic set of \\axiom{\\spad{ps}}),{} if no non-zero constant polynomials appear during the computatioms,{} else \\axiom{\"failed\"} is returned. In the former case,{} \\axiom{\\spad{bs}} has to be understood as a candidate for being a characteristic set of \\axiom{\\spad{ps}}. In the original algorithm,{} \\axiom{\\spad{bs}} is simply a basic set of \\axiom{\\spad{ps}}."))) 
-((-4520 . T) (-4519 . T)) 
+((-4522 . T) (-4521 . T)) 
 ((|HasCategory| |#4| (LIST (QUOTE -609) (QUOTE (-541)))) (|HasCategory| |#4| (QUOTE (-1090))) (-12 (|HasCategory| |#4| (LIST (QUOTE -303) (|devaluate| |#4|))) (|HasCategory| |#4| (QUOTE (-1090)))) (|HasCategory| |#1| (QUOTE (-558))) (|HasCategory| |#3| (QUOTE (-370)))) 
 (-1256 R) 
 ((|constructor| (NIL "This is the category of algebras over non-commutative rings. It is used by constructors of non-commutative algebras such as XPolynomialRing and XFreeAlgebra")) (|coerce| (($ |#1|) "\\spad{coerce(r)} equals \\spad{r*1}."))) 
-((-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-1257 |vl| R) 
 ((|constructor| (NIL "This type supports distributed multivariate polynomials whose variables do not commute. The coefficient ring may be non-commutative too. However,{} coefficients and variables commute."))) 
-((-4516 . T) (-4512 |has| |#2| (-6 -4512)) (-4514 . T) (-4513 . T)) 
-((|HasCategory| |#2| (QUOTE (-172))) (|HasAttribute| |#2| (QUOTE -4512))) 
+((-4518 . T) (-4514 |has| |#2| (-6 -4514)) (-4516 . T) (-4515 . T)) 
+((|HasCategory| |#2| (QUOTE (-172))) (|HasAttribute| |#2| (QUOTE -4514))) 
 (-1258 R |VarSet| XPOLY) 
 ((|constructor| (NIL "This package provides computations of logarithms and exponentials for polynomials in non-commutative variables.")) (|Hausdorff| ((|#3| |#3| |#3| (|NonNegativeInteger|)) "\\axiom{Hausdorff(a,{}\\spad{b},{}\\spad{n})} returns log(exp(a)*exp(\\spad{b})) truncated at order \\axiom{\\spad{n}}.")) (|log| ((|#3| |#3| (|NonNegativeInteger|)) "\\axiom{log(\\spad{p},{} \\spad{n})} returns the logarithm of \\axiom{\\spad{p}} truncated at order \\axiom{\\spad{n}}.")) (|exp| ((|#3| |#3| (|NonNegativeInteger|)) "\\axiom{exp(\\spad{p},{} \\spad{n})} returns the exponential of \\axiom{\\spad{p}} truncated at order \\axiom{\\spad{n}}."))) 
 NIL 
 NIL 
 (-1259 |vl| R) 
 ((|constructor| (NIL "This category specifies opeations for polynomials and formal series with non-commutative variables.")) (|varList| (((|List| |#1|) $) "\\spad{varList(x)} returns the list of variables which appear in \\spad{x}.")) (|map| (($ (|Mapping| |#2| |#2|) $) "\\spad{map(fn,{}x)} returns \\spad{Sum(fn(r_i) w_i)} if \\spad{x} writes \\spad{Sum(r_i w_i)}.")) (|sh| (($ $ (|NonNegativeInteger|)) "\\spad{sh(x,{}n)} returns the shuffle power of \\spad{x} to the \\spad{n}.") (($ $ $) "\\spad{sh(x,{}y)} returns the shuffle-product of \\spad{x} by \\spad{y}. This multiplication is associative and commutative.")) (|quasiRegular| (($ $) "\\spad{quasiRegular(x)} return \\spad{x} minus its constant term.")) (|quasiRegular?| (((|Boolean|) $) "\\spad{quasiRegular?(x)} return \\spad{true} if \\spad{constant(x)} is zero")) (|constant| ((|#2| $) "\\spad{constant(x)} returns the constant term of \\spad{x}.")) (|constant?| (((|Boolean|) $) "\\spad{constant?(x)} returns \\spad{true} if \\spad{x} is constant.")) (|coerce| (($ |#1|) "\\spad{coerce(v)} returns \\spad{v}.")) (|mirror| (($ $) "\\spad{mirror(x)} returns \\spad{Sum(r_i mirror(w_i))} if \\spad{x} writes \\spad{Sum(r_i w_i)}.")) (|monomial?| (((|Boolean|) $) "\\spad{monomial?(x)} returns \\spad{true} if \\spad{x} is a monomial")) (|monom| (($ (|OrderedFreeMonoid| |#1|) |#2|) "\\spad{monom(w,{}r)} returns the product of the word \\spad{w} by the coefficient \\spad{r}.")) (|rquo| (($ $ $) "\\spad{rquo(x,{}y)} returns the right simplification of \\spad{x} by \\spad{y}.") (($ $ (|OrderedFreeMonoid| |#1|)) "\\spad{rquo(x,{}w)} returns the right simplification of \\spad{x} by \\spad{w}.") (($ $ |#1|) "\\spad{rquo(x,{}v)} returns the right simplification of \\spad{x} by the variable \\spad{v}.")) (|lquo| (($ $ $) "\\spad{lquo(x,{}y)} returns the left simplification of \\spad{x} by \\spad{y}.") (($ $ (|OrderedFreeMonoid| |#1|)) "\\spad{lquo(x,{}w)} returns the left simplification of \\spad{x} by the word \\spad{w}.") (($ $ |#1|) "\\spad{lquo(x,{}v)} returns the left simplification of \\spad{x} by the variable \\spad{v}.")) (|coef| ((|#2| $ $) "\\spad{coef(x,{}y)} returns scalar product of \\spad{x} by \\spad{y},{} the set of words being regarded as an orthogonal basis.") ((|#2| $ (|OrderedFreeMonoid| |#1|)) "\\spad{coef(x,{}w)} returns the coefficient of the word \\spad{w} in \\spad{x}.")) (|mindegTerm| (((|Record| (|:| |k| (|OrderedFreeMonoid| |#1|)) (|:| |c| |#2|)) $) "\\spad{mindegTerm(x)} returns the term whose word is \\spad{mindeg(x)}.")) (|mindeg| (((|OrderedFreeMonoid| |#1|) $) "\\spad{mindeg(x)} returns the little word which appears in \\spad{x}. Error if \\spad{x=0}.")) (* (($ $ |#2|) "\\spad{x * r} returns the product of \\spad{x} by \\spad{r}. Usefull if \\spad{R} is a non-commutative Ring.") (($ |#1| $) "\\spad{v * x} returns the product of a variable \\spad{x} by \\spad{x}."))) 
-((-4512 |has| |#2| (-6 -4512)) (-4514 . T) (-4513 . T) (-4516 . T)) 
+((-4514 |has| |#2| (-6 -4514)) (-4516 . T) (-4515 . T) (-4518 . T)) 
 NIL 
 (-1260 S -1478) 
 ((|constructor| (NIL "ExtensionField \\spad{F} is the category of fields which extend the field \\spad{F}")) (|Frobenius| (($ $ (|NonNegativeInteger|)) "\\spad{Frobenius(a,{}s)} returns \\spad{a**(q**s)} where \\spad{q} is the size()\\$\\spad{F}.") (($ $) "\\spad{Frobenius(a)} returns \\spad{a ** q} where \\spad{q} is the \\spad{size()\\$F}.")) (|transcendenceDegree| (((|NonNegativeInteger|)) "\\spad{transcendenceDegree()} returns the transcendence degree of the field extension,{} 0 if the extension is algebraic.")) (|extensionDegree| (((|OnePointCompletion| (|PositiveInteger|))) "\\spad{extensionDegree()} returns the degree of the field extension if the extension is algebraic,{} and \\spad{infinity} if it is not.")) (|degree| (((|OnePointCompletion| (|PositiveInteger|)) $) "\\spad{degree(a)} returns the degree of minimal polynomial of an element \\spad{a} if \\spad{a} is algebraic with respect to the ground field \\spad{F},{} and \\spad{infinity} otherwise.")) (|inGroundField?| (((|Boolean|) $) "\\spad{inGroundField?(a)} tests whether an element \\spad{a} is already in the ground field \\spad{F}.")) (|transcendent?| (((|Boolean|) $) "\\spad{transcendent?(a)} tests whether an element \\spad{a} is transcendent with respect to the ground field \\spad{F}.")) (|algebraic?| (((|Boolean|) $) "\\spad{algebraic?(a)} tests whether an element \\spad{a} is algebraic with respect to the ground field \\spad{F}."))) 
@@ -4974,28 +4974,28 @@ NIL
 ((|HasCategory| |#2| (QUOTE (-370))) (|HasCategory| |#2| (QUOTE (-148))) (|HasCategory| |#2| (QUOTE (-150)))) 
 (-1261 -1478) 
 ((|constructor| (NIL "ExtensionField \\spad{F} is the category of fields which extend the field \\spad{F}")) (|Frobenius| (($ $ (|NonNegativeInteger|)) "\\spad{Frobenius(a,{}s)} returns \\spad{a**(q**s)} where \\spad{q} is the size()\\$\\spad{F}.") (($ $) "\\spad{Frobenius(a)} returns \\spad{a ** q} where \\spad{q} is the \\spad{size()\\$F}.")) (|transcendenceDegree| (((|NonNegativeInteger|)) "\\spad{transcendenceDegree()} returns the transcendence degree of the field extension,{} 0 if the extension is algebraic.")) (|extensionDegree| (((|OnePointCompletion| (|PositiveInteger|))) "\\spad{extensionDegree()} returns the degree of the field extension if the extension is algebraic,{} and \\spad{infinity} if it is not.")) (|degree| (((|OnePointCompletion| (|PositiveInteger|)) $) "\\spad{degree(a)} returns the degree of minimal polynomial of an element \\spad{a} if \\spad{a} is algebraic with respect to the ground field \\spad{F},{} and \\spad{infinity} otherwise.")) (|inGroundField?| (((|Boolean|) $) "\\spad{inGroundField?(a)} tests whether an element \\spad{a} is already in the ground field \\spad{F}.")) (|transcendent?| (((|Boolean|) $) "\\spad{transcendent?(a)} tests whether an element \\spad{a} is transcendent with respect to the ground field \\spad{F}.")) (|algebraic?| (((|Boolean|) $) "\\spad{algebraic?(a)} tests whether an element \\spad{a} is algebraic with respect to the ground field \\spad{F}."))) 
-((-4511 . T) (-4517 . T) (-4512 . T) ((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+((-4513 . T) (-4519 . T) (-4514 . T) ((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 (-1262 |VarSet| R) 
 ((|constructor| (NIL "This domain constructor implements polynomials in non-commutative variables written in the Poincare-Birkhoff-Witt basis from the Lyndon basis. These polynomials can be used to compute Baker-Campbell-Hausdorff relations.")) (|log| (($ $ (|NonNegativeInteger|)) "\\axiom{log(\\spad{p},{}\\spad{n})} returns the logarithm of \\axiom{\\spad{p}} (truncated up to order \\axiom{\\spad{n}}).")) (|exp| (($ $ (|NonNegativeInteger|)) "\\axiom{exp(\\spad{p},{}\\spad{n})} returns the exponential of \\axiom{\\spad{p}} (truncated up to order \\axiom{\\spad{n}}).")) (|product| (($ $ $ (|NonNegativeInteger|)) "\\axiom{product(a,{}\\spad{b},{}\\spad{n})} returns \\axiom{a*b} (truncated up to order \\axiom{\\spad{n}}).")) (|LiePolyIfCan| (((|Union| (|LiePolynomial| |#1| |#2|) "failed") $) "\\axiom{LiePolyIfCan(\\spad{p})} return \\axiom{\\spad{p}} if \\axiom{\\spad{p}} is a Lie polynomial.")) (|coerce| (((|XRecursivePolynomial| |#1| |#2|) $) "\\axiom{coerce(\\spad{p})} returns \\axiom{\\spad{p}} as a recursive polynomial.") (((|XDistributedPolynomial| |#1| |#2|) $) "\\axiom{coerce(\\spad{p})} returns \\axiom{\\spad{p}} as a distributed polynomial.") (($ (|LiePolynomial| |#1| |#2|)) "\\axiom{coerce(\\spad{p})} returns \\axiom{\\spad{p}}."))) 
-((-4512 |has| |#2| (-6 -4512)) (-4514 . T) (-4513 . T) (-4516 . T)) 
-((|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (LIST (QUOTE -707) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasAttribute| |#2| (QUOTE -4512))) 
+((-4514 |has| |#2| (-6 -4514)) (-4516 . T) (-4515 . T) (-4518 . T)) 
+((|HasCategory| |#2| (QUOTE (-172))) (|HasCategory| |#2| (LIST (QUOTE -707) (LIST (QUOTE -409) (QUOTE (-568))))) (|HasAttribute| |#2| (QUOTE -4514))) 
 (-1263 |vl| R) 
 ((|constructor| (NIL "The Category of polynomial rings with non-commutative variables. The coefficient ring may be non-commutative too. However coefficients commute with vaiables.")) (|trunc| (($ $ (|NonNegativeInteger|)) "\\spad{trunc(p,{}n)} returns the polynomial \\spad{p} truncated at order \\spad{n}.")) (|degree| (((|NonNegativeInteger|) $) "\\spad{degree(p)} returns the degree of \\spad{p}. \\indented{1}{Note that the degree of a word is its length.}")) (|maxdeg| (((|OrderedFreeMonoid| |#1|) $) "\\spad{maxdeg(p)} returns the greatest leading word in the support of \\spad{p}."))) 
-((-4512 |has| |#2| (-6 -4512)) (-4514 . T) (-4513 . T) (-4516 . T)) 
+((-4514 |has| |#2| (-6 -4514)) (-4516 . T) (-4515 . T) (-4518 . T)) 
 NIL 
 (-1264 R) 
 ((|constructor| (NIL "This type supports multivariate polynomials whose set of variables is \\spadtype{Symbol}. The representation is recursive. The coefficient ring may be non-commutative and the variables do not commute. However,{} coefficients and variables commute."))) 
-((-4512 |has| |#1| (-6 -4512)) (-4514 . T) (-4513 . T) (-4516 . T)) 
-((|HasCategory| |#1| (QUOTE (-172))) (|HasAttribute| |#1| (QUOTE -4512))) 
+((-4514 |has| |#1| (-6 -4514)) (-4516 . T) (-4515 . T) (-4518 . T)) 
+((|HasCategory| |#1| (QUOTE (-172))) (|HasAttribute| |#1| (QUOTE -4514))) 
 (-1265 R E) 
 ((|constructor| (NIL "This domain represents generalized polynomials with coefficients (from a not necessarily commutative ring),{} and words belonging to an arbitrary \\spadtype{OrderedMonoid}. This type is used,{} for instance,{} by the \\spadtype{XDistributedPolynomial} domain constructor where the Monoid is free.")) (|canonicalUnitNormal| ((|attribute|) "canonicalUnitNormal guarantees that the function unitCanonical returns the same representative for all associates of any particular element.")) (/ (($ $ |#1|) "\\spad{p/r} returns \\spad{p*(1/r)}.")) (|map| (($ (|Mapping| |#1| |#1|) $) "\\spad{map(fn,{}x)} returns \\spad{Sum(fn(r_i) w_i)} if \\spad{x} writes \\spad{Sum(r_i w_i)}.")) (|quasiRegular| (($ $) "\\spad{quasiRegular(x)} return \\spad{x} minus its constant term.")) (|quasiRegular?| (((|Boolean|) $) "\\spad{quasiRegular?(x)} return \\spad{true} if \\spad{constant(p)} is zero.")) (|constant| ((|#1| $) "\\spad{constant(p)} return the constant term of \\spad{p}.")) (|constant?| (((|Boolean|) $) "\\spad{constant?(p)} tests whether the polynomial \\spad{p} belongs to the coefficient ring.")) (|coef| ((|#1| $ |#2|) "\\spad{coef(p,{}e)} extracts the coefficient of the monomial \\spad{e}. Returns zero if \\spad{e} is not present.")) (|reductum| (($ $) "\\spad{reductum(p)} returns \\spad{p} minus its leading term. An error is produced if \\spad{p} is zero.")) (|mindeg| ((|#2| $) "\\spad{mindeg(p)} returns the smallest word occurring in the polynomial \\spad{p} with a non-zero coefficient. An error is produced if \\spad{p} is zero.")) (|maxdeg| ((|#2| $) "\\spad{maxdeg(p)} returns the greatest word occurring in the polynomial \\spad{p} with a non-zero coefficient. An error is produced if \\spad{p} is zero.")) (|coerce| (($ |#2|) "\\spad{coerce(e)} returns \\spad{1*e}")) (|#| (((|NonNegativeInteger|) $) "\\spad{\\# p} returns the number of terms in \\spad{p}.")) (* (($ $ |#1|) "\\spad{p*r} returns the product of \\spad{p} by \\spad{r}."))) 
-((-4516 . T) (-4517 |has| |#1| (-6 -4517)) (-4512 |has| |#1| (-6 -4512)) (-4514 . T) (-4513 . T)) 
-((|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasAttribute| |#1| (QUOTE -4516)) (|HasAttribute| |#1| (QUOTE -4517)) (|HasAttribute| |#1| (QUOTE -4512))) 
+((-4518 . T) (-4519 |has| |#1| (-6 -4519)) (-4514 |has| |#1| (-6 -4514)) (-4516 . T) (-4515 . T)) 
+((|HasCategory| |#1| (QUOTE (-172))) (|HasCategory| |#1| (QUOTE (-365))) (|HasAttribute| |#1| (QUOTE -4518)) (|HasAttribute| |#1| (QUOTE -4519)) (|HasAttribute| |#1| (QUOTE -4514))) 
 (-1266 |VarSet| R) 
 ((|constructor| (NIL "This type supports multivariate polynomials whose variables do not commute. The representation is recursive. The coefficient ring may be non-commutative. Coefficients and variables commute.")) (|RemainderList| (((|List| (|Record| (|:| |k| |#1|) (|:| |c| $))) $) "\\spad{RemainderList(p)} returns the regular part of \\spad{p} as a list of terms.")) (|unexpand| (($ (|XDistributedPolynomial| |#1| |#2|)) "\\spad{unexpand(p)} returns \\spad{p} in recursive form.")) (|expand| (((|XDistributedPolynomial| |#1| |#2|) $) "\\spad{expand(p)} returns \\spad{p} in distributed form."))) 
-((-4512 |has| |#2| (-6 -4512)) (-4514 . T) (-4513 . T) (-4516 . T)) 
-((|HasCategory| |#2| (QUOTE (-172))) (|HasAttribute| |#2| (QUOTE -4512))) 
+((-4514 |has| |#2| (-6 -4514)) (-4516 . T) (-4515 . T) (-4518 . T)) 
+((|HasCategory| |#2| (QUOTE (-172))) (|HasAttribute| |#2| (QUOTE -4514))) 
 (-1267 A) 
 ((|constructor| (NIL "This package implements fixed-point computations on streams.")) (Y (((|List| (|Stream| |#1|)) (|Mapping| (|List| (|Stream| |#1|)) (|List| (|Stream| |#1|))) (|Integer|)) "\\spad{Y(g,{}n)} computes a fixed point of the function \\spad{g},{} where \\spad{g} takes a list of \\spad{n} streams and returns a list of \\spad{n} streams.") (((|Stream| |#1|) (|Mapping| (|Stream| |#1|) (|Stream| |#1|))) "\\spad{Y(f)} computes a fixed point of the function \\spad{f}."))) 
 NIL 
@@ -5010,7 +5010,7 @@ NIL
 NIL 
 (-1270 |p|) 
 ((|constructor| (NIL "IntegerMod(\\spad{n}) creates the ring of integers reduced modulo the integer \\spad{n}."))) 
-(((-4521 "*") . T) (-4513 . T) (-4514 . T) (-4516 . T)) 
+(((-4523 "*") . T) (-4515 . T) (-4516 . T) (-4518 . T)) 
 NIL 
 NIL 
 NIL 
@@ -5032,4 +5032,4 @@ NIL
 NIL 
 NIL 
 NIL 
-((-1275 NIL 2465018 2465023 2465028 2465033) (-3 NIL 2464998 2465003 2465008 2465013) (-2 NIL 2464978 2464983 2464988 2464993) (-1 NIL 2464958 2464963 2464968 2464973) (0 NIL 2464938 2464943 2464948 2464953) (-1270 "bookvol10.3.pamphlet" 2464747 2464760 2464876 2464933) (-1269 "bookvol10.4.pamphlet" 2463791 2463802 2464737 2464742) (-1268 "bookvol10.4.pamphlet" 2454031 2454053 2463781 2463786) (-1267 "bookvol10.4.pamphlet" 2453524 2453535 2454021 2454026) (-1266 "bookvol10.3.pamphlet" 2452759 2452779 2453380 2453449) (-1265 "bookvol10.3.pamphlet" 2450488 2450501 2452477 2452576) (-1264 "bookvol10.3.pamphlet" 2450058 2450069 2450344 2450413) (-1263 "bookvol10.2.pamphlet" 2449375 2449391 2449984 2450053) (-1262 "bookvol10.3.pamphlet" 2447872 2447892 2449155 2449224) (-1261 "bookvol10.2.pamphlet" 2446332 2446347 2447774 2447867) (-1260 NIL 2444772 2444789 2446216 2446221) (-1259 "bookvol10.2.pamphlet" 2441797 2441813 2444698 2444767) (-1258 "bookvol10.4.pamphlet" 2441108 2441134 2441787 2441792) (-1257 "bookvol10.3.pamphlet" 2440737 2440753 2440964 2441033) (-1256 "bookvol10.2.pamphlet" 2440436 2440447 2440693 2440732) (-1255 "bookvol10.3.pamphlet" 2436710 2436727 2440138 2440165) (-1254 "bookvol10.3.pamphlet" 2435724 2435768 2436568 2436635) (-1253 "bookvol10.4.pamphlet" 2433287 2433309 2435714 2435719) (-1252 "bookvol10.4.pamphlet" 2431493 2431504 2433277 2433282) (-1251 "bookvol10.2.pamphlet" 2431166 2431177 2431461 2431488) (-1250 NIL 2430859 2430872 2431156 2431161) (-1249 "bookvol10.3.pamphlet" 2430449 2430458 2430849 2430854) (-1248 "bookvol10.4.pamphlet" 2428071 2428080 2430439 2430444) (-1247 "bookvol10.4.pamphlet" 2423268 2423277 2428061 2428066) (-1246 "bookvol10.3.pamphlet" 2407022 2407031 2423258 2423263) (-1245 "bookvol10.3.pamphlet" 2394759 2394768 2407012 2407017) (-1244 "bookvol10.3.pamphlet" 2393656 2393667 2393907 2393934) (-1243 "bookvol10.4.pamphlet" 2392298 2392311 2393646 2393651) (-1242 "bookvol10.2.pamphlet" 2390186 2390197 2392254 2392293) (-1241 NIL 2387893 2387906 2389963 2389968) (-1240 "bookvol10.3.pamphlet" 2387673 2387688 2387883 2387888) (-1239 "bookvol10.3.pamphlet" 2382857 2382879 2386140 2386237) (-1238 "bookvol10.4.pamphlet" 2382760 2382788 2382847 2382852) (-1237 "bookvol10.4.pamphlet" 2382068 2382092 2382716 2382721) (-1236 "bookvol10.4.pamphlet" 2380220 2380240 2382058 2382063) (-1235 "bookvol10.3.pamphlet" 2375009 2375037 2378687 2378784) (-1234 "bookvol10.2.pamphlet" 2372460 2372476 2374907 2375004) (-1233 NIL 2369555 2369573 2372004 2372009) (-1232 "bookvol10.4.pamphlet" 2369178 2369213 2369545 2369550) (-1231 "bookvol10.2.pamphlet" 2363776 2363787 2369158 2369173) (-1230 NIL 2358348 2358361 2363732 2363737) (-1229 "bookvol10.3.pamphlet" 2355991 2356017 2357429 2357562) (-1228 "bookvol10.3.pamphlet" 2353126 2353154 2354123 2354272) (-1227 "bookvol10.3.pamphlet" 2350883 2350903 2351258 2351407) (-1226 "bookvol10.2.pamphlet" 2349341 2349361 2350729 2350878) (-1225 NIL 2347941 2347963 2349331 2349336) (-1224 "bookvol10.2.pamphlet" 2346522 2346538 2347787 2347936) (-1223 "bookvol10.4.pamphlet" 2346063 2346116 2346512 2346517) (-1222 "bookvol10.4.pamphlet" 2344475 2344489 2346053 2346058) (-1221 "bookvol10.2.pamphlet" 2342055 2342079 2344373 2344470) (-1220 NIL 2339341 2339367 2341661 2341666) (-1219 "bookvol10.2.pamphlet" 2334315 2334326 2339183 2339336) (-1218 NIL 2329181 2329194 2334051 2334056) (-1217 "bookvol10.4.pamphlet" 2328646 2328665 2329171 2329176) (-1216 "bookvol10.3.pamphlet" 2325597 2325612 2326196 2326349) (-1215 "bookvol10.4.pamphlet" 2324487 2324500 2325587 2325592) (-1214 "bookvol10.4.pamphlet" 2324050 2324064 2324477 2324482) (-1213 "bookvol10.4.pamphlet" 2322287 2322301 2324040 2324045) (-1212 "bookvol10.4.pamphlet" 2321494 2321510 2322277 2322282) (-1211 "bookvol10.4.pamphlet" 2320856 2320877 2321484 2321489) (-1210 "bookvol10.3.pamphlet" 2320209 2320220 2320775 2320780) (-1209 "bookvol10.4.pamphlet" 2319702 2319715 2320165 2320170) (-1208 "bookvol10.4.pamphlet" 2318803 2318815 2319692 2319697) (-1207 "bookvol10.3.pamphlet" 2309463 2309491 2310448 2310877) (-1206 "bookvol10.3.pamphlet" 2303500 2303520 2303872 2304021) (-1205 "bookvol10.2.pamphlet" 2301093 2301113 2303320 2303495) (-1204 NIL 2298820 2298842 2301049 2301054) (-1203 "bookvol10.2.pamphlet" 2297036 2297052 2298666 2298815) (-1202 "bookvol10.4.pamphlet" 2296578 2296631 2297026 2297031) (-1201 "bookvol10.3.pamphlet" 2294971 2294987 2295045 2295142) (-1200 "bookvol10.4.pamphlet" 2294886 2294902 2294961 2294966) (-1199 "bookvol10.2.pamphlet" 2293951 2293960 2294812 2294881) (-1198 NIL 2293078 2293089 2293941 2293946) (-1197 "bookvol10.4.pamphlet" 2291925 2291934 2293068 2293073) (-1196 "bookvol10.4.pamphlet" 2289411 2289422 2291881 2291886) (-1195 "bookvol10.2.pamphlet" 2289333 2289342 2289391 2289406) (-1194 "bookvol10.4.pamphlet" 2287983 2287998 2289323 2289328) (-1193 "bookvol10.3.pamphlet" 2286886 2286897 2287938 2287943) (-1192 "bookvol10.4.pamphlet" 2283720 2283729 2286876 2286881) (-1191 "bookvol10.3.pamphlet" 2282376 2282393 2283710 2283715) (-1190 "bookvol10.3.pamphlet" 2280965 2280981 2281941 2282038) (-1189 "bookvol10.2.pamphlet" 2268275 2268292 2280921 2280960) (-1188 NIL 2255583 2255602 2268231 2268236) (-1187 "bookvol10.4.pamphlet" 2249949 2249966 2255289 2255294) (-1186 "bookvol10.4.pamphlet" 2248908 2248933 2249939 2249944) (-1185 "bookvol10.4.pamphlet" 2247425 2247442 2248898 2248903) (-1184 "bookvol10.2.pamphlet" 2246937 2246946 2247415 2247420) (-1183 NIL 2246447 2246458 2246927 2246932) (-1182 "bookvol10.3.pamphlet" 2244496 2244507 2246277 2246304) (-1181 "bookvol10.2.pamphlet" 2244327 2244336 2244486 2244491) (-1180 NIL 2244156 2244167 2244317 2244322) (-1179 "bookvol10.4.pamphlet" 2243830 2243839 2244146 2244151) (-1178 "bookvol10.4.pamphlet" 2243493 2243504 2243820 2243825) (-1177 "bookvol10.3.pamphlet" 2242050 2242059 2243483 2243488) (-1176 "bookvol10.3.pamphlet" 2239067 2239076 2242040 2242045) (-1175 "bookvol10.4.pamphlet" 2238623 2238634 2239057 2239062) (-1174 "bookvol10.4.pamphlet" 2238178 2238187 2238613 2238618) (-1173 "bookvol10.4.pamphlet" 2236271 2236294 2238168 2238173) (-1172 "bookvol10.2.pamphlet" 2235118 2235141 2236239 2236266) (-1171 NIL 2233985 2234010 2235108 2235113) (-1170 "bookvol10.4.pamphlet" 2233361 2233372 2233975 2233980) (-1169 "bookvol10.3.pamphlet" 2232334 2232357 2232604 2232631) (-1168 "bookvol10.3.pamphlet" 2231830 2231841 2232324 2232329) (-1167 "bookvol10.4.pamphlet" 2228682 2228693 2231820 2231825) (-1166 "bookvol10.4.pamphlet" 2225275 2225286 2228672 2228677) (-1165 "bookvol10.3.pamphlet" 2223328 2223337 2225265 2225270) (-1164 "bookvol10.3.pamphlet" 2219313 2219322 2223318 2223323) (-1163 "bookvol10.3.pamphlet" 2218320 2218331 2218402 2218529) (-1162 "bookvol10.4.pamphlet" 2217795 2217806 2218310 2218315) (-1161 "bookvol10.3.pamphlet" 2215123 2215132 2217785 2217790) (-1160 "bookvol10.3.pamphlet" 2211879 2211888 2215113 2215118) (-1159 "bookvol10.3.pamphlet" 2208886 2208914 2210346 2210443) (-1158 "bookvol10.3.pamphlet" 2206008 2206036 2207018 2207167) (-1157 "bookvol10.3.pamphlet" 2202691 2202702 2203558 2203711) (-1156 "bookvol10.4.pamphlet" 2201811 2201829 2202681 2202686) (-1155 "bookvol10.3.pamphlet" 2199255 2199266 2199324 2199477) (-1154 "bookvol10.4.pamphlet" 2198645 2198658 2199245 2199250) (-1153 "bookvol10.4.pamphlet" 2197123 2197134 2198635 2198640) (-1152 "bookvol10.4.pamphlet" 2196749 2196766 2197113 2197118) (-1151 "bookvol10.3.pamphlet" 2187396 2187424 2188394 2188823) (-1150 "bookvol10.3.pamphlet" 2187076 2187091 2187386 2187391) (-1149 "bookvol10.3.pamphlet" 2179047 2179062 2187066 2187071) (-1148 "bookvol10.4.pamphlet" 2178219 2178233 2179003 2179008) (-1147 "bookvol10.4.pamphlet" 2174318 2174334 2178209 2178214) (-1146 "bookvol10.4.pamphlet" 2170786 2170802 2174308 2174313) (-1145 "bookvol10.4.pamphlet" 2163186 2163197 2170667 2170672) (-1144 "bookvol10.3.pamphlet" 2162265 2162282 2162414 2162441) (-1143 "bookvol10.3.pamphlet" 2161648 2161657 2161746 2161773) (-1142 "bookvol10.2.pamphlet" 2161424 2161433 2161604 2161643) (-1141 "bookvol10.3.pamphlet" 2156372 2156383 2161172 2161187) (-1140 "bookvol10.4.pamphlet" 2155583 2155598 2156362 2156367) (-1139 "bookvol10.4.pamphlet" 2153792 2153805 2155573 2155578) (-1138 "bookvol10.4.pamphlet" 2153216 2153227 2153782 2153787) (-1137 "bookvol10.4.pamphlet" 2152122 2152138 2153206 2153211) (-1136 "bookvol10.2.pamphlet" 2151328 2151337 2152112 2152117) (-1135 "bookvol10.3.pamphlet" 2150416 2150444 2150583 2150598) (-1134 "bookvol10.2.pamphlet" 2149473 2149484 2150396 2150411) (-1133 NIL 2148538 2148551 2149463 2149468) (-1132 "bookvol10.3.pamphlet" 2144163 2144174 2148368 2148395) (-1131 "bookvol10.3.pamphlet" 2142206 2142223 2143865 2143892) (-1130 "bookvol10.4.pamphlet" 2140933 2140953 2142196 2142201) (-1129 "bookvol10.2.pamphlet" 2135976 2135985 2140889 2140928) (-1128 NIL 2131051 2131062 2135966 2135971) (-1127 "bookvol10.3.pamphlet" 2128731 2128749 2129639 2129726) (-1126 "bookvol10.3.pamphlet" 2123598 2123611 2128482 2128509) (-1125 "bookvol10.3.pamphlet" 2120138 2120151 2123588 2123593) (-1124 "bookvol10.2.pamphlet" 2118915 2118924 2120128 2120133) (-1123 "bookvol10.4.pamphlet" 2117480 2117489 2118905 2118910) (-1122 "bookvol10.2.pamphlet" 2101307 2101318 2117470 2117475) (-1121 "bookvol10.3.pamphlet" 2101083 2101094 2101297 2101302) (-1120 "bookvol10.4.pamphlet" 2100628 2100641 2101039 2101044) (-1119 "bookvol10.4.pamphlet" 2098221 2098232 2100618 2100623) (-1118 "bookvol10.4.pamphlet" 2096786 2096797 2098211 2098216) (-1117 "bookvol10.4.pamphlet" 2090213 2090224 2096776 2096781) (-1116 "bookvol10.4.pamphlet" 2088633 2088651 2090203 2090208) (-1115 "bookvol10.2.pamphlet" 2088400 2088417 2088589 2088628) (-1114 "bookvol10.3.pamphlet" 2086516 2086542 2087965 2088062) (-1113 "bookvol10.3.pamphlet" 2083970 2083990 2084345 2084472) (-1112 "bookvol10.4.pamphlet" 2082813 2082838 2083960 2083965) (-1111 "bookvol10.2.pamphlet" 2080911 2080941 2082745 2082808) (-1110 NIL 2078953 2078985 2080789 2080794) (-1109 "bookvol10.2.pamphlet" 2077391 2077402 2078909 2078948) (-1108 "bookvol10.3.pamphlet" 2075756 2075765 2077257 2077386) (-1107 "bookvol10.4.pamphlet" 2075499 2075508 2075746 2075751) (-1106 "bookvol10.4.pamphlet" 2074607 2074618 2075489 2075494) (-1105 "bookvol10.4.pamphlet" 2073876 2073893 2074597 2074602) (-1104 "bookvol10.4.pamphlet" 2071746 2071761 2073832 2073837) (-1103 "bookvol10.3.pamphlet" 2063459 2063486 2063961 2064092) (-1102 "bookvol10.2.pamphlet" 2062694 2062703 2063449 2063454) (-1101 NIL 2061927 2061938 2062684 2062689) (-1100 "bookvol10.4.pamphlet" 2054953 2054962 2061917 2061922) (-1099 "bookvol10.2.pamphlet" 2054432 2054449 2054909 2054948) (-1098 "bookvol10.4.pamphlet" 2054131 2054151 2054422 2054427) (-1097 "bookvol10.4.pamphlet" 2049456 2049476 2054121 2054126) (-1096 "bookvol10.3.pamphlet" 2048891 2048905 2049446 2049451) (-1095 "bookvol10.3.pamphlet" 2048734 2048774 2048881 2048886) (-1094 "bookvol10.3.pamphlet" 2048626 2048635 2048724 2048729) (-1093 "bookvol10.2.pamphlet" 2045715 2045755 2048616 2048621) (-1092 "bookvol10.3.pamphlet" 2044025 2044036 2045192 2045231) (-1091 "bookvol10.3.pamphlet" 2042443 2042460 2044015 2044020) (-1090 "bookvol10.2.pamphlet" 2041925 2041934 2042433 2042438) (-1089 NIL 2041405 2041416 2041915 2041920) (-1088 "bookvol10.2.pamphlet" 2041294 2041303 2041395 2041400) (-1087 "bookvol10.2.pamphlet" 2037782 2037793 2041262 2041289) (-1086 NIL 2034290 2034303 2037772 2037777) (-1085 "bookvol10.2.pamphlet" 2033402 2033415 2034270 2034285) (-1084 "bookvol10.3.pamphlet" 2033215 2033226 2033321 2033326) (-1083 "bookvol10.2.pamphlet" 2032021 2032032 2033195 2033210) (-1082 "bookvol10.3.pamphlet" 2031093 2031104 2031976 2031981) (-1081 "bookvol10.4.pamphlet" 2030789 2030802 2031083 2031088) (-1080 "bookvol10.4.pamphlet" 2030214 2030227 2030745 2030750) (-1079 "bookvol10.3.pamphlet" 2029490 2029501 2030204 2030209) (-1078 "bookvol10.3.pamphlet" 2026892 2026903 2027171 2027298) (-1077 "bookvol10.4.pamphlet" 2024971 2024982 2026882 2026887) (-1076 "bookvol10.4.pamphlet" 2023852 2023863 2024961 2024966) (-1075 "bookvol10.3.pamphlet" 2023724 2023733 2023842 2023847) (-1074 "bookvol10.4.pamphlet" 2023437 2023457 2023714 2023719) (-1073 "bookvol10.3.pamphlet" 2021558 2021574 2022223 2022358) (-1072 "bookvol10.4.pamphlet" 2021259 2021279 2021548 2021553) (-1071 "bookvol10.4.pamphlet" 2018945 2018961 2021249 2021254) (-1070 "bookvol10.3.pamphlet" 2018347 2018371 2018935 2018940) (-1069 "bookvol10.3.pamphlet" 2016691 2016715 2018337 2018342) (-1068 "bookvol10.3.pamphlet" 2016543 2016556 2016681 2016686) (-1067 "bookvol10.4.pamphlet" 2013611 2013631 2016533 2016538) (-1066 "bookvol10.2.pamphlet" 2004071 2004088 2013567 2013606) (-1065 NIL 1994563 1994582 2004061 2004066) (-1064 "bookvol10.4.pamphlet" 1993197 1993217 1994553 1994558) (-1063 "bookvol10.2.pamphlet" 1991581 1991611 1993187 1993192) (-1062 NIL 1989963 1989995 1991571 1991576) (-1061 "bookvol10.2.pamphlet" 1969279 1969294 1989831 1989958) (-1060 NIL 1948309 1948326 1968863 1968868) (-1059 "bookvol10.3.pamphlet" 1944754 1944763 1947538 1947565) (-1058 "bookvol10.3.pamphlet" 1944001 1944010 1944620 1944749) (-1057 NIL 1943081 1943113 1943991 1943996) (-1056 "bookvol10.2.pamphlet" 1941984 1941993 1942983 1943076) (-1055 NIL 1940973 1940984 1941974 1941979) (-1054 "bookvol10.2.pamphlet" 1940495 1940504 1940963 1940968) (-1053 "bookvol10.2.pamphlet" 1939972 1939983 1940485 1940490) (-1052 "bookvol10.4.pamphlet" 1939380 1939437 1939962 1939967) (-1051 "bookvol10.3.pamphlet" 1938115 1938134 1938603 1938642) (-1050 "bookvol10.2.pamphlet" 1933632 1933663 1938059 1938110) (-1049 NIL 1929051 1929084 1933480 1933485) (-1048 "bookvol10.4.pamphlet" 1928939 1928959 1929041 1929046) (-1047 "bookvol10.2.pamphlet" 1928292 1928301 1928919 1928934) (-1046 NIL 1927653 1927664 1928282 1928287) (-1045 "bookvol10.4.pamphlet" 1926547 1926556 1927643 1927648) (-1044 "bookvol10.3.pamphlet" 1925212 1925228 1926107 1926134) (-1043 "bookvol10.4.pamphlet" 1923254 1923265 1925202 1925207) (-1042 "bookvol10.4.pamphlet" 1920868 1920879 1923244 1923249) (-1041 "bookvol10.4.pamphlet" 1920330 1920341 1920858 1920863) (-1040 "bookvol10.4.pamphlet" 1920065 1920077 1920320 1920325) (-1039 "bookvol10.4.pamphlet" 1919053 1919062 1920055 1920060) (-1038 "bookvol10.4.pamphlet" 1918470 1918483 1919043 1919048) (-1037 "bookvol10.2.pamphlet" 1917819 1917830 1918460 1918465) (-1036 NIL 1917166 1917179 1917809 1917814) (-1035 "bookvol10.3.pamphlet" 1915808 1915817 1916395 1916422) (-1034 "bookvol10.3.pamphlet" 1915155 1915202 1915746 1915803) (-1033 "bookvol10.4.pamphlet" 1914479 1914490 1915145 1915150) (-1032 "bookvol10.4.pamphlet" 1914208 1914219 1914469 1914474) (-1031 "bookvol10.4.pamphlet" 1911760 1911769 1914198 1914203) (-1030 "bookvol10.4.pamphlet" 1911465 1911476 1911750 1911755) (-1029 "bookvol10.4.pamphlet" 1900907 1900918 1911307 1911312) (-1028 "bookvol10.4.pamphlet" 1894883 1894894 1900857 1900862) (-1027 "bookvol10.3.pamphlet" 1892974 1892991 1894585 1894612) (-1026 "bookvol10.3.pamphlet" 1892318 1892329 1892929 1892934) (-1025 "bookvol10.4.pamphlet" 1891494 1891511 1892308 1892313) (-1024 "bookvol10.4.pamphlet" 1889791 1889808 1891449 1891454) (-1023 "bookvol10.3.pamphlet" 1888574 1888594 1889278 1889371) (-1022 "bookvol10.4.pamphlet" 1887029 1887038 1888564 1888569) (-1021 "bookvol10.2.pamphlet" 1886901 1886910 1887019 1887024) (-1020 "bookvol10.4.pamphlet" 1884198 1884213 1886891 1886896) (-1019 "bookvol10.4.pamphlet" 1881041 1881056 1884188 1884193) (-1018 "bookvol10.4.pamphlet" 1880786 1880811 1881031 1881036) (-1017 "bookvol10.4.pamphlet" 1880349 1880360 1880776 1880781) (-1016 "bookvol10.4.pamphlet" 1879249 1879267 1880339 1880344) (-1015 "bookvol10.4.pamphlet" 1877454 1877472 1879239 1879244) (-1014 "bookvol10.4.pamphlet" 1876679 1876696 1877444 1877449) (-1013 "bookvol10.4.pamphlet" 1875829 1875846 1876669 1876674) (-1012 "bookvol10.2.pamphlet" 1873012 1873021 1875731 1875824) (-1011 NIL 1870281 1870292 1873002 1873007) (-1010 "bookvol10.2.pamphlet" 1868190 1868201 1870261 1870276) (-1009 NIL 1866036 1866049 1868109 1868114) (-1008 "bookvol10.4.pamphlet" 1865453 1865464 1866026 1866031) (-1007 "bookvol10.4.pamphlet" 1864637 1864649 1865443 1865448) (-1006 "bookvol10.4.pamphlet" 1863994 1864003 1864627 1864632) (-1005 "bookvol10.4.pamphlet" 1863748 1863757 1863984 1863989) (-1004 "bookvol10.3.pamphlet" 1860533 1860547 1862215 1862308) (-1003 "bookvol10.3.pamphlet" 1858946 1858983 1859065 1859221) (-1002 "bookvol10.2.pamphlet" 1858539 1858548 1858936 1858941) (-1001 NIL 1858130 1858141 1858529 1858534) (-1000 "bookvol10.3.pamphlet" 1853519 1853530 1857960 1857987) (-999 "bookvol10.3.pamphlet" 1852146 1852156 1852443 1852508) (-998 "bookvol10.4.pamphlet" 1851469 1851487 1852136 1852141) (-997 "bookvol10.2.pamphlet" 1849630 1849640 1851399 1851464) (-996 NIL 1847542 1847554 1849313 1849318) (-995 "bookvol10.2.pamphlet" 1846348 1846358 1847498 1847537) (-994 "bookvol10.3.pamphlet" 1845811 1845825 1846338 1846343) (-993 "bookvol10.2.pamphlet" 1844502 1844512 1845701 1845806) (-992 NIL 1842796 1842808 1843997 1844002) (-991 "bookvol10.4.pamphlet" 1842487 1842503 1842786 1842791) (-990 "bookvol10.3.pamphlet" 1842044 1842052 1842477 1842482) (-989 "bookvol10.4.pamphlet" 1837446 1837465 1842034 1842039) (-988 "bookvol10.3.pamphlet" 1833521 1833553 1837360 1837365) (-987 "bookvol10.4.pamphlet" 1831517 1831535 1833511 1833516) (-986 "bookvol10.4.pamphlet" 1828827 1828848 1831507 1831512) (-985 "bookvol10.4.pamphlet" 1828154 1828173 1828817 1828822) (-984 "bookvol10.2.pamphlet" 1824280 1824290 1828144 1828149) (-983 "bookvol10.4.pamphlet" 1821364 1821374 1824270 1824275) (-982 "bookvol10.4.pamphlet" 1821181 1821195 1821354 1821359) (-981 "bookvol10.2.pamphlet" 1820263 1820273 1821137 1821176) (-980 "bookvol10.4.pamphlet" 1819570 1819594 1820253 1820258) (-979 "bookvol10.4.pamphlet" 1818428 1818438 1819560 1819565) (-978 "bookvol10.4.pamphlet" 1803829 1803845 1818306 1818311) (-977 "bookvol10.2.pamphlet" 1797722 1797745 1803797 1803824) (-976 NIL 1791601 1791626 1797678 1797683) (-975 "bookvol10.2.pamphlet" 1790584 1790592 1791591 1791596) (-974 "bookvol10.2.pamphlet" 1789347 1789376 1790482 1790579) (-973 NIL 1788200 1788231 1789337 1789342) (-972 "bookvol10.3.pamphlet" 1787015 1787023 1788190 1788195) (-971 "bookvol10.2.pamphlet" 1784348 1784358 1787005 1787010) (-970 "bookvol10.4.pamphlet" 1774493 1774510 1784304 1784309) (-969 "bookvol10.2.pamphlet" 1773912 1773922 1774449 1774488) (-968 "bookvol10.3.pamphlet" 1773794 1773810 1773902 1773907) (-967 "bookvol10.3.pamphlet" 1773682 1773692 1773784 1773789) (-966 "bookvol10.3.pamphlet" 1773570 1773580 1773672 1773677) (-965 "bookvol10.3.pamphlet" 1770971 1770983 1771536 1771591) (-964 "bookvol10.3.pamphlet" 1769357 1769369 1770062 1770189) (-963 "bookvol10.4.pamphlet" 1768561 1768600 1769347 1769352) (-962 "bookvol10.4.pamphlet" 1768313 1768321 1768551 1768556) (-961 "bookvol10.4.pamphlet" 1766556 1766566 1768303 1768308) (-960 "bookvol10.4.pamphlet" 1764529 1764543 1766546 1766551) (-959 "bookvol10.2.pamphlet" 1764152 1764160 1764519 1764524) (-958 "bookvol10.3.pamphlet" 1763395 1763405 1763558 1763585) (-957 "bookvol10.4.pamphlet" 1761287 1761299 1763385 1763390) (-956 "bookvol10.4.pamphlet" 1760659 1760671 1761277 1761282) (-955 "bookvol10.2.pamphlet" 1759796 1759804 1760649 1760654) (-954 "bookvol10.4.pamphlet" 1758568 1758590 1759752 1759757) (-953 "bookvol10.3.pamphlet" 1755880 1755890 1756382 1756509) (-952 "bookvol10.4.pamphlet" 1755141 1755164 1755870 1755875) (-951 "bookvol10.4.pamphlet" 1753205 1753227 1755131 1755136) (-950 "bookvol10.2.pamphlet" 1746607 1746628 1753073 1753200) (-949 NIL 1739311 1739334 1745779 1745784) (-948 "bookvol10.4.pamphlet" 1738759 1738773 1739301 1739306) (-947 "bookvol10.4.pamphlet" 1738369 1738381 1738749 1738754) (-946 "bookvol10.4.pamphlet" 1737310 1737339 1738325 1738330) (-945 "bookvol10.4.pamphlet" 1736058 1736073 1737300 1737305) (-944 "bookvol10.3.pamphlet" 1735119 1735129 1735206 1735233) (-943 "bookvol10.4.pamphlet" 1731759 1731767 1735109 1735114) (-942 "bookvol10.4.pamphlet" 1730516 1730530 1731749 1731754) (-941 "bookvol10.4.pamphlet" 1730061 1730071 1730506 1730511) (-940 "bookvol10.4.pamphlet" 1729648 1729662 1730051 1730056) (-939 "bookvol10.4.pamphlet" 1729174 1729188 1729638 1729643) (-938 "bookvol10.4.pamphlet" 1728675 1728697 1729164 1729169) (-937 "bookvol10.4.pamphlet" 1727745 1727763 1728607 1728612) (-936 "bookvol10.4.pamphlet" 1727326 1727340 1727735 1727740) (-935 "bookvol10.4.pamphlet" 1726893 1726905 1727316 1727321) (-934 "bookvol10.4.pamphlet" 1726469 1726479 1726883 1726888) (-933 "bookvol10.4.pamphlet" 1726042 1726060 1726459 1726464) (-932 "bookvol10.4.pamphlet" 1725324 1725338 1726032 1726037) (-931 "bookvol10.4.pamphlet" 1724393 1724401 1725314 1725319) (-930 "bookvol10.4.pamphlet" 1723419 1723435 1724383 1724388) (-929 "bookvol10.4.pamphlet" 1722317 1722355 1723409 1723414) (-928 "bookvol10.4.pamphlet" 1722097 1722105 1722307 1722312) (-927 "bookvol10.3.pamphlet" 1716769 1716777 1722087 1722092) (-926 "bookvol10.3.pamphlet" 1713171 1713179 1716759 1716764) (-925 "bookvol10.4.pamphlet" 1712304 1712314 1713161 1713166) (-924 "bookvol10.4.pamphlet" 1698261 1698288 1712294 1712299) (-923 "bookvol10.3.pamphlet" 1698168 1698182 1698251 1698256) (-922 "bookvol10.3.pamphlet" 1698079 1698089 1698158 1698163) (-921 "bookvol10.3.pamphlet" 1697990 1698000 1698069 1698074) (-920 "bookvol10.2.pamphlet" 1697018 1697032 1697980 1697985) (-919 "bookvol10.4.pamphlet" 1696634 1696653 1697008 1697013) (-918 "bookvol10.4.pamphlet" 1696416 1696432 1696624 1696629) (-917 "bookvol10.3.pamphlet" 1696038 1696046 1696390 1696411) (-916 "bookvol10.2.pamphlet" 1694994 1695002 1695964 1696033) (-915 "bookvol10.4.pamphlet" 1694723 1694733 1694984 1694989) (-914 "bookvol10.4.pamphlet" 1693335 1693349 1694713 1694718) (-913 "bookvol10.4.pamphlet" 1684701 1684709 1693325 1693330) (-912 "bookvol10.4.pamphlet" 1683251 1683268 1684691 1684696) (-911 "bookvol10.4.pamphlet" 1682266 1682276 1683241 1683246) (-910 "bookvol10.3.pamphlet" 1677634 1677644 1682168 1682261) (-909 "bookvol10.4.pamphlet" 1676989 1677005 1677624 1677629) (-908 "bookvol10.4.pamphlet" 1675024 1675053 1676979 1676984) (-907 "bookvol10.4.pamphlet" 1674394 1674412 1675014 1675019) (-906 "bookvol10.4.pamphlet" 1673813 1673840 1674384 1674389) (-905 "bookvol10.3.pamphlet" 1673480 1673492 1673618 1673711) (-904 "bookvol10.2.pamphlet" 1671146 1671154 1673406 1673475) (-903 NIL 1668840 1668850 1671102 1671107) (-902 "bookvol10.4.pamphlet" 1666725 1666737 1668830 1668835) (-901 "bookvol10.4.pamphlet" 1664325 1664348 1666715 1666720) (-900 "bookvol10.3.pamphlet" 1659311 1659321 1664155 1664170) (-899 "bookvol10.3.pamphlet" 1654001 1654011 1659301 1659306) (-898 "bookvol10.2.pamphlet" 1652554 1652564 1653981 1653996) (-897 "bookvol10.4.pamphlet" 1651217 1651231 1652544 1652549) (-896 "bookvol10.3.pamphlet" 1650487 1650497 1651069 1651074) (-895 "bookvol10.2.pamphlet" 1648781 1648791 1650467 1650482) (-894 NIL 1647083 1647095 1648771 1648776) (-893 "bookvol10.3.pamphlet" 1645188 1645196 1647073 1647078) (-892 "bookvol10.4.pamphlet" 1638980 1638988 1645178 1645183) (-891 "bookvol10.4.pamphlet" 1638280 1638297 1638970 1638975) (-890 "bookvol10.2.pamphlet" 1636424 1636432 1638270 1638275) (-889 "bookvol10.4.pamphlet" 1636113 1636126 1636414 1636419) (-888 "bookvol10.3.pamphlet" 1634755 1634772 1636103 1636108) (-887 "bookvol10.3.pamphlet" 1629186 1629196 1634745 1634750) (-886 "bookvol10.4.pamphlet" 1628923 1628935 1629176 1629181) (-885 "bookvol10.4.pamphlet" 1627213 1627229 1628913 1628918) (-884 "bookvol10.3.pamphlet" 1624752 1624764 1627203 1627208) (-883 "bookvol10.4.pamphlet" 1624406 1624420 1624742 1624747) (-882 "bookvol10.4.pamphlet" 1622563 1622594 1624114 1624119) (-881 "bookvol10.2.pamphlet" 1621988 1621998 1622553 1622558) (-880 "bookvol10.3.pamphlet" 1621072 1621086 1621978 1621983) (-879 "bookvol10.2.pamphlet" 1620836 1620846 1621062 1621067) (-878 "bookvol10.4.pamphlet" 1618198 1618206 1620826 1620831) (-877 "bookvol10.3.pamphlet" 1617626 1617654 1618188 1618193) (-876 "bookvol10.4.pamphlet" 1617417 1617433 1617616 1617621) (-875 "bookvol10.3.pamphlet" 1616845 1616873 1617407 1617412) (-874 "bookvol10.4.pamphlet" 1616630 1616646 1616835 1616840) (-873 "bookvol10.3.pamphlet" 1616088 1616116 1616620 1616625) (-872 "bookvol10.4.pamphlet" 1615873 1615889 1616078 1616083) (-871 "bookvol10.4.pamphlet" 1614664 1614713 1615863 1615868) (-870 "bookvol10.4.pamphlet" 1614076 1614084 1614654 1614659) (-869 "bookvol10.3.pamphlet" 1613046 1613054 1614066 1614071) (-868 "bookvol10.4.pamphlet" 1607429 1607452 1613002 1613007) (-867 "bookvol10.4.pamphlet" 1601248 1601271 1607378 1607383) (-866 "bookvol10.3.pamphlet" 1598578 1598596 1599753 1599846) (-865 "bookvol10.3.pamphlet" 1596593 1596605 1596814 1596907) (-864 "bookvol10.3.pamphlet" 1596288 1596300 1596519 1596588) (-863 "bookvol10.2.pamphlet" 1594844 1594856 1596214 1596283) (-862 "bookvol10.4.pamphlet" 1593773 1593792 1594834 1594839) (-861 "bookvol10.4.pamphlet" 1592754 1592770 1593763 1593768) (-860 "bookvol10.3.pamphlet" 1591355 1591363 1592425 1592518) (-859 "bookvol10.2.pamphlet" 1590105 1590113 1591257 1591350) (-858 "bookvol10.2.pamphlet" 1588168 1588176 1590007 1590100) (-857 "bookvol10.3.pamphlet" 1586893 1586903 1587964 1588057) (-856 "bookvol10.2.pamphlet" 1585646 1585654 1586795 1586888) (-855 "bookvol10.3.pamphlet" 1583951 1583971 1585036 1585129) (-854 "bookvol10.2.pamphlet" 1582693 1582701 1583853 1583946) (-853 "bookvol10.3.pamphlet" 1581677 1581707 1582551 1582618) (-852 "bookvol10.3.pamphlet" 1581458 1581481 1581667 1581672) (-851 "bookvol10.4.pamphlet" 1580542 1580550 1581448 1581453) (-850 "bookvol10.3.pamphlet" 1569956 1569964 1580532 1580537) (-849 "bookvol10.3.pamphlet" 1569545 1569553 1569946 1569951) (-848 "bookvol10.4.pamphlet" 1568006 1568016 1569462 1569467) (-847 "bookvol10.3.pamphlet" 1567364 1567392 1567686 1567725) (-846 "bookvol10.3.pamphlet" 1566663 1566687 1567044 1567083) (-845 "bookvol10.4.pamphlet" 1564497 1564509 1566583 1566588) (-844 "bookvol10.2.pamphlet" 1558643 1558653 1564453 1564492) (-843 NIL 1552679 1552691 1558491 1558496) (-842 "bookvol10.2.pamphlet" 1551845 1551853 1552669 1552674) (-841 NIL 1551009 1551019 1551835 1551840) (-840 "bookvol10.2.pamphlet" 1550343 1550351 1550989 1551004) (-839 NIL 1549685 1549695 1550333 1550338) (-838 "bookvol10.2.pamphlet" 1549439 1549447 1549675 1549680) (-837 "bookvol10.4.pamphlet" 1548580 1548596 1549429 1549434) (-836 "bookvol10.2.pamphlet" 1548514 1548522 1548570 1548575) (-835 "bookvol10.3.pamphlet" 1547000 1547010 1548061 1548090) (-834 "bookvol10.4.pamphlet" 1546340 1546352 1546990 1546995) (-833 "bookvol10.3.pamphlet" 1544024 1544032 1546330 1546335) (-832 "bookvol10.4.pamphlet" 1536208 1536216 1544014 1544019) (-831 "bookvol10.2.pamphlet" 1533674 1533682 1536198 1536203) (-830 "bookvol10.4.pamphlet" 1533223 1533231 1533664 1533669) (-829 "bookvol10.3.pamphlet" 1532965 1532975 1533045 1533112) (-828 "bookvol10.3.pamphlet" 1531739 1531749 1532512 1532541) (-827 "bookvol10.4.pamphlet" 1531212 1531224 1531729 1531734) (-826 "bookvol10.4.pamphlet" 1530214 1530222 1531202 1531207) (-825 "bookvol10.2.pamphlet" 1529990 1530000 1530158 1530209) (-824 "bookvol10.4.pamphlet" 1528602 1528610 1529980 1529985) (-823 "bookvol10.2.pamphlet" 1527567 1527575 1528592 1528597) (-822 "bookvol10.3.pamphlet" 1526992 1527004 1527453 1527492) (-821 "bookvol10.4.pamphlet" 1526826 1526836 1526982 1526987) (-820 "bookvol10.3.pamphlet" 1526369 1526377 1526816 1526821) (-819 "bookvol10.3.pamphlet" 1525403 1525411 1526359 1526364) (-818 "bookvol10.3.pamphlet" 1524747 1524755 1525393 1525398) (-817 "bookvol10.3.pamphlet" 1519036 1519044 1524737 1524742) (-816 "bookvol10.3.pamphlet" 1518445 1518453 1519026 1519031) (-815 "bookvol10.2.pamphlet" 1518220 1518228 1518371 1518440) (-814 "bookvol10.3.pamphlet" 1511591 1511601 1518210 1518215) (-813 "bookvol10.3.pamphlet" 1510852 1510862 1511581 1511586) (-812 "bookvol10.3.pamphlet" 1510300 1510326 1510664 1510813) (-811 "bookvol10.3.pamphlet" 1507658 1507668 1507986 1508113) (-810 "bookvol10.3.pamphlet" 1499515 1499535 1499873 1500004) (-809 "bookvol10.4.pamphlet" 1498094 1498113 1499505 1499510) (-808 "bookvol10.4.pamphlet" 1495744 1495761 1498084 1498089) (-807 "bookvol10.4.pamphlet" 1491687 1491704 1495701 1495706) (-806 "bookvol10.4.pamphlet" 1491074 1491098 1491677 1491682) (-805 "bookvol10.4.pamphlet" 1488640 1488657 1491064 1491069) (-804 "bookvol10.4.pamphlet" 1485531 1485553 1488630 1488635) (-803 "bookvol10.3.pamphlet" 1484117 1484125 1485521 1485526) (-802 "bookvol10.4.pamphlet" 1481421 1481443 1484107 1484112) (-801 "bookvol10.4.pamphlet" 1480797 1480821 1481411 1481416) (-800 "bookvol10.4.pamphlet" 1467159 1467167 1480787 1480792) (-799 "bookvol10.4.pamphlet" 1466590 1466606 1467149 1467154) (-798 "bookvol10.3.pamphlet" 1463985 1463993 1466580 1466585) (-797 "bookvol10.4.pamphlet" 1459352 1459368 1463975 1463980) (-796 "bookvol10.4.pamphlet" 1458871 1458889 1459342 1459347) (-795 "bookvol10.2.pamphlet" 1457256 1457264 1458861 1458866) (-794 "bookvol10.3.pamphlet" 1455392 1455402 1456110 1456149) (-793 "bookvol10.4.pamphlet" 1455028 1455049 1455382 1455387) (-792 "bookvol10.2.pamphlet" 1452802 1452812 1454984 1455023) (-791 NIL 1450301 1450313 1452485 1452490) (-790 "bookvol10.2.pamphlet" 1450149 1450157 1450291 1450296) (-789 "bookvol10.2.pamphlet" 1449897 1449905 1450139 1450144) (-788 "bookvol10.2.pamphlet" 1449189 1449197 1449887 1449892) (-787 "bookvol10.2.pamphlet" 1449050 1449058 1449179 1449184) (-786 "bookvol10.2.pamphlet" 1448912 1448920 1449040 1449045) (-785 "bookvol10.4.pamphlet" 1448635 1448651 1448902 1448907) (-784 "bookvol10.4.pamphlet" 1436952 1436960 1448625 1448630) (-783 "bookvol10.4.pamphlet" 1427711 1427719 1436942 1436947) (-782 "bookvol10.2.pamphlet" 1425050 1425058 1427701 1427706) (-781 "bookvol10.4.pamphlet" 1423890 1423898 1425040 1425045) (-780 "bookvol10.4.pamphlet" 1415962 1415972 1423695 1423700) (-779 "bookvol10.2.pamphlet" 1415259 1415275 1415918 1415957) (-778 "bookvol10.4.pamphlet" 1414804 1414814 1415176 1415181) (-777 "bookvol10.3.pamphlet" 1407793 1407803 1412354 1412507) (-776 "bookvol10.4.pamphlet" 1407185 1407197 1407783 1407788) (-775 "bookvol10.3.pamphlet" 1403380 1403399 1403688 1403815) (-774 "bookvol10.3.pamphlet" 1401904 1401914 1401981 1402074) (-773 "bookvol10.4.pamphlet" 1400276 1400290 1401894 1401899) (-772 "bookvol10.4.pamphlet" 1400168 1400197 1400266 1400271) (-771 "bookvol10.4.pamphlet" 1399414 1399434 1400158 1400163) (-770 "bookvol10.3.pamphlet" 1399302 1399316 1399394 1399409) (-769 "bookvol10.4.pamphlet" 1398896 1398935 1399292 1399297) (-768 "bookvol10.4.pamphlet" 1397430 1397449 1398886 1398891) (-767 "bookvol10.4.pamphlet" 1397118 1397144 1397420 1397425) (-766 "bookvol10.3.pamphlet" 1396859 1396867 1397108 1397113) (-765 "bookvol10.4.pamphlet" 1396535 1396545 1396849 1396854) (-764 "bookvol10.4.pamphlet" 1396004 1396020 1396525 1396530) (-763 "bookvol10.3.pamphlet" 1394894 1394902 1395978 1395999) (-762 "bookvol10.4.pamphlet" 1393516 1393526 1394884 1394889) (-761 "bookvol10.3.pamphlet" 1391114 1391122 1393506 1393511) (-760 "bookvol10.4.pamphlet" 1388574 1388591 1391104 1391109) (-759 "bookvol10.4.pamphlet" 1387827 1387841 1388564 1388569) (-758 "bookvol10.4.pamphlet" 1385939 1385955 1387817 1387822) (-757 "bookvol10.4.pamphlet" 1385596 1385610 1385929 1385934) (-756 "bookvol10.4.pamphlet" 1383756 1383770 1385586 1385591) (-755 "bookvol10.2.pamphlet" 1383352 1383360 1383746 1383751) (-754 NIL 1382946 1382956 1383342 1383347) (-753 "bookvol10.2.pamphlet" 1382232 1382240 1382936 1382941) (-752 NIL 1381516 1381526 1382222 1382227) (-751 "bookvol10.4.pamphlet" 1380589 1380597 1381506 1381511) (-750 "bookvol10.4.pamphlet" 1370155 1370163 1380579 1380584) (-749 "bookvol10.4.pamphlet" 1368591 1368599 1370145 1370150) (-748 "bookvol10.4.pamphlet" 1362765 1362773 1368581 1368586) (-747 "bookvol10.4.pamphlet" 1356509 1356517 1362755 1362760) (-746 "bookvol10.4.pamphlet" 1352131 1352139 1356499 1356504) (-745 "bookvol10.4.pamphlet" 1345505 1345513 1352121 1352126) (-744 "bookvol10.4.pamphlet" 1335900 1335908 1345495 1345500) (-743 "bookvol10.4.pamphlet" 1331827 1331835 1335890 1335895) (-742 "bookvol10.4.pamphlet" 1329702 1329710 1331817 1331822) (-741 "bookvol10.4.pamphlet" 1322148 1322156 1329692 1329697) (-740 "bookvol10.4.pamphlet" 1316304 1316312 1322138 1322143) (-739 "bookvol10.4.pamphlet" 1312134 1312142 1316294 1316299) (-738 "bookvol10.4.pamphlet" 1310646 1310654 1312124 1312129) (-737 "bookvol10.4.pamphlet" 1309944 1309952 1310636 1310641) (-736 "bookvol10.2.pamphlet" 1309450 1309460 1309912 1309939) (-735 NIL 1308976 1308988 1309440 1309445) (-734 "bookvol10.3.pamphlet" 1306197 1306211 1306526 1306679) (-733 "bookvol10.3.pamphlet" 1304316 1304330 1304388 1304608) (-732 "bookvol10.4.pamphlet" 1301300 1301317 1304306 1304311) (-731 "bookvol10.4.pamphlet" 1300698 1300715 1301290 1301295) (-730 "bookvol10.2.pamphlet" 1298732 1298753 1300596 1300693) (-729 "bookvol10.4.pamphlet" 1298389 1298399 1298722 1298727) (-728 "bookvol10.4.pamphlet" 1297829 1297837 1298379 1298384) (-727 "bookvol10.3.pamphlet" 1295834 1295844 1297591 1297630) (-726 "bookvol10.2.pamphlet" 1295667 1295677 1295790 1295829) (-725 "bookvol10.3.pamphlet" 1292620 1292632 1295375 1295442) (-724 "bookvol10.4.pamphlet" 1292180 1292194 1292610 1292615) (-723 "bookvol10.4.pamphlet" 1291741 1291758 1292170 1292175) (-722 "bookvol10.4.pamphlet" 1289786 1289805 1291731 1291736) (-721 "bookvol10.3.pamphlet" 1287236 1287251 1287580 1287707) (-720 "bookvol10.4.pamphlet" 1286515 1286534 1287226 1287231) (-719 "bookvol10.4.pamphlet" 1286323 1286366 1286505 1286510) (-718 "bookvol10.4.pamphlet" 1286067 1286103 1286313 1286318) (-717 "bookvol10.4.pamphlet" 1284402 1284419 1286057 1286062) (-716 "bookvol10.2.pamphlet" 1283266 1283274 1284392 1284397) (-715 NIL 1282128 1282138 1283256 1283261) (-714 "bookvol10.2.pamphlet" 1280874 1280887 1281988 1282123) (-713 NIL 1279642 1279657 1280758 1280763) (-712 "bookvol10.2.pamphlet" 1277648 1277656 1279632 1279637) (-711 NIL 1275652 1275662 1277638 1277643) (-710 "bookvol10.2.pamphlet" 1274796 1274804 1275642 1275647) (-709 NIL 1273938 1273948 1274786 1274791) (-708 "bookvol10.3.pamphlet" 1272617 1272631 1273918 1273933) (-707 "bookvol10.2.pamphlet" 1272298 1272308 1272585 1272612) (-706 NIL 1271999 1272011 1272288 1272293) (-705 "bookvol10.3.pamphlet" 1271312 1271351 1271979 1271994) (-704 "bookvol10.3.pamphlet" 1269954 1269966 1271134 1271201) (-703 "bookvol10.3.pamphlet" 1269465 1269483 1269944 1269949) (-702 "bookvol10.3.pamphlet" 1266125 1266141 1266943 1267096) (-701 "bookvol10.3.pamphlet" 1265486 1265525 1266027 1266120) (-700 "bookvol10.3.pamphlet" 1264273 1264281 1265476 1265481) (-699 "bookvol10.4.pamphlet" 1264013 1264047 1264263 1264268) (-698 "bookvol10.2.pamphlet" 1262455 1262465 1263969 1264008) (-697 "bookvol10.4.pamphlet" 1261027 1261044 1262445 1262450) (-696 "bookvol10.4.pamphlet" 1260497 1260515 1261017 1261022) (-695 "bookvol10.4.pamphlet" 1260083 1260096 1260487 1260492) (-694 "bookvol10.4.pamphlet" 1259398 1259408 1260073 1260078) (-693 "bookvol10.4.pamphlet" 1258291 1258301 1259388 1259393) (-692 "bookvol10.3.pamphlet" 1258067 1258077 1258281 1258286) (-691 "bookvol10.4.pamphlet" 1257528 1257546 1258057 1258062) (-690 "bookvol10.3.pamphlet" 1256967 1256975 1257430 1257523) (-689 "bookvol10.4.pamphlet" 1255606 1255616 1256957 1256962) (-688 "bookvol10.3.pamphlet" 1254050 1254058 1255496 1255601) (-687 "bookvol10.4.pamphlet" 1253450 1253472 1254040 1254045) (-686 "bookvol10.4.pamphlet" 1251312 1251320 1253440 1253445) (-685 "bookvol10.4.pamphlet" 1249553 1249563 1251302 1251307) (-684 "bookvol10.2.pamphlet" 1248828 1248838 1249521 1249548) (-683 "bookvol10.3.pamphlet" 1244801 1244809 1245415 1245616) (-682 "bookvol10.4.pamphlet" 1244009 1244021 1244791 1244796) (-681 "bookvol10.4.pamphlet" 1241117 1241143 1243999 1244004) (-680 "bookvol10.4.pamphlet" 1238393 1238403 1241107 1241112) (-679 "bookvol10.3.pamphlet" 1237284 1237294 1237768 1237795) (-678 "bookvol10.4.pamphlet" 1234610 1234634 1237168 1237173) (-677 "bookvol10.2.pamphlet" 1219821 1219843 1234566 1234605) (-676 NIL 1204880 1204904 1219627 1219632) (-675 "bookvol10.4.pamphlet" 1204148 1204196 1204870 1204875) (-674 "bookvol10.4.pamphlet" 1202868 1202880 1204138 1204143) (-673 "bookvol10.4.pamphlet" 1201767 1201781 1202858 1202863) (-672 "bookvol10.4.pamphlet" 1201101 1201113 1201757 1201762) (-671 "bookvol10.4.pamphlet" 1199919 1199929 1201091 1201096) (-670 "bookvol10.4.pamphlet" 1199727 1199741 1199909 1199914) (-669 "bookvol10.4.pamphlet" 1199492 1199504 1199717 1199722) (-668 "bookvol10.4.pamphlet" 1199122 1199132 1199482 1199487) (-667 "bookvol10.3.pamphlet" 1197066 1197083 1199112 1199117) (-666 "bookvol10.3.pamphlet" 1194985 1194995 1196667 1196672) (-665 "bookvol10.2.pamphlet" 1190441 1190451 1194965 1194980) (-664 NIL 1185905 1185917 1190431 1190436) (-663 "bookvol10.3.pamphlet" 1182711 1182728 1185895 1185900) (-662 "bookvol10.3.pamphlet" 1180969 1180983 1181391 1181442) (-661 "bookvol10.4.pamphlet" 1180502 1180519 1180959 1180964) (-660 "bookvol10.4.pamphlet" 1179342 1179370 1180492 1180497) (-659 "bookvol10.4.pamphlet" 1177146 1177160 1179332 1179337) (-658 "bookvol10.2.pamphlet" 1176803 1176813 1177102 1177141) (-657 NIL 1176492 1176504 1176793 1176798) (-656 "bookvol10.3.pamphlet" 1175506 1175525 1176348 1176417) (-655 "bookvol10.4.pamphlet" 1174763 1174773 1175496 1175501) (-654 "bookvol10.4.pamphlet" 1173208 1173257 1174753 1174758) (-653 "bookvol10.4.pamphlet" 1171847 1171857 1173198 1173203) (-652 "bookvol10.3.pamphlet" 1171248 1171262 1171781 1171808) (-651 "bookvol10.2.pamphlet" 1170850 1170858 1171238 1171243) (-650 NIL 1170450 1170460 1170840 1170845) (-649 "bookvol10.4.pamphlet" 1169368 1169380 1170440 1170445) (-648 "bookvol10.3.pamphlet" 1168755 1168771 1169048 1169087) (-647 "bookvol10.4.pamphlet" 1167799 1167816 1168712 1168717) (-646 "bookvol10.2.pamphlet" 1166416 1166426 1167755 1167794) (-645 NIL 1165031 1165043 1166372 1166377) (-644 "bookvol10.3.pamphlet" 1164307 1164319 1164711 1164750) (-643 "bookvol10.3.pamphlet" 1163710 1163720 1163987 1164026) (-642 "bookvol10.4.pamphlet" 1162482 1162500 1163700 1163705) (-641 "bookvol10.2.pamphlet" 1160857 1160867 1162384 1162477) (-640 "bookvol10.2.pamphlet" 1156605 1156615 1160837 1160852) (-639 NIL 1152327 1152339 1156561 1156566) (-638 "bookvol10.3.pamphlet" 1149063 1149080 1152317 1152322) (-637 "bookvol10.2.pamphlet" 1148546 1148556 1149053 1149058) (-636 "bookvol10.3.pamphlet" 1147646 1147656 1148320 1148347) (-635 "bookvol10.4.pamphlet" 1147077 1147091 1147636 1147641) (-634 "bookvol10.3.pamphlet" 1145018 1145028 1146447 1146474) (-633 "bookvol10.4.pamphlet" 1144309 1144323 1145008 1145013) (-632 "bookvol10.4.pamphlet" 1142949 1142961 1144299 1144304) (-631 "bookvol10.4.pamphlet" 1139822 1139834 1142939 1142944) (-630 "bookvol10.2.pamphlet" 1139254 1139264 1139802 1139817) (-629 "bookvol10.4.pamphlet" 1138031 1138043 1139166 1139171) (-628 "bookvol10.4.pamphlet" 1135945 1135955 1138021 1138026) (-627 "bookvol10.4.pamphlet" 1134828 1134841 1135935 1135940) (-626 "bookvol10.3.pamphlet" 1132842 1132854 1134118 1134263) (-625 "bookvol10.2.pamphlet" 1132367 1132377 1132768 1132837) (-624 NIL 1131920 1131932 1132323 1132328) (-623 "bookvol10.3.pamphlet" 1130453 1130461 1131161 1131176) (-622 "bookvol10.4.pamphlet" 1127821 1127840 1130443 1130448) (-621 "bookvol10.4.pamphlet" 1126740 1126756 1127811 1127816) (-620 "bookvol10.2.pamphlet" 1125759 1125767 1126730 1126735) (-619 "bookvol10.4.pamphlet" 1121411 1121426 1125749 1125754) (-618 "bookvol10.3.pamphlet" 1119474 1119501 1121391 1121406) (-617 "bookvol10.4.pamphlet" 1117858 1117875 1119464 1119469) (-616 "bookvol10.4.pamphlet" 1116916 1116938 1117848 1117853) (-615 "bookvol10.3.pamphlet" 1115688 1115701 1116509 1116578) (-614 "bookvol10.4.pamphlet" 1115261 1115277 1115678 1115683) (-613 "bookvol10.3.pamphlet" 1114701 1114715 1115183 1115222) (-612 "bookvol10.2.pamphlet" 1114477 1114487 1114681 1114696) (-611 NIL 1114261 1114273 1114467 1114472) (-610 "bookvol10.4.pamphlet" 1112974 1112991 1114251 1114256) (-609 "bookvol10.2.pamphlet" 1112696 1112706 1112964 1112969) (-608 "bookvol10.2.pamphlet" 1112433 1112443 1112686 1112691) (-607 "bookvol10.3.pamphlet" 1110968 1110978 1112217 1112222) (-606 "bookvol10.4.pamphlet" 1110671 1110683 1110958 1110963) (-605 "bookvol10.2.pamphlet" 1109762 1109784 1110639 1110666) (-604 NIL 1108873 1108897 1109752 1109757) (-603 "bookvol10.3.pamphlet" 1107495 1107511 1108220 1108247) (-602 "bookvol10.3.pamphlet" 1105472 1105484 1106785 1106930) (-601 "bookvol10.2.pamphlet" 1103554 1103578 1105452 1105467) (-600 NIL 1101501 1101527 1103401 1103406) (-599 "bookvol10.3.pamphlet" 1100509 1100524 1100649 1100676) (-598 "bookvol10.3.pamphlet" 1099669 1099679 1100499 1100504) (-597 "bookvol10.4.pamphlet" 1098480 1098499 1099659 1099664) (-596 "bookvol10.4.pamphlet" 1097974 1097988 1098470 1098475) (-595 "bookvol10.4.pamphlet" 1097704 1097716 1097964 1097969) (-594 "bookvol10.3.pamphlet" 1095496 1095511 1097540 1097665) (-593 "bookvol10.3.pamphlet" 1087922 1087937 1094470 1094567) (-592 "bookvol10.4.pamphlet" 1087405 1087421 1087912 1087917) (-591 "bookvol10.3.pamphlet" 1086635 1086648 1086801 1086828) (-590 "bookvol10.4.pamphlet" 1085715 1085734 1086625 1086630) (-589 "bookvol10.4.pamphlet" 1083679 1083687 1085705 1085710) (-588 "bookvol10.4.pamphlet" 1082202 1082212 1083635 1083640) (-587 "bookvol10.4.pamphlet" 1081803 1081814 1082192 1082197) (-586 "bookvol10.4.pamphlet" 1080149 1080159 1081793 1081798) (-585 "bookvol10.3.pamphlet" 1077894 1077908 1080004 1080031) (-584 "bookvol10.4.pamphlet" 1077030 1077046 1077884 1077889) (-583 "bookvol10.4.pamphlet" 1076171 1076187 1077020 1077025) (-582 "bookvol10.4.pamphlet" 1075931 1075939 1076161 1076166) (-581 "bookvol10.3.pamphlet" 1075624 1075636 1075736 1075829) (-580 "bookvol10.3.pamphlet" 1075385 1075411 1075550 1075619) (-579 "bookvol10.4.pamphlet" 1074994 1075010 1075375 1075380) (-578 "bookvol10.4.pamphlet" 1068240 1068257 1074984 1074989) (-577 "bookvol10.4.pamphlet" 1066099 1066115 1067814 1067819) (-576 "bookvol10.4.pamphlet" 1065405 1065413 1066089 1066094) (-575 "bookvol10.3.pamphlet" 1065181 1065191 1065319 1065400) (-574 "bookvol10.4.pamphlet" 1063545 1063559 1065171 1065176) (-573 "bookvol10.4.pamphlet" 1063034 1063044 1063535 1063540) (-572 "bookvol10.4.pamphlet" 1061679 1061696 1063024 1063029) (-571 "bookvol10.4.pamphlet" 1060042 1060058 1061322 1061327) (-570 "bookvol10.4.pamphlet" 1057769 1057787 1059974 1059979) (-569 "bookvol10.4.pamphlet" 1047876 1047884 1057759 1057764) (-568 "bookvol10.3.pamphlet" 1047237 1047245 1047730 1047871) (-567 "bookvol10.4.pamphlet" 1046503 1046520 1047227 1047232) (-566 "bookvol10.4.pamphlet" 1046168 1046192 1046493 1046498) (-565 "bookvol10.4.pamphlet" 1042569 1042577 1046158 1046163) (-564 "bookvol10.4.pamphlet" 1035949 1035967 1042501 1042506) (-563 "bookvol10.3.pamphlet" 1029947 1029955 1035939 1035944) (-562 "bookvol10.4.pamphlet" 1029047 1029104 1029937 1029942) (-561 "bookvol10.4.pamphlet" 1028121 1028131 1029037 1029042) (-560 "bookvol10.4.pamphlet" 1027989 1028013 1028111 1028116) (-559 "bookvol10.4.pamphlet" 1026303 1026319 1027979 1027984) (-558 "bookvol10.2.pamphlet" 1024927 1024935 1026229 1026298) (-557 NIL 1023613 1023623 1024917 1024922) (-556 "bookvol10.4.pamphlet" 1022743 1022830 1023603 1023608) (-555 "bookvol10.2.pamphlet" 1021206 1021216 1022657 1022738) (-554 "bookvol10.4.pamphlet" 1020709 1020717 1021196 1021201) (-553 "bookvol10.4.pamphlet" 1019891 1019918 1020699 1020704) (-552 "bookvol10.4.pamphlet" 1019383 1019399 1019881 1019886) (-551 "bookvol10.3.pamphlet" 1018463 1018494 1018626 1018653) (-550 "bookvol10.2.pamphlet" 1015859 1015867 1018365 1018458) (-549 NIL 1013341 1013351 1015849 1015854) (-548 "bookvol10.4.pamphlet" 1012775 1012788 1013331 1013336) (-547 "bookvol10.4.pamphlet" 1011841 1011860 1012765 1012770) (-546 "bookvol10.4.pamphlet" 1010899 1010923 1011831 1011836) (-545 "bookvol10.4.pamphlet" 1009885 1009902 1010889 1010894) (-544 "bookvol10.4.pamphlet" 1009032 1009062 1009875 1009880) (-543 "bookvol10.4.pamphlet" 1007317 1007339 1009022 1009027) (-542 "bookvol10.4.pamphlet" 1006367 1006386 1007307 1007312) (-541 "bookvol10.3.pamphlet" 1003411 1003419 1006357 1006362) (-540 "bookvol10.4.pamphlet" 1003036 1003046 1003401 1003406) (-539 "bookvol10.4.pamphlet" 1002624 1002632 1003026 1003031) (-538 "bookvol10.3.pamphlet" 1002005 1002068 1002614 1002619) (-537 "bookvol10.3.pamphlet" 1001411 1001434 1001995 1002000) (-536 "bookvol10.2.pamphlet" 1000034 1000097 1001401 1001406) (-535 "bookvol10.4.pamphlet" 998566 998588 1000024 1000029) (-534 "bookvol10.3.pamphlet" 998472 998489 998556 998561) (-533 "bookvol10.4.pamphlet" 997893 997903 998462 998467) (-532 "bookvol10.4.pamphlet" 993659 993670 997883 997888) (-531 "bookvol10.3.pamphlet" 992791 992817 993303 993330) (-530 "bookvol10.4.pamphlet" 991881 991925 992747 992752) (-529 "bookvol10.4.pamphlet" 990486 990510 991837 991842) (-528 "bookvol10.3.pamphlet" 989365 989380 989892 989919) (-527 "bookvol10.3.pamphlet" 989090 989128 989195 989222) (-526 "bookvol10.3.pamphlet" 988500 988516 988771 988864) (-525 "bookvol10.3.pamphlet" 985571 985586 987906 987933) (-524 "bookvol10.3.pamphlet" 985409 985426 985527 985532) (-523 "bookvol10.2.pamphlet" 984798 984810 985399 985404) (-522 NIL 984185 984199 984788 984793) (-521 "bookvol10.3.pamphlet" 983998 984010 984175 984180) (-520 "bookvol10.3.pamphlet" 983769 983781 983988 983993) (-519 "bookvol10.3.pamphlet" 983504 983516 983759 983764) (-518 "bookvol10.2.pamphlet" 982438 982450 983494 983499) (-517 "bookvol10.3.pamphlet" 982198 982210 982428 982433) (-516 "bookvol10.3.pamphlet" 981960 981972 982188 982193) (-515 "bookvol10.4.pamphlet" 979212 979230 981950 981955) (-514 "bookvol10.3.pamphlet" 974146 974185 979147 979152) (-513 "bookvol10.3.pamphlet" 973567 973590 974136 974141) (-512 "bookvol10.4.pamphlet" 972718 972734 973557 973562) (-511 "bookvol10.3.pamphlet" 971941 971949 972708 972713) (-510 "bookvol10.4.pamphlet" 970564 970581 971931 971936) (-509 "bookvol10.3.pamphlet" 969842 969855 970258 970285) (-508 "bookvol10.4.pamphlet" 966717 966736 969832 969837) (-507 "bookvol10.4.pamphlet" 965605 965620 966707 966712) (-506 "bookvol10.3.pamphlet" 965336 965362 965435 965462) (-505 "bookvol10.3.pamphlet" 964649 964664 964742 964769) (-504 "bookvol10.3.pamphlet" 962862 962870 964465 964558) (-503 "bookvol10.4.pamphlet" 962417 962450 962852 962857) (-502 "bookvol10.2.pamphlet" 961841 961849 962407 962412) (-501 NIL 961263 961273 961831 961836) (-500 "bookvol10.3.pamphlet" 960063 960071 961253 961258) (-499 "bookvol10.2.pamphlet" 957313 957323 960043 960058) (-498 NIL 954404 954416 957136 957141) (-497 "bookvol10.3.pamphlet" 952273 952281 952871 952964) (-496 "bookvol10.4.pamphlet" 951127 951138 952263 952268) (-495 "bookvol10.3.pamphlet" 950717 950741 951117 951122) (-494 "bookvol10.3.pamphlet" 946440 946450 950547 950574) (-493 "bookvol10.3.pamphlet" 938293 938309 938655 938786) (-492 "bookvol10.3.pamphlet" 935484 935499 936087 936214) (-491 "bookvol10.4.pamphlet" 934024 934032 935474 935479) (-490 "bookvol10.3.pamphlet" 933056 933087 933267 933294) (-489 "bookvol10.3.pamphlet" 932641 932649 932958 933051) (-488 "bookvol10.4.pamphlet" 918518 918530 932631 932636) (-487 "bookvol10.4.pamphlet" 918263 918271 918363 918368) (-486 "bookvol10.4.pamphlet" 902336 902372 918133 918138) (-485 "bookvol10.4.pamphlet" 902097 902105 902195 902200) (-484 "bookvol10.4.pamphlet" 901918 901932 902031 902036) (-483 "bookvol10.4.pamphlet" 901795 901809 901908 901913) (-482 "bookvol10.4.pamphlet" 901628 901636 901728 901733) (-481 "bookvol10.3.pamphlet" 900820 900836 901330 901357) (-480 "bookvol10.3.pamphlet" 899901 899936 900075 900090) (-479 "bookvol10.3.pamphlet" 897068 897095 898033 898182) (-478 "bookvol10.2.pamphlet" 896034 896042 897048 897063) (-477 NIL 895008 895018 896024 896029) (-476 "bookvol10.4.pamphlet" 893591 893612 894998 895003) (-475 "bookvol10.2.pamphlet" 892169 892181 893581 893586) (-474 NIL 890745 890759 892159 892164) (-473 "bookvol10.3.pamphlet" 883350 883358 890735 890740) (-472 "bookvol10.4.pamphlet" 881729 881737 883340 883345) (-471 "bookvol10.4.pamphlet" 880172 880180 881719 881724) (-470 "bookvol10.2.pamphlet" 879226 879238 880162 880167) (-469 NIL 878278 878292 879216 879221) (-468 "bookvol10.3.pamphlet" 877788 877811 878016 878043) (-467 "bookvol10.4.pamphlet" 872478 872565 877744 877749) (-466 "bookvol10.4.pamphlet" 871739 871757 872468 872473) (-465 "bookvol10.3.pamphlet" 867687 867695 871729 871734) (-464 "bookvol10.4.pamphlet" 865270 865278 867677 867682) (-463 "bookvol10.3.pamphlet" 864377 864404 865238 865265) (-462 "bookvol10.4.pamphlet" 863487 863501 864367 864372) (-461 "bookvol10.4.pamphlet" 859588 859601 863477 863482) (-460 "bookvol10.4.pamphlet" 859192 859202 859578 859583) (-459 "bookvol10.4.pamphlet" 858776 858793 859182 859187) (-458 "bookvol10.4.pamphlet" 858243 858262 858766 858771) (-457 "bookvol10.4.pamphlet" 856233 856246 858233 858238) (-456 "bookvol10.4.pamphlet" 854490 854498 856223 856228) (-455 "bookvol10.3.pamphlet" 851523 851540 852284 852411) (-454 "bookvol10.3.pamphlet" 845418 845445 851317 851384) (-453 "bookvol10.2.pamphlet" 844346 844354 845344 845413) (-452 NIL 843336 843346 844336 844341) (-451 "bookvol10.4.pamphlet" 837117 837155 843292 843297) (-450 "bookvol10.4.pamphlet" 833215 833253 837107 837112) (-449 "bookvol10.4.pamphlet" 828281 828319 833205 833210) (-448 "bookvol10.4.pamphlet" 824536 824574 828271 828276) (-447 "bookvol10.4.pamphlet" 823833 823841 824526 824531) (-446 "bookvol10.4.pamphlet" 822155 822165 823789 823794) (-445 "bookvol10.4.pamphlet" 820614 820627 822145 822150) (-444 "bookvol10.4.pamphlet" 818779 818798 820604 820609) (-443 "bookvol10.4.pamphlet" 809045 809056 818769 818774) (-442 "bookvol10.2.pamphlet" 806058 806066 809025 809040) (-441 "bookvol10.2.pamphlet" 805100 805108 806038 806053) (-440 "bookvol10.3.pamphlet" 804949 804961 805090 805095) (-439 NIL 803161 803169 804939 804944) (-438 "bookvol10.3.pamphlet" 802324 802332 803151 803156) (-437 "bookvol10.4.pamphlet" 801366 801385 802260 802265) (-436 "bookvol10.3.pamphlet" 799452 799460 801356 801361) (-435 "bookvol10.4.pamphlet" 798874 798890 799442 799447) (-434 "bookvol10.4.pamphlet" 797682 797698 798831 798836) (-433 "bookvol10.4.pamphlet" 794954 794970 797672 797677) (-432 "bookvol10.2.pamphlet" 788988 788998 794717 794949) (-431 NIL 782812 782824 788543 788548) (-430 "bookvol10.4.pamphlet" 782434 782450 782802 782807) (-429 "bookvol10.3.pamphlet" 781742 781754 782254 782353) (-428 "bookvol10.4.pamphlet" 781016 781032 781732 781737) (-427 "bookvol10.2.pamphlet" 780117 780127 780960 781011) (-426 NIL 779192 779204 780037 780042) (-425 "bookvol10.4.pamphlet" 777879 777895 779182 779187) (-424 "bookvol10.4.pamphlet" 772268 772302 777869 777874) (-423 "bookvol10.4.pamphlet" 771878 771894 772258 772263) (-422 "bookvol10.4.pamphlet" 771001 771024 771868 771873) (-421 "bookvol10.4.pamphlet" 769943 769953 770991 770996) (-420 "bookvol10.3.pamphlet" 761367 761377 768967 769036) (-419 "bookvol10.2.pamphlet" 756446 756456 761309 761362) (-418 NIL 751537 751549 756402 756407) (-417 "bookvol10.4.pamphlet" 750983 751001 751527 751532) (-416 "bookvol10.3.pamphlet" 750377 750407 750914 750919) (-415 "bookvol10.3.pamphlet" 749572 749593 750357 750372) (-414 "bookvol10.4.pamphlet" 749308 749340 749562 749567) (-413 "bookvol10.2.pamphlet" 748972 748982 749298 749303) (-412 NIL 748502 748514 748830 748835) (-411 "bookvol10.2.pamphlet" 746830 746843 748458 748497) (-410 NIL 745190 745205 746820 746825) (-409 "bookvol10.3.pamphlet" 742289 742299 742692 742865) (-408 "bookvol10.4.pamphlet" 741892 741904 742279 742284) (-407 "bookvol10.4.pamphlet" 741226 741238 741882 741887) (-406 "bookvol10.2.pamphlet" 738196 738204 741116 741221) (-405 NIL 735194 735204 738116 738121) (-404 "bookvol10.2.pamphlet" 734238 734246 735096 735189) (-403 NIL 733368 733378 734228 734233) (-402 "bookvol10.2.pamphlet" 733120 733130 733348 733363) (-401 "bookvol10.3.pamphlet" 731896 731913 733110 733115) (-400 NIL 730381 730430 731886 731891) (-399 "bookvol10.4.pamphlet" 729310 729318 730371 730376) (-398 "bookvol10.2.pamphlet" 726470 726478 729290 729305) (-397 "bookvol10.2.pamphlet" 726144 726152 726450 726465) (-396 "bookvol10.3.pamphlet" 723482 723490 726134 726139) (-395 "bookvol10.4.pamphlet" 722961 722971 723472 723477) (-394 "bookvol10.4.pamphlet" 722742 722766 722951 722956) (-393 "bookvol10.4.pamphlet" 721943 721951 722732 722737) (-392 "bookvol10.3.pamphlet" 721365 721387 721911 721938) (-391 "bookvol10.2.pamphlet" 719693 719701 721355 721360) (-390 "bookvol10.3.pamphlet" 719585 719593 719683 719688) (-389 "bookvol10.2.pamphlet" 719383 719391 719511 719580) (-388 "bookvol10.3.pamphlet" 716438 716448 719339 719344) (-387 "bookvol10.3.pamphlet" 716133 716145 716372 716399) (-386 "bookvol10.2.pamphlet" 713153 713161 716113 716128) (-385 "bookvol10.2.pamphlet" 712195 712203 713133 713148) (-384 "bookvol10.2.pamphlet" 709899 709917 712163 712190) (-383 "bookvol10.3.pamphlet" 709359 709371 709833 709860) (-382 "bookvol10.4.pamphlet" 707095 707109 709349 709354) (-381 "bookvol10.3.pamphlet" 700516 700524 706961 707090) (-380 "bookvol10.4.pamphlet" 697948 697962 700506 700511) (-379 "bookvol10.2.pamphlet" 697660 697670 697928 697943) (-378 NIL 697326 697338 697596 697601) (-377 "bookvol10.4.pamphlet" 696576 696588 697316 697321) (-376 "bookvol10.2.pamphlet" 694281 694300 696502 696571) (-375 "bookvol10.2.pamphlet" 691279 691289 694249 694276) (-374 NIL 688190 688202 691162 691167) (-373 "bookvol10.4.pamphlet" 686859 686875 688180 688185) (-372 "bookvol10.2.pamphlet" 684892 684905 686815 686854) (-371 NIL 682851 682866 684776 684781) (-370 "bookvol10.2.pamphlet" 682003 682011 682841 682846) (-369 "bookvol10.2.pamphlet" 670932 670942 681945 681998) (-368 NIL 659873 659885 670888 670893) (-367 "bookvol10.3.pamphlet" 659456 659466 659863 659868) (-366 "bookvol10.2.pamphlet" 657885 657902 659446 659451) (-365 "bookvol10.2.pamphlet" 657203 657211 657787 657880) (-364 NIL 656607 656617 657193 657198) (-363 "bookvol10.3.pamphlet" 655216 655226 656587 656602) (-362 "bookvol10.4.pamphlet" 654031 654046 655206 655211) (-361 "bookvol10.3.pamphlet" 653450 653465 653747 653840) (-360 "bookvol10.4.pamphlet" 653315 653332 653440 653445) (-359 "bookvol10.4.pamphlet" 652804 652825 653305 653310) (-358 "bookvol10.4.pamphlet" 644083 644094 652794 652799) (-357 "bookvol10.4.pamphlet" 643129 643146 644073 644078) (-356 "bookvol10.3.pamphlet" 642615 642635 642845 642938) (-355 "bookvol10.3.pamphlet" 642063 642079 642296 642389) (-354 "bookvol10.3.pamphlet" 640581 640601 641779 641872) (-353 "bookvol10.3.pamphlet" 639091 639108 640297 640390) (-352 "bookvol10.3.pamphlet" 637602 637623 638772 638865) (-351 "bookvol10.4.pamphlet" 634964 634983 637592 637597) (-350 "bookvol10.2.pamphlet" 632538 632546 634866 634959) (-349 NIL 630198 630208 632528 632533) (-348 "bookvol10.4.pamphlet" 628943 628960 630188 630193) (-347 "bookvol10.4.pamphlet" 626358 626369 628933 628938) (-346 "bookvol10.4.pamphlet" 619566 619582 626348 626353) (-345 "bookvol10.4.pamphlet" 618181 618200 619556 619561) (-344 "bookvol10.4.pamphlet" 617590 617607 618171 618176) (-343 "bookvol10.3.pamphlet" 616443 616463 617306 617399) (-342 "bookvol10.3.pamphlet" 615338 615358 616159 616252) (-341 "bookvol10.3.pamphlet" 614137 614158 615019 615112) (-340 "bookvol10.2.pamphlet" 602768 602790 613976 614132) (-339 NIL 591478 591502 602688 602693) (-338 "bookvol10.4.pamphlet" 591223 591263 591468 591473) (-337 "bookvol10.3.pamphlet" 583853 583899 590979 591018) (-336 "bookvol10.2.pamphlet" 583559 583569 583843 583848) (-335 NIL 583050 583062 583336 583341) (-334 "bookvol10.3.pamphlet" 582483 582507 583040 583045) (-333 "bookvol10.2.pamphlet" 580525 580549 582473 582478) (-332 NIL 578565 578591 580515 580520) (-331 "bookvol10.4.pamphlet" 578309 578349 578555 578560) (-330 "bookvol10.4.pamphlet" 576830 576838 578299 578304) (-329 "bookvol10.3.pamphlet" 576359 576369 576820 576825) (-328 NIL 566184 566192 576349 576354) (-327 "bookvol10.2.pamphlet" 559057 559071 566086 566179) (-326 NIL 551982 551998 559013 559018) (-325 "bookvol10.3.pamphlet" 550396 550406 551388 551415) (-324 "bookvol10.2.pamphlet" 548516 548528 550294 550391) (-323 NIL 546620 546634 548400 548405) (-322 "bookvol10.4.pamphlet" 546170 546192 546610 546615) (-321 "bookvol10.3.pamphlet" 545820 545830 546124 546129) (-320 "bookvol10.2.pamphlet" 544011 544023 545810 545815) (-319 "bookvol10.3.pamphlet" 543617 543627 543907 543934) (-318 "bookvol10.4.pamphlet" 541813 541830 543607 543612) (-317 "bookvol10.4.pamphlet" 541695 541705 541803 541808) (-316 "bookvol10.4.pamphlet" 540871 540881 541685 541690) (-315 "bookvol10.4.pamphlet" 540753 540763 540861 540866) (-314 "bookvol10.3.pamphlet" 537586 537609 538885 539034) (-313 "bookvol10.4.pamphlet" 534950 534958 537576 537581) (-312 "bookvol10.4.pamphlet" 534852 534881 534940 534945) (-311 "bookvol10.4.pamphlet" 531660 531676 534842 534847) (-310 "bookvol10.3.pamphlet" 526909 526919 527649 528056) (-309 "bookvol10.4.pamphlet" 522969 522982 526899 526904) (-308 "bookvol10.4.pamphlet" 522729 522741 522959 522964) (-307 "bookvol10.3.pamphlet" 519667 519692 520301 520394) (-306 "bookvol10.4.pamphlet" 519520 519528 519657 519662) (-305 "bookvol10.3.pamphlet" 519187 519195 519510 519515) (-304 "bookvol10.4.pamphlet" 518677 518691 519177 519182) (-303 "bookvol10.2.pamphlet" 518241 518251 518667 518672) (-302 NIL 517803 517815 518231 518236) (-301 "bookvol10.2.pamphlet" 515337 515345 517729 517798) (-300 NIL 512933 512943 515327 515332) (-299 "bookvol10.4.pamphlet" 504773 504781 512923 512928) (-298 "bookvol10.4.pamphlet" 504358 504372 504763 504768) (-297 "bookvol10.4.pamphlet" 504035 504046 504348 504353) (-296 "bookvol10.2.pamphlet" 496582 496590 504025 504030) (-295 NIL 489035 489045 496480 496485) (-294 "bookvol10.4.pamphlet" 485808 485816 489025 489030) (-293 "bookvol10.4.pamphlet" 485549 485561 485798 485803) (-292 "bookvol10.4.pamphlet" 485044 485060 485539 485544) (-291 "bookvol10.4.pamphlet" 484610 484626 485034 485039) (-290 "bookvol10.4.pamphlet" 481984 481992 484600 484605) (-289 "bookvol10.3.pamphlet" 481018 481040 481227 481254) (-288 "bookvol10.3.pamphlet" 475876 475886 478691 478803) (-287 "bookvol10.4.pamphlet" 475592 475604 475866 475871) (-286 "bookvol10.4.pamphlet" 471906 471916 475582 475587) (-285 "bookvol10.2.pamphlet" 471448 471456 471850 471901) (-284 "bookvol10.3.pamphlet" 470628 470669 471374 471443) (-283 "bookvol10.2.pamphlet" 468882 468901 470618 470623) (-282 NIL 467100 467121 468838 468843) (-281 "bookvol10.2.pamphlet" 466564 466582 467090 467095) (-280 "bookvol10.4.pamphlet" 465943 465962 466554 466559) (-279 "bookvol10.2.pamphlet" 465632 465640 465933 465938) (-278 NIL 465319 465329 465622 465627) (-277 "bookvol10.2.pamphlet" 463023 463033 465287 465314) (-276 NIL 460676 460688 462942 462947) (-275 "bookvol10.4.pamphlet" 457467 457497 460632 460637) (-274 "bookvol10.4.pamphlet" 454318 454341 457423 457428) (-273 "bookvol10.4.pamphlet" 452273 452289 454308 454313) (-272 "bookvol10.4.pamphlet" 447039 447055 452263 452268) (-271 "bookvol10.3.pamphlet" 445315 445323 447029 447034) (-270 "bookvol10.3.pamphlet" 444851 444859 445305 445310) (-269 "bookvol10.3.pamphlet" 444428 444436 444841 444846) (-268 "bookvol10.3.pamphlet" 444008 444016 444418 444423) (-267 "bookvol10.3.pamphlet" 443544 443552 443998 444003) (-266 "bookvol10.3.pamphlet" 443080 443088 443534 443539) (-265 "bookvol10.3.pamphlet" 442616 442624 443070 443075) (-264 "bookvol10.3.pamphlet" 442152 442160 442606 442611) (-263 "bookvol10.4.pamphlet" 437768 437776 442142 442147) (-262 "bookvol10.2.pamphlet" 434449 434459 437758 437763) (-261 NIL 431128 431140 434439 434444) (-260 "bookvol10.4.pamphlet" 428108 428195 431118 431123) (-259 "bookvol10.3.pamphlet" 427278 427288 427938 427965) (-258 "bookvol10.2.pamphlet" 426866 426876 427234 427273) (-257 "bookvol10.3.pamphlet" 424309 424323 424602 424729) (-256 "bookvol10.3.pamphlet" 418254 418262 424299 424304) (-255 "bookvol10.4.pamphlet" 417915 417925 418244 418249) (-254 "bookvol10.4.pamphlet" 412740 412748 417905 417910) (-253 "bookvol10.4.pamphlet" 410895 410903 412730 412735) (-252 "bookvol10.4.pamphlet" 403495 403508 410885 410890) (-251 "bookvol10.4.pamphlet" 402748 402758 403485 403490) (-250 "bookvol10.4.pamphlet" 400103 400111 402738 402743) (-249 "bookvol10.4.pamphlet" 399640 399655 400093 400098) (-248 "bookvol10.4.pamphlet" 388812 388820 399630 399635) (-247 "bookvol10.2.pamphlet" 386964 386974 388768 388807) (-246 "bookvol10.2.pamphlet" 382305 382321 386832 386959) (-245 NIL 377732 377750 382261 382266) (-244 "bookvol10.3.pamphlet" 371091 371107 371229 371530) (-243 "bookvol10.3.pamphlet" 364463 364481 364588 364889) (-242 "bookvol10.3.pamphlet" 361700 361715 362257 362384) (-241 "bookvol10.4.pamphlet" 361044 361054 361690 361695) (-240 "bookvol10.3.pamphlet" 359679 359689 360450 360477) (-239 "bookvol10.2.pamphlet" 358072 358082 359659 359674) (-238 "bookvol10.2.pamphlet" 357519 357527 358016 358067) (-237 NIL 357010 357020 357509 357514) (-236 "bookvol10.3.pamphlet" 356863 356873 356942 356969) (-235 "bookvol10.2.pamphlet" 355622 355632 356831 356858) (-234 "bookvol10.4.pamphlet" 353802 353810 355612 355617) (-233 "bookvol10.3.pamphlet" 353094 353109 353638 353763) (-232 "bookvol10.3.pamphlet" 344684 344700 345309 345440) (-231 "bookvol10.4.pamphlet" 343507 343525 344674 344679) (-230 "bookvol10.2.pamphlet" 342669 342685 343359 343502) (-229 NIL 341572 341590 342264 342269) (-228 "bookvol10.4.pamphlet" 340375 340383 341562 341567) (-227 "bookvol10.2.pamphlet" 339347 339357 340343 340370) (-226 NIL 338305 338317 339303 339308) (-225 "bookvol10.2.pamphlet" 337418 337426 338285 338300) (-224 NIL 336539 336549 337408 337413) (-223 "bookvol10.2.pamphlet" 335698 335708 336519 336534) (-222 NIL 334774 334786 335597 335602) (-221 "bookvol10.2.pamphlet" 334392 334402 334742 334769) (-220 NIL 334030 334042 334382 334387) (-219 "bookvol10.3.pamphlet" 332238 332248 333674 333701) (-218 "bookvol10.3.pamphlet" 330966 330974 331362 331389) (-217 "bookvol10.4.pamphlet" 322208 322216 330956 330961) (-216 "bookvol10.3.pamphlet" 321411 321419 321840 321867) (-215 "bookvol10.3.pamphlet" 317688 317696 321301 321406) (-214 "bookvol10.4.pamphlet" 315897 315913 317678 317683) (-213 "bookvol10.3.pamphlet" 313807 313839 315877 315892) (-212 "bookvol10.3.pamphlet" 307481 307491 313637 313664) (-211 "bookvol10.4.pamphlet" 307094 307108 307471 307476) (-210 "bookvol10.4.pamphlet" 304575 304585 307084 307089) (-209 "bookvol10.4.pamphlet" 303071 303087 304565 304570) (-208 "bookvol10.3.pamphlet" 300952 300960 301538 301631) (-207 "bookvol10.4.pamphlet" 298803 298820 300942 300947) (-206 "bookvol10.4.pamphlet" 298401 298425 298793 298798) (-205 "bookvol10.3.pamphlet" 296988 296998 298391 298396) (-204 "bookvol10.3.pamphlet" 296816 296824 296978 296983) (-203 "bookvol10.3.pamphlet" 296636 296644 296806 296811) (-202 "bookvol10.4.pamphlet" 295575 295583 296626 296631) (-201 "bookvol10.3.pamphlet" 295037 295045 295565 295570) (-200 "bookvol10.3.pamphlet" 294515 294523 295027 295032) (-199 "bookvol10.3.pamphlet" 294005 294013 294505 294510) (-198 "bookvol10.3.pamphlet" 293495 293503 293995 294000) (-197 "bookvol10.4.pamphlet" 288337 288345 293485 293490) (-196 "bookvol10.4.pamphlet" 286656 286664 288327 288332) (-195 "bookvol10.3.pamphlet" 286633 286641 286646 286651) (-194 "bookvol10.3.pamphlet" 286155 286163 286623 286628) (-193 "bookvol10.3.pamphlet" 285677 285685 286145 286150) (-192 "bookvol10.3.pamphlet" 285145 285153 285667 285672) (-191 "bookvol10.3.pamphlet" 284630 284638 285135 285140) (-190 "bookvol10.3.pamphlet" 284054 284062 284620 284625) (-189 "bookvol10.3.pamphlet" 283548 283556 284044 284049) (-188 "bookvol10.3.pamphlet" 283058 283066 283538 283543) (-187 "bookvol10.3.pamphlet" 282598 282606 283048 283053) (-186 "bookvol10.3.pamphlet" 282124 282132 282588 282593) (-185 "bookvol10.3.pamphlet" 281647 281655 282114 282119) (-184 "bookvol10.4.pamphlet" 277706 277714 281637 281642) (-183 "bookvol10.4.pamphlet" 277210 277218 277696 277701) (-182 "bookvol10.4.pamphlet" 274027 274035 277200 277205) (-181 "bookvol10.4.pamphlet" 273442 273452 274017 274022) (-180 "bookvol10.4.pamphlet" 271932 271948 273432 273437) (-179 "bookvol10.4.pamphlet" 270601 270614 271922 271927) (-178 "bookvol10.4.pamphlet" 264428 264441 270591 270596) (-177 "bookvol10.4.pamphlet" 263467 263477 264418 264423) (-176 "bookvol10.4.pamphlet" 262967 262982 263392 263397) (-175 "bookvol10.4.pamphlet" 262672 262691 262957 262962) (-174 "bookvol10.4.pamphlet" 257565 257575 262662 262667) (-173 "bookvol10.3.pamphlet" 253300 253310 257467 257560) (-172 "bookvol10.2.pamphlet" 252975 252983 253238 253295) (-171 "bookvol10.3.pamphlet" 252471 252479 252965 252970) (-170 "bookvol10.4.pamphlet" 252238 252253 252461 252466) (-169 "bookvol10.3.pamphlet" 246262 246272 246505 246766) (-168 "bookvol10.4.pamphlet" 245975 245987 246252 246257) (-167 "bookvol10.4.pamphlet" 245771 245785 245965 245970) (-166 "bookvol10.2.pamphlet" 243827 243837 245493 245766) (-165 NIL 241587 241599 243255 243260) (-164 "bookvol10.4.pamphlet" 241333 241351 241577 241582) (-163 "bookvol10.4.pamphlet" 240866 240874 241323 241328) (-162 "bookvol10.3.pamphlet" 240673 240681 240856 240861) (-161 "bookvol10.2.pamphlet" 239578 239586 240663 240668) (-160 "bookvol10.4.pamphlet" 238076 238086 239568 239573) (-159 "bookvol10.4.pamphlet" 235336 235352 238066 238071) (-158 "bookvol10.3.pamphlet" 234173 234181 235326 235331) (-157 "bookvol10.4.pamphlet" 233505 233522 234163 234168) (-156 "bookvol10.4.pamphlet" 229569 229577 233495 233500) (-155 "bookvol10.3.pamphlet" 228222 228238 229525 229564) (-154 "bookvol10.2.pamphlet" 224493 224503 228202 228217) (-153 NIL 220645 220657 224356 224361) (-152 "bookvol10.4.pamphlet" 219970 219983 220635 220640) (-151 "bookvol10.4.pamphlet" 218048 218070 219960 219965) (-150 "bookvol10.2.pamphlet" 217963 217971 218028 218043) (-149 "bookvol10.4.pamphlet" 217471 217481 217953 217958) (-148 "bookvol10.2.pamphlet" 217224 217232 217451 217466) (-147 "bookvol10.3.pamphlet" 212724 212732 217214 217219) (-146 "bookvol10.2.pamphlet" 211905 211913 212714 212719) (-145 "bookvol10.3.pamphlet" 210142 210150 210843 210870) (-144 "bookvol10.3.pamphlet" 209260 209268 209698 209725) (-143 "bookvol10.4.pamphlet" 208418 208432 209250 209255) (-142 "bookvol10.3.pamphlet" 206781 206789 207887 207926) (-141 "bookvol10.3.pamphlet" 196438 196462 206771 206776) (-140 "bookvol10.4.pamphlet" 195824 195851 196428 196433) (-139 "bookvol10.3.pamphlet" 192160 192168 195798 195819) (-138 "bookvol10.2.pamphlet" 191782 191790 192150 192155) (-137 "bookvol10.2.pamphlet" 191293 191301 191772 191777) (-136 "bookvol10.3.pamphlet" 190311 190321 191123 191150) (-135 "bookvol10.3.pamphlet" 189505 189515 190141 190168) (-134 "bookvol10.2.pamphlet" 188869 188879 189461 189500) (-133 NIL 188265 188277 188859 188864) (-132 "bookvol10.2.pamphlet" 187330 187338 188221 188260) (-131 NIL 186427 186437 187320 187325) (-130 "bookvol10.3.pamphlet" 184947 184957 186257 186284) (-129 "bookvol10.4.pamphlet" 183710 183721 184937 184942) (-128 "bookvol10.2.pamphlet" 182624 182634 183690 183705) (-127 NIL 181512 181524 182580 182585) (-126 "bookvol10.3.pamphlet" 179493 179505 179748 179841) (-125 "bookvol10.3.pamphlet" 179157 179169 179419 179488) (-124 "bookvol10.4.pamphlet" 178813 178830 179147 179152) (-123 "bookvol10.3.pamphlet" 174205 174213 178803 178808) (-122 "bookvol10.4.pamphlet" 171583 171593 174161 174166) (-121 "bookvol10.3.pamphlet" 170477 170485 171573 171578) (-120 "bookvol10.2.pamphlet" 170135 170147 170445 170472) (-119 "bookvol10.4.pamphlet" 168341 168377 170125 170130) (-118 "bookvol10.3.pamphlet" 168231 168239 168306 168336) (-117 "bookvol10.2.pamphlet" 168208 168216 168221 168226) (-116 "bookvol10.3.pamphlet" 168100 168108 168175 168203) (-115 "bookvol10.5.pamphlet" 165464 165472 168090 168095) (-114 "bookvol10.3.pamphlet" 164941 164949 165158 165185) (-113 "bookvol10.3.pamphlet" 164284 164292 164931 164936) (-112 "bookvol10.3.pamphlet" 162124 162132 162751 162844) (-111 "bookvol10.2.pamphlet" 161309 161319 162092 162119) (-110 NIL 160514 160526 161299 161304) (-109 "bookvol10.3.pamphlet" 159935 159943 160494 160509) (-108 "bookvol10.4.pamphlet" 159069 159096 159885 159890) (-107 "bookvol10.4.pamphlet" 156390 156400 159059 159064) (-106 "bookvol10.3.pamphlet" 151452 151462 156220 156247) (-105 "bookvol10.2.pamphlet" 151124 151132 151442 151447) (-104 NIL 150794 150804 151114 151119) (-103 "bookvol10.4.pamphlet" 150233 150246 150784 150789) (-102 "bookvol10.4.pamphlet" 150093 150101 150223 150228) (-101 "bookvol10.3.pamphlet" 149539 149549 150073 150088) (-100 "bookvol10.2.pamphlet" 146136 146144 149279 149534) (-99 "bookvol10.3.pamphlet" 142171 142178 146116 146131) (-98 "bookvol10.2.pamphlet" 141641 141648 142161 142166) (-97 NIL 141109 141118 141631 141636) (-96 "bookvol10.3.pamphlet" 136401 136410 140939 140966) (-95 "bookvol10.4.pamphlet" 135201 135212 136357 136362) (-94 "bookvol10.3.pamphlet" 134272 134285 135191 135196) (-93 "bookvol10.3.pamphlet" 132761 132774 134262 134267) (-92 "bookvol10.3.pamphlet" 131881 131894 132751 132756) (-91 "bookvol10.3.pamphlet" 130849 130862 131871 131876) (-90 "bookvol10.3.pamphlet" 130224 130237 130839 130844) (-89 "bookvol10.3.pamphlet" 129429 129442 130214 130219) (-88 "bookvol10.3.pamphlet" 128082 128095 129419 129424) (-87 "bookvol10.3.pamphlet" 127173 127186 128072 128077) (-86 "bookvol10.3.pamphlet" 125295 125308 127163 127168) (-85 "bookvol10.3.pamphlet" 123012 123025 125285 125290) (-84 "bookvol10.3.pamphlet" 119204 119217 123002 123007) (-83 "bookvol10.3.pamphlet" 118345 118358 119194 119199) (-82 "bookvol10.3.pamphlet" 116982 116995 118335 118340) (-81 "bookvol10.3.pamphlet" 114334 114373 116972 116977) (-80 "bookvol10.3.pamphlet" 112008 112047 114324 114329) (-79 "bookvol10.3.pamphlet" 110645 110658 111998 112003) (-78 "bookvol10.3.pamphlet" 109384 109397 110635 110640) (-77 "bookvol10.3.pamphlet" 108898 108911 109374 109379) (-76 "bookvol10.3.pamphlet" 107694 107707 108888 108893) (-75 "bookvol10.3.pamphlet" 105698 105711 107684 107689) (-74 "bookvol10.3.pamphlet" 105008 105021 105688 105693) (-73 "bookvol10.3.pamphlet" 92049 92062 104998 105003) (-72 "bookvol10.3.pamphlet" 90155 90168 92039 92044) (-71 "bookvol10.3.pamphlet" 88878 88891 90145 90150) (-70 "bookvol10.3.pamphlet" 87729 87742 88868 88873) (-69 "bookvol10.3.pamphlet" 87043 87056 87719 87724) (-68 "bookvol10.3.pamphlet" 77536 77549 87033 87038) (-67 "bookvol10.3.pamphlet" 76838 76851 77526 77531) (-66 "bookvol10.3.pamphlet" 75953 75966 76828 76833) (-65 "bookvol10.3.pamphlet" 75551 75560 75783 75810) (-64 "bookvol10.3.pamphlet" 74439 74448 74957 74984) (-63 "bookvol10.4.pamphlet" 72262 72273 74429 74434) (-62 "bookvol10.2.pamphlet" 64788 64809 72218 72257) (-61 NIL 57346 57369 64778 64783) (-60 "bookvol10.4.pamphlet" 56590 56612 57336 57341) (-59 "bookvol10.4.pamphlet" 56205 56218 56580 56585) (-58 "bookvol10.4.pamphlet" 55592 55599 56195 56200) (-57 "bookvol10.3.pamphlet" 53934 53941 55582 55587) (-56 "bookvol10.4.pamphlet" 53005 53014 53924 53929) (-55 "bookvol10.3.pamphlet" 51444 51460 52985 53000) (-54 "bookvol10.3.pamphlet" 51357 51364 51434 51439) (-53 "bookvol10.3.pamphlet" 49658 49665 51173 51266) (-52 "bookvol10.2.pamphlet" 47837 47848 49556 49653) (-51 NIL 45853 45866 47574 47579) (-50 "bookvol10.3.pamphlet" 43897 43918 44247 44274) (-49 "bookvol10.3.pamphlet" 43020 43046 43769 43822) (-48 "bookvol10.4.pamphlet" 38807 38818 42976 42981) (-47 "bookvol10.4.pamphlet" 37996 38010 38797 38802) (-46 "bookvol10.4.pamphlet" 35416 35431 37793 37798) (-45 "bookvol10.3.pamphlet" 33730 33757 33948 34104) (-44 "bookvol10.4.pamphlet" 32843 32853 33720 33725) (-43 "bookvol10.2.pamphlet" 32295 32304 32799 32838) (-42 NIL 31779 31790 32285 32290) (-41 "bookvol10.2.pamphlet" 31277 31298 31735 31774) (-40 "bookvol10.2.pamphlet" 30658 30665 31267 31272) (-39 "bookvol10.2.pamphlet" 28939 28946 30638 30653) (-38 NIL 27194 27203 28895 28900) (-37 "bookvol10.2.pamphlet" 24922 24931 27184 27189) (-36 "bookvol10.4.pamphlet" 23347 23362 24857 24862) (-35 "bookvol10.3.pamphlet" 23190 23205 23337 23342) (-34 "bookvol10.3.pamphlet" 23039 23048 23180 23185) (-33 "bookvol10.3.pamphlet" 22888 22897 23029 23034) (-32 "bookvol10.4.pamphlet" 22771 22809 22878 22883) (-31 "bookvol10.4.pamphlet" 22304 22342 22761 22766) (-30 "bookvol10.3.pamphlet" 20372 20379 22294 22299) (-29 "bookvol10.2.pamphlet" 18103 18112 20262 20367) (-28 NIL 15932 15943 18093 18098) (-27 "bookvol10.2.pamphlet" 10604 10611 15834 15927) (-26 NIL 5362 5371 10594 10599) (-25 "bookvol10.2.pamphlet" 4706 4713 5352 5357) (-24 NIL 4048 4057 4696 4701) (-23 "bookvol10.2.pamphlet" 3399 3406 4038 4043) (-22 NIL 2748 2757 3389 3394) (-21 "bookvol10.2.pamphlet" 2236 2243 2738 2743) (-20 NIL 1722 1731 2226 2231) (-19 "bookvol10.2.pamphlet" 860 869 1678 1717) (-18 NIL 30 41 850 855)) 
\ No newline at end of file
+((-1275 NIL 2465506 2465511 2465516 2465521) (-3 NIL 2465486 2465491 2465496 2465501) (-2 NIL 2465466 2465471 2465476 2465481) (-1 NIL 2465446 2465451 2465456 2465461) (0 NIL 2465426 2465431 2465436 2465441) (-1270 "bookvol10.3.pamphlet" 2465235 2465248 2465364 2465421) (-1269 "bookvol10.4.pamphlet" 2464279 2464290 2465225 2465230) (-1268 "bookvol10.4.pamphlet" 2454519 2454541 2464269 2464274) (-1267 "bookvol10.4.pamphlet" 2454012 2454023 2454509 2454514) (-1266 "bookvol10.3.pamphlet" 2453247 2453267 2453868 2453937) (-1265 "bookvol10.3.pamphlet" 2450976 2450989 2452965 2453064) (-1264 "bookvol10.3.pamphlet" 2450546 2450557 2450832 2450901) (-1263 "bookvol10.2.pamphlet" 2449863 2449879 2450472 2450541) (-1262 "bookvol10.3.pamphlet" 2448360 2448380 2449643 2449712) (-1261 "bookvol10.2.pamphlet" 2446820 2446835 2448262 2448355) (-1260 NIL 2445260 2445277 2446704 2446709) (-1259 "bookvol10.2.pamphlet" 2442285 2442301 2445186 2445255) (-1258 "bookvol10.4.pamphlet" 2441596 2441622 2442275 2442280) (-1257 "bookvol10.3.pamphlet" 2441225 2441241 2441452 2441521) (-1256 "bookvol10.2.pamphlet" 2440924 2440935 2441181 2441220) (-1255 "bookvol10.3.pamphlet" 2437198 2437215 2440626 2440653) (-1254 "bookvol10.3.pamphlet" 2436212 2436256 2437056 2437123) (-1253 "bookvol10.4.pamphlet" 2433775 2433797 2436202 2436207) (-1252 "bookvol10.4.pamphlet" 2431981 2431992 2433765 2433770) (-1251 "bookvol10.2.pamphlet" 2431654 2431665 2431949 2431976) (-1250 NIL 2431347 2431360 2431644 2431649) (-1249 "bookvol10.3.pamphlet" 2430937 2430946 2431337 2431342) (-1248 "bookvol10.4.pamphlet" 2428559 2428568 2430927 2430932) (-1247 "bookvol10.4.pamphlet" 2423756 2423765 2428549 2428554) (-1246 "bookvol10.3.pamphlet" 2407510 2407519 2423746 2423751) (-1245 "bookvol10.3.pamphlet" 2395247 2395256 2407500 2407505) (-1244 "bookvol10.3.pamphlet" 2394144 2394155 2394395 2394422) (-1243 "bookvol10.4.pamphlet" 2392786 2392799 2394134 2394139) (-1242 "bookvol10.2.pamphlet" 2390674 2390685 2392742 2392781) (-1241 NIL 2388381 2388394 2390451 2390456) (-1240 "bookvol10.3.pamphlet" 2388161 2388176 2388371 2388376) (-1239 "bookvol10.3.pamphlet" 2383345 2383367 2386628 2386725) (-1238 "bookvol10.4.pamphlet" 2383248 2383276 2383335 2383340) (-1237 "bookvol10.4.pamphlet" 2382556 2382580 2383204 2383209) (-1236 "bookvol10.4.pamphlet" 2380708 2380728 2382546 2382551) (-1235 "bookvol10.3.pamphlet" 2375497 2375525 2379175 2379272) (-1234 "bookvol10.2.pamphlet" 2372948 2372964 2375395 2375492) (-1233 NIL 2370043 2370061 2372492 2372497) (-1232 "bookvol10.4.pamphlet" 2369666 2369701 2370033 2370038) (-1231 "bookvol10.2.pamphlet" 2364264 2364275 2369646 2369661) (-1230 NIL 2358836 2358849 2364220 2364225) (-1229 "bookvol10.3.pamphlet" 2356479 2356505 2357917 2358050) (-1228 "bookvol10.3.pamphlet" 2353614 2353642 2354611 2354760) (-1227 "bookvol10.3.pamphlet" 2351371 2351391 2351746 2351895) (-1226 "bookvol10.2.pamphlet" 2349829 2349849 2351217 2351366) (-1225 NIL 2348429 2348451 2349819 2349824) (-1224 "bookvol10.2.pamphlet" 2347010 2347026 2348275 2348424) (-1223 "bookvol10.4.pamphlet" 2346551 2346604 2347000 2347005) (-1222 "bookvol10.4.pamphlet" 2344963 2344977 2346541 2346546) (-1221 "bookvol10.2.pamphlet" 2342543 2342567 2344861 2344958) (-1220 NIL 2339829 2339855 2342149 2342154) (-1219 "bookvol10.2.pamphlet" 2334803 2334814 2339671 2339824) (-1218 NIL 2329669 2329682 2334539 2334544) (-1217 "bookvol10.4.pamphlet" 2329134 2329153 2329659 2329664) (-1216 "bookvol10.3.pamphlet" 2326085 2326100 2326684 2326837) (-1215 "bookvol10.4.pamphlet" 2324975 2324988 2326075 2326080) (-1214 "bookvol10.4.pamphlet" 2324538 2324552 2324965 2324970) (-1213 "bookvol10.4.pamphlet" 2322775 2322789 2324528 2324533) (-1212 "bookvol10.4.pamphlet" 2321982 2321998 2322765 2322770) (-1211 "bookvol10.4.pamphlet" 2321344 2321365 2321972 2321977) (-1210 "bookvol10.3.pamphlet" 2320697 2320708 2321263 2321268) (-1209 "bookvol10.4.pamphlet" 2320190 2320203 2320653 2320658) (-1208 "bookvol10.4.pamphlet" 2319291 2319303 2320180 2320185) (-1207 "bookvol10.3.pamphlet" 2309951 2309979 2310936 2311365) (-1206 "bookvol10.3.pamphlet" 2303988 2304008 2304360 2304509) (-1205 "bookvol10.2.pamphlet" 2301581 2301601 2303808 2303983) (-1204 NIL 2299308 2299330 2301537 2301542) (-1203 "bookvol10.2.pamphlet" 2297524 2297540 2299154 2299303) (-1202 "bookvol10.4.pamphlet" 2297066 2297119 2297514 2297519) (-1201 "bookvol10.3.pamphlet" 2295459 2295475 2295533 2295630) (-1200 "bookvol10.4.pamphlet" 2295374 2295390 2295449 2295454) (-1199 "bookvol10.2.pamphlet" 2294439 2294448 2295300 2295369) (-1198 NIL 2293566 2293577 2294429 2294434) (-1197 "bookvol10.4.pamphlet" 2292413 2292422 2293556 2293561) (-1196 "bookvol10.4.pamphlet" 2289899 2289910 2292369 2292374) (-1195 "bookvol10.2.pamphlet" 2289821 2289830 2289879 2289894) (-1194 "bookvol10.4.pamphlet" 2288471 2288486 2289811 2289816) (-1193 "bookvol10.3.pamphlet" 2287374 2287385 2288426 2288431) (-1192 "bookvol10.4.pamphlet" 2284208 2284217 2287364 2287369) (-1191 "bookvol10.3.pamphlet" 2282864 2282881 2284198 2284203) (-1190 "bookvol10.3.pamphlet" 2281453 2281469 2282429 2282526) (-1189 "bookvol10.2.pamphlet" 2268763 2268780 2281409 2281448) (-1188 NIL 2256071 2256090 2268719 2268724) (-1187 "bookvol10.4.pamphlet" 2250437 2250454 2255777 2255782) (-1186 "bookvol10.4.pamphlet" 2249396 2249421 2250427 2250432) (-1185 "bookvol10.4.pamphlet" 2247913 2247930 2249386 2249391) (-1184 "bookvol10.2.pamphlet" 2247425 2247434 2247903 2247908) (-1183 NIL 2246935 2246946 2247415 2247420) (-1182 "bookvol10.3.pamphlet" 2244984 2244995 2246765 2246792) (-1181 "bookvol10.2.pamphlet" 2244815 2244824 2244974 2244979) (-1180 NIL 2244644 2244655 2244805 2244810) (-1179 "bookvol10.4.pamphlet" 2244318 2244327 2244634 2244639) (-1178 "bookvol10.4.pamphlet" 2243981 2243992 2244308 2244313) (-1177 "bookvol10.3.pamphlet" 2242538 2242547 2243971 2243976) (-1176 "bookvol10.3.pamphlet" 2239555 2239564 2242528 2242533) (-1175 "bookvol10.4.pamphlet" 2239111 2239122 2239545 2239550) (-1174 "bookvol10.4.pamphlet" 2238666 2238675 2239101 2239106) (-1173 "bookvol10.4.pamphlet" 2236759 2236782 2238656 2238661) (-1172 "bookvol10.2.pamphlet" 2235606 2235629 2236727 2236754) (-1171 NIL 2234473 2234498 2235596 2235601) (-1170 "bookvol10.4.pamphlet" 2233849 2233860 2234463 2234468) (-1169 "bookvol10.3.pamphlet" 2232822 2232845 2233092 2233119) (-1168 "bookvol10.3.pamphlet" 2232318 2232329 2232812 2232817) (-1167 "bookvol10.4.pamphlet" 2229170 2229181 2232308 2232313) (-1166 "bookvol10.4.pamphlet" 2225763 2225774 2229160 2229165) (-1165 "bookvol10.3.pamphlet" 2223816 2223825 2225753 2225758) (-1164 "bookvol10.3.pamphlet" 2219801 2219810 2223806 2223811) (-1163 "bookvol10.3.pamphlet" 2218808 2218819 2218890 2219017) (-1162 "bookvol10.4.pamphlet" 2218283 2218294 2218798 2218803) (-1161 "bookvol10.3.pamphlet" 2215611 2215620 2218273 2218278) (-1160 "bookvol10.3.pamphlet" 2212367 2212376 2215601 2215606) (-1159 "bookvol10.3.pamphlet" 2209374 2209402 2210834 2210931) (-1158 "bookvol10.3.pamphlet" 2206496 2206524 2207506 2207655) (-1157 "bookvol10.3.pamphlet" 2203179 2203190 2204046 2204199) (-1156 "bookvol10.4.pamphlet" 2202299 2202317 2203169 2203174) (-1155 "bookvol10.3.pamphlet" 2199743 2199754 2199812 2199965) (-1154 "bookvol10.4.pamphlet" 2199133 2199146 2199733 2199738) (-1153 "bookvol10.4.pamphlet" 2197611 2197622 2199123 2199128) (-1152 "bookvol10.4.pamphlet" 2197237 2197254 2197601 2197606) (-1151 "bookvol10.3.pamphlet" 2187884 2187912 2188882 2189311) (-1150 "bookvol10.3.pamphlet" 2187564 2187579 2187874 2187879) (-1149 "bookvol10.3.pamphlet" 2179535 2179550 2187554 2187559) (-1148 "bookvol10.4.pamphlet" 2178707 2178721 2179491 2179496) (-1147 "bookvol10.4.pamphlet" 2174806 2174822 2178697 2178702) (-1146 "bookvol10.4.pamphlet" 2171274 2171290 2174796 2174801) (-1145 "bookvol10.4.pamphlet" 2163674 2163685 2171155 2171160) (-1144 "bookvol10.3.pamphlet" 2162753 2162770 2162902 2162929) (-1143 "bookvol10.3.pamphlet" 2162136 2162145 2162234 2162261) (-1142 "bookvol10.2.pamphlet" 2161912 2161921 2162092 2162131) (-1141 "bookvol10.3.pamphlet" 2156860 2156871 2161660 2161675) (-1140 "bookvol10.4.pamphlet" 2156071 2156086 2156850 2156855) (-1139 "bookvol10.4.pamphlet" 2154280 2154293 2156061 2156066) (-1138 "bookvol10.4.pamphlet" 2153704 2153715 2154270 2154275) (-1137 "bookvol10.4.pamphlet" 2152610 2152626 2153694 2153699) (-1136 "bookvol10.2.pamphlet" 2151816 2151825 2152600 2152605) (-1135 "bookvol10.3.pamphlet" 2150904 2150932 2151071 2151086) (-1134 "bookvol10.2.pamphlet" 2149961 2149972 2150884 2150899) (-1133 NIL 2149026 2149039 2149951 2149956) (-1132 "bookvol10.3.pamphlet" 2144651 2144662 2148856 2148883) (-1131 "bookvol10.3.pamphlet" 2142694 2142711 2144353 2144380) (-1130 "bookvol10.4.pamphlet" 2141421 2141441 2142684 2142689) (-1129 "bookvol10.2.pamphlet" 2136464 2136473 2141377 2141416) (-1128 NIL 2131539 2131550 2136454 2136459) (-1127 "bookvol10.3.pamphlet" 2129219 2129237 2130127 2130214) (-1126 "bookvol10.3.pamphlet" 2124086 2124099 2128970 2128997) (-1125 "bookvol10.3.pamphlet" 2120626 2120639 2124076 2124081) (-1124 "bookvol10.2.pamphlet" 2119403 2119412 2120616 2120621) (-1123 "bookvol10.4.pamphlet" 2117968 2117977 2119393 2119398) (-1122 "bookvol10.2.pamphlet" 2101795 2101806 2117958 2117963) (-1121 "bookvol10.3.pamphlet" 2101571 2101582 2101785 2101790) (-1120 "bookvol10.4.pamphlet" 2101116 2101129 2101527 2101532) (-1119 "bookvol10.4.pamphlet" 2098709 2098720 2101106 2101111) (-1118 "bookvol10.4.pamphlet" 2097274 2097285 2098699 2098704) (-1117 "bookvol10.4.pamphlet" 2090701 2090712 2097264 2097269) (-1116 "bookvol10.4.pamphlet" 2089121 2089139 2090691 2090696) (-1115 "bookvol10.2.pamphlet" 2088888 2088905 2089077 2089116) (-1114 "bookvol10.3.pamphlet" 2087004 2087030 2088453 2088550) (-1113 "bookvol10.3.pamphlet" 2084458 2084478 2084833 2084960) (-1112 "bookvol10.4.pamphlet" 2083301 2083326 2084448 2084453) (-1111 "bookvol10.2.pamphlet" 2081399 2081429 2083233 2083296) (-1110 NIL 2079441 2079473 2081277 2081282) (-1109 "bookvol10.2.pamphlet" 2077879 2077890 2079397 2079436) (-1108 "bookvol10.3.pamphlet" 2076244 2076253 2077745 2077874) (-1107 "bookvol10.4.pamphlet" 2075987 2075996 2076234 2076239) (-1106 "bookvol10.4.pamphlet" 2075095 2075106 2075977 2075982) (-1105 "bookvol10.4.pamphlet" 2074364 2074381 2075085 2075090) (-1104 "bookvol10.4.pamphlet" 2072234 2072249 2074320 2074325) (-1103 "bookvol10.3.pamphlet" 2063947 2063974 2064449 2064580) (-1102 "bookvol10.2.pamphlet" 2063182 2063191 2063937 2063942) (-1101 NIL 2062415 2062426 2063172 2063177) (-1100 "bookvol10.4.pamphlet" 2055441 2055450 2062405 2062410) (-1099 "bookvol10.2.pamphlet" 2054920 2054937 2055397 2055436) (-1098 "bookvol10.4.pamphlet" 2054619 2054639 2054910 2054915) (-1097 "bookvol10.4.pamphlet" 2049944 2049964 2054609 2054614) (-1096 "bookvol10.3.pamphlet" 2049379 2049393 2049934 2049939) (-1095 "bookvol10.3.pamphlet" 2049222 2049262 2049369 2049374) (-1094 "bookvol10.3.pamphlet" 2049114 2049123 2049212 2049217) (-1093 "bookvol10.2.pamphlet" 2046203 2046243 2049104 2049109) (-1092 "bookvol10.3.pamphlet" 2044513 2044524 2045680 2045719) (-1091 "bookvol10.3.pamphlet" 2042931 2042948 2044503 2044508) (-1090 "bookvol10.2.pamphlet" 2042413 2042422 2042921 2042926) (-1089 NIL 2041893 2041904 2042403 2042408) (-1088 "bookvol10.2.pamphlet" 2041782 2041791 2041883 2041888) (-1087 "bookvol10.2.pamphlet" 2038270 2038281 2041750 2041777) (-1086 NIL 2034778 2034791 2038260 2038265) (-1085 "bookvol10.2.pamphlet" 2033890 2033903 2034758 2034773) (-1084 "bookvol10.3.pamphlet" 2033703 2033714 2033809 2033814) (-1083 "bookvol10.2.pamphlet" 2032509 2032520 2033683 2033698) (-1082 "bookvol10.3.pamphlet" 2031581 2031592 2032464 2032469) (-1081 "bookvol10.4.pamphlet" 2031277 2031290 2031571 2031576) (-1080 "bookvol10.4.pamphlet" 2030702 2030715 2031233 2031238) (-1079 "bookvol10.3.pamphlet" 2029978 2029989 2030692 2030697) (-1078 "bookvol10.3.pamphlet" 2027380 2027391 2027659 2027786) (-1077 "bookvol10.4.pamphlet" 2025459 2025470 2027370 2027375) (-1076 "bookvol10.4.pamphlet" 2024340 2024351 2025449 2025454) (-1075 "bookvol10.3.pamphlet" 2024212 2024221 2024330 2024335) (-1074 "bookvol10.4.pamphlet" 2023925 2023945 2024202 2024207) (-1073 "bookvol10.3.pamphlet" 2022046 2022062 2022711 2022846) (-1072 "bookvol10.4.pamphlet" 2021747 2021767 2022036 2022041) (-1071 "bookvol10.4.pamphlet" 2019433 2019449 2021737 2021742) (-1070 "bookvol10.3.pamphlet" 2018835 2018859 2019423 2019428) (-1069 "bookvol10.3.pamphlet" 2017179 2017203 2018825 2018830) (-1068 "bookvol10.3.pamphlet" 2017031 2017044 2017169 2017174) (-1067 "bookvol10.4.pamphlet" 2014099 2014119 2017021 2017026) (-1066 "bookvol10.2.pamphlet" 2004559 2004576 2014055 2014094) (-1065 NIL 1995051 1995070 2004549 2004554) (-1064 "bookvol10.4.pamphlet" 1993685 1993705 1995041 1995046) (-1063 "bookvol10.2.pamphlet" 1992069 1992099 1993675 1993680) (-1062 NIL 1990451 1990483 1992059 1992064) (-1061 "bookvol10.2.pamphlet" 1969767 1969782 1990319 1990446) (-1060 NIL 1948797 1948814 1969351 1969356) (-1059 "bookvol10.3.pamphlet" 1945242 1945251 1948026 1948053) (-1058 "bookvol10.3.pamphlet" 1944489 1944498 1945108 1945237) (-1057 NIL 1943569 1943601 1944479 1944484) (-1056 "bookvol10.2.pamphlet" 1942472 1942481 1943471 1943564) (-1055 NIL 1941461 1941472 1942462 1942467) (-1054 "bookvol10.2.pamphlet" 1940983 1940992 1941451 1941456) (-1053 "bookvol10.2.pamphlet" 1940460 1940471 1940973 1940978) (-1052 "bookvol10.4.pamphlet" 1939868 1939925 1940450 1940455) (-1051 "bookvol10.3.pamphlet" 1938603 1938622 1939091 1939130) (-1050 "bookvol10.2.pamphlet" 1934120 1934151 1938547 1938598) (-1049 NIL 1929539 1929572 1933968 1933973) (-1048 "bookvol10.4.pamphlet" 1929427 1929447 1929529 1929534) (-1047 "bookvol10.2.pamphlet" 1928780 1928789 1929407 1929422) (-1046 NIL 1928141 1928152 1928770 1928775) (-1045 "bookvol10.4.pamphlet" 1927035 1927044 1928131 1928136) (-1044 "bookvol10.3.pamphlet" 1925700 1925716 1926595 1926622) (-1043 "bookvol10.4.pamphlet" 1923742 1923753 1925690 1925695) (-1042 "bookvol10.4.pamphlet" 1921356 1921367 1923732 1923737) (-1041 "bookvol10.4.pamphlet" 1920818 1920829 1921346 1921351) (-1040 "bookvol10.4.pamphlet" 1920553 1920565 1920808 1920813) (-1039 "bookvol10.4.pamphlet" 1919541 1919550 1920543 1920548) (-1038 "bookvol10.4.pamphlet" 1918958 1918971 1919531 1919536) (-1037 "bookvol10.2.pamphlet" 1918307 1918318 1918948 1918953) (-1036 NIL 1917654 1917667 1918297 1918302) (-1035 "bookvol10.3.pamphlet" 1916296 1916305 1916883 1916910) (-1034 "bookvol10.3.pamphlet" 1915643 1915690 1916234 1916291) (-1033 "bookvol10.4.pamphlet" 1914967 1914978 1915633 1915638) (-1032 "bookvol10.4.pamphlet" 1914696 1914707 1914957 1914962) (-1031 "bookvol10.4.pamphlet" 1912248 1912257 1914686 1914691) (-1030 "bookvol10.4.pamphlet" 1911953 1911964 1912238 1912243) (-1029 "bookvol10.4.pamphlet" 1901395 1901406 1911795 1911800) (-1028 "bookvol10.4.pamphlet" 1895371 1895382 1901345 1901350) (-1027 "bookvol10.3.pamphlet" 1893462 1893479 1895073 1895100) (-1026 "bookvol10.3.pamphlet" 1892806 1892817 1893417 1893422) (-1025 "bookvol10.4.pamphlet" 1891982 1891999 1892796 1892801) (-1024 "bookvol10.4.pamphlet" 1890279 1890296 1891937 1891942) (-1023 "bookvol10.3.pamphlet" 1889062 1889082 1889766 1889859) (-1022 "bookvol10.4.pamphlet" 1887517 1887526 1889052 1889057) (-1021 "bookvol10.2.pamphlet" 1887389 1887398 1887507 1887512) (-1020 "bookvol10.4.pamphlet" 1884686 1884701 1887379 1887384) (-1019 "bookvol10.4.pamphlet" 1881529 1881544 1884676 1884681) (-1018 "bookvol10.4.pamphlet" 1881274 1881299 1881519 1881524) (-1017 "bookvol10.4.pamphlet" 1880837 1880848 1881264 1881269) (-1016 "bookvol10.4.pamphlet" 1879737 1879755 1880827 1880832) (-1015 "bookvol10.4.pamphlet" 1877942 1877960 1879727 1879732) (-1014 "bookvol10.4.pamphlet" 1877167 1877184 1877932 1877937) (-1013 "bookvol10.4.pamphlet" 1876317 1876334 1877157 1877162) (-1012 "bookvol10.2.pamphlet" 1873500 1873509 1876219 1876312) (-1011 NIL 1870769 1870780 1873490 1873495) (-1010 "bookvol10.2.pamphlet" 1868678 1868689 1870749 1870764) (-1009 NIL 1866524 1866537 1868597 1868602) (-1008 "bookvol10.4.pamphlet" 1865941 1865952 1866514 1866519) (-1007 "bookvol10.4.pamphlet" 1865125 1865137 1865931 1865936) (-1006 "bookvol10.4.pamphlet" 1864482 1864491 1865115 1865120) (-1005 "bookvol10.4.pamphlet" 1864236 1864245 1864472 1864477) (-1004 "bookvol10.3.pamphlet" 1861021 1861035 1862703 1862796) (-1003 "bookvol10.3.pamphlet" 1859434 1859471 1859553 1859709) (-1002 "bookvol10.2.pamphlet" 1859027 1859036 1859424 1859429) (-1001 NIL 1858618 1858629 1859017 1859022) (-1000 "bookvol10.3.pamphlet" 1854007 1854018 1858448 1858475) (-999 "bookvol10.3.pamphlet" 1852634 1852644 1852931 1852996) (-998 "bookvol10.4.pamphlet" 1851957 1851975 1852624 1852629) (-997 "bookvol10.2.pamphlet" 1850118 1850128 1851887 1851952) (-996 NIL 1848030 1848042 1849801 1849806) (-995 "bookvol10.2.pamphlet" 1846836 1846846 1847986 1848025) (-994 "bookvol10.3.pamphlet" 1846299 1846313 1846826 1846831) (-993 "bookvol10.2.pamphlet" 1844990 1845000 1846189 1846294) (-992 NIL 1843284 1843296 1844485 1844490) (-991 "bookvol10.4.pamphlet" 1842975 1842991 1843274 1843279) (-990 "bookvol10.3.pamphlet" 1842532 1842540 1842965 1842970) (-989 "bookvol10.4.pamphlet" 1837934 1837953 1842522 1842527) (-988 "bookvol10.3.pamphlet" 1834009 1834041 1837848 1837853) (-987 "bookvol10.4.pamphlet" 1832005 1832023 1833999 1834004) (-986 "bookvol10.4.pamphlet" 1829315 1829336 1831995 1832000) (-985 "bookvol10.4.pamphlet" 1828642 1828661 1829305 1829310) (-984 "bookvol10.2.pamphlet" 1824768 1824778 1828632 1828637) (-983 "bookvol10.4.pamphlet" 1821852 1821862 1824758 1824763) (-982 "bookvol10.4.pamphlet" 1821669 1821683 1821842 1821847) (-981 "bookvol10.2.pamphlet" 1820751 1820761 1821625 1821664) (-980 "bookvol10.4.pamphlet" 1820058 1820082 1820741 1820746) (-979 "bookvol10.4.pamphlet" 1818916 1818926 1820048 1820053) (-978 "bookvol10.4.pamphlet" 1804317 1804333 1818794 1818799) (-977 "bookvol10.2.pamphlet" 1798210 1798233 1804285 1804312) (-976 NIL 1792089 1792114 1798166 1798171) (-975 "bookvol10.2.pamphlet" 1791072 1791080 1792079 1792084) (-974 "bookvol10.2.pamphlet" 1789835 1789864 1790970 1791067) (-973 NIL 1788688 1788719 1789825 1789830) (-972 "bookvol10.3.pamphlet" 1787503 1787511 1788678 1788683) (-971 "bookvol10.2.pamphlet" 1784836 1784846 1787493 1787498) (-970 "bookvol10.4.pamphlet" 1774981 1774998 1784792 1784797) (-969 "bookvol10.2.pamphlet" 1774400 1774410 1774937 1774976) (-968 "bookvol10.3.pamphlet" 1774282 1774298 1774390 1774395) (-967 "bookvol10.3.pamphlet" 1774170 1774180 1774272 1774277) (-966 "bookvol10.3.pamphlet" 1774058 1774068 1774160 1774165) (-965 "bookvol10.3.pamphlet" 1771459 1771471 1772024 1772079) (-964 "bookvol10.3.pamphlet" 1769845 1769857 1770550 1770677) (-963 "bookvol10.4.pamphlet" 1769049 1769088 1769835 1769840) (-962 "bookvol10.4.pamphlet" 1768801 1768809 1769039 1769044) (-961 "bookvol10.4.pamphlet" 1767044 1767054 1768791 1768796) (-960 "bookvol10.4.pamphlet" 1765017 1765031 1767034 1767039) (-959 "bookvol10.2.pamphlet" 1764640 1764648 1765007 1765012) (-958 "bookvol10.3.pamphlet" 1763883 1763893 1764046 1764073) (-957 "bookvol10.4.pamphlet" 1761775 1761787 1763873 1763878) (-956 "bookvol10.4.pamphlet" 1761147 1761159 1761765 1761770) (-955 "bookvol10.2.pamphlet" 1760284 1760292 1761137 1761142) (-954 "bookvol10.4.pamphlet" 1759056 1759078 1760240 1760245) (-953 "bookvol10.3.pamphlet" 1756368 1756378 1756870 1756997) (-952 "bookvol10.4.pamphlet" 1755629 1755652 1756358 1756363) (-951 "bookvol10.4.pamphlet" 1753693 1753715 1755619 1755624) (-950 "bookvol10.2.pamphlet" 1747095 1747116 1753561 1753688) (-949 NIL 1739799 1739822 1746267 1746272) (-948 "bookvol10.4.pamphlet" 1739247 1739261 1739789 1739794) (-947 "bookvol10.4.pamphlet" 1738857 1738869 1739237 1739242) (-946 "bookvol10.4.pamphlet" 1737798 1737827 1738813 1738818) (-945 "bookvol10.4.pamphlet" 1736546 1736561 1737788 1737793) (-944 "bookvol10.3.pamphlet" 1735607 1735617 1735694 1735721) (-943 "bookvol10.4.pamphlet" 1732247 1732255 1735597 1735602) (-942 "bookvol10.4.pamphlet" 1731004 1731018 1732237 1732242) (-941 "bookvol10.4.pamphlet" 1730549 1730559 1730994 1730999) (-940 "bookvol10.4.pamphlet" 1730136 1730150 1730539 1730544) (-939 "bookvol10.4.pamphlet" 1729662 1729676 1730126 1730131) (-938 "bookvol10.4.pamphlet" 1729163 1729185 1729652 1729657) (-937 "bookvol10.4.pamphlet" 1728233 1728251 1729095 1729100) (-936 "bookvol10.4.pamphlet" 1727814 1727828 1728223 1728228) (-935 "bookvol10.4.pamphlet" 1727381 1727393 1727804 1727809) (-934 "bookvol10.4.pamphlet" 1726957 1726967 1727371 1727376) (-933 "bookvol10.4.pamphlet" 1726530 1726548 1726947 1726952) (-932 "bookvol10.4.pamphlet" 1725812 1725826 1726520 1726525) (-931 "bookvol10.4.pamphlet" 1724881 1724889 1725802 1725807) (-930 "bookvol10.4.pamphlet" 1723907 1723923 1724871 1724876) (-929 "bookvol10.4.pamphlet" 1722805 1722843 1723897 1723902) (-928 "bookvol10.4.pamphlet" 1722585 1722593 1722795 1722800) (-927 "bookvol10.3.pamphlet" 1717257 1717265 1722575 1722580) (-926 "bookvol10.3.pamphlet" 1713659 1713667 1717247 1717252) (-925 "bookvol10.4.pamphlet" 1712792 1712802 1713649 1713654) (-924 "bookvol10.4.pamphlet" 1698749 1698776 1712782 1712787) (-923 "bookvol10.3.pamphlet" 1698656 1698670 1698739 1698744) (-922 "bookvol10.3.pamphlet" 1698567 1698577 1698646 1698651) (-921 "bookvol10.3.pamphlet" 1698478 1698488 1698557 1698562) (-920 "bookvol10.2.pamphlet" 1697506 1697520 1698468 1698473) (-919 "bookvol10.4.pamphlet" 1697122 1697141 1697496 1697501) (-918 "bookvol10.4.pamphlet" 1696904 1696920 1697112 1697117) (-917 "bookvol10.3.pamphlet" 1696526 1696534 1696878 1696899) (-916 "bookvol10.2.pamphlet" 1695482 1695490 1696452 1696521) (-915 "bookvol10.4.pamphlet" 1695211 1695221 1695472 1695477) (-914 "bookvol10.4.pamphlet" 1693823 1693837 1695201 1695206) (-913 "bookvol10.4.pamphlet" 1685189 1685197 1693813 1693818) (-912 "bookvol10.4.pamphlet" 1683739 1683756 1685179 1685184) (-911 "bookvol10.4.pamphlet" 1682754 1682764 1683729 1683734) (-910 "bookvol10.3.pamphlet" 1678122 1678132 1682656 1682749) (-909 "bookvol10.4.pamphlet" 1677477 1677493 1678112 1678117) (-908 "bookvol10.4.pamphlet" 1675512 1675541 1677467 1677472) (-907 "bookvol10.4.pamphlet" 1674882 1674900 1675502 1675507) (-906 "bookvol10.4.pamphlet" 1674301 1674328 1674872 1674877) (-905 "bookvol10.3.pamphlet" 1673968 1673980 1674106 1674199) (-904 "bookvol10.2.pamphlet" 1671634 1671642 1673894 1673963) (-903 NIL 1669328 1669338 1671590 1671595) (-902 "bookvol10.4.pamphlet" 1667213 1667225 1669318 1669323) (-901 "bookvol10.4.pamphlet" 1664813 1664836 1667203 1667208) (-900 "bookvol10.3.pamphlet" 1659799 1659809 1664643 1664658) (-899 "bookvol10.3.pamphlet" 1654489 1654499 1659789 1659794) (-898 "bookvol10.2.pamphlet" 1653042 1653052 1654469 1654484) (-897 "bookvol10.4.pamphlet" 1651705 1651719 1653032 1653037) (-896 "bookvol10.3.pamphlet" 1650975 1650985 1651557 1651562) (-895 "bookvol10.2.pamphlet" 1649269 1649279 1650955 1650970) (-894 NIL 1647571 1647583 1649259 1649264) (-893 "bookvol10.3.pamphlet" 1645676 1645684 1647561 1647566) (-892 "bookvol10.4.pamphlet" 1639468 1639476 1645666 1645671) (-891 "bookvol10.4.pamphlet" 1638768 1638785 1639458 1639463) (-890 "bookvol10.2.pamphlet" 1636912 1636920 1638758 1638763) (-889 "bookvol10.4.pamphlet" 1636601 1636614 1636902 1636907) (-888 "bookvol10.3.pamphlet" 1635243 1635260 1636591 1636596) (-887 "bookvol10.3.pamphlet" 1629674 1629684 1635233 1635238) (-886 "bookvol10.4.pamphlet" 1629411 1629423 1629664 1629669) (-885 "bookvol10.4.pamphlet" 1627701 1627717 1629401 1629406) (-884 "bookvol10.3.pamphlet" 1625240 1625252 1627691 1627696) (-883 "bookvol10.4.pamphlet" 1624894 1624908 1625230 1625235) (-882 "bookvol10.4.pamphlet" 1623051 1623082 1624602 1624607) (-881 "bookvol10.2.pamphlet" 1622476 1622486 1623041 1623046) (-880 "bookvol10.3.pamphlet" 1621560 1621574 1622466 1622471) (-879 "bookvol10.2.pamphlet" 1621324 1621334 1621550 1621555) (-878 "bookvol10.4.pamphlet" 1618686 1618694 1621314 1621319) (-877 "bookvol10.3.pamphlet" 1618114 1618142 1618676 1618681) (-876 "bookvol10.4.pamphlet" 1617905 1617921 1618104 1618109) (-875 "bookvol10.3.pamphlet" 1617333 1617361 1617895 1617900) (-874 "bookvol10.4.pamphlet" 1617118 1617134 1617323 1617328) (-873 "bookvol10.3.pamphlet" 1616576 1616604 1617108 1617113) (-872 "bookvol10.4.pamphlet" 1616361 1616377 1616566 1616571) (-871 "bookvol10.4.pamphlet" 1615152 1615201 1616351 1616356) (-870 "bookvol10.4.pamphlet" 1614564 1614572 1615142 1615147) (-869 "bookvol10.3.pamphlet" 1613534 1613542 1614554 1614559) (-868 "bookvol10.4.pamphlet" 1607917 1607940 1613490 1613495) (-867 "bookvol10.4.pamphlet" 1601736 1601759 1607866 1607871) (-866 "bookvol10.3.pamphlet" 1599066 1599084 1600241 1600334) (-865 "bookvol10.3.pamphlet" 1597081 1597093 1597302 1597395) (-864 "bookvol10.3.pamphlet" 1596776 1596788 1597007 1597076) (-863 "bookvol10.2.pamphlet" 1595332 1595344 1596702 1596771) (-862 "bookvol10.4.pamphlet" 1594261 1594280 1595322 1595327) (-861 "bookvol10.4.pamphlet" 1593242 1593258 1594251 1594256) (-860 "bookvol10.3.pamphlet" 1591843 1591851 1592913 1593006) (-859 "bookvol10.2.pamphlet" 1590593 1590601 1591745 1591838) (-858 "bookvol10.2.pamphlet" 1588656 1588664 1590495 1590588) (-857 "bookvol10.3.pamphlet" 1587381 1587391 1588452 1588545) (-856 "bookvol10.2.pamphlet" 1586134 1586142 1587283 1587376) (-855 "bookvol10.3.pamphlet" 1584439 1584459 1585524 1585617) (-854 "bookvol10.2.pamphlet" 1583181 1583189 1584341 1584434) (-853 "bookvol10.3.pamphlet" 1582165 1582195 1583039 1583106) (-852 "bookvol10.3.pamphlet" 1581946 1581969 1582155 1582160) (-851 "bookvol10.4.pamphlet" 1581030 1581038 1581936 1581941) (-850 "bookvol10.3.pamphlet" 1570444 1570452 1581020 1581025) (-849 "bookvol10.3.pamphlet" 1570033 1570041 1570434 1570439) (-848 "bookvol10.4.pamphlet" 1568494 1568504 1569950 1569955) (-847 "bookvol10.3.pamphlet" 1567852 1567880 1568174 1568213) (-846 "bookvol10.3.pamphlet" 1567151 1567175 1567532 1567571) (-845 "bookvol10.4.pamphlet" 1564985 1564997 1567071 1567076) (-844 "bookvol10.2.pamphlet" 1559131 1559141 1564941 1564980) (-843 NIL 1553167 1553179 1558979 1558984) (-842 "bookvol10.2.pamphlet" 1552333 1552341 1553157 1553162) (-841 NIL 1551497 1551507 1552323 1552328) (-840 "bookvol10.2.pamphlet" 1550831 1550839 1551477 1551492) (-839 NIL 1550173 1550183 1550821 1550826) (-838 "bookvol10.2.pamphlet" 1549927 1549935 1550163 1550168) (-837 "bookvol10.4.pamphlet" 1549068 1549084 1549917 1549922) (-836 "bookvol10.2.pamphlet" 1549002 1549010 1549058 1549063) (-835 "bookvol10.3.pamphlet" 1547488 1547498 1548549 1548578) (-834 "bookvol10.4.pamphlet" 1546828 1546840 1547478 1547483) (-833 "bookvol10.3.pamphlet" 1544512 1544520 1546818 1546823) (-832 "bookvol10.4.pamphlet" 1536696 1536704 1544502 1544507) (-831 "bookvol10.2.pamphlet" 1534162 1534170 1536686 1536691) (-830 "bookvol10.4.pamphlet" 1533711 1533719 1534152 1534157) (-829 "bookvol10.3.pamphlet" 1533453 1533463 1533533 1533600) (-828 "bookvol10.3.pamphlet" 1532227 1532237 1533000 1533029) (-827 "bookvol10.4.pamphlet" 1531700 1531712 1532217 1532222) (-826 "bookvol10.4.pamphlet" 1530702 1530710 1531690 1531695) (-825 "bookvol10.2.pamphlet" 1530478 1530488 1530646 1530697) (-824 "bookvol10.4.pamphlet" 1529090 1529098 1530468 1530473) (-823 "bookvol10.2.pamphlet" 1528055 1528063 1529080 1529085) (-822 "bookvol10.3.pamphlet" 1527480 1527492 1527941 1527980) (-821 "bookvol10.4.pamphlet" 1527314 1527324 1527470 1527475) (-820 "bookvol10.3.pamphlet" 1526857 1526865 1527304 1527309) (-819 "bookvol10.3.pamphlet" 1525891 1525899 1526847 1526852) (-818 "bookvol10.3.pamphlet" 1525235 1525243 1525881 1525886) (-817 "bookvol10.3.pamphlet" 1519524 1519532 1525225 1525230) (-816 "bookvol10.3.pamphlet" 1518933 1518941 1519514 1519519) (-815 "bookvol10.2.pamphlet" 1518708 1518716 1518859 1518928) (-814 "bookvol10.3.pamphlet" 1512079 1512089 1518698 1518703) (-813 "bookvol10.3.pamphlet" 1511340 1511350 1512069 1512074) (-812 "bookvol10.3.pamphlet" 1510788 1510814 1511152 1511301) (-811 "bookvol10.3.pamphlet" 1508146 1508156 1508474 1508601) (-810 "bookvol10.3.pamphlet" 1500003 1500023 1500361 1500492) (-809 "bookvol10.4.pamphlet" 1498582 1498601 1499993 1499998) (-808 "bookvol10.4.pamphlet" 1496232 1496249 1498572 1498577) (-807 "bookvol10.4.pamphlet" 1492175 1492192 1496189 1496194) (-806 "bookvol10.4.pamphlet" 1491562 1491586 1492165 1492170) (-805 "bookvol10.4.pamphlet" 1489128 1489145 1491552 1491557) (-804 "bookvol10.4.pamphlet" 1486019 1486041 1489118 1489123) (-803 "bookvol10.3.pamphlet" 1484605 1484613 1486009 1486014) (-802 "bookvol10.4.pamphlet" 1481909 1481931 1484595 1484600) (-801 "bookvol10.4.pamphlet" 1481285 1481309 1481899 1481904) (-800 "bookvol10.4.pamphlet" 1467647 1467655 1481275 1481280) (-799 "bookvol10.4.pamphlet" 1467078 1467094 1467637 1467642) (-798 "bookvol10.3.pamphlet" 1464473 1464481 1467068 1467073) (-797 "bookvol10.4.pamphlet" 1459840 1459856 1464463 1464468) (-796 "bookvol10.4.pamphlet" 1459359 1459377 1459830 1459835) (-795 "bookvol10.2.pamphlet" 1457744 1457752 1459349 1459354) (-794 "bookvol10.3.pamphlet" 1455880 1455890 1456598 1456637) (-793 "bookvol10.4.pamphlet" 1455516 1455537 1455870 1455875) (-792 "bookvol10.2.pamphlet" 1453290 1453300 1455472 1455511) (-791 NIL 1450789 1450801 1452973 1452978) (-790 "bookvol10.2.pamphlet" 1450637 1450645 1450779 1450784) (-789 "bookvol10.2.pamphlet" 1450385 1450393 1450627 1450632) (-788 "bookvol10.2.pamphlet" 1449677 1449685 1450375 1450380) (-787 "bookvol10.2.pamphlet" 1449538 1449546 1449667 1449672) (-786 "bookvol10.2.pamphlet" 1449400 1449408 1449528 1449533) (-785 "bookvol10.4.pamphlet" 1449123 1449139 1449390 1449395) (-784 "bookvol10.4.pamphlet" 1437440 1437448 1449113 1449118) (-783 "bookvol10.4.pamphlet" 1428199 1428207 1437430 1437435) (-782 "bookvol10.2.pamphlet" 1425538 1425546 1428189 1428194) (-781 "bookvol10.4.pamphlet" 1424378 1424386 1425528 1425533) (-780 "bookvol10.4.pamphlet" 1416450 1416460 1424183 1424188) (-779 "bookvol10.2.pamphlet" 1415747 1415763 1416406 1416445) (-778 "bookvol10.4.pamphlet" 1415292 1415302 1415664 1415669) (-777 "bookvol10.3.pamphlet" 1408281 1408291 1412842 1412995) (-776 "bookvol10.4.pamphlet" 1407673 1407685 1408271 1408276) (-775 "bookvol10.3.pamphlet" 1403868 1403887 1404176 1404303) (-774 "bookvol10.3.pamphlet" 1402392 1402402 1402469 1402562) (-773 "bookvol10.4.pamphlet" 1400764 1400778 1402382 1402387) (-772 "bookvol10.4.pamphlet" 1400656 1400685 1400754 1400759) (-771 "bookvol10.4.pamphlet" 1399902 1399922 1400646 1400651) (-770 "bookvol10.3.pamphlet" 1399790 1399804 1399882 1399897) (-769 "bookvol10.4.pamphlet" 1399384 1399423 1399780 1399785) (-768 "bookvol10.4.pamphlet" 1397918 1397937 1399374 1399379) (-767 "bookvol10.4.pamphlet" 1397606 1397632 1397908 1397913) (-766 "bookvol10.3.pamphlet" 1397347 1397355 1397596 1397601) (-765 "bookvol10.4.pamphlet" 1397023 1397033 1397337 1397342) (-764 "bookvol10.4.pamphlet" 1396492 1396508 1397013 1397018) (-763 "bookvol10.3.pamphlet" 1395382 1395390 1396466 1396487) (-762 "bookvol10.4.pamphlet" 1394004 1394014 1395372 1395377) (-761 "bookvol10.3.pamphlet" 1391602 1391610 1393994 1393999) (-760 "bookvol10.4.pamphlet" 1389062 1389079 1391592 1391597) (-759 "bookvol10.4.pamphlet" 1388315 1388329 1389052 1389057) (-758 "bookvol10.4.pamphlet" 1386427 1386443 1388305 1388310) (-757 "bookvol10.4.pamphlet" 1386084 1386098 1386417 1386422) (-756 "bookvol10.4.pamphlet" 1384244 1384258 1386074 1386079) (-755 "bookvol10.2.pamphlet" 1383840 1383848 1384234 1384239) (-754 NIL 1383434 1383444 1383830 1383835) (-753 "bookvol10.2.pamphlet" 1382720 1382728 1383424 1383429) (-752 NIL 1382004 1382014 1382710 1382715) (-751 "bookvol10.4.pamphlet" 1381077 1381085 1381994 1381999) (-750 "bookvol10.4.pamphlet" 1370643 1370651 1381067 1381072) (-749 "bookvol10.4.pamphlet" 1369079 1369087 1370633 1370638) (-748 "bookvol10.4.pamphlet" 1363253 1363261 1369069 1369074) (-747 "bookvol10.4.pamphlet" 1356997 1357005 1363243 1363248) (-746 "bookvol10.4.pamphlet" 1352619 1352627 1356987 1356992) (-745 "bookvol10.4.pamphlet" 1345993 1346001 1352609 1352614) (-744 "bookvol10.4.pamphlet" 1336388 1336396 1345983 1345988) (-743 "bookvol10.4.pamphlet" 1332315 1332323 1336378 1336383) (-742 "bookvol10.4.pamphlet" 1330190 1330198 1332305 1332310) (-741 "bookvol10.4.pamphlet" 1322636 1322644 1330180 1330185) (-740 "bookvol10.4.pamphlet" 1316792 1316800 1322626 1322631) (-739 "bookvol10.4.pamphlet" 1312622 1312630 1316782 1316787) (-738 "bookvol10.4.pamphlet" 1311134 1311142 1312612 1312617) (-737 "bookvol10.4.pamphlet" 1310432 1310440 1311124 1311129) (-736 "bookvol10.2.pamphlet" 1309938 1309948 1310400 1310427) (-735 NIL 1309464 1309476 1309928 1309933) (-734 "bookvol10.3.pamphlet" 1306685 1306699 1307014 1307167) (-733 "bookvol10.3.pamphlet" 1304804 1304818 1304876 1305096) (-732 "bookvol10.4.pamphlet" 1301788 1301805 1304794 1304799) (-731 "bookvol10.4.pamphlet" 1301186 1301203 1301778 1301783) (-730 "bookvol10.2.pamphlet" 1299220 1299241 1301084 1301181) (-729 "bookvol10.4.pamphlet" 1298877 1298887 1299210 1299215) (-728 "bookvol10.4.pamphlet" 1298317 1298325 1298867 1298872) (-727 "bookvol10.3.pamphlet" 1296322 1296332 1298079 1298118) (-726 "bookvol10.2.pamphlet" 1296155 1296165 1296278 1296317) (-725 "bookvol10.3.pamphlet" 1293108 1293120 1295863 1295930) (-724 "bookvol10.4.pamphlet" 1292668 1292682 1293098 1293103) (-723 "bookvol10.4.pamphlet" 1292229 1292246 1292658 1292663) (-722 "bookvol10.4.pamphlet" 1290274 1290293 1292219 1292224) (-721 "bookvol10.3.pamphlet" 1287724 1287739 1288068 1288195) (-720 "bookvol10.4.pamphlet" 1287003 1287022 1287714 1287719) (-719 "bookvol10.4.pamphlet" 1286811 1286854 1286993 1286998) (-718 "bookvol10.4.pamphlet" 1286555 1286591 1286801 1286806) (-717 "bookvol10.4.pamphlet" 1284890 1284907 1286545 1286550) (-716 "bookvol10.2.pamphlet" 1283754 1283762 1284880 1284885) (-715 NIL 1282616 1282626 1283744 1283749) (-714 "bookvol10.2.pamphlet" 1281362 1281375 1282476 1282611) (-713 NIL 1280130 1280145 1281246 1281251) (-712 "bookvol10.2.pamphlet" 1278136 1278144 1280120 1280125) (-711 NIL 1276140 1276150 1278126 1278131) (-710 "bookvol10.2.pamphlet" 1275284 1275292 1276130 1276135) (-709 NIL 1274426 1274436 1275274 1275279) (-708 "bookvol10.3.pamphlet" 1273105 1273119 1274406 1274421) (-707 "bookvol10.2.pamphlet" 1272786 1272796 1273073 1273100) (-706 NIL 1272487 1272499 1272776 1272781) (-705 "bookvol10.3.pamphlet" 1271800 1271839 1272467 1272482) (-704 "bookvol10.3.pamphlet" 1270442 1270454 1271622 1271689) (-703 "bookvol10.3.pamphlet" 1269953 1269971 1270432 1270437) (-702 "bookvol10.3.pamphlet" 1266613 1266629 1267431 1267584) (-701 "bookvol10.3.pamphlet" 1265974 1266013 1266515 1266608) (-700 "bookvol10.3.pamphlet" 1264761 1264769 1265964 1265969) (-699 "bookvol10.4.pamphlet" 1264501 1264535 1264751 1264756) (-698 "bookvol10.2.pamphlet" 1262943 1262953 1264457 1264496) (-697 "bookvol10.4.pamphlet" 1261515 1261532 1262933 1262938) (-696 "bookvol10.4.pamphlet" 1260985 1261003 1261505 1261510) (-695 "bookvol10.4.pamphlet" 1260571 1260584 1260975 1260980) (-694 "bookvol10.4.pamphlet" 1259886 1259896 1260561 1260566) (-693 "bookvol10.4.pamphlet" 1258779 1258789 1259876 1259881) (-692 "bookvol10.3.pamphlet" 1258555 1258565 1258769 1258774) (-691 "bookvol10.4.pamphlet" 1258016 1258034 1258545 1258550) (-690 "bookvol10.3.pamphlet" 1257455 1257463 1257918 1258011) (-689 "bookvol10.4.pamphlet" 1256094 1256104 1257445 1257450) (-688 "bookvol10.3.pamphlet" 1254538 1254546 1255984 1256089) (-687 "bookvol10.4.pamphlet" 1253938 1253960 1254528 1254533) (-686 "bookvol10.4.pamphlet" 1251800 1251808 1253928 1253933) (-685 "bookvol10.4.pamphlet" 1250041 1250051 1251790 1251795) (-684 "bookvol10.2.pamphlet" 1249316 1249326 1250009 1250036) (-683 "bookvol10.3.pamphlet" 1245289 1245297 1245903 1246104) (-682 "bookvol10.4.pamphlet" 1244497 1244509 1245279 1245284) (-681 "bookvol10.4.pamphlet" 1241605 1241631 1244487 1244492) (-680 "bookvol10.4.pamphlet" 1238881 1238891 1241595 1241600) (-679 "bookvol10.3.pamphlet" 1237772 1237782 1238256 1238283) (-678 "bookvol10.4.pamphlet" 1235098 1235122 1237656 1237661) (-677 "bookvol10.2.pamphlet" 1220309 1220331 1235054 1235093) (-676 NIL 1205368 1205392 1220115 1220120) (-675 "bookvol10.4.pamphlet" 1204636 1204684 1205358 1205363) (-674 "bookvol10.4.pamphlet" 1203356 1203368 1204626 1204631) (-673 "bookvol10.4.pamphlet" 1202255 1202269 1203346 1203351) (-672 "bookvol10.4.pamphlet" 1201589 1201601 1202245 1202250) (-671 "bookvol10.4.pamphlet" 1200407 1200417 1201579 1201584) (-670 "bookvol10.4.pamphlet" 1200215 1200229 1200397 1200402) (-669 "bookvol10.4.pamphlet" 1199980 1199992 1200205 1200210) (-668 "bookvol10.4.pamphlet" 1199610 1199620 1199970 1199975) (-667 "bookvol10.3.pamphlet" 1197554 1197571 1199600 1199605) (-666 "bookvol10.3.pamphlet" 1195473 1195483 1197155 1197160) (-665 "bookvol10.2.pamphlet" 1190929 1190939 1195453 1195468) (-664 NIL 1186393 1186405 1190919 1190924) (-663 "bookvol10.3.pamphlet" 1183199 1183216 1186383 1186388) (-662 "bookvol10.3.pamphlet" 1181457 1181471 1181879 1181930) (-661 "bookvol10.4.pamphlet" 1180990 1181007 1181447 1181452) (-660 "bookvol10.4.pamphlet" 1179830 1179858 1180980 1180985) (-659 "bookvol10.4.pamphlet" 1177634 1177648 1179820 1179825) (-658 "bookvol10.2.pamphlet" 1177291 1177301 1177590 1177629) (-657 NIL 1176980 1176992 1177281 1177286) (-656 "bookvol10.3.pamphlet" 1175994 1176013 1176836 1176905) (-655 "bookvol10.4.pamphlet" 1175251 1175261 1175984 1175989) (-654 "bookvol10.4.pamphlet" 1173696 1173745 1175241 1175246) (-653 "bookvol10.4.pamphlet" 1172335 1172345 1173686 1173691) (-652 "bookvol10.3.pamphlet" 1171736 1171750 1172269 1172296) (-651 "bookvol10.2.pamphlet" 1171338 1171346 1171726 1171731) (-650 NIL 1170938 1170948 1171328 1171333) (-649 "bookvol10.4.pamphlet" 1169856 1169868 1170928 1170933) (-648 "bookvol10.3.pamphlet" 1169243 1169259 1169536 1169575) (-647 "bookvol10.4.pamphlet" 1168287 1168304 1169200 1169205) (-646 "bookvol10.2.pamphlet" 1166904 1166914 1168243 1168282) (-645 NIL 1165519 1165531 1166860 1166865) (-644 "bookvol10.3.pamphlet" 1164795 1164807 1165199 1165238) (-643 "bookvol10.3.pamphlet" 1164198 1164208 1164475 1164514) (-642 "bookvol10.4.pamphlet" 1162970 1162988 1164188 1164193) (-641 "bookvol10.2.pamphlet" 1161345 1161355 1162872 1162965) (-640 "bookvol10.2.pamphlet" 1157093 1157103 1161325 1161340) (-639 NIL 1152815 1152827 1157049 1157054) (-638 "bookvol10.3.pamphlet" 1149551 1149568 1152805 1152810) (-637 "bookvol10.2.pamphlet" 1149034 1149044 1149541 1149546) (-636 "bookvol10.3.pamphlet" 1148134 1148144 1148808 1148835) (-635 "bookvol10.4.pamphlet" 1147565 1147579 1148124 1148129) (-634 "bookvol10.3.pamphlet" 1145506 1145516 1146935 1146962) (-633 "bookvol10.4.pamphlet" 1144797 1144811 1145496 1145501) (-632 "bookvol10.4.pamphlet" 1143437 1143449 1144787 1144792) (-631 "bookvol10.4.pamphlet" 1140310 1140322 1143427 1143432) (-630 "bookvol10.2.pamphlet" 1139742 1139752 1140290 1140305) (-629 "bookvol10.4.pamphlet" 1138519 1138531 1139654 1139659) (-628 "bookvol10.4.pamphlet" 1136433 1136443 1138509 1138514) (-627 "bookvol10.4.pamphlet" 1135316 1135329 1136423 1136428) (-626 "bookvol10.3.pamphlet" 1133330 1133342 1134606 1134751) (-625 "bookvol10.2.pamphlet" 1132855 1132865 1133256 1133325) (-624 NIL 1132408 1132420 1132811 1132816) (-623 "bookvol10.3.pamphlet" 1130941 1130949 1131649 1131664) (-622 "bookvol10.4.pamphlet" 1128309 1128328 1130931 1130936) (-621 "bookvol10.4.pamphlet" 1127052 1127068 1128299 1128304) (-620 "bookvol10.2.pamphlet" 1125759 1125767 1127042 1127047) (-619 "bookvol10.4.pamphlet" 1121411 1121426 1125749 1125754) (-618 "bookvol10.3.pamphlet" 1119474 1119501 1121391 1121406) (-617 "bookvol10.4.pamphlet" 1117858 1117875 1119464 1119469) (-616 "bookvol10.4.pamphlet" 1116916 1116938 1117848 1117853) (-615 "bookvol10.3.pamphlet" 1115688 1115701 1116509 1116578) (-614 "bookvol10.4.pamphlet" 1115261 1115277 1115678 1115683) (-613 "bookvol10.3.pamphlet" 1114701 1114715 1115183 1115222) (-612 "bookvol10.2.pamphlet" 1114477 1114487 1114681 1114696) (-611 NIL 1114261 1114273 1114467 1114472) (-610 "bookvol10.4.pamphlet" 1112974 1112991 1114251 1114256) (-609 "bookvol10.2.pamphlet" 1112696 1112706 1112964 1112969) (-608 "bookvol10.2.pamphlet" 1112433 1112443 1112686 1112691) (-607 "bookvol10.3.pamphlet" 1110968 1110978 1112217 1112222) (-606 "bookvol10.4.pamphlet" 1110671 1110683 1110958 1110963) (-605 "bookvol10.2.pamphlet" 1109762 1109784 1110639 1110666) (-604 NIL 1108873 1108897 1109752 1109757) (-603 "bookvol10.3.pamphlet" 1107495 1107511 1108220 1108247) (-602 "bookvol10.3.pamphlet" 1105472 1105484 1106785 1106930) (-601 "bookvol10.2.pamphlet" 1103554 1103578 1105452 1105467) (-600 NIL 1101501 1101527 1103401 1103406) (-599 "bookvol10.3.pamphlet" 1100509 1100524 1100649 1100676) (-598 "bookvol10.3.pamphlet" 1099669 1099679 1100499 1100504) (-597 "bookvol10.4.pamphlet" 1098480 1098499 1099659 1099664) (-596 "bookvol10.4.pamphlet" 1097974 1097988 1098470 1098475) (-595 "bookvol10.4.pamphlet" 1097704 1097716 1097964 1097969) (-594 "bookvol10.3.pamphlet" 1095496 1095511 1097540 1097665) (-593 "bookvol10.3.pamphlet" 1087922 1087937 1094470 1094567) (-592 "bookvol10.4.pamphlet" 1087405 1087421 1087912 1087917) (-591 "bookvol10.3.pamphlet" 1086635 1086648 1086801 1086828) (-590 "bookvol10.4.pamphlet" 1085715 1085734 1086625 1086630) (-589 "bookvol10.4.pamphlet" 1083679 1083687 1085705 1085710) (-588 "bookvol10.4.pamphlet" 1082202 1082212 1083635 1083640) (-587 "bookvol10.4.pamphlet" 1081803 1081814 1082192 1082197) (-586 "bookvol10.4.pamphlet" 1080149 1080159 1081793 1081798) (-585 "bookvol10.3.pamphlet" 1077894 1077908 1080004 1080031) (-584 "bookvol10.4.pamphlet" 1077030 1077046 1077884 1077889) (-583 "bookvol10.4.pamphlet" 1076171 1076187 1077020 1077025) (-582 "bookvol10.4.pamphlet" 1075931 1075939 1076161 1076166) (-581 "bookvol10.3.pamphlet" 1075624 1075636 1075736 1075829) (-580 "bookvol10.3.pamphlet" 1075385 1075411 1075550 1075619) (-579 "bookvol10.4.pamphlet" 1074994 1075010 1075375 1075380) (-578 "bookvol10.4.pamphlet" 1068240 1068257 1074984 1074989) (-577 "bookvol10.4.pamphlet" 1066099 1066115 1067814 1067819) (-576 "bookvol10.4.pamphlet" 1065405 1065413 1066089 1066094) (-575 "bookvol10.3.pamphlet" 1065181 1065191 1065319 1065400) (-574 "bookvol10.4.pamphlet" 1063545 1063559 1065171 1065176) (-573 "bookvol10.4.pamphlet" 1063034 1063044 1063535 1063540) (-572 "bookvol10.4.pamphlet" 1061679 1061696 1063024 1063029) (-571 "bookvol10.4.pamphlet" 1060042 1060058 1061322 1061327) (-570 "bookvol10.4.pamphlet" 1057769 1057787 1059974 1059979) (-569 "bookvol10.4.pamphlet" 1047876 1047884 1057759 1057764) (-568 "bookvol10.3.pamphlet" 1047237 1047245 1047730 1047871) (-567 "bookvol10.4.pamphlet" 1046503 1046520 1047227 1047232) (-566 "bookvol10.4.pamphlet" 1046168 1046192 1046493 1046498) (-565 "bookvol10.4.pamphlet" 1042569 1042577 1046158 1046163) (-564 "bookvol10.4.pamphlet" 1035949 1035967 1042501 1042506) (-563 "bookvol10.3.pamphlet" 1029947 1029955 1035939 1035944) (-562 "bookvol10.4.pamphlet" 1029047 1029104 1029937 1029942) (-561 "bookvol10.4.pamphlet" 1028121 1028131 1029037 1029042) (-560 "bookvol10.4.pamphlet" 1027989 1028013 1028111 1028116) (-559 "bookvol10.4.pamphlet" 1026303 1026319 1027979 1027984) (-558 "bookvol10.2.pamphlet" 1024927 1024935 1026229 1026298) (-557 NIL 1023613 1023623 1024917 1024922) (-556 "bookvol10.4.pamphlet" 1022743 1022830 1023603 1023608) (-555 "bookvol10.2.pamphlet" 1021206 1021216 1022657 1022738) (-554 "bookvol10.4.pamphlet" 1020709 1020717 1021196 1021201) (-553 "bookvol10.4.pamphlet" 1019891 1019918 1020699 1020704) (-552 "bookvol10.4.pamphlet" 1019383 1019399 1019881 1019886) (-551 "bookvol10.3.pamphlet" 1018463 1018494 1018626 1018653) (-550 "bookvol10.2.pamphlet" 1015859 1015867 1018365 1018458) (-549 NIL 1013341 1013351 1015849 1015854) (-548 "bookvol10.4.pamphlet" 1012775 1012788 1013331 1013336) (-547 "bookvol10.4.pamphlet" 1011841 1011860 1012765 1012770) (-546 "bookvol10.4.pamphlet" 1010899 1010923 1011831 1011836) (-545 "bookvol10.4.pamphlet" 1009885 1009902 1010889 1010894) (-544 "bookvol10.4.pamphlet" 1009032 1009062 1009875 1009880) (-543 "bookvol10.4.pamphlet" 1007317 1007339 1009022 1009027) (-542 "bookvol10.4.pamphlet" 1006367 1006386 1007307 1007312) (-541 "bookvol10.3.pamphlet" 1003411 1003419 1006357 1006362) (-540 "bookvol10.4.pamphlet" 1003036 1003046 1003401 1003406) (-539 "bookvol10.4.pamphlet" 1002624 1002632 1003026 1003031) (-538 "bookvol10.3.pamphlet" 1002005 1002068 1002614 1002619) (-537 "bookvol10.3.pamphlet" 1001411 1001434 1001995 1002000) (-536 "bookvol10.2.pamphlet" 1000034 1000097 1001401 1001406) (-535 "bookvol10.4.pamphlet" 998566 998588 1000024 1000029) (-534 "bookvol10.3.pamphlet" 998472 998489 998556 998561) (-533 "bookvol10.4.pamphlet" 997893 997903 998462 998467) (-532 "bookvol10.4.pamphlet" 993659 993670 997883 997888) (-531 "bookvol10.3.pamphlet" 992791 992817 993303 993330) (-530 "bookvol10.4.pamphlet" 991881 991925 992747 992752) (-529 "bookvol10.4.pamphlet" 990486 990510 991837 991842) (-528 "bookvol10.3.pamphlet" 989365 989380 989892 989919) (-527 "bookvol10.3.pamphlet" 989090 989128 989195 989222) (-526 "bookvol10.3.pamphlet" 988500 988516 988771 988864) (-525 "bookvol10.3.pamphlet" 985571 985586 987906 987933) (-524 "bookvol10.3.pamphlet" 985409 985426 985527 985532) (-523 "bookvol10.2.pamphlet" 984798 984810 985399 985404) (-522 NIL 984185 984199 984788 984793) (-521 "bookvol10.3.pamphlet" 983998 984010 984175 984180) (-520 "bookvol10.3.pamphlet" 983769 983781 983988 983993) (-519 "bookvol10.3.pamphlet" 983504 983516 983759 983764) (-518 "bookvol10.2.pamphlet" 982438 982450 983494 983499) (-517 "bookvol10.3.pamphlet" 982198 982210 982428 982433) (-516 "bookvol10.3.pamphlet" 981960 981972 982188 982193) (-515 "bookvol10.4.pamphlet" 979212 979230 981950 981955) (-514 "bookvol10.3.pamphlet" 974146 974185 979147 979152) (-513 "bookvol10.3.pamphlet" 973567 973590 974136 974141) (-512 "bookvol10.4.pamphlet" 972718 972734 973557 973562) (-511 "bookvol10.3.pamphlet" 971941 971949 972708 972713) (-510 "bookvol10.4.pamphlet" 970564 970581 971931 971936) (-509 "bookvol10.3.pamphlet" 969842 969855 970258 970285) (-508 "bookvol10.4.pamphlet" 966717 966736 969832 969837) (-507 "bookvol10.4.pamphlet" 965605 965620 966707 966712) (-506 "bookvol10.3.pamphlet" 965336 965362 965435 965462) (-505 "bookvol10.3.pamphlet" 964649 964664 964742 964769) (-504 "bookvol10.3.pamphlet" 962862 962870 964465 964558) (-503 "bookvol10.4.pamphlet" 962417 962450 962852 962857) (-502 "bookvol10.2.pamphlet" 961841 961849 962407 962412) (-501 NIL 961263 961273 961831 961836) (-500 "bookvol10.3.pamphlet" 960063 960071 961253 961258) (-499 "bookvol10.2.pamphlet" 957313 957323 960043 960058) (-498 NIL 954404 954416 957136 957141) (-497 "bookvol10.3.pamphlet" 952273 952281 952871 952964) (-496 "bookvol10.4.pamphlet" 951127 951138 952263 952268) (-495 "bookvol10.3.pamphlet" 950717 950741 951117 951122) (-494 "bookvol10.3.pamphlet" 946440 946450 950547 950574) (-493 "bookvol10.3.pamphlet" 938293 938309 938655 938786) (-492 "bookvol10.3.pamphlet" 935484 935499 936087 936214) (-491 "bookvol10.4.pamphlet" 934024 934032 935474 935479) (-490 "bookvol10.3.pamphlet" 933056 933087 933267 933294) (-489 "bookvol10.3.pamphlet" 932641 932649 932958 933051) (-488 "bookvol10.4.pamphlet" 918518 918530 932631 932636) (-487 "bookvol10.4.pamphlet" 918263 918271 918363 918368) (-486 "bookvol10.4.pamphlet" 902336 902372 918133 918138) (-485 "bookvol10.4.pamphlet" 902097 902105 902195 902200) (-484 "bookvol10.4.pamphlet" 901918 901932 902031 902036) (-483 "bookvol10.4.pamphlet" 901795 901809 901908 901913) (-482 "bookvol10.4.pamphlet" 901628 901636 901728 901733) (-481 "bookvol10.3.pamphlet" 900820 900836 901330 901357) (-480 "bookvol10.3.pamphlet" 899901 899936 900075 900090) (-479 "bookvol10.3.pamphlet" 897068 897095 898033 898182) (-478 "bookvol10.2.pamphlet" 896034 896042 897048 897063) (-477 NIL 895008 895018 896024 896029) (-476 "bookvol10.4.pamphlet" 893591 893612 894998 895003) (-475 "bookvol10.2.pamphlet" 892169 892181 893581 893586) (-474 NIL 890745 890759 892159 892164) (-473 "bookvol10.3.pamphlet" 883350 883358 890735 890740) (-472 "bookvol10.4.pamphlet" 881729 881737 883340 883345) (-471 "bookvol10.4.pamphlet" 880172 880180 881719 881724) (-470 "bookvol10.2.pamphlet" 879226 879238 880162 880167) (-469 NIL 878278 878292 879216 879221) (-468 "bookvol10.3.pamphlet" 877788 877811 878016 878043) (-467 "bookvol10.4.pamphlet" 872478 872565 877744 877749) (-466 "bookvol10.4.pamphlet" 871739 871757 872468 872473) (-465 "bookvol10.3.pamphlet" 867687 867695 871729 871734) (-464 "bookvol10.4.pamphlet" 865270 865278 867677 867682) (-463 "bookvol10.3.pamphlet" 864377 864404 865238 865265) (-462 "bookvol10.4.pamphlet" 863487 863501 864367 864372) (-461 "bookvol10.4.pamphlet" 859588 859601 863477 863482) (-460 "bookvol10.4.pamphlet" 859192 859202 859578 859583) (-459 "bookvol10.4.pamphlet" 858776 858793 859182 859187) (-458 "bookvol10.4.pamphlet" 858243 858262 858766 858771) (-457 "bookvol10.4.pamphlet" 856233 856246 858233 858238) (-456 "bookvol10.4.pamphlet" 854490 854498 856223 856228) (-455 "bookvol10.3.pamphlet" 851523 851540 852284 852411) (-454 "bookvol10.3.pamphlet" 845418 845445 851317 851384) (-453 "bookvol10.2.pamphlet" 844346 844354 845344 845413) (-452 NIL 843336 843346 844336 844341) (-451 "bookvol10.4.pamphlet" 837117 837155 843292 843297) (-450 "bookvol10.4.pamphlet" 833215 833253 837107 837112) (-449 "bookvol10.4.pamphlet" 828281 828319 833205 833210) (-448 "bookvol10.4.pamphlet" 824536 824574 828271 828276) (-447 "bookvol10.4.pamphlet" 823833 823841 824526 824531) (-446 "bookvol10.4.pamphlet" 822155 822165 823789 823794) (-445 "bookvol10.4.pamphlet" 820614 820627 822145 822150) (-444 "bookvol10.4.pamphlet" 818779 818798 820604 820609) (-443 "bookvol10.4.pamphlet" 809045 809056 818769 818774) (-442 "bookvol10.2.pamphlet" 806058 806066 809025 809040) (-441 "bookvol10.2.pamphlet" 805100 805108 806038 806053) (-440 "bookvol10.3.pamphlet" 804949 804961 805090 805095) (-439 NIL 803161 803169 804939 804944) (-438 "bookvol10.3.pamphlet" 802324 802332 803151 803156) (-437 "bookvol10.4.pamphlet" 801366 801385 802260 802265) (-436 "bookvol10.3.pamphlet" 799452 799460 801356 801361) (-435 "bookvol10.4.pamphlet" 798874 798890 799442 799447) (-434 "bookvol10.4.pamphlet" 797682 797698 798831 798836) (-433 "bookvol10.4.pamphlet" 794954 794970 797672 797677) (-432 "bookvol10.2.pamphlet" 788988 788998 794717 794949) (-431 NIL 782812 782824 788543 788548) (-430 "bookvol10.4.pamphlet" 782434 782450 782802 782807) (-429 "bookvol10.3.pamphlet" 781742 781754 782254 782353) (-428 "bookvol10.4.pamphlet" 781016 781032 781732 781737) (-427 "bookvol10.2.pamphlet" 780117 780127 780960 781011) (-426 NIL 779192 779204 780037 780042) (-425 "bookvol10.4.pamphlet" 777879 777895 779182 779187) (-424 "bookvol10.4.pamphlet" 772268 772302 777869 777874) (-423 "bookvol10.4.pamphlet" 771878 771894 772258 772263) (-422 "bookvol10.4.pamphlet" 771001 771024 771868 771873) (-421 "bookvol10.4.pamphlet" 769943 769953 770991 770996) (-420 "bookvol10.3.pamphlet" 761367 761377 768967 769036) (-419 "bookvol10.2.pamphlet" 756446 756456 761309 761362) (-418 NIL 751537 751549 756402 756407) (-417 "bookvol10.4.pamphlet" 750983 751001 751527 751532) (-416 "bookvol10.3.pamphlet" 750377 750407 750914 750919) (-415 "bookvol10.3.pamphlet" 749572 749593 750357 750372) (-414 "bookvol10.4.pamphlet" 749308 749340 749562 749567) (-413 "bookvol10.2.pamphlet" 748972 748982 749298 749303) (-412 NIL 748502 748514 748830 748835) (-411 "bookvol10.2.pamphlet" 746830 746843 748458 748497) (-410 NIL 745190 745205 746820 746825) (-409 "bookvol10.3.pamphlet" 742289 742299 742692 742865) (-408 "bookvol10.4.pamphlet" 741892 741904 742279 742284) (-407 "bookvol10.4.pamphlet" 741226 741238 741882 741887) (-406 "bookvol10.2.pamphlet" 738196 738204 741116 741221) (-405 NIL 735194 735204 738116 738121) (-404 "bookvol10.2.pamphlet" 734238 734246 735096 735189) (-403 NIL 733368 733378 734228 734233) (-402 "bookvol10.2.pamphlet" 733120 733130 733348 733363) (-401 "bookvol10.3.pamphlet" 731896 731913 733110 733115) (-400 NIL 730381 730430 731886 731891) (-399 "bookvol10.4.pamphlet" 729310 729318 730371 730376) (-398 "bookvol10.2.pamphlet" 726470 726478 729290 729305) (-397 "bookvol10.2.pamphlet" 726144 726152 726450 726465) (-396 "bookvol10.3.pamphlet" 723482 723490 726134 726139) (-395 "bookvol10.4.pamphlet" 722961 722971 723472 723477) (-394 "bookvol10.4.pamphlet" 722742 722766 722951 722956) (-393 "bookvol10.4.pamphlet" 721943 721951 722732 722737) (-392 "bookvol10.3.pamphlet" 721365 721387 721911 721938) (-391 "bookvol10.2.pamphlet" 719693 719701 721355 721360) (-390 "bookvol10.3.pamphlet" 719585 719593 719683 719688) (-389 "bookvol10.2.pamphlet" 719383 719391 719511 719580) (-388 "bookvol10.3.pamphlet" 716438 716448 719339 719344) (-387 "bookvol10.3.pamphlet" 716133 716145 716372 716399) (-386 "bookvol10.2.pamphlet" 713153 713161 716113 716128) (-385 "bookvol10.2.pamphlet" 712195 712203 713133 713148) (-384 "bookvol10.2.pamphlet" 709899 709917 712163 712190) (-383 "bookvol10.3.pamphlet" 709359 709371 709833 709860) (-382 "bookvol10.4.pamphlet" 707095 707109 709349 709354) (-381 "bookvol10.3.pamphlet" 700516 700524 706961 707090) (-380 "bookvol10.4.pamphlet" 697948 697962 700506 700511) (-379 "bookvol10.2.pamphlet" 697660 697670 697928 697943) (-378 NIL 697326 697338 697596 697601) (-377 "bookvol10.4.pamphlet" 696576 696588 697316 697321) (-376 "bookvol10.2.pamphlet" 694281 694300 696502 696571) (-375 "bookvol10.2.pamphlet" 691279 691289 694249 694276) (-374 NIL 688190 688202 691162 691167) (-373 "bookvol10.4.pamphlet" 686859 686875 688180 688185) (-372 "bookvol10.2.pamphlet" 684892 684905 686815 686854) (-371 NIL 682851 682866 684776 684781) (-370 "bookvol10.2.pamphlet" 682003 682011 682841 682846) (-369 "bookvol10.2.pamphlet" 670932 670942 681945 681998) (-368 NIL 659873 659885 670888 670893) (-367 "bookvol10.3.pamphlet" 659456 659466 659863 659868) (-366 "bookvol10.2.pamphlet" 657885 657902 659446 659451) (-365 "bookvol10.2.pamphlet" 657203 657211 657787 657880) (-364 NIL 656607 656617 657193 657198) (-363 "bookvol10.3.pamphlet" 655216 655226 656587 656602) (-362 "bookvol10.4.pamphlet" 654031 654046 655206 655211) (-361 "bookvol10.3.pamphlet" 653450 653465 653747 653840) (-360 "bookvol10.4.pamphlet" 653315 653332 653440 653445) (-359 "bookvol10.4.pamphlet" 652804 652825 653305 653310) (-358 "bookvol10.4.pamphlet" 644083 644094 652794 652799) (-357 "bookvol10.4.pamphlet" 643129 643146 644073 644078) (-356 "bookvol10.3.pamphlet" 642615 642635 642845 642938) (-355 "bookvol10.3.pamphlet" 642063 642079 642296 642389) (-354 "bookvol10.3.pamphlet" 640581 640601 641779 641872) (-353 "bookvol10.3.pamphlet" 639091 639108 640297 640390) (-352 "bookvol10.3.pamphlet" 637602 637623 638772 638865) (-351 "bookvol10.4.pamphlet" 634964 634983 637592 637597) (-350 "bookvol10.2.pamphlet" 632538 632546 634866 634959) (-349 NIL 630198 630208 632528 632533) (-348 "bookvol10.4.pamphlet" 628943 628960 630188 630193) (-347 "bookvol10.4.pamphlet" 626358 626369 628933 628938) (-346 "bookvol10.4.pamphlet" 619566 619582 626348 626353) (-345 "bookvol10.4.pamphlet" 618181 618200 619556 619561) (-344 "bookvol10.4.pamphlet" 617590 617607 618171 618176) (-343 "bookvol10.3.pamphlet" 616443 616463 617306 617399) (-342 "bookvol10.3.pamphlet" 615338 615358 616159 616252) (-341 "bookvol10.3.pamphlet" 614137 614158 615019 615112) (-340 "bookvol10.2.pamphlet" 602768 602790 613976 614132) (-339 NIL 591478 591502 602688 602693) (-338 "bookvol10.4.pamphlet" 591223 591263 591468 591473) (-337 "bookvol10.3.pamphlet" 583853 583899 590979 591018) (-336 "bookvol10.2.pamphlet" 583559 583569 583843 583848) (-335 NIL 583050 583062 583336 583341) (-334 "bookvol10.3.pamphlet" 582483 582507 583040 583045) (-333 "bookvol10.2.pamphlet" 580525 580549 582473 582478) (-332 NIL 578565 578591 580515 580520) (-331 "bookvol10.4.pamphlet" 578309 578349 578555 578560) (-330 "bookvol10.4.pamphlet" 576830 576838 578299 578304) (-329 "bookvol10.3.pamphlet" 576359 576369 576820 576825) (-328 NIL 566184 566192 576349 576354) (-327 "bookvol10.2.pamphlet" 559057 559071 566086 566179) (-326 NIL 551982 551998 559013 559018) (-325 "bookvol10.3.pamphlet" 550396 550406 551388 551415) (-324 "bookvol10.2.pamphlet" 548516 548528 550294 550391) (-323 NIL 546620 546634 548400 548405) (-322 "bookvol10.4.pamphlet" 546170 546192 546610 546615) (-321 "bookvol10.3.pamphlet" 545820 545830 546124 546129) (-320 "bookvol10.2.pamphlet" 544011 544023 545810 545815) (-319 "bookvol10.3.pamphlet" 543617 543627 543907 543934) (-318 "bookvol10.4.pamphlet" 541813 541830 543607 543612) (-317 "bookvol10.4.pamphlet" 541695 541705 541803 541808) (-316 "bookvol10.4.pamphlet" 540871 540881 541685 541690) (-315 "bookvol10.4.pamphlet" 540753 540763 540861 540866) (-314 "bookvol10.3.pamphlet" 537586 537609 538885 539034) (-313 "bookvol10.4.pamphlet" 534950 534958 537576 537581) (-312 "bookvol10.4.pamphlet" 534852 534881 534940 534945) (-311 "bookvol10.4.pamphlet" 531660 531676 534842 534847) (-310 "bookvol10.3.pamphlet" 526909 526919 527649 528056) (-309 "bookvol10.4.pamphlet" 522969 522982 526899 526904) (-308 "bookvol10.4.pamphlet" 522729 522741 522959 522964) (-307 "bookvol10.3.pamphlet" 519667 519692 520301 520394) (-306 "bookvol10.4.pamphlet" 519520 519528 519657 519662) (-305 "bookvol10.3.pamphlet" 519187 519195 519510 519515) (-304 "bookvol10.4.pamphlet" 518677 518691 519177 519182) (-303 "bookvol10.2.pamphlet" 518241 518251 518667 518672) (-302 NIL 517803 517815 518231 518236) (-301 "bookvol10.2.pamphlet" 515337 515345 517729 517798) (-300 NIL 512933 512943 515327 515332) (-299 "bookvol10.4.pamphlet" 504773 504781 512923 512928) (-298 "bookvol10.4.pamphlet" 504358 504372 504763 504768) (-297 "bookvol10.4.pamphlet" 504035 504046 504348 504353) (-296 "bookvol10.2.pamphlet" 496582 496590 504025 504030) (-295 NIL 489035 489045 496480 496485) (-294 "bookvol10.4.pamphlet" 485808 485816 489025 489030) (-293 "bookvol10.4.pamphlet" 485549 485561 485798 485803) (-292 "bookvol10.4.pamphlet" 485044 485060 485539 485544) (-291 "bookvol10.4.pamphlet" 484610 484626 485034 485039) (-290 "bookvol10.4.pamphlet" 481984 481992 484600 484605) (-289 "bookvol10.3.pamphlet" 481018 481040 481227 481254) (-288 "bookvol10.3.pamphlet" 475876 475886 478691 478803) (-287 "bookvol10.4.pamphlet" 475592 475604 475866 475871) (-286 "bookvol10.4.pamphlet" 471906 471916 475582 475587) (-285 "bookvol10.2.pamphlet" 471448 471456 471850 471901) (-284 "bookvol10.3.pamphlet" 470628 470669 471374 471443) (-283 "bookvol10.2.pamphlet" 468882 468901 470618 470623) (-282 NIL 467100 467121 468838 468843) (-281 "bookvol10.2.pamphlet" 466564 466582 467090 467095) (-280 "bookvol10.4.pamphlet" 465943 465962 466554 466559) (-279 "bookvol10.2.pamphlet" 465632 465640 465933 465938) (-278 NIL 465319 465329 465622 465627) (-277 "bookvol10.2.pamphlet" 463023 463033 465287 465314) (-276 NIL 460676 460688 462942 462947) (-275 "bookvol10.4.pamphlet" 457467 457497 460632 460637) (-274 "bookvol10.4.pamphlet" 454318 454341 457423 457428) (-273 "bookvol10.4.pamphlet" 452273 452289 454308 454313) (-272 "bookvol10.4.pamphlet" 447039 447055 452263 452268) (-271 "bookvol10.3.pamphlet" 445315 445323 447029 447034) (-270 "bookvol10.3.pamphlet" 444851 444859 445305 445310) (-269 "bookvol10.3.pamphlet" 444428 444436 444841 444846) (-268 "bookvol10.3.pamphlet" 444008 444016 444418 444423) (-267 "bookvol10.3.pamphlet" 443544 443552 443998 444003) (-266 "bookvol10.3.pamphlet" 443080 443088 443534 443539) (-265 "bookvol10.3.pamphlet" 442616 442624 443070 443075) (-264 "bookvol10.3.pamphlet" 442152 442160 442606 442611) (-263 "bookvol10.4.pamphlet" 437768 437776 442142 442147) (-262 "bookvol10.2.pamphlet" 434449 434459 437758 437763) (-261 NIL 431128 431140 434439 434444) (-260 "bookvol10.4.pamphlet" 428108 428195 431118 431123) (-259 "bookvol10.3.pamphlet" 427278 427288 427938 427965) (-258 "bookvol10.2.pamphlet" 426866 426876 427234 427273) (-257 "bookvol10.3.pamphlet" 424309 424323 424602 424729) (-256 "bookvol10.3.pamphlet" 418254 418262 424299 424304) (-255 "bookvol10.4.pamphlet" 417915 417925 418244 418249) (-254 "bookvol10.4.pamphlet" 412740 412748 417905 417910) (-253 "bookvol10.4.pamphlet" 410895 410903 412730 412735) (-252 "bookvol10.4.pamphlet" 403495 403508 410885 410890) (-251 "bookvol10.4.pamphlet" 402748 402758 403485 403490) (-250 "bookvol10.4.pamphlet" 400103 400111 402738 402743) (-249 "bookvol10.4.pamphlet" 399640 399655 400093 400098) (-248 "bookvol10.4.pamphlet" 388812 388820 399630 399635) (-247 "bookvol10.2.pamphlet" 386964 386974 388768 388807) (-246 "bookvol10.2.pamphlet" 382305 382321 386832 386959) (-245 NIL 377732 377750 382261 382266) (-244 "bookvol10.3.pamphlet" 371091 371107 371229 371530) (-243 "bookvol10.3.pamphlet" 364463 364481 364588 364889) (-242 "bookvol10.3.pamphlet" 361700 361715 362257 362384) (-241 "bookvol10.4.pamphlet" 361044 361054 361690 361695) (-240 "bookvol10.3.pamphlet" 359679 359689 360450 360477) (-239 "bookvol10.2.pamphlet" 358072 358082 359659 359674) (-238 "bookvol10.2.pamphlet" 357519 357527 358016 358067) (-237 NIL 357010 357020 357509 357514) (-236 "bookvol10.3.pamphlet" 356863 356873 356942 356969) (-235 "bookvol10.2.pamphlet" 355622 355632 356831 356858) (-234 "bookvol10.4.pamphlet" 353802 353810 355612 355617) (-233 "bookvol10.3.pamphlet" 353094 353109 353638 353763) (-232 "bookvol10.3.pamphlet" 344684 344700 345309 345440) (-231 "bookvol10.4.pamphlet" 343507 343525 344674 344679) (-230 "bookvol10.2.pamphlet" 342669 342685 343359 343502) (-229 NIL 341572 341590 342264 342269) (-228 "bookvol10.4.pamphlet" 340375 340383 341562 341567) (-227 "bookvol10.2.pamphlet" 339347 339357 340343 340370) (-226 NIL 338305 338317 339303 339308) (-225 "bookvol10.2.pamphlet" 337418 337426 338285 338300) (-224 NIL 336539 336549 337408 337413) (-223 "bookvol10.2.pamphlet" 335698 335708 336519 336534) (-222 NIL 334774 334786 335597 335602) (-221 "bookvol10.2.pamphlet" 334392 334402 334742 334769) (-220 NIL 334030 334042 334382 334387) (-219 "bookvol10.3.pamphlet" 332238 332248 333674 333701) (-218 "bookvol10.3.pamphlet" 330966 330974 331362 331389) (-217 "bookvol10.4.pamphlet" 322208 322216 330956 330961) (-216 "bookvol10.3.pamphlet" 321411 321419 321840 321867) (-215 "bookvol10.3.pamphlet" 317688 317696 321301 321406) (-214 "bookvol10.4.pamphlet" 315897 315913 317678 317683) (-213 "bookvol10.3.pamphlet" 313807 313839 315877 315892) (-212 "bookvol10.3.pamphlet" 307481 307491 313637 313664) (-211 "bookvol10.4.pamphlet" 307094 307108 307471 307476) (-210 "bookvol10.4.pamphlet" 304575 304585 307084 307089) (-209 "bookvol10.4.pamphlet" 303071 303087 304565 304570) (-208 "bookvol10.3.pamphlet" 300952 300960 301538 301631) (-207 "bookvol10.4.pamphlet" 298803 298820 300942 300947) (-206 "bookvol10.4.pamphlet" 298401 298425 298793 298798) (-205 "bookvol10.3.pamphlet" 296988 296998 298391 298396) (-204 "bookvol10.3.pamphlet" 296816 296824 296978 296983) (-203 "bookvol10.3.pamphlet" 296636 296644 296806 296811) (-202 "bookvol10.4.pamphlet" 295575 295583 296626 296631) (-201 "bookvol10.3.pamphlet" 295037 295045 295565 295570) (-200 "bookvol10.3.pamphlet" 294515 294523 295027 295032) (-199 "bookvol10.3.pamphlet" 294005 294013 294505 294510) (-198 "bookvol10.3.pamphlet" 293495 293503 293995 294000) (-197 "bookvol10.4.pamphlet" 288337 288345 293485 293490) (-196 "bookvol10.4.pamphlet" 286656 286664 288327 288332) (-195 "bookvol10.3.pamphlet" 286633 286641 286646 286651) (-194 "bookvol10.3.pamphlet" 286155 286163 286623 286628) (-193 "bookvol10.3.pamphlet" 285677 285685 286145 286150) (-192 "bookvol10.3.pamphlet" 285145 285153 285667 285672) (-191 "bookvol10.3.pamphlet" 284630 284638 285135 285140) (-190 "bookvol10.3.pamphlet" 284054 284062 284620 284625) (-189 "bookvol10.3.pamphlet" 283548 283556 284044 284049) (-188 "bookvol10.3.pamphlet" 283058 283066 283538 283543) (-187 "bookvol10.3.pamphlet" 282598 282606 283048 283053) (-186 "bookvol10.3.pamphlet" 282124 282132 282588 282593) (-185 "bookvol10.3.pamphlet" 281647 281655 282114 282119) (-184 "bookvol10.4.pamphlet" 277706 277714 281637 281642) (-183 "bookvol10.4.pamphlet" 277210 277218 277696 277701) (-182 "bookvol10.4.pamphlet" 274027 274035 277200 277205) (-181 "bookvol10.4.pamphlet" 273442 273452 274017 274022) (-180 "bookvol10.4.pamphlet" 271932 271948 273432 273437) (-179 "bookvol10.4.pamphlet" 270601 270614 271922 271927) (-178 "bookvol10.4.pamphlet" 264428 264441 270591 270596) (-177 "bookvol10.4.pamphlet" 263467 263477 264418 264423) (-176 "bookvol10.4.pamphlet" 262967 262982 263392 263397) (-175 "bookvol10.4.pamphlet" 262672 262691 262957 262962) (-174 "bookvol10.4.pamphlet" 257565 257575 262662 262667) (-173 "bookvol10.3.pamphlet" 253300 253310 257467 257560) (-172 "bookvol10.2.pamphlet" 252975 252983 253238 253295) (-171 "bookvol10.3.pamphlet" 252471 252479 252965 252970) (-170 "bookvol10.4.pamphlet" 252238 252253 252461 252466) (-169 "bookvol10.3.pamphlet" 246262 246272 246505 246766) (-168 "bookvol10.4.pamphlet" 245975 245987 246252 246257) (-167 "bookvol10.4.pamphlet" 245771 245785 245965 245970) (-166 "bookvol10.2.pamphlet" 243827 243837 245493 245766) (-165 NIL 241587 241599 243255 243260) (-164 "bookvol10.4.pamphlet" 241333 241351 241577 241582) (-163 "bookvol10.4.pamphlet" 240866 240874 241323 241328) (-162 "bookvol10.3.pamphlet" 240673 240681 240856 240861) (-161 "bookvol10.2.pamphlet" 239578 239586 240663 240668) (-160 "bookvol10.4.pamphlet" 238076 238086 239568 239573) (-159 "bookvol10.4.pamphlet" 235336 235352 238066 238071) (-158 "bookvol10.3.pamphlet" 234173 234181 235326 235331) (-157 "bookvol10.4.pamphlet" 233505 233522 234163 234168) (-156 "bookvol10.4.pamphlet" 229569 229577 233495 233500) (-155 "bookvol10.3.pamphlet" 228222 228238 229525 229564) (-154 "bookvol10.2.pamphlet" 224493 224503 228202 228217) (-153 NIL 220645 220657 224356 224361) (-152 "bookvol10.4.pamphlet" 219970 219983 220635 220640) (-151 "bookvol10.4.pamphlet" 218048 218070 219960 219965) (-150 "bookvol10.2.pamphlet" 217963 217971 218028 218043) (-149 "bookvol10.4.pamphlet" 217471 217481 217953 217958) (-148 "bookvol10.2.pamphlet" 217224 217232 217451 217466) (-147 "bookvol10.3.pamphlet" 212724 212732 217214 217219) (-146 "bookvol10.2.pamphlet" 211905 211913 212714 212719) (-145 "bookvol10.3.pamphlet" 210142 210150 210843 210870) (-144 "bookvol10.3.pamphlet" 209260 209268 209698 209725) (-143 "bookvol10.4.pamphlet" 208418 208432 209250 209255) (-142 "bookvol10.3.pamphlet" 206781 206789 207887 207926) (-141 "bookvol10.3.pamphlet" 196438 196462 206771 206776) (-140 "bookvol10.4.pamphlet" 195824 195851 196428 196433) (-139 "bookvol10.3.pamphlet" 192160 192168 195798 195819) (-138 "bookvol10.2.pamphlet" 191782 191790 192150 192155) (-137 "bookvol10.2.pamphlet" 191293 191301 191772 191777) (-136 "bookvol10.3.pamphlet" 190311 190321 191123 191150) (-135 "bookvol10.3.pamphlet" 189505 189515 190141 190168) (-134 "bookvol10.2.pamphlet" 188869 188879 189461 189500) (-133 NIL 188265 188277 188859 188864) (-132 "bookvol10.2.pamphlet" 187330 187338 188221 188260) (-131 NIL 186427 186437 187320 187325) (-130 "bookvol10.3.pamphlet" 184947 184957 186257 186284) (-129 "bookvol10.4.pamphlet" 183710 183721 184937 184942) (-128 "bookvol10.2.pamphlet" 182624 182634 183690 183705) (-127 NIL 181512 181524 182580 182585) (-126 "bookvol10.3.pamphlet" 179493 179505 179748 179841) (-125 "bookvol10.3.pamphlet" 179157 179169 179419 179488) (-124 "bookvol10.4.pamphlet" 178813 178830 179147 179152) (-123 "bookvol10.3.pamphlet" 174205 174213 178803 178808) (-122 "bookvol10.4.pamphlet" 171583 171593 174161 174166) (-121 "bookvol10.3.pamphlet" 170477 170485 171573 171578) (-120 "bookvol10.2.pamphlet" 170135 170147 170445 170472) (-119 "bookvol10.4.pamphlet" 168341 168377 170125 170130) (-118 "bookvol10.3.pamphlet" 168231 168239 168306 168336) (-117 "bookvol10.2.pamphlet" 168208 168216 168221 168226) (-116 "bookvol10.3.pamphlet" 168100 168108 168175 168203) (-115 "bookvol10.5.pamphlet" 165464 165472 168090 168095) (-114 "bookvol10.3.pamphlet" 164941 164949 165158 165185) (-113 "bookvol10.3.pamphlet" 164284 164292 164931 164936) (-112 "bookvol10.3.pamphlet" 162124 162132 162751 162844) (-111 "bookvol10.2.pamphlet" 161309 161319 162092 162119) (-110 NIL 160514 160526 161299 161304) (-109 "bookvol10.3.pamphlet" 159935 159943 160494 160509) (-108 "bookvol10.4.pamphlet" 159069 159096 159885 159890) (-107 "bookvol10.4.pamphlet" 156390 156400 159059 159064) (-106 "bookvol10.3.pamphlet" 151452 151462 156220 156247) (-105 "bookvol10.2.pamphlet" 151124 151132 151442 151447) (-104 NIL 150794 150804 151114 151119) (-103 "bookvol10.4.pamphlet" 150233 150246 150784 150789) (-102 "bookvol10.4.pamphlet" 150093 150101 150223 150228) (-101 "bookvol10.3.pamphlet" 149539 149549 150073 150088) (-100 "bookvol10.2.pamphlet" 146136 146144 149279 149534) (-99 "bookvol10.3.pamphlet" 142171 142178 146116 146131) (-98 "bookvol10.2.pamphlet" 141641 141648 142161 142166) (-97 NIL 141109 141118 141631 141636) (-96 "bookvol10.3.pamphlet" 136401 136410 140939 140966) (-95 "bookvol10.4.pamphlet" 135201 135212 136357 136362) (-94 "bookvol10.3.pamphlet" 134272 134285 135191 135196) (-93 "bookvol10.3.pamphlet" 132761 132774 134262 134267) (-92 "bookvol10.3.pamphlet" 131881 131894 132751 132756) (-91 "bookvol10.3.pamphlet" 130849 130862 131871 131876) (-90 "bookvol10.3.pamphlet" 130224 130237 130839 130844) (-89 "bookvol10.3.pamphlet" 129429 129442 130214 130219) (-88 "bookvol10.3.pamphlet" 128082 128095 129419 129424) (-87 "bookvol10.3.pamphlet" 127173 127186 128072 128077) (-86 "bookvol10.3.pamphlet" 125295 125308 127163 127168) (-85 "bookvol10.3.pamphlet" 123012 123025 125285 125290) (-84 "bookvol10.3.pamphlet" 119204 119217 123002 123007) (-83 "bookvol10.3.pamphlet" 118345 118358 119194 119199) (-82 "bookvol10.3.pamphlet" 116982 116995 118335 118340) (-81 "bookvol10.3.pamphlet" 114334 114373 116972 116977) (-80 "bookvol10.3.pamphlet" 112008 112047 114324 114329) (-79 "bookvol10.3.pamphlet" 110645 110658 111998 112003) (-78 "bookvol10.3.pamphlet" 109384 109397 110635 110640) (-77 "bookvol10.3.pamphlet" 108898 108911 109374 109379) (-76 "bookvol10.3.pamphlet" 107694 107707 108888 108893) (-75 "bookvol10.3.pamphlet" 105698 105711 107684 107689) (-74 "bookvol10.3.pamphlet" 105008 105021 105688 105693) (-73 "bookvol10.3.pamphlet" 92049 92062 104998 105003) (-72 "bookvol10.3.pamphlet" 90155 90168 92039 92044) (-71 "bookvol10.3.pamphlet" 88878 88891 90145 90150) (-70 "bookvol10.3.pamphlet" 87729 87742 88868 88873) (-69 "bookvol10.3.pamphlet" 87043 87056 87719 87724) (-68 "bookvol10.3.pamphlet" 77536 77549 87033 87038) (-67 "bookvol10.3.pamphlet" 76838 76851 77526 77531) (-66 "bookvol10.3.pamphlet" 75953 75966 76828 76833) (-65 "bookvol10.3.pamphlet" 75551 75560 75783 75810) (-64 "bookvol10.3.pamphlet" 74439 74448 74957 74984) (-63 "bookvol10.4.pamphlet" 72262 72273 74429 74434) (-62 "bookvol10.2.pamphlet" 64788 64809 72218 72257) (-61 NIL 57346 57369 64778 64783) (-60 "bookvol10.4.pamphlet" 56590 56612 57336 57341) (-59 "bookvol10.4.pamphlet" 56205 56218 56580 56585) (-58 "bookvol10.4.pamphlet" 55592 55599 56195 56200) (-57 "bookvol10.3.pamphlet" 53934 53941 55582 55587) (-56 "bookvol10.4.pamphlet" 53005 53014 53924 53929) (-55 "bookvol10.3.pamphlet" 51444 51460 52985 53000) (-54 "bookvol10.3.pamphlet" 51357 51364 51434 51439) (-53 "bookvol10.3.pamphlet" 49658 49665 51173 51266) (-52 "bookvol10.2.pamphlet" 47837 47848 49556 49653) (-51 NIL 45853 45866 47574 47579) (-50 "bookvol10.3.pamphlet" 43897 43918 44247 44274) (-49 "bookvol10.3.pamphlet" 43020 43046 43769 43822) (-48 "bookvol10.4.pamphlet" 38807 38818 42976 42981) (-47 "bookvol10.4.pamphlet" 37996 38010 38797 38802) (-46 "bookvol10.4.pamphlet" 35416 35431 37793 37798) (-45 "bookvol10.3.pamphlet" 33730 33757 33948 34104) (-44 "bookvol10.4.pamphlet" 32843 32853 33720 33725) (-43 "bookvol10.2.pamphlet" 32295 32304 32799 32838) (-42 NIL 31779 31790 32285 32290) (-41 "bookvol10.2.pamphlet" 31277 31298 31735 31774) (-40 "bookvol10.2.pamphlet" 30658 30665 31267 31272) (-39 "bookvol10.2.pamphlet" 28939 28946 30638 30653) (-38 NIL 27194 27203 28895 28900) (-37 "bookvol10.2.pamphlet" 24922 24931 27184 27189) (-36 "bookvol10.4.pamphlet" 23347 23362 24857 24862) (-35 "bookvol10.3.pamphlet" 23190 23205 23337 23342) (-34 "bookvol10.3.pamphlet" 23039 23048 23180 23185) (-33 "bookvol10.3.pamphlet" 22888 22897 23029 23034) (-32 "bookvol10.4.pamphlet" 22771 22809 22878 22883) (-31 "bookvol10.4.pamphlet" 22304 22342 22761 22766) (-30 "bookvol10.3.pamphlet" 20372 20379 22294 22299) (-29 "bookvol10.2.pamphlet" 18103 18112 20262 20367) (-28 NIL 15932 15943 18093 18098) (-27 "bookvol10.2.pamphlet" 10604 10611 15834 15927) (-26 NIL 5362 5371 10594 10599) (-25 "bookvol10.2.pamphlet" 4706 4713 5352 5357) (-24 NIL 4048 4057 4696 4701) (-23 "bookvol10.2.pamphlet" 3399 3406 4038 4043) (-22 NIL 2748 2757 3389 3394) (-21 "bookvol10.2.pamphlet" 2236 2243 2738 2743) (-20 NIL 1722 1731 2226 2231) (-19 "bookvol10.2.pamphlet" 860 869 1678 1717) (-18 NIL 30 41 850 855)) 
\ No newline at end of file
diff --git a/src/share/algebra/category.daase b/src/share/algebra/category.daase
index 9a32aac..9ec0f20 100644
--- a/src/share/algebra/category.daase
+++ b/src/share/algebra/category.daase
@@ -1,14 +1,14 @@
 
-(155805 . 3487447485)        
-(((|#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) |has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) 
+(155805 . 3488060047)        
+(((|#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) |has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) 
 (((|#2| |#2|) . T)) 
 ((((-568)) . T)) 
-((($ $) -2198 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) ((|#2| |#2|) . T) (((-409 (-568)) (-409 (-568))) |has| |#2| (-43 (-409 (-568))))) 
+((($ $) -2199 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) ((|#2| |#2|) . T) (((-409 (-568)) (-409 (-568))) |has| |#2| (-43 (-409 (-568))))) 
 ((($) . T)) 
 (((|#1|) . T)) 
 ((($) . T) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (((|#2|) . T)) 
-((($) -2198 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) ((|#2|) . T) (((-409 (-568))) |has| |#2| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) ((|#2|) . T) (((-409 (-568))) |has| |#2| (-43 (-409 (-568))))) 
 (|has| |#1| (-904)) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
@@ -26,29 +26,29 @@
 ((((-215)) . T) (((-850)) . T)) 
 (((|#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 (((|#1|) . T)) 
-(-2198 (|has| |#1| (-21)) (|has| |#1| (-840))) 
-((($ $) . T) (((-409 (-568)) (-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-350))) ((|#1| |#1|) . T)) 
-(-2198 (|has| |#1| (-815)) (|has| |#1| (-842))) 
+(-2199 (|has| |#1| (-21)) (|has| |#1| (-840))) 
+((($ $) . T) (((-409 (-568)) (-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-350))) ((|#1| |#1|) . T)) 
+(-2199 (|has| |#1| (-815)) (|has| |#1| (-842))) 
 ((((-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) (((-568)) |has| |#1| (-1037 (-568))) ((|#1|) . T)) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-558))) 
 (|has| |#1| (-840)) 
 (((|#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 (((|#1| |#2| |#3|) . T)) 
 (((|#4|) . T)) 
-((($) . T) (((-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-350))) ((|#1|) . T)) 
+((($) . T) (((-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-350))) ((|#1|) . T)) 
 (((|#1| (-763) (-1075)) . T)) 
 ((((-850)) . T)) 
 ((((-850)) |has| |#1| (-1090))) 
 (((|#1|) . T) ((|#2|) . T)) 
 (((|#1|) . T) (((-568)) |has| |#1| (-1037 (-568))) (((-409 (-568))) |has| |#1| (-1037 (-409 (-568))))) 
-(-2198 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
-(((|#2| (-493 (-1697 |#1|) (-763))) . T)) 
+(-2199 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(((|#2| (-493 (-1699 |#1|) (-763))) . T)) 
 (((|#1| (-534 (-1161))) . T)) 
 ((((-864 |#1|) (-864 |#1|)) . T) (((-409 (-568)) (-409 (-568))) . T) (($ $) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 (|has| |#1| (-1181)) 
 (|has| |#4| (-370)) 
 (|has| |#3| (-370)) 
@@ -59,10 +59,10 @@
 (|has| |#1| (-148)) 
 (|has| |#1| (-150)) 
 (|has| |#1| (-558)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-558))) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-558))) 
 ((($) . T)) 
-((((-850)) -2198 (|has| |#1| (-842)) (|has| |#1| (-1090)))) 
+((((-850)) -2199 (|has| |#1| (-842)) (|has| |#1| (-1090)))) 
 ((((-541)) |has| |#1| (-609 (-541)))) 
 ((($) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) . T)) 
 ((((-169 (-215)) (-145) (-145)) . T)) 
@@ -84,52 +84,52 @@
 ((((-850)) . T)) 
 (((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) (($) . T)) 
 (((|#1|) . T)) 
-((((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (((-1235 |#1| |#2| |#3|)) |has| |#1| (-365)) (($) . T) ((|#1|) . T)) 
-(((|#1|) . T) (((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) . T)) 
-((((-409 (-568)) (-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2| |#2|) . T) (($ $) -2198 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
+((((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (((-1235 |#1| |#2| |#3|)) |has| |#1| (-365)) (($) . T) ((|#1|) . T)) 
+(((|#1|) . T) (((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) . T)) 
+((((-409 (-568)) (-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2| |#2|) . T) (($ $) -2199 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
 (((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) (($) . T)) 
 (((|#1|) . T)) 
-(-2198 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
-((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) |has| |#2| (-172)) (($) -2198 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
-((($) -2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+(-2199 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
+((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) |has| |#2| (-172)) (($) -2199 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
+((($) -2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (((|#1|) . T) (((-409 (-568))) . T) (($) . T)) 
 (((|#1|) . T) (((-409 (-568))) . T) (($) . T)) 
 (((|#1|) . T) (((-409 (-568))) . T) (($) . T)) 
-((((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1| |#1|) . T) (($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904)))) 
+((((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1| |#1|) . T) (($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904)))) 
 ((($ $) . T)) 
 (((|#2|) . T)) 
-((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) . T) (($) -2198 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
-((((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) . T) (($) -2198 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904)))) 
+((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) . T) (($) -2199 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
+((((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) . T) (($) -2199 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904)))) 
 ((($) . T)) 
 (|has| |#1| (-370)) 
 (((|#1|) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 (((|#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
 (((|#1| |#2|) . T)) 
-(-2198 (|has| |#1| (-21)) (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047))) 
-(-2198 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047))) 
+(-2199 (|has| |#1| (-21)) (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047))) 
+(-2199 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047))) 
 (((|#1| |#1|) . T)) 
 (|has| |#1| (-558)) 
 (((|#2| |#2|) -12 (|has| |#1| (-365)) (|has| |#2| (-303 |#2|))) (((-1161) |#2|) -12 (|has| |#1| (-365)) (|has| |#2| (-523 (-1161) |#2|)))) 
 ((((-409 |#2|)) . T) (((-409 (-568))) . T) (($) . T)) 
-(-2198 (|has| |#1| (-21)) (|has| |#1| (-840))) 
+(-2199 (|has| |#1| (-21)) (|has| |#1| (-840))) 
 ((($ $) . T) (((-409 (-568)) (-409 (-568))) . T)) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) 
-(-2198 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
 (|has| |#1| (-1090)) 
-(-2198 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
+(-2199 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
 (|has| |#1| (-1090)) 
-(-2198 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
+(-2199 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
 (|has| |#1| (-840)) 
 ((($) . T) (((-409 (-568))) . T)) 
 (((|#1|) . T)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-350))) 
-(-2198 (|has| |#4| (-788)) (|has| |#4| (-840))) 
-(-2198 (|has| |#4| (-788)) (|has| |#4| (-840))) 
-(-2198 (|has| |#3| (-788)) (|has| |#3| (-840))) 
-(-2198 (|has| |#3| (-788)) (|has| |#3| (-840))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-350))) 
+(-2199 (|has| |#4| (-788)) (|has| |#4| (-840))) 
+(-2199 (|has| |#4| (-788)) (|has| |#4| (-840))) 
+(-2199 (|has| |#3| (-788)) (|has| |#3| (-840))) 
+(-2199 (|has| |#3| (-788)) (|has| |#3| (-840))) 
 (((|#1| |#2|) . T)) 
 (((|#1| |#2|) . T)) 
 (|has| |#2| (-365)) 
@@ -144,10 +144,10 @@
 ((((-568)) . T)) 
 ((((-568)) . T)) 
 (((|#1|) . T)) 
-(-2198 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047)) SEQ) 
+(-2199 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047)) SEQ) 
 (((|#1| (-763)) . T)) 
 (|has| |#2| (-788)) 
-(-2198 (|has| |#2| (-788)) (|has| |#2| (-840))) 
+(-2199 (|has| |#2| (-788)) (|has| |#2| (-840))) 
 (|has| |#2| (-840)) 
 (((|#1|) . T)) 
 (((|#1| |#2| |#3| |#4|) . T)) 
@@ -158,8 +158,8 @@
 (((|#3| (-763)) . T)) 
 (|has| |#1| (-150)) 
 (|has| |#1| (-148)) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) 
 (|has| |#1| (-1090)) 
 ((((-409 (-568))) . T) (((-568)) . T)) 
 ((((-1161) |#2|) |has| |#2| (-523 (-1161) |#2|)) ((|#2| |#2|) |has| |#2| (-303 |#2|))) 
@@ -167,7 +167,7 @@
 (((|#1|) . T) (($) . T)) 
 ((((-568)) . T)) 
 ((((-568)) . T)) 
-((($) -2198 (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) ((|#1|) |has| |#1| (-172))) 
+((($) -2199 (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) ((|#1|) |has| |#1| (-172))) 
 ((((-568)) . T)) 
 ((((-568)) . T)) 
 ((((-688) (-1157 (-688))) . T)) 
@@ -188,12 +188,12 @@
 ((((-850)) . T)) 
 ((((-850)) . T)) 
 (((|#1| |#1|) . T)) 
-((((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1| |#1|) . T) (($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904)))) 
-((($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1| |#1|) . T) (($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904)))) 
+((($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (((|#1|) . T)) 
-((((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) . T) (($) -2198 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904)))) 
-((($) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
-((($) -2198 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047))) ((|#2|) -2198 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-1047)))) 
+((((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) . T) (($) -2199 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904)))) 
+((($) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047))) ((|#2|) -2199 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-1047)))) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
@@ -204,31 +204,31 @@
 ((((-850)) . T)) 
 (((|#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 (((|#1|) . T)) 
-(-2198 (|has| |#1| (-21)) (|has| |#1| (-840))) 
-(-2198 (|has| |#1| (-21)) (|has| |#1| (-840))) 
-((((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2198 (|has| |#1| (-365)) (|has| |#1| (-558))) ((|#2|) |has| |#1| (-365)) ((|#1|) |has| |#1| (-172))) 
+(-2199 (|has| |#1| (-21)) (|has| |#1| (-840))) 
+(-2199 (|has| |#1| (-21)) (|has| |#1| (-840))) 
+((((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2199 (|has| |#1| (-365)) (|has| |#1| (-558))) ((|#2|) |has| |#1| (-365)) ((|#1|) |has| |#1| (-172))) 
 (|has| |#2| (-558)) 
 (|has| |#1| (-365)) 
-(((|#1|) |has| |#1| (-172)) (((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2198 (|has| |#1| (-365)) (|has| |#1| (-558)))) 
+(((|#1|) |has| |#1| (-172)) (((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2199 (|has| |#1| (-365)) (|has| |#1| (-558)))) 
 ((((-857 |#1|) (-774 (-857 |#1|))) . T)) 
 (((|#1| |#1|) |has| |#1| (-172)) (($ $) |has| |#1| (-172))) 
 (-12 (|has| |#4| (-225)) (|has| |#4| (-1047))) 
 (-12 (|has| |#3| (-225)) (|has| |#3| (-1047))) 
 (((|#1|) |has| |#1| (-172)) (($) |has| |#1| (-172))) 
-(-2198 (|has| |#4| (-172)) (|has| |#4| (-840)) (|has| |#4| (-1047))) 
-(-2198 (|has| |#3| (-172)) (|has| |#3| (-840)) (|has| |#3| (-1047))) 
+(-2199 (|has| |#4| (-172)) (|has| |#4| (-840)) (|has| |#4| (-1047))) 
+(-2199 (|has| |#3| (-172)) (|has| |#3| (-840)) (|has| |#3| (-1047))) 
 ((((-850)) . T)) 
 (((|#1|) . T)) 
 ((((-1161)) |has| |#2| (-895 (-1161))) (((-1075)) . T)) 
 ((((-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) (((-568)) |has| |#1| (-1037 (-568))) ((|#1|) . T)) 
 (((|#1|) . T) (((-568)) |has| |#1| (-630 (-568)))) 
-(((|#2|) . T) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
-(((|#1|) . T) (((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) . T)) 
+(((|#2|) . T) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
+(((|#1|) . T) (((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) . T)) 
 (|has| |#1| (-558)) 
 (|has| |#1| (-558)) 
 (((|#1|) . T)) 
 (((|#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
-(-2198 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
+(-2199 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
 (((|#1|) . T)) 
 (|has| |#1| (-558)) 
 (|has| |#1| (-558)) 
@@ -239,11 +239,11 @@
 (-12 (|has| |#1| (-1002)) (|has| |#1| (-1181))) 
 (((|#2|) . T) (($) . T) (((-409 (-568))) . T)) 
 ((($) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) . T)) 
-((((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (((-1159 |#1| |#2| |#3|)) |has| |#1| (-365)) (($) . T) ((|#1|) . T)) 
-(((|#1|) . T) (((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) . T)) 
+((((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (((-1159 |#1| |#2| |#3|)) |has| |#1| (-365)) (($) . T) ((|#1|) . T)) 
+(((|#1|) . T) (((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) . T)) 
 (((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) (($) . T)) 
-(((|#4| |#4|) -2198 (|has| |#4| (-172)) (|has| |#4| (-365)) (|has| |#4| (-1047))) (($ $) |has| |#4| (-172))) 
-(((|#3| |#3|) -2198 (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-1047))) (($ $) |has| |#3| (-172))) 
+(((|#4| |#4|) -2199 (|has| |#4| (-172)) (|has| |#4| (-365)) (|has| |#4| (-1047))) (($ $) |has| |#4| (-172))) 
+(((|#3| |#3|) -2199 (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-1047))) (($ $) |has| |#3| (-172))) 
 (((|#2|) . T)) 
 (((|#1|) . T)) 
 ((((-541)) |has| |#2| (-609 (-541))) (((-887 (-381))) |has| |#2| (-609 (-887 (-381)))) (((-887 (-568))) |has| |#2| (-609 (-887 (-568))))) 
@@ -252,22 +252,22 @@
 ((((-850)) . T)) 
 ((((-541)) |has| |#1| (-609 (-541))) (((-887 (-381))) |has| |#1| (-609 (-887 (-381)))) (((-887 (-568))) |has| |#1| (-609 (-887 (-568))))) 
 ((((-850)) . T)) 
-(((|#4|) -2198 (|has| |#4| (-172)) (|has| |#4| (-365)) (|has| |#4| (-1047))) (($) |has| |#4| (-172))) 
-(((|#3|) -2198 (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-1047))) (($) |has| |#3| (-172))) 
+(((|#4|) -2199 (|has| |#4| (-172)) (|has| |#4| (-365)) (|has| |#4| (-1047))) (($) |has| |#4| (-172))) 
+(((|#3|) -2199 (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-1047))) (($) |has| |#3| (-172))) 
 ((((-850)) . T)) 
 ((((-541)) . T) (((-568)) . T) (((-887 (-568))) . T) (((-381)) . T) (((-215)) . T)) 
 ((((-1075)) . T) ((|#2|) . T) (((-568)) |has| |#2| (-1037 (-568))) (((-409 (-568))) |has| |#2| (-1037 (-409 (-568))))) 
 (((|#1|) . T) (((-568)) |has| |#1| (-1037 (-568))) (((-409 (-568))) |has| |#1| (-1037 (-409 (-568))))) 
 ((($) . T) (((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) . T)) 
 ((((-409 $) (-409 $)) |has| |#2| (-558)) (($ $) . T) ((|#2| |#2|) . T)) 
-((((-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) . T)) 
+((((-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) . T)) 
 (((|#1|) . T)) 
 (|has| |#2| (-904)) 
 ((((-1143) (-57)) . T)) 
 ((((-568)) |has| (-409 |#2|) (-630 (-568))) (((-409 |#2|)) . T)) 
 ((((-541)) . T) (((-215)) . T) (((-381)) . T) (((-887 (-381))) . T)) 
 ((((-850)) . T)) 
-(-2198 (|has| |#1| (-21)) (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047))) 
+(-2199 (|has| |#1| (-21)) (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047))) 
 (((|#1|) |has| |#1| (-172))) 
 (|has| |#1| (-43 (-409 (-568)))) 
 (|has| |#1| (-43 (-409 (-568)))) 
@@ -282,14 +282,14 @@
 (|has| |#1| (-43 (-409 (-568)))) 
 (|has| |#1| (-1090)) 
 (((|#1|) . T)) 
-((((-850)) -2198 (|has| |#1| (-842)) (|has| |#1| (-1090)))) 
+((((-850)) -2199 (|has| |#1| (-842)) (|has| |#1| (-1090)))) 
 ((((-541)) |has| |#1| (-609 (-541)))) 
-((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) |has| |#2| (-172)) (($) -2198 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
+((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) |has| |#2| (-172)) (($) -2199 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
 (((|#2| (-763)) . T)) 
-((($) -2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
-((($) -2198 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (|has| |#1| (-225)) 
-((($) -2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (((|#1| (-534 (-813 (-1161)))) . T)) 
 (((|#1| (-972)) . T)) 
 ((((-864 |#1|) $) |has| (-864 |#1|) (-281 (-864 |#1|) (-864 |#1|)))) 
@@ -299,7 +299,7 @@
 (((|#2| |#2|) . T)) 
 (|has| |#1| (-1136)) 
 (((|#1| (-763) (-1075)) . T)) 
-((((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) . T)) 
+((((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) . T)) 
 (|has| (-1229 |#1| |#2| |#3| |#4|) (-148)) 
 (|has| (-1229 |#1| |#2| |#3| |#4|) (-150)) 
 (|has| |#1| (-148)) 
@@ -318,20 +318,20 @@
 ((($) . T) ((|#1|) . T)) 
 (((|#2|) |has| |#2| (-1047))) 
 ((((-850)) . T)) 
-(((|#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) |has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) 
+(((|#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) |has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) 
 (((|#1|) . T)) 
-(((|#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) (((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) |has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-303 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))))) 
+(((|#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) (((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) |has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-303 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))))) 
 ((((-568) |#1|) . T)) 
 ((((-850)) . T)) 
 ((((-541)) -12 (|has| |#1| (-609 (-541))) (|has| |#2| (-609 (-541)))) (((-887 (-381))) -12 (|has| |#1| (-609 (-887 (-381)))) (|has| |#2| (-609 (-887 (-381))))) (((-887 (-568))) -12 (|has| |#1| (-609 (-887 (-568)))) (|has| |#2| (-609 (-887 (-568)))))) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
 ((($) . T)) 
-((($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 ((($) . T)) 
 ((($) . T)) 
 ((($) . T)) 
-((($) -2198 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
 (|has| (-1228 |#2| |#3| |#4|) (-150)) 
@@ -342,16 +342,16 @@
 ((((-850)) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
-(-2198 (|has| |#1| (-21)) (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047))) 
+(-2199 (|has| |#1| (-21)) (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047))) 
 (((|#1|) . T)) 
 ((((-568) |#1|) . T)) 
 (((|#2|) |has| |#2| (-172))) 
 (((|#1|) |has| |#1| (-172))) 
 (((|#1|) . T)) 
-(-2198 (|has| |#1| (-21)) (|has| |#1| (-840))) 
+(-2199 (|has| |#1| (-21)) (|has| |#1| (-840))) 
 ((((-850)) |has| |#1| (-1090))) 
-(-2198 (|has| |#1| (-478)) (|has| |#1| (-716)) (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047)) (|has| |#1| (-1102))) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-350))) 
+(-2199 (|has| |#1| (-478)) (|has| |#1| (-716)) (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047)) (|has| |#1| (-1102))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-350))) 
 (|has| |#1| (-150)) 
 (|has| |#1| (-148)) 
 ((((-905 |#1|)) . T)) 
@@ -366,7 +366,7 @@
 ((((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) |has| |#1| (-172)) (($) |has| |#1| (-558))) 
 (|has| |#1| (-15 * (|#1| (-763) |#1|))) 
 (|has| |#1| (-365)) 
-(-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|)))) 
+(-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|)))) 
 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) 
 ((((-568)) . T)) 
 (|has| |#1| (-365)) 
@@ -378,10 +378,10 @@
 (((|#1|) . T)) 
 ((((-568) |#1|) . T)) 
 (((|#2|) . T)) 
-(-2198 (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
+(-2199 (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
 ((((-2 (|:| |k| (-568)) (|:| |c| |#1|))) . T)) 
-(-2198 (|has| |#2| (-788)) (|has| |#2| (-840))) 
-(-2198 (|has| |#2| (-788)) (|has| |#2| (-840))) 
+(-2199 (|has| |#2| (-788)) (|has| |#2| (-840))) 
+(-2199 (|has| |#2| (-788)) (|has| |#2| (-840))) 
 (((|#1|) . T)) 
 (|has| |#2| (-148)) 
 (|has| |#2| (-150)) 
@@ -389,26 +389,26 @@
 (((|#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 ((((-850)) . T)) 
 (-12 (|has| |#1| (-365)) (|has| |#2| (-815))) 
-(-2198 (|has| |#1| (-301)) (|has| |#1| (-365)) (|has| |#1| (-350)) (|has| |#1| (-558))) 
-((((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1| |#1|) . T) (($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-558)))) 
+(-2199 (|has| |#1| (-301)) (|has| |#1| (-365)) (|has| |#1| (-350)) (|has| |#1| (-558))) 
+((((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1| |#1|) . T) (($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-558)))) 
 ((($ $) |has| |#1| (-558))) 
 ((((-688) (-1157 (-688))) . T)) 
 ((((-850)) . T)) 
 ((((-850)) . T) (((-1244 |#4|)) . T)) 
 ((((-850)) . T) (((-1244 |#3|)) . T)) 
-((((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) . T) (($) -2198 (|has| |#1| (-172)) (|has| |#1| (-558)))) 
+((((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) . T) (($) -2199 (|has| |#1| (-172)) (|has| |#1| (-558)))) 
 ((($) |has| |#1| (-558))) 
 ((((-850)) . T)) 
 ((($) . T)) 
-((($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
-((($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568)) (-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (((-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|)) |has| |#1| (-365)) ((|#1| |#1|) . T)) 
-(((|#1| |#1|) . T) (($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568)) (-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365)))) 
-((($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
-((($) -2198 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
-((($) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (((-1235 |#1| |#2| |#3|)) |has| |#1| (-365)) ((|#1|) . T)) 
+((($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568)) (-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (((-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|)) |has| |#1| (-365)) ((|#1| |#1|) . T)) 
+(((|#1| |#1|) . T) (($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568)) (-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365)))) 
+((($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (((-1235 |#1| |#2| |#3|)) |has| |#1| (-365)) ((|#1|) . T)) 
 (((|#3|) |has| |#3| (-1047))) 
-(((|#1|) . T) (($) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365)))) 
-((($) -2198 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+(((|#1|) . T) (($) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365)))) 
+((($) -2199 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (|has| |#1| (-1090)) 
 (((|#2| (-814 |#1|)) . T)) 
 (((|#1|) . T)) 
@@ -420,42 +420,42 @@
 ((((-147)) . T)) 
 (((|#3|) |has| |#3| (-1090)) (((-568)) -12 (|has| |#3| (-1037 (-568))) (|has| |#3| (-1090))) (((-409 (-568))) -12 (|has| |#3| (-1037 (-409 (-568)))) (|has| |#3| (-1090)))) 
 ((((-850)) . T)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-904))) 
 ((((-409 (-568))) . T) (($) . T)) 
 ((((-409 (-568))) . T) (($) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 (((|#1|) . T)) 
-((((-850)) -2198 (|has| |#1| (-842)) (|has| |#1| (-1090)))) 
+((((-850)) -2199 (|has| |#1| (-842)) (|has| |#1| (-1090)))) 
 ((((-541)) |has| |#1| (-609 (-541)))) 
-((((-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) . T)) 
+((((-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) . T)) 
 (|has| |#1| (-365)) 
-(-2198 (|has| |#1| (-21)) (|has| |#1| (-840))) 
+(-2199 (|has| |#1| (-21)) (|has| |#1| (-840))) 
 ((((-1161) |#1|) |has| |#1| (-523 (-1161) |#1|)) ((|#1| |#1|) |has| |#1| (-303 |#1|))) 
 (|has| |#2| (-815)) 
 (|has| |#1| (-43 (-409 (-568)))) 
 (|has| |#1| (-840)) 
-(-2198 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
+(-2199 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
 ((((-850)) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 ((((-541)) |has| |#1| (-609 (-541)))) 
 (((|#1| |#2|) . T)) 
 ((((-1161)) -12 (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))))) 
 ((((-1143) |#1|) . T)) 
 (((|#1| |#2| |#3| (-534 |#3|)) . T)) 
 ((((-917) |#1|) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 (|has| |#1| (-370)) 
 (|has| |#1| (-370)) 
 (|has| |#1| (-370)) 
 ((((-850)) . T)) 
 (((|#1|) . T)) 
-(-2198 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
+(-2199 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
 (((|#1| |#2|) . T)) 
 (|has| |#1| (-370)) 
-(-2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
 ((((-568)) . T)) 
 ((((-568)) . T)) 
-(-2198 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
+(-2199 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
 ((((-850)) . T)) 
 (((|#2|) . T)) 
 ((((-850)) . T)) 
@@ -465,7 +465,7 @@
 ((((-568) |#4|) . T)) 
 ((((-568) |#3|) . T)) 
 (((|#1|) . T) (((-568)) |has| |#1| (-630 (-568)))) 
-(-2198 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
+(-2199 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
 ((((-1229 |#1| |#2| |#3| |#4|)) . T)) 
 ((((-409 (-568))) . T) (((-568)) . T)) 
 ((((-850)) |has| |#1| (-1090))) 
@@ -497,38 +497,38 @@
 ((($) . T)) 
 ((($ $) . T) (((-1161) $) . T) (((-1161) |#1|) . T)) 
 (((|#2|) |has| |#2| (-172))) 
-((($) -2198 (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) ((|#2|) |has| |#2| (-172)) (((-409 (-568))) |has| |#2| (-43 (-409 (-568))))) 
-(((|#2| |#2|) -2198 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-1047))) (($ $) |has| |#2| (-172))) 
+((($) -2199 (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) ((|#2|) |has| |#2| (-172)) (((-409 (-568))) |has| |#2| (-43 (-409 (-568))))) 
+(((|#2| |#2|) -2199 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-1047))) (($ $) |has| |#2| (-172))) 
 ((((-147)) . T)) 
 (((|#1|) . T)) 
 (-12 (|has| |#1| (-370)) (|has| |#2| (-370))) 
 ((((-850)) . T)) 
-(((|#2|) -2198 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-1047))) (($) |has| |#2| (-172))) 
+(((|#2|) -2199 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-1047))) (($) |has| |#2| (-172))) 
 (((|#1|) . T)) 
 ((((-850)) . T)) 
 (|has| |#1| (-1090)) 
 (|has| $ (-150)) 
-((((-857 |#1|) |#2| (-242 |#2| (-857 |#1|)) (-232 (-1697 |#2|) (-763)) (-967 |#1|) (-774 (-857 |#1|)) (-922 |#1|) (-236 (-922 |#1|)) |#3|) . T)) 
+((((-857 |#1|) |#2| (-242 |#2| (-857 |#1|)) (-232 (-1699 |#2|) (-763)) (-967 |#1|) (-774 (-857 |#1|)) (-922 |#1|) (-236 (-922 |#1|)) |#3|) . T)) 
 ((((-568) |#1|) . T)) 
-((($) -2198 (|has| |#1| (-301)) (|has| |#1| (-365)) (|has| |#1| (-350)) (|has| |#1| (-558))) (((-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-350))) ((|#1|) . T)) 
+((($) -2199 (|has| |#1| (-301)) (|has| |#1| (-365)) (|has| |#1| (-350)) (|has| |#1| (-558))) (((-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-350))) ((|#1|) . T)) 
 ((((-1161)) -12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) 
 (|has| |#1| (-365)) 
-(-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|)))) 
+(-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|)))) 
 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) 
 (|has| |#1| (-365)) 
 (|has| |#1| (-15 * (|#1| (-763) |#1|))) 
 (((|#1|) . T)) 
-(-2198 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
+(-2199 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
 ((((-850)) . T)) 
 (((|#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
-(-2198 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
+(-2199 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
 (((|#2| (-534 (-852 |#1|))) . T)) 
 ((((-850)) . T)) 
 (((|#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 (((|#1|) . T)) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
-(-2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
 ((((-581 |#1|)) . T)) 
 ((($) . T)) 
 (|has| |#1| (-1181)) 
@@ -550,30 +550,30 @@
 ((((-850)) . T)) 
 ((((-850)) . T)) 
 (((|#1| |#2| |#3| |#4| |#5|) . T)) 
-((((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1| |#1|) . T) (($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-558)))) 
-((($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568)) (-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (((-1159 |#1| |#2| |#3|) (-1159 |#1| |#2| |#3|)) |has| |#1| (-365)) ((|#1| |#1|) . T)) 
-(((|#1| |#1|) . T) (($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568)) (-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365)))) 
-((($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1| |#1|) . T) (($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-558)))) 
+((($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568)) (-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (((-1159 |#1| |#2| |#3|) (-1159 |#1| |#2| |#3|)) |has| |#1| (-365)) ((|#1| |#1|) . T)) 
+(((|#1| |#1|) . T) (($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568)) (-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365)))) 
+((($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (((|#2|) |has| |#2| (-1047))) 
 (|has| |#1| (-1090)) 
-((((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) . T) (($) -2198 (|has| |#1| (-172)) (|has| |#1| (-558)))) 
+((((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) . T) (($) -2199 (|has| |#1| (-172)) (|has| |#1| (-558)))) 
 (|has| |#1| (-172)) 
-((($) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (((-1159 |#1| |#2| |#3|)) |has| |#1| (-365)) ((|#1|) . T)) 
-(((|#1|) . T) (($) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365)))) 
-((($) -2198 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (((-1159 |#1| |#2| |#3|)) |has| |#1| (-365)) ((|#1|) . T)) 
+(((|#1|) . T) (($) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365)))) 
+((($) -2199 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (((|#1|) |has| |#1| (-172)) (($) . T)) 
 (((|#1|) . T)) 
-((((-409 (-568)) (-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2| |#2|) . T) (($ $) -2198 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
+((((-409 (-568)) (-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2| |#2|) . T) (($ $) -2199 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
 ((((-850)) . T)) 
-((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) |has| |#2| (-172)) (($) -2198 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
+((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) |has| |#2| (-172)) (($) -2199 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
 ((($) . T) ((|#2|) . T) (((-409 (-568))) |has| |#2| (-43 (-409 (-568))))) 
 ((($ $) . T) ((|#2| $) . T) ((|#2| |#1|) . T)) 
-((((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) |has| |#1| (-172)) (($) -2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904)))) 
+((((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) |has| |#1| (-172)) (($) -2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904)))) 
 ((((-1075) |#1|) . T) (((-1075) $) . T) (($ $) . T)) 
-((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) . T) (($) -2198 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
+((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) . T) (($) -2199 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
 ((($) . T)) 
 (((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) (($) . T)) 
-(-2198 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
+(-2199 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
 (((|#2|) |has| |#1| (-365))) 
 (((|#1|) . T)) 
 (|has| |#2| (-904)) 
@@ -589,8 +589,8 @@
 (|has| |#1| (-43 (-409 (-568)))) 
 (|has| |#1| (-148)) 
 (|has| |#1| (-150)) 
-((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) |has| |#2| (-172)) (($) -2198 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
-((($) -2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) |has| |#2| (-172)) (($) -2199 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
+((($) -2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 ((((-409 (-568))) . T) (($) . T)) 
 ((((-409 (-568))) . T) (($) . T)) 
 ((((-409 (-568))) . T) (($) . T)) 
@@ -601,12 +601,12 @@
 (((|#1| (-763) (-1075)) . T)) 
 ((((-409 (-568))) |has| |#2| (-365)) (($) . T)) 
 (((|#1| (-534 (-1079 (-1161))) (-1079 (-1161))) . T)) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
 (((|#1|) . T)) 
-(-2198 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047)) SEQ) 
+(-2199 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047)) SEQ) 
 (|has| |#2| (-788)) 
-(-2198 (|has| |#2| (-788)) (|has| |#2| (-840))) 
+(-2199 (|has| |#2| (-788)) (|has| |#2| (-840))) 
 (|has| |#1| (-370)) 
 (|has| |#1| (-370)) 
 (|has| |#1| (-370)) 
@@ -642,30 +642,30 @@
 (((|#4| |#4|) -12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) 
 (((|#2|) . T) (((-568)) |has| |#2| (-1037 (-568))) (((-409 (-568))) |has| |#2| (-1037 (-409 (-568))))) 
 (((|#3| |#3|) -12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) 
-(((|#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) |has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) 
+(((|#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) |has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) 
 (((|#1|) . T)) 
 (((|#1| |#2|) . T)) 
 ((($) . T)) 
 ((($) . T)) 
 (((|#2|) . T)) 
 (((|#3|) . T)) 
-(-2198 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
-(((|#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) |has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) 
+(-2199 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
+(((|#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) |has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) 
 (((|#2|) . T)) 
-((((-850)) -2198 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-370)) (|has| |#2| (-716)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047)) (|has| |#2| (-1090))) (((-1244 |#2|)) . T)) 
+((((-850)) -2199 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-370)) (|has| |#2| (-716)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047)) (|has| |#2| (-1090))) (((-1244 |#2|)) . T)) 
 (((|#1|) |has| |#1| (-172))) 
 ((((-568)) . T)) 
-((((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) |has| |#1| (-172)) (($) -2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904)))) 
-((($) -2198 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) |has| |#1| (-172)) (($) -2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904)))) 
+((($) -2199 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 ((((-568) (-147)) . T)) 
-((($) -2198 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047))) ((|#2|) -2198 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-1047)))) 
-(-2198 (|has| |#1| (-21)) (|has| |#1| (-148)) (|has| |#1| (-150)) (|has| |#1| (-172)) (|has| |#1| (-558)) (|has| |#1| (-1047))) 
+((($) -2199 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047))) ((|#2|) -2199 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-1047)))) 
+(-2199 (|has| |#1| (-21)) (|has| |#1| (-148)) (|has| |#1| (-150)) (|has| |#1| (-172)) (|has| |#1| (-558)) (|has| |#1| (-1047))) 
 (((|#1|) . T)) 
-(-2198 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-148)) (|has| |#1| (-150)) (|has| |#1| (-172)) (|has| |#1| (-558)) (|has| |#1| (-1047))) 
+(-2199 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-148)) (|has| |#1| (-150)) (|has| |#1| (-172)) (|has| |#1| (-558)) (|has| |#1| (-1047))) 
 (((|#2|) |has| |#1| (-365))) 
 (((|#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 (((|#1| |#1|) . T) (($ $) . T)) 
-((($) -2198 (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) ((|#1|) |has| |#1| (-172))) 
+((($) -2199 (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) ((|#1|) |has| |#1| (-172))) 
 (((|#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 ((($) . T) (((-409 (-568))) . T) ((|#1|) |has| |#1| (-172))) 
 ((($) . T) (((-409 (-568))) . T)) 
@@ -674,34 +674,34 @@
 (|has| |#4| (-172)) 
 (|has| |#3| (-172)) 
 ((((-409 (-953 |#1|)) (-409 (-953 |#1|))) . T)) 
-(-2198 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
+(-2199 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
 (|has| |#1| (-1090)) 
-(-2198 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
+(-2199 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
 (|has| |#1| (-1090)) 
-((((-850)) -2198 (|has| |#1| (-842)) (|has| |#1| (-1090)))) 
+((((-850)) -2199 (|has| |#1| (-842)) (|has| |#1| (-1090)))) 
 ((((-541)) |has| |#1| (-609 (-541)))) 
-(-2198 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
+(-2199 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
 (((|#1|) |has| |#1| (-172)) (($) |has| |#1| (-172))) 
 (((|#1| |#1|) |has| |#1| (-172))) 
 ((((-860)) . T) (((-409 (-568))) . T)) 
 ((((-409 (-568))) . T)) 
-((($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 ((((-409 (-953 |#1|))) . T)) 
 (((|#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 (((|#1|) . T)) 
 (((|#1|) |has| |#1| (-172))) 
-((($) -2198 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
-(-2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+((($) -2199 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+(-2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
 ((((-850)) . T)) 
 ((((-1229 |#1| |#2| |#3| |#4|)) . T)) 
 (((|#1|) |has| |#1| (-1047)) (((-568)) -12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047)))) 
 (((|#1| |#2|) . T)) 
-(-2198 (|has| |#3| (-172)) (|has| |#3| (-840)) (|has| |#3| (-1047)) SEQ) 
+(-2199 (|has| |#3| (-172)) (|has| |#3| (-840)) (|has| |#3| (-1047)) SEQ) 
 (|has| |#3| (-788)) 
-(-2198 (|has| |#3| (-788)) (|has| |#3| (-840))) 
+(-2199 (|has| |#3| (-788)) (|has| |#3| (-840))) 
 (|has| |#3| (-840)) 
-((((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2198 (|has| |#1| (-365)) (|has| |#1| (-558))) ((|#2|) |has| |#1| (-365)) ((|#1|) |has| |#1| (-172))) 
-(((|#1|) |has| |#1| (-172)) (((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2198 (|has| |#1| (-365)) (|has| |#1| (-558)))) 
+((((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2199 (|has| |#1| (-365)) (|has| |#1| (-558))) ((|#2|) |has| |#1| (-365)) ((|#1|) |has| |#1| (-172))) 
+(((|#1|) |has| |#1| (-172)) (((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2199 (|has| |#1| (-365)) (|has| |#1| (-558)))) 
 (((|#2|) . T)) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
@@ -717,22 +717,22 @@
 (|has| |#1| (-1090)) 
 (((|#2|) . T)) 
 ((((-541)) |has| |#2| (-609 (-541))) (((-887 (-381))) |has| |#2| (-609 (-887 (-381)))) (((-887 (-568))) |has| |#2| (-609 (-887 (-568))))) 
-(((|#4|) -2198 (|has| |#4| (-172)) (|has| |#4| (-365)))) 
-(((|#3|) -2198 (|has| |#3| (-172)) (|has| |#3| (-365)))) 
+(((|#4|) -2199 (|has| |#4| (-172)) (|has| |#4| (-365)))) 
+(((|#3|) -2199 (|has| |#3| (-172)) (|has| |#3| (-365)))) 
 ((((-850)) . T)) 
 (((|#1|) . T)) 
-(-2198 (|has| |#2| (-453)) (|has| |#2| (-904))) 
-(-2198 (|has| |#1| (-453)) (|has| |#1| (-904))) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-904))) 
+(-2199 (|has| |#2| (-453)) (|has| |#2| (-904))) 
+(-2199 (|has| |#1| (-453)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-904))) 
 ((($ $) . T) (((-1161) $) |has| |#1| (-225)) (((-1161) |#1|) |has| |#1| (-225)) (((-813 (-1161)) |#1|) . T) (((-813 (-1161)) $) . T)) 
-(-2198 (|has| |#1| (-453)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-453)) (|has| |#1| (-904))) 
 ((((-568) |#2|) . T)) 
 ((((-850)) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 (((|#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
-((($) -2198 (|has| |#3| (-172)) (|has| |#3| (-840)) (|has| |#3| (-1047))) ((|#3|) -2198 (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-1047)))) 
+((($) -2199 (|has| |#3| (-172)) (|has| |#3| (-840)) (|has| |#3| (-1047))) ((|#3|) -2199 (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-1047)))) 
 ((((-568) |#1|) . T)) 
 (|has| (-409 |#2|) (-150)) 
 (|has| (-409 |#2|) (-148)) 
@@ -745,22 +745,22 @@
 (|has| |#1| (-558)) 
 (|has| |#1| (-43 (-409 (-568)))) 
 (|has| |#1| (-43 (-409 (-568)))) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 ((((-850)) . T)) 
-((((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) . T)) 
+((((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) . T)) 
 (|has| |#1| (-43 (-409 (-568)))) 
-((((-390) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) . T)) 
+((((-390) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) . T)) 
 (|has| |#1| (-43 (-409 (-568)))) 
 (|has| |#2| (-1136)) 
 (|has| |#1| (-558)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-558))) 
 (((|#1|) . T)) 
 ((((-390) (-1143)) . T)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-558))) 
 (|has| |#1| (-558)) 
 ((((-125 |#1|)) . T)) 
 ((((-568) |#1|) . T)) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
 (((|#2|) . T)) 
 ((((-850)) . T)) 
 (((|#2|) |has| |#2| (-1047)) (((-568)) -12 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047)))) 
@@ -774,7 +774,7 @@
 (((|#1|) |has| |#1| (-172))) 
 ((((-850)) . T)) 
 ((((-541)) |has| |#1| (-609 (-541)))) 
-(-2198 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
+(-2199 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
 (((|#2|) |has| |#2| (-303 |#2|))) 
 ((((-568) (-568)) . T) (((-409 (-568)) (-409 (-568))) . T) (($ $) . T)) 
 (((|#1|) . T)) 
@@ -784,7 +784,7 @@
 ((((-568) (-568)) . T) (((-409 (-568)) (-409 (-568))) . T) (($ $) . T)) 
 ((($) . T) (((-568)) . T) (((-409 (-568))) . T)) 
 (|has| |#2| (-370)) 
-(-2198 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
+(-2199 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
 (((|#1|) . T) (((-409 (-568))) . T) (($) . T)) 
 (((|#1|) . T) (((-409 (-568))) . T) (($) . T)) 
 (((|#1|) . T) (((-409 (-568))) . T) (($) . T)) 
@@ -795,7 +795,7 @@
 ((((-1159 |#1| |#2| |#3|) $) -12 (|has| (-1159 |#1| |#2| |#3|) (-281 (-1159 |#1| |#2| |#3|) (-1159 |#1| |#2| |#3|))) (|has| |#1| (-365))) (($ $) . T)) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
-((($) . T) (((-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-350))) ((|#1|) . T)) 
+((($) . T) (((-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-350))) ((|#1|) . T)) 
 ((((-541)) |has| |#1| (-609 (-541)))) 
 ((((-850)) |has| |#1| (-1090))) 
 ((($ $) . T)) 
@@ -806,13 +806,13 @@
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
-((($) -2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 ((((-409 (-568))) . T) (((-568)) . T)) 
 ((((-568) (-147)) . T)) 
 ((((-147)) . T)) 
 (((|#1|) . T)) 
 (|has| |#1| (-842)) 
-(-2198 (|has| |#1| (-21)) (|has| |#1| (-148)) (|has| |#1| (-150)) (|has| |#1| (-172)) (|has| |#1| (-558)) (|has| |#1| (-1047))) 
+(-2199 (|has| |#1| (-21)) (|has| |#1| (-148)) (|has| |#1| (-150)) (|has| |#1| (-172)) (|has| |#1| (-558)) (|has| |#1| (-1047))) 
 ((((-121)) . T)) 
 (((|#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 ((((-121)) . T)) 
@@ -820,49 +820,49 @@
 ((((-541)) |has| |#1| (-609 (-541))) (((-215)) |has| |#1| (-1021)) (((-381)) |has| |#1| (-1021))) 
 ((((-850)) . T)) 
 (|has| |#1| (-815)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
 (|has| |#1| (-842)) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-558))) 
 (|has| |#1| (-558)) 
 (|has| |#1| (-43 (-409 (-568)))) 
 (|has| |#1| (-904)) 
 (((|#1|) . T)) 
 (|has| |#1| (-1090)) 
 ((((-850)) . T)) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-558))) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-558))) 
 (((|#1| (-1244 |#1|) (-1244 |#1|)) . T)) 
 ((((-568) (-147)) . T)) 
 ((($) . T)) 
-(-2198 (|has| |#4| (-172)) (|has| |#4| (-840)) (|has| |#4| (-1047))) 
-(-2198 (|has| |#3| (-172)) (|has| |#3| (-840)) (|has| |#3| (-1047))) 
+(-2199 (|has| |#4| (-172)) (|has| |#4| (-840)) (|has| |#4| (-1047))) 
+(-2199 (|has| |#3| (-172)) (|has| |#3| (-840)) (|has| |#3| (-1047))) 
 (((|#2| (-763)) . T)) 
 ((((-850)) . T)) 
 (|has| |#1| (-1090)) 
 (((|#1| (-972)) . T)) 
 (((|#1| |#1|) . T)) 
 (|has| (-409 (-568)) (-148)) 
-(-2198 (|has| |#2| (-788)) (|has| |#2| (-840))) 
-(-2198 (|has| |#2| (-788)) (|has| |#2| (-840))) 
+(-2199 (|has| |#2| (-788)) (|has| |#2| (-840))) 
+(-2199 (|has| |#2| (-788)) (|has| |#2| (-840))) 
 (|has| (-409 (-568)) (-148)) 
 (((|#1| (-568)) . T)) 
 ((($) . T)) 
-(-2198 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047)) SEQ) 
+(-2199 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047)) SEQ) 
 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) 
 (((|#1|) . T)) 
 (|has| |#2| (-788)) 
-(-2198 (|has| |#2| (-788)) (|has| |#2| (-840))) 
+(-2199 (|has| |#2| (-788)) (|has| |#2| (-840))) 
 (((|#1| |#2|) . T)) 
 (((|#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 (|has| |#2| (-840)) 
 (-12 (|has| |#1| (-788)) (|has| |#2| (-788))) 
 (-12 (|has| |#1| (-788)) (|has| |#2| (-788))) 
-(-2198 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) (-12 (|has| |#1| (-716)) (|has| |#2| (-716)))) 
+(-2199 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) (-12 (|has| |#1| (-716)) (|has| |#2| (-716)))) 
 (((|#1| |#2|) . T)) 
 (((|#2|) |has| |#2| (-172))) 
 (((|#1|) |has| |#1| (-172))) 
@@ -872,7 +872,7 @@
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 ((((-409 (-568))) . T) (($) . T)) 
-((($) . T) (((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) ((|#1|) . T)) 
+((($) . T) (((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) ((|#1|) . T)) 
 (|has| |#1| (-823)) 
 ((((-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) (((-568)) |has| |#1| (-1037 (-568))) ((|#1|) . T)) 
 (|has| |#1| (-1090)) 
@@ -884,9 +884,9 @@
 (|has| |#3| (-370)) 
 (((|#1|) . T) (((-850)) . T)) 
 ((($) |has| |#1| (-558)) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
-((((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2198 (|has| |#1| (-365)) (|has| |#1| (-558))) (((-1235 |#1| |#2| |#3|)) |has| |#1| (-365)) ((|#1|) |has| |#1| (-172))) 
+((((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2199 (|has| |#1| (-365)) (|has| |#1| (-558))) (((-1235 |#1| |#2| |#3|)) |has| |#1| (-365)) ((|#1|) |has| |#1| (-172))) 
 ((((-850)) . T)) 
-(((|#1|) |has| |#1| (-172)) (((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2198 (|has| |#1| (-365)) (|has| |#1| (-558)))) 
+(((|#1|) |has| |#1| (-172)) (((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2199 (|has| |#1| (-365)) (|has| |#1| (-558)))) 
 ((($) |has| |#1| (-558)) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (((|#2|) . T)) 
 (((|#1| |#1|) |has| |#1| (-172))) 
@@ -895,33 +895,33 @@
 (((|#1|) . T)) 
 (((|#1|) |has| |#1| (-172))) 
 ((((-409 (-568))) . T) (((-568)) . T)) 
-((($ $) -2198 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) ((|#2| |#2|) . T) (((-409 (-568)) (-409 (-568))) |has| |#2| (-43 (-409 (-568))))) 
-((($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
-((($) -2198 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) ((|#2|) . T) (((-409 (-568))) |has| |#2| (-43 (-409 (-568))))) 
-((($) -2198 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($ $) -2199 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) ((|#2| |#2|) . T) (((-409 (-568)) (-409 (-568))) |has| |#2| (-43 (-409 (-568))))) 
+((($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) ((|#2|) . T) (((-409 (-568))) |has| |#2| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (((|#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) 
 ((((-147)) . T)) 
 (((|#1|) . T)) 
 ((((-147)) . T)) 
-((($) -2198 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047))) ((|#2|) -2198 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-1047)))) 
+((($) -2199 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047))) ((|#2|) -2199 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-1047)))) 
 ((((-147)) . T)) 
 (((|#1| |#2| |#3|) . T)) 
-(-2198 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-148)) (|has| |#1| (-150)) (|has| |#1| (-172)) (|has| |#1| (-558)) (|has| |#1| (-1047))) 
+(-2199 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-148)) (|has| |#1| (-150)) (|has| |#1| (-172)) (|has| |#1| (-558)) (|has| |#1| (-1047))) 
 (|has| $ (-150)) 
 (|has| $ (-150)) 
 (|has| |#1| (-1090)) 
 ((((-850)) . T)) 
 (|has| |#1| (-43 (-409 (-568)))) 
 (|has| |#1| (-43 (-409 (-568)))) 
-(-2198 (|has| |#1| (-148)) (|has| |#1| (-150)) (|has| |#1| (-172)) (|has| |#1| (-478)) (|has| |#1| (-558)) (|has| |#1| (-1047)) (|has| |#1| (-1102))) 
+(-2199 (|has| |#1| (-148)) (|has| |#1| (-150)) (|has| |#1| (-172)) (|has| |#1| (-478)) (|has| |#1| (-558)) (|has| |#1| (-1047)) (|has| |#1| (-1102))) 
 ((($ $) |has| |#1| (-281 $ $)) ((|#1| $) |has| |#1| (-281 |#1| |#1|))) 
 (((|#1| (-409 (-568))) . T)) 
 (((|#1|) . T)) 
 (((|#1| (-568)) . T)) 
 ((((-1161)) . T)) 
 (|has| |#1| (-558)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-558))) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-558))) 
 (|has| |#1| (-558)) 
 (|has| |#1| (-43 (-409 (-568)))) 
 (|has| |#1| (-43 (-409 (-568)))) 
@@ -932,7 +932,7 @@
 (|has| |#1| (-150)) 
 (|has| |#1| (-148)) 
 (|has| |#4| (-840)) 
-(((|#2| (-232 (-1697 |#1|) (-763)) (-852 |#1|)) . T)) 
+(((|#2| (-232 (-1699 |#1|) (-763)) (-852 |#1|)) . T)) 
 (|has| |#3| (-840)) 
 (((|#1| (-534 |#3|) |#3|) . T)) 
 (|has| |#1| (-150)) 
@@ -946,22 +946,22 @@
 (|has| |#1| (-148)) 
 ((((-409 (-568))) |has| |#2| (-365)) (($) . T)) 
 (((|#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
-(-2198 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
-(-2198 (|has| |#1| (-350)) (|has| |#1| (-370))) 
+(-2199 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
+(-2199 (|has| |#1| (-350)) (|has| |#1| (-370))) 
 ((((-1127 |#2| |#1|)) . T) ((|#1|) . T)) 
 (((|#1|) . T)) 
 (|has| |#2| (-172)) 
 (((|#1| |#2|) . T)) 
 (-12 (|has| |#2| (-225)) (|has| |#2| (-1047))) 
-(((|#2|) . T) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
-(-2198 (|has| |#3| (-788)) (|has| |#3| (-840))) 
-(-2198 (|has| |#3| (-788)) (|has| |#3| (-840))) 
+(((|#2|) . T) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
+(-2199 (|has| |#3| (-788)) (|has| |#3| (-840))) 
+(-2199 (|has| |#3| (-788)) (|has| |#3| (-840))) 
 ((((-850)) . T)) 
 (((|#1|) . T)) 
 (((|#2|) . T) (($) . T)) 
 (((|#1|) . T) (($) . T)) 
 ((((-688)) . T)) 
-(-2198 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
+(-2199 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
 (|has| |#1| (-558)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
@@ -983,10 +983,10 @@
 (((|#1| (-409 (-568))) . T)) 
 (((|#3|) . T) (((-607 $)) . T)) 
 (((|#1| |#2|) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 (((|#1|) . T)) 
 (((|#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 ((($ $) . T) ((|#2| $) . T)) 
 (((|#1|) . T) (((-409 (-568))) . T) (($) . T)) 
 ((((-1159 |#1| |#2| |#3|) (-1159 |#1| |#2| |#3|)) -12 (|has| (-1159 |#1| |#2| |#3|) (-303 (-1159 |#1| |#2| |#3|))) (|has| |#1| (-365))) (((-1161) (-1159 |#1| |#2| |#3|)) -12 (|has| (-1159 |#1| |#2| |#3|) (-523 (-1161) (-1159 |#1| |#2| |#3|))) (|has| |#1| (-365)))) 
@@ -994,8 +994,8 @@
 ((((-850)) . T)) 
 ((((-850)) . T)) 
 (((|#1| |#1|) . T)) 
-(((|#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) |has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) 
-(((|#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) (((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) |has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-303 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))))) 
+(((|#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) |has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) 
+(((|#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) (((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) |has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-303 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))))) 
 ((((-850)) . T)) 
 (((|#1|) . T)) 
 (((|#3| |#3|) . T)) 
@@ -1006,10 +1006,10 @@
 ((($ $) . T) (((-852 |#1|) $) . T) (((-852 |#1|) |#2|) . T)) 
 (|has| |#1| (-823)) 
 (|has| |#1| (-1090)) 
-(((|#2| |#2|) -2198 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-1047))) (($ $) |has| |#2| (-172))) 
-(((|#2|) -2198 (|has| |#2| (-172)) (|has| |#2| (-365)))) 
-((((-568) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((|#1| |#2|) . T)) 
-(((|#2|) -2198 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-1047))) (($) |has| |#2| (-172))) 
+(((|#2| |#2|) -2199 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-1047))) (($ $) |has| |#2| (-172))) 
+(((|#2|) -2199 (|has| |#2| (-172)) (|has| |#2| (-365)))) 
+((((-568) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((|#1| |#2|) . T)) 
+(((|#2|) -2199 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-1047))) (($) |has| |#2| (-172))) 
 ((((-763)) . T)) 
 ((((-568)) . T)) 
 (|has| |#1| (-558)) 
@@ -1023,34 +1023,34 @@
 (((|#1| (-568) (-1075)) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-558))) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-558))) 
 (|has| |#1| (-150)) 
 ((((-887 (-568))) . T) (((-887 (-381))) . T) (((-541)) . T) (((-1161)) . T)) 
 ((((-850)) . T)) 
-(-2198 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
+(-2199 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
 ((($) . T)) 
 ((((-850)) . T)) 
-(-2198 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
+(-2199 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
 ((((-568)) |has| |#1| (-630 (-568))) ((|#1|) . T)) 
 (((|#2|) |has| |#2| (-172))) 
-((($) -2198 (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) ((|#2|) |has| |#2| (-172)) (((-409 (-568))) |has| |#2| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) ((|#2|) |has| |#2| (-172)) (((-409 (-568))) |has| |#2| (-43 (-409 (-568))))) 
 ((((-864 |#1|)) . T)) 
-(-2198 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-370)) (|has| |#2| (-716)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047)) (|has| |#2| (-1090))) 
+(-2199 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-370)) (|has| |#2| (-716)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047)) (|has| |#2| (-1090))) 
 ((((-850)) . T)) 
 (-12 (|has| |#3| (-225)) (|has| |#3| (-1047))) 
 (|has| |#2| (-1136)) 
-((((-57)) . T) (((-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) . T)) 
+((((-57)) . T) (((-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) . T)) 
 ((((-2 (|:| |k| (-568)) (|:| |c| |#1|))) . T)) 
 (|has| |#2| (-558)) 
 (((|#1| |#2|) . T)) 
-(-2198 (|has| |#3| (-172)) (|has| |#3| (-840)) (|has| |#3| (-1047))) 
+(-2199 (|has| |#3| (-172)) (|has| |#3| (-840)) (|has| |#3| (-1047))) 
 (((|#1| (-568) (-1075)) . T)) 
 (((|#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 (((|#1| (-409 (-568)) (-1075)) . T)) 
-((($) -2198 (|has| |#1| (-301)) (|has| |#1| (-365)) (|has| |#1| (-350)) (|has| |#1| (-558))) (((-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-350))) ((|#1|) . T)) 
+((($) -2199 (|has| |#1| (-301)) (|has| |#1| (-365)) (|has| |#1| (-350)) (|has| |#1| (-558))) (((-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-350))) ((|#1|) . T)) 
 ((((-568) |#2|) . T)) 
 (((|#1| |#2|) . T)) 
 (((|#1| |#2|) . T)) 
@@ -1058,30 +1058,30 @@
 (-12 (|has| |#1| (-370)) (|has| |#2| (-370))) 
 ((((-850)) . T)) 
 ((((-1161) |#1|) |has| |#1| (-523 (-1161) |#1|)) ((|#1| |#1|) |has| |#1| (-303 |#1|))) 
-(-2198 (|has| |#1| (-148)) (|has| |#1| (-370))) 
-(-2198 (|has| |#1| (-148)) (|has| |#1| (-370))) 
-(-2198 (|has| |#1| (-148)) (|has| |#1| (-370))) 
+(-2199 (|has| |#1| (-148)) (|has| |#1| (-370))) 
+(-2199 (|has| |#1| (-148)) (|has| |#1| (-370))) 
+(-2199 (|has| |#1| (-148)) (|has| |#1| (-370))) 
 (((|#1|) . T)) 
 ((((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) |has| |#1| (-172)) (($) |has| |#1| (-558))) 
-((((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2198 (|has| |#1| (-365)) (|has| |#1| (-558))) (((-1159 |#1| |#2| |#3|)) |has| |#1| (-365)) ((|#1|) |has| |#1| (-172))) 
-(((|#1|) |has| |#1| (-172)) (((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2198 (|has| |#1| (-365)) (|has| |#1| (-558)))) 
+((((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2199 (|has| |#1| (-365)) (|has| |#1| (-558))) (((-1159 |#1| |#2| |#3|)) |has| |#1| (-365)) ((|#1|) |has| |#1| (-172))) 
+(((|#1|) |has| |#1| (-172)) (((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2199 (|has| |#1| (-365)) (|has| |#1| (-558)))) 
 ((($) |has| |#1| (-558)) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (|has| |#1| (-558)) 
 (|has| |#1| (-350)) 
 (((|#1|) . T)) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
-(((|#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) |has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) 
+(((|#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) |has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) 
 (|has| |#1| (-558)) 
 (((|#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 ((((-850)) . T)) 
 (((|#1| |#2|) . T)) 
-(-2198 (|has| |#2| (-453)) (|has| |#2| (-904))) 
-(-2198 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
-(-2198 (|has| |#1| (-453)) (|has| |#1| (-904))) 
+(-2199 (|has| |#2| (-453)) (|has| |#2| (-904))) 
+(-2199 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
+(-2199 (|has| |#1| (-453)) (|has| |#1| (-904))) 
 ((((-409 (-568))) . T) (((-568)) . T)) 
 ((((-568)) . T)) 
-((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) |has| |#2| (-172)) (($) -2198 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
+((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) |has| |#2| (-172)) (($) -2199 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
 ((($) . T)) 
 ((((-850)) . T)) 
 (((|#1|) . T)) 
@@ -1089,10 +1089,10 @@
 ((((-850)) . T)) 
 (|has| (-409 (-568)) (-148)) 
 (|has| (-409 (-568)) (-148)) 
-(((|#3| |#3|) -2198 (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-1047))) (($ $) |has| |#3| (-172))) 
+(((|#3| |#3|) -2199 (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-1047))) (($ $) |has| |#3| (-172))) 
 (|has| |#1| (-1021)) 
 ((((-850)) . T)) 
-(((|#3|) -2198 (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-1047))) (($) |has| |#3| (-172))) 
+(((|#3|) -2199 (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-1047))) (($) |has| |#3| (-172))) 
 ((((-568) (-121)) . T)) 
 (((|#1|) |has| |#1| (-303 |#1|))) 
 (|has| |#1| (-370)) 
@@ -1101,32 +1101,32 @@
 ((((-1161) $) |has| |#1| (-523 (-1161) $)) (($ $) |has| |#1| (-303 $)) ((|#1| |#1|) |has| |#1| (-303 |#1|)) (((-1161) |#1|) |has| |#1| (-523 (-1161) |#1|))) 
 (|has| |#2| (-558)) 
 ((((-1161)) |has| |#1| (-895 (-1161)))) 
-(-2198 (-12 (|has| |#1| (-225)) (|has| |#1| (-365))) (|has| |#1| (-350))) 
+(-2199 (-12 (|has| |#1| (-225)) (|has| |#1| (-365))) (|has| |#1| (-350))) 
 ((((-390) (-1108)) . T)) 
 (((|#1| |#4|) . T)) 
 (((|#1| |#3|) . T)) 
 ((((-390) |#1|) . T)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-350))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-350))) 
 (|has| |#1| (-1090)) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
 ((((-905 |#1|)) . T)) 
-((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) |has| |#2| (-172)) (($) -2198 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
-((((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) |has| |#1| (-172)) (($) -2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904)))) 
+((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) |has| |#2| (-172)) (($) -2199 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
+((((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) |has| |#1| (-172)) (($) -2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904)))) 
 (((|#1| |#2|) . T)) 
 ((($) . T)) 
 (((|#1| |#1|) . T)) 
 ((((-864 |#1|)) |has| (-864 |#1|) (-303 (-864 |#1|)))) 
 (|has| |#1| (-1181)) 
 (((|#1| |#2|) . T)) 
-(-2198 (|has| |#2| (-788)) (|has| |#2| (-840))) 
-(-2198 (|has| |#2| (-788)) (|has| |#2| (-840))) 
+(-2199 (|has| |#2| (-788)) (|has| |#2| (-840))) 
+(-2199 (|has| |#2| (-788)) (|has| |#2| (-840))) 
 (-12 (|has| |#1| (-788)) (|has| |#2| (-788))) 
 (((|#1|) . T)) 
 (-12 (|has| |#1| (-788)) (|has| |#2| (-788))) 
-(-2198 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
+(-2199 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
 (((|#2|) . T) (($) . T)) 
-(((|#2|) . T) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+(((|#2|) . T) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 (|has| |#1| (-1181)) 
 ((((-568) (-568)) . T) (((-409 (-568)) (-409 (-568))) . T) (($ $) . T)) 
 ((((-409 (-568))) . T) (($) . T)) 
@@ -1144,7 +1144,7 @@
 (((|#1|) . T) (($) . T) (((-409 (-568))) . T)) 
 (((|#1|) . T) (($) . T) (((-409 (-568))) . T)) 
 (((|#1|) . T)) 
-((($ $) . T) (((-409 (-568)) (-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-350))) ((|#1| |#1|) . T)) 
+((($ $) . T) (((-409 (-568)) (-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-350))) ((|#1| |#1|) . T)) 
 ((((-850)) . T)) 
 (((|#1|) . T)) 
 ((((-541)) |has| |#3| (-609 (-541)))) 
@@ -1152,16 +1152,16 @@
 (((|#1| |#2|) . T)) 
 (|has| |#1| (-840)) 
 (|has| |#1| (-840)) 
-((($) . T) (((-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-350))) ((|#1|) . T)) 
+((($) . T) (((-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-350))) ((|#1|) . T)) 
 ((((-568) |#3|) . T)) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-558))) 
-((((-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) |has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-303 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-558))) 
+((((-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) |has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-303 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))))) 
 ((($) . T)) 
 ((((-409 $) (-409 $)) |has| |#2| (-558)) (($ $) . T) ((|#2| |#2|) . T)) 
 ((((-169 (-215))) . T)) 
 ((((-215)) . T)) 
 (((|#2|) |has| |#2| (-1090))) 
-((((-850)) -2198 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-370)) (|has| |#2| (-716)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047)) (|has| |#2| (-1090))) (((-1244 |#2|)) . T)) 
+((((-850)) -2199 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-370)) (|has| |#2| (-716)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047)) (|has| |#2| (-1090))) (((-1244 |#2|)) . T)) 
 (|has| |#2| (-842)) 
 (|has| |#1| (-842)) 
 (|has| |#1| (-842)) 
@@ -1171,10 +1171,10 @@
 ((((-850)) . T)) 
 ((((-568)) |has| (-409 |#2|) (-630 (-568))) (((-409 |#2|)) . T)) 
 ((((-568) (-147)) . T)) 
-((((-568) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((|#1| |#2|) . T)) 
+((((-568) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((|#1| |#2|) . T)) 
 ((((-409 (-568))) . T) (($) . T)) 
 (((|#1|) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 ((((-850)) . T)) 
 ((((-905 |#1|)) . T)) 
 (|has| |#1| (-365)) 
@@ -1200,31 +1200,31 @@
 ((($) . T)) 
 (((|#2|) . T) (($) . T)) 
 (((|#1|) |has| |#1| (-172))) 
-((((-568) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((|#1| |#2|) . T)) 
+((((-568) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((|#1| |#2|) . T)) 
 (((|#1|) . T)) 
 ((($) |has| |#1| (-558)) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (((|#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 (((|#3|) . T)) 
 (((|#1|) |has| |#1| (-172))) 
-((((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) |has| |#1| (-172)) (($) -2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904)))) 
-((($) -2198 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) |has| |#1| (-172)) (($) -2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904)))) 
+((($) -2199 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 ((((-541)) |has| |#1| (-609 (-541))) (((-887 (-381))) |has| |#1| (-609 (-887 (-381)))) (((-887 (-568))) |has| |#1| (-609 (-887 (-568))))) 
 ((((-850)) . T)) 
-(((|#2|) . T) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+(((|#2|) . T) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 (|has| |#2| (-840)) 
 (-12 (|has| |#2| (-225)) (|has| |#2| (-1047))) 
 (|has| |#1| (-558)) 
 (|has| |#1| (-1136)) 
 ((((-1143) |#1|) . T)) 
-(-2198 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
-((((-409 (-568)) (-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) ((|#1| |#1|) . T)) 
+(-2199 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
+((((-409 (-568)) (-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) ((|#1| |#1|) . T)) 
 ((((-409 (-568))) |has| |#1| (-1037 (-568))) (((-568)) |has| |#1| (-1037 (-568))) (((-1161)) |has| |#1| (-1037 (-1161))) ((|#1|) . T)) 
 ((((-568) |#2|) . T)) 
 ((((-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) (((-568)) |has| |#1| (-1037 (-568))) ((|#1|) . T)) 
 ((((-568)) |has| |#1| (-881 (-568))) (((-381)) |has| |#1| (-881 (-381)))) 
-((((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) ((|#1|) . T)) 
+((((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) ((|#1|) . T)) 
 (((|#1|) . T)) 
 ((((-634 |#4|)) . T) (((-850)) . T)) 
 ((((-541)) |has| |#4| (-609 (-541)))) 
@@ -1238,17 +1238,17 @@
 (((|#1|) . T)) 
 (((|#2|) . T)) 
 ((((-1161)) |has| (-409 |#2|) (-895 (-1161)))) 
-(((|#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) |has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) 
+(((|#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) |has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) 
 ((($) . T)) 
 ((($) . T)) 
 (((|#2|) . T)) 
-((((-850)) -2198 (|has| |#3| (-25)) (|has| |#3| (-137)) (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-370)) (|has| |#3| (-716)) (|has| |#3| (-788)) (|has| |#3| (-840)) (|has| |#3| (-1047)) (|has| |#3| (-1090))) (((-1244 |#3|)) . T)) 
+((((-850)) -2199 (|has| |#3| (-25)) (|has| |#3| (-137)) (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-370)) (|has| |#3| (-716)) (|has| |#3| (-788)) (|has| |#3| (-840)) (|has| |#3| (-1047)) (|has| |#3| (-1090))) (((-1244 |#3|)) . T)) 
 ((((-568) |#2|) . T)) 
-(-2198 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
-(((|#2| |#2|) -2198 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-1047))) (($ $) |has| |#2| (-172))) 
+(-2199 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
+(((|#2| |#2|) -2199 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-1047))) (($ $) |has| |#2| (-172))) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((|#2|) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((|#2|) . T)) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
 ((((-1143) (-1161) (-568) (-215) (-850)) . T)) 
@@ -1284,7 +1284,7 @@
 ((((-850)) . T)) 
 ((((-541)) |has| |#1| (-609 (-541)))) 
 ((((-850)) |has| |#1| (-1090))) 
-(((|#2|) -2198 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-1047))) (($) |has| |#2| (-172))) 
+(((|#2|) -2199 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-1047))) (($) |has| |#2| (-172))) 
 (|has| $ (-150)) 
 ((((-409 |#2|)) . T)) 
 ((((-409 (-568))) |has| (-409 |#2|) (-1037 (-409 (-568)))) (((-568)) |has| (-409 |#2|) (-1037 (-568))) (((-409 |#2|)) . T)) 
@@ -1295,18 +1295,18 @@
 (((|#3|) |has| |#3| (-172))) 
 (|has| |#1| (-150)) 
 (|has| |#1| (-148)) 
-(-2198 (|has| |#1| (-148)) (|has| |#1| (-370))) 
+(-2199 (|has| |#1| (-148)) (|has| |#1| (-370))) 
 (|has| |#1| (-150)) 
-(-2198 (|has| |#1| (-148)) (|has| |#1| (-370))) 
+(-2199 (|has| |#1| (-148)) (|has| |#1| (-370))) 
 (|has| |#1| (-150)) 
-(-2198 (|has| |#1| (-148)) (|has| |#1| (-370))) 
+(-2199 (|has| |#1| (-148)) (|has| |#1| (-370))) 
 (|has| |#1| (-150)) 
 (((|#1|) . T)) 
 (((|#2|) . T)) 
 (|has| |#2| (-225)) 
 ((((-1161) (-57)) . T)) 
 ((((-850)) . T)) 
-(-2198 (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
+(-2199 (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
 (((|#1| |#1|) . T)) 
 ((((-1161)) |has| |#2| (-895 (-1161)))) 
 ((((-568) (-121)) . T)) 
@@ -1331,7 +1331,7 @@
 ((((-999 |#1|)) . T) ((|#1|) . T)) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 ((((-409 (-568))) . T) (((-409 |#1|)) . T) ((|#1|) . T) (($) . T)) 
 (((|#1| (-1157 |#1|)) . T)) 
 ((((-568)) . T) (($) . T) (((-409 (-568))) . T)) 
@@ -1339,7 +1339,7 @@
 (|has| |#1| (-842)) 
 (((|#2|) . T)) 
 ((((-568)) . T) (($) . T) (((-409 (-568))) . T)) 
-((((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) . T)) 
+((((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) . T)) 
 ((((-568) |#2|) . T)) 
 ((((-850)) |has| |#1| (-1090))) 
 (((|#2|) . T)) 
@@ -1356,7 +1356,7 @@
 (|has| |#1| (-43 (-409 (-568)))) 
 (((|#2|) . T)) 
 (((|#1|) . T)) 
-(((|#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) |has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) 
+(((|#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) |has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) 
 (((|#2| |#2|) . T)) 
 (((|#2|) . T)) 
 (|has| |#2| (-365)) 
@@ -1367,7 +1367,7 @@
 (((|#2|) |has| |#2| (-172))) 
 ((((-568) |#3|) . T)) 
 ((((-568) (-147)) . T)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
 ((((-147)) . T)) 
 ((((-850)) . T)) 
 (|has| |#1| (-904)) 
@@ -1394,20 +1394,20 @@
 (((|#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 (((|#1| |#2|) . T)) 
 ((((-568) (-147)) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) |has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) ((|#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) 
-(-2198 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
-((($) -2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) |has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) ((|#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) 
+(-2199 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
+((($) -2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (|has| |#1| (-842)) 
 (((|#2| (-763) (-1075)) . T)) 
 (((|#1| |#2|) . T)) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-558))) 
 (|has| |#1| (-786)) 
 (((|#1|) |has| |#1| (-172))) 
 (((|#4|) . T)) 
 (((|#4|) . T)) 
 (((|#1| |#2|) . T)) 
-(-2198 (|has| |#1| (-150)) (-12 (|has| |#1| (-365)) (|has| |#2| (-150)))) 
-(-2198 (|has| |#1| (-148)) (-12 (|has| |#1| (-365)) (|has| |#2| (-148)))) 
+(-2199 (|has| |#1| (-150)) (-12 (|has| |#1| (-365)) (|has| |#2| (-150)))) 
+(-2199 (|has| |#1| (-148)) (-12 (|has| |#1| (-365)) (|has| |#2| (-148)))) 
 (((|#4|) . T)) 
 (|has| |#1| (-148)) 
 ((((-1143) |#1|) . T)) 
@@ -1420,7 +1420,7 @@
 (((|#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 (((|#3|) . T)) 
 ((((-1235 |#1| |#2| |#3|)) |has| |#1| (-365))) 
-(-2198 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
+(-2199 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
 (((|#1|) . T)) 
 ((((-850)) |has| |#1| (-1090))) 
 ((((-850)) |has| |#1| (-1090)) (((-958 |#1|)) . T)) 
@@ -1434,11 +1434,11 @@
 (((|#3| |#3|) -12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) 
 (((|#2| (-888 |#1|)) . T)) 
 ((($) . T)) 
-((($) -2198 (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) ((|#2|) |has| |#2| (-172)) (((-409 (-568))) |has| |#2| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) ((|#2|) |has| |#2| (-172)) (((-409 (-568))) |has| |#2| (-43 (-409 (-568))))) 
 ((((-390) (-1143)) . T)) 
 ((($) |has| |#1| (-558)) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
-((((-850)) -2198 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-370)) (|has| |#2| (-716)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047)) (|has| |#2| (-1090))) (((-1244 |#2|)) . T)) 
-((((-57)) . T) (((-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) . T)) 
+((((-850)) -2199 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-370)) (|has| |#2| (-716)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047)) (|has| |#2| (-1090))) (((-1244 |#2|)) . T)) 
+((((-57)) . T) (((-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) . T)) 
 (((|#1|) . T)) 
 ((((-850)) . T)) 
 (((|#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) 
@@ -1446,7 +1446,7 @@
 (|has| |#2| (-148)) 
 (|has| |#2| (-150)) 
 (|has| |#1| (-478)) 
-(-2198 (|has| |#1| (-478)) (|has| |#1| (-716)) (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047))) 
+(-2199 (|has| |#1| (-478)) (|has| |#1| (-716)) (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047))) 
 (|has| |#1| (-365)) 
 ((((-850)) . T)) 
 (|has| |#1| (-43 (-409 (-568)))) 
@@ -1457,8 +1457,8 @@
 (|has| |#1| (-840)) 
 ((((-850)) . T)) 
 ((($) |has| |#1| (-558)) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
-((((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2198 (|has| |#1| (-365)) (|has| |#1| (-558))) (((-1235 |#1| |#2| |#3|)) |has| |#1| (-365)) ((|#1|) |has| |#1| (-172))) 
-(((|#1|) |has| |#1| (-172)) (((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2198 (|has| |#1| (-365)) (|has| |#1| (-558)))) 
+((((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2199 (|has| |#1| (-365)) (|has| |#1| (-558))) (((-1235 |#1| |#2| |#3|)) |has| |#1| (-365)) ((|#1|) |has| |#1| (-172))) 
+(((|#1|) |has| |#1| (-172)) (((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2199 (|has| |#1| (-365)) (|has| |#1| (-558)))) 
 ((($) |has| |#1| (-558)) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (((|#1| |#2|) . T)) 
 ((((-1161)) |has| |#1| (-895 (-1161)))) 
@@ -1466,7 +1466,7 @@
 ((((-850)) . T)) 
 ((((-850)) . T)) 
 (|has| |#1| (-1090)) 
-(((|#2| (-493 (-1697 |#1|) (-763)) (-852 |#1|)) . T)) 
+(((|#2| (-493 (-1699 |#1|) (-763)) (-852 |#1|)) . T)) 
 ((((-409 (-568))) |has| |#2| (-365)) (($) |has| |#2| (-365))) 
 (((|#1| (-534 (-1161)) (-1161)) . T)) 
 (((|#1|) . T)) 
@@ -1486,17 +1486,17 @@
 (|has| |#1| (-150)) 
 (((|#1|) . T)) 
 (((|#2|) . T)) 
-(((|#1|) . T) (((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+(((|#1|) . T) (((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 (((|#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9|) . T)) 
-((((-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) . T)) 
+((((-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) . T)) 
 ((((-1159 |#1| |#2| |#3|)) |has| |#1| (-365))) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 ((((-1161) (-57)) . T)) 
 ((($ $) . T)) 
 (((|#1| (-568)) . T)) 
 ((((-905 |#1|)) . T)) 
-(((|#1|) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-1047))) (($) -2198 (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047)))) 
+(((|#1|) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-1047))) (($) -2199 (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047)))) 
 (((|#1|) . T) (((-568)) |has| |#1| (-1037 (-568))) (((-409 (-568))) |has| |#1| (-1037 (-409 (-568))))) 
 (|has| |#1| (-842)) 
 (|has| |#1| (-842)) 
@@ -1511,14 +1511,14 @@
 (((|#4| |#4|) -12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) 
 (((|#1|) |has| |#1| (-172))) 
 (((|#4| |#4|) -12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) 
-(((|#3|) -2198 (|has| |#3| (-172)) (|has| |#3| (-365)))) 
+(((|#3|) -2199 (|has| |#3| (-172)) (|has| |#3| (-365)))) 
 (|has| |#2| (-842)) 
 (|has| |#1| (-842)) 
-(-2198 (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-904))) 
+(-2199 (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-904))) 
 (((|#1|) . T)) 
 ((($ $) . T) (((-409 (-568)) (-409 (-568))) . T)) 
 ((((-568) |#2|) . T)) 
-(((|#2|) -2198 (|has| |#2| (-172)) (|has| |#2| (-365)))) 
+(((|#2|) -2199 (|has| |#2| (-172)) (|has| |#2| (-365)))) 
 (|has| |#1| (-350)) 
 (((|#3| |#3|) -12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) 
 ((($) . T) (((-409 (-568))) . T)) 
@@ -1526,7 +1526,7 @@
 (|has| |#1| (-815)) 
 (|has| |#1| (-815)) 
 (((|#1|) . T)) 
-(-2198 (|has| |#1| (-301)) (|has| |#1| (-365)) (|has| |#1| (-350))) 
+(-2199 (|has| |#1| (-301)) (|has| |#1| (-365)) (|has| |#1| (-350))) 
 (|has| |#1| (-840)) 
 (|has| |#1| (-840)) 
 (|has| |#1| (-840)) 
@@ -1535,14 +1535,14 @@
 ((((-568)) . T) (($) . T) (((-409 (-568))) . T)) 
 (|has| |#1| (-43 (-409 (-568)))) 
 (|has| |#1| (-43 (-409 (-568)))) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-350))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-350))) 
 (|has| |#1| (-43 (-409 (-568)))) 
 (|has| |#1| (-43 (-409 (-568)))) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 ((((-1161)) |has| |#1| (-895 (-1161))) (((-1075)) . T)) 
 (((|#1|) . T)) 
 (|has| |#1| (-840)) 
-((((-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) |has| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-303 (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))))) 
+((((-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) |has| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-303 (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))))) 
 (((|#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 (|has| |#1| (-1090)) 
 (((|#1|) . T)) 
@@ -1560,7 +1560,7 @@
 (((|#1|) . T)) 
 ((((-147)) . T)) 
 (((|#2|) |has| |#2| (-172))) 
-(-2198 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-370)) (|has| |#2| (-716)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047)) (|has| |#2| (-1090))) 
+(-2199 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-370)) (|has| |#2| (-716)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047)) (|has| |#2| (-1090))) 
 (((|#1|) . T)) 
 (|has| |#1| (-148)) 
 (|has| |#1| (-150)) 
@@ -1582,32 +1582,32 @@
 (((|#2|) . T)) 
 (((|#1|) . T)) 
 (((|#1| |#2|) . T)) 
-(((|#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) (((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) |has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-303 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))))) 
-(-2198 (|has| |#2| (-453)) (|has| |#2| (-904))) 
-(-2198 (|has| |#1| (-453)) (|has| |#1| (-904))) 
+(((|#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) (((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) |has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-303 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))))) 
+(-2199 (|has| |#2| (-453)) (|has| |#2| (-904))) 
+(-2199 (|has| |#1| (-453)) (|has| |#1| (-904))) 
 (((|#1|) . T) (($) . T)) 
 (((|#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) 
 (((|#1| |#2|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
-(((|#3|) -2198 (|has| |#3| (-172)) (|has| |#3| (-365)))) 
+(((|#3|) -2199 (|has| |#3| (-172)) (|has| |#3| (-365)))) 
 (|has| |#1| (-842)) 
 (|has| |#1| (-558)) 
 ((((-581 |#1|)) . T)) 
 ((($) . T)) 
 (((|#2|) . T)) 
-(-2198 (-12 (|has| |#1| (-365)) (|has| |#2| (-815))) (-12 (|has| |#1| (-365)) (|has| |#2| (-842)))) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (-12 (|has| |#1| (-365)) (|has| |#2| (-815))) (-12 (|has| |#1| (-365)) (|has| |#2| (-842)))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-558))) 
 ((((-905 |#1|)) . T)) 
 (((|#1| (-505 |#1| |#3|) (-505 |#1| |#2|)) . T)) 
 (((|#1| |#4| |#5|) . T)) 
 (((|#1| (-763)) . T)) 
 ((((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) |has| |#1| (-172)) (($) |has| |#1| (-558))) 
-((((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2198 (|has| |#1| (-365)) (|has| |#1| (-558))) (((-1159 |#1| |#2| |#3|)) |has| |#1| (-365)) ((|#1|) |has| |#1| (-172))) 
-(((|#1|) |has| |#1| (-172)) (((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2198 (|has| |#1| (-365)) (|has| |#1| (-558)))) 
+((((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2199 (|has| |#1| (-365)) (|has| |#1| (-558))) (((-1159 |#1| |#2| |#3|)) |has| |#1| (-365)) ((|#1|) |has| |#1| (-172))) 
+(((|#1|) |has| |#1| (-172)) (((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2199 (|has| |#1| (-365)) (|has| |#1| (-558)))) 
 ((($) |has| |#1| (-558)) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
-((((-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) . T)) 
+((((-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) . T)) 
 ((((-409 |#2|)) . T) (((-409 (-568))) . T) (($) . T)) 
 ((((-663 |#1|)) . T)) 
 (((|#1| |#2| |#3| |#4|) . T)) 
@@ -1615,17 +1615,17 @@
 ((((-850)) . T)) 
 (((|#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 ((((-850)) . T)) 
-((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) |has| |#2| (-172)) (($) -2198 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
+((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) |has| |#2| (-172)) (($) -2199 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
 (((|#2|) . T)) 
-(-2198 (|has| |#3| (-25)) (|has| |#3| (-137)) (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-370)) (|has| |#3| (-716)) (|has| |#3| (-788)) (|has| |#3| (-840)) (|has| |#3| (-1047)) (|has| |#3| (-1090))) 
-(-2198 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
+(-2199 (|has| |#3| (-25)) (|has| |#3| (-137)) (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-370)) (|has| |#3| (-716)) (|has| |#3| (-788)) (|has| |#3| (-840)) (|has| |#3| (-1047)) (|has| |#3| (-1090))) 
+(-2199 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
 ((((-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) (((-568)) |has| |#1| (-1037 (-568))) ((|#1|) . T)) 
 (|has| |#1| (-1181)) 
 (|has| |#1| (-1181)) 
-(-2198 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-370)) (|has| |#2| (-716)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047)) (|has| |#2| (-1090))) 
+(-2199 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-370)) (|has| |#2| (-716)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047)) (|has| |#2| (-1090))) 
 (|has| |#1| (-1181)) 
 (|has| |#1| (-1181)) 
 (((|#3| |#3|) . T)) 
@@ -1638,37 +1638,37 @@
 (((|#1|) . T) (((-409 (-568))) . T) (($) . T)) 
 ((((-1143) (-57)) . T)) 
 (|has| |#1| (-1090)) 
-(-2198 (|has| |#2| (-815)) (|has| |#2| (-842))) 
+(-2199 (|has| |#2| (-815)) (|has| |#2| (-842))) 
 (((|#1|) . T)) 
 (((|#1|) |has| |#1| (-172)) (($) . T)) 
-((($) -2198 (|has| |#1| (-365)) (|has| |#1| (-350))) (((-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-350))) ((|#1|) . T)) 
+((($) -2199 (|has| |#1| (-365)) (|has| |#1| (-350))) (((-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-350))) ((|#1|) . T)) 
 ((($) . T)) 
 ((((-1159 |#1| |#2| |#3|)) -12 (|has| (-1159 |#1| |#2| |#3|) (-303 (-1159 |#1| |#2| |#3|))) (|has| |#1| (-365)))) 
 ((((-850)) . T)) 
-(-2198 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
+(-2199 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
 ((($) . T)) 
 (((|#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
-(-2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
 ((((-850)) . T)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
-(-2198 (|has| |#1| (-453)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-453)) (|has| |#1| (-904))) 
 (|has| |#2| (-904)) 
 (|has| |#1| (-365)) 
 (((|#2|) |has| |#2| (-1090))) 
-(-2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
 ((($) . T) ((|#2|) . T)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-904))) 
 ((((-541)) . T) (((-409 (-1157 (-568)))) . T) (((-215)) . T) (((-381)) . T)) 
 ((((-381)) . T) (((-215)) . T) (((-850)) . T)) 
 (|has| |#1| (-904)) 
 (|has| |#1| (-904)) 
 (|has| |#1| (-904)) 
-(-2198 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
+(-2199 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
 (((|#1|) . T)) 
 (((|#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) 
 (|has| (-169 (-215)) (-842)) 
 ((($ $) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 (|has| |#1| (-365)) 
 ((($ $) . T)) 
 ((((-568) (-121)) . T)) 
@@ -1676,7 +1676,7 @@
 (|has| |#2| (-558)) 
 (((|#1|) . T)) 
 ((((-121)) . T)) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) 
 ((((-568)) . T)) 
 (((|#1| (-568)) . T)) 
 ((($) . T)) 
@@ -1698,7 +1698,7 @@
 (((|#1| (-1235 |#1| |#2| |#3|)) . T)) 
 (((|#1|) . T)) 
 (((|#1| (-409 (-568))) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 ((((-850)) . T)) 
 (((|#1| (-1207 |#1| |#2| |#3|)) . T)) 
 (|has| |#1| (-1090)) 
@@ -1720,18 +1720,18 @@
 (((|#1|) . T)) 
 ((((-568)) . T)) 
 ((((-850)) . T)) 
-(-2198 (|has| |#1| (-148)) (|has| |#1| (-350))) 
+(-2199 (|has| |#1| (-148)) (|has| |#1| (-350))) 
 (|has| |#1| (-150)) 
 ((((-850)) . T)) 
 (((|#3|) . T)) 
-(-2198 (|has| |#3| (-172)) (|has| |#3| (-840)) (|has| |#3| (-1047))) 
+(-2199 (|has| |#3| (-172)) (|has| |#3| (-840)) (|has| |#3| (-1047))) 
 ((((-850)) . T)) 
 ((((-1228 |#2| |#3| |#4|)) . T) (((-1229 |#1| |#2| |#3| |#4|)) . T)) 
 ((((-850)) . T)) 
-((((-53)) -12 (|has| |#1| (-558)) (|has| |#1| (-1037 (-568)))) (((-607 $)) . T) ((|#1|) . T) (((-568)) |has| |#1| (-1037 (-568))) (((-409 (-568))) -2198 (-12 (|has| |#1| (-558)) (|has| |#1| (-1037 (-568)))) (|has| |#1| (-1037 (-409 (-568))))) (((-409 (-953 |#1|))) |has| |#1| (-558)) (((-953 |#1|)) |has| |#1| (-1047)) (((-1161)) . T)) 
+((((-53)) -12 (|has| |#1| (-558)) (|has| |#1| (-1037 (-568)))) (((-607 $)) . T) ((|#1|) . T) (((-568)) |has| |#1| (-1037 (-568))) (((-409 (-568))) -2199 (-12 (|has| |#1| (-558)) (|has| |#1| (-1037 (-568)))) (|has| |#1| (-1037 (-409 (-568))))) (((-409 (-953 |#1|))) |has| |#1| (-558)) (((-953 |#1|)) |has| |#1| (-1047)) (((-1161)) . T)) 
 (((|#1|) . T) (($) . T)) 
 (((|#1| (-763)) . T)) 
-((($) -2198 (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) ((|#1|) |has| |#1| (-172))) 
+((($) -2199 (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) ((|#1|) |has| |#1| (-172))) 
 (((|#1|) |has| |#1| (-303 |#1|))) 
 ((((-1229 |#1| |#2| |#3| |#4|)) . T)) 
 ((((-568)) |has| |#1| (-881 (-568))) (((-381)) |has| |#1| (-881 (-381)))) 
@@ -1739,7 +1739,7 @@
 (|has| |#1| (-558)) 
 (((|#1|) . T)) 
 ((((-850)) . T)) 
-(((|#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) |has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) 
+(((|#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) |has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) 
 (((|#1|) |has| |#1| (-172))) 
 ((($) |has| |#1| (-558)) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (((|#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
@@ -1747,7 +1747,7 @@
 ((((-1161)) -12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) 
 (((|#1|) . T)) 
 (((|#3|) |has| |#3| (-1090))) 
-(((|#2|) -2198 (|has| |#2| (-172)) (|has| |#2| (-365)))) 
+(((|#2|) -2199 (|has| |#2| (-172)) (|has| |#2| (-365)))) 
 ((((-1228 |#2| |#3| |#4|)) . T)) 
 ((((-121)) . T)) 
 (|has| |#1| (-815)) 
@@ -1757,8 +1757,8 @@
 (|has| |#1| (-840)) 
 (|has| |#1| (-840)) 
 (((|#1| (-763) (-1075)) . T)) 
-(-2198 (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047))) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+(-2199 (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047))) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 ((((-1161)) . T)) 
 (((|#1| (-568) (-1075)) . T)) 
 (((|#1| (-409 (-568)) (-1075)) . T)) 
@@ -1778,34 +1778,34 @@
 (|has| |#1| (-1090)) 
 ((((-568)) -12 (|has| |#1| (-365)) (|has| |#2| (-630 (-568)))) ((|#2|) |has| |#1| (-365))) 
 (((|#2|) |has| |#2| (-1047))) 
-(-2198 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-370)) (|has| |#2| (-716)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047)) (|has| |#2| (-1090))) 
+(-2199 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-370)) (|has| |#2| (-716)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047)) (|has| |#2| (-1090))) 
 (((|#2|) |has| |#2| (-172))) 
 (((|#1|) |has| |#1| (-172))) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
-((((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
+((((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) . T)) 
 ((((-850)) . T)) 
 (|has| |#3| (-840)) 
 ((((-850)) . T)) 
 ((((-1228 |#2| |#3| |#4|) (-314 |#2| |#3| |#4|)) . T)) 
 ((((-850)) . T)) 
-(((|#1| |#1|) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-1047)))) 
+(((|#1| |#1|) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-1047)))) 
 (((|#1|) . T)) 
 ((((-568)) . T)) 
 ((((-850)) . T)) 
 ((((-568)) . T)) 
-((((-734 |#1| |#2|)) . T) (((-607 $)) . T) ((|#2|) . T) (((-568)) . T) (((-409 (-568))) -2198 (-12 (|has| |#2| (-558)) (|has| |#2| (-1037 (-568)))) (|has| |#2| (-1037 (-409 (-568))))) (((-409 (-953 |#2|))) |has| |#2| (-558)) (((-953 |#2|)) |has| |#2| (-1047)) (((-1161)) . T)) 
-(((|#1|) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-1047)))) 
+((((-734 |#1| |#2|)) . T) (((-607 $)) . T) ((|#2|) . T) (((-568)) . T) (((-409 (-568))) -2199 (-12 (|has| |#2| (-558)) (|has| |#2| (-1037 (-568)))) (|has| |#2| (-1037 (-409 (-568))))) (((-409 (-953 |#2|))) |has| |#2| (-558)) (((-953 |#2|)) |has| |#2| (-1047)) (((-1161)) . T)) 
+(((|#1|) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-1047)))) 
 (((|#2|) |has| |#2| (-365))) 
 ((((-568)) |has| |#2| (-881 (-568))) (((-381)) |has| |#2| (-881 (-381)))) 
 (((|#2|) . T)) 
 (|has| |#1| (-842)) 
 ((($) . T) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-365))) 
 (((|#2|) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 (((|#1| (-763)) . T)) 
 (((|#2|) . T)) 
-((((-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) |has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-303 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))))) 
-(-2198 (|has| |#1| (-453)) (|has| |#1| (-904))) 
+((((-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) |has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-303 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))))) 
+(-2199 (|has| |#1| (-453)) (|has| |#1| (-904))) 
 (((|#2|) . T) (((-568)) |has| |#2| (-630 (-568)))) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
@@ -1839,7 +1839,7 @@
 (|has| |#1| (-43 (-409 (-568)))) 
 (|has| |#1| (-43 (-409 (-568)))) 
 (((|#1|) . T)) 
-(-2198 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
+(-2199 (|has| |#2| (-172)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
 (((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) . T) (($ $) . T)) 
 ((((-850)) . T)) 
 (((|#1|) . T) (((-409 (-568))) . T) (($) . T)) 
@@ -1850,7 +1850,7 @@
 (|has| (-409 |#2|) (-225)) 
 (|has| |#1| (-904)) 
 (((|#2|) |has| |#2| (-1047))) 
-(((|#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) |has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) 
+(((|#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) |has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) 
 (|has| |#1| (-365)) 
 (((|#1|) |has| |#1| (-172))) 
 (((|#1| |#1|) . T)) 
@@ -1877,7 +1877,7 @@
 (((|#1| (-409 (-568)) (-1075)) . T)) 
 (((|#1| (-763) (-1075)) . T)) 
 ((((-409 |#2|) (-409 |#2|)) . T) (((-409 (-568)) (-409 (-568))) . T) (($ $) . T)) 
-(((|#1|) . T) (((-568)) -2198 (|has| (-409 (-568)) (-1037 (-568))) (|has| |#1| (-1037 (-568)))) (((-409 (-568))) . T)) 
+(((|#1|) . T) (((-568)) -2199 (|has| (-409 (-568)) (-1037 (-568))) (|has| |#1| (-1037 (-568)))) (((-409 (-568))) . T)) 
 (((|#1| (-599 |#1| |#3|) (-599 |#1| |#2|)) . T)) 
 (((|#1|) |has| |#1| (-172))) 
 (((|#1|) . T)) 
@@ -1886,7 +1886,7 @@
 ((((-409 |#2|)) . T) (((-409 (-568))) . T) (($) . T)) 
 (|has| |#2| (-225)) 
 (((|#2| (-534 (-852 |#1|)) (-852 |#1|)) . T)) 
-((($) -2198 (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) ((|#2|) |has| |#2| (-172)) (((-409 (-568))) |has| |#2| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) ((|#2|) |has| |#2| (-172)) (((-409 (-568))) |has| |#2| (-43 (-409 (-568))))) 
 ((((-850)) . T)) 
 ((($) |has| |#1| (-558)) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 ((((-850)) . T)) 
@@ -1898,10 +1898,10 @@
 ((((-688)) . T)) 
 (((|#2|) |has| |#2| (-172))) 
 (|has| |#2| (-840)) 
-((((-121)) |has| |#1| (-1090)) (((-850)) -2198 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-478)) (|has| |#1| (-716)) (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047)) (|has| |#1| (-1102)) (|has| |#1| (-1090)))) 
+((((-121)) |has| |#1| (-1090)) (((-850)) -2199 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-478)) (|has| |#1| (-716)) (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047)) (|has| |#1| (-1102)) (|has| |#1| (-1090)))) 
 (((|#1|) . T) (($) . T)) 
 (((|#1| |#2|) . T)) 
-((((-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) . T)) 
+((((-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) . T)) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
@@ -1909,15 +1909,15 @@
 ((((-688)) . T) (((-409 (-568))) . T) (((-568)) . T)) 
 (((|#2|) . T)) 
 (((|#1| |#1|) |has| |#1| (-172))) 
-(((|#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) |has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) 
+(((|#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) |has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) 
 ((((-381)) . T)) 
 ((((-688)) . T)) 
 ((((-409 (-568))) |has| |#2| (-365)) (($) |has| |#2| (-365))) 
 (((|#1|) |has| |#1| (-172))) 
 ((((-409 (-953 |#1|))) . T)) 
 (((|#2| |#2|) . T)) 
-(-2198 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
-(-2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
+(-2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
 ((($) . T)) 
 (((|#2|) . T)) 
 (|has| |#2| (-842)) 
@@ -1928,7 +1928,7 @@
 (|has| |#1| (-842)) 
 ((((-1161)) |has| |#2| (-895 (-1161)))) 
 ((((-850)) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 ((((-409 (-568))) . T) (($) . T)) 
 (|has| |#1| (-478)) 
 (|has| |#1| (-370)) 
@@ -1936,7 +1936,7 @@
 (|has| |#1| (-370)) 
 (|has| |#1| (-365)) 
 ((((-850)) . T)) 
-(-2198 (|has| |#1| (-148)) (|has| |#1| (-150)) (|has| |#1| (-172)) (|has| |#1| (-478)) (|has| |#1| (-558)) (|has| |#1| (-1047)) (|has| |#1| (-1102))) 
+(-2199 (|has| |#1| (-148)) (|has| |#1| (-150)) (|has| |#1| (-172)) (|has| |#1| (-478)) (|has| |#1| (-558)) (|has| |#1| (-1047)) (|has| |#1| (-1102))) 
 ((((-125 |#1|)) . T)) 
 ((((-125 |#1|)) . T)) 
 ((((-147)) . T)) 
@@ -1961,14 +1961,14 @@
 (|has| |#1| (-43 (-409 (-568)))) 
 (|has| |#1| (-842)) 
 (|has| |#1| (-43 (-409 (-568)))) 
-((((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) . T)) 
+((((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) . T)) 
 (|has| |#1| (-43 (-409 (-568)))) 
 (|has| |#1| (-43 (-409 (-568)))) 
 (|has| |#1| (-43 (-409 (-568)))) 
 (((|#1| |#2|) . T)) 
 (|has| |#1| (-150)) 
 (|has| |#1| (-148)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) |has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) ((|#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) |has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) ((|#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) 
 (((|#2|) . T)) 
 (((|#1|) . T)) 
 (((|#3|) . T)) 
@@ -1989,11 +1989,11 @@
 ((((-541)) |has| |#1| (-609 (-541))) (((-887 (-568))) |has| |#1| (-609 (-887 (-568)))) (((-887 (-381))) |has| |#1| (-609 (-887 (-381)))) (((-381)) |has| |#1| (-1021)) (((-215)) |has| |#1| (-1021))) 
 (((|#1|) |has| |#1| (-365))) 
 ((((-850)) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 ((($ $) . T) (((-607 $) $) . T)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-558))) 
 ((($) . T) (((-1229 |#1| |#2| |#3| |#4|)) . T) (((-409 (-568))) . T)) 
-((($) -2198 (|has| |#1| (-148)) (|has| |#1| (-150)) (|has| |#1| (-172)) (|has| |#1| (-558)) (|has| |#1| (-1047))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-558))) 
+((($) -2199 (|has| |#1| (-148)) (|has| |#1| (-150)) (|has| |#1| (-172)) (|has| |#1| (-558)) (|has| |#1| (-1047))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-558))) 
 (|has| |#1| (-365)) 
 (|has| |#1| (-365)) 
 (|has| |#1| (-365)) 
@@ -2004,7 +2004,7 @@
 ((((-381)) . T)) 
 (((|#3|) -12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) 
 ((((-850)) . T)) 
-(-2198 (|has| |#2| (-453)) (|has| |#2| (-904))) 
+(-2199 (|has| |#2| (-453)) (|has| |#2| (-904))) 
 (((|#1|) . T)) 
 (|has| |#1| (-842)) 
 (|has| |#1| (-842)) 
@@ -2018,16 +2018,16 @@
 (|has| |#1| (-148)) 
 (|has| |#1| (-150)) 
 ((((-568)) . T)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-558))) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-558))) 
 ((((-1228 |#2| |#3| |#4|)) . T) (((-409 (-568))) |has| (-1228 |#2| |#3| |#4|) (-43 (-409 (-568)))) (($) . T)) 
 ((((-568)) . T)) 
 (|has| |#2| (-478)) 
 (|has| |#1| (-150)) 
 (|has| |#1| (-148)) 
 (|has| |#1| (-365)) 
-(-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-150)) (|has| |#1| (-365))) (|has| |#1| (-150))) 
-(-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-148)) (|has| |#1| (-365))) (|has| |#1| (-148))) 
+(-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-150)) (|has| |#1| (-365))) (|has| |#1| (-150))) 
+(-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-148)) (|has| |#1| (-365))) (|has| |#1| (-148))) 
 (|has| |#1| (-365)) 
 (|has| |#1| (-148)) 
 (|has| |#1| (-225)) 
@@ -2047,19 +2047,19 @@
 ((((-215)) . T)) 
 (((|#1|) . T) (((-568)) |has| |#1| (-630 (-568)))) 
 (((|#3|) |has| |#3| (-172))) 
-(-2198 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-370)) (|has| |#2| (-716)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047)) (|has| |#2| (-1090))) 
+(-2199 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-370)) (|has| |#2| (-716)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047)) (|has| |#2| (-1090))) 
 ((((-568)) . T)) 
 (((|#1| $) |has| |#1| (-281 |#1| |#1|))) 
 ((((-409 (-568))) . T) (($) . T) (((-409 |#1|)) . T) ((|#1|) . T)) 
 ((((-850)) . T)) 
 (((|#3|) . T)) 
-(((|#1| |#1|) . T) (($ $) -2198 (|has| |#1| (-285)) (|has| |#1| (-365))) (((-409 (-568)) (-409 (-568))) |has| |#1| (-365))) 
-((((-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) . T)) 
+(((|#1| |#1|) . T) (($ $) -2199 (|has| |#1| (-285)) (|has| |#1| (-365))) (((-409 (-568)) (-409 (-568))) |has| |#1| (-365))) 
+((((-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) . T)) 
 ((($) . T)) 
 ((($) . T) ((|#2|) |has| |#2| (-172)) (((-409 (-568))) |has| |#2| (-558))) 
 ((((-568) |#1|) . T)) 
 ((((-1161)) |has| (-409 |#2|) (-895 (-1161)))) 
-(((|#1|) . T) (($) -2198 (|has| |#1| (-285)) (|has| |#1| (-365))) (((-409 (-568))) |has| |#1| (-365))) 
+(((|#1|) . T) (($) -2199 (|has| |#1| (-285)) (|has| |#1| (-365))) (((-409 (-568))) |has| |#1| (-365))) 
 ((((-541)) |has| |#2| (-609 (-541)))) 
 ((((-679 |#2|)) . T) (((-850)) . T)) 
 (((|#1|) . T)) 
@@ -2067,8 +2067,8 @@
 (((|#4|) -12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) 
 ((((-864 |#1|)) . T)) 
 (((|#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
-(-2198 (|has| |#4| (-788)) (|has| |#4| (-840))) 
-(-2198 (|has| |#3| (-788)) (|has| |#3| (-840))) 
+(-2199 (|has| |#4| (-788)) (|has| |#4| (-840))) 
+(-2199 (|has| |#3| (-788)) (|has| |#3| (-840))) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
 (((|#4|) -12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) 
@@ -2084,7 +2084,7 @@
 ((((-409 (-568))) . T) (($) . T)) 
 ((((-409 (-568))) . T) (($) . T)) 
 ((((-409 (-568))) . T) (($) . T)) 
-(-2198 (|has| |#1| (-453)) (|has| |#1| (-1199))) 
+(-2199 (|has| |#1| (-453)) (|has| |#1| (-1199))) 
 ((($) . T)) 
 ((((-409 (-568))) |has| (-409 |#2|) (-1037 (-409 (-568)))) (((-568)) |has| (-409 |#2|) (-1037 (-568))) (((-409 |#2|)) . T)) 
 (((|#2|) . T) (((-568)) |has| |#2| (-630 (-568)))) 
@@ -2092,8 +2092,8 @@
 (|has| |#1| (-842)) 
 (((|#1|) . T) (((-568)) |has| |#1| (-630 (-568)))) 
 ((((-568)) . T)) 
-((($) -2198 (|has| |#1| (-365)) (|has| |#1| (-350))) (((-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-350))) ((|#1|) . T)) 
-((((-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) |has| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-303 (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))))) 
+((($) -2199 (|has| |#1| (-365)) (|has| |#1| (-350))) (((-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-350))) ((|#1|) . T)) 
+((((-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) |has| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-303 (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))))) 
 (((|#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 (|has| |#1| (-840)) 
 (|has| |#1| (-43 (-409 (-568)))) 
@@ -2123,11 +2123,11 @@
 ((((-850)) |has| |#1| (-1090))) 
 (|has| |#1| (-1181)) 
 (((|#1|) . T)) 
-(-2198 (|has| |#3| (-25)) (|has| |#3| (-137)) (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-370)) (|has| |#3| (-716)) (|has| |#3| (-788)) (|has| |#3| (-840)) (|has| |#3| (-1047)) (|has| |#3| (-1090))) 
+(-2199 (|has| |#3| (-25)) (|has| |#3| (-137)) (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-370)) (|has| |#3| (-716)) (|has| |#3| (-788)) (|has| |#3| (-840)) (|has| |#3| (-1047)) (|has| |#3| (-1090))) 
 ((((-1161) |#1|) |has| |#1| (-523 (-1161) |#1|))) 
 (((|#2|) . T)) 
-((($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
-((($) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 ((((-905 |#1|)) . T)) 
 ((($) . T)) 
 ((((-409 (-953 |#1|))) . T)) 
@@ -2135,10 +2135,10 @@
 ((((-541)) |has| |#4| (-609 (-541)))) 
 ((((-850)) . T) (((-634 |#4|)) . T)) 
 (|has| |#1| (-840)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 (|has| |#1| (-1090)) 
 (((|#1|) . T)) 
-(((|#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) (((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) |has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-303 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))))) 
+(((|#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) (((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) |has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-303 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))))) 
 (((|#2|) . T)) 
 (|has| |#1| (-365)) 
 (|has| |#1| (-842)) 
@@ -2146,11 +2146,11 @@
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 ((($) . T) (((-409 (-568))) . T)) 
-((($) -2198 (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) ((|#1|) |has| |#1| (-172))) 
+((($) -2199 (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) ((|#1|) |has| |#1| (-172))) 
 (|has| |#1| (-148)) 
 (|has| |#1| (-150)) 
-(-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-150)) (|has| |#1| (-365))) (|has| |#1| (-150))) 
-(-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-148)) (|has| |#1| (-365))) (|has| |#1| (-148))) 
+(-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-150)) (|has| |#1| (-365))) (|has| |#1| (-150))) 
+(-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-148)) (|has| |#1| (-365))) (|has| |#1| (-148))) 
 (|has| |#1| (-148)) 
 (|has| |#1| (-150)) 
 (|has| |#1| (-150)) 
@@ -2180,9 +2180,9 @@
 ((((-850)) . T)) 
 ((((-850)) . T)) 
 ((((-541)) |has| |#1| (-609 (-541)))) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 ((((-1161) |#1|) |has| |#1| (-523 (-1161) |#1|)) ((|#1| |#1|) |has| |#1| (-303 |#1|))) 
-(((|#1|) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)))) 
+(((|#1|) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)))) 
 ((((-310 |#1|)) . T)) 
 (((|#2|) |has| |#2| (-365))) 
 (((|#2|) . T)) 
@@ -2203,13 +2203,13 @@
 (|has| |#1| (-148)) 
 (|has| |#1| (-150)) 
 ((($ $) . T)) 
-(-2198 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-478)) (|has| |#1| (-716)) (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047)) (|has| |#1| (-1102)) (|has| |#1| (-1090))) 
+(-2199 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-478)) (|has| |#1| (-716)) (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047)) (|has| |#1| (-1102)) (|has| |#1| (-1090))) 
 (|has| |#1| (-558)) 
 (((|#2|) . T)) 
 ((((-568)) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 (((|#1|) . T)) 
-(-2198 (|has| |#1| (-148)) (|has| |#1| (-150)) (|has| |#1| (-172)) (|has| |#1| (-558)) (|has| |#1| (-1047))) 
+(-2199 (|has| |#1| (-148)) (|has| |#1| (-150)) (|has| |#1| (-172)) (|has| |#1| (-558)) (|has| |#1| (-1047))) 
 ((((-581 |#1|)) . T)) 
 ((($) . T)) 
 (((|#1| (-64 |#1|) (-64 |#1|)) . T)) 
@@ -2218,7 +2218,7 @@
 ((($) . T)) 
 (((|#1|) . T)) 
 ((((-850)) . T)) 
-(((|#2|) |has| |#2| (-6 (-4521 "*")))) 
+(((|#2|) |has| |#2| (-6 (-4523 "*")))) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
@@ -2236,11 +2236,11 @@
 ((((-1161) |#1|) . T)) 
 (((|#4|) . T)) 
 (((|#1|) . T)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-350))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-350))) 
 ((((-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) (((-568)) |has| |#1| (-1037 (-568))) ((|#1|) . T)) 
 ((((-1161) (-57)) . T)) 
 ((((-850)) . T)) 
-(-2198 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-370)) (|has| |#2| (-716)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047)) (|has| |#2| (-1090))) 
+(-2199 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-370)) (|has| |#2| (-716)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047)) (|has| |#2| (-1090))) 
 ((($) . T) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 ((((-1228 |#2| |#3| |#4|) (-314 |#2| |#3| |#4|)) . T)) 
 ((((-1229 |#1| |#2| |#3| |#4|) (-1229 |#1| |#2| |#3| |#4|)) . T) (((-409 (-568)) (-409 (-568))) . T) (($ $) . T)) 
@@ -2262,16 +2262,16 @@
 ((((-1161)) . T)) 
 (((|#1|) . T)) 
 (((|#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) 
-(-2198 (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-904))) 
+(-2199 (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-904))) 
 (((|#2| |#3|) . T)) 
-(-2198 (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
+(-2199 (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
 (((|#1| (-534 |#2|)) . T)) 
 (((|#1| (-763)) . T)) 
 (((|#1| (-534 (-1079 (-1161)))) . T)) 
 (((|#1|) |has| |#1| (-172))) 
 (((|#1|) . T)) 
 (|has| |#2| (-904)) 
-(-2198 (|has| |#2| (-788)) (|has| |#2| (-840))) 
+(-2199 (|has| |#2| (-788)) (|has| |#2| (-840))) 
 ((((-850)) . T)) 
 ((($ $) . T) (((-1228 |#2| |#3| |#4|) (-1228 |#2| |#3| |#4|)) . T) (((-409 (-568)) (-409 (-568))) |has| (-1228 |#2| |#3| |#4|) (-43 (-409 (-568))))) 
 ((((-905 |#1|)) . T)) 
@@ -2280,14 +2280,14 @@
 ((($) . T)) 
 ((($) . T)) 
 (|has| |#1| (-365)) 
-(-2198 (|has| |#1| (-301)) (|has| |#1| (-365)) (|has| |#1| (-350)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-301)) (|has| |#1| (-365)) (|has| |#1| (-350)) (|has| |#1| (-558))) 
 (|has| |#1| (-365)) 
 ((($) . T) (((-1228 |#2| |#3| |#4|)) . T) (((-409 (-568))) |has| (-1228 |#2| |#3| |#4|) (-43 (-409 (-568))))) 
 (((|#1| |#2|) . T)) 
 (|has| |#2| (-558)) 
 ((((-1159 |#1| |#2| |#3|)) |has| |#1| (-365))) 
-(-2198 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-365)) (|has| |#1| (-350))) 
-(-2198 (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047))) 
+(-2199 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-365)) (|has| |#1| (-350))) 
+(-2199 (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047))) 
 ((((-568)) |has| |#1| (-630 (-568))) ((|#1|) . T)) 
 (((|#1| |#2|) . T)) 
 ((((-850)) . T)) 
@@ -2295,12 +2295,12 @@
 ((((-121)) . T)) 
 (((|#1| |#2| |#3| |#4|) . T)) 
 (((|#1| |#2| |#3| |#4|) . T)) 
-((($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 ((((-409 |#2|)) . T) (((-409 (-568))) . T) (($) . T)) 
 (((|#1| |#2| |#3| |#4|) . T)) 
 (((|#1| (-534 (-852 |#2|)) (-852 |#2|) (-775 |#1| (-852 |#2|))) . T)) 
 (|has| |#2| (-365)) 
-((($) -2198 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#1| (-172)) (|has| |#1| (-558))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (|has| |#1| (-842)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
@@ -2323,21 +2323,21 @@
 (((|#1|) |has| |#1| (-172))) 
 ((((-850)) . T)) 
 (((|#4| |#4|) -12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) 
-(((|#2|) -2198 (|has| |#2| (-6 (-4521 "*"))) (|has| |#2| (-172)))) 
-(-2198 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
-(-2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(((|#2|) -2199 (|has| |#2| (-6 (-4523 "*"))) (|has| |#2| (-172)))) 
+(-2199 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
+(-2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
 (|has| |#2| (-842)) 
 (|has| |#2| (-904)) 
 (|has| |#1| (-904)) 
 (((|#2|) |has| |#2| (-172))) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 ((((-1235 |#1| |#2| |#3|)) |has| |#1| (-365))) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
 ((((-541)) . T) (((-568)) . T) (((-887 (-568))) . T) (((-381)) . T) (((-215)) . T)) 
 (((|#1| |#2|) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
-((((-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
+((((-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) . T)) 
 (((|#1|) . T)) 
 ((((-860)) . T) (((-568)) . T) (((-409 (-568))) . T)) 
 ((((-409 (-568))) . T) (((-568)) . T)) 
@@ -2346,7 +2346,7 @@
 (((|#1| |#2|) . T)) 
 (((|#1| (-409 (-568))) . T)) 
 (((|#1|) . T)) 
-(-2198 (|has| |#1| (-285)) (|has| |#1| (-365))) 
+(-2199 (|has| |#1| (-285)) (|has| |#1| (-365))) 
 ((((-147)) . T)) 
 ((((-409 |#2|)) . T) (((-409 (-568))) . T) (($) . T)) 
 (|has| |#1| (-840)) 
@@ -2362,7 +2362,7 @@
 ((((-409 (-568))) . T) (($) . T)) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 (((|#2| |#2|) . T) ((|#1| |#1|) . T)) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
@@ -2373,7 +2373,7 @@
 (((|#1|) . T)) 
 ((((-850)) . T)) 
 ((((-634 (-147))) . T) (((-1143)) . T)) 
-((((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) . T)) 
+((((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) . T)) 
 ((((-1161) |#1|) |has| |#1| (-523 (-1161) |#1|)) ((|#1| |#1|) |has| |#1| (-303 |#1|))) 
 (|has| |#1| (-842)) 
 ((((-850)) . T)) 
@@ -2385,16 +2385,16 @@
 ((((-850)) . T) (((-634 |#4|)) . T)) 
 (((|#2|) . T)) 
 ((((-905 |#1|)) . T) (((-409 (-568))) . T) (($) . T)) 
-(-2198 (|has| |#4| (-172)) (|has| |#4| (-716)) (|has| |#4| (-840)) (|has| |#4| (-1047))) 
-(-2198 (|has| |#3| (-172)) (|has| |#3| (-716)) (|has| |#3| (-840)) (|has| |#3| (-1047))) 
+(-2199 (|has| |#4| (-172)) (|has| |#4| (-716)) (|has| |#4| (-840)) (|has| |#4| (-1047))) 
+(-2199 (|has| |#3| (-172)) (|has| |#3| (-716)) (|has| |#3| (-840)) (|has| |#3| (-1047))) 
 ((((-1161) (-57)) . T)) 
-(-2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
-(-2198 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
-(-2198 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
+(-2199 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
+(-2199 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
 (|has| |#1| (-904)) 
 (|has| |#1| (-904)) 
 ((((-2 (|:| |k| (-568)) (|:| |c| |#1|))) . T)) 
@@ -2411,7 +2411,7 @@
 (|has| |#1| (-43 (-409 (-568)))) 
 (|has| |#1| (-43 (-409 (-568)))) 
 (|has| |#1| (-43 (-409 (-568)))) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
 (|has| |#1| (-815)) 
 ((((-850)) |has| |#1| (-1090))) 
 ((((-905 |#1|) (-905 |#1|)) . T) (($ $) . T) (((-409 (-568)) (-409 (-568))) . T)) 
@@ -2430,11 +2430,11 @@
 (|has| |#1| (-150)) 
 (|has| |#1| (-148)) 
 (((|#2|) . T)) 
-(-2198 (|has| |#1| (-148)) (|has| |#1| (-370))) 
-(-2198 (|has| |#1| (-148)) (|has| |#1| (-370))) 
-(-2198 (|has| |#1| (-148)) (|has| |#1| (-370))) 
-((((-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) . T)) 
-((((-57)) . T) (((-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) . T)) 
+(-2199 (|has| |#1| (-148)) (|has| |#1| (-370))) 
+(-2199 (|has| |#1| (-148)) (|has| |#1| (-370))) 
+(-2199 (|has| |#1| (-148)) (|has| |#1| (-370))) 
+((((-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) . T)) 
+((((-57)) . T) (((-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) . T)) 
 (|has| |#1| (-350)) 
 ((((-568)) . T)) 
 ((((-850)) . T)) 
@@ -2443,14 +2443,14 @@
 ((((-1229 |#1| |#2| |#3| |#4|) $) |has| (-1229 |#1| |#2| |#3| |#4|) (-281 (-1229 |#1| |#2| |#3| |#4|) (-1229 |#1| |#2| |#3| |#4|)))) 
 (|has| |#1| (-365)) 
 ((((-1075) |#1|) . T) (((-1075) $) . T) (($ $) . T)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-350))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-350))) 
 ((((-409 (-568)) (-409 (-568))) . T) (((-688) (-688)) . T) (($ $) . T)) 
 ((((-310 |#1|)) . T) (($) . T)) 
 (((|#1|) . T) (((-409 (-568))) |has| |#1| (-365))) 
 (|has| |#1| (-1090)) 
 (((|#1|) . T)) 
-(((|#1|) -2198 (|has| |#2| (-369 |#1|)) (|has| |#2| (-419 |#1|)))) 
-(((|#1|) -2198 (|has| |#2| (-369 |#1|)) (|has| |#2| (-419 |#1|)))) 
+(((|#1|) -2199 (|has| |#2| (-369 |#1|)) (|has| |#2| (-419 |#1|)))) 
+(((|#1|) -2199 (|has| |#2| (-369 |#1|)) (|has| |#2| (-419 |#1|)))) 
 (((|#2|) . T)) 
 ((((-409 (-568))) . T) (((-688)) . T) (($) . T)) 
 (|has| |#1| (-43 (-409 (-568)))) 
@@ -2471,7 +2471,7 @@
 (((|#2|) . T)) 
 (((|#1|) . T)) 
 ((((-568)) . T)) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
 (((|#2|) . T) (((-568)) |has| |#2| (-630 (-568)))) 
 (((|#1| |#2|) . T)) 
 ((($) . T)) 
@@ -2509,20 +2509,20 @@
 (|has| |#2| (-1021)) 
 ((($) . T)) 
 (|has| |#1| (-904)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
-((($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
+((($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 ((((-568)) . T)) 
 ((($) . T)) 
 (((|#2|) . T)) 
 (((|#1|) . T)) 
-((($) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (((|#1|) . T) (($) . T)) 
 ((($) . T)) 
 (|has| |#1| (-365)) 
 ((((-905 |#1|)) . T)) 
-((($) -2198 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 ((($ $) . T) (((-409 (-568)) (-409 (-568))) . T)) 
-(-2198 (|has| |#1| (-370)) (|has| |#1| (-842))) 
+(-2199 (|has| |#1| (-370)) (|has| |#1| (-842))) 
 (((|#1|) . T)) 
 ((((-850)) . T)) 
 ((((-1161)) -12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) 
@@ -2530,15 +2530,15 @@
 ((((-1161)) -12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) 
 ((($) . T) (((-409 (-568))) . T)) 
 ((((-763) |#1|) . T)) 
-(((|#2| (-232 (-1697 |#1|) (-763))) . T)) 
+(((|#2| (-232 (-1699 |#1|) (-763))) . T)) 
 (((|#1| (-534 |#3|)) . T)) 
 ((((-409 (-568))) . T)) 
-(-2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
 ((((-850)) . T)) 
-((((-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) |has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-303 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))))) 
+((((-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) |has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-303 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))))) 
 (|has| |#1| (-904)) 
 (|has| |#2| (-365)) 
-(-2198 (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
+(-2199 (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
 (((|#1|) . T)) 
 ((((-169 (-381))) . T) (((-215)) . T) (((-381)) . T)) 
 ((((-850)) . T)) 
@@ -2557,11 +2557,11 @@
 (|has| |#1| (-43 (-409 (-568)))) 
 (|has| |#1| (-43 (-409 (-568)))) 
 (|has| |#1| (-43 (-409 (-568)))) 
-(-2198 (|has| |#1| (-301)) (|has| |#1| (-365)) (|has| |#1| (-350))) 
+(-2199 (|has| |#1| (-301)) (|has| |#1| (-365)) (|has| |#1| (-350))) 
 (|has| |#1| (-43 (-409 (-568)))) 
 (-12 (|has| |#1| (-550)) (|has| |#1| (-823))) 
 ((((-850)) . T)) 
-((((-1161)) -2198 (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))) (-12 (|has| |#1| (-365)) (|has| |#2| (-895 (-1161)))))) 
+((((-1161)) -2199 (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))) (-12 (|has| |#1| (-365)) (|has| |#2| (-895 (-1161)))))) 
 (|has| |#1| (-365)) 
 ((((-1161)) -12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) 
 (|has| |#1| (-365)) 
@@ -2573,7 +2573,7 @@
 (((|#2|) |has| |#1| (-365))) 
 (((|#2|) |has| |#1| (-365))) 
 ((((-850)) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 (((|#1|) . T)) 
 (((|#1|) |has| |#1| (-172))) 
 (((|#1|) . T)) 
@@ -2599,9 +2599,9 @@
 ((((-381)) -12 (|has| |#1| (-365)) (|has| |#2| (-881 (-381)))) (((-568)) -12 (|has| |#1| (-365)) (|has| |#2| (-881 (-568))))) 
 (|has| |#1| (-365)) 
 (((|#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-558))) 
 (|has| |#1| (-365)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-558))) 
 (|has| |#1| (-365)) 
 (|has| |#1| (-558)) 
 (|has| |#1| (-558)) 
@@ -2609,22 +2609,22 @@
 (((|#3|) . T)) 
 (((|#1|) . T)) 
 (|has| |#2| (-842)) 
-(-2198 (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
+(-2199 (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
 (((|#2|) . T)) 
 (((|#2|) . T)) 
-(-2198 (|has| |#2| (-172)) (|has| |#2| (-716)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
-((((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+(-2199 (|has| |#2| (-172)) (|has| |#2| (-716)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
+((((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 (|has| |#1| (-43 (-409 (-568)))) 
 (((|#1| |#2|) . T)) 
 (|has| |#1| (-43 (-409 (-568)))) 
-(-2198 (|has| |#1| (-148)) (|has| |#1| (-370))) 
+(-2199 (|has| |#1| (-148)) (|has| |#1| (-370))) 
 (|has| |#1| (-150)) 
 ((((-1143) |#1|) . T)) 
-(-2198 (|has| |#1| (-148)) (|has| |#1| (-370))) 
+(-2199 (|has| |#1| (-148)) (|has| |#1| (-370))) 
 (|has| |#1| (-150)) 
-(-2198 (|has| |#1| (-148)) (|has| |#1| (-370))) 
+(-2199 (|has| |#1| (-148)) (|has| |#1| (-370))) 
 (|has| |#1| (-150)) 
 ((((-581 |#1|)) . T)) 
 ((($) . T)) 
@@ -2634,7 +2634,7 @@
 (|has| |#1| (-43 (-409 (-568)))) 
 ((((-860)) . T) (((-409 (-568))) . T) (($) . T)) 
 ((($) . T) (((-409 (-568))) . T)) 
-(-2198 (|has| |#1| (-148)) (|has| |#1| (-350))) 
+(-2199 (|has| |#1| (-148)) (|has| |#1| (-350))) 
 (|has| |#1| (-150)) 
 ((((-409 |#2|) (-409 |#2|)) . T) (((-409 (-568)) (-409 (-568))) . T) (($ $) . T)) 
 ((((-409 (-568))) |has| |#2| (-1037 (-568))) (((-568)) |has| |#2| (-1037 (-568))) (((-1161)) |has| |#2| (-1037 (-1161))) ((|#2|) . T)) 
@@ -2661,7 +2661,7 @@
 (|has| |#1| (-786)) 
 ((((-850)) . T)) 
 ((((-541)) |has| |#1| (-609 (-541)))) 
-((((-850)) -2198 (|has| |#1| (-842)) (|has| |#1| (-1090)))) 
+((((-850)) -2199 (|has| |#1| (-842)) (|has| |#1| (-1090)))) 
 ((((-123)) . T) ((|#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
@@ -2675,7 +2675,7 @@
 ((((-850)) . T)) 
 ((((-905 |#1|) (-905 |#1|)) . T) (($ $) . T) (((-409 (-568)) (-409 (-568))) . T)) 
 (((|#1|) . T)) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-558))) 
 (((|#1|) . T)) 
 ((((-905 |#1|)) . T) (($) . T) (((-409 (-568))) . T)) 
 (|has| |#1| (-365)) 
@@ -2683,7 +2683,7 @@
 ((((-568)) . T)) 
 ((((-2 (|:| |k| (-568)) (|:| |c| |#1|))) . T)) 
 ((((-568)) . T)) 
-(-2198 (|has| |#2| (-788)) (|has| |#2| (-840))) 
+(-2199 (|has| |#2| (-788)) (|has| |#2| (-840))) 
 ((((-169 (-381))) . T) (((-215)) . T) (((-381)) . T)) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
@@ -2697,7 +2697,7 @@
 (|has| |#1| (-365)) 
 ((((-850)) |has| |#1| (-1090))) 
 ((((-850)) |has| |#1| (-1090))) 
-(-2198 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-478)) (|has| |#1| (-716)) (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047)) (|has| |#1| (-1102)) (|has| |#1| (-1090))) 
+(-2199 (|has| |#1| (-21)) (|has| |#1| (-25)) (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-478)) (|has| |#1| (-716)) (|has| |#1| (-895 (-1161))) (|has| |#1| (-1047)) (|has| |#1| (-1102)) (|has| |#1| (-1090))) 
 (|has| |#1| (-1136)) 
 ((($) |has| |#1| (-558)) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 ((((-568) |#1|) . T)) 
@@ -2721,18 +2721,18 @@
 (((|#2|) |has| |#2| (-172)) (($) . T) (((-409 (-568))) |has| |#2| (-558))) 
 ((((-409 |#2|)) . T) (((-409 (-568))) . T) (($) . T)) 
 (|has| |#1| (-558)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-558))) 
 ((((-381)) . T)) 
 (|has| |#1| (-1090)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (|has| |#1| (-365)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-558))) 
 (|has| |#1| (-365)) 
 (|has| |#1| (-558)) 
 (|has| |#1| (-1090)) 
 ((((-775 |#1| (-852 |#2|))) |has| (-775 |#1| (-852 |#2|)) (-303 (-775 |#1| (-852 |#2|))))) 
-(-2198 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
+(-2199 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
 (((|#1|) . T)) 
 (((|#2| |#3|) . T)) 
 (|has| |#2| (-904)) 
@@ -2742,14 +2742,14 @@
 (|has| |#1| (-225)) 
 (((|#1| (-534 (-1079 (-1161)))) . T)) 
 (|has| |#2| (-365)) 
-((((-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) . T)) 
+((((-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) . T)) 
 (((|#1|) . T)) 
 ((((-860)) . T) (((-409 (-568))) . T)) 
 ((((-409 (-568))) . T)) 
 (((|#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
-(-2198 (|has| |#3| (-788)) (|has| |#3| (-840))) 
+(-2199 (|has| |#3| (-788)) (|has| |#3| (-840))) 
 ((((-850)) . T)) 
 (((|#1|) . T)) 
 ((($ $) . T) (((-607 $) $) . T)) 
@@ -2757,9 +2757,9 @@
 ((((-568)) . T)) 
 (((|#3|) . T)) 
 ((((-850)) . T)) 
-(-2198 (|has| |#1| (-301)) (|has| |#1| (-365)) (|has| |#1| (-350))) 
+(-2199 (|has| |#1| (-301)) (|has| |#1| (-365)) (|has| |#1| (-350))) 
 ((((-850)) . T)) 
-(-2198 (|has| |#1| (-148)) (|has| |#1| (-150)) (|has| |#1| (-172)) (|has| |#1| (-558)) (|has| |#1| (-1047))) 
+(-2199 (|has| |#1| (-148)) (|has| |#1| (-150)) (|has| |#1| (-172)) (|has| |#1| (-558)) (|has| |#1| (-1047))) 
 ((((-568)) |has| |#2| (-630 (-568))) ((|#2|) . T)) 
 ((((-581 |#1|) (-581 |#1|)) . T) (($ $) . T) (((-409 (-568)) (-409 (-568))) . T)) 
 ((($ $) . T) (((-409 (-568)) (-409 (-568))) . T)) 
@@ -2768,33 +2768,33 @@
 ((((-581 |#1|)) . T) (($) . T) (((-409 (-568))) . T)) 
 ((($) . T) (((-409 (-568))) . T)) 
 ((($) . T) (((-409 (-568))) . T)) 
-(((|#2|) |has| |#2| (-6 (-4521 "*")))) 
+(((|#2|) |has| |#2| (-6 (-4523 "*")))) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 ((((-288 |#3|)) . T)) 
 (((|#1|) . T)) 
-((((-409 (-568)) (-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2| |#2|) . T) (($ $) -2198 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
+((((-409 (-568)) (-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2| |#2|) . T) (($ $) -2199 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
 (((|#2| |#2|) . T) ((|#6| |#6|) . T)) 
 ((($) . T) (((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) . T)) 
 ((($) . T) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (((|#1|) . T) (((-409 (-568))) . T) (($) . T)) 
 (((|#1|) . T) (((-409 (-568))) . T) (($) . T)) 
 (((|#1|) . T) (((-409 (-568))) . T) (($) . T)) 
-((($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
-((($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (((|#2|) . T)) 
-((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) . T) (($) -2198 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
+((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) . T) (($) -2199 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
 (((|#2|) . T) ((|#6|) . T)) 
-((($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 ((((-850)) . T)) 
-((($) -2198 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
-((($) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (|has| |#2| (-904)) 
 (|has| |#1| (-904)) 
-((($) -2198 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 ((((-568) (-568)) . T)) 
 (((|#1|) . T)) 
-((((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) . T)) 
+((((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) . T)) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (((|#1| |#1|) . T)) 
@@ -2809,16 +2809,16 @@
 (((|#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) 
 ((((-409 (-568)) (-409 (-568))) . T)) 
 ((((-409 (-568))) . T)) 
-(-2198 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
+(-2199 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
-(-2198 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
+(-2199 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
 ((((-541)) . T)) 
 ((((-850)) . T)) 
 ((((-1161)) |has| |#2| (-895 (-1161))) (((-1075)) . T)) 
 ((((-1228 |#2| |#3| |#4|)) . T)) 
 ((((-905 |#1|)) . T)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
 ((($) . T) (((-409 (-568))) . T)) 
 (-12 (|has| |#1| (-365)) (|has| |#2| (-815))) 
 (-12 (|has| |#1| (-365)) (|has| |#2| (-815))) 
@@ -2827,14 +2827,14 @@
 ((($ $) . T) (((-409 (-568)) (-409 (-568))) . T)) 
 ((((-1161)) |has| |#1| (-895 (-1161)))) 
 ((((-905 |#1|)) . T) (((-409 (-568))) . T) (($) . T)) 
-((($) . T) (((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) ((|#1|) . T)) 
-((((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1| |#1|) . T) (($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-558)))) 
+((($) . T) (((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) ((|#1|) . T)) 
+((((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1| |#1|) . T) (($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-558)))) 
 ((($) . T) (((-409 (-568))) . T) ((|#1|) . T)) 
 (((|#1|) . T) (((-409 (-568))) . T) (($) . T)) 
 ((($) . T) (((-409 (-568))) . T)) 
 (((|#1|) . T) (((-409 (-568))) . T) (((-568)) . T) (($) . T)) 
 (((|#2|) |has| |#2| (-1047)) (((-568)) -12 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047)))) 
-((((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) . T) (($) -2198 (|has| |#1| (-172)) (|has| |#1| (-558)))) 
+((((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) . T) (($) -2199 (|has| |#1| (-172)) (|has| |#1| (-558)))) 
 (|has| |#1| (-558)) 
 (((|#1|) |has| |#1| (-365))) 
 ((((-568)) . T)) 
@@ -2849,16 +2849,16 @@
 ((((-568) (-763)) . T) ((|#3| (-763)) . T)) 
 ((((-1075) |#1|) . T) (((-1075) $) . T) (($ $) . T)) 
 (((|#1|) . T)) 
-(((|#1| |#2| (-242 |#2| |#1|) (-232 (-1697 |#2|) (-763)) (-966 |#1|) (-774 |#1|) (-921 |#1|) (-236 (-921 |#1|)) |#3|) . T)) 
+(((|#1| |#2| (-242 |#2| |#1|) (-232 (-1699 |#2|) (-763)) (-966 |#1|) (-774 |#1|) (-921 |#1|) (-236 (-921 |#1|)) |#3|) . T)) 
 (((|#2|) . T)) 
 (((|#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 ((((-850)) . T)) 
 (((|#1| |#2|) . T)) 
 (|has| |#2| (-815)) 
 (|has| |#2| (-815)) 
-((((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) ((|#2|) |has| |#1| (-365)) (($) . T) ((|#1|) . T)) 
+((((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) ((|#2|) |has| |#1| (-365)) (($) . T) ((|#1|) . T)) 
 (((|#1|) . T) (((-568)) |has| |#1| (-1037 (-568))) (((-409 (-568))) |has| |#1| (-1037 (-409 (-568))))) 
-(((|#1|) . T) (((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) . T)) 
+(((|#1|) . T) (((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) . T)) 
 (((|#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 ((((-568)) |has| |#1| (-881 (-568))) (((-381)) |has| |#1| (-881 (-381)))) 
 (((|#1|) . T)) 
@@ -2883,15 +2883,15 @@
 (((|#2| (-763)) . T)) 
 ((((-1161)) . T)) 
 ((((-864 |#1|)) . T)) 
-(-2198 (|has| |#3| (-25)) (|has| |#3| (-137)) (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-788)) (|has| |#3| (-840)) (|has| |#3| (-1047))) 
-(-2198 (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-840)) (|has| |#3| (-1047))) 
+(-2199 (|has| |#3| (-25)) (|has| |#3| (-137)) (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-788)) (|has| |#3| (-840)) (|has| |#3| (-1047))) 
+(-2199 (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-840)) (|has| |#3| (-1047))) 
 ((((-850)) . T)) 
 (((|#1|) . T)) 
-(-2198 (|has| |#2| (-788)) (|has| |#2| (-840))) 
-(-2198 (-12 (|has| |#1| (-788)) (|has| |#2| (-788))) (-12 (|has| |#1| (-842)) (|has| |#2| (-842)))) 
+(-2199 (|has| |#2| (-788)) (|has| |#2| (-840))) 
+(-2199 (-12 (|has| |#1| (-788)) (|has| |#2| (-788))) (-12 (|has| |#1| (-842)) (|has| |#2| (-842)))) 
 ((((-864 |#1|)) . T)) 
 (((|#1|) . T)) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
 (|has| |#1| (-370)) 
 (|has| |#1| (-370)) 
 (|has| |#1| (-370)) 
@@ -2920,7 +2920,7 @@
 (((|#1|) . T)) 
 ((((-850)) . T)) 
 (|has| |#2| (-904)) 
-((((-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) . T)) 
+((((-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) . T)) 
 ((((-541)) |has| |#2| (-609 (-541))) (((-887 (-381))) |has| |#2| (-609 (-887 (-381)))) (((-887 (-568))) |has| |#2| (-609 (-887 (-568))))) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
@@ -2942,7 +2942,7 @@
 ((((-850)) . T)) 
 (((|#1|) . T)) 
 ((((-850)) . T)) 
-((($) -2198 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (((|#1|) |has| |#1| (-172)) (($) . T)) 
 ((((-568)) . T) (((-409 (-568))) . T)) 
 (((|#1|) |has| |#1| (-303 |#1|))) 
@@ -2955,12 +2955,12 @@
 ((((-409 |#2|) |#3|) . T)) 
 (((|#1|) . T)) 
 (|has| |#1| (-1090)) 
-(((|#2| (-493 (-1697 |#1|) (-763))) . T)) 
+(((|#2| (-493 (-1699 |#1|) (-763))) . T)) 
 ((((-568) |#1|) . T)) 
 (((|#2| |#2|) . T)) 
 (((|#1| (-534 (-1161))) . T)) 
 ((((-2 (|:| |k| (-568)) (|:| |c| |#1|))) . T)) 
-(-2198 (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
+(-2199 (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
 ((((-568)) . T)) 
 (((|#2|) . T)) 
 (((|#2|) . T)) 
@@ -2971,9 +2971,9 @@
 ((($) . T) (((-409 (-568))) . T)) 
 ((($) . T)) 
 ((($) . T)) 
-(-2198 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
+(-2199 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
 (((|#1|) . T)) 
-((($) -2198 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 ((((-850)) . T)) 
 ((((-147)) . T)) 
 (((|#1|) . T) (((-409 (-568))) . T)) 
@@ -3009,27 +3009,27 @@
 ((((-568)) . T)) 
 ((((-1161)) -12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))) 
 ((((-1161)) -12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) 
-(-2198 (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
+(-2199 (|has| |#2| (-365)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
 (((|#1|) . T)) 
 (|has| |#1| (-225)) 
 (((|#1| (-534 |#3|)) . T)) 
-(((|#2| (-232 (-1697 |#1|) (-763))) . T)) 
+(((|#2| (-232 (-1699 |#1|) (-763))) . T)) 
 (|has| |#1| (-370)) 
 (|has| |#1| (-370)) 
 (|has| |#1| (-370)) 
 (|has| |#2| (-904)) 
 (((|#1|) . T) (($) . T)) 
-(-2198 (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
+(-2199 (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
 (((|#1| (-534 |#2|)) . T)) 
 (((|#1| (-763)) . T)) 
-(-2198 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
-(-2198 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
+(-2199 (|has| |#2| (-25)) (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
+(-2199 (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) 
 ((((-850)) . T)) 
-(-2198 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-137)) (|has| |#2| (-137))) (-12 (|has| |#1| (-788)) (|has| |#2| (-788)))) 
+(-2199 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-137)) (|has| |#2| (-137))) (-12 (|has| |#1| (-788)) (|has| |#2| (-788)))) 
 (|has| |#1| (-558)) 
-(-2198 (|has| |#3| (-137)) (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-788)) (|has| |#3| (-840)) (|has| |#3| (-1047))) 
-(-2198 (|has| |#2| (-172)) (|has| |#2| (-716)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
+(-2199 (|has| |#3| (-137)) (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-788)) (|has| |#3| (-840)) (|has| |#3| (-1047))) 
+(-2199 (|has| |#2| (-172)) (|has| |#2| (-716)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
 (((|#1|) |has| |#1| (-172))) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
@@ -3037,7 +3037,7 @@
 (((|#3|) |has| |#3| (-1047))) 
 (-12 (|has| |#1| (-365)) (|has| |#2| (-815))) 
 (-12 (|has| |#1| (-365)) (|has| |#2| (-815))) 
-((((-850)) -2198 (|has| |#1| (-842)) (|has| |#1| (-1090)))) 
+((((-850)) -2199 (|has| |#1| (-842)) (|has| |#1| (-1090)))) 
 ((((-541)) |has| |#1| (-609 (-541)))) 
 ((((-409 |#2|)) . T) (((-409 (-568))) . T) (($) . T)) 
 ((($ $) . T) (((-409 (-568)) (-409 (-568))) . T)) 
@@ -3054,14 +3054,14 @@
 (((|#2|) |has| |#2| (-1047)) (((-568)) -12 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047)))) 
 (((|#1|) . T)) 
 (|has| |#2| (-365)) 
-((((-409 (-568)) (-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2| |#2|) . T) (($ $) -2198 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
-((($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((((-409 (-568)) (-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2| |#2|) . T) (($ $) -2199 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
+((($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (((|#1| |#1|) . T) (($ $) . T) (((-409 (-568)) (-409 (-568))) . T)) 
 (((|#1| |#1|) . T) (($ $) . T) (((-409 (-568)) (-409 (-568))) . T)) 
 (((|#1| |#1|) . T) (($ $) . T) (((-409 (-568)) (-409 (-568))) . T)) 
 (((|#2| |#2|) . T)) 
-((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) . T) (($) -2198 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
-((($) -2198 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) . T) (($) -2199 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
+((($) -2199 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (((|#1|) . T) (($) . T) (((-409 (-568))) . T)) 
 (((|#1|) . T) (($) . T) (((-409 (-568))) . T)) 
 (((|#1|) . T) (($) . T) (((-409 (-568))) . T)) 
@@ -3082,25 +3082,25 @@
 (((|#1|) |has| |#2| (-419 |#1|))) 
 (((|#1|) |has| |#2| (-419 |#1|))) 
 ((((-905 |#1|)) . T) (((-409 (-568))) . T) (($) . T)) 
-((((-850)) -2198 (|has| |#1| (-842)) (|has| |#1| (-1090)))) 
+((((-850)) -2199 (|has| |#1| (-842)) (|has| |#1| (-1090)))) 
 ((((-541)) |has| |#1| (-609 (-541)))) 
 ((((-850)) . T)) 
-((((-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) |has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-303 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))))) 
-(-2198 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
+((((-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) |has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-303 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))))) 
+(-2199 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
 ((((-568) |#1|) . T)) 
 ((((-568) |#1|) . T)) 
 ((((-568) |#1|) . T)) 
-(-2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
 ((((-568) |#1|) . T)) 
 (((|#1|) . T)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
-(-2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
 ((((-1161)) |has| |#1| (-895 (-1161))) (((-813 (-1161))) . T)) 
-(-2198 (|has| |#3| (-137)) (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-788)) (|has| |#3| (-840)) (|has| |#3| (-1047))) 
+(-2199 (|has| |#3| (-137)) (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-788)) (|has| |#3| (-840)) (|has| |#3| (-1047))) 
 ((((-814 |#1|)) . T)) 
 (((|#1| |#2|) . T)) 
 ((((-850)) . T)) 
-(-2198 (|has| |#3| (-172)) (|has| |#3| (-716)) (|has| |#3| (-840)) (|has| |#3| (-1047))) 
+(-2199 (|has| |#3| (-172)) (|has| |#3| (-716)) (|has| |#3| (-840)) (|has| |#3| (-1047))) 
 (((|#1| |#2|) . T)) 
 (|has| |#1| (-43 (-409 (-568)))) 
 ((((-850)) . T)) 
@@ -3108,17 +3108,17 @@
 (((|#1|) |has| |#1| (-172)) (($) |has| |#1| (-558)) (((-409 (-568))) |has| |#1| (-558))) 
 (((|#2|) . T) (((-568)) |has| |#2| (-630 (-568)))) 
 (|has| |#1| (-365)) 
-(-2198 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (-12 (|has| |#1| (-365)) (|has| |#2| (-225)))) 
+(-2199 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (-12 (|has| |#1| (-365)) (|has| |#2| (-225)))) 
 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) 
 (|has| |#1| (-365)) 
 (((|#1|) . T)) 
-((((-409 (-568)) (-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) ((|#1| |#1|) . T)) 
+((((-409 (-568)) (-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) ((|#1| |#1|) . T)) 
 ((((-568) |#1|) . T)) 
 ((((-310 |#1|)) . T)) 
 ((((-409 (-568)) (-409 (-568))) . T) (($ $) . T) ((|#1| |#1|) . T)) 
 (((|#1| |#1|) . T) (((-409 (-568)) (-409 (-568))) . T) (($ $) . T)) 
 ((((-688) (-1157 (-688))) . T)) 
-((((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) ((|#1|) . T)) 
+((((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) (($) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) ((|#1|) . T)) 
 ((((-409 (-568))) . T) (($) . T) ((|#1|) . T)) 
 (((|#1|) . T) (((-409 (-568))) . T) (($) . T)) 
 (((|#1| |#2| |#3| |#4|) . T)) 
@@ -3137,13 +3137,13 @@
 ((((-1229 |#1| |#2| |#3| |#4|)) |has| (-1229 |#1| |#2| |#3| |#4|) (-303 (-1229 |#1| |#2| |#3| |#4|)))) 
 ((($) . T)) 
 (((|#1|) . T)) 
-((($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568)) (-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) ((|#2| |#2|) |has| |#1| (-365)) ((|#1| |#1|) . T)) 
-(((|#1| |#1|) . T) (($ $) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568)) (-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365)))) 
+((($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568)) (-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) ((|#2| |#2|) |has| |#1| (-365)) ((|#1| |#1|) . T)) 
+(((|#1| |#1|) . T) (($ $) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568)) (-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365)))) 
 (((|#2|) . T)) 
 (|has| |#2| (-225)) 
 (|has| $ (-150)) 
 ((((-850)) . T)) 
-((($) . T) (((-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-350))) ((|#1|) . T)) 
+((($) . T) (((-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-350))) ((|#1|) . T)) 
 ((((-850)) . T)) 
 (|has| |#1| (-840)) 
 ((((-1161)) -12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) 
@@ -3156,25 +3156,25 @@
 (((|#4|) . T)) 
 (|has| |#1| (-558)) 
 ((((-1161)) -12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) 
-((($) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) ((|#2|) |has| |#1| (-365)) ((|#1|) . T)) 
-((((-1161)) -2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) 
-(((|#1|) . T) (($) -2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568))) -2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365)))) 
+((($) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365))) ((|#2|) |has| |#1| (-365)) ((|#1|) . T)) 
+((((-1161)) -2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) 
+(((|#1|) . T) (($) -2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-558))) (((-409 (-568))) -2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-365)))) 
 ((((-1161)) -12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) 
 ((((-1161)) -12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) 
 ((($) |has| |#1| (-558)) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (((|#4|) -12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) 
 ((((-568) |#1|) . T)) 
-(-2198 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
+(-2199 (|has| |#2| (-172)) (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
 (((|#1|) . T)) 
 (((|#1| (-534 (-813 (-1161)))) . T)) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
 ((((-568) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) . T)) 
 (((|#1|) . T)) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
 (((|#1|) . T)) 
-(-2198 (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
-(-2198 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-137)) (|has| |#2| (-137))) (-12 (|has| |#1| (-788)) (|has| |#2| (-788)))) 
+(-2199 (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
+(-2199 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-137)) (|has| |#2| (-137))) (-12 (|has| |#1| (-788)) (|has| |#2| (-788)))) 
 ((((-1235 |#1| |#2| |#3|)) |has| |#1| (-365))) 
 ((($) . T) (((-864 |#1|)) . T) (((-409 (-568))) . T)) 
 ((((-1235 |#1| |#2| |#3|)) |has| |#1| (-365))) 
@@ -3184,13 +3184,13 @@
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 ((((-409 |#2|)) . T)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-350))) 
-((((-850)) -2198 (|has| |#1| (-842)) (|has| |#1| (-1090)))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-350))) 
+((((-850)) -2199 (|has| |#1| (-842)) (|has| |#1| (-1090)))) 
 ((((-541)) |has| |#1| (-609 (-541)))) 
 ((((-850)) |has| |#1| (-1090))) 
-((((-850)) -2198 (|has| |#1| (-842)) (|has| |#1| (-1090)))) 
+((((-850)) -2199 (|has| |#1| (-842)) (|has| |#1| (-1090)))) 
 ((((-541)) |has| |#1| (-609 (-541)))) 
-((((-850)) -2198 (|has| |#1| (-842)) (|has| |#1| (-1090)))) 
+((((-850)) -2199 (|has| |#1| (-842)) (|has| |#1| (-1090)))) 
 ((((-541)) |has| |#1| (-609 (-541)))) 
 ((((-850)) |has| |#1| (-1090))) 
 (((|#1|) . T)) 
@@ -3224,16 +3224,16 @@
 ((((-1235 |#1| |#2| |#3|)) |has| |#1| (-365))) 
 ((((-1161)) . T) (((-850)) . T)) 
 (|has| |#1| (-365)) 
-((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) |has| |#2| (-172)) (($) -2198 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
+((((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) |has| |#2| (-172)) (($) -2199 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904)))) 
 (((|#2|) . T) ((|#6|) . T)) 
 ((($) . T) (((-409 (-568))) |has| |#2| (-43 (-409 (-568)))) ((|#2|) . T)) 
-((($) -2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 ((((-1094)) . T)) 
 ((((-850)) . T)) 
-((($) -2198 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 ((($) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) . T)) 
 ((($) . T)) 
-((($) -2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (|has| |#2| (-904)) 
 (|has| |#1| (-904)) 
 (((|#1|) . T)) 
@@ -3248,11 +3248,11 @@
 ((((-409 (-568))) . T) (($) . T)) 
 (((|#1| (-568)) . T)) 
 ((((-850)) . T)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-350))) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-350))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-350))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-350))) 
 (|has| |#1| (-365)) 
 (|has| |#1| (-365)) 
-(-2198 (|has| |#1| (-172)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-172)) (|has| |#1| (-558))) 
 (((|#1| (-763)) . T)) 
 (((|#1| (-568)) . T)) 
 (((|#1| (-409 (-568))) . T)) 
@@ -3270,16 +3270,16 @@
 ((((-887 (-381))) . T) (((-887 (-568))) . T) (((-1161)) . T) (((-541)) . T)) 
 (((|#1|) . T)) 
 ((((-850)) . T)) 
-(-2198 (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
-(-2198 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-137)) (|has| |#2| (-137))) (-12 (|has| |#1| (-788)) (|has| |#2| (-788)))) 
+(-2199 (|has| |#2| (-137)) (|has| |#2| (-172)) (|has| |#2| (-365)) (|has| |#2| (-788)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
+(-2199 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-137)) (|has| |#2| (-137))) (-12 (|has| |#1| (-788)) (|has| |#2| (-788)))) 
 ((((-568)) . T)) 
 ((((-568)) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 (((|#1| |#2|) . T)) 
 (((|#1|) . T)) 
-(-2198 (|has| |#2| (-172)) (|has| |#2| (-716)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
+(-2199 (|has| |#2| (-172)) (|has| |#2| (-716)) (|has| |#2| (-840)) (|has| |#2| (-1047))) 
 ((((-1161)) -12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) 
-(-2198 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) (-12 (|has| |#1| (-716)) (|has| |#2| (-716)))) 
+(-2199 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) (-12 (|has| |#1| (-716)) (|has| |#2| (-716)))) 
 (|has| |#1| (-148)) 
 (|has| |#1| (-150)) 
 (|has| |#1| (-365)) 
@@ -3307,7 +3307,7 @@
 (((|#1| |#2| |#3| |#4|) . T)) 
 (((|#1| |#2|) . T)) 
 ((((-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((|#1|) |has| |#1| (-172)) (($) |has| |#1| (-558))) 
-(-2198 (|has| |#1| (-350)) (|has| |#1| (-370))) 
+(-2199 (|has| |#1| (-350)) (|has| |#1| (-370))) 
 (((|#1| |#2|) . T)) 
 (((|#1|) . T)) 
 ((($) . T) ((|#1|) . T)) 
@@ -3316,7 +3316,7 @@
 ((($) . T) ((|#1|) . T) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 (((|#2|) |has| |#2| (-1090)) (((-568)) -12 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090))) (((-409 (-568))) -12 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) 
 ((((-541)) |has| |#1| (-609 (-541)))) 
-((((-850)) -2198 (|has| |#1| (-842)) (|has| |#1| (-1090)))) 
+((((-850)) -2199 (|has| |#1| (-842)) (|has| |#1| (-1090)))) 
 ((($) . T) (((-409 (-568))) . T)) 
 (|has| |#1| (-904)) 
 (|has| |#1| (-904)) 
@@ -3325,10 +3325,10 @@
 ((((-850)) . T)) 
 (((|#2| |#2|) . T)) 
 (((|#1| |#1|) |has| |#1| (-172))) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-558))) 
-(-2198 (|has| |#1| (-21)) (|has| |#1| (-840))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-558))) 
+(-2199 (|has| |#1| (-21)) (|has| |#1| (-840))) 
 (((|#2|) . T)) 
-(-2198 (|has| |#1| (-21)) (|has| |#1| (-840))) 
+(-2199 (|has| |#1| (-21)) (|has| |#1| (-840))) 
 (((|#1|) |has| |#1| (-172))) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
@@ -3343,17 +3343,17 @@
 (((|#1|) . T) (((-409 (-568))) . T) (((-568)) . T) (($) . T)) 
 ((((-568) (-568)) . T)) 
 ((($) . T) (((-409 (-568))) . T)) 
-(-2198 (|has| |#4| (-172)) (|has| |#4| (-840)) (|has| |#4| (-1047)) SEQ) 
-(-2198 (|has| |#3| (-172)) (|has| |#3| (-840)) (|has| |#3| (-1047)) SEQ) 
+(-2199 (|has| |#4| (-172)) (|has| |#4| (-840)) (|has| |#4| (-1047)) SEQ) 
+(-2199 (|has| |#3| (-172)) (|has| |#3| (-840)) (|has| |#3| (-1047)) SEQ) 
 (|has| |#4| (-788)) 
-(-2198 (|has| |#4| (-788)) (|has| |#4| (-840))) 
+(-2199 (|has| |#4| (-788)) (|has| |#4| (-840))) 
 (|has| |#4| (-840)) 
 (|has| |#3| (-788)) 
-(-2198 (|has| |#3| (-788)) (|has| |#3| (-840))) 
+(-2199 (|has| |#3| (-788)) (|has| |#3| (-840))) 
 (|has| |#3| (-840)) 
 ((((-568)) . T)) 
 (((|#2|) . T)) 
-((((-1161)) -2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) 
+((((-1161)) -2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) 
 ((((-1161)) -12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) 
 (((|#1|) |has| |#1| (-172)) (($) . T)) 
 ((((-1161)) -12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) 
@@ -3372,11 +3372,11 @@
 ((((-1159 |#1| |#2| |#3|)) |has| |#1| (-365))) 
 ((((-1159 |#1| |#2| |#3|)) |has| |#1| (-365))) 
 ((((-1125 |#1| |#2|)) . T)) 
-(((|#2|) . T) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
-((((-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) . T)) 
+(((|#2|) . T) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
+((((-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) . T)) 
 ((($) . T)) 
 (|has| |#1| (-1021)) 
-(((|#2|) . T) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+(((|#2|) . T) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 ((((-850)) . T)) 
 ((((-541)) |has| |#2| (-609 (-541))) (((-887 (-568))) |has| |#2| (-609 (-887 (-568)))) (((-887 (-381))) |has| |#2| (-609 (-887 (-381)))) (((-381)) |has| |#2| (-1021)) (((-215)) |has| |#2| (-1021))) 
 ((((-1161) (-57)) . T)) 
@@ -3398,8 +3398,8 @@
 (((|#1|) . T)) 
 (((|#2|) . T)) 
 (|has| |#2| (-365)) 
-(((|#3|) . T) ((|#2|) . T) (($) -2198 (|has| |#4| (-172)) (|has| |#4| (-840)) (|has| |#4| (-1047))) ((|#4|) -2198 (|has| |#4| (-172)) (|has| |#4| (-365)) (|has| |#4| (-1047)))) 
-(((|#2|) . T) (($) -2198 (|has| |#3| (-172)) (|has| |#3| (-840)) (|has| |#3| (-1047))) ((|#3|) -2198 (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-1047)))) 
+(((|#3|) . T) ((|#2|) . T) (($) -2199 (|has| |#4| (-172)) (|has| |#4| (-840)) (|has| |#4| (-1047))) ((|#4|) -2199 (|has| |#4| (-172)) (|has| |#4| (-365)) (|has| |#4| (-1047)))) 
+(((|#2|) . T) (($) -2199 (|has| |#3| (-172)) (|has| |#3| (-840)) (|has| |#3| (-1047))) ((|#3|) -2199 (|has| |#3| (-172)) (|has| |#3| (-365)) (|has| |#3| (-1047)))) 
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 (|has| |#1| (-365)) 
@@ -3422,21 +3422,21 @@
 (((|#1|) . T)) 
 (((|#2| $) -12 (|has| |#1| (-365)) (|has| |#2| (-281 |#2| |#2|))) (($ $) . T)) 
 ((($ $) . T)) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-904))) 
-(-2198 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-904))) 
+(-2199 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
 ((((-850)) . T)) 
 (((|#1| (-534 |#2|)) . T)) 
-((((-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) . T)) 
+((((-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) . T)) 
 (((|#1| (-568)) . T)) 
 (((|#1| (-409 (-568))) . T)) 
 (((|#1| (-763)) . T)) 
 (((|#1| (-763)) . T)) 
 (((|#1|) . T)) 
 ((((-125 |#1|)) . T) (($) . T) (((-409 (-568))) . T)) 
-(-2198 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
-(-2198 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
+(-2199 (|has| |#2| (-453)) (|has| |#2| (-558)) (|has| |#2| (-904))) 
+(-2199 (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) 
 ((($) . T)) 
 (((|#2| (-534 (-852 |#1|))) . T)) 
 ((((-2 (|:| |k| (-568)) (|:| |c| |#1|))) . T)) 
@@ -3448,22 +3448,22 @@
 (((|#1| |#2|) . T)) 
 ((((-1143) |#1|) . T)) 
 ((((-409 |#2|)) . T)) 
-((((-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
+((((-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
 (|has| |#1| (-558)) 
 (|has| |#1| (-558)) 
-((($) -2198 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
+((($) -2199 (|has| |#1| (-365)) (|has| |#1| (-453)) (|has| |#1| (-558)) (|has| |#1| (-904))) ((|#1|) |has| |#1| (-172)) (((-409 (-568))) |has| |#1| (-43 (-409 (-568))))) 
 ((($) . T) ((|#2|) . T)) 
 (((|#1|) . T)) 
 (((|#1| |#2|) . T)) 
 (((|#2| $) |has| |#2| (-281 |#2| |#2|))) 
 (((|#1| (-634 |#1|)) |has| |#1| (-840))) 
-(-2198 (|has| |#1| (-225)) (|has| |#1| (-350))) 
-(-2198 (|has| |#1| (-365)) (|has| |#1| (-350))) 
+(-2199 (|has| |#1| (-225)) (|has| |#1| (-350))) 
+(-2199 (|has| |#1| (-365)) (|has| |#1| (-350))) 
 (|has| |#1| (-1090)) 
 (((|#1|) . T)) 
 (|has| |#1| (-1136)) 
 ((((-409 (-568))) . T) (($) . T)) 
-((((-999 |#1|)) . T) ((|#1|) . T) (((-568)) -2198 (|has| (-999 |#1|) (-1037 (-568))) (|has| |#1| (-1037 (-568)))) (((-409 (-568))) -2198 (|has| (-999 |#1|) (-1037 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568)))))) 
+((((-999 |#1|)) . T) ((|#1|) . T) (((-568)) -2199 (|has| (-999 |#1|) (-1037 (-568))) (|has| |#1| (-1037 (-568)))) (((-409 (-568))) -2199 (|has| (-999 |#1|) (-1037 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568)))))) 
 (((|#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 (((|#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
 (((|#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) 
@@ -3478,9 +3478,9 @@
 ((((-215)) . T)) 
 (((|#1| |#2| |#3| |#4|) . T)) 
 ((((-1125 |#1| |#2|) (-1125 |#1| |#2|)) |has| (-1125 |#1| |#2|) (-303 (-1125 |#1| |#2|)))) 
-(((|#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) |has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) 
+(((|#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) |has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) 
 ((((-125 |#1|)) |has| (-125 |#1|) (-303 (-125 |#1|)))) 
-(-2198 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
+(-2199 (|has| |#1| (-842)) (|has| |#1| (-1090))) 
 ((($ $) . T)) 
 ((($ $) . T) (((-852 |#1|) $) . T) (((-852 |#1|) |#2|) . T)) 
 ((($ $) . T) ((|#2| $) |has| |#1| (-225)) ((|#2| |#1|) |has| |#1| (-225)) ((|#3| |#1|) . T) ((|#3| $) . T)) 
diff --git a/src/share/algebra/compress.daase b/src/share/algebra/compress.daase
index 8d7f0e0..c6e8fa3 100644
--- a/src/share/algebra/compress.daase
+++ b/src/share/algebra/compress.daase
@@ -1,3 +1,3 @@
 
-(30 . 3487447478)            
-(4522 |Enumeration| |Mapping| |Record| |Union| |ofCategory| |isDomain| ATTRIBUTE |package| |domain| |category| CATEGORY |nobranch| AND |Join| |ofType| SIGNATURE "failed" "algebra" |OneDimensionalArrayAggregate&| |OneDimensionalArrayAggregate| |AbelianGroup&| |AbelianGroup| |AbelianMonoid&| |AbelianMonoid| |AbelianSemiGroup&| |AbelianSemiGroup| |AlgebraicallyClosedField&| |AlgebraicallyClosedField| |AlgebraicallyClosedFunctionSpace&| |AlgebraicallyClosedFunctionSpace| |PlaneAlgebraicCurvePlot| |AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgebraicFunction| |AffineSpaceCategory| |Aggregate&| |Aggregate| |ArcHyperbolicFunctionCategory| |AssociationListAggregate| |Algebra&| |Algebra| |AlgFactor| |AlgebraicFunctionField| |AlgebraicManipulations| |AlgebraicMultFact| |AlgebraPackage| |AlgebraGivenByStructuralConstants| |AssociationList| |AbelianMonoidRing&| |AbelianMonoidRing| |AlgebraicNumber| |AnonymousFunction| |AntiSymm| |AnyFunctions1| |Any| |ApplicationProgramInterface| |ApplyUnivariateSkewPolynomial| |ApplyRules| |TwoDimensionalArrayCategory&| |TwoDimensionalArrayCategory| |OneDimensionalArrayFunctions2| |OneDimensionalArray| |TwoDimensionalArray| |Asp10| |Asp12| |Asp19| |Asp1| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp41| |Asp42| |Asp49| |Asp4| |Asp50| |Asp55| |Asp6| |Asp73| |Asp74| |Asp77| |Asp78| |Asp7| |Asp80| |Asp8| |Asp9| |AssociatedEquations| |ArrayStack| |ArcTrigonometricFunctionCategory&| |ArcTrigonometricFunctionCategory| |AttributeButtons| |AttributeRegistry| |Automorphism| |AxiomServer| |BalancedFactorisation| |BasicType&| |BasicType| |BalancedBinaryTree| |Bezier| |BezoutMatrix| |BasicFunctions| |BagAggregate&| |BagAggregate| |BinaryExpansion| |BinaryFile| |Bits| |BlasLevelOne| |BlowUpWithHamburgerNoether| |BlowUpMethodCategory| |BlowUpWithQuadTrans| |BlowUpPackage| |BiModule| |Boolean| |BasicOperatorFunctions1| |BasicOperator| |BoundIntegerRoots| |BalancedPAdicInteger| |BalancedPAdicRational| |BinaryRecursiveAggregate&| |BinaryRecursiveAggregate| |BrillhartTests| |BinarySearchTree| |BitAggregate&| |BitAggregate| |BinaryTreeCategory&| |BinaryTreeCategory| |BinaryTournament| |BinaryTree| |CancellationAbelianMonoid| |CachableSet| |CardinalNumber| |CartesianTensorFunctions2| |CartesianTensor| |CharacterClass| |CommonDenominator| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |CombinatorialFunctionCategory| |Character| |CharacteristicNonZero| |CharacteristicPolynomialPackage| |CharacteristicZero| |ChangeOfVariable| |ComplexIntegerSolveLinearPolynomialEquation| |Collection&| |Collection| |CliffordAlgebra| |TwoDimensionalPlotClipping| |ComplexRootPackage| |Color| |CombinatorialFunction| |IntegerCombinatoricFunctions| |CombinatorialOpsCategory| |Commutator| |CommonOperators| |CommuteUnivariatePolynomialCategory| |ComplexCategory&| |ComplexCategory| |ComplexFactorization| |ComplexFunctions2| |Complex| |ComplexPattern| |SubSpaceComponentProperty| |CommutativeRing| |ContinuedFraction| |CoordinateSystems| |CharacteristicPolynomialInMonogenicalAlgebra| |ComplexPatternMatch| |CRApackage| |ComplexRootFindingPackage| |CyclicStreamTools| |ComplexTrigonometricManipulations| |CoerceVectorMatrixPackage| |CycleIndicators| |CyclotomicPolynomialPackage| |d01AgentsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d01TransformFunctionType| |d01WeightsPackage| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |d03fafAnnaType| |Database| |DoubleResultantPackage| |DistinctDegreeFactorize| |DecimalExpansion| |ElementaryFunctionDefiniteIntegration| |RationalFunctionDefiniteIntegration| |DegreeReductionPackage| |Dequeue| |DeRhamComplex| |DefiniteIntegrationTools| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DenavitHartenbergMatrix| |Dictionary&| |Dictionary| |DifferentialExtension&| |DifferentialExtension| |DifferentialRing&| |DifferentialRing| |DictionaryOperations&| |DictionaryOperations| |DiophantineSolutionPackage| |DirectProductCategory&| |DirectProductCategory| |DirectProductFunctions2| |DirectProduct| |DirichletRing| |DisplayPackage| |DivisorCategory| |Divisor| |DivisionRing&| |DivisionRing| |DoublyLinkedAggregate| |DataList| |DiscreteLogarithmPackage| |DistributedMultivariatePolynomial| |DirectProductMatrixModule| |DirectProductModule| |DifferentialPolynomialCategory&| |DifferentialPolynomialCategory| |DequeueAggregate| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |DrawComplex| |DrawNumericHack| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForPoints| |DrawOptionFunctions0| |DrawOptionFunctions1| |DrawOption| |DifferentialSparseMultivariatePolynomial| |DesingTreeCategory| |DesingTree| |DesingTreePackage| |DifferentialVariableCategory&| |DifferentialVariableCategory| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType| |ExtAlgBasis| |ElementaryFunction| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ExtensibleLinearAggregate&| |ExtensibleLinearAggregate| |ElementaryFunctionCategory&| |ElementaryFunctionCategory| |EllipticFunctionsUnivariateTaylorSeries| |Eltable| |EltableAggregate&| |EltableAggregate| |EuclideanModularRing| |EntireRing| |EigenPackage| |EquationFunctions2| |Equation| |EqTable| |ErrorFunctions| |ExpressionSpaceFunctions1| |ExpressionSpaceFunctions2| |ExpertSystemContinuityPackage1| |ExpertSystemContinuityPackage| |ExpressionSpace&| |ExpressionSpace| |ExpertSystemToolsPackage1| |ExpertSystemToolsPackage2| |ExpertSystemToolsPackage| |EuclideanDomain&| |EuclideanDomain| |Evalable&| |Evalable| |EvaluateCycleIndicators| |Exit| |Export3D| |ExponentialExpansion| |ExpressionFunctions2| |ExpressionToUnivariatePowerSeries| |Expression| |ExpressionSpaceODESolver| |ExpressionSolve| |ExpressionTubePlot| |ExponentialOfUnivariatePuiseuxSeries| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactoredFunctions| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |FactoringUtilities| |FreeAbelianGroup| |FreeAbelianMonoidCategory| |FreeAbelianMonoid| |FiniteAbelianMonoidRingFunctions2| |FiniteAbelianMonoidRing&| |FiniteAbelianMonoidRing| |FlexibleArray| |FiniteAlgebraicExtensionField&| |FiniteAlgebraicExtensionField| |FortranCode| |FourierComponent| |FortranCodePackage1| |FiniteDivisorFunctions2| |FiniteDivisorCategory&| |FiniteDivisorCategory| |FiniteDivisor| |FullyEvalableOver&| |FullyEvalableOver| |FortranExpression| |FunctionFieldCategoryFunctions2| |FunctionFieldCategory&| |FunctionFieldCategory| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldCyclicGroupExtension| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FractionFreeFastGaussianFractions| |FractionFreeFastGaussian| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldCategory&| |FiniteFieldCategory| |FunctionFieldIntegralBasis| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldNormalBasisExtension| |FiniteField| |FiniteFieldExtensionByPolynomial| |FiniteFieldPolynomialPackage2| |FiniteFieldPolynomialPackage| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteFieldExtension| |FGLMIfCanPackage| |FreeGroup| |Field&| |Field| |FileCategory| |File| |FiniteRankNonAssociativeAlgebra&| |FiniteRankNonAssociativeAlgebra| |Finite| |FiniteRankAlgebra&| |FiniteRankAlgebra| |FiniteLinearAggregateFunctions2| |FiniteLinearAggregate&| |FiniteLinearAggregate| |FreeLieAlgebra| |FiniteLinearAggregateSort| |FullyLinearlyExplicitRingOver&| |FullyLinearlyExplicitRingOver| |FloatingComplexPackage| |Float| |FloatingRealPackage| |FreeModule1| |FreeModuleCat| |FortranMatrixCategory| |FortranMatrixFunctionCategory| |FreeModule| |FreeMonoid| |FortranMachineTypeCategory| |FileName| |FileNameCategory| |FreeNilpotentLie| |FortranOutputStackPackage| |FindOrderFinite| |ScriptFormulaFormat1| |ScriptFormulaFormat| |FortranProgramCategory| |FortranFunctionCategory| |FortranPackage| |FortranProgram| |FullPartialFractionExpansion| |FullyPatternMatchable| |FieldOfPrimeCharacteristic&| |FieldOfPrimeCharacteristic| |FloatingPointSystem&| |FloatingPointSystem| |FactoredFunctions2| |FractionFunctions2| |Fraction| |FramedAlgebra&| |FramedAlgebra| |FullyRetractableTo&| |FullyRetractableTo| |FractionalIdealFunctions2| |FractionalIdeal| |FramedModule| |FramedNonAssociativeAlgebraFunctions2| |FramedNonAssociativeAlgebra&| |FramedNonAssociativeAlgebra| |Factored| |FactoredFunctionUtilities| |FunctionSpaceToExponentialExpansion| |FunctionSpaceFunctions2| |FunctionSpaceToUnivariatePowerSeries| |FiniteSetAggregateFunctions2| |FiniteSetAggregate&| |FiniteSetAggregate| |FunctionSpaceComplexIntegration| |FourierSeries| |FunctionSpaceIntegration| |FunctionSpace&| |FunctionSpace| |FunctionalSpecialFunction| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FortranScalarType| |FunctionSpaceUnivariatePolynomialFactor| |FortranTemplate| |FortranType| |FunctionCalled| |FortranVectorCategory| |FortranVectorFunctionCategory| |GaloisGroupFactorizer| |GaloisGroupFactorizationUtilities| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GaussianFactorizationPackage| |EuclideanGroebnerBasisPackage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |GcdDomain&| |GcdDomain| |GenericNonAssociativeAlgebra| |GeneralDistributedMultivariatePolynomial| |GnuDraw| |GenExEuclid| |GeneralizedMultivariateFactorize| |GeneralPolynomialGcdPackage| |GenUFactorize| |GenerateUnivariatePowerSeries| |GeneralHenselPackage| |GeneralModulePolynomial| |GuessOptionFunctions0| |GuessOption| |GosperSummationMethod| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialSet| |GradedAlgebra&| |GradedAlgebra| |GrayCode| |GraphicsDefaults| |GraphImage| |GradedModule&| |GradedModule| |GroebnerSolve| |Group&| |Group| |GeneralUnivariatePowerSeries| |GeneralSparseTable| |GeneralTriangularSet| |GuessAlgebraicNumber| |GuessFiniteFunctions| |GuessFinite| |GuessInteger| |Guess| |GuessPolynomial| |GuessUnivariatePolynomial| |Pi| |HashTable| |HallBasis| |HomogeneousDistributedMultivariatePolynomial| |HomogeneousDirectProduct| |Heap| |HyperellipticFiniteDivisor| |HeuGcd| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousAggregate| |HTMLFormat| |HyperbolicFunctionCategory&| |HyperbolicFunctionCategory| |InnerAlgFactor| |InnerAlgebraicNumber| |IndexedOneDimensionalArray| |IndexedTwoDimensionalArray| |ChineseRemainderToolsForIntegralBases| |IntegralBasisTools| |IndexedBits| |IntegralBasisPolynomialTools| |IndexCard| |InnerCommonDenominator| |InfClsPt| |PolynomialIdeals| |IdealDecompositionPackage| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductCategory| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedDirectProductObject| |InnerEvalable&| |InnerEvalable| |InnerFreeAbelianMonoid| |IndexedFlexibleArray| |InnerFiniteField| |InnerIndexedTwoDimensionalArray| |IndexedList| |InnerMatrixLinearAlgebraFunctions| |InnerMatrixQuotientFieldFunctions| |IndexedMatrix| |InnerNormalBasisFieldFunctions| |IncrementingMaps| |IndexedExponents| |InnerNumericEigenPackage| |InfinitlyClosePointCategory| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InfinitlyClosePoint| |Infinity| |InputFormFunctions1| |InputForm| |InfiniteProductCharacteristicZero| |InnerNumericFloatSolvePackage| |InnerModularGcd| |InnerMultFact| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InnerPolySign| |IntegerNumberSystem&| |IntegerNumberSystem| |InnerTable| |AlgebraicIntegration| |AlgebraicIntegrate| |IntegerBits| |IntervalCategory| |IntersectionDivisorPackage| |IntegralDomain&| |IntegralDomain| |ElementaryIntegration| |InterfaceGroebnerPackage| |IntegerFactorizationPackage| |InterpolateFormsPackage| |IntegrationFunctionsTable| |GenusZeroIntegration| |IntegerNumberTheoryFunctions| |AlgebraicHermiteIntegration| |TranscendentalHermiteIntegration| |Integer| |AnnaNumericalIntegrationPackage| |PureAlgebraicIntegration| |PatternMatchIntegration| |RationalIntegration| |IntegerRetractions| |RationalFunctionIntegration| |Interval| |IntegerSolveLinearPolynomialEquation| |IntegrationTools| |TranscendentalIntegration| |InverseLaplaceTransform| |InnerPAdicInteger| |InnerPrimeField| |InternalPrintPackage| |IntegrationResultToFunction| |IntegrationResultFunctions2| |IntegrationResult| |IntegerRoots| |IrredPolyOverFiniteField| |IntegrationResultRFToFunction| |IrrRepSymNatPackage| |InternalRationalUnivariateRepresentationPackage| |IndexedString| |InnerPolySum| |InnerSparseUnivariatePowerSeries| |InnerTaylorSeries| |InfiniteTupleFunctions2| |InfiniteTupleFunctions3| |InnerTrigonometricManipulations| |InfiniteTuple| |IndexedVector| |IndexedAggregate&| |IndexedAggregate| |AssociatedJordanAlgebra| |KeyedAccessFile| |KeyedDictionary&| |KeyedDictionary| |KernelFunctions2| |Kernel| |CoercibleTo| |ConvertibleTo| |Kovacic| |LeftAlgebra&| |LeftAlgebra| |LocalAlgebra| |LaplaceTransform| |LaurentPolynomial| |LazardSetSolvingPackage| |LeadingCoefDetermination| |LieExponentials| |LexTriangularPackage| |LiouvillianFunctionCategory| |LiouvillianFunction| |LinGroebnerPackage| |Library| |LieAlgebra&| |LieAlgebra| |AssociatedLieAlgebra| |PowerSeriesLimitPackage| |RationalFunctionLimitPackage| |LinearDependence| |LinearlyExplicitRingOver| |ListToMap| |ListFunctions2| |ListFunctions3| |List| |LinearSystemFromPowerSeriesPackage| |ListMultiDictionary| |LeftModule| |ListMonoidOps| |LinearAggregate&| |LinearAggregate| |LocalPowerSeriesCategory| |ElementaryFunctionLODESolver| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorCategory&| |LinearOrdinaryDifferentialOperatorCategory| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperatorsOps| |Logic&| |Logic| |Localize| |LinesOpPack| |LocalParametrizationOfSimplePointPackage| |LinearPolynomialEquationByFractions| |LiePolynomial| |ListAggregate&| |ListAggregate| |LinearSystemMatrixPackage1| |LinearSystemMatrixPackage| |LinearSystemPolynomialPackage| |LieSquareMatrix| |LyndonWord| |LazyStreamAggregate&| |LazyStreamAggregate| |ThreeDimensionalMatrix| |Magma| |MappingPackageInternalHacks1| |MappingPackageInternalHacks2| |MappingPackageInternalHacks3| |MappingPackage1| |MappingPackage2| |MappingPackage3| |MappingPackage4| |MatrixCategoryFunctions2| |MatrixCategory&| |MatrixCategory| |MatrixLinearAlgebraFunctions| |Matrix| |StorageEfficientMatrixOperations| |MultiVariableCalculusFunctions| |MatrixCommonDenominator| |MachineComplex| |MultiDictionary| |ModularDistinctDegreeFactorizer| |MeshCreationRoutinesForThreeDimensions| |MultFiniteFactorize| |MachineFloat| |ModularHermitianRowReduction| |MachineInteger| |MakeBinaryCompiledFunction| |MakeCachableSet| |MakeFloatCompiledFunction| |MakeFunction| |MakeRecord| |MakeUnaryCompiledFunction| |MultivariateLifting| |MonogenicLinearOperator| |MultipleMap| |MathMLFormat| |ModularField| |ModMonic| |ModuleMonomial| |ModuleOperator| |ModularRing| |Module&| |Module| |MoebiusTransform| |Monad&| |Monad| |MonadWithUnit&| |MonadWithUnit| |MonogenicAlgebra&| |MonogenicAlgebra| |Monoid&| |Monoid| |MonomialExtensionTools| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatPolyFactorizer| |MultivariatePolynomial| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MonoidRingFunctions2| |MonoidRing| |MultisetAggregate| |Multiset| |MoreSystemCommands| |MergeThing| |MultivariateTaylorSeriesCategory| |MultivariateFactorize| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NonAssociativeAlgebra&| |NonAssociativeAlgebra| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagIntegrationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagInterpolationPackage| |NagFittingPackage| |NagOptimisationPackage| |NagMatrixOperationsPackage| |NagEigenPackage| |NagLinearEquationSolvingPackage| |NagLapack| |NagSpecialFunctionsPackage| |NAGLinkSupportPackage| |NonAssociativeRng&| |NonAssociativeRng| |NonAssociativeRing&| |NonAssociativeRing| |NumericComplexEigenPackage| |NumericContinuedFraction| |NonCommutativeOperatorDivision| |NewtonInterpolation| |NumberFieldIntegralBasis| |NumericalIntegrationProblem| |NonLinearSolvePackage| |NonNegativeInteger| |NonLinearFirstOrderODESolver| |NoneFunctions1| |None| |NormInMonogenicAlgebra| |NormalizationPackage| |NormRetractPackage| |NottinghamGroup| |NPCoef| |NewtonPolygon| |NumericRealEigenPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomialFunctions2| |NewSparseUnivariatePolynomial| |NumberTheoreticPolynomialFunctions| |NormalizedTriangularSetCategory| |Numeric| |NumberFormats| |NumericalIntegrationCategory| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |NumericTubePlot| |OrderedAbelianGroup| |OrderedAbelianMonoid| |OrderedAbelianMonoidSup| |OrderedAbelianSemiGroup| |OrderedCancellationAbelianMonoid| |OctonionCategory&| |OctonionCategory| |OctonionCategoryFunctions2| |Octonion| |OrdinaryDifferentialEquationsSolverCategory| |ConstantLODE| |ElementaryFunctionODESolver| |ODEIntensityFunctionsTable| |ODEIntegration| |AnnaOrdinaryDifferentialEquationPackage| |PureAlgebraicLODE| |PrimitiveRatDE| |NumericalODEProblem| |PrimitiveRatRicDE| |RationalLODE| |ReduceLODE| |RationalRicDE| |SystemODESolver| |ODETools| |OrderedDirectProduct| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OrderlyDifferentialVariable| |OrderedFreeMonoid| |OrderedIntegralDomain| |OpenMathConnection| |OpenMathDevice| |OpenMathEncoding| |OpenMathErrorKind| |OpenMathError| |ExpressionToOpenMath| |OppositeMonogenicLinearOperator| |OpenMath| |OpenMathPackage| |OrderedMultisetAggregate| |OpenMathServerPackage| |OnePointCompletionFunctions2| |OnePointCompletion| |Operator| |OperationsQuery| |NumericalOptimizationCategory| |AnnaNumericalOptimizationPackage| |NumericalOptimizationProblem| |OrderedCompletionFunctions2| |OrderedCompletion| |OrderedFinite| |OrderingFunctions| |OrderedMonoid| |OrderedRing&| |OrderedRing| |OrderedSet&| |OrderedSet| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategory| |UnivariateSkewPolynomialCategoryOps| |SparseUnivariateSkewPolynomial| |UnivariateSkewPolynomial| |OrthogonalPolynomialFunctions| |OrdSetInts| |OutputForm| |OutputPackage| |OrderedVariableList| |OrdinaryWeightedPolynomials| |PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteFieldCategory| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfPerfectFieldCategory| |PseudoAlgebraicClosureOfRationalNumberCategory| |PseudoAlgebraicClosureOfRationalNumber| |PadeApproximants| |PadeApproximantPackage| |PAdicIntegerCategory| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForAlgebraicFunctionField| |Palette| |PolynomialAN2Expression| |ParametrizationPackage| |ParametricPlaneCurveFunctions2| |ParametricPlaneCurve| |ParametricSpaceCurveFunctions2| |ParametricSpaceCurve| |ParametricSurfaceFunctions2| |ParametricSurface| |PartitionsAndPermutations| |Patternable| |PatternMatchListResult| |PatternMatchable| |PatternMatch| |PatternMatchResultFunctions2| |PatternMatchResult| |PatternFunctions1| |PatternFunctions2| |Pattern| |PoincareBirkhoffWittLyndonBasis| |PolynomialComposition| |PartialDifferentialEquationsSolverCategory| |PolynomialDecomposition| |AnnaPartialDifferentialEquationPackage| |NumericalPDEProblem| |PartialDifferentialRing&| |PartialDifferentialRing| |PendantTree| |Permanent| |PermutationCategory| |PermutationGroup| |Permutation| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialFactorizationExplicit| |PrimeField| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PackageForPoly| |PointsOfFiniteOrderTools| |PartialFraction| |PartialFractionPackage| |PolynomialGcdPackage| |PermutationGroupExamples| |PolyGroebner| |PiCoercions| |PrincipalIdealDomain| |PositiveInteger| |PolynomialInterpolationAlgorithms| |PolynomialInterpolation| |PlacesCategory| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |Plcs| |ParametricLinearEquations| |PlotFunctions1| |Plot3D| |Plot| |PlotTools| |PolynomialPackageForCurve| |FunctionSpaceAssertions| |PatternMatchAssertions| |PatternMatchPushDown| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchKernel| |PatternMatchListAggregate| |PatternMatchPolynomialCategory| |FunctionSpaceAttachPredicates| |AttachPredicates| |PatternMatchQuotientFieldCategory| |PatternMatchSymbol| |PatternMatchTools| |PolynomialNumberTheoryFunctions| |Point| |PolToPol| |RealPolynomialUtilitiesPackage| |PolynomialFunctions2| |PolynomialToUnivariatePolynomial| |PolynomialCategory&| |PolynomialCategory| |PolynomialCategoryQuotientFunctions| |PolynomialCategoryLifting| |Polynomial| |PolynomialRoots| |PlottablePlaneCurveCategory| |PrecomputedAssociatedEquations| |PrimitiveArrayFunctions2| |PrimitiveArray| |PrimitiveFunctionCategory| |PrimitiveElement| |IntegerPrimesPackage| |PrintPackage| |ProjectiveAlgebraicSetPackage| |PolynomialRing| |Product| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PriorityQueueAggregate| |PseudoRemainderSequence| |ProjectiveSpaceCategory| |Partition| |PowerSeriesCategory&| |PowerSeriesCategory| |PlottableSpaceCurveCategory| |PolynomialSetCategory&| |PolynomialSetCategory| |PolynomialSetUtilitiesPackage| |PseudoLinearNormalForm| |PolynomialSquareFree| |PointCategory| |PointFunctions2| |PointPackage| |PartialTranscendentalFunctions| |PushVariables| |PAdicWildFunctionFieldIntegralBasis| |QuasiAlgebraicSet2| |QuasiAlgebraicSet| |QuasiComponentPackage| |QueryEquation| |QuotientFieldCategoryFunctions2| |QuotientFieldCategory&| |QuotientFieldCategory| |QuadraticForm| |QueueAggregate| |QuaternionCategory&| |QuaternionCategory| |QuaternionCategoryFunctions2| |Quaternion| |Queue| |RadicalCategory&| |RadicalCategory| |RadicalFunctionField| |RadixExpansion| |RadixUtilities| |RandomNumberSource| |RationalFactorize| |RationalRetractions| |RecursiveAggregate&| |RecursiveAggregate| |RealClosedField&| |RealClosedField| |ElementaryRischDE| |ElementaryRischDESystem| |TranscendentalRischDE| |TranscendentalRischDESystem| |RandomDistributions| |ReducedDivisor| |RealZeroPackage| |RealZeroPackageQ| |RealConstant| |RealSolvePackage| |RealClosure| |RecurrenceOperator| |ReductionOfOrder| |Reference| |RegularTriangularSet| |RepresentationPackage1| |RepresentationPackage2| |RepeatedDoubling| |RadicalEigenPackage| |RepeatedSquaring| |ResolveLatticeCompletion| |ResidueRing| |Result| |RetractableTo&| |RetractableTo| |RetractSolvePackage| |RandomFloatDistributions| |RationalFunctionFactor| |RationalFunctionFactorizer| |RationalFunction| |RootsFindingPackage| |RegularChain| |RandomIntegerDistributions| |Ring&| |Ring| |RationalInterpolation| |RectangularMatrixCategory&| |RectangularMatrixCategory| |RectangularMatrix| |RectangularMatrixCategoryFunctions2| |RightModule| |Rng| |RealNumberSystem&| |RealNumberSystem| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RoutinesTable| |RecursivePolynomialCategory&| |RecursivePolynomialCategory| |RealRootCharacterizationCategory&| |RealRootCharacterizationCategory| |RegularSetDecompositionPackage| |RegularTriangularSetCategory&| |RegularTriangularSetCategory| |RegularTriangularSetGcdPackage| |RuleCalled| |RewriteRule| |Ruleset| |RationalUnivariateRepresentationPackage| |SimpleAlgebraicExtensionAlgFactor| |SimpleAlgebraicExtension| |SAERationalFunctionAlgFactor| |SingletonAsOrderedSet| |SortedCache| |StructuralConstantsPackage| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |SegmentFunctions2| |SegmentBindingFunctions2| |SegmentBinding| |SegmentCategory| |Segment| |SegmentExpansionCategory| |SetAggregate&| |SetAggregate| |SetCategoryWithDegree| |SetCategory&| |SetCategory| |SetOfMIntegersInOneToN| |Set| |SExpressionCategory| |SExpression| |SExpressionOf| |SimpleFortranProgram| |SquareFreeQuasiComponentPackage| |SquareFreeRegularTriangularSetGcdPackage| |SquareFreeRegularTriangularSetCategory| |SymmetricGroupCombinatoricFunctions| |SemiGroup&| |SemiGroup| |SplitHomogeneousDirectProduct| |SturmHabichtPackage| |ElementaryFunctionSign| |RationalFunctionSign| |SimplifyAlgebraicNumberConvertPackage| |SingleInteger| |StackAggregate| |SquareMatrixCategory&| |SquareMatrixCategory| |SmithNormalForm| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SquareFreeNormalizedTriangularSetCategory| |PolynomialSolveByFormulas| |RadicalSolvePackage| |TransSolvePackageService| |TransSolvePackage| |SortPackage| |ThreeSpace| |ThreeSpaceCategory| |SpecialOutputPackage| |SpecialFunctionCategory| |SplittingNode| |SplittingTree| |SquareMatrix| |StringAggregate&| |StringAggregate| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |Stack| |StreamAggregate&| |StreamAggregate| |SparseTable| |StepThrough| |StreamInfiniteProduct| |StreamFunctions1| |StreamFunctions2| |StreamFunctions3| |Stream| |StringCategory| |String| |StringTable| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctionsNonCommutative| |StreamTranscendentalFunctions| |SubResultantPackage| |SubSpace| |SuchThat| |SparseUnivariateLaurentSeries| |FunctionSpaceSum| |RationalFunctionSum| |SparseUnivariatePolynomialFunctions2| |SparseUnivariatePolynomialExpressions| |SupFractionFactorizer| |SparseUnivariatePolynomial| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |Switch| |Symbol| |SymmetricFunctions| |SymmetricPolynomial| |TheSymbolTable| |SymbolTable| |SystemSolvePackage| |TableauxBumpers| |Tableau| |Table| |TangentExpansions| |TableAggregate&| |TableAggregate| |TabulatedComputationPackage| |TemplateUtilities| |TexFormat1| |TexFormat| |TextFile| |ToolsForSign| |TopLevelThreeSpace| |TranscendentalFunctionCategory&| |TranscendentalFunctionCategory| |Tree| |TrigonometricFunctionCategory&| |TrigonometricFunctionCategory| |TrigonometricManipulations| |TriangularMatrixOperations| |TranscendentalManipulations| |TriangularSetCategory&| |TriangularSetCategory| |TaylorSeries| |TubePlot| |TubePlotTools| |Tuple| |TwoFactorize| |Type| |UserDefinedPartialOrdering| |UserDefinedVariableOrdering| |UniqueFactorizationDomain&| |UniqueFactorizationDomain| |UnivariateFormalPowerSeriesFunctions| |UnivariateFormalPowerSeries| |UnivariateLaurentSeriesFunctions2| |UnivariateLaurentSeriesCategory| |UnivariateLaurentSeriesConstructorCategory&| |UnivariateLaurentSeriesConstructorCategory| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeries| |UnivariateFactorize| |UniversalSegmentFunctions2| |UniversalSegment| |UnivariatePolynomialFunctions2| |UnivariatePolynomialCommonDenominator| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePolynomial| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategory| |UnivariatePowerSeriesCategory&| |UnivariatePowerSeriesCategory| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeriesFunctions2| |UnivariatePuiseuxSeriesCategory| |UnivariatePuiseuxSeriesConstructorCategory&| |UnivariatePuiseuxSeriesConstructorCategory| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnaryRecursiveAggregate&| |UnaryRecursiveAggregate| |UnivariateTaylorSeriesFunctions2| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesCategory| |UnivariateTaylorSeries| |UnivariateTaylorSeriesODESolver| |UTSodetools| |TaylorSolve| |UnivariateTaylorSeriesCZero| |Variable| |VectorCategory&| |VectorCategory| |VectorFunctions2| |Vector| |TwoDimensionalViewport| |ThreeDimensionalViewport| |ViewDefaultsPackage| |ViewportPackage| |Void| |VectorSpace&| |VectorSpace| |WeierstrassPreparation| |WildFunctionFieldIntegralBasis| |WeightedPolynomials| |WuWenTsunTriangularSet| |XAlgebra| |XDistributedPolynomial| |XExponentialPackage| |XFreeAlgebra| |ExtensionField&| |ExtensionField| |XPBWPolynomial| |XPolynomialsCat| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ParadoxicalCombinatorsForStreams| |ZeroDimensionalSolvePackage| |IntegerLinearDependence| |IntegerMod| |Enumeration| |Mapping| |Record| |Union| |Category| |mapmult| |printInfo| |supDimElseRittWu?| |pointDominateBy| |semiResultantEuclidean2| |reduced?| |prinb| |positiveRemainder| |cExp| |setTower!| |mathieu22| |iter| |setFoundPlacesToEmpty| |rdHack1| |collectUpper| |legendre| |setFormula!| |leftDivide| |generalCoefficient| |wrregime| |nonSingularModel| |extendedSubResultantGcd| |poisson| |nullary?| |inverseIntegralMatrixAtInfinity| |degreeOfMinimalForm| |coefficients| |polygamma| |numericalIntegration| |variable| |nextPrimitivePoly| |rk4f| |hermite| |rightUnits| |stoseInvertibleSetreg| |leadingSupport| |OMUnknownSymbol?| |basisOfMiddleNucleus| |subMultV| |extract!| |Frobenius| |removeCosSq| |genericLeftNorm| |any?| |dimensionOfIrreducibleRepresentation| |axesColorDefault| |lazyIrreducibleFactors| |internalIntegrate0| |iiBeta| |delta| |setAdaptive3D| |LagrangeInterpolation| |euclideanGroebner| |redpps| |reducedDiscriminant| |reducedForm| |numerator| |OMputEndAttr| |bubbleSort!| |symmetric?| |modularGcd| |rewriteSetByReducingWithParticularGenerators| |range| |eval| |showAll?| |mainCharacterization| |changeMeasure| |plotPolar| |generateIrredPoly| |semiSubResultantGcdEuclidean2| |flexible?| |merge| |lfextlimint| |algDsolve| |moduleSum| |xRange| |fullDisplay| |zeroVector| |primextendedint| |solveLinearPolynomialEquationByRecursion| |OMencodingXML| |palglimint| |insertRoot!| |heap| |fortranLogical| |matrixDimensions| |normalized?| |qqq| |listYoungTableaus| |extractIndex| |associatedSystem| |polynomial| |explicitlyEmpty?| |besselJ| |rdregime| |rightMinimalPolynomial| |doubleResultant| |startTable!| |center| |placesOfDegree| |viewWriteAvailable| |initials| |chartV| |ord| |fortranInteger| |OMputInteger| |leftQuotient| |enqueue!| |times| |factorList| |replace| |every?| |pushuconst| |subscript| |coshIfCan| |cLog| |predicate| |rowEchWoZeroLinesWOVectorise| |unitVector| |doublyTransitive?| |zeroDim?| |rangeIsFinite| |setcurve!| |prefixRagits| |birth| |dcabs1| |variableName| |datalist| |iiasec| |cfirst| |writeLine!| |measure2Result| |maxint| |traverse| |fullParamInit| |rootOfIrreduciblePoly| |groebner?| |seed| |guessRat| |initiallyReduced?| |rightRank| |binaryTournament| |factorsOfCyclicGroupSize| |region| |makingStats?| |toseInvertible?| |linearAssociatedLog| |hMonic| |bombieriNorm| |overset?| |laplacian| |numberOfFractionalTerms| |unravel| |removeZeroes| |whileLoop| |sincos| |mainVariables| |isAbsolutelyIrreducible?| |oneDimensionalArray| |probablyZeroDim?| |argscript| |surface| |rootKerSimp| |iicsc| |divOfPole| |outputFixed| |fffg| |objects| |nthCoef| |leadingIndex| |comp| |redPol| |palgint| |computePowers| |fortranLinkerArgs| |nextIrreduciblePoly| |romberg| |createZechTable| |e01sff| |constantLeft| |karatsuba| |powmod| |conjugate| |solid?| |OMbindTCP| |base| |sup| |generalizedInverse| |OMputEndBVar| |newLine| |lhs| |setsymbName!| |contractSolve| |reseed| |clearTheFTable| |critBonD| |stack| |previousTower| |compose| |mr| |resize| |credPol| F |viewDeltaXDefault| |options| |evaluate| |clipBoolean| |getDomains| |initial| |createHN| |constantCoefficientRicDE| |float?| |closedCurve?| |integral?| |unrankImproperPartitions1| |getCode| |wholePart| |stoseInvertible?reg| |doubleDisc| |semicolonSeparate| |rst| |sizeLess?| |quadraticNorm| |prinshINFO| |remainder| |removeConjugate| |putGraph| |mapUp!| |iiacoth| |ref| |symbolTableOf| |option?| |gbasis| |associatorDependence| |setDegree!| |figureUnits| RF2UTS |sn| |factorset| |equality| |noLinearFactor?| |lowerPolynomial| |ScanRoman| |floor| |car| |rowEch| |sylvesterMatrix| |rightExtendedGcd| |modifyPointData| |leftLcm| |points| |cdr| |elColumn2!| |ellipticCylindrical| |sturmVariationsOf| |stFunc2| |lexGroebner| |rootRadius| |upperCase?| |elementary| |symmetricDifference| |noncommutativeJordanAlgebra?| |prologue| |singularitiesOf| |constantOperator| |cartesian| |rischNormalize| |nilFactor| |newReduc| |hasoln| |setClipValue| |placesAbove| |plus| |asimpson| |magnitude| |weight| |ideal| |extensionDegree| |resultantEuclidean| |basisOfRightAnnihilator| |One| |integralDerivationMatrix| |algintegrate| |dmp2rfi| |fglmIfCan| |pattern| |suchThat| |iiacot| |ShiftC| |roughUnitIdeal?| |cyclicParents| |collectQuasiMonic| |applyRules| |tanintegrate| |OMencodingSGML| |htrigs| |numberOfComposites| |unit?| |errorKind| |intPatternMatch| |computeCycleLength| |beauzamyBound| |reverse!| |complexEigenvectors| |lieAlgebra?| |safety| |rowEchWoZeroLines| |clearCache| |countRealRootsMultiple| |groebnerIdeal| |computeBasis| |checkPrecision| |musserTrials| |univcase| |ratDsolve| |symmetricSquare| |iprint| |standardBasisOfCyclicSubmodule| |initializeGroupForWordProblem| |deepestTail| |maxrow| |enterPointData| |viewDeltaYDefault| |univariatePolynomialsGcds| |setpoint!| |possiblyInfinite?| |subHeight| |leftFactorIfCan| |foundZeroes| |OMgetEndAtp| |degOneCoef| |halfExtendedResultant1| |nextSubsetGray| |initTable!| |basisOfLeftAnnihilator| ~ |dequeue| |skewSFunction| |setOfMinN| |clipWithRanges| |identitySquareMatrix| |numberOfPrimitivePoly| |crushedSet| |separate| |string?| |aCubic| |En| |nthRootIfCan| |sumOfDivisors| |cCosh| |definingPolynomial| |mathieu24| |fractionFreeGauss!| |critM| |integralMatrix| |rightTraceMatrix| |laguerre| |guess| |discriminantEuclidean| |typeLists| |resetNew| |LPolynomial| |unary?| |contains?| |findOrderOfDivisor| |summary| |rationalIfCan| |karatsubaDivide| |check| |eisensteinIrreducible?| |rotate| |show| |expIfCan| |multiEuclideanTree| |df2ef| |leaf?| |mathieu11| |rightDivide| |unvectorise| |e02aef| |packageCall| |slope| |integralCoordinates| |setvalue!| |argumentListOf| |cos2sec| |blue| |maxRowIndex| |c02agf| |extendIfCan| |maxdeg| |convergents| |sylvesterSequence| |c02aff| |rspace| |iifact| |testModulus| |tubePlot| |e02adf| |showAttributes| |stoseInternalLastSubResultant| |algebraicDecompose| |squareFree| |second| |c05pbf| |zeroOf| |findTerm| GF2FG |shallowCopy| |problemPoints| |genericRightMinimalPolynomial| |compile| |setPrologue!| |diophantineSystem| |leader| |credits| |derivative| |completeHensel| |nextPartition| |lieAdmissible?| |infix?| |#| |binarySearchTree| |BumInSepFFE| |node?| |iiacsch| |e01sef| |blowUpWithExcpDiv| |lastSubResultantEuclidean| |write!| |allDegrees| |comment| |e01saf| |regularRepresentation| |simplifyLog| |iiBesselI| |nonQsign| |id| |e01daf| |overlap| |multiplyCoefficients| = |axes| |invertibleElseSplit?| |arg1| |integer| |e01bhf| |digit| |consnewpol| |zag| |module| |arg2| |iisec| |e01bgf| |conjug| |random| < |head| |bat1| |iisqrt2| |e01bff| |more?| > |transcendenceDegree| |weierstrass| |someBasis| |string| |e01bef| |optpair| <= |OMreceive| |torsionIfCan| |localUnquote| |e01baf| |squareFreePolynomial| >= |dmpToHdmp| |sumOfKthPowerDivisors| |e02zaf| |compiledFunction| |stoseInvertible?| |realEigenvectors| |addPoint2| |e02gaf| |eigenvalues| |guessHP| |OMUnknownCD?| |youngGroup| |highCommonTerms| |e02dff| |updatF| + |checkRur| |getVariableOrder| |randomLC| |e02def| |createRandomElement| - |getCurve| |hadamard| |alphanumeric?| |e02ddf| |atanhIfCan| / |asechIfCan| |BasicMethod| |e02dcf| |delete!| |title| |setsubMatrix!| |explicitlyFinite?| |tubePoints| |e02daf| |perfectNthRoot| |calcRanges| |union| |stripCommentsAndBlanks| |e02bef| |isPlus| |list?| |preprocess| |mpsode| |open| |duplicates| |pile| |genusNeg| |outerProduct| |e01sbf| |jordanAlgebra?| |chainSubResultants| |elements| |extend| |deleteProperty!| |edf2efi| |reverseLex| |complete| |Ei6| |color| |selectSumOfSquaresRoutines| |top!| |in?| |stFunc1| |row| |hue| |integralBasisAtInfinity| |prevPrime| |pade| |pointPlot| |irreducibleFactor| |odd?| |associates?| |divideIfCan| |generic| |guessExpRat| |ReduceOrder| |pureLex| |affineAlgSetLocal| |tryFunctionalDecomposition?| |symmetricProduct| |setScreenResolution3D| |trueEqual| |overbar| |hconcat| |diagonals| |firstSubsetGray| |const| |gradient| |compdegd| |ptree| |se2rfi| |singularPoints| |digamma| |satisfy?| |new| |quadTransform| |radix| |coerceP| |eq| |unparse| |append| |sinIfCan| |ddFact| |solveLinearPolynomialEquation| |translate| |arity| |cyclotomicFactorization| |purelyTranscendental?| |build| |function| |setImagSteps| |rightTrace| |constant?| |swap!| |rightTrim| |shift| |insertTop!| |palgintegrate| |upperCase!| |makeGraphImage| |droot| |expt| |symmetricRemainder| |coHeight| |separateDegrees| |resultantReduit| |minIndex| |antisymmetricTensors| |blowUp| |rightExactQuotient| |optAttributes| |ode1| ^ |simpleBounds?| |exponents| |inspect| |mapUnivariateIfCan| |exp| |cSin| |setMinPoints3D| |rationalPoints| |fullInfClsPt| |pi| |getStream| |numFunEvals3D| |defineProperty| |iteratedInitials| |sqrt| |sdf2lst| |useEisensteinCriterion| UP2UTS |OMgetApp| |log10| |lfintegrate| |vark| |antisymmetric?| |li| |nonLinearPart| |lfextendedint| |moduloP| |rischDEsys| |erf| |supp| |normalizeIfCan| |interpolate| |elRow1!| |common| |fortranCharacter| |components| |ratpart| |flagFactor| |localReal?| |imagK| |dilog| |partitions| |conjugates| |perspective| |trace| |tan| |linearPolynomials| |linearMatrix| |getZechTable| |cot| |FormatArabic| |completeSmith| |failed?| |sec| |genericRightDiscriminant| |basisOfNucleus| |fullDesTree| |csc| |keys| |partialNumerators| |lazyPseudoQuotient| |asin| |minimumExponent| |cTanh| |replaceDiffs| |acos| |OMencodingUnknown| |generalizedEigenvectors| |updateStatus!| |mapUnivariate| |atan| |squareFreeFactors| |diagonal?| |guessBinRat| |acot| |qPot| |moebiusMu| |singular?| |asec| |bfKeys| |radicalEigenvector| |Ei| |acsc| |subresultantVector| |useEisensteinCriterion?| |powern| |sinh| |infiniteProduct| |nlde| |Vectorise| |cosh| |members| |setVariableOrder| |atanIfCan| |tanh| |principalIdeal| |closedCurve| |padicallyExpand| |coth| |findCoef| |complexExpand| |isobaric?| |sech| |affineAlgSet| |ffactor| E1 |csch| |basisOfCentroid| |numFunEvals| |primintegrate| |asinh| |Aleph| |chvar| |createLowComplexityNormalBasis| |acosh| |lowerCase| |areEquivalent?| |internalIntegrate| |atanh| |polar| |stopTable!| |triangSolve| |acoth| |oddlambert| |rightRemainder| |OMputEndAtp| |asech| |var2StepsDefault| |sorted?| |guessAlg| |mindeg| |resetAttributeButtons| |univariate?| |multinomial| |representationType| |deriv| |safetyMargin| |balancedFactorisation| |modifyPoint| |createNormalElement| |pascalTriangle| |cSec| |transform| |mainDefiningPolynomial| |subset?| |positive?| |minrank| |linearAssociatedOrder| |algebraicSet| |asinhIfCan| |pushucoef| |directProduct| |positiveSolve| |entries| |ignore?| |destruct| |sinh2csch| |minimalPolynomial| |mkPrim| |monomial| |indiceSubResultant| |oddInfiniteProduct| |OMclose| |multivariate| |quasiMonicPolynomials| |primitivePart!| |mesh?| |variables| |tanSum| |variationOfParameters| |setMaxPoints| |plot| |diff| |leastPower| |removeZero| |removeRedundantFactorsInContents| |sPol| |taylor| |getlo| |rur| |moreAlgebraic?| |returnType!| |laurent| |palgLODE0| |upperCase| |iiasech| |numberOfImproperPartitions| |puiseux| |pfaffian| |stirling2| |exp1| |createThreeSpace| |true| |inv| |evaluateInverse| |cAcsch| |OMgetType| |dictionary| |ground?| |minRowIndex| |LyndonCoordinates| |OMgetObject| |SturmHabicht| |ground| |box| |normInvertible?| |rules| |OMencodingBinary| |mapGen| |leadingMonomial| |OMgetEndAttr| |internalZeroSetSplit| |coordinate| |monicCompleteDecompose| |leadingCoefficient| |extractPoint| |leastMonomial| |drawStyle| |selectNonFiniteRoutines| |rhs| |primitiveMonomials| |linearAssociatedExp| |invmod| |mainContent| |copies| |numberOfNormalPoly| |reductum| |var2Steps| |repeating| |separateFactors| |leastAffineMultiple| |OMlistCDs| |rk4a| |nullity| |exprHasAlgebraicWeight| |OMputEndObject| |specialTrigs| |sequences| |genus| |sinhcosh| |makeCos| |revert| |nary?| |dihedral| |effective?| |Yun| |localParamV| |OMserve| |acschIfCan| |setStatus| |iisin| |and| |postfix| |subspace| |innerSolve1| |root| |minimumDegree| |finiteSeries2LinSys| |realZeros| |clipSurface| |zeta| |UpTriBddDenomInv| |extendedint| |plus!| |polyRing2UPUP| |encode| |noKaratsuba| |gcdPolynomial| |LazardQuotient| |lifting| |iisqrt3| |expintegrate| |complement| |fortranCarriageReturn| |monicRightFactorIfCan| |iiAiryBi| |removeSuperfluousQuasiComponents| |hypergeometric0F1| |less?| |divideExponents| |basisOfInterpolateFormsForFact| |critMTonD1| |reindex| |internal?| |getOrder| |removeRedundantFactors| |bat| |unaryFunction| |desingTree| |mkIntegral| |int| |realEigenvalues| |idealiserMatrix| |identityMatrix| |cycleElt| |error| |fullOut| |integers| |padicFraction| |irreducibleRepresentation| |cAtan| |antiAssociative?| |initializeParamOfPlaces| |normalDenom| NOT |lyndon?| |viewPhiDefault| |palgint0| |parse| |totolex| OR |commaSeparate| |shanksDiscLogAlgorithm| |hasTopPredicate?| |basisOfLeftNucleus| |balancedBinaryTree| AND |linear| |OMgetEndError| |quasiRegular| |alphabetic| |assert| |curry| |Lazard| |subQuasiComponent?| |condition| |printStatement| |parametrize| |extractTop!| |discriminant| |doubleRank| |type| |groebSolve| |conditions| |internalLastSubResultant| |maxIndex| |generalLambert| |fintegrate| |semiResultantReduitEuclidean| |unitCanonical| |quotVecSpaceBasis| |cyclicSubmodule| |square?| |partialFraction| |redmat| |lists| |rationalPoint?| |third| |acothIfCan| |simplifyExp| |sh| |numberOfCycles| |sech2cosh| |Ei1| |normal| |setleaves!| |mainVariable| |negative?| |lBasis| |setlocalParam!| |printingInfo?| |subResultantsChain| |monomialIntegrate| |inR?| |radicalRoots| |LiePolyIfCan| * |removeFirstZeroes| |copyInto!| |meshPar1Var| |isQuotient| |transCoord| |leftExactQuotient| |iicos| |absolutelyIrreducible?| |OMconnectTCP| |rotatez| |leftMinimalPolynomial| |radicalEigenvectors| |genericLeftDiscriminant| |cAsech| |matrix| |stopTableGcd!| |setTex!| |OMsupportsSymbol?| |completeEchelonBasis| |removeRedundantFactorsInPols| |gramschmidt| |makeop| |classNumber| |monic?| |linearlyDependent?| |lazyResidueClass| |df2st| |diagonalMatrix| |algebraicSort| |quotedOperators| |ceiling| |normFactors| |nodes| |algebraicCoefficients?| |solid| |drawComplexVectorField| |pushdterm| |multiServ| |notelem| |infix| |unit| |point?| |mainPrimitivePart| |twoFactor| |addMatchRestricted| |LowTriBddDenomInv| |exponentialOrder| |diag| |iiabs| |llprop| |OMgetBVar| |ScanArabic| |leftOne| |OMgetEndBVar| |ldf2lst| |double?| |splitSquarefree| |newtonPolygon| |fprindINFO| |predicates| |leadingTerm| |reset| |numer| |bezoutMatrix| |rubiksGroup| |useSingleFactorBound| |generalPosition| |cCot| |write| |denom| |toroidal| |cup| |clearTheIFTable| |basisOfRightNucloid| |dAndcExp| |save| |coefChoose| |An| |irreducibleFactors| |setLegalFortranSourceExtensions| |invertibleSet| |draw| |fortranReal| |makeprod| |recolor| |cycleTail| |pair?| |makeObject| |hex| |expressIdealMember| |att2Result| |idealSimplify| |cyclotomicDecomposition| |coef| |dec| |OMputApp| |allPairsAmong| |simplifyPower| |commutator| |monom| |rewriteIdealWithRemainder| |mvar| |airyAi| |showClipRegion| |boundOfCauchy| |firstDenom| |LazardQuotient2| |heapSort| |rightOne| |integralLastSubResultant| |columnSpace| |subst| |bag| |dequeue!| |sechIfCan| |OMputError| |testDim| |evenlambert| |create| |critpOrder| |besselK| |xn| |fixPredicate| |makeSketch| |extendedResultant| |mainCoefficients| |fillPascalTriangle| |singleFactorBound| |logical?| |constantKernel| |complexZeros| |lp| |zeroSetSplitIntoTriangularSystems| |divisorAtDesingTree| |squareFreePrim| |initParLocLeaves| |ratPoly| |isMult| |prolateSpheroidal| |zerosOf| |setlast!| |negAndPosEdge| |listexp| |var1StepsDefault| |OMopenFile| |dom| |rem| |constantRight| |hcrf| |getMeasure| |createMultiplicationMatrix| |lexTriangular| |mirror| |nthExpon| |lazyPremWithDefault| |cAtanh| |intersectionDivisor| |quo| |permutation| |block| |zeroSetSplit| |putColorInfo| |lllip| |library| |multiset| |rightLcm| |posExpnPart| |definingEquations| |sumOfSquares| |/\\| |rational| |intermediateResultsIF| |factorial| |cylindrical| |mainMonomial| |\\/| |tubePointsDefault| |cardinality| |antiCommutative?| |Lazard2| |csch2sinh| |setelt| |semiLastSubResultantEuclidean| |rCoord| |infieldIntegrate| |maxPoints3D| |createNormalPoly| |finiteBasis| |palgRDE0| |chiSquare1| |functionIsContinuousAtEndPoints| |countable?| ~= |totalfract| |nthFlag| |leftGcd| |setColumn!| |checkOptions| |setCondition!| |createPrimitivePoly| |orderIfNegative| |chartCoord| |readLineIfCan!| |ramifMult| |dark| |nor| |OMconnOutDevice| |trailingCoefficient| |segment| |nthFractionalTerm| |determinant| |bracket| |level| |degreePartition| |clearDenominator| |outputFloating| |complexLimit| |tableau| |vconcat| |viewZoomDefault| |cubic| |origin| |factorUsingMusser| |typeList| |degreeSubResultantEuclidean| |adjunctionDivisor| |coth2tanh| |linGenPos| |iCompose| |inverseLaplace| |cCoth| |pointColorDefault| |exprToXXP| |safeFloor| |edf2fi| |increase| |null?| |rewriteIdealWithHeadRemainder| |slex| |binary| |lcm| |lowerCase!| |transcendentalDecompose| |axServer| |UP2ifCan| |symbol?| |viewpoint| |scripted?| |factorAndSplit| |modTree| |mapExpon| |startPolynomial| |monicModulo| |currentSubProgram| |oddintegers| |size?| |reopen!| |scan| |listOfMonoms| |zRange| |getGoodPrime| |bumptab| |setfirst!| |monicDecomposeIfCan| |factor1| |resetVariableOrder| |min| |denomLODE| |tensorProduct| |cAcosh| |interpolateFormsForFact| |addBadValue| |lazyVariations| |saturate| |style| |atrapezoidal| |rotatey| |lquo| |suppOfZero| |factorsOfDegree| |possiblyNewVariety?| |radPoly| |zero?| |subResultantGcdEuclidean| |quote| |fortranTypeOf| |eulerE| |bernoulli| |rightMult| |untab| |interReduce| |OMputAtp| |screenResolution3D| |affineSingularPoints| |graphState| |listBranches| |mapSolve| |makeMulti| |sub| |messagePrint| |ncols| |tryFunctionalDecomposition| |lighting| |approxSqrt| |inverseColeman| |tRange| |tanh2coth| |paraboloidal| |minimalForm| |superHeight| |ode2| |laguerreL| |aQuartic| |removeRoughlyRedundantFactorsInPols| |mapBivariate| |dim| LT |vectorise| |decreasePrecision| |augment| |OMgetVariable| |shallowExpand| |logpart| |solveInField| |newSubProgram| |solve1| |cothIfCan| |complexElementary| |terms| |elRow2!| |iiasin| |resultantReduitEuclidean| |inBetweenExcpDiv| |tanhIfCan| |swap| |lyndonIfCan| |showTheRoutinesTable| |returns| |rightUnit| |tan2cot| |exquo| |ZetaFunction| |null| |characteristicSerie| |leftUnit| |updatD| |div| |qelt| |restorePrecision| |coefficient| |machineFraction| |theCurve| |rightQuotient| |lagrange| |meatAxe| |iitanh| |lflimitedint| ^= |rroot| |OMsupportsCD?| |transcendent?| |top| |truncate| |move| |sts2stst| |limitPlus| |constantOpIfCan| |graeffe| |normalizedAssociate| |setTopPredicate| |desingTreeAtPoint| |lllp| |sum| |rquo| |adaptive3D?| |factorSquareFree| |iiBesselJ| |invertible?| |normalForm| |sturmSequence| |fibonacci| |real?| |affinePoint| |viewport2D| |wordsForStrongGenerators| |makeUnit| |showTheIFTable| |goodnessOfFit| |factorSqFree| |infRittWu?| |doubleComplex?| |yCoordinates| |OMputBVar| |insertMatch| |cyclic| |goodPoint| |multisect| |cycleRagits| |factorSquareFreeByRecursion| |lepol| |quotValuation| |ldf2vmf| |norm| |central?| |guessHolo| |nthExponent| |match| |monomial2series| |brillhartIrreducible?| |interpolateForms| |Hausdorff| |OMreadStr| |affineRationalPoints| |interval| |rootSimp| |rootPower| |sample| |isPower| |deepExpand| |search| |expint| |incrementKthElement| |bumprow| |characteristicPolynomial| |getExplanations| |numberOfChildren| |rightGcd| |initiallyReduce| |call| LE |symFunc| |toseInvertibleSet| |escape| |rational?| |exists?| |submod| |stirling1| |chiSquare| |patternMatchTimes| |ridHack1| |factorSFBRlcUnit| |SturmHabichtCoefficients| |composites| |whatInfinity| |symmetricPower| |pol| |inHallBasis?| |showTypeInOutput| |unexpand| |generator| |headRemainder| |infieldint| |mightHaveRoots| |normalDeriv| |euclideanSize| |evenInfiniteProduct| |rootNormalize| |branchPoint?| |retractToGrn| |cycleSplit!| |groebner| |sin2csc| |lastSubResultantElseSplit| |decrease| |increasePrecision| |compactFraction| |gcd| |contract| GT |groebnerFactorize| |singularPointsWithRestriction| |genericLeftMinimalPolynomial| |showIntensityFunctions| |OMconnInDevice| |pmComplexintegrate| |ParCondList| |iiacosh| |bezoutDiscriminant| |ravel| |deepestInitial| |one?| |removeSuperfluousCases| |linears| |curryLeft| |algebraicVariables| |suppOfPole| |writeObj| |perfectSqrt| |setOrder| |createPrimitiveNormalPoly| |coerce| |lo| |quadraticBezier| |cross| |set| |leadingIdeal| |incr| |cap| |external?| |hi| |OMsetEncoding| |polCase| |exprToGenUPS| |getMultiplicationTable| |LyndonBasis| |PollardSmallFactor| |outputGeneral| |declare| |limit| |position| |ode| |goppaCode| |leftAlternative?| |concat| |chineseRemainder| |cyclePartition| |nthr| |wordInStrongGenerators| |totalDegree| GE |cycleLength| |structuralConstants| |iiexp| |deepCopy| |elt| |vspace| |generate| |exprHasLogarithmicWeights| |equation| |factorials| |incrementBy| |sin| |binomial| |guessPRec| |expand| |cos| |bit?| |npcoef| |root?| |filterWhile| |map| |tail| |iiAiryAi| |filterUntil| |getGraph| |comparison| |select| |assoc| |fTable| |pointData| |unrankImproperPartitions0| |rk4qc| |light| |hermiteH| |crest| |completeEval| |vedf2vef| |status| |coercePreimagesImages| |critT| |iiGamma| |trace2PowMod| |makeRecord| |complexNormalize| |stronglyReduce| |zeroMatrix| |trunc| |baseRDEsys| |property| |combineFeatureCompatibility| |sqfrFactor| |delete| |decomposeFunc| |primes| |dioSolve| |quasiAlgebraicSet| |identification| |units| |sncndn| |scanOneDimSubspaces| |addPointLast| |indexName| |nsqfree| |e| |makeResult| |repSq| |is?| |extDegree| |maxrank| |listVariable| |code| |rectangularMatrix| |decompose| |polyPart| |divisor| |value| |fortranDoubleComplex| |lineColorDefault| |anticoord| |retract| |numericalOptimization| |cyclicEntries| |coerceL| |horizConcat| |OMputEndError| |semiIndiceSubResultantEuclidean| |minGbasis| |properties| |bipolarCylindrical| |inGroundField?| |generators| |makeSeries| |iicsch| |zoom| |leaves| |transpose| |charpol| |implies| |quatern| |partialDenominators| |pquo| |stoseInvertible?sqfreg| |closeComponent| |integerBound| |halfExtendedSubResultantGcd2| |lfinfieldint| |wreath| |nthFactor| |normalElement| |homogeneous| |OMcloseConn| |principal?| |belong?| |fractRagits| |leftTrace| |complexIntegrate| |lastNonNul| |lazyEvaluate| |maxColIndex| |solveid| |weakBiRank| |f04adf| |abs| |biRank| |pop!| |ScanFloatIgnoreSpacesIfCan| |linSolve| |Ci| |makeYoungTableau| |shufflein| |factorSquareFreePolynomial| |rarrow| |mapCoef| |fortranCompilerName| |continue| |reduceRow| |selectsecond| |eigenMatrix| |OMunhandledSymbol| |mergeDifference| |deref| |char| |pushup| |push!| |jordanAdmissible?| |f07fef| |cycles| |polynomialZeros| |direction| |f07fdf| |recip| Y |alternatingGroup| |mat| |f07aef| |findCycle| |smith| |rootOf| |f07adf| |atoms| |getPickedPoints| |makeFR| |rename!| |indiceSubResultantEuclidean| |parametersOf| |s17dlf| |OMmakeConn| |numeric| |listAllMonoExp| |s17dhf| |radicalOfLeftTraceForm| |roughBasicSet| |solveLinear| |s17dgf| |linkToFortran| |radicalSimplify| |removeSinhSq| |f02xef| |btwFact| |henselFact| |makeTerm| |f02wef| |cAcoth| |curryRight| |palglimint0| |option| |height| |f02fjf| |resultantnaif| |OMgetInteger| |coerceImages| |f02bjf| |update| |palgextint0| |indicialEquation| |linearlyDependentOverZ?| |high| |f02bbf| |cubicBezier| |aQuadratic| |quadratic| |monomials| |f02axf| |graphs| |conditionP| FG2F |f02awf| |divergence| |reducedContinuedFraction| |curveColorPalette| |pdf2df| |table| |f02akf| |evalRec| |rightCharacteristicPolynomial| |minPol| |definingInequation| |f02ajf| EQ |algint| |selectMultiDimensionalRoutines| |iicot| |f02agf| |times!| |supersub| |mkcomm| |tower| |pseudoRemainder| |palgRDE| |isOp| |And| |f02aff| |minPoly| |coth2trigh| |aspFilename| |setPoly| |f02aef| |hitherPlane| |denominator| |dfRange| |f02adf| |complementaryBasis| |normalizeAtInfinity| |element?| |cosh2sech| |f02abf| |sortConstraints| |cyclicEqual?| |omError| |f02aaf| |qfactor| |socf2socdf| |explimitedint| |left| |measure| |varselect| |realElementary| |firstUncouplingMatrix| |multiple| |lyndon| |df2mf| |integralMatrixAtInfinity| |optional| |nextItem| |homogenize| |quartic| |fixedDivisor| |rightRegularRepresentation| |nrows| |not| |OMgetString| |functionName| |round| |modularGcdPrimitive| |lprop| |listRepresentation| |distinguishedCommonRootsOf| |displayAsGF| |acotIfCan| |appendPoint| |exactQuotient!| |Zero| |idealiser| |applyQuote| |infinity| |iidsum| |edf2ef| |listAllMono| |double| |geometric| |createPrimitiveElement| |debug3D| |numberOfHues| LODO2FUN |primPartElseUnitCanonical!| |OMgetEndObject| |outputAsScript| |OMgetError| |symmetricGroup| |laurentIfCan| |exteriorDifferential| |rightFactorIfCan| |cRationalPower| |hclf| |ocf2ocdf| |nextSublist| |blankSeparate| |minordet| |curveColor| |empty?| |lift| |janko2| |genericRightTrace| |pomopo!| |setleft!| |generalizedContinuumHypothesisAssumed| |xor| |reduce| |commonDenominator| |modulus| |mapdiv| |viewPosDefault| |DiffC| |OMputAttr| |addiag| |cAsin| |rotatex| |genericLeftTrace| |GospersMethod| |or| |realSolve| |roughEqualIdeals?| |stepBlowUp| |reduceLineOverLine| |member?| |linearPart| |patternVariable| |signAround| |midpoints| |numberPlacesDegExtDeg| |shiftInfoRec| |leftUnits| |imagk| |stFuncN| |enterInCache| |OMputEndBind| |frst| |generalizedEigenvector| |bitCoef| |cAsec| |permutationRepresentation| |setRealSteps| |matrixConcat3D| |totalLex| |nextColeman| |iibinom| |fixedPoints| |iflist2Result| |cot2trig| |subtractIfCan| |alphanumeric| |removeIrreducibleRedundantFactors| |completeHermite| |setPosition| |setprevious!| |inverse| |dihedralGroup| |e02bcf| |discreteLog| |maxPoints| |complexForm| |frobenius| |jacobian| |e02bbf| |df2fi| |graphStates| |shiftRight| |lex| |Ei5| |e02baf| |DiffAction| |kovacic| |numberOfFactors| |choosemon| |splitLinear| |e02akf| |factorCantorZassenhaus| |iidigamma| |isList| |reducedSystem| |removeSquaresIfCan| |nodeOf?| |e02ajf| |expintfldpoly| |mindegTerm| |normalise| |eq?| |polyRingToBlUpRing| |e04ycf| |script| |expenseOfEvaluationIF| |subscriptedVariables| |distdfact| |SturmHabichtMultiple| |startTableGcd!| |symbol| |e04ucf| |clip| |leftZero| |leftScalarTimes!| |number?| |OMReadError?| |primlimitedint| |e04naf| |one| D |pmintegrate| |movedPoints| |purelyAlgebraic?| |startTableInvSet!| |e04mbf| |univariatePolynomial| |unmakeSUP| |SFunction| |rootBound| |drawToScale| |trigs2explogs| |makeViewport2D| |halfExtendedSubResultantGcd1| |e04jaf| |zero| |degree| |inrootof| |listOfLists| |listLoops| |divide| |tableForDiscreteLogarithm| |intersect| |e04gcf| |rootsOf| |iiacsc| |selectPolynomials| |prindINFO| |primeFrobenius| |e04fdf| |fortran| |extractProperty| |domainOf| |algSplitSimple| |epilogue| |readLine!| |green| |topPredicate| |e04dgf| |systemCommand| |certainlySubVariety?| |sparsityIF| |finiteSeries2Vector| |definingField| |exponential1| |cAcsc| |rewriteIdealWithQuasiMonicGenerators| |f01ref| |leftRank| |extractSplittingLeaf| |showTheSymbolTable| |diagonalProduct| |prinpolINFO| |leftRecip| |f01rdf| |pleskenSplit| |pdf2ef| |eulerPhi| |empty| |selectIntegrationRoutines| |primitivePart| |Not| |f01rcf| |exprex| |toScale| |invertIfCan| |argument| |semiSubResultantGcdEuclidean1| |f01qef| |baseRDE| |dmpToP| |kroneckerDelta| |localAbs| |OMreadFile| |moebius| |semiResultantEuclidean1| |f01qdf| |pr2dmp| |max| |logIfCan| |ipow| |permanent| |product| |dimensionsOf| |spherical| |f01qcf| |factors| |even?| |rootProduct| |gcdcofactprim| |intChoose| |numberOfPlacesOfDegree| |numberOfValuesNeeded| |rk4| |right| |f01mcf| |bottom!| |tablePow| |lifting1| |f01maf| |mainSquareFreePart| |stosePrepareSubResAlgo| |autoReduced?| |Or| |trapezoidal| |conditionsForIdempotents| |operators| |complexNumericIfCan| |strongGenerators| |controlPanel| |stronglyReduced?| |setLabelValue| |cache| |f01bsf| |simpsono| |iomode| |label| |permutations| |f01brf| |child| |thetaCoord| |monomialIntPoly| |imagJ| |identity| |OMlistSymbols| |OMgetAtp| |associatedEquations| |drawCurves| |fortranLiteral| |complex?| |createGenericMatrix| |eyeDistance| |cosIfCan| |iiBesselY| |isTimes| |ShiftAction| |mulmod| |read!| |univariateSolve| |leftNorm| |endSubProgram| |iisech| |anfactor| |exptMod| |aLinear| |cycleEntry| |closed?| |recur| |minimize| |nand| |orbit| |node| |exprHasWeightCosWXorSinWX| |hdmpToP| |tracePowMod| |semiDegreeSubResultantEuclidean| |coerceS| |vertConcat| |changeName| |merge!| |OMsend| |iiatan| |pushdown| |cSech| |numberRatPlacesExtDeg| |newElement| |nextNormalPoly| |directSum| |lazyIntegrate| |precision| |rule| |localParam| |useSingleFactorBound?| |quasiRegular?| |minColIndex| |showTheFTable| |nextsousResultant2| |content| |tube| |removeDuplicates!| |f2df| |setEpilogue!| |has?| |getShiftRec| |retractable?| |brillhartTrials| |quickSort| |writable?| |polarCoordinates| |monicDivide| |pack!| |stiffnessAndStabilityFactor| |leftTrim| |nextPrimitiveNormalPoly| |rightAlternative?| |ruleset| |leftFactor| |listConjugateBases| |showAllElements| |orbits| |prefix| |name| |mainVariable?| |setmult!| |tex| |generalSqFr| |digits| |viewThetaDefault| |daxpy| |tree| |gcdPrimitive| |leadingExponent| |rombergo| |removeRoughlyRedundantFactorsInPol| |upDateBranches| |remove!| |operation| |perfectNthPower?| |Is| |newtonPolySlope| |rightScalarTimes!| |tanAn| |deleteRoutine!| |lazyPrem| |taylorQuoByVar| |universe| |rangePascalTriangle| |print| |toseSquareFreePart| |squareFreeLexTriangular| |factorByRecursion| |reduceLODE| |scalarMatrix| |maxShift| |directory| |fullPartialFraction| |critMonD1| |pointToPlace| |physicalLength!| |laurentRep| |diffHP| |primPartElseUnitCanonical| |setref| |commutative?| |denominators| |Ei4| |squareMatrix| |ranges| |exponent| |maxLevel| |algebraicOf| |stiffnessAndStabilityOfODEIF| |mainValue| |kernel| |quadraticForm| |iitan| |elem?| |zeroDimPrime?| |myDegree| |finite?| |polyRDE| |divisorCascade| |stoseInvertibleSetsqfreg| |fi2df| |bivariateSLPEBR| |evalADE| |genericLeftTraceForm| |getDatabase| |sinhIfCan| |functionIsOscillatory| |usingTable?| |monomRDEsys| UTS2UP |divideIfCan!| |cSinh| |any| |bitTruth| |bezoutResultant| |cCsch| |OMputEndApp| |setsubmult!| |complexRoots| |lambda| |internalAugment| |bright| |rotate!| |red| |result| |insertionSort!| |OMgetAttr| |stop| |translateToOrigin| |viewport3D| |failed| |bivariate?| |tubeRadius| |iilog| |goto| |operator| |copy!| |quoByVar| |child?| |t| |pToDmp| |output| |constant| |palgextint| |setright!| |represents| |getBadValues| |antiCommutator| |zeroDimPrimary?| |distribute| |cycle| |stoseIntegralLastSubResultant| |removeCoshSq| |po| |select!| |getOp| |cotIfCan| |superscript| |cschIfCan| |hexDigit?| |iicoth| |symmetricTensors| |OMgetEndApp| |repeating?| |asecIfCan| |parametric?| |setnext!| |numberOfIrreduciblePoly| |maxPower| |stoseLastSubResultant| |dimensions| |setchart!| |acoshIfCan| |divisors| |super| |cot2tan| |seriesToOutputForm| |queue| |coerceListOfPairs| |sizePascalTriangle| |rationalPower| |projectivePoint| |shrinkable| |multiplyExponents| |inconsistent?| |fortranLiteralLine| |rename| |OMputVariable| |hyperelliptic| |alternating| |iiperm| |mantissa| |factorPolynomial| |slash| |lazyPseudoDivide| |key?| |bsolve| |rightRecip| |rightPower| |explicitEntries?| |prepareDecompose| |checkForZero| |rischDE| |basicSet| |enumerate| |iipow| |finiteBound| |semiDiscriminantEuclidean| |limitedIntegrate| |multiEuclidean| |froot| |constantIfCan| |charClass| |wholeRagits| |selectODEIVPRoutines| |setProperties| |rightDiscriminant| |selectOrPolynomials| |var1Steps| |bitLength| |quoted?| |pointColor| |physicalLength| |tanNa| |pointColorPalette| |index?| |ptFunc| |itsALeaf!| |pseudoQuotient| |inf| |loopPoints| |removeRoughlyRedundantFactorsInContents| |numberOfDivisors| |e02bdf| |OMputBind| |solveLinearPolynomialEquationByFractions| |ParCond| |powers| |intcompBasis| |FormatRoman| |factorUsingYun| |minusInfinity| |varList| |readable?| |character?| |distinguishedRootsOf| |radicalSolve| |wronskianMatrix| |RittWuCompare| |plusInfinity| |iiBesselK| |genericRightTraceForm| |shuffle| |hasPredicate?| |laplace| |extractIfCan| |arrayStack| |useNagFunctions| |void| |denomRicDE| |taylorRep| |maxTower| |qnew| |interpretString| |linearBezier| |reciprocalPolynomial| |sec2cos| |halfExtendedResultant2| |rootSplit| |swapColumns!| |graphCurves| |zeroDimensional?| |conical| |leftCharacteristicPolynomial| |reduction| |normalize| |randomR| |roman| |mathieu12| |gethi| |elliptic| |solveLinearlyOverQ| |quasiComponent| |userOrdered?| |close!| |padecf| |subsInVar| |biringToPolyRing| |guessADE| |pointV| |interpret| |sort| |unitsColorDefault| |scale| |kmax| |clipParametric| |key| |next| |mask| |maximumExponent| |supRittWu?| |cAcot| |viewDefaults| |unprotectedRemoveRedundantFactors| |besselY| |dasum| |hexDigit| |dominantTerm| |integralBasis| |sign| |monomRDE| |setErrorBound| |pdct| |retractIfCan| |iiasinh| |d01gbf| |raisePolynomial| |relerror| |reducedQPowers| |polygon?| |suffix?| |map!| |setlocalPoint!| |subMatrix| |d01gaf| |length| |schema| |outputForm| |normal01| |dot| |lookup| |extendedIntegrate| |d01fcf| |subCase?| |scripts| |meshFun2Var| |getRef| |integral| |regime| |reduceBasisAtInfinity| |mainKernel| |d01bbf| |roughBase?| |iExquo| |exQuo| |schwerpunkt| |pToHdmp| |rank| |d01asf| |mathieu23| |uniform| |processTemplate| |primintfldpoly| |tanh2trigh| |showRegion| |eigenvector| |randnum| |qroot| |OMopenString| |unitNormal| |mesh| |localIntegralBasis| |d02raf| |Ei3| |numericIfCan| |factorGroebnerBasis| |OMgetEndBind| |harmonic| |univariatePolynomials| |d02kef| |weighted| |fill!| |printCode| |reduceRowOnList| |rowEchelonLocal| |series| |d02gbf| |lambert| |column| |collectUnder| |resultantEuclideannaif| |pointInIdeal?| |lfunc| |d02gaf| |besselI| |badNum| |octon| |twist| |power| |subs2ndVar| |cosSinInfo| |d02ejf| |coleman| |basis| |LyndonWordsList1| |leftRemainder| |lazyGintegrate| |critB| |isExpt| |d02cjf| |chebyshevU| |OMwrite| |trigs| |pointSizeDefault| |singRicDE| |leftExtendedGcd| |basisOfLeftNucloid| |substring?| |d02bhf| |cn| |foundPlaces| |makeSUP| |maxDerivative| |prefix?| |xCoord| |float| |d02bbf| |message| |gderiv| |shiftLeft| |previous| |lazyPquo| |find| |getEq| |imaginary| |e02ahf| |primeFactor| |setelt!| |evalIfCan| |HenselLift| |printTypes| |OMgetSymbol| |presub| |computeCycleEntry| |powerSum| |RemainderList| |logGamma| |cyclic?| |removeConstantTerm| |Beta| |computeInt| |infinite?| |differentialVariables| |iisinh| |HermiteIntegrate| |redPo| |changeBase| |subNode?| |symbolIfCan| |flexibleArray| |abelianGroup| |kernels| |createIrreduciblePoly| |increment| |multV| |mapMatrixIfCan| |subResultantGcd| |cAcos| |zCoord| |presuper| |declare!| |d03faf| |diagonal| |generalTwoFactor| |imagE| |stopTableInvSet!| |complexNumeric| |relativeApprox| |branchIfCan| |d03eef| |apply| |triangular?| |radicalEigenvalues| |atom?| |setchildren!| |airyBi| |hspace| |orthonormalBasis| |adaptive| |d03edf| |Si| |polyred| |minus!| |numberOfComputedEntries| |integrate| |mdeg| |univariate| |jacobiIdentity?| |subs1stVar| |mapExponents| |showArrayValues| |brace| |concat!| |roughSubIdeal?| |selectAndPolynomials| |factor| |infinityNorm| |inc| |lazy?| |cCsc| |cons| |tan2trig| |toseLastSubResultant| |resetBadValues| |real| |colorFunction| |fixedPoint| |front| |readIfCan!| |firstNumer| |copy| |secIfCan| |setValue!| |imag| |qinterval| |open?| |setrest!| |assign| |yellow| |sqfree| |setProperty| |integralAtInfinity?| |distFact| |first| |width| |continuedFraction| |routines| |fractionPart| |complexSolve| |associator| |curve?| |characteristicSet| |bivariatePolynomials| |applyTransform| |extension| |SturmHabichtSequence| |leadingCoefficientRicDE| |pointValue| |subTriSet?| |fortranDouble| |mkAnswer| |scaleRoots| |subSet| |list| |expandLog| |leftDiscriminant| |aromberg| |numberOfComponents| |permutationGroup| |weights| |LiePoly| |unitNormalize| |finiteSeries2LinSysWOVectorise| |generic?| |basisOfCommutingElements| |sort!| |subResultantChain| |split!| |false| |infLex?| |systemSizeIF| |palginfieldint| |imagj| |basisOfRightNucleus| |normal?| |scalarTypeOf| |torsion?| |outputAsTex| |monomial?| |partialQuotients| |extractBottom!| |removeDuplicates| |eigenvectors| |singularAtInfinity?| |prime?| |acosIfCan| |Gamma| |selectPDERoutines| |functionIsFracPolynomial?| |c05nbf| |newton| |localPointV| |rest| |fullOutput| |monicLeftDivide| |modularFactor| |leadingBasisTerm| |c05adf| |colorDef| |medialSet| |reverse| |collect| |B1solve| |setMinPoints| |multMonom| |c06gsf| |polygon| |composite| |setDifference| |tab1| |innerSolve| |OMputFloat| |basisOfCenter| |c06gqf| |recoverAfterFail| |outputSpacing| |pow| |setIntersection| |quotient| |getMatch| |c06gcf| |screenResolution| |cyclicGroup| |normDeriv2| |constantToUnaryFunction| |accuracyIF| |split| |uncouplingMatrices| |setUnion| |c06gbf| |nil| |quotientByP| |sbt| |squareTop| |rowEchLocal| |chebyshevT| |shiftRoots| |c06fuf| |integerIfCan| |euler| |size| |asinIfCan| |ScanFloatIgnoreSpaces| |generalizedContinuumHypothesisAssumed?| |validExponential| |c06frf| |qsetelt!| |triangulate| |substitute| |pole?| |sumSquares| |replaceVarByZero| |c06fqf| |approximate| |intensity| |exprToUPS| |expextendedint| |hasHi| |shellSort| |euclideanNormalForm| |complex| |c06fpf| |Ei2| |midpoint| |desingTreeWoFullParam| |tubeRadiusDefault| |drawComplex| |setScreenResolution| |say| |c06ekf| |ratDenom| |expenseOfEvaluation| |setPredicates| |taylorIfCan| |yRange| |bipolar| |debug| |duplicates?| |c06ecf| |hash| |acsch| |uniform01| |headReduce| |localize| |radical| |c06ebf| |multiplicity| |PDESolve| |position!| |numberOfVariables| |iroot| |c06eaf| |minPoints| |rationalApproximation| |outputMeasure| |over| |nextNormalPrimitivePoly| |s17def| |palgLODE| |bits| |legendreP| |nthRoot| |normalizedDivide| |s17dcf| |overlabel| |internalSubPolSet?| |exactQuotient| |ef2edf| |setAttributeButtonStep| |s17akf| |invmultisect| |quasiMonic?| |extractClosed| |groebgen| |returnTypeOf| |s17ajf| |freeOf?| |safeCeiling| |coord| |match?| |argumentList!| |replaceVarByOne| |s17ahf| |showFortranOutputStack| |irreducible?| |prime| |refine| |complexEigenvalues| |s17agf| |outlineRender| |coordinates| |bumptab1| |distance| |s17aff| |selectOptimizationRoutines| |characteristic| |reduceByQuasiMonic| |maxDegree| |lexico| |repeatUntilLoop| |entry| |s17aef| |linearDependence| |optimize| |quadratic?| |mergeFactors| |shiftHP| |s17adf| |selectfirst| |close| |mainMonomials| |leftMult| |adaptive?| |matrixGcd| |innerint| |s17acf| |symbolTable| |low| |fortranComplex| |guessPade| |nextLatticePermutation| |pushFortranOutputStack| |s15aef| |fractRadix| |alternative?| |makeCrit| |splitNodeOf!| |ODESolve| |filename| |s15adf| |expandPower| |splitDenominator| |subNodeOf?| |primextintfrac| |clipPointsDefault| |elliptic?| |popFortranOutputStack| |s14baf| |binaryTree| |insert| |monicRightDivide| |meshPar2Var| |display| |setButtonValue| |s14abf| |outputAsFortran| |graphImage| |nextPrime| |lastNonNull| |create3Space| |cond| |Nul| |s14aaf| |createNormalPrimitivePoly| |addMatch| |totalGroebner| |removeSinSq| |s13adf| |OMputString| |hessian| BY |pseudoDivide| |lowerCase?| |constDsolve| |lSpaceBasis| |s13acf| |setSingularPoints| |alphabetic?| |expr| |bandedHessian| |rightZero| |depth| |s13aaf| |externalList| |indicialEquations| |primlimintfrac| |setRow!| |printInfo!| |s01eaf| |last| |expandTrigProducts| |semiResultantEuclideannaif| |changeNameToObjf| |yCoord| |rowEchelon| |count| |flush| |s21bdf| |binomThmExpt| |UnVectorise| |explogs2trigs| |indices| |s21bcf| |iFTable| |associative?| |numberOfMonomials| |iidprod| |separant| |getMultiplicationMatrix| |s21bbf| |reshape| |imagI| |decimal| |objectOf| |cTan| |s21baf| |differentiate| |back| |dn| |op| |getButtonValue| |space| |bfEntry| |s20adf| |qShiftC| |f2st| |branchPointAtInfinity?| |changeVar| |pointLists| |e02agf| |point| |divOfZero| |oblateSpheroidal| |cscIfCan| |genusTreeNeg| |s20acf| |vector| |leftTraceMatrix| |trivialIdeal?| |OMputSymbol| |inRadical?| |d01aqf| |makeViewport3D| |generalInfiniteProduct| F2FG |hdmpToDmp| |s19adf| |primitiveElement| |iipolygamma| |leftPower| |selectFiniteRoutines| |makeSin| |integerDecode| |d01apf| |triangularSystems| |tValues| |badValues| |prepareSubResAlgo| |realRoots| |s19acf| |viewWriteDefault| |setStatus!| |endOfFile?| |trapezoidalo| |totalDifferential| |d01anf| |withPredicates| |cPower| |multiplicative?| |LyndonWordsList| |relationsIdeal| |d01amf| |corrPoly| |commutativeEquality| |iiacos| |actualExtensionV| |zeroSquareMatrix| |d01alf| |seriesSolve| |localParamOfSimplePt| SEGMENT |OMgetBind| |traceMatrix| |s19abf| |connect| |virtualDegree| |clikeUniv| |minPoints3D| |parabolicCylindrical| |d01akf| |OMread| |outputList| |resultant| |neglist| |bringDown| |s19aaf| |factorFraction| |iiatanh| |expPot| |nullSpace| |filterUpTo| |d01ajf| |rewriteSetWithReduction| |setCurve| |clearTable!| |convert| |middle| |mapDown!| |numberOfOperations| |s18def| |printHeader| |flatten| |fmecg| |purelyAlgebraicLeadingMonomial?| |construct| |infClsPt?| |s18dcf| |dflist| |wholeRadix| |additive?| |prem| |s18aff| |KrullNumber| |formula| |listOfTerms| |createLowComplexityTable| |log2| |makeVariable| |s18aef| |subPolSet?| |rightFactorCandidate| |approxNthRoot| |squareFreePart| |iicosh| |s18adf| |insertBottom!| |allRootsOf| |cyclicCopy| |genericRightNorm| |s18acf| |setParam!| |particularSolution| |nullary| |acscIfCan| |bernoulliB| |genericPosition| |f04qaf| |qShiftAction| |dimension| |wordInGenerators| |gcdprim| F2EXPRR |innerEigenvectors| |f04mcf| |exponential| |remove| |guessRec| |lastSubResultant| |f04mbf| |newTypeLists| |leftRegularRepresentation| |setEmpty!| |firstExponent| |replaceKthElement| |f04maf| |indicialEquationAtInfinity| |children| |setMaxPoints3D| |imagi| |pastel| |swapRows!| |f04jgf| |multiple?| |stoseSquareFreePart| |headReduced?| |edf2df| |f04faf| |internalSubQuasiComponent?| |solve| |simplify| |setClosed| |internalInfRittWu?| |index| |ksec| |f04axf| |showScalarValues| |csc2sin| |parts| |sayLength| |compBound| |f04atf| |linear?| |viewSizeDefault| |changeWeightLevel| |fracPart| |integralRepresents| |f04asf| |powerAssociative?| |charthRoot| |setAdaptive| |plenaryPower| |errorInfo| |lintgcd| |psolve| |degreeSubResultant| |linearDependenceOverZ| |leviCivitaSymbol| |f04arf| |outputArgs| |difference| |knownInfBasis| |startStats!| |largest| |shade| |derivationCoordinates| |basisOfInterpolateForms| |topFortranOutputStack| |algebraic?| |adjoint| |bandedJacobian| |splitConstant| |excpDivV| |input| |nextsubResultant2| |rationalPlaces| |fixedPointExquo| |simpson| |stoseInvertibleSet| |test| |digit?| |trim| |karatsubaOnce| |backOldPos| |makeEq| |subresultantSequence| |rightRankPolynomial| |rightNorm| |patternMatch| |cyclotomic| |ricDsolve| |parabolic| |ran| |generalInterpolation| |log| |printStats!| |lazyPseudoRemainder| |addmod| |createMultiplicationTable| |tab| |obj| |numerators| |genusTree| |reorder| |OMputObject| |dcopy| |minset| |primaryDecomp| |curve| |sin?| |opeval| |sizeMultiplication| |init| |prod| |symbNameV| |clearFortranOutputStack| |OMgetFloat| |gcdcofact| |doubleFloatFormat| |csubst| |approximants| |perfectSquare?| |tanIfCan| |component| |rationalFunction| |coefOfFirstNonZeroTerm| |factorOfDegree| |ramifiedAtInfinity?| |insert!| |solveRetract| |summation| |changeThreshhold| |leftRankPolynomial| |tanQ| |primitive?| |clearTheSymbolTable| |makeFloatFunction| |curveV| ** |mainForm| |optional?| |cAsinh| |setFieldInfo| |forLoop| |mix| |entry?| |companionBlocks| |integer?| |addPoint| |morphism| |inverseIntegralMatrix| |partition| |limitedint| |internalDecompose| |setexcpDiv!| |order| |setFoundZeroes| |jacobi| |countRealRoots| |ramified?| |polyRicDE| |power!| |Musser| |hasSolution?| |excepCoord| |latex| |stopMusserTrials| |OMParseError?| |cCos| |gnuDraw| |parent| |delay| |homogeneous?| |rootPoly| |binaryFunction| |extendedEuclidean| |phiCoord| |paren| |nil| |infinite| |arbitraryExponent| |approximate| |complex| |shallowMutable| |canonical| |noetherian| |central| |partiallyOrderedSet| |arbitraryPrecision| |canonicalsClosed| |noZeroDivisors| |rightUnitary| |leftUnitary| |additiveValuation| |unitsKnown| |canonicalUnitNormal| |multiplicativeValuation| |finiteAggregate| |shallowlyMutable| |commutative|) 
\ No newline at end of file
+(30 . 3488060040)            
+(4524 |Enumeration| |Mapping| |Record| |Union| |ofCategory| |isDomain| ATTRIBUTE |package| |domain| |category| CATEGORY |nobranch| AND |Join| |ofType| SIGNATURE "failed" "algebra" |OneDimensionalArrayAggregate&| |OneDimensionalArrayAggregate| |AbelianGroup&| |AbelianGroup| |AbelianMonoid&| |AbelianMonoid| |AbelianSemiGroup&| |AbelianSemiGroup| |AlgebraicallyClosedField&| |AlgebraicallyClosedField| |AlgebraicallyClosedFunctionSpace&| |AlgebraicallyClosedFunctionSpace| |PlaneAlgebraicCurvePlot| |AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgebraicFunction| |AffineSpaceCategory| |Aggregate&| |Aggregate| |ArcHyperbolicFunctionCategory| |AssociationListAggregate| |Algebra&| |Algebra| |AlgFactor| |AlgebraicFunctionField| |AlgebraicManipulations| |AlgebraicMultFact| |AlgebraPackage| |AlgebraGivenByStructuralConstants| |AssociationList| |AbelianMonoidRing&| |AbelianMonoidRing| |AlgebraicNumber| |AnonymousFunction| |AntiSymm| |AnyFunctions1| |Any| |ApplicationProgramInterface| |ApplyUnivariateSkewPolynomial| |ApplyRules| |TwoDimensionalArrayCategory&| |TwoDimensionalArrayCategory| |OneDimensionalArrayFunctions2| |OneDimensionalArray| |TwoDimensionalArray| |Asp10| |Asp12| |Asp19| |Asp1| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp41| |Asp42| |Asp49| |Asp4| |Asp50| |Asp55| |Asp6| |Asp73| |Asp74| |Asp77| |Asp78| |Asp7| |Asp80| |Asp8| |Asp9| |AssociatedEquations| |ArrayStack| |ArcTrigonometricFunctionCategory&| |ArcTrigonometricFunctionCategory| |AttributeButtons| |AttributeRegistry| |Automorphism| |AxiomServer| |BalancedFactorisation| |BasicType&| |BasicType| |BalancedBinaryTree| |Bezier| |BezoutMatrix| |BasicFunctions| |BagAggregate&| |BagAggregate| |BinaryExpansion| |BinaryFile| |Bits| |BlasLevelOne| |BlowUpWithHamburgerNoether| |BlowUpMethodCategory| |BlowUpWithQuadTrans| |BlowUpPackage| |BiModule| |Boolean| |BasicOperatorFunctions1| |BasicOperator| |BoundIntegerRoots| |BalancedPAdicInteger| |BalancedPAdicRational| |BinaryRecursiveAggregate&| |BinaryRecursiveAggregate| |BrillhartTests| |BinarySearchTree| |BitAggregate&| |BitAggregate| |BinaryTreeCategory&| |BinaryTreeCategory| |BinaryTournament| |BinaryTree| |CancellationAbelianMonoid| |CachableSet| |CardinalNumber| |CartesianTensorFunctions2| |CartesianTensor| |CharacterClass| |CommonDenominator| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |CombinatorialFunctionCategory| |Character| |CharacteristicNonZero| |CharacteristicPolynomialPackage| |CharacteristicZero| |ChangeOfVariable| |ComplexIntegerSolveLinearPolynomialEquation| |Collection&| |Collection| |CliffordAlgebra| |TwoDimensionalPlotClipping| |ComplexRootPackage| |Color| |CombinatorialFunction| |IntegerCombinatoricFunctions| |CombinatorialOpsCategory| |Commutator| |CommonOperators| |CommuteUnivariatePolynomialCategory| |ComplexCategory&| |ComplexCategory| |ComplexFactorization| |ComplexFunctions2| |Complex| |ComplexPattern| |SubSpaceComponentProperty| |CommutativeRing| |ContinuedFraction| |CoordinateSystems| |CharacteristicPolynomialInMonogenicalAlgebra| |ComplexPatternMatch| |CRApackage| |ComplexRootFindingPackage| |CyclicStreamTools| |ComplexTrigonometricManipulations| |CoerceVectorMatrixPackage| |CycleIndicators| |CyclotomicPolynomialPackage| |d01AgentsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d01TransformFunctionType| |d01WeightsPackage| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |d03fafAnnaType| |Database| |DoubleResultantPackage| |DistinctDegreeFactorize| |DecimalExpansion| |ElementaryFunctionDefiniteIntegration| |RationalFunctionDefiniteIntegration| |DegreeReductionPackage| |Dequeue| |DeRhamComplex| |DefiniteIntegrationTools| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DenavitHartenbergMatrix| |Dictionary&| |Dictionary| |DifferentialExtension&| |DifferentialExtension| |DifferentialRing&| |DifferentialRing| |DictionaryOperations&| |DictionaryOperations| |DiophantineSolutionPackage| |DirectProductCategory&| |DirectProductCategory| |DirectProductFunctions2| |DirectProduct| |DirichletRing| |DisplayPackage| |DivisorCategory| |Divisor| |DivisionRing&| |DivisionRing| |DoublyLinkedAggregate| |DataList| |DiscreteLogarithmPackage| |DistributedMultivariatePolynomial| |DirectProductMatrixModule| |DirectProductModule| |DifferentialPolynomialCategory&| |DifferentialPolynomialCategory| |DequeueAggregate| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |DrawComplex| |DrawNumericHack| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForPoints| |DrawOptionFunctions0| |DrawOptionFunctions1| |DrawOption| |DifferentialSparseMultivariatePolynomial| |DesingTreeCategory| |DesingTree| |DesingTreePackage| |DifferentialVariableCategory&| |DifferentialVariableCategory| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType| |ExtAlgBasis| |ElementaryFunction| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ExtensibleLinearAggregate&| |ExtensibleLinearAggregate| |ElementaryFunctionCategory&| |ElementaryFunctionCategory| |EllipticFunctionsUnivariateTaylorSeries| |Eltable| |EltableAggregate&| |EltableAggregate| |EuclideanModularRing| |EntireRing| |EigenPackage| |EquationFunctions2| |Equation| |EqTable| |ErrorFunctions| |ExpressionSpaceFunctions1| |ExpressionSpaceFunctions2| |ExpertSystemContinuityPackage1| |ExpertSystemContinuityPackage| |ExpressionSpace&| |ExpressionSpace| |ExpertSystemToolsPackage1| |ExpertSystemToolsPackage2| |ExpertSystemToolsPackage| |EuclideanDomain&| |EuclideanDomain| |Evalable&| |Evalable| |EvaluateCycleIndicators| |Exit| |Export3D| |ExponentialExpansion| |ExpressionFunctions2| |ExpressionToUnivariatePowerSeries| |Expression| |ExpressionSpaceODESolver| |ExpressionSolve| |ExpressionTubePlot| |ExponentialOfUnivariatePuiseuxSeries| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactoredFunctions| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |FactoringUtilities| |FreeAbelianGroup| |FreeAbelianMonoidCategory| |FreeAbelianMonoid| |FiniteAbelianMonoidRingFunctions2| |FiniteAbelianMonoidRing&| |FiniteAbelianMonoidRing| |FlexibleArray| |FiniteAlgebraicExtensionField&| |FiniteAlgebraicExtensionField| |FortranCode| |FourierComponent| |FortranCodePackage1| |FiniteDivisorFunctions2| |FiniteDivisorCategory&| |FiniteDivisorCategory| |FiniteDivisor| |FullyEvalableOver&| |FullyEvalableOver| |FortranExpression| |FunctionFieldCategoryFunctions2| |FunctionFieldCategory&| |FunctionFieldCategory| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldCyclicGroupExtension| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FractionFreeFastGaussianFractions| |FractionFreeFastGaussian| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldCategory&| |FiniteFieldCategory| |FunctionFieldIntegralBasis| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldNormalBasisExtension| |FiniteField| |FiniteFieldExtensionByPolynomial| |FiniteFieldPolynomialPackage2| |FiniteFieldPolynomialPackage| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteFieldExtension| |FGLMIfCanPackage| |FreeGroup| |Field&| |Field| |FileCategory| |File| |FiniteRankNonAssociativeAlgebra&| |FiniteRankNonAssociativeAlgebra| |Finite| |FiniteRankAlgebra&| |FiniteRankAlgebra| |FiniteLinearAggregateFunctions2| |FiniteLinearAggregate&| |FiniteLinearAggregate| |FreeLieAlgebra| |FiniteLinearAggregateSort| |FullyLinearlyExplicitRingOver&| |FullyLinearlyExplicitRingOver| |FloatingComplexPackage| |Float| |FloatingRealPackage| |FreeModule1| |FreeModuleCat| |FortranMatrixCategory| |FortranMatrixFunctionCategory| |FreeModule| |FreeMonoid| |FortranMachineTypeCategory| |FileName| |FileNameCategory| |FreeNilpotentLie| |FortranOutputStackPackage| |FindOrderFinite| |ScriptFormulaFormat1| |ScriptFormulaFormat| |FortranProgramCategory| |FortranFunctionCategory| |FortranPackage| |FortranProgram| |FullPartialFractionExpansion| |FullyPatternMatchable| |FieldOfPrimeCharacteristic&| |FieldOfPrimeCharacteristic| |FloatingPointSystem&| |FloatingPointSystem| |FactoredFunctions2| |FractionFunctions2| |Fraction| |FramedAlgebra&| |FramedAlgebra| |FullyRetractableTo&| |FullyRetractableTo| |FractionalIdealFunctions2| |FractionalIdeal| |FramedModule| |FramedNonAssociativeAlgebraFunctions2| |FramedNonAssociativeAlgebra&| |FramedNonAssociativeAlgebra| |Factored| |FactoredFunctionUtilities| |FunctionSpaceToExponentialExpansion| |FunctionSpaceFunctions2| |FunctionSpaceToUnivariatePowerSeries| |FiniteSetAggregateFunctions2| |FiniteSetAggregate&| |FiniteSetAggregate| |FunctionSpaceComplexIntegration| |FourierSeries| |FunctionSpaceIntegration| |FunctionSpace&| |FunctionSpace| |FunctionalSpecialFunction| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FortranScalarType| |FunctionSpaceUnivariatePolynomialFactor| |FortranTemplate| |FortranType| |FunctionCalled| |FortranVectorCategory| |FortranVectorFunctionCategory| |GaloisGroupFactorizer| |GaloisGroupFactorizationUtilities| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GaussianFactorizationPackage| |EuclideanGroebnerBasisPackage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |GcdDomain&| |GcdDomain| |GenericNonAssociativeAlgebra| |GeneralDistributedMultivariatePolynomial| |GnuDraw| |GenExEuclid| |GeneralizedMultivariateFactorize| |GeneralPolynomialGcdPackage| |GenUFactorize| |GenerateUnivariatePowerSeries| |GeneralHenselPackage| |GeneralModulePolynomial| |GuessOptionFunctions0| |GuessOption| |GosperSummationMethod| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialSet| |GradedAlgebra&| |GradedAlgebra| |GrayCode| |GraphicsDefaults| |GraphImage| |GradedModule&| |GradedModule| |GroebnerSolve| |Group&| |Group| |GeneralUnivariatePowerSeries| |GeneralSparseTable| |GeneralTriangularSet| |GuessAlgebraicNumber| |GuessFiniteFunctions| |GuessFinite| |GuessInteger| |Guess| |GuessPolynomial| |GuessUnivariatePolynomial| |Pi| |HashTable| |HallBasis| |HomogeneousDistributedMultivariatePolynomial| |HomogeneousDirectProduct| |Heap| |HyperellipticFiniteDivisor| |HeuGcd| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousAggregate| |HTMLFormat| |HyperbolicFunctionCategory&| |HyperbolicFunctionCategory| |InnerAlgFactor| |InnerAlgebraicNumber| |IndexedOneDimensionalArray| |IndexedTwoDimensionalArray| |ChineseRemainderToolsForIntegralBases| |IntegralBasisTools| |IndexedBits| |IntegralBasisPolynomialTools| |IndexCard| |InnerCommonDenominator| |InfClsPt| |PolynomialIdeals| |IdealDecompositionPackage| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductCategory| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedDirectProductObject| |InnerEvalable&| |InnerEvalable| |InnerFreeAbelianMonoid| |IndexedFlexibleArray| |InnerFiniteField| |InnerIndexedTwoDimensionalArray| |IndexedList| |InnerMatrixLinearAlgebraFunctions| |InnerMatrixQuotientFieldFunctions| |IndexedMatrix| |InnerNormalBasisFieldFunctions| |IncrementingMaps| |IndexedExponents| |InnerNumericEigenPackage| |InfinitlyClosePointCategory| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InfinitlyClosePoint| |Infinity| |InputFormFunctions1| |InputForm| |InfiniteProductCharacteristicZero| |InnerNumericFloatSolvePackage| |InnerModularGcd| |InnerMultFact| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InnerPolySign| |IntegerNumberSystem&| |IntegerNumberSystem| |InnerTable| |AlgebraicIntegration| |AlgebraicIntegrate| |IntegerBits| |IntervalCategory| |IntersectionDivisorPackage| |IntegralDomain&| |IntegralDomain| |ElementaryIntegration| |InterfaceGroebnerPackage| |IntegerFactorizationPackage| |InterpolateFormsPackage| |IntegrationFunctionsTable| |GenusZeroIntegration| |IntegerNumberTheoryFunctions| |AlgebraicHermiteIntegration| |TranscendentalHermiteIntegration| |Integer| |AnnaNumericalIntegrationPackage| |PureAlgebraicIntegration| |PatternMatchIntegration| |RationalIntegration| |IntegerRetractions| |RationalFunctionIntegration| |Interval| |IntegerSolveLinearPolynomialEquation| |IntegrationTools| |TranscendentalIntegration| |InverseLaplaceTransform| |InnerPAdicInteger| |InnerPrimeField| |InternalPrintPackage| |IntegrationResultToFunction| |IntegrationResultFunctions2| |IntegrationResult| |IntegerRoots| |IrredPolyOverFiniteField| |IntegrationResultRFToFunction| |IrrRepSymNatPackage| |InternalRationalUnivariateRepresentationPackage| |IndexedString| |InnerPolySum| |InnerSparseUnivariatePowerSeries| |InnerTaylorSeries| |InfiniteTupleFunctions2| |InfiniteTupleFunctions3| |InnerTrigonometricManipulations| |InfiniteTuple| |IndexedVector| |IndexedAggregate&| |IndexedAggregate| |AssociatedJordanAlgebra| |KeyedAccessFile| |KeyedDictionary&| |KeyedDictionary| |KernelFunctions2| |Kernel| |CoercibleTo| |ConvertibleTo| |Kovacic| |LeftAlgebra&| |LeftAlgebra| |LocalAlgebra| |LaplaceTransform| |LaurentPolynomial| |LazardSetSolvingPackage| |LeadingCoefDetermination| |LieExponentials| |LexTriangularPackage| |LiouvillianFunctionCategory| |LiouvillianFunction| |LinGroebnerPackage| |Library| |LieAlgebra&| |LieAlgebra| |AssociatedLieAlgebra| |PowerSeriesLimitPackage| |RationalFunctionLimitPackage| |LinearDependence| |LinearlyExplicitRingOver| |ListToMap| |ListFunctions2| |ListFunctions3| |List| |LinearSystemFromPowerSeriesPackage| |ListMultiDictionary| |LeftModule| |ListMonoidOps| |LinearAggregate&| |LinearAggregate| |LocalPowerSeriesCategory| |ElementaryFunctionLODESolver| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorCategory&| |LinearOrdinaryDifferentialOperatorCategory| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperatorsOps| |Logic&| |Logic| |Localize| |LinesOpPack| |LocalParametrizationOfSimplePointPackage| |LinearPolynomialEquationByFractions| |LiePolynomial| |ListAggregate&| |ListAggregate| |LinearSystemMatrixPackage1| |LinearSystemMatrixPackage| |LinearSystemPolynomialPackage| |LieSquareMatrix| |LyndonWord| |LazyStreamAggregate&| |LazyStreamAggregate| |ThreeDimensionalMatrix| |Magma| |MappingPackageInternalHacks1| |MappingPackageInternalHacks2| |MappingPackageInternalHacks3| |MappingPackage1| |MappingPackage2| |MappingPackage3| |MappingPackage4| |MatrixCategoryFunctions2| |MatrixCategory&| |MatrixCategory| |MatrixLinearAlgebraFunctions| |Matrix| |StorageEfficientMatrixOperations| |MultiVariableCalculusFunctions| |MatrixCommonDenominator| |MachineComplex| |MultiDictionary| |ModularDistinctDegreeFactorizer| |MeshCreationRoutinesForThreeDimensions| |MultFiniteFactorize| |MachineFloat| |ModularHermitianRowReduction| |MachineInteger| |MakeBinaryCompiledFunction| |MakeCachableSet| |MakeFloatCompiledFunction| |MakeFunction| |MakeRecord| |MakeUnaryCompiledFunction| |MultivariateLifting| |MonogenicLinearOperator| |MultipleMap| |MathMLFormat| |ModularField| |ModMonic| |ModuleMonomial| |ModuleOperator| |ModularRing| |Module&| |Module| |MoebiusTransform| |Monad&| |Monad| |MonadWithUnit&| |MonadWithUnit| |MonogenicAlgebra&| |MonogenicAlgebra| |Monoid&| |Monoid| |MonomialExtensionTools| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatPolyFactorizer| |MultivariatePolynomial| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MonoidRingFunctions2| |MonoidRing| |MultisetAggregate| |Multiset| |MoreSystemCommands| |MergeThing| |MultivariateTaylorSeriesCategory| |MultivariateFactorize| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NonAssociativeAlgebra&| |NonAssociativeAlgebra| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagIntegrationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagInterpolationPackage| |NagFittingPackage| |NagOptimisationPackage| |NagMatrixOperationsPackage| |NagEigenPackage| |NagLinearEquationSolvingPackage| |NagLapack| |NagSpecialFunctionsPackage| |NAGLinkSupportPackage| |NonAssociativeRng&| |NonAssociativeRng| |NonAssociativeRing&| |NonAssociativeRing| |NumericComplexEigenPackage| |NumericContinuedFraction| |NonCommutativeOperatorDivision| |NewtonInterpolation| |NumberFieldIntegralBasis| |NumericalIntegrationProblem| |NonLinearSolvePackage| |NonNegativeInteger| |NonLinearFirstOrderODESolver| |NoneFunctions1| |None| |NormInMonogenicAlgebra| |NormalizationPackage| |NormRetractPackage| |NottinghamGroup| |NPCoef| |NewtonPolygon| |NumericRealEigenPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomialFunctions2| |NewSparseUnivariatePolynomial| |NumberTheoreticPolynomialFunctions| |NormalizedTriangularSetCategory| |Numeric| |NumberFormats| |NumericalIntegrationCategory| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |NumericTubePlot| |OrderedAbelianGroup| |OrderedAbelianMonoid| |OrderedAbelianMonoidSup| |OrderedAbelianSemiGroup| |OrderedCancellationAbelianMonoid| |OctonionCategory&| |OctonionCategory| |OctonionCategoryFunctions2| |Octonion| |OrdinaryDifferentialEquationsSolverCategory| |ConstantLODE| |ElementaryFunctionODESolver| |ODEIntensityFunctionsTable| |ODEIntegration| |AnnaOrdinaryDifferentialEquationPackage| |PureAlgebraicLODE| |PrimitiveRatDE| |NumericalODEProblem| |PrimitiveRatRicDE| |RationalLODE| |ReduceLODE| |RationalRicDE| |SystemODESolver| |ODETools| |OrderedDirectProduct| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OrderlyDifferentialVariable| |OrderedFreeMonoid| |OrderedIntegralDomain| |OpenMathConnection| |OpenMathDevice| |OpenMathEncoding| |OpenMathErrorKind| |OpenMathError| |ExpressionToOpenMath| |OppositeMonogenicLinearOperator| |OpenMath| |OpenMathPackage| |OrderedMultisetAggregate| |OpenMathServerPackage| |OnePointCompletionFunctions2| |OnePointCompletion| |Operator| |OperationsQuery| |NumericalOptimizationCategory| |AnnaNumericalOptimizationPackage| |NumericalOptimizationProblem| |OrderedCompletionFunctions2| |OrderedCompletion| |OrderedFinite| |OrderingFunctions| |OrderedMonoid| |OrderedRing&| |OrderedRing| |OrderedSet&| |OrderedSet| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategory| |UnivariateSkewPolynomialCategoryOps| |SparseUnivariateSkewPolynomial| |UnivariateSkewPolynomial| |OrthogonalPolynomialFunctions| |OrdSetInts| |OutputForm| |OutputPackage| |OrderedVariableList| |OrdinaryWeightedPolynomials| |PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteFieldCategory| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfPerfectFieldCategory| |PseudoAlgebraicClosureOfRationalNumberCategory| |PseudoAlgebraicClosureOfRationalNumber| |PadeApproximants| |PadeApproximantPackage| |PAdicIntegerCategory| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForAlgebraicFunctionField| |Palette| |PolynomialAN2Expression| |ParametrizationPackage| |ParametricPlaneCurveFunctions2| |ParametricPlaneCurve| |ParametricSpaceCurveFunctions2| |ParametricSpaceCurve| |ParametricSurfaceFunctions2| |ParametricSurface| |PartitionsAndPermutations| |Patternable| |PatternMatchListResult| |PatternMatchable| |PatternMatch| |PatternMatchResultFunctions2| |PatternMatchResult| |PatternFunctions1| |PatternFunctions2| |Pattern| |PoincareBirkhoffWittLyndonBasis| |PolynomialComposition| |PartialDifferentialEquationsSolverCategory| |PolynomialDecomposition| |AnnaPartialDifferentialEquationPackage| |NumericalPDEProblem| |PartialDifferentialRing&| |PartialDifferentialRing| |PendantTree| |Permanent| |PermutationCategory| |PermutationGroup| |Permutation| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialFactorizationExplicit| |PrimeField| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PackageForPoly| |PointsOfFiniteOrderTools| |PartialFraction| |PartialFractionPackage| |PolynomialGcdPackage| |PermutationGroupExamples| |PolyGroebner| |PiCoercions| |PrincipalIdealDomain| |PositiveInteger| |PolynomialInterpolationAlgorithms| |PolynomialInterpolation| |PlacesCategory| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |Plcs| |ParametricLinearEquations| |PlotFunctions1| |Plot3D| |Plot| |PlotTools| |PolynomialPackageForCurve| |FunctionSpaceAssertions| |PatternMatchAssertions| |PatternMatchPushDown| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchKernel| |PatternMatchListAggregate| |PatternMatchPolynomialCategory| |FunctionSpaceAttachPredicates| |AttachPredicates| |PatternMatchQuotientFieldCategory| |PatternMatchSymbol| |PatternMatchTools| |PolynomialNumberTheoryFunctions| |Point| |PolToPol| |RealPolynomialUtilitiesPackage| |PolynomialFunctions2| |PolynomialToUnivariatePolynomial| |PolynomialCategory&| |PolynomialCategory| |PolynomialCategoryQuotientFunctions| |PolynomialCategoryLifting| |Polynomial| |PolynomialRoots| |PlottablePlaneCurveCategory| |PrecomputedAssociatedEquations| |PrimitiveArrayFunctions2| |PrimitiveArray| |PrimitiveFunctionCategory| |PrimitiveElement| |IntegerPrimesPackage| |PrintPackage| |ProjectiveAlgebraicSetPackage| |PolynomialRing| |Product| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PriorityQueueAggregate| |PseudoRemainderSequence| |ProjectiveSpaceCategory| |Partition| |PowerSeriesCategory&| |PowerSeriesCategory| |PlottableSpaceCurveCategory| |PolynomialSetCategory&| |PolynomialSetCategory| |PolynomialSetUtilitiesPackage| |PseudoLinearNormalForm| |PolynomialSquareFree| |PointCategory| |PointFunctions2| |PointPackage| |PartialTranscendentalFunctions| |PushVariables| |PAdicWildFunctionFieldIntegralBasis| |QuasiAlgebraicSet2| |QuasiAlgebraicSet| |QuasiComponentPackage| |QueryEquation| |QuotientFieldCategoryFunctions2| |QuotientFieldCategory&| |QuotientFieldCategory| |QuadraticForm| |QueueAggregate| |QuaternionCategory&| |QuaternionCategory| |QuaternionCategoryFunctions2| |Quaternion| |Queue| |RadicalCategory&| |RadicalCategory| |RadicalFunctionField| |RadixExpansion| |RadixUtilities| |RandomNumberSource| |RationalFactorize| |RationalRetractions| |RecursiveAggregate&| |RecursiveAggregate| |RealClosedField&| |RealClosedField| |ElementaryRischDE| |ElementaryRischDESystem| |TranscendentalRischDE| |TranscendentalRischDESystem| |RandomDistributions| |ReducedDivisor| |RealZeroPackage| |RealZeroPackageQ| |RealConstant| |RealSolvePackage| |RealClosure| |RecurrenceOperator| |ReductionOfOrder| |Reference| |RegularTriangularSet| |RepresentationPackage1| |RepresentationPackage2| |RepeatedDoubling| |RadicalEigenPackage| |RepeatedSquaring| |ResolveLatticeCompletion| |ResidueRing| |Result| |RetractableTo&| |RetractableTo| |RetractSolvePackage| |RandomFloatDistributions| |RationalFunctionFactor| |RationalFunctionFactorizer| |RationalFunction| |RootsFindingPackage| |RegularChain| |RandomIntegerDistributions| |Ring&| |Ring| |RationalInterpolation| |RectangularMatrixCategory&| |RectangularMatrixCategory| |RectangularMatrix| |RectangularMatrixCategoryFunctions2| |RightModule| |Rng| |RealNumberSystem&| |RealNumberSystem| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RoutinesTable| |RecursivePolynomialCategory&| |RecursivePolynomialCategory| |RealRootCharacterizationCategory&| |RealRootCharacterizationCategory| |RegularSetDecompositionPackage| |RegularTriangularSetCategory&| |RegularTriangularSetCategory| |RegularTriangularSetGcdPackage| |RuleCalled| |RewriteRule| |Ruleset| |RationalUnivariateRepresentationPackage| |SimpleAlgebraicExtensionAlgFactor| |SimpleAlgebraicExtension| |SAERationalFunctionAlgFactor| |SingletonAsOrderedSet| |SortedCache| |StructuralConstantsPackage| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |SegmentFunctions2| |SegmentBindingFunctions2| |SegmentBinding| |SegmentCategory| |Segment| |SegmentExpansionCategory| |SetAggregate&| |SetAggregate| |SetCategoryWithDegree| |SetCategory&| |SetCategory| |SetOfMIntegersInOneToN| |Set| |SExpressionCategory| |SExpression| |SExpressionOf| |SimpleFortranProgram| |SquareFreeQuasiComponentPackage| |SquareFreeRegularTriangularSetGcdPackage| |SquareFreeRegularTriangularSetCategory| |SymmetricGroupCombinatoricFunctions| |SemiGroup&| |SemiGroup| |SplitHomogeneousDirectProduct| |SturmHabichtPackage| |ElementaryFunctionSign| |RationalFunctionSign| |SimplifyAlgebraicNumberConvertPackage| |SingleInteger| |StackAggregate| |SquareMatrixCategory&| |SquareMatrixCategory| |SmithNormalForm| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SquareFreeNormalizedTriangularSetCategory| |PolynomialSolveByFormulas| |RadicalSolvePackage| |TransSolvePackageService| |TransSolvePackage| |SortPackage| |ThreeSpace| |ThreeSpaceCategory| |SpecialOutputPackage| |SpecialFunctionCategory| |SplittingNode| |SplittingTree| |SquareMatrix| |StringAggregate&| |StringAggregate| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |Stack| |StreamAggregate&| |StreamAggregate| |SparseTable| |StepThrough| |StreamInfiniteProduct| |StreamFunctions1| |StreamFunctions2| |StreamFunctions3| |Stream| |StringCategory| |String| |StringTable| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctionsNonCommutative| |StreamTranscendentalFunctions| |SubResultantPackage| |SubSpace| |SuchThat| |SparseUnivariateLaurentSeries| |FunctionSpaceSum| |RationalFunctionSum| |SparseUnivariatePolynomialFunctions2| |SparseUnivariatePolynomialExpressions| |SupFractionFactorizer| |SparseUnivariatePolynomial| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |Switch| |Symbol| |SymmetricFunctions| |SymmetricPolynomial| |TheSymbolTable| |SymbolTable| |SystemSolvePackage| |TableauxBumpers| |Tableau| |Table| |TangentExpansions| |TableAggregate&| |TableAggregate| |TabulatedComputationPackage| |TemplateUtilities| |TexFormat1| |TexFormat| |TextFile| |ToolsForSign| |TopLevelThreeSpace| |TranscendentalFunctionCategory&| |TranscendentalFunctionCategory| |Tree| |TrigonometricFunctionCategory&| |TrigonometricFunctionCategory| |TrigonometricManipulations| |TriangularMatrixOperations| |TranscendentalManipulations| |TriangularSetCategory&| |TriangularSetCategory| |TaylorSeries| |TubePlot| |TubePlotTools| |Tuple| |TwoFactorize| |Type| |UserDefinedPartialOrdering| |UserDefinedVariableOrdering| |UniqueFactorizationDomain&| |UniqueFactorizationDomain| |UnivariateFormalPowerSeriesFunctions| |UnivariateFormalPowerSeries| |UnivariateLaurentSeriesFunctions2| |UnivariateLaurentSeriesCategory| |UnivariateLaurentSeriesConstructorCategory&| |UnivariateLaurentSeriesConstructorCategory| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeries| |UnivariateFactorize| |UniversalSegmentFunctions2| |UniversalSegment| |UnivariatePolynomialFunctions2| |UnivariatePolynomialCommonDenominator| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePolynomial| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategory| |UnivariatePowerSeriesCategory&| |UnivariatePowerSeriesCategory| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeriesFunctions2| |UnivariatePuiseuxSeriesCategory| |UnivariatePuiseuxSeriesConstructorCategory&| |UnivariatePuiseuxSeriesConstructorCategory| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnaryRecursiveAggregate&| |UnaryRecursiveAggregate| |UnivariateTaylorSeriesFunctions2| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesCategory| |UnivariateTaylorSeries| |UnivariateTaylorSeriesODESolver| |UTSodetools| |TaylorSolve| |UnivariateTaylorSeriesCZero| |Variable| |VectorCategory&| |VectorCategory| |VectorFunctions2| |Vector| |TwoDimensionalViewport| |ThreeDimensionalViewport| |ViewDefaultsPackage| |ViewportPackage| |Void| |VectorSpace&| |VectorSpace| |WeierstrassPreparation| |WildFunctionFieldIntegralBasis| |WeightedPolynomials| |WuWenTsunTriangularSet| |XAlgebra| |XDistributedPolynomial| |XExponentialPackage| |XFreeAlgebra| |ExtensionField&| |ExtensionField| |XPBWPolynomial| |XPolynomialsCat| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ParadoxicalCombinatorsForStreams| |ZeroDimensionalSolvePackage| |IntegerLinearDependence| |IntegerMod| |Enumeration| |Mapping| |Record| |Union| |Category| |ScanFloatIgnoreSpaces| |printInfo| |ratDsolve| |areEquivalent?| |expint| |iiatan| |generalizedContinuumHypothesisAssumed?| |symmetricSquare| |internalIntegrate| |incrementKthElement| |pushdown| |validExponential| |iprint| |polar| |bumprow| |cSech| |qsetelt!| |standardBasisOfCyclicSubmodule| |stopTable!| |characteristicPolynomial| |numberRatPlacesExtDeg| |triangulate| |initializeGroupForWordProblem| |triangSolve| |getExplanations| |newElement| |pole?| |deepestTail| |oddlambert| |numberOfChildren| |nextNormalPoly| |sumSquares| |maxrow| |rightRemainder| |rightGcd| |directSum| |replaceVarByZero| |enterPointData| |OMputEndAtp| |initiallyReduce| |lazyIntegrate| |intensity| |lintgcd| |viewDeltaYDefault| |var2StepsDefault| |symFunc| |localParam| |exprToUPS| |sorted?| |univariatePolynomialsGcds| |toseInvertibleSet| |psolve| |useSingleFactorBound?| |expextendedint| |mapmult| |escape| |setpoint!| |guessAlg| |degreeSubResultant| |quasiRegular?| |hasHi| |supDimElseRittWu?| |rational?| |eval| |possiblyInfinite?| |mindeg| |linearDependenceOverZ| |minColIndex| |shellSort| |pointDominateBy| |resetAttributeButtons| |subHeight| |leviCivitaSymbol| |exists?| |showTheFTable| |euclideanNormalForm| |semiResultantEuclidean2| |submod| |leftFactorIfCan| |univariate?| |outputArgs| |nextsousResultant2| |Ei2| |reduced?| |multinomial| |foundZeroes| |stirling1| |difference| |content| |midpoint| |knownInfBasis| |OMgetEndAtp| |representationType| |chiSquare| |tube| |desingTreeWoFullParam| |patternMatchTimes| |degOneCoef| |center| |deriv| |startStats!| |removeDuplicates!| |tubeRadiusDefault| |safetyMargin| |halfExtendedResultant1| |ridHack1| |largest| |f2df| |drawComplex| |balancedFactorisation| |nextSubsetGray| |factorSFBRlcUnit| |shade| |setEpilogue!| |setScreenResolution| |derivationCoordinates| |initTable!| |modifyPoint| |SturmHabichtCoefficients| |has?| |ratDenom| |basisOfLeftAnnihilator| |createNormalElement| |basisOfInterpolateForms| |composites| |getShiftRec| |expenseOfEvaluation| |dequeue| |topFortranOutputStack| |pascalTriangle| |whatInfinity| |retractable?| |setPredicates| |traverse| |skewSFunction| |cSec| |symmetricPower| |algebraic?| |brillhartTrials| |taylorIfCan| |pol| |setOfMinN| |transform| |adjoint| |quickSort| |yRange| |clipWithRanges| |inHallBasis?| |mainDefiningPolynomial| |bandedJacobian| |writable?| |bipolar| |showTypeInOutput| |identitySquareMatrix| |subset?| |splitConstant| |polarCoordinates| |duplicates?| |numberOfPrimitivePoly| |excpDivV| |positive?| |unexpand| |monicDivide| |acsch| |headRemainder| |crushedSet| |minrank| |nextsubResultant2| |pack!| |uniform01| |comp| |linearAssociatedOrder| |separate| |infieldint| |rationalPlaces| |stiffnessAndStabilityFactor| |headReduce| |mightHaveRoots| |string?| |algebraicSet| |fixedPointExquo| |nextPrimitiveNormalPoly| |localize| |normalDeriv| |aCubic| |asinhIfCan| |simpson| |rightAlternative?| |radical| |En| |euclideanSize| |pushucoef| |stoseInvertibleSet| |leftFactor| |multiplicity| |evenInfiniteProduct| |nthRootIfCan| |positiveSolve| |trim| |listConjugateBases| |PDESolve| |rootNormalize| F |sumOfDivisors| |entries| |karatsubaOnce| |showAllElements| |position!| |initial| |ignore?| |cCosh| |branchPoint?| |backOldPos| |orbits| |numberOfVariables| |makeEq| |definingPolynomial| |sinh2csch| |retractToGrn| |mainVariable?| |iroot| |minimalPolynomial| |mathieu24| |cycleSplit!| |subresultantSequence| |setmult!| |minPoints| |rightRankPolynomial| |fractionFreeGauss!| |mkPrim| |groebner| |generalSqFr| |rationalApproximation| |rightNorm| |critM| |indiceSubResultant| |sin2csc| |digits| |outputMeasure| |integralMatrix| |lastSubResultantElseSplit| |oddInfiniteProduct| |car| |patternMatch| |viewThetaDefault| |over| |decrease| |daxpy| |rightTraceMatrix| |OMclose| |cyclotomic| |cdr| |nextNormalPrimitivePoly| |increasePrecision| |laguerre| |quasiMonicPolynomials| |ricDsolve| |tree| |palgLODE| |parabolic| |guess| |primitivePart!| |compactFraction| |gcdPrimitive| |bits| |ran| |mesh?| |contract| |leadingExponent| |legendreP| |generalInterpolation| |tanSum| |groebnerFactorize| |rombergo| |nthRoot| |singularPointsWithRestriction| |variationOfParameters| |printStats!| |removeRoughlyRedundantFactorsInPol| |normalizedDivide| |genericLeftMinimalPolynomial| |One| |fresnelS| |setMaxPoints| |lazyPseudoRemainder| |upDateBranches| |overlabel| |suchThat| |addmod| |fresnelC| |plot| |showIntensityFunctions| |remove!| |internalSubPolSet?| |createMultiplicationTable| |diff| |OMconnInDevice| |operation| |exactQuotient| |leastPower| |pmComplexintegrate| |tab| |perfectNthPower?| |ef2edf| |obj| |ParCondList| |Is| |setAttributeButtonStep| |numerators| |iiacosh| |clearCache| |newtonPolySlope| |invmultisect| |checkPrecision| |bezoutDiscriminant| |genusTree| |rightScalarTimes!| |quasiMonic?| |reorder| |deepestInitial| |tanAn| |extractClosed| |one?| |OMputObject| |deleteRoutine!| |groebgen| |dcopy| |removeSuperfluousCases| |lazyPrem| |returnTypeOf| |linears| |minset| |taylorQuoByVar| |freeOf?| |primaryDecomp| |universe| |safeCeiling| ~ |axServer| |curve| |rangePascalTriangle| |coord| |UP2ifCan| |sin?| |sPol| |toseSquareFreePart| |argumentList!| |symbol?| |opeval| |squareFreeLexTriangular| |replaceVarByOne| |viewpoint| |sizeMultiplication| |factorByRecursion| |showFortranOutputStack| |scripted?| |prod| |reduceLODE| |irreducible?| |factorAndSplit| |symbNameV| |scalarMatrix| |prime| |modTree| |clearFortranOutputStack| |monomialIntegrate| |refine| |summary| |mapExpon| |choosemon| |OMgetFloat| |complexEigenvalues| |startPolynomial| |show| |splitLinear| |gcdcofact| |outlineRender| |monicModulo| |factorCantorZassenhaus| |doubleFloatFormat| |coordinates| |e02aef| |currentSubProgram| |iidigamma| |csubst| |bumptab1| |oddintegers| |isList| |approximants| |distance| |c02agf| |size?| |reducedSystem| |perfectSquare?| |selectOptimizationRoutines| |c02aff| |reopen!| |removeSquaresIfCan| |tanIfCan| |component| |e02adf| |showAttributes| |scan| |nodeOf?| |changeBase| |second| |c05pbf| |expintfldpoly| |listOfMonoms| |rationalFunction| |subNode?| |compile| |symbolIfCan| |zRange| |mindegTerm| |coefOfFirstNonZeroTerm| |leader| |credits| |factorOfDegree| |getGoodPrime| |normalise| |flexibleArray| |infix?| |#| |ramifiedAtInfinity?| |bumptab| |eq?| |abelianGroup| |e01sef| |polyRingToBlUpRing| |setfirst!| |createIrreduciblePoly| |insert!| |comment| |e01saf| |expenseOfEvaluationIF| |monicDecomposeIfCan| |increment| |solveRetract| |summation| |id| |e01daf| |factor1| = |subscriptedVariables| |multV| |arg1| |integer| |e01bhf| |distdfact| |resetVariableOrder| |mapMatrixIfCan| |changeThreshhold| |arg2| |leftRankPolynomial| |e01bgf| |min| |random| < |SturmHabichtMultiple| |subResultantGcd| |tanQ| |e01bff| |denomLODE| > |startTableGcd!| |cAcos| |clip| |string| |e01bef| |tensorProduct| <= |primitive?| |zCoord| |leftZero| |e01baf| |cAcosh| >= |clearTheSymbolTable| |presuper| |e02zaf| |leftScalarTimes!| |interpolateFormsForFact| |makeFloatFunction| |diagonal| |e02gaf| |number?| |addBadValue| |curveV| |generalTwoFactor| |e02dff| |imagE| |lazyVariations| + |OMReadError?| |mainForm| |saturate| |e02def| |primlimitedint| - |optional?| |stopTableInvSet!| |style| |e02ddf| |pmintegrate| / |cAsinh| |relativeApprox| |e02dcf| |setFieldInfo| |atrapezoidal| |movedPoints| |branchIfCan| |rotatey| |e02daf| |forLoop| |purelyAlgebraic?| |union| |triangular?| |e02bef| |mix| |lquo| |startTableInvSet!| |radicalEigenvalues| |suppOfZero| |entry?| |univariatePolynomial| |atom?| |outerProduct| |e01sbf| |factorsOfDegree| |unmakeSUP| |companionBlocks| |setchildren!| |SFunction| |possiblyNewVariety?| |integer?| |airyBi| |radPoly| |rootBound| |addPoint| |hspace| |morphism| |zero?| |drawToScale| |orthonormalBasis| |inverseIntegralMatrix| |subResultantGcdEuclidean| |trigs2explogs| |adaptive| |Si| |quote| |makeViewport2D| |partition| |limitedint| |fortranTypeOf| |halfExtendedSubResultantGcd1| |polyred| |minus!| |eulerE| |degree| |internalDecompose| |inrootof| |bernoulli| |setexcpDiv!| |numberOfComputedEntries| |rightMult| |listOfLists| |order| |integrate| |ptree| |setFoundZeroes| |untab| |listLoops| |mdeg| |new| |jacobiIdentity?| |interReduce| |divide| |jacobi| |tableForDiscreteLogarithm| |append| |OMputAtp| |countRealRoots| |subs1stVar| |translate| |ramified?| |screenResolution3D| |intersect| |mapExponents| |function| |rootsOf| |affineSingularPoints| |polyRicDE| |showArrayValues| |rightTrim| |shift| |iiacsc| |graphState| |power!| |concat!| |Musser| |listBranches| |selectPolynomials| |roughSubIdeal?| |prindINFO| |mapSolve| |hasSolution?| |selectAndPolynomials| |excepCoord| |makeMulti| |primeFrobenius| |infinityNorm| ^ |inc| |sub| |extractProperty| |latex| |exp| |domainOf| |messagePrint| |stopMusserTrials| |lazy?| |pi| |algSplitSimple| |ncols| |cCsc| |OMParseError?| |sqrt| |tryFunctionalDecomposition| |cCos| |epilogue| |tan2trig| |gnuDraw| |lighting| |readLine!| |toseLastSubResultant| |li| |green| |approxSqrt| |parent| |resetBadValues| |erf| |colorFunction| |inverseColeman| |topPredicate| |delay| |homogeneous?| |tRange| |certainlySubVariety?| |fixedPoint| |tanh2coth| |sparsityIF| |front| |dilog| |paraboloidal| |finiteSeries2Vector| |readIfCan!| |trace| |tan| |minimalForm| |definingField| |firstNumer| |cot| |superHeight| |exponential1| |secIfCan| |sec| |ode2| |cAcsc| |setValue!| |csc| |laguerreL| |rewriteIdealWithQuasiMonicGenerators| |qinterval| |asin| |aQuartic| |leftRank| |open?| |acos| |removeRoughlyRedundantFactorsInPols| |extractSplittingLeaf| |setrest!| |atan| |padicFraction| |mapBivariate| |showTheSymbolTable| |assign| |acot| |dim| |diagonalProduct| |yellow| |asec| |vectorise| |prinpolINFO| |sqfree| |acsc| |decreasePrecision| |leftRecip| |setProperty| |sinh| |augment| |pleskenSplit| |integralAtInfinity?| |cosh| |OMgetVariable| |pdf2ef| |distFact| |tanh| |shallowExpand| |eulerPhi| |width| |coth| |logpart| |empty| |continuedFraction| |sech| |solveInField| |selectIntegrationRoutines| |routines| |csch| |newSubProgram| |primitivePart| |fractionPart| |asinh| |solve1| |exprex| |complexSolve| |acosh| |cothIfCan| |toScale| |associator| |atanh| |complexElementary| |invertIfCan| |curve?| |acoth| |terms| |argument| |characteristicSet| |asech| |elRow2!| |semiSubResultantGcdEuclidean1| |bivariatePolynomials| |iiasin| |baseRDE| |applyTransform| |resultantReduitEuclidean| |dmpToP| |extension| |inBetweenExcpDiv| |kroneckerDelta| |SturmHabichtSequence| |tanhIfCan| |localAbs| |leadingCoefficientRicDE| |swap| |OMreadFile| |pointValue| |lyndonIfCan| |moebius| |subTriSet?| |showTheRoutinesTable| |semiResultantEuclidean1| |fortranDouble| |directProduct| |returns| |pr2dmp| |mkAnswer| |destruct| |rightUnit| |max| |scaleRoots| |monomial| |tan2cot| |logIfCan| |subSet| |multivariate| |ZetaFunction| |ipow| |expandLog| |variables| |characteristicSerie| |permanent| |leftDiscriminant| |leftUnit| |product| |aromberg| |updatD| |dimensionsOf| |numberOfComponents| |taylor| |rangeIsFinite| |qelt| |spherical| |permutationGroup| |laurent| |setcurve!| |restorePrecision| |factors| |weights| |puiseux| |prefixRagits| |coefficient| |even?| |LiePoly| |true| |inv| |birth| |machineFraction| |rootProduct| |unitNormalize| |ground?| |dcabs1| |theCurve| |gcdcofactprim| |finiteSeries2LinSysWOVectorise| |ground| |variableName| |rules| |rightQuotient| |intChoose| |generic?| |leadingMonomial| |datalist| |lagrange| |numberOfPlacesOfDegree| |basisOfCommutingElements| |leadingCoefficient| |iiasec| |stripCommentsAndBlanks| |meatAxe| |numberOfValuesNeeded| |sort!| |primitiveMonomials| |cfirst| |isPlus| |iitanh| |rk4| |subResultantChain| |reductum| |writeLine!| |list?| |lflimitedint| |bottom!| |split!| |measure2Result| |preprocess| |rroot| |tablePow| |infLex?| |maxint| |mpsode| |OMsupportsCD?| |lifting1| |systemSizeIF| |fullParamInit| |open| |transcendent?| |mainSquareFreePart| |palginfieldint| |rootOfIrreduciblePoly| |duplicates| |stosePrepareSubResAlgo| |imagj| |and| |groebner?| |pile| |critpOrder| |autoReduced?| |basisOfRightNucleus| |seed| |genusNeg| |besselK| |trapezoidal| |normal?| |guessRat| |jordanAlgebra?| |xn| |conditionsForIdempotents| |scalarTypeOf| |initiallyReduced?| |chainSubResultants| |fixPredicate| |operators| |torsion?| |rightRank| |elements| |makeSketch| |complexNumericIfCan| |outputAsTex| |binaryTournament| |extend| |extendedResultant| |strongGenerators| |monomial?| |factorsOfCyclicGroupSize| |deleteProperty!| |mainCoefficients| |partialQuotients| |region| |edf2efi| |fillPascalTriangle| |varselect| |extractBottom!| |makingStats?| |reverseLex| |singleFactorBound| |realElementary| |error| |eigenvectors| |toseInvertible?| |complete| |logical?| |firstUncouplingMatrix| |singularAtInfinity?| |Ei6| |linearAssociatedLog| NOT |constantKernel| |lyndon| |prime?| |hMonic| OR |color| |complexZeros| |df2mf| |acosIfCan| |bombieriNorm| AND |selectSumOfSquaresRoutines| |lp| |integralMatrixAtInfinity| |Gamma| |overset?| |assert| |top!| |zeroSetSplitIntoTriangularSystems| |nextItem| |condition| |laplacian| |in?| |divisorAtDesingTree| |homogenize| |pdct| |type| |numberOfFractionalTerms| |stFunc1| |squareFreePrim| |quartic| |iiasinh| |unravel| |row| |initParLocLeaves| |fixedDivisor| |raisePolynomial| |removeZeroes| |hue| |ratPoly| |rightRegularRepresentation| |relerror| |third| |whileLoop| |integralBasisAtInfinity| |isMult| |nrows| |reducedQPowers| |sincos| |normal| |prevPrime| |prolateSpheroidal| |OMgetString| |polygon?| |mainVariables| |pade| |zerosOf| |round| |map!| |pointPlot| |isAbsolutelyIrreducible?| * |setlast!| |modularGcdPrimitive| |setlocalPoint!| |isQuotient| |oneDimensionalArray| |irreducibleFactor| |negAndPosEdge| |lprop| |subMatrix| |listexp| |probablyZeroDim?| |odd?| |schema| |listRepresentation| |matrix| |argscript| |associates?| |var1StepsDefault| |distinguishedCommonRootsOf| |outputForm| |surface| |divideIfCan| |OMopenFile| |displayAsGF| |normal01| |rootKerSimp| |generic| |constantRight| |acotIfCan| |dot| |iicsc| |guessExpRat| |hcrf| |appendPoint| |lookup| |divOfPole| |ReduceOrder| |getMeasure| |exactQuotient!| |extendedIntegrate| |outputFixed| |pureLex| |createMultiplicationMatrix| |idealiser| |subCase?| |cycleElt| |fffg| |affineAlgSetLocal| |lexTriangular| |iidsum| |meshFun2Var| |objects| |tryFunctionalDecomposition?| |mirror| |edf2ef| |getRef| |nthCoef| |symmetricProduct| |nthExpon| |listAllMono| |integral| |reset| |numer| |leadingIndex| |setScreenResolution3D| |lazyPremWithDefault| |geometric| |regime| |write| |denom| |redPol| |trueEqual| |cAtanh| |createPrimitiveElement| |reduceBasisAtInfinity| |save| |palgint| |overbar| |intersectionDivisor| |debug3D| |mainKernel| |draw| |computePowers| |hconcat| |permutation| |numberOfHues| |roughBase?| |makeObject| |fortranLinkerArgs| |diagonals| |block| LODO2FUN |iExquo| |coef| |nextIrreduciblePoly| |firstSubsetGray| |zeroSetSplit| |primPartElseUnitCanonical!| |exQuo| |monom| |romberg| |const| |putColorInfo| |OMgetEndObject| |schwerpunkt| |createZechTable| |gradient| |lllip| |outputAsScript| |pToHdmp| |e01sff| |compdegd| |multiset| |OMgetError| |rank| |constantLeft| |se2rfi| |rightLcm| |symmetricGroup| |mathieu23| |karatsuba| |singularPoints| |posExpnPart| |laurentIfCan| |uniform| |powmod| |digamma| |definingEquations| |exteriorDifferential| |processTemplate| |conjugate| |satisfy?| |sumOfSquares| |rightFactorIfCan| |primintfldpoly| |solid?| |quadTransform| |rational| |cRationalPower| |tanh2trigh| |OMbindTCP| |radix| |intermediateResultsIF| |hclf| |showRegion| |dom| |rem| |base| |coerceP| |factorial| |ocf2ocdf| |eigenvector| |sup| |eq| |cylindrical| |nextSublist| |randnum| |quo| |generalizedInverse| |unparse| |mainMonomial| |blankSeparate| |qroot| |library| |OMputEndBVar| |sinIfCan| |tubePointsDefault| |minordet| |OMopenString| |/\\| |newLine| |ddFact| |cardinality| |curveColor| |unitNormal| |\\/| |lhs| |solveLinearPolynomialEquation| |antiCommutative?| |empty?| |mesh| |setelt| |setsymbName!| |arity| |Lazard2| |janko2| |localIntegralBasis| |contractSolve| |cyclotomicFactorization| |csch2sinh| |genericRightTrace| |Ei3| ~= |reseed| |purelyTranscendental?| |semiLastSubResultantEuclidean| |pomopo!| |numericIfCan| |clearTheFTable| |build| |rCoord| |setleft!| |factorGroebnerBasis| |critBonD| |setImagSteps| |infieldIntegrate| |generalizedContinuumHypothesisAssumed| |OMgetEndBind| |segment| |mkIntegral| |rightTrace| |stack| |level| |maxPoints3D| |commonDenominator| |harmonic| |int| |previousTower| |constant?| |createNormalPoly| |modulus| |univariatePolynomials| |realEigenvalues| |compose| |swap!| |finiteBasis| |mapdiv| |weighted| |idealiserMatrix| |mr| |insertTop!| |palgRDE0| |viewPosDefault| |fill!| |identityMatrix| |resize| |palgintegrate| |chiSquare1| |DiffC| |printCode| |credPol| |lcm| |upperCase!| |functionIsContinuousAtEndPoints| |OMputAttr| |reduceRowOnList| |viewDeltaXDefault| |makeGraphImage| |countable?| |addiag| |rowEchelonLocal| |options| |droot| |totalfract| |cAsin| |series| |evaluate| |expt| |nthFlag| |rotatex| |lambert| |clipBoolean| |symmetricRemainder| |leftGcd| |genericLeftTrace| |column| |getDomains| |coHeight| |setColumn!| |GospersMethod| |collectUnder| |createHN| |separateDegrees| |checkOptions| |realSolve| |resultantEuclideannaif| |constantCoefficientRicDE| |resultantReduit| |setCondition!| |roughEqualIdeals?| |pointInIdeal?| |float?| |minIndex| |createPrimitivePoly| |stepBlowUp| |lfunc| |closedCurve?| |antisymmetricTensors| |orderIfNegative| |reduceLineOverLine| |besselI| |integral?| |blowUp| |chartCoord| |member?| |badNum| |unrankImproperPartitions1| |rightExactQuotient| |readLineIfCan!| |linearPart| |octon| |getCode| |optAttributes| |ramifMult| |patternVariable| |twist| |wholePart| |ode1| |dark| |signAround| |power| |stoseInvertible?reg| |simpleBounds?| |nor| |midpoints| |subs2ndVar| LT |doubleDisc| |exponents| |OMconnOutDevice| |numberPlacesDegExtDeg| |cosSinInfo| |semicolonSeparate| |inspect| |trailingCoefficient| |shiftInfoRec| |coleman| |rst| |mapUnivariateIfCan| |nthFractionalTerm| |leftUnits| |basis| |sizeLess?| |cSin| |determinant| |imagk| |LyndonWordsList1| |quadraticNorm| |null| |setMinPoints3D| |exquo| |bracket| |stFuncN| |leftRemainder| |prinshINFO| |div| |rationalPoints| |degreePartition| |enterInCache| |lazyGintegrate| |remainder| |fullInfClsPt| |clearDenominator| |OMputEndBind| |critB| |getStream| |removeConjugate| ^= |outputFloating| |frst| |isExpt| |top| |putGraph| |numFunEvals3D| |complexLimit| |generalizedEigenvector| |chebyshevU| |mapUp!| |defineProperty| |tableau| |bitCoef| |OMwrite| |iiacoth| |sum| |iteratedInitials| |vconcat| |cAsec| |trigs| |ref| |sdf2lst| |viewZoomDefault| |permutationRepresentation| |pointSizeDefault| |partialFraction| |symbolTableOf| |useEisensteinCriterion| |cubic| |setRealSteps| |singRicDE| |redmat| |option?| UP2UTS |origin| |matrixConcat3D| |leftExtendedGcd| |gbasis| |OMgetApp| |factorUsingMusser| |totalLex| |basisOfLeftNucloid| |associatorDependence| |log10| |typeList| |nextColeman| |cn| |setDegree!| |lfintegrate| |degreeSubResultantEuclidean| |iibinom| |foundPlaces| |figureUnits| |vark| |adjunctionDivisor| |fixedPoints| |makeSUP| |iflist2Result| |lists| RF2UTS |antisymmetric?| |coth2tanh| |maxDerivative| |search| |rationalPoint?| |sn| |nonLinearPart| |linGenPos| |cot2trig| |xCoord| |call| |lfextendedint| LE |iCompose| |subtractIfCan| |message| |moduloP| |inverseLaplace| |alphanumeric| |gderiv| |acothIfCan| |rischDEsys| |cCoth| |removeIrreducibleRedundantFactors| |shiftLeft| |supp| |pointColorDefault| |completeHermite| |previous| |setPosition| |normalizeIfCan| |exprToXXP| |generator| |lazyPquo| |interpolate| |safeFloor| |setprevious!| |find| |elRow1!| |edf2fi| |inverse| |getEq| |increase| |dihedralGroup| |imaginary| |simplifyExp| |discreteLog| |null?| |gcd| |primeFactor| GT |sh| |rewriteIdealWithHeadRemainder| |maxPoints| |setelt!| |numberOfCycles| |slex| |complexForm| |evalIfCan| |ravel| |binary| |frobenius| |HenselLift| |sech2cosh| |lowerCase!| |jacobian| |printTypes| |transcendentalDecompose| |df2fi| |OMgetSymbol| |Ei1| |graphStates| |coerce| |lo| |presub| |setleaves!| |set| |shiftRight| |incr| |computeCycleEntry| |lex| |hi| |powerSum| |Ei5| |RemainderList| |DiffAction| |logGamma| |kovacic| |cyclic?| |numberOfFactors| |declare| |position| |removeConstantTerm| |Beta| |normalElement| |concat| |computeInt| |homogeneous| |infinite?| |OMcloseConn| |differentialVariables| |principal?| GE |iisinh| |belong?| |HermiteIntegrate| |elt| |fractRagits| |generate| |redPo| |equation| |leftTrace| |incrementBy| |sin| |complexIntegrate| |mantissa| |expand| |cos| |getlo| |lastNonNul| |factorPolynomial| |filterWhile| |map| |lazyEvaluate| |slash| |filterUntil| |maxColIndex| |lazyPseudoDivide| |select| |assoc| |rur| |solveid| |key?| |moreAlgebraic?| |weakBiRank| |bsolve| |abs| |rightRecip| |biRank| |status| |rightPower| |setStatus!| |mainVariable| |explicitEntries?| |pop!| |makeRecord| |endOfFile?| |ScanFloatIgnoreSpacesIfCan| |prepareDecompose| |trapezoidalo| |property| |checkForZero| |linSolve| |delete| |totalDifferential| |Ci| |rischDE| |withPredicates| |units| |makeYoungTableau| |basicSet| |cPower| |shufflein| |enumerate| |multiplicative?| |e| |factorSquareFreePolynomial| |iipow| |LyndonWordsList| |rarrow| |finiteBound| |relationsIdeal| |mapCoef| |code| |semiDiscriminantEuclidean| |corrPoly| |fortranCompilerName| |value| |limitedIntegrate| |commutativeEquality| |multiEuclidean| |reduceRow| |retract| |iiacos| |negative?| |fullOut| |selectsecond| |froot| |actualExtensionV| |properties| |lBasis| |eigenMatrix| |integers| |constantIfCan| |zeroSquareMatrix| |setlocalParam!| |OMunhandledSymbol| |charClass| |seriesSolve| |implies| |mergeDifference| |wholeRagits| |localParamOfSimplePt| |deref| |selectODEIVPRoutines| |OMgetBind| |pushup| |setProperties| |traceMatrix| |printingInfo?| |push!| |rightDiscriminant| |connect| |subResultantsChain| |jordanAdmissible?| |selectOrPolynomials| |virtualDegree| |cycles| |var1Steps| |clikeUniv| |polynomialZeros| |bitLength| |minPoints3D| |f04adf| |direction| |quoted?| |parabolicCylindrical| |recip| |pointColor| |OMread| |alternatingGroup| |physicalLength| |outputList| |mat| |tanNa| |resultant| |continue| |findCycle| |pointColorPalette| |neglist| |smith| |index?| |bringDown| |char| |rootOf| |ptFunc| |factorFraction| |f07fef| |atoms| |itsALeaf!| |iiatanh| |f07fdf| |getPickedPoints| Y |pseudoQuotient| |expPot| |f07aef| |makeFR| |inf| |nullSpace| |f07adf| |rename!| |loopPoints| |filterUpTo| |indiceSubResultantEuclidean| |removeRoughlyRedundantFactorsInContents| |rewriteSetWithReduction| |s17dlf| |parametersOf| |numberOfDivisors| |setCurve| |s17dhf| |OMmakeConn| |OMputBind| |clearTable!| |s17dgf| |numeric| |solveLinearPolynomialEquationByFractions| |middle| |f02xef| |listAllMonoExp| |ParCond| |mapDown!| |f02wef| |radicalOfLeftTraceForm| |powers| |numberOfOperations| |option| |height| |f02fjf| |roughBasicSet| |intcompBasis| |printHeader| |f02bjf| |update| |irreducibleRepresentation| |solveLinear| |FormatRoman| |fmecg| |f02bbf| |cAtan| |linkToFortran| |factorUsingYun| |purelyAlgebraicLeadingMonomial?| |f02axf| |radicalSimplify| |varList| |infClsPt?| |f02awf| |antiAssociative?| |dflist| |removeSinhSq| |readable?| |table| |f02akf| |initializeParamOfPlaces| |btwFact| |character?| |wholeRadix| |f02ajf| EQ |henselFact| |distinguishedRootsOf| |additive?| |f02agf| |makeTerm| |radicalSolve| |prem| |cAcoth| |unaryFunction| |wronskianMatrix| |KrullNumber| |And| |f02aff| |formula| |curryRight| |RittWuCompare| |desingTree| |f02aef| |palglimint0| |iiBesselK| |listOfTerms| |f02adf| |normalDenom| |resultantnaif| |genericRightTraceForm| |createLowComplexityTable| |f02abf| |OMgetInteger| |shuffle| |log2| |f02aaf| |coerceImages| |hasPredicate?| |makeVariable| |left| |measure| |palgextint0| |laplace| |subPolSet?| |multiple| |indicialEquation| |extractIfCan| |rightFactorCandidate| |optional| |linearlyDependentOverZ?| |arrayStack| |approxNthRoot| |high| |useNagFunctions| |squareFreePart| |not| |lyndon?| |cubicBezier| |functionName| |denomRicDE| |iicosh| |viewPhiDefault| |aQuadratic| |taylorRep| |insertBottom!| |quadratic| |maxTower| |Zero| |allRootsOf| |applyQuote| |infinity| |monomials| |qnew| |cyclicCopy| |double| |graphs| |interpretString| |genericRightNorm| |palgint0| |conditionP| |linearBezier| |setParam!| FG2F |reciprocalPolynomial| |particularSolution| |parse| |palgLODE0| |divergence| |sec2cos| |nullary| |reducedContinuedFraction| |halfExtendedResultant2| |upperCase| |acscIfCan| |rootSplit| |returnType!| |lift| |curveColorPalette| |iiasech| |bernoulliB| |pdf2df| |totolex| |xor| |reduce| |genericPosition| |swapColumns!| |numberOfImproperPartitions| |commaSeparate| |qShiftAction| |evalRec| |graphCurves| |pfaffian| |stirling2| |shanksDiscLogAlgorithm| |rightCharacteristicPolynomial| |zeroDimensional?| |or| |dimension| |conical| |minPol| |exp1| |wordInGenerators| |hasTopPredicate?| |leftCharacteristicPolynomial| |definingInequation| |gcdprim| |createThreeSpace| |basisOfLeftNucleus| F2EXPRR |algint| |reduction| |evaluateInverse| |balancedBinaryTree| |innerEigenvectors| |selectMultiDimensionalRoutines| |normalize| |cAcsch| |iicot| |exponential| |randomR| |OMgetType| |dictionary| |times!| |roman| |guessRec| |supersub| |lastSubResultant| |mathieu12| |minRowIndex| |mkcomm| |gethi| |LyndonCoordinates| |newTypeLists| |e02bcf| |tower| |elliptic| |leftRegularRepresentation| |OMgetObject| |prinb| |e02bbf| |solveLinearlyOverQ| |pseudoRemainder| |SturmHabicht| |setEmpty!| |positiveRemainder| |e02baf| |palgRDE| |quasiComponent| |box| |firstExponent| |cExp| |e02akf| |linear| |normInvertible?| |isOp| |userOrdered?| |replaceKthElement| |setTower!| |e02ajf| |minPoly| |close!| |indicialEquationAtInfinity| |OMencodingBinary| |e04ycf| |mathieu22| |script| |mapGen| |coth2trigh| |padecf| |children| |iter| |symbol| |e04ucf| |OMgetEndError| |aspFilename| |subsInVar| |OMgetEndAttr| |setMaxPoints3D| |setFoundPlacesToEmpty| |e04naf| |biringToPolyRing| D |one| |setPoly| |imagi| |internalZeroSetSplit| |e04mbf| |rdHack1| |discriminantEuclidean| |guessADE| |quasiRegular| |e04jaf| |hitherPlane| |coordinate| |pastel| |collectUpper| |zero| |typeLists| |pointV| |denominator| |swapRows!| |monicCompleteDecompose| |e04gcf| |legendre| |resetNew| |dfRange| |setFormula!| |unitsColorDefault| |extractPoint| |multiple?| |e04fdf| |fortran| |LPolynomial| |complementaryBasis| |scale| |leastMonomial| |stoseSquareFreePart| |unary?| |leftDivide| |e04dgf| |systemCommand| |alphabetic| |normalizeAtInfinity| |kmax| |drawStyle| |headReduced?| |generalCoefficient| |contains?| |f01ref| |clipParametric| |element?| |edf2df| |selectNonFiniteRoutines| |f01rdf| |wrregime| |findOrderOfDivisor| |nonSingularModel| |mask| |cosh2sech| |rhs| |internalSubQuasiComponent?| |f01rcf| |Not| |rationalIfCan| |removeZero| |sortConstraints| |linearAssociatedExp| |maximumExponent| |solve| |f01qef| |extendedSubResultantGcd| |karatsubaDivide| |removeRedundantFactorsInContents| |invmod| |cyclicEqual?| |supRittWu?| |simplify| |f01qdf| |poisson| |check| |inR?| |cAcot| |omError| |mainContent| |setClosed| |nullary?| |eisensteinIrreducible?| |f01qcf| |radicalRoots| |copies| |inverseIntegralMatrixAtInfinity| |qfactor| |viewDefaults| |internalInfRittWu?| |f01mcf| |right| |rotate| |LiePolyIfCan| |socf2socdf| |numberOfNormalPoly| |ksec| |unprotectedRemoveRedundantFactors| |f01maf| |degreeOfMinimalForm| |Or| |expIfCan| |removeFirstZeroes| |multiEuclideanTree| |var2Steps| |explimitedint| |besselY| |showScalarValues| |cache| |coefficients| |f01bsf| |copyInto!| |dasum| |repeating| |csc2sin| |df2ef| |polygamma| |f01brf| |meshPar1Var| |curryLeft| |hexDigit| |separateFactors| |parts| |numericalIntegration| |leaf?| |transCoord| |algebraicVariables| |sayLength| |dominantTerm| |leastAffineMultiple| |variable| |mathieu11| |leftExactQuotient| |suppOfPole| |compBound| |integralBasis| |OMlistCDs| |nextPrimitivePoly| |rightDivide| |iicos| |writeObj| |rk4a| |sign| |linear?| |rk4f| |unvectorise| |absolutelyIrreducible?| |perfectSqrt| |monomRDE| |nullity| |viewSizeDefault| |hermite| |packageCall| |OMconnectTCP| |setOrder| |setErrorBound| |exprHasAlgebraicWeight| |changeWeightLevel| |rotatez| |rightUnits| |slope| |createPrimitiveNormalPoly| |curry| |fracPart| |precision| |OMputEndObject| |stoseInvertibleSetreg| |rule| |integralCoordinates| |leftMinimalPolynomial| |quadraticBezier| |maxShift| |specialTrigs| |integralRepresents| |leadingSupport| |setvalue!| |radicalEigenvectors| |cross| |fullPartialFraction| |basisOfMiddleNucleus| |powerAssociative?| |sequences| |genericLeftDiscriminant| |OMUnknownSymbol?| |argumentListOf| |leadingIdeal| |Lazard| |critMonD1| |genus| |leftTrim| |charthRoot| |cap| |ruleset| |cos2sec| |cAsech| |pointToPlace| |sinhcosh| |prefix| |name| |setAdaptive| |blue| |subMultV| |tex| |stopTableGcd!| |external?| |physicalLength!| |makeCos| |plenaryPower| |extract!| |OMsetEncoding| |maxRowIndex| |setTex!| |subQuasiComponent?| |laurentRep| |revert| |errorInfo| |printStatement| |Frobenius| |extendIfCan| |OMsupportsSymbol?| |polCase| |diffHP| |nary?| |exprToGenUPS| |print| |removeCosSq| |maxdeg| |completeEchelonBasis| |parametrize| |primPartElseUnitCanonical| |characteristic| |convergents| |dihedral| |directory| |genericLeftNorm| |extractTop!| |removeRedundantFactorsInPols| |getMultiplicationTable| |setref| |reduceByQuasiMonic| |effective?| |LyndonBasis| |any?| |sylvesterSequence| |gramschmidt| |discriminant| |commutative?| |maxDegree| |doubleRank| |Yun| |dimensionOfIrreducibleRepresentation| |kernel| |rspace| |makeop| |PollardSmallFactor| |denominators| |lexico| |localParamV| |iifact| |axesColorDefault| |outputGeneral| |classNumber| |groebSolve| |Ei4| |repeatUntilLoop| |OMserve| |lazyIrreducibleFactors| |testModulus| |monic?| |limit| |squareMatrix| |linearDependence| |any| |acschIfCan| |quadratic?| |internalIntegrate0| |tubePlot| |linearlyDependent?| |ode| |ranges| |iisin| |bright| |setStatus| |iiBeta| |goppaCode| |stoseInternalLastSubResultant| |lazyResidueClass| |conditions| |exponent| |mergeFactors| |failed| |df2st| |leftAlternative?| |delta| |algebraicDecompose| |maxLevel| |internalLastSubResultant| |shiftHP| |setAdaptive3D| |t| |postfix| |output| |constant| |squareFree| |diagonalMatrix| |chineseRemainder| |algebraicOf| |selectfirst| |subspace| |LagrangeInterpolation| |zeroOf| |algebraicSort| |cyclePartition| |stiffnessAndStabilityOfODEIF| |mainMonomials| |innerSolve1| |euclideanGroebner| |findTerm| |quotedOperators| |nthr| |mainValue| |leftMult| |root| |redpps| GF2FG |ceiling| |wordInStrongGenerators| |quadraticForm| |adaptive?| |minimumDegree| |reducedDiscriminant| |shallowCopy| |normFactors| |totalDegree| |iitan| |matrixGcd| |finiteSeries2LinSys| |reducedForm| |problemPoints| |nodes| |cycleLength| |elem?| |innerint| |realZeros| |numerator| |genericRightMinimalPolynomial| |algebraicCoefficients?| |structuralConstants| |zeroDimPrime?| |low| |clipSurface| |OMputEndAttr| |setPrologue!| |solid| |iiexp| |myDegree| |fortranComplex| |zeta| |bubbleSort!| |diophantineSystem| |drawComplexVectorField| |deepCopy| |finite?| |guessPade| |UpTriBddDenomInv| |symmetric?| |derivative| |pushdterm| |vspace| |polyRDE| |nextLatticePermutation| |extendedint| |modularGcd| |completeHensel| |multiServ| |exprHasLogarithmicWeights| |divisorCascade| |fractRadix| |plus!| |rewriteSetByReducingWithParticularGenerators| |nextPartition| |notelem| |factorials| |stoseInvertibleSetsqfreg| |alternative?| |polyRing2UPUP| |range| |lieAdmissible?| |infix| |binomial| |fi2df| |makeCrit| |encode| |e02bdf| |showAll?| |binarySearchTree| |unit| |guessPRec| |bivariateSLPEBR| |splitNodeOf!| |noKaratsuba| |minusInfinity| |mainCharacterization| |BumInSepFFE| |point?| |bit?| |evalADE| |ODESolve| |gcdPolynomial| |plusInfinity| |changeMeasure| |node?| |mainPrimitivePart| |npcoef| |genericLeftTraceForm| |expandPower| |LazardQuotient| |plotPolar| |void| |iiacsch| |twoFactor| |root?| |getDatabase| |splitDenominator| |lifting| |generateIrredPoly| |blowUpWithExcpDiv| |addMatchRestricted| |tail| |sinhIfCan| |subNodeOf?| |iisqrt3| |iiAiryAi| |semiSubResultantGcdEuclidean2| |lastSubResultantEuclidean| |LowTriBddDenomInv| |maxIndex| |functionIsOscillatory| |primextintfrac| |expintegrate| |exponentialOrder| |flexible?| |write!| |generalLambert| |getGraph| |usingTable?| |clipPointsDefault| |comparison| |allDegrees| |interpret| |merge| |diag| |sort| |fintegrate| |monomRDEsys| |elliptic?| |key| |next| |regularRepresentation| |lfextlimint| |iiabs| |fTable| |semiResultantReduitEuclidean| UTS2UP |binaryTree| |iiBesselI| |unitCanonical| |algDsolve| |simplifyLog| |llprop| |pointData| |divideIfCan!| |monicRightDivide| |retractIfCan| |moduleSum| |d01gbf| |cSinh| |quotVecSpaceBasis| |OMgetBVar| |unrankImproperPartitions0| |suffix?| |meshPar2Var| |d01gaf| |ScanArabic| |xRange| |length| |nonQsign| |rk4qc| |cyclicSubmodule| |bitTruth| |setButtonValue| |leftOne| |fullDisplay| |d01fcf| |scripts| |overlap| |square?| |light| |bezoutResultant| |graphImage| |complement| |d01bbf| |zeroVector| |multiplyCoefficients| |OMgetEndBVar| |hermiteH| |cCsch| |nextPrime| |d01asf| |primextendedint| |axes| |ldf2lst| |crest| |OMputEndApp| |lastNonNull| |fortranCarriageReturn| |solveLinearPolynomialEquationByRecursion| |invertibleElseSplit?| |double?| |completeEval| |setsubmult!| |create3Space| |d02raf| |OMencodingXML| |digit| |splitSquarefree| |vedf2vef| |complexRoots| |Nul| |d02kef| |palglimint| |consnewpol| |newtonPolygon| |coercePreimagesImages| |lambda| |createNormalPrimitivePoly| |d02gbf| |insertRoot!| |zag| |fprindINFO| |critT| |internalAugment| |addMatch| |d02gaf| |heap| |module| |predicates| |iiGamma| |rotate!| |totalGroebner| |monicRightFactorIfCan| |d02ejf| |fortranLogical| |iisec| |leadingTerm| |trace2PowMod| |red| |removeSinSq| |iiAiryBi| |d02cjf| |matrixDimensions| |conjug| |bezoutMatrix| |complexNormalize| |result| |OMputString| |d02bhf| |substring?| |head| |normalized?| |insertionSort!| |rubiksGroup| |stronglyReduce| |prefix?| |hessian| |float| |d02bbf| |qqq| |bat1| |useSingleFactorBound| |zeroMatrix| |OMgetAttr| |pseudoDivide| |removeSuperfluousQuasiComponents| |basisOfRightNucloid| |e02ahf| |listYoungTableaus| |iisqrt2| |generalPosition| |trunc| |stop| |lowerCase?| |hypergeometric0F1| |localUnquote| |associatedSystem| |extractIndex| |more?| |cCot| |baseRDEsys| |translateToOrigin| |constDsolve| |less?| |reindex| |alphabetic?| |rootPoly| |transcendenceDegree| |toroidal| |combineFeatureCompatibility| |viewport3D| |lSpaceBasis| |divideExponents| |cup| |dioSolve| |polynomial| |weierstrass| |tubeRadius| |sqfrFactor| |bivariate?| |setSingularPoints| |basisOfInterpolateFormsForFact| |declare!| |d03faf| |explicitlyEmpty?| |someBasis| |clearTheIFTable| |decomposeFunc| |iilog| |critMTonD1| |complexNumeric| |binaryFunction| |d03eef| |besselJ| |optpair| |apply| |primes| |rightZero| |bandedHessian| |kernels| |extendedEuclidean| |d03edf| |rdregime| |OMreceive| |dAndcExp| |goto| |rightMinimalPolynomial| |univariate| |internal?| |operator| |coefChoose| |torsionIfCan| |phiCoord| |brace| |quasiAlgebraicSet| |externalList| |getOrder| |factor| |doubleResultant| |identification| |copy!| |An| |paren| |cons| |indicialEquations| |removeRedundantFactors| |real| |sncndn| |primlimintfrac| |startTable!| |squareFreePolynomial| |irreducibleFactors| |copy| |quoByVar| |bat| |imag| |placesOfDegree| |dmpToHdmp| |setLegalFortranSourceExtensions| |scanOneDimSubspaces| |child?| |setRow!| |sumOfKthPowerDivisors| |viewWriteAvailable| |first| |invertibleSet| |addPointLast| |pToDmp| |printInfo!| |initials| |compiledFunction| |fortranReal| |indexName| |palgextint| |expandTrigProducts| |chartV| |stoseInvertible?| |makeprod| |nsqfree| |setright!| |semiResultantEuclideannaif| |ord| |recolor| |realEigenvectors| |list| |makeResult| |represents| |changeNameToObjf| |fortranInteger| |addPoint2| |cycleTail| |repSq| |getBadValues| |yCoord| |OMputInteger| |eigenvalues| |pair?| |is?| |antiCommutator| |rowEchelon| |false| |leftQuotient| |guessHP| |hex| |extDegree| |zeroDimPrimary?| |flush| |enqueue!| |OMUnknownCD?| |expressIdealMember| |maxrank| |distribute| |binomThmExpt| |removeDuplicates| |times| |youngGroup| |att2Result| |listVariable| |cycle| |UnVectorise| |highCommonTerms| |c05nbf| |factorList| |rest| |idealSimplify| |rectangularMatrix| |stoseIntegralLastSubResultant| |explogs2trigs| |cyclotomicDecomposition| |c05adf| |replace| |updatF| |reverse| |decompose| |removeCoshSq| |indices| |polyPart| |c06gsf| |every?| |checkRur| |dec| |setDifference| |po| |iFTable| |divisor| |c06gqf| |pushuconst| |getVariableOrder| |OMputApp| |setIntersection| |select!| |associative?| |c06gcf| |subscript| |randomLC| |allPairsAmong| |fortranDoubleComplex| |getOp| |numberOfMonomials| |simplifyPower| |nil| |c06gbf| |coshIfCan| |createRandomElement| |setUnion| |lineColorDefault| |cotIfCan| |iidprod| |cLog| |c06fuf| |anticoord| |getCurve| |commutator| |size| |superscript| |separant| |substitute| |c06frf| |predicate| |hadamard| |rewriteIdealWithRemainder| |numericalOptimization| |cschIfCan| |getMultiplicationMatrix| |rowEchWoZeroLinesWOVectorise| |c06fqf| |approximate| |alphanumeric?| |mvar| |cyclicEntries| |hexDigit?| |imagI| |complex| |c06fpf| |unitVector| |atanhIfCan| |airyAi| |coerceL| |iicoth| |decimal| |say| |c06ekf| |doublyTransitive?| |asechIfCan| |showClipRegion| |horizConcat| |symmetricTensors| |objectOf| |debug| |zeroDim?| |c06ecf| |BasicMethod| |hash| |boundOfCauchy| |OMputEndError| |OMgetEndApp| |cTan| |c06ebf| |delete!| |firstDenom| |semiIndiceSubResultantEuclidean| |repeating?| |back| |c06eaf| |title| |LazardQuotient2| |minGbasis| |asecIfCan| |dn| |s17def| |setsubMatrix!| |heapSort| |bipolarCylindrical| |parametric?| |getButtonValue| |s17dcf| |explicitlyFinite?| |rightOne| |inGroundField?| |setnext!| |space| |s17akf| |tubePoints| |integralLastSubResultant| |generators| |numberOfIrreduciblePoly| |bfEntry| |s17ajf| |maxPower| |perfectNthRoot| |columnSpace| |makeSeries| |match?| |qShiftC| |s17ahf| |calcRanges| |subst| |iicsch| |stoseLastSubResultant| |f2st| |s17agf| |bag| |zoom| |dimensions| |branchPointAtInfinity?| |s17aff| |factorset| |dequeue!| |leaves| |setchart!| |changeVar| |equality| |entry| |s17aef| |sechIfCan| |optimize| |transpose| |acoshIfCan| |pointLists| |noLinearFactor?| |s17adf| |close| |OMputError| |charpol| |divisors| |point| |lowerPolynomial| |s17acf| |symbolTable| |testDim| |quatern| |super| |divOfZero| |pushFortranOutputStack| |s15aef| |ScanRoman| |evenlambert| |partialDenominators| |cot2tan| |oblateSpheroidal| |filename| |s15adf| |floor| |create| |pquo| |seriesToOutputForm| |cscIfCan| |popFortranOutputStack| |rowEch| |s14baf| |genusTreeNeg| |insert| |stoseInvertible?sqfreg| |queue| |display| |sylvesterMatrix| |s14abf| |outputAsFortran| |common| |closeComponent| |coerceListOfPairs| |leftTraceMatrix| |cond| |s14aaf| |rightExtendedGcd| |fortranCharacter| |integerBound| |sizePascalTriangle| |trivialIdeal?| |s13adf| |modifyPointData| |components| BY |halfExtendedSubResultantGcd2| |rationalPower| |OMputSymbol| |s13acf| |leftLcm| |ratpart| |lfinfieldint| |expr| |projectivePoint| |inRadical?| |depth| |s13aaf| |points| |flagFactor| |wreath| |shrinkable| |makeViewport3D| |elColumn2!| |last| |s01eaf| |localReal?| |nthFactor| |multiplyExponents| |generalInfiniteProduct| |count| |ellipticCylindrical| |s21bdf| |imagK| |inconsistent?| F2FG |s21bcf| |sturmVariationsOf| |partitions| |truncate| |fortranLiteralLine| |hdmpToDmp| |reshape| |s21bbf| |stFunc2| |conjugates| |move| |rename| |primitiveElement| |s21baf| |lexGroebner| |differentiate| |perspective| |sts2stst| |op| |OMputVariable| |iipolygamma| |rootRadius| |s20adf| |linearPolynomials| |limitPlus| |hyperelliptic| |leftPower| |upperCase?| |e02agf| |linearMatrix| |constantOpIfCan| |alternating| |selectFiniteRoutines| |elementary| |s20acf| |vector| |getZechTable| |graeffe| |iiperm| |makeSin| |d01aqf| |symmetricDifference| |FormatArabic| |normalizedAssociate| |integerDecode| |noncommutativeJordanAlgebra?| |s19adf| |completeSmith| |setTopPredicate| |controlPanel| |triangularSystems| |d01apf| |prologue| |failed?| |desingTreeAtPoint| |stronglyReduced?| |tValues| |singularitiesOf| |s19acf| |genericRightDiscriminant| |lllp| |setLabelValue| |badValues| |constantOperator| |d01anf| |basisOfNucleus| |rquo| |simpsono| |prepareSubResAlgo| |cartesian| |d01amf| |fullDesTree| |adaptive3D?| |iomode| |realRoots| |rischNormalize| |d01alf| |keys| |factorSquareFree| SEGMENT |label| |viewWriteDefault| |nilFactor| |s19abf| |partialNumerators| |iiBesselJ| |permutations| |newReduc| |d01akf| |lazyPseudoQuotient| |invertible?| |child| |selectPDERoutines| |s19aaf| |hasoln| |minimumExponent| |normalForm| |thetaCoord| |functionIsFracPolynomial?| |setClipValue| |monomialIntPoly| |d01ajf| |cTanh| |sturmSequence| |convert| |newton| |replaceDiffs| |s18def| |placesAbove| |flatten| |fibonacci| |imagJ| |localPointV| |construct| |plus| |s18dcf| |OMencodingUnknown| |real?| |identity| |fullOutput| |s18aff| |asimpson| |generalizedEigenvectors| |affinePoint| |OMlistSymbols| |monicLeftDivide| |s18aef| |magnitude| |updateStatus!| |viewport2D| |OMgetAtp| |modularFactor| |weight| |s18adf| |mapUnivariate| |wordsForStrongGenerators| |associatedEquations| |leadingBasisTerm| |ideal| |s18acf| |squareFreeFactors| |makeUnit| |drawCurves| |colorDef| |f04qaf| |extensionDegree| |diagonal?| |showTheIFTable| |fortranLiteral| |medialSet| |guessBinRat| |f04mcf| |resultantEuclidean| |goodnessOfFit| |remove| |complex?| |collect| |basisOfRightAnnihilator| |f04mbf| |qPot| |factorSqFree| |createGenericMatrix| |B1solve| |integralDerivationMatrix| |f04maf| |moebiusMu| |infRittWu?| |eyeDistance| |setMinPoints| |algintegrate| |f04jgf| |singular?| |doubleComplex?| |cosIfCan| |multMonom| |f04faf| |dmp2rfi| |bfKeys| |yCoordinates| |iiBesselY| |polygon| |index| |fglmIfCan| |f04axf| |radicalEigenvector| |OMputBVar| |isTimes| |composite| |f04atf| |pattern| |Ei| |insertMatch| |ShiftAction| |tab1| |iiacot| |f04asf| |subresultantVector| |cyclic| |mulmod| |innerSolve| |ShiftC| |useEisensteinCriterion?| |goodPoint| |read!| |OMputFloat| |f04arf| |roughUnitIdeal?| |powern| |multisect| |univariateSolve| |basisOfCenter| |cyclicParents| |infiniteProduct| |cycleRagits| |leftNorm| |recoverAfterFail| |collectQuasiMonic| |nlde| |factorSquareFreeByRecursion| |endSubProgram| |outputSpacing| |input| |applyRules| |Vectorise| |lepol| |iisech| |pow| |test| |quotValuation| |tanintegrate| |members| |digit?| |anfactor| |quotient| |OMencodingSGML| |setVariableOrder| |ldf2vmf| |exptMod| |getMatch| |atanIfCan| |htrigs| |norm| |log| |aLinear| |screenResolution| |numberOfComposites| |principalIdeal| |central?| |cycleEntry| |cyclicGroup| |unit?| |closedCurve| |guessHolo| |closed?| |normDeriv2| |errorKind| |padicallyExpand| |nthExponent| |recur| |constantToUnaryFunction| |init| |intPatternMatch| |findCoef| |match| |minimize| |accuracyIF| |computeCycleLength| |complexExpand| |monomial2series| |nand| |split| |beauzamyBound| |isobaric?| |brillhartIrreducible?| |orbit| |uncouplingMatrices| |reverse!| |affineAlgSet| |interpolateForms| |node| |quotientByP| |exprHasWeightCosWXorSinWX| |complexEigenvectors| |ffactor| |Hausdorff| |sbt| ** |lieAlgebra?| E1 |OMreadStr| |hdmpToP| |squareTop| |safety| |basisOfCentroid| |affineRationalPoints| |tracePowMod| |rowEchLocal| |rowEchWoZeroLines| |numFunEvals| |interval| |semiDegreeSubResultantEuclidean| |chebyshevT| |countRealRootsMultiple| |primintegrate| |rootSimp| |coerceS| |shiftRoots| |groebnerIdeal| |Aleph| |rootPower| |vertConcat| |integerIfCan| |computeBasis| |chvar| |sample| |changeName| |euler| |musserTrials| |createLowComplexityNormalBasis| |isPower| |merge!| |asinIfCan| |univcase| |lowerCase| |deepExpand| |OMsend| |nil| |infinite| |arbitraryExponent| |approximate| |complex| |shallowMutable| |canonical| |noetherian| |central| |partiallyOrderedSet| |arbitraryPrecision| |canonicalsClosed| |noZeroDivisors| |rightUnitary| |leftUnitary| |additiveValuation| |unitsKnown| |canonicalUnitNormal| |multiplicativeValuation| |finiteAggregate| |shallowlyMutable| |commutative|) 
\ No newline at end of file
diff --git a/src/share/algebra/dependents.daase/index.kaf b/src/share/algebra/dependents.daase/index.kaf
index fce8e8c..e935ec4 100755
--- a/src/share/algebra/dependents.daase/index.kaf
+++ b/src/share/algebra/dependents.daase/index.kaf
@@ -1,7 +1,8 @@
-67647               (|AbelianGroup&| |FourierSeries| |FreeAbelianGroup| |IndexedDirectProductAbelianGroup| |QuadraticForm|)
-(|AbelianMonoid&| |CardinalNumber| |EuclideanModularRing| |GradedAlgebra| |GradedAlgebra&| |GradedModule| |GradedModule&| |IndexedDirectProductAbelianMonoid| |ListMonoidOps| |ModularField| |ModularRing|)
-(|AbelianMonoidRing&|)
+76844               (|AbelianGroup&| |FourierSeries| |FreeAbelianGroup| |IndexedDirectProductAbelianGroup| |QuadraticForm|)
+(|AbelianMonoid&| |CardinalNumber| |EuclideanModularRing| |GradedAlgebra| |GradedAlgebra&| |GradedModule| |GradedModule&| |IndexedDirectProductAbelianMonoid| |ListMonoidOps| |ModularField| |ModularRing| |RecurrenceOperator|)
+(|AbelianMonoidRing&| |FractionFreeFastGaussian|)
 (|AbelianSemiGroup&| |Color| |IncrementingMaps| |PositiveInteger|)
+(|AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace|)
 (|Aggregate&| |SplittingNode| |SplittingTree|)
 (|Algebra&| |CliffordAlgebra| |ContinuedFraction| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |EvaluateCycleIndicators| |Factored| |FortranExpression| |FourierSeries| |LocalAlgebra| |PartialFraction| |RealClosure| |ResidueRing| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |UnivariateTaylorSeriesODESolver|)
 (|AlgFactor| |AlgebraicMultFact|)
@@ -14,36 +15,43 @@
 (|BagAggregate&|)
 (|BalancedPAdicRational|)
 (|ModuleOperator| |Operator|)
-(|BasicType&| |IVField| |IVValue| |Timer|)
+(|BasicType&|)
 (|FreeModule| |OrdinaryDifferentialRing|)
 (|BinaryRecursiveAggregate&| |PendantTree|)
 (|BalancedBinaryTree| |BinarySearchTree| |BinaryTournament| |BinaryTree| |BinaryTreeCategory&|)
 (|BitAggregate&| |Bits| |IndexedBits|)
+(|BlowUpPackage| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |DesingTreePackage| |GeneralPackageForAlgebraicFunctionField| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointCategory| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |IntersectionDivisorPackage| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField|)
 (|GeneralModulePolynomial| |InnerPAdicInteger| |ModuleMonomial| |OrderedDirectProduct|)
 (|Kernel| |MakeCachableSet| |SortedCache|)
 (|FreeAbelianMonoidCategory| |InnerFreeAbelianMonoid|)
 (|CharacterClass|)
 (|AlgebraicNumber| |BalancedFactorisation| |ConstantLODE| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |FullPartialFractionExpansion| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |GenusZeroIntegration| |GroebnerFactorizationPackage| |InfiniteProductCharacteristicZero| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerMultFact| |InternalRationalUnivariateRepresentationPackage| |InverseLaplaceTransform| |Kovacic| |LaplaceTransform| |LinearOrdinaryDifferentialOperatorFactorizer| |MRationalFactorize| |MachineFloat| |MultivariateFactorize| |NonLinearFirstOrderODESolver| |ODEIntegration| |ParametricLinearEquations| |PartialFractionPackage| |Pi| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |PureAlgebraicIntegration| |PureAlgebraicLODE| |RadicalSolvePackage| |RationalFunctionDefiniteIntegration| |RationalFunctionIntegration| |RationalIntegration| |RationalLODE| |RationalRicDE| |RationalUnivariateRepresentationPackage| |SAERationalFunctionAlgFactor| |SimpleAlgebraicExtensionAlgFactor| |StreamInfiniteProduct| |TransSolvePackage| |TranscendentalRischDE| |TranscendentalRischDESystem| |UnivariatePolynomialDecompositionPackage| |ZeroDimensionalSolvePackage|)
-(|AssociatedJordanAlgebra| |AssociatedLieAlgebra| |Float| |FortranScalarType| |InfiniteTuple| |InventorDataSink| |LieSquareMatrix| |MakeCachableSet| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |Pi| |QuasiAlgebraicSet| |QueryEquation| |RectangularMatrix| |SquareMatrix| |Switch| |SymbolTable| |TheSymbolTable| |Tuple| |Variable|)
+(|AssociatedJordanAlgebra| |AssociatedLieAlgebra| |Float| |FortranScalarType| |InfiniteTuple| |LieSquareMatrix| |MakeCachableSet| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |Pi| |QuasiAlgebraicSet| |QueryEquation| |RectangularMatrix| |SquareMatrix| |Switch| |SymbolTable| |TheSymbolTable| |Tuple| |Variable|)
 (|Collection&|)
-(|FunctionSpaceSum|)
-(|Algebra| |Algebra&| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |CartesianTensor| |CartesianTensorFunctions2| |CharacteristicPolynomialInMonogenicalAlgebra| |CharacteristicPolynomialPackage| |CoerceVectorMatrixPackage| |Complex| |ComplexCategory| |ComplexCategory&| |ComplexFunctions2| |ComplexPattern| |ComplexPatternMatch| |EuclideanModularRing| |FiniteRankAlgebra| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra| |FiniteRankNonAssociativeAlgebra&| |FourierSeries| |FramedAlgebra| |FramedAlgebra&| |FramedNonAssociativeAlgebra| |FramedNonAssociativeAlgebra&| |FramedNonAssociativeAlgebraFunctions2| |FreeLieAlgebra| |FreeNilpotentLie| |GeneralModulePolynomial| |GenericNonAssociativeAlgebra| |GradedAlgebra| |GradedAlgebra&| |GradedModule| |GradedModule&| |IntegerMod| |LieAlgebra| |LieAlgebra&| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LocalAlgebra| |Localize| |MatrixLinearAlgebraFunctions| |ModularField| |ModularRing| |Module| |Module&| |MonogenicAlgebra| |MonogenicAlgebra&| |NonAssociativeAlgebra| |NonAssociativeAlgebra&| |NumberTheoreticPolynomialFunctions| |Octonion| |OctonionCategory| |OctonionCategory&| |OctonionCategoryFunctions2| |OrthogonalPolynomialFunctions| |PackedHermitianSequence| |Quaternion| |QuaternionCategory| |QuaternionCategory&| |QuaternionCategoryFunctions2| |ResidueRing| |SimpleAlgebraicExtension| |XPBWPolynomial|)
-(|AlgebraicNumber| |ComplexFactorization| |ComplexRootFindingPackage| |ComplexRootPackage| |ComplexTrigonometricManipulations| |InnerAlgebraicNumber| |InnerTrigonometricManipulations|)
+(|FunctionSpaceSum| |Guess| |MyExpression| |RecurrenceOperator|)
+(|Algebra| |Algebra&| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |CartesianTensor| |CartesianTensorFunctions2| |CharacteristicPolynomialInMonogenicalAlgebra| |CharacteristicPolynomialPackage| |CoerceVectorMatrixPackage| |Complex| |ComplexCategory| |ComplexCategory&| |ComplexFunctions2| |ComplexPattern| |ComplexPatternMatch| |EuclideanModularRing| |FiniteRankAlgebra| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra| |FiniteRankNonAssociativeAlgebra&| |FourierSeries| |FramedAlgebra| |FramedAlgebra&| |FramedNonAssociativeAlgebra| |FramedNonAssociativeAlgebra&| |FramedNonAssociativeAlgebraFunctions2| |FreeLieAlgebra| |FreeNilpotentLie| |GeneralModulePolynomial| |GenericNonAssociativeAlgebra| |GradedAlgebra| |GradedAlgebra&| |GradedModule| |GradedModule&| |IntegerMod| |LieAlgebra| |LieAlgebra&| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LocalAlgebra| |Localize| |MatrixLinearAlgebraFunctions| |ModularField| |ModularRing| |Module| |Module&| |MonogenicAlgebra| |MonogenicAlgebra&| |NonAssociativeAlgebra| |NonAssociativeAlgebra&| |NumberTheoreticPolynomialFunctions| |Octonion| |OctonionCategory| |OctonionCategory&| |OctonionCategoryFunctions2| |OrthogonalPolynomialFunctions| |Quaternion| |QuaternionCategory| |QuaternionCategory&| |QuaternionCategoryFunctions2| |ResidueRing| |SimpleAlgebraicExtension| |XPBWPolynomial|)
+(|AlgebraicNumber| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexFactorization| |ComplexRootFindingPackage| |ComplexRootPackage| |ComplexTrigonometricManipulations| |InnerAlgebraicNumber| |InnerTrigonometricManipulations|)
 (|Complex| |ComplexCategory&| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexPattern| |ComplexPatternMatch| |MachineComplex|)
-(|AlgebraicNumber| |ApplyRules| |Boolean| |CharacterClass| |ComplexPattern| |DoubleFloat| |DrawNumericHack| |ExpressionSpaceODESolver| |Float| |FullPartialFractionExpansion| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InnerAlgebraicNumber| |InnerPrimeField| |InputForm| |Integer| |IntegerMod| |LaurentPolynomial| |MakeBinaryCompiledFunction| |MakeFloatCompiledFunction| |MakeFunction| |MakeUnaryCompiledFunction| |Numeric| |OrderedVariableList| |ParametricLinearEquations| |Partition| |PatternMatch| |PatternMatchFunctionSpace| |PatternMatchKernel| |PatternMatchPolynomialCategory| |PatternMatchQuotientFieldCategory| |PatternMatchTools| |Pi| |PlotFunctions1| |PrimeField| |RewriteRule| |Ruleset| |Symbol| |TopLevelDrawFunctions|)
+(|ComplexDoubleFloatMatrix|)
+(|AlgebraicNumber| |ApplyRules| |Boolean| |CharacterClass| |ComplexPattern| |DoubleFloat| |DrawNumericHack| |ExpressionSolve| |ExpressionSpaceODESolver| |Float| |FullPartialFractionExpansion| |GuessFinite| |GuessFiniteFunctions| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InnerAlgebraicNumber| |InnerPrimeField| |InputForm| |Integer| |IntegerMod| |LaurentPolynomial| |MakeBinaryCompiledFunction| |MakeFloatCompiledFunction| |MakeFunction| |MakeUnaryCompiledFunction| |Numeric| |OrderedVariableList| |ParametricLinearEquations| |Partition| |PatternMatch| |PatternMatchFunctionSpace| |PatternMatchKernel| |PatternMatchPolynomialCategory| |PatternMatchQuotientFieldCategory| |PatternMatchTools| |Pi| |PlotFunctions1| |PrimeField| |RecurrenceOperator| |RewriteRule| |Ruleset| |Symbol| |TopLevelDrawFunctions|)
 (|Dequeue|)
+(|DesingTree| |DesingTreePackage| |GeneralPackageForAlgebraicFunctionField| |IntersectionDivisorPackage|)
 (|Dictionary&|)
 (|DictionaryOperations&|)
 (|DifferentialExtension&| |Factored| |LaurentPolynomial|)
 (|DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |OrderlyDifferentialPolynomial| |SequentialDifferentialPolynomial|)
 (|AlgebraicNumber| |DifferentialRing&| |DoubleFloat| |Float| |InnerAlgebraicNumber| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |OrdinaryDifferentialRing|)
 (|DifferentialPolynomialCategory| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |OrderlyDifferentialVariable| |SequentialDifferentialVariable|)
-(|DirectProductMatrixModule| |DistributedMultivariatePolynomial| |LieSquareMatrix| |RectangularMatrix| |SquareMatrix|)
-(|DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |HomogeneousDirectProduct| |OrderedDirectProduct| |RectangularMatrixCategory| |RectangularMatrixCategory&| |RectangularMatrixCategoryFunctions2| |SplitHomogeneousDirectProduct| |SquareMatrixCategory| |SquareMatrixCategory&|)
+(|DirectProductMatrixModule| |DistributedMultivariatePolynomial| |InfClsPt| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |LieSquareMatrix| |RectangularMatrix| |SquareMatrix|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |BlowUpPackage| |DesingTreePackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |HomogeneousDirectProduct| |InfinitlyClosePoint| |InfinitlyClosePointCategory| |InterpolateFormsPackage| |IntersectionDivisorPackage| |LocalParametrizationOfSimplePointPackage| |NewtonPolygon| |OrderedDirectProduct| |PackageForPoly| |ParametrizationPackage| |PolynomialPackageForCurve| |ProjectiveAlgebraicSetPackage| |RectangularMatrixCategory| |RectangularMatrixCategory&| |RectangularMatrixCategoryFunctions2| |SplitHomogeneousDirectProduct| |SquareMatrixCategory| |SquareMatrixCategory&|)
+(|InfClsPt| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField|)
 (|DivisionRing&|)
-(|ExpertSystemContinuityPackage1| |Float| |InputForm| |Pi| |SExpression|)
+(|InfClsPt| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField|)
+(|DesingTreePackage| |Divisor| |GeneralPackageForAlgebraicFunctionField| |InfinitlyClosePoint| |InfinitlyClosePointCategory| |InterpolateFormsPackage| |IntersectionDivisorPackage|)
+(|ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |DoubleFloatMatrix| |DoubleFloatVector| |ExpertSystemContinuityPackage1| |Float| |InputForm| |Pi| |SExpression|)
+(|DoubleFloatMatrix|)
 (|ElementaryFunctionCategory&| |GaloisGroupFactorizationUtilities|)
-(|Automorphism| |LinearOrdinaryDifferentialOperator2| |ModuleOperator| |Operator| |RewriteRule| |Ruleset|)
+(|Automorphism| |DirichletRing| |LinearOrdinaryDifferentialOperator2| |ModuleOperator| |Operator| |RewriteRule| |Ruleset|)
 (|EltableAggregate&|)
 (|RewriteRule|)
 (|CRApackage| |ComplexFactorization| |ConstantLODE| |ContinuedFraction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |EuclideanDomain&| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |FractionalIdeal| |FractionalIdealFunctions2| |FramedModule| |FunctionFieldIntegralBasis| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |GenExEuclid| |GenUFactorize| |GeneralHenselPackage| |GroebnerFactorizationPackage| |InnerModularGcd| |InnerMultFact| |IntegralBasisTools| |InternalRationalUnivariateRepresentationPackage| |InverseLaplaceTransform| |LaplaceTransform| |LeadingCoefDetermination| |MPolyCatPolyFactorizer| |MRationalFactorize| |ModularHermitianRowReduction| |MultivariateFactorize| |MultivariateLifting| |MultivariateSquareFree| |NPCoef| |NonLinearFirstOrderODESolver| |ODEIntegration| |ParametricLinearEquations| |PartialFraction| |PartialFractionPackage| |PolynomialGcdPackage| |RadicalSolvePackage| |RationalFunctionDefiniteIntegration| |RationalFunctionFactorizer| |RationalUnivariateRepresentationPackage| |SmithNormalForm| |TransSolvePackage| |ZeroDimensionalSolvePackage|)
@@ -52,17 +60,17 @@
 (|DeRhamComplex|)
 (|AlgebraicManipulations| |AlgebraicNumber| |ExpressionSpace&| |ExpressionSpaceFunctions1| |ExpressionSpaceFunctions2| |FortranExpression| |InnerAlgebraicNumber|)
 (|ExtensibleLinearAggregate&| |FlexibleArray| |IndexedFlexibleArray|)
-(|ExtensionField&|)
-(|AlgebraGivenByStructuralConstants| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicManipulations| |BoundIntegerRoots| |CliffordAlgebra| |ComplexRootFindingPackage| |ComplexRootPackage| |ContinuedFraction| |CoordinateSystems| |DenavitHartenbergMatrix| |DoubleResultantPackage| |EllipticFunctionsUnivariateTaylorSeries| |ExponentialOfUnivariatePuiseuxSeries| |ExtensionField| |ExtensionField&| |Field&| |FindOrderFinite| |FiniteAlgebraicExtensionField| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteDivisorCategory| |FiniteDivisorCategory&| |FiniteDivisorFunctions2| |FloatingComplexPackage| |FloatingRealPackage| |FormalFraction| |FullPartialFractionExpansion| |FunctionSpaceToUnivariatePowerSeries| |GaloisGroupFactorizationUtilities| |GosperSummationMethod| |HyperellipticFiniteDivisor| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InnerAlgFactor| |InnerMatrixLinearAlgebraFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |IntegrationResult| |IntegrationResultFunctions2| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperatorsOps| |LinearSystemMatrixPackage| |LinearSystemMatrixPackage1| |MachineFloat| |ModularField| |MoebiusTransform| |MonomialExtensionTools| |NonCommutativeOperatorDivision| |NumericComplexEigenPackage| |NumericRealEigenPackage| |ODETools| |PadeApproximantPackage| |PadeApproximants| |PartialFraction| |Pi| |PolynomialCategoryQuotientFunctions| |PolynomialDecomposition| |PolynomialIdeals| |PolynomialInterpolation| |PolynomialInterpolationAlgorithms| |PolynomialRoots| |PolynomialSolveByFormulas| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |PseudoLinearNormalForm| |PureAlgebraicLODE| |QuadraticForm| |RationalIntegration| |RationalLODE| |RationalRicDE| |RealClosure| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory| |RealRootCharacterizationCategory&| |ReduceLODE| |ReducedDivisor| |ReductionOfOrder| |ResidueRing| |RightOpenIntervalRootCharacterization| |SAERationalFunctionAlgFactor| |SimpleAlgebraicExtensionAlgFactor| |StructuralConstantsPackage| |SystemODESolver| |TangentExpansions| |TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalRischDE| |TranscendentalRischDESystem| |VectorSpace| |VectorSpace&| |WeierstrassPreparation|)
+(|ExtensionField&| |PseudoAlgebraicClosureOfFiniteField|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffineSpace| |AffineSpaceCategory| |AlgebraGivenByStructuralConstants| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicManipulations| |BlowUpPackage| |BoundIntegerRoots| |CliffordAlgebra| |ComplexRootFindingPackage| |ComplexRootPackage| |ContinuedFraction| |CoordinateSystems| |DenavitHartenbergMatrix| |DesingTreePackage| |DoubleResultantPackage| |EllipticFunctionsUnivariateTaylorSeries| |ExponentialOfUnivariatePuiseuxSeries| |ExtensionField| |ExtensionField&| |Field&| |FindOrderFinite| |FiniteAlgebraicExtensionField| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteDivisorCategory| |FiniteDivisorCategory&| |FiniteDivisorFunctions2| |FloatingComplexPackage| |FloatingRealPackage| |FullPartialFractionExpansion| |FunctionSpaceToUnivariatePowerSeries| |GaloisGroupFactorizationUtilities| |GeneralPackageForAlgebraicFunctionField| |GosperSummationMethod| |Guess| |HyperellipticFiniteDivisor| |InfClsPt| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InfinitlyClosePoint| |InfinitlyClosePointCategory| |InnerAlgFactor| |InnerMatrixLinearAlgebraFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |IntegrationResult| |IntegrationResultFunctions2| |InterfaceGroebnerPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperatorsOps| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemMatrixPackage1| |LinesOpPack| |LocalParametrizationOfSimplePointPackage| |LocalPowerSeriesCategory| |MachineFloat| |ModularField| |MoebiusTransform| |MonomialExtensionTools| |NeitherSparseOrDensePowerSeries| |NonCommutativeOperatorDivision| |NumericComplexEigenPackage| |NumericRealEigenPackage| |ODETools| |PackageForAlgebraicFunctionField| |PadeApproximantPackage| |PadeApproximants| |ParametrizationPackage| |PartialFraction| |Pi| |Places| |PlacesCategory| |Plcs| |PolynomialCategoryQuotientFunctions| |PolynomialDecomposition| |PolynomialIdeals| |PolynomialInterpolation| |PolynomialInterpolationAlgorithms| |PolynomialPackageForCurve| |PolynomialRoots| |PolynomialSolveByFormulas| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectiveSpace| |ProjectiveSpaceCategory| |PseudoLinearNormalForm| |PureAlgebraicLODE| |QuadraticForm| |RationalIntegration| |RationalInterpolation| |RationalLODE| |RationalRicDE| |RealClosure| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory| |RealRootCharacterizationCategory&| |ReduceLODE| |ReducedDivisor| |ReductionOfOrder| |ResidueRing| |RightOpenIntervalRootCharacterization| |RootsFindingPackage| |SAERationalFunctionAlgFactor| |SimpleAlgebraicExtensionAlgFactor| |StructuralConstantsPackage| |SystemODESolver| |TangentExpansions| |TaylorSolve| |TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalRischDE| |TranscendentalRischDESystem| |VectorSpace| |VectorSpace&| |WeierstrassPreparation|)
 (|FieldOfPrimeCharacteristic&| |FiniteFieldPolynomialPackage2|)
 (|BinaryFile| |File| |FortranTemplate| |KeyedAccessFile| |TextFile|)
 (|BinaryFile| |File| |FortranTemplate| |KeyedAccessFile| |TextFile|)
 (|FileName|)
 (|Boolean| |DiscreteLogarithmPackage| |FindOrderFinite| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |IntegerMod| |ReducedDivisor| |SetOfMIntegersInOneToN|)
-(|FiniteAbelianMonoidRing&| |PolynomialRing| |SymmetricPolynomial| |UnivariatePuiseuxSeriesWithExponentialSingularity|)
+(|BlowUpPackage| |FiniteAbelianMonoidRing&| |FiniteAbelianMonoidRingFunctions2| |FractionFreeFastGaussianFractions| |NewtonPolygon| |PackageForPoly| |PolynomialPackageForCurve| |PolynomialRing| |SymmetricPolynomial| |UnivariatePuiseuxSeriesWithExponentialSingularity|)
 (|FiniteAlgebraicExtensionField&| |FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |InnerFiniteField| |InnerPrimeField| |NormRetractPackage| |PrimeField|)
 (|FiniteDivisor| |FiniteDivisorCategory&| |HyperellipticFiniteDivisor|)
-(|ChineseRemainderToolsForIntegralBases| |DistinctDegreeFactorize| |FiniteFieldCategory&| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSolveLinearPolynomialEquation| |InnerNormalBasisFieldFunctions| |InnerPrimeField| |IrredPolyOverFiniteField| |MultFiniteFactorize| |NormRetractPackage| |PAdicWildFunctionFieldIntegralBasis| |PrimeField| |TwoFactorize| |WildFunctionFieldIntegralBasis|)
+(|AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |ChineseRemainderToolsForIntegralBases| |DistinctDegreeFactorize| |FiniteFieldCategory&| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |GuessFinite| |GuessFiniteFunctions| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerNormalBasisFieldFunctions| |InnerPrimeField| |IrredPolyOverFiniteField| |MultFiniteFactorize| |NormRetractPackage| |NottinghamGroup| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionFieldOverFiniteField| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PrimeField| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfFiniteField| |TwoFactorize| |WildFunctionFieldIntegralBasis|)
 (|BezoutMatrix| |CommonDenominator| |FiniteLinearAggregate&| |FiniteLinearAggregateFunctions2| |FiniteLinearAggregateSort| |InnerCommonDenominator| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerMatrixQuotientFieldFunctions| |LinearSystemMatrixPackage| |MatrixCategory| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |MultiVariableCalculusFunctions| |SmithNormalForm| |TriangularMatrixOperations| |TwoDimensionalArrayCategory| |TwoDimensionalArrayCategory&|)
 (|FiniteRankAlgebra&|)
 (|FiniteRankNonAssociativeAlgebra&|)
@@ -77,7 +85,7 @@
 (|FortranProgram|)
 (|Asp8|)
 (|Asp10| |Asp19| |Asp31| |Asp35| |Asp41| |Asp42| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp78|)
-(|AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicNumber| |BoundIntegerRoots| |ChangeOfVariable| |ContinuedFraction| |DoubleResultantPackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |EvaluateCycleIndicators| |FindOrderFinite| |FiniteDivisor| |FiniteDivisorCategory| |FiniteDivisorCategory&| |FiniteDivisorFunctions2| |FormalFraction| |FourierSeries| |FullPartialFractionExpansion| |FunctionFieldCategory| |FunctionFieldCategory&| |FunctionFieldCategoryFunctions2| |GenericNonAssociativeAlgebra| |GosperSummationMethod| |HyperellipticFiniteDivisor| |InnerAlgebraicNumber| |IntegrationResult| |Kovacic| |LaurentPolynomial| |LieExponentials| |LinearOrdinaryDifferentialOperatorFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineFloat| |MultipleMap| |Pi| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |PrimitiveRatDE| |PrimitiveRatRicDE| |PureAlgebraicLODE| |RadicalFunctionField| |RationalFactorize| |RationalFunctionFactor| |RationalLODE| |RationalRetractions| |RationalRicDE| |RealZeroPackageQ| |ReducedDivisor| |SAERationalFunctionAlgFactor| |SimpleAlgebraicExtensionAlgFactor| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |UnivariateTaylorSeriesODESolver| |XExponentialPackage|)
+(|AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicNumber| |BoundIntegerRoots| |ChangeOfVariable| |ContinuedFraction| |DoubleResultantPackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |EvaluateCycleIndicators| |FindOrderFinite| |FiniteDivisor| |FiniteDivisorCategory| |FiniteDivisorCategory&| |FiniteDivisorFunctions2| |FourierSeries| |FractionFreeFastGaussianFractions| |FullPartialFractionExpansion| |FunctionFieldCategory| |FunctionFieldCategory&| |FunctionFieldCategoryFunctions2| |GenericNonAssociativeAlgebra| |GosperSummationMethod| |HyperellipticFiniteDivisor| |InnerAlgebraicNumber| |IntegrationResult| |Kovacic| |LaurentPolynomial| |LieExponentials| |LinearOrdinaryDifferentialOperatorFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineFloat| |MultipleMap| |Pi| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |PrimitiveRatDE| |PrimitiveRatRicDE| |PureAlgebraicLODE| |RadicalFunctionField| |RationalFactorize| |RationalFunctionFactor| |RationalLODE| |RationalRetractions| |RationalRicDE| |RealZeroPackageQ| |ReducedDivisor| |SAERationalFunctionAlgFactor| |SimpleAlgebraicExtensionAlgFactor| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |UnivariateTaylorSeriesODESolver| |XExponentialPackage|)
 (|FractionalIdeal| |FractionalIdealFunctions2| |FramedAlgebra&| |FramedModule| |FunctionFieldIntegralBasis| |IntegralBasisTools| |NumberFieldIntegralBasis| |WildFunctionFieldIntegralBasis|)
 (|AlgebraGivenByStructuralConstants| |AlgebraPackage| |FramedNonAssociativeAlgebra&| |FramedNonAssociativeAlgebraFunctions2| |GenericNonAssociativeAlgebra| |LieSquareMatrix|)
 (|FreeAbelianGroup| |FreeAbelianMonoid| |InnerFreeAbelianMonoid|)
@@ -87,44 +95,44 @@
 (|FullyLinearlyExplicitRingOver&|)
 (|Factored| |FullyRetractableTo&| |LaurentPolynomial| |Octonion| |OnePointCompletion| |OrderedCompletion| |RealClosure|)
 (|AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |DoubleResultantPackage| |FindOrderFinite| |FiniteDivisor| |FiniteDivisorCategory| |FiniteDivisorCategory&| |FiniteDivisorFunctions2| |FunctionFieldCategory&| |FunctionFieldCategoryFunctions2| |HyperellipticFiniteDivisor| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PureAlgebraicLODE| |RadicalFunctionField| |ReducedDivisor|)
-(|AlgebraicFunction| |AlgebraicIntegrate| |AlgebraicIntegration| |ApplyRules| |CombinatorialFunction| |ComplexTrigonometricManipulations| |ElementaryFunction| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |ExponentialExpansion| |Expression| |ExpressionSpaceODESolver| |ExpressionToUnivariatePowerSeries| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceFunctions2| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GenerateUnivariatePowerSeries| |GenusZeroIntegration| |InnerTrigonometricManipulations| |IntegrationTools| |LiouvillianFunction| |PatternMatchFunctionSpace| |PatternMatchIntegration| |PointsOfFiniteOrder| |PowerSeriesLimitPackage| |PureAlgebraicIntegration| |RewriteRule| |Ruleset| |SimpleFortranProgram| |TopLevelDrawFunctionsForAlgebraicCurves| |TranscendentalManipulations| |TrigonometricManipulations| |UnivariatePuiseuxSeriesWithExponentialSingularity|)
-(|BalancedFactorisation| |DefiniteIntegrationTools| |EigenPackage| |ElementaryFunctionSign| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |ExponentialExpansion| |ExpressionToUnivariatePowerSeries| |FGLMIfCanPackage| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |GcdDomain&| |GenusZeroIntegration| |GroebnerInternalPackage| |GroebnerPackage| |GroebnerSolve| |InnerNumericFloatSolvePackage| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |LazardSetSolvingPackage| |LexTriangularPackage| |LinGroebnerPackage| |NormInMonogenicAlgebra| |NormalizationPackage| |NormalizedTriangularSetCategory| |PatternMatchIntegration| |PolyGroebner| |PolynomialSquareFree| |PowerSeriesLimitPackage| |PureAlgebraicIntegration| |QuasiAlgebraicSet| |QuasiComponentPackage| |RationalFunctionLimitPackage| |RationalFunctionSign| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |SquareFreeNormalizedTriangularSetCategory| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetCategory| |SquareFreeRegularTriangularSetGcdPackage| |SupFractionFactorizer| |TranscendentalManipulations| |TrigonometricManipulations| |UnivariatePuiseuxSeriesWithExponentialSingularity|)
+(|AlgebraicFunction| |AlgebraicIntegrate| |AlgebraicIntegration| |ApplyRules| |CombinatorialFunction| |ComplexTrigonometricManipulations| |ElementaryFunction| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |ExponentialExpansion| |Expression| |ExpressionSolve| |ExpressionSpaceODESolver| |ExpressionToUnivariatePowerSeries| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceFunctions2| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GenerateUnivariatePowerSeries| |GenusZeroIntegration| |Guess| |InnerTrigonometricManipulations| |IntegrationTools| |LiouvillianFunction| |MyExpression| |PatternMatchFunctionSpace| |PatternMatchIntegration| |PointsOfFiniteOrder| |PowerSeriesLimitPackage| |PureAlgebraicIntegration| |RecurrenceOperator| |RewriteRule| |Ruleset| |SimpleFortranProgram| |TopLevelDrawFunctionsForAlgebraicCurves| |TranscendentalManipulations| |TrigonometricManipulations| |UnivariatePuiseuxSeriesWithExponentialSingularity|)
+(|BalancedFactorisation| |DefiniteIntegrationTools| |EigenPackage| |ElementaryFunctionSign| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |ExponentialExpansion| |ExpressionToUnivariatePowerSeries| |FGLMIfCanPackage| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |GcdDomain&| |GenusZeroIntegration| |GroebnerInternalPackage| |GroebnerPackage| |GroebnerSolve| |Guess| |InnerNumericFloatSolvePackage| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |LazardSetSolvingPackage| |LexTriangularPackage| |LinGroebnerPackage| |NormInMonogenicAlgebra| |NormalizationPackage| |NormalizedTriangularSetCategory| |PatternMatchIntegration| |PolyGroebner| |PolynomialSquareFree| |PowerSeriesLimitPackage| |PureAlgebraicIntegration| |QuasiAlgebraicSet| |QuasiComponentPackage| |RationalFunctionLimitPackage| |RationalFunctionSign| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |SquareFreeNormalizedTriangularSetCategory| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetCategory| |SquareFreeRegularTriangularSetGcdPackage| |SupFractionFactorizer| |TranscendentalManipulations| |TrigonometricManipulations| |UnivariatePuiseuxSeriesWithExponentialSingularity|)
 (|CartesianTensor| |GradedAlgebra&|)
 (|CartesianTensor| |GradedModule&|)
-(|Automorphism| |FractionalIdeal| |FreeGroup| |Group&| |LieExponentials| |MoebiusTransform|)
+(|Automorphism| |FractionalIdeal| |FreeGroup| |Group&| |LieExponentials| |MoebiusTransform| |NottinghamGroup|)
 (|HomogeneousAggregate&| |ThreeDimensionalMatrix|)
 (|HomogeneousDistributedMultivariatePolynomial|)
 (|HyperbolicFunctionCategory&|)
-(|IVBaseColor| |IVCoordinate3| |IVCoordinate4| |IVFaceSet| |IVIndexedLineSet| |IVPointSet| |IVQuadMesh|)
-(|IVBasicNode| |IVGroup| |IVNodeObject| |IVSeparator|)
 (|IndexedAggregate&| |SortPackage|)
 (|FreeModule| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents|)
 (|DifferentialSparseMultivariatePolynomial| |MultivariatePolynomial| |NewSparseMultivariatePolynomial| |OrderlyDifferentialPolynomial| |Polynomial| |RegularChain| |SequentialDifferentialPolynomial| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries|)
 (|IndexedTwoDimensionalArray|)
 (|IndexedMatrix|)
+(|DesingTreePackage| |GeneralPackageForAlgebraicFunctionField| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |IntersectionDivisorPackage|)
 (|InnerEvalable&|)
 (|InnerFiniteField|)
-(|Boolean| |DoubleFloat| |ExpressionSpaceODESolver| |Float| |MakeBinaryCompiledFunction| |MakeFloatCompiledFunction| |MakeFunction| |MakeUnaryCompiledFunction| |OrderedVariableList| |Pi| |PlotFunctions1| |Symbol| |TopLevelDrawFunctions|)
-(|AlgebraicIntegrate| |AlgebraicNumber| |BalancedPAdicInteger| |BalancedPAdicRational| |BinaryExpansion| |BoundIntegerRoots| |BrillhartTests| |CartesianTensor| |CartesianTensorFunctions2| |ComplexRootPackage| |ComplexTrigonometricManipulations| |ConstantLODE| |DecimalExpansion| |DefiniteIntegrationTools| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EvaluateCycleIndicators| |ExponentialExpansion| |ExpressionToUnivariatePowerSeries| |FourierSeries| |FreeAbelianGroup| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizer| |GenerateUnivariatePowerSeries| |GenusZeroIntegration| |GosperSummationMethod| |HeuGcd| |HexadecimalExpansion| |IndexedBits| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InnerAlgebraicNumber| |InnerIndexedTwoDimensionalArray| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InputForm| |IntegerLinearDependence| |IntegerMod| |IntegerRetractions| |IntegrationResult| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |InverseLaplaceTransform| |Kovacic| |LaplaceTransform| |LieExponentials| |LinearOrdinaryDifferentialOperatorFactorizer| |MachineFloat| |ModularDistinctDegreeFactorizer| |NonLinearFirstOrderODESolver| |NumberFieldIntegralBasis| |ODEIntegration| |OrderedVariableList| |PAdicInteger| |PAdicIntegerCategory| |PAdicRational| |PAdicRationalConstructor| |Partition| |PatternMatchIntegration| |Pi| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveRatDE| |PrimitiveRatRicDE| |PureAlgebraicIntegration| |PureAlgebraicLODE| |RadixExpansion| |RationalFactorize| |RationalFunctionDefiniteIntegration| |RationalFunctionFactor| |RationalFunctionIntegration| |RationalFunctionSum| |RationalIntegration| |RationalLODE| |RationalRetractions| |RationalRicDE| |RealZeroPackage| |RealZeroPackageQ| |SAERationalFunctionAlgFactor| |SExpression| |SimpleAlgebraicExtensionAlgFactor| |SortPackage| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |Symbol| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |TranscendentalRischDE| |TranscendentalRischDESystem| |TrigonometricManipulations| |UnivariateFactorize| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateTaylorSeriesODESolver| |XExponentialPackage|)
+(|Boolean| |DoubleFloat| |ExpressionSolve| |ExpressionSpaceODESolver| |Float| |MakeBinaryCompiledFunction| |MakeFloatCompiledFunction| |MakeFunction| |MakeUnaryCompiledFunction| |OrderedVariableList| |Pi| |PlotFunctions1| |RecurrenceOperator| |Symbol| |TopLevelDrawFunctions|)
+(|AlgebraicIntegrate| |AlgebraicNumber| |BalancedPAdicInteger| |BalancedPAdicRational| |BinaryExpansion| |BoundIntegerRoots| |BrillhartTests| |CartesianTensor| |CartesianTensorFunctions2| |ComplexRootPackage| |ComplexTrigonometricManipulations| |ConstantLODE| |DecimalExpansion| |DefiniteIntegrationTools| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EvaluateCycleIndicators| |ExponentialExpansion| |ExpressionToUnivariatePowerSeries| |FourierSeries| |FreeAbelianGroup| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizer| |GenerateUnivariatePowerSeries| |GenusZeroIntegration| |GosperSummationMethod| |Guess| |GuessFinite| |GuessFiniteFunctions| |HeuGcd| |HexadecimalExpansion| |IndexedBits| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InnerAlgebraicNumber| |InnerIndexedTwoDimensionalArray| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InputForm| |IntegerLinearDependence| |IntegerMod| |IntegerRetractions| |IntegrationResult| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |InverseLaplaceTransform| |Kovacic| |LaplaceTransform| |LieExponentials| |LinearOrdinaryDifferentialOperatorFactorizer| |MachineFloat| |ModularDistinctDegreeFactorizer| |MyExpression| |NeitherSparseOrDensePowerSeries| |NonLinearFirstOrderODESolver| |NumberFieldIntegralBasis| |ODEIntegration| |OrderedVariableList| |PAdicInteger| |PAdicIntegerCategory| |PAdicRational| |PAdicRationalConstructor| |Partition| |PatternMatchIntegration| |Pi| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveRatDE| |PrimitiveRatRicDE| |PureAlgebraicIntegration| |PureAlgebraicLODE| |RadixExpansion| |RationalFactorize| |RationalFunctionDefiniteIntegration| |RationalFunctionFactor| |RationalFunctionIntegration| |RationalFunctionSum| |RationalIntegration| |RationalLODE| |RationalRetractions| |RationalRicDE| |RealZeroPackage| |RealZeroPackageQ| |RecurrenceOperator| |SAERationalFunctionAlgFactor| |SExpression| |SimpleAlgebraicExtensionAlgFactor| |SortPackage| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |Symbol| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |TranscendentalRischDE| |TranscendentalRischDESystem| |TrigonometricManipulations| |UnivariateFactorize| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateTaylorSeriesODESolver| |XExponentialPackage|)
 (|ComplexIntegerSolveLinearPolynomialEquation| |Integer| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerNumberSystem&| |IntegerPrimesPackage| |IntegerRoots| |MachineInteger| |PatternMatchIntegerNumberSystem| |RomanNumeral| |SingleInteger|)
-(|AlgebraPackage| |AlgebraicFunction| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicallyClosedFunctionSpace| |AlgebraicallyClosedFunctionSpace&| |AssociatedEquations| |CombinatorialFunction| |CommonDenominator| |ComplexTrigonometricManipulations| |DegreeReductionPackage| |DrawNumericHack| |ElementaryFunction| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ExpressionSpaceODESolver| |Factored| |FactoredFunctionUtilities| |FactoredFunctions| |FactoredFunctions2| |FormalFraction| |Fraction| |FractionFunctions2| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GeneralTriangularSet| |GeneralizedMultivariateFactorize| |GenerateUnivariatePowerSeries| |GosperSummationMethod| |InfiniteProductCharacteristicZero| |InnerCommonDenominator| |InnerMatrixQuotientFieldFunctions| |InnerPolySum| |InnerTrigonometricManipulations| |IntegralDomain&| |LaurentPolynomial| |LinearDependence| |LinearSystemPolynomialPackage| |LiouvillianFunction| |MPolyCatRationalFunctionFactorizer| |MatrixCommonDenominator| |MultipleMap| |NonLinearSolvePackage| |PatternMatchFunctionSpace| |PatternMatchQuotientFieldCategory| |PiCoercions| |PointsOfFiniteOrder| |PolynomialRoots| |PolynomialSetUtilitiesPackage| |PrecomputedAssociatedEquations| |PseudoRemainderSequence| |QuotientFieldCategory| |QuotientFieldCategory&| |QuotientFieldCategoryFunctions2| |RationalFunction| |RationalFunctionIntegration| |RationalFunctionSum| |RetractSolvePackage| |StreamInfiniteProduct| |SubResultantPackage| |SystemSolvePackage| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackageService| |TriangularMatrixOperations| |TriangularSetCategory| |TriangularSetCategory&| |UnivariatePolynomialCommonDenominator| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeriesWithExponentialSingularity| |WuWenTsunTriangularSet|)
+(|AlgebraPackage| |AlgebraicFunction| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicallyClosedFunctionSpace| |AlgebraicallyClosedFunctionSpace&| |AssociatedEquations| |CombinatorialFunction| |CommonDenominator| |ComplexTrigonometricManipulations| |DegreeReductionPackage| |DrawNumericHack| |ElementaryFunction| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ExpressionSolve| |ExpressionSpaceODESolver| |Factored| |FactoredFunctionUtilities| |FactoredFunctions| |FactoredFunctions2| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionFunctions2| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GeneralTriangularSet| |GeneralizedMultivariateFactorize| |GenerateUnivariatePowerSeries| |GosperSummationMethod| |Guess| |InfiniteProductCharacteristicZero| |InnerCommonDenominator| |InnerMatrixQuotientFieldFunctions| |InnerPolySum| |InnerTrigonometricManipulations| |IntegralDomain&| |LaurentPolynomial| |LinearDependence| |LinearSystemPolynomialPackage| |LiouvillianFunction| |MPolyCatRationalFunctionFactorizer| |MatrixCommonDenominator| |MultipleMap| |MyExpression| |NewtonInterpolation| |NonLinearSolvePackage| |PatternMatchFunctionSpace| |PatternMatchQuotientFieldCategory| |PiCoercions| |PointsOfFiniteOrder| |PolynomialRoots| |PolynomialSetUtilitiesPackage| |PrecomputedAssociatedEquations| |PseudoRemainderSequence| |QuotientFieldCategory| |QuotientFieldCategory&| |QuotientFieldCategoryFunctions2| |RationalFunction| |RationalFunctionIntegration| |RationalFunctionSum| |RecurrenceOperator| |RetractSolvePackage| |StreamInfiniteProduct| |SubResultantPackage| |SystemSolvePackage| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackageService| |TriangularMatrixOperations| |TriangularSetCategory| |TriangularSetCategory&| |UnivariatePolynomialCommonDenominator| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeriesWithExponentialSingularity| |WuWenTsunTriangularSet|)
 (|Interval|)
 (|PatternMatchFunctionSpace| |PatternMatchKernel|)
 (|KeyedDictionary&|)
-(|CyclicStreamTools| |LazyStreamAggregate&| |Stream|)
+(|CyclicStreamTools| |LazyStreamAggregate&| |NeitherSparseOrDensePowerSeries| |Stream|)
 (|AntiSymm| |DeRhamComplex| |LeftAlgebra&|)
 (|AlgebraGivenByStructuralConstants| |ApplyUnivariateSkewPolynomial| |DirectProductMatrixModule| |DirectProductModule| |GenericNonAssociativeAlgebra| |LinearOrdinaryDifferentialOperator2| |ModuleOperator|)
 (|LieAlgebra&|)
-(|LinearAggregate&| |PackedHermitianSequence|)
+(|LinearAggregate&|)
 (|AssociatedEquations| |ConstantLODE| |ElementaryFunctionLODESolver| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorCategory&| |LinearOrdinaryDifferentialOperatorsOps| |ODETools| |PrecomputedAssociatedEquations| |PrimitiveRatDE| |PrimitiveRatRicDE| |ReduceLODE| |ReductionOfOrder| |SystemODESolver| |UTSodetools|)
 (|AlgebraicNumber| |ConstantLODE| |DefiniteIntegrationTools| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |ExponentialExpansion| |ExpressionToUnivariatePowerSeries| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenusZeroIntegration| |InnerAlgebraicNumber| |IntegerLinearDependence| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |InverseLaplaceTransform| |LaplaceTransform| |LinearDependence| |NonLinearFirstOrderODESolver| |ODEIntegration| |PatternMatchIntegration| |PowerSeriesLimitPackage| |PureAlgebraicIntegration| |RationalFunctionDefiniteIntegration| |TransSolvePackage| |TrigonometricManipulations| |UnivariatePuiseuxSeriesWithExponentialSingularity|)
-(|AlgebraGivenByStructuralConstants| |AntiSymm| |CharacterClass| |DeRhamComplex| |DistributedMultivariatePolynomial| |FGLMIfCanPackage| |FiniteFieldNormalBasisExtensionByPolynomial| |FortranExpression| |FortranProgram| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GenericNonAssociativeAlgebra| |GroebnerSolve| |HomogeneousDistributedMultivariatePolynomial| |IdealDecompositionPackage| |LexTriangularPackage| |LinGroebnerPackage| |MultivariatePolynomial| |OrderedVariableList| |OrdinaryWeightedPolynomials| |Partition| |PolToPol| |QuasiAlgebraicSet2| |RationalUnivariateRepresentationPackage| |RegularChain| |ResidueRing| |WeightedPolynomials| |ZeroDimensionalSolvePackage|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AlgebraGivenByStructuralConstants| |AntiSymm| |BlowUpPackage| |CharacterClass| |DeRhamComplex| |DesingTreePackage| |DistributedMultivariatePolynomial| |FGLMIfCanPackage| |FiniteFieldNormalBasisExtensionByPolynomial| |FortranExpression| |FortranProgram| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GenericNonAssociativeAlgebra| |GroebnerSolve| |HomogeneousDistributedMultivariatePolynomial| |IdealDecompositionPackage| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointCategory| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InterfaceGroebnerPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |LexTriangularPackage| |LinGroebnerPackage| |LocalParametrizationOfSimplePointPackage| |MultivariatePolynomial| |OrderedVariableList| |OrdinaryWeightedPolynomials| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |ParametrizationPackage| |Partition| |PolToPol| |ProjectiveAlgebraicSetPackage| |QuasiAlgebraicSet2| |RationalUnivariateRepresentationPackage| |RegularChain| |ResidueRing| |WeightedPolynomials| |ZeroDimensionalSolvePackage|)
 (|DataList| |IndexedList| |List| |ListAggregate&| |PatternMatchListAggregate| |PatternMatchListResult|)
+(|DesingTreePackage| |GeneralPackageForAlgebraicFunctionField| |InfinitlyClosePoint| |InfinitlyClosePointCategory| |InterpolateFormsPackage| |IntersectionDivisorPackage| |LinearSystemFromPowerSeriesPackage| |LocalParametrizationOfSimplePointPackage| |NeitherSparseOrDensePowerSeries| |ParametrizationPackage| |PlacesCategory| |Plcs|)
 (|Boolean| |Logic&| |SingleInteger|)
 (|LiePolynomial| |PoincareBirkhoffWittLyndonBasis|)
 (|MachineComplex|)
 (|AlgebraGivenByStructuralConstants| |GenericNonAssociativeAlgebra| |LieSquareMatrix| |RectangularMatrix| |SquareMatrix|)
-(|BezoutMatrix| |DenavitHartenbergMatrix| |IndexedMatrix| |InnerMatrixLinearAlgebraFunctions| |InnerMatrixQuotientFieldFunctions| |LinearSystemMatrixPackage| |Matrix| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |SmithNormalForm| |TriangularMatrixOperations|)
+(|BezoutMatrix| |ComplexDoubleFloatMatrix| |DenavitHartenbergMatrix| |DoubleFloatMatrix| |IndexedMatrix| |InnerMatrixLinearAlgebraFunctions| |InnerMatrixQuotientFieldFunctions| |LinearSystemMatrixPackage| |Matrix| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |SmithNormalForm| |TriangularMatrixOperations|)
 (|FreeAbelianGroup| |GeneralModulePolynomial| |IntegrationResult| |LieExponentials| |Localize| |Module&| |XExponentialPackage|)
 (|Monad&|)
 (|MonadWithUnit&|)
@@ -134,54 +142,67 @@
 (|ListMultiDictionary|)
 (|Multiset|)
 (|SparseMultivariateTaylorSeries| |TaylorSeries|)
+(|MyExpression|)
+(|InfClsPt| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField|)
 (|RegularChain|)
 (|AssociatedJordanAlgebra| |AssociatedLieAlgebra| |FreeNilpotentLie| |NonAssociativeAlgebra&|)
 (|NonAssociativeRing&|)
 (|NonAssociativeRng&|)
-(|CardinalNumber| |CartesianTensor| |CartesianTensorFunctions2| |DirectProduct| |DirectProductCategory| |DirectProductCategory&| |DirectProductFunctions2| |DirectProductModule| |DistributedMultivariatePolynomial| |FreeAbelianMonoid| |FreeNilpotentLie| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |IdealDecompositionPackage| |IndexedExponents| |InnerModularGcd| |OrderedDirectProduct| |OrderingFunctions| |OrdinaryWeightedPolynomials| |QuasiAlgebraicSet2| |RadicalFunctionField| |RectangularMatrix| |RectangularMatrixCategory| |RectangularMatrixCategory&| |RectangularMatrixCategoryFunctions2| |SplitHomogeneousDirectProduct| |SquareMatrix| |SquareMatrixCategory| |SquareMatrixCategory&| |WeightedPolynomials|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffineSpace| |BlowUpPackage| |CardinalNumber| |CartesianTensor| |CartesianTensorFunctions2| |DesingTreePackage| |DirectProduct| |DirectProductCategory| |DirectProductCategory&| |DirectProductFunctions2| |DirectProductModule| |DistributedMultivariatePolynomial| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FreeAbelianMonoid| |FreeNilpotentLie| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |IdealDecompositionPackage| |IndexedExponents| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointCategory| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerModularGcd| |InterpolateFormsPackage| |IntersectionDivisorPackage| |LocalParametrizationOfSimplePointPackage| |NewtonPolygon| |OrderedDirectProduct| |OrderingFunctions| |OrdinaryWeightedPolynomials| |PackageForPoly| |ParametrizationPackage| |PolynomialPackageForCurve| |ProjectiveAlgebraicSetPackage| |ProjectiveSpace| |QuasiAlgebraicSet2| |RadicalFunctionField| |RectangularMatrix| |RectangularMatrixCategory| |RectangularMatrixCategory&| |RectangularMatrixCategoryFunctions2| |SplitHomogeneousDirectProduct| |SquareMatrix| |SquareMatrixCategory| |SquareMatrixCategory&| |WeightedPolynomials|)
 (|d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType|)
 (|e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|Octonion| |OctonionCategory&| |OctonionCategoryFunctions2|)
 (|TwoDimensionalArray|)
 (|FlexibleArray| |IndexedFlexibleArray| |IndexedOneDimensionalArray| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |PrimitiveArray|)
 (|DoubleFloat| |ExpressionToOpenMath| |Float| |Integer| |SingleInteger| |Symbol|)
-(|AbelianMonoidRing| |AbelianMonoidRing&| |ExponentialOfUnivariatePuiseuxSeries| |FiniteAbelianMonoidRing| |FiniteAbelianMonoidRing&| |IndexedDirectProductOrderedAbelianMonoid| |OrderingFunctions| |PolynomialRing| |PowerSeriesCategory| |PowerSeriesCategory&| |UnivariatePowerSeriesCategory| |UnivariatePowerSeriesCategory&|)
-(|AlgebraicMultFact| |DifferentialPolynomialCategory| |DifferentialPolynomialCategory&| |EuclideanGroebnerBasisPackage| |FactoringUtilities| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralTriangularSet| |GeneralizedMultivariateFactorize| |GosperSummationMethod| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |HomogeneousDirectProduct| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |InnerMultFact| |InnerPolySum| |InternalRationalUnivariateRepresentationPackage| |LazardSetSolvingPackage| |LeadingCoefDetermination| |LinearSystemPolynomialPackage| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MultFiniteFactorize| |MultivariateFactorize| |MultivariateLifting| |MultivariateSquareFree| |NPCoef| |NonNegativeInteger| |NormalizationPackage| |NormalizedTriangularSetCategory| |OrderedDirectProduct| |ParametricLinearEquations| |PatternMatchPolynomialCategory| |PolynomialCategory| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialFactorizationByRecursion| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialRoots| |PolynomialSetCategory| |PolynomialSetCategory&| |PolynomialSetUtilitiesPackage| |PolynomialSquareFree| |PushVariables| |QuasiAlgebraicSet| |QuasiComponentPackage| |RecursivePolynomialCategory| |RecursivePolynomialCategory&| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |ResidueRing| |SplitHomogeneousDirectProduct| |SquareFreeNormalizedTriangularSetCategory| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetCategory| |SquareFreeRegularTriangularSetGcdPackage| |SupFractionFactorizer| |TriangularSetCategory| |TriangularSetCategory&| |WeightedPolynomials| |WuWenTsunTriangularSet|)
+(|AbelianMonoidRing| |AbelianMonoidRing&| |ExponentialOfUnivariatePuiseuxSeries| |FiniteAbelianMonoidRing| |FiniteAbelianMonoidRing&| |FiniteAbelianMonoidRingFunctions2| |IndexedDirectProductOrderedAbelianMonoid| |OrderingFunctions| |PolynomialRing| |PowerSeriesCategory| |PowerSeriesCategory&| |UnivariatePowerSeriesCategory| |UnivariatePowerSeriesCategory&|)
+(|AlgebraicMultFact| |DifferentialPolynomialCategory| |DifferentialPolynomialCategory&| |EuclideanGroebnerBasisPackage| |FactoringUtilities| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralTriangularSet| |GeneralizedMultivariateFactorize| |GosperSummationMethod| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |HomogeneousDirectProduct| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |InnerMultFact| |InnerPolySum| |InterfaceGroebnerPackage| |InternalRationalUnivariateRepresentationPackage| |LazardSetSolvingPackage| |LeadingCoefDetermination| |LinearSystemPolynomialPackage| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MultFiniteFactorize| |MultivariateFactorize| |MultivariateLifting| |MultivariateSquareFree| |NPCoef| |NonNegativeInteger| |NormalizationPackage| |NormalizedTriangularSetCategory| |OrderedDirectProduct| |ParametricLinearEquations| |PatternMatchPolynomialCategory| |PolynomialCategory| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialFactorizationByRecursion| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialRoots| |PolynomialSetCategory| |PolynomialSetCategory&| |PolynomialSetUtilitiesPackage| |PolynomialSquareFree| |PushVariables| |QuasiAlgebraicSet| |QuasiComponentPackage| |RecursivePolynomialCategory| |RecursivePolynomialCategory&| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |ResidueRing| |SplitHomogeneousDirectProduct| |SquareFreeNormalizedTriangularSetCategory| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetCategory| |SquareFreeRegularTriangularSetGcdPackage| |SupFractionFactorizer| |TriangularSetCategory| |TriangularSetCategory&| |WeightedPolynomials| |WuWenTsunTriangularSet|)
 (|Partition|)
 (|Character| |OrderedVariableList|)
 (|XDistributedPolynomial|)
 (|SturmHabichtPackage|)
 (|OrderedFreeMonoid| |XPolynomialRing|)
 (|ComplexRootFindingPackage| |ComplexRootPackage| |ExpertSystemToolsPackage1| |FloatingComplexPackage| |FloatingRealPackage| |FunctionSpaceToUnivariatePowerSeries| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |NumericComplexEigenPackage| |NumericRealEigenPackage| |OrderedRing&| |RealClosure| |RealRootCharacterizationCategory| |RealRootCharacterizationCategory&| |RightOpenIntervalRootCharacterization| |SegmentExpansionCategory| |ZeroDimensionalSolvePackage|)
-(|AlgebraicFunction| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicMultFact| |AlgebraicallyClosedFunctionSpace| |AlgebraicallyClosedFunctionSpace&| |ApplyRules| |BasicOperator| |BinarySearchTree| |BinaryTournament| |Boolean| |CardinalNumber| |CombinatorialFunction| |ComplexTrigonometricManipulations| |ConstantLODE| |DataList| |Database| |DeRhamComplex| |DefiniteIntegrationTools| |DegreeReductionPackage| |DifferentialPolynomialCategory| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory| |DifferentialVariableCategory&| |DrawNumericHack| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EuclideanGroebnerBasisPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionFunctions2| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExtAlgBasis| |FactoringUtilities| |FourierComponent| |FourierSeries| |FreeLieAlgebra| |FreeModule| |FreeModule1| |FunctionSpace| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceFunctions2| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GeneralModulePolynomial| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralTriangularSet| |GeneralizedMultivariateFactorize| |GenerateUnivariatePowerSeries| |GenusZeroIntegration| |GosperSummationMethod| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |Heap| |IndexCard| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductCategory| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |InnerMultFact| |InnerPolySum| |InnerTrigonometricManipulations| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |InternalRationalUnivariateRepresentationPackage| |InverseLaplaceTransform| |Kernel| |KernelFunctions2| |LaplaceTransform| |LazardSetSolvingPackage| |LeadingCoefDetermination| |LieExponentials| |LiePolynomial| |LinearSystemPolynomialPackage| |LiouvillianFunction| |LyndonWord| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |Magma| |MergeThing| |ModuleMonomial| |MultFiniteFactorize| |MultivariateFactorize| |MultivariateLifting| |MultivariateSquareFree| |MultivariateTaylorSeriesCategory| |NPCoef| |NewSparseMultivariatePolynomial| |NonLinearFirstOrderODESolver| |NormalizationPackage| |NormalizedTriangularSetCategory| |ODEIntegration| |OrdSetInts| |OrderedFreeMonoid| |OrderedMultisetAggregate| |OrderedSet&| |OrderlyDifferentialVariable| |ParametricLinearEquations| |PatternMatchFunctionSpace| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchPolynomialCategory| |PatternMatchTools| |PiCoercions| |PoincareBirkhoffWittLyndonBasis| |PointsOfFiniteOrder| |PolynomialCategory| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialFactorizationByRecursion| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialRoots| |PolynomialSetCategory| |PolynomialSetCategory&| |PolynomialSetUtilitiesPackage| |PolynomialSquareFree| |PositiveInteger| |PowerSeriesCategory| |PowerSeriesCategory&| |PowerSeriesLimitPackage| |PriorityQueueAggregate| |PureAlgebraicIntegration| |PushVariables| |QuasiAlgebraicSet| |QuasiComponentPackage| |RadicalSolvePackage| |RationalFunctionDefiniteIntegration| |RationalFunctionSum| |RecursivePolynomialCategory| |RecursivePolynomialCategory&| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |ResidueRing| |RewriteRule| |Ruleset| |SequentialDifferentialVariable| |SimpleFortranProgram| |SingletonAsOrderedSet| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SquareFreeNormalizedTriangularSetCategory| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetCategory| |SquareFreeRegularTriangularSetGcdPackage| |SupFractionFactorizer| |Symbol| |TableauxBumpers| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |TransSolvePackageService| |TranscendentalManipulations| |TriangularSetCategory| |TriangularSetCategory&| |TrigonometricManipulations| |UnivariatePuiseuxSeriesWithExponentialSingularity| |WeightedPolynomials| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XExponentialPackage| |XFreeAlgebra| |XPBWPolynomial| |XPolynomialsCat| |XRecursivePolynomial|)
-(|DistributedMultivariatePolynomial| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |HomogeneousDistributedMultivariatePolynomial| |MultivariatePolynomial| |RegularChain|)
+(|AlgebraicFunction| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicMultFact| |AlgebraicallyClosedFunctionSpace| |AlgebraicallyClosedFunctionSpace&| |ApplyRules| |BasicOperator| |BinarySearchTree| |BinaryTournament| |Boolean| |CardinalNumber| |CombinatorialFunction| |ComplexTrigonometricManipulations| |ConstantLODE| |DataList| |Database| |DeRhamComplex| |DefiniteIntegrationTools| |DegreeReductionPackage| |DifferentialPolynomialCategory| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory| |DifferentialVariableCategory&| |DrawNumericHack| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EuclideanGroebnerBasisPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionFunctions2| |ExpressionSolve| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExtAlgBasis| |FactoringUtilities| |FourierComponent| |FourierSeries| |FreeLieAlgebra| |FreeModule| |FreeModule1| |FunctionSpace| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceFunctions2| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GeneralModulePolynomial| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralTriangularSet| |GeneralizedMultivariateFactorize| |GenerateUnivariatePowerSeries| |GenusZeroIntegration| |GosperSummationMethod| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |Guess| |Heap| |IndexCard| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductCategory| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |InnerMultFact| |InnerPolySum| |InnerTrigonometricManipulations| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |InterfaceGroebnerPackage| |InternalRationalUnivariateRepresentationPackage| |InverseLaplaceTransform| |Kernel| |KernelFunctions2| |LaplaceTransform| |LazardSetSolvingPackage| |LeadingCoefDetermination| |LieExponentials| |LiePolynomial| |LinearSystemPolynomialPackage| |LiouvillianFunction| |LyndonWord| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |Magma| |MergeThing| |ModuleMonomial| |MultFiniteFactorize| |MultivariateFactorize| |MultivariateLifting| |MultivariateSquareFree| |MultivariateTaylorSeriesCategory| |MyExpression| |NPCoef| |NewSparseMultivariatePolynomial| |NonLinearFirstOrderODESolver| |NormalizationPackage| |NormalizedTriangularSetCategory| |ODEIntegration| |OrdSetInts| |OrderedFreeMonoid| |OrderedMultisetAggregate| |OrderedSet&| |OrderlyDifferentialVariable| |ParametricLinearEquations| |PatternMatchFunctionSpace| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchPolynomialCategory| |PatternMatchTools| |PiCoercions| |PoincareBirkhoffWittLyndonBasis| |PointsOfFiniteOrder| |PolynomialCategory| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialFactorizationByRecursion| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialRoots| |PolynomialSetCategory| |PolynomialSetCategory&| |PolynomialSetUtilitiesPackage| |PolynomialSquareFree| |PositiveInteger| |PowerSeriesCategory| |PowerSeriesCategory&| |PowerSeriesLimitPackage| |PriorityQueueAggregate| |PureAlgebraicIntegration| |PushVariables| |QuasiAlgebraicSet| |QuasiComponentPackage| |RadicalSolvePackage| |RationalFunctionDefiniteIntegration| |RationalFunctionSum| |RecurrenceOperator| |RecursivePolynomialCategory| |RecursivePolynomialCategory&| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |ResidueRing| |RewriteRule| |Ruleset| |SequentialDifferentialVariable| |SimpleFortranProgram| |SingletonAsOrderedSet| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SquareFreeNormalizedTriangularSetCategory| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetCategory| |SquareFreeRegularTriangularSetGcdPackage| |SupFractionFactorizer| |Symbol| |TableauxBumpers| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |TransSolvePackageService| |TranscendentalManipulations| |TriangularSetCategory| |TriangularSetCategory&| |TrigonometricManipulations| |UnivariatePuiseuxSeriesWithExponentialSingularity| |WeightedPolynomials| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XExponentialPackage| |XFreeAlgebra| |XPBWPolynomial| |XPolynomialsCat| |XRecursivePolynomial|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |DesingTreePackage| |DistributedMultivariatePolynomial| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |HomogeneousDistributedMultivariatePolynomial| |InfinitlyClosePoint| |InfinitlyClosePointCategory| |InterpolateFormsPackage| |IntersectionDivisorPackage| |LocalParametrizationOfSimplePointPackage| |MultivariatePolynomial| |ParametrizationPackage| |ProjectiveAlgebraicSetPackage| |RegularChain|)
 (|OrderlyDifferentialPolynomial|)
 (|d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType|)
-(|FortranScalarType| |InfiniteTuple| |InputForm| |InventorDataSink| |QuasiAlgebraicSet| |QueryEquation| |SExpression| |Switch| |SymbolTable| |TheSymbolTable|)
+(|FortranScalarType| |InfiniteTuple| |InputForm| |QuasiAlgebraicSet| |QueryEquation| |SExpression| |Switch| |SymbolTable| |TheSymbolTable|)
 (|PAdicRational|)
 (|BalancedPAdicInteger| |InnerPAdicInteger| |PAdicInteger| |PAdicRationalConstructor|)
 (|d03eefAnnaType| |d03fafAnnaType|)
-(|FortranExpression| |MultiVariableCalculusFunctions| |OrdinaryDifferentialRing| |PartialDifferentialRing&|)
+(|FortranExpression| |Guess| |MultiVariableCalculusFunctions| |MyExpression| |OrdinaryDifferentialRing| |PartialDifferentialRing&| |RecurrenceOperator|)
 (|ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |FunctionSpaceToUnivariatePowerSeries|)
 (|SymmetricPolynomial|)
 (|ApplyRules| |ComplexPattern| |OrderedVariableList| |PatternMatch| |PatternMatchFunctionSpace| |PatternMatchKernel| |PatternMatchPolynomialCategory| |PatternMatchQuotientFieldCategory| |PatternMatchTools| |RewriteRule| |Ruleset| |Symbol|)
 (|ApplyRules| |ComplexPatternMatch| |PatternMatch| |PatternMatchFunctionSpace| |PatternMatchKernel| |PatternMatchListAggregate| |PatternMatchPolynomialCategory| |PatternMatchPushDown| |PatternMatchQuotientFieldCategory| |RewriteRule| |Ruleset| |Symbol|)
 (|Kernel|)
 (|Permutation|)
+(|InfClsPt|)
+(|DesingTreePackage| |GeneralPackageForAlgebraicFunctionField| |InfinitlyClosePoint| |InfinitlyClosePointCategory| |InterpolateFormsPackage| |IntersectionDivisorPackage| |LocalParametrizationOfSimplePointPackage| |ParametrizationPackage| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |Plcs|)
+(|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField|)
 (|PlaneAlgebraicCurvePlot| |Plot|)
 (|NumericTubePlot| |Plot3D| |TubePlot|)
 (|XPBWPolynomial|)
 (|Point|)
 (|GenericNonAssociativeAlgebra| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |PushVariables| |RationalFunctionFactor| |SAERationalFunctionAlgFactor|)
-(|AlgebraicMultFact| |DistributedMultivariatePolynomial| |EuclideanGroebnerBasisPackage| |FactoringUtilities| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPolynomialGcdPackage| |GeneralizedMultivariateFactorize| |GosperSummationMethod| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |HomogeneousDistributedMultivariatePolynomial| |InnerMultFact| |InnerPolySum| |LeadingCoefDetermination| |LinearSystemPolynomialPackage| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MultFiniteFactorize| |MultivariateFactorize| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |NPCoef| |ParametricLinearEquations| |PatternMatchPolynomialCategory| |Polynomial| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialFactorizationByRecursion| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialRoots| |PolynomialSquareFree| |PushVariables| |QuasiAlgebraicSet| |ResidueRing| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SupFractionFactorizer| |WeightedPolynomials|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AlgebraicMultFact| |DesingTreePackage| |DistributedMultivariatePolynomial| |EuclideanGroebnerBasisPackage| |FactoringUtilities| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralizedMultivariateFactorize| |GosperSummationMethod| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |HomogeneousDistributedMultivariatePolynomial| |InfinitlyClosePoint| |InfinitlyClosePointCategory| |InnerMultFact| |InnerPolySum| |InterfaceGroebnerPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |LeadingCoefDetermination| |LinearSystemPolynomialPackage| |LocalParametrizationOfSimplePointPackage| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MultFiniteFactorize| |MultivariateFactorize| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |NPCoef| |ParametricLinearEquations| |ParametrizationPackage| |PatternMatchPolynomialCategory| |Polynomial| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialFactorizationByRecursion| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialRoots| |PolynomialSquareFree| |ProjectiveAlgebraicSetPackage| |PushVariables| |QuasiAlgebraicSet| |ResidueRing| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SupFractionFactorizer| |WeightedPolynomials|)
 (|GeneralPolynomialGcdPackage| |LinearPolynomialEquationByFractions| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&|)
 (|GeneralPolynomialSet| |PolynomialSetCategory&|)
-(|AlgebraGivenByStructuralConstants| |CliffordAlgebra| |DirectProductMatrixModule| |FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldExtension| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |GenericNonAssociativeAlgebra| |InnerFiniteField| |InnerPrimeField| |IntegerMod| |LieExponentials| |LieSquareMatrix| |NormRetractPackage| |Permanent| |PrimeField| |QuadraticForm| |SetOfMIntegersInOneToN| |SubSpace|)
+(|AlgebraGivenByStructuralConstants| |CliffordAlgebra| |DirectProductMatrixModule| |DirichletRing| |FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldExtension| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |GenericNonAssociativeAlgebra| |InnerFiniteField| |InnerPrimeField| |IntegerMod| |LieExponentials| |LieSquareMatrix| |NormRetractPackage| |Permanent| |PrimeField| |QuadraticForm| |SetOfMIntegersInOneToN| |SubSpace|)
 (|PowerSeriesCategory&|)
 (|FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldNormalBasis|)
 (|Tuple|)
 (|ConstantLODE| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |FunctionSpaceIntegration| |InverseLaplaceTransform| |LaplaceTransform| |NonLinearFirstOrderODESolver| |ODEIntegration|)
 (|Heap|)
+(|InfClsPt|)
+(|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |DesingTreePackage| |GeneralPackageForAlgebraicFunctionField| |InfinitlyClosePoint| |InfinitlyClosePointCategory| |InterpolateFormsPackage| |IntersectionDivisorPackage| |LocalParametrizationOfSimplePointPackage| |ParametrizationPackage| |PolynomialPackageForCurve| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace|)
+(|FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber|)
+(|AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField|)
+(|PseudoAlgebraicClosureOfFiniteField|)
+(|PseudoAlgebraicClosureOfAlgExtOfRationalNumber|)
+(|FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |PseudoAlgebraicClosureOfRationalNumber|)
 (|CliffordAlgebra|)
 (|Octonion|)
 (|Quaternion| |QuaternionCategory&| |QuaternionCategoryFunctions2|)
@@ -196,8 +217,8 @@
 (|RecursiveAggregate&| |SplittingTree| |Tree|)
 (|GeneralPolynomialSet| |GeneralTriangularSet| |InternalRationalUnivariateRepresentationPackage| |LazardSetSolvingPackage| |NewSparseMultivariatePolynomial| |NormalizationPackage| |NormalizedTriangularSetCategory| |PolynomialSetCategory| |PolynomialSetCategory&| |PolynomialSetUtilitiesPackage| |QuasiComponentPackage| |RecursivePolynomialCategory&| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |SquareFreeNormalizedTriangularSetCategory| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetCategory| |SquareFreeRegularTriangularSetGcdPackage| |TriangularSetCategory| |TriangularSetCategory&| |WuWenTsunTriangularSet|)
 (|LazardSetSolvingPackage| |NormalizationPackage| |QuasiComponentPackage| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |SquareFreeQuasiComponentPackage| |SquareFreeRegularTriangularSetGcdPackage|)
-(|AlgebraicIntegrate| |AlgebraicNumber| |AntiSymm| |BoundIntegerRoots| |CardinalNumber| |ComplexTrigonometricManipulations| |ConstantLODE| |DeRhamComplex| |DefiniteIntegrationTools| |DifferentialSparseMultivariatePolynomial| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |ExponentialExpansion| |ExpressionToUnivariatePowerSeries| |FortranExpression| |FractionalIdeal| |FractionalIdealFunctions2| |FreeGroup| |FreeMonoid| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizationUtilities| |GenerateUnivariatePowerSeries| |GenusZeroIntegration| |GosperSummationMethod| |InnerAlgebraicNumber| |IntegerRetractions| |IntegrationResult| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |InverseLaplaceTransform| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LinearOrdinaryDifferentialOperatorFactorizer| |ListMonoidOps| |LyndonWord| |MachineFloat| |Magma| |ModuleOperator| |MonoidRing| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonLinearFirstOrderODESolver| |ODEIntegration| |Operator| |OrderedFreeMonoid| |OrderlyDifferentialPolynomial| |Pattern| |PatternMatchFunctionSpace| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchPushDown| |PatternMatchTools| |Pi| |PoincareBirkhoffWittLyndonBasis| |PointsOfFiniteOrder| |PowerSeriesLimitPackage| |PrimitiveRatDE| |PrimitiveRatRicDE| |PureAlgebraicIntegration| |PureAlgebraicLODE| |RationalFunctionDefiniteIntegration| |RationalFunctionIntegration| |RationalFunctionSum| |RationalIntegration| |RationalLODE| |RationalRetractions| |RationalRicDE| |RetractSolvePackage| |RetractableTo&| |RewriteRule| |SequentialDifferentialPolynomial| |SparseUnivariatePuiseuxSeries| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |TranscendentalRischDE| |TranscendentalRischDESystem| |TrigonometricManipulations| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesWithExponentialSingularity|)
-(|AbelianMonoidRing| |AbelianMonoidRing&| |AntiSymm| |ApplyRules| |ApplyUnivariateSkewPolynomial| |Automorphism| |BezoutMatrix| |BiModule| |CliffordAlgebra| |CommuteUnivariatePolynomialCategory| |DeRhamComplex| |DegreeReductionPackage| |DifferentialExtension| |DifferentialExtension&| |DifferentialPolynomialCategory| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DirectProductMatrixModule| |DirectProductModule| |DistributedMultivariatePolynomial| |ExpertSystemToolsPackage2| |ExpressionToOpenMath| |FactoringUtilities| |FiniteAbelianMonoidRing| |FiniteAbelianMonoidRing&| |FreeModule| |FreeModule1| |FreeModuleCat| |FullyLinearlyExplicitRingOver| |FullyLinearlyExplicitRingOver&| |FunctionSpaceFunctions2| |GaloisGroupFactorizationUtilities| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GeneralDistributedMultivariatePolynomial| |GeneralPolynomialSet| |GeneralUnivariatePowerSeries| |HomogeneousDistributedMultivariatePolynomial| |IndexedMatrix| |InnerPolySign| |InnerSparseUnivariatePowerSeries| |InnerTaylorSeries| |IntegralBasisPolynomialTools| |LeftAlgebra| |LeftAlgebra&| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperatorCategory| |LinearOrdinaryDifferentialOperatorCategory&| |LinearlyExplicitRingOver| |MPolyCatFunctions2| |MPolyCatFunctions3| |Matrix| |MatrixCategory| |MatrixCategory&| |MatrixCategoryFunctions2| |ModMonic| |ModularRing| |ModuleOperator| |MonogenicLinearOperator| |MonoidRing| |MonoidRingFunctions2| |MultivariatePolynomial| |MultivariateTaylorSeriesCategory| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewSparseUnivariatePolynomialFunctions2| |Operator| |OppositeMonogenicLinearOperator| |OrderlyDifferentialPolynomial| |OrdinaryWeightedPolynomials| |PatternMatchPolynomialCategory| |PatternMatchTools| |Permanent| |Point| |PointCategory| |PointFunctions2| |PointPackage| |PolToPol| |Polynomial| |PolynomialCategory| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialComposition| |PolynomialFunctions2| |PolynomialRing| |PolynomialSetCategory| |PolynomialSetCategory&| |PolynomialToUnivariatePolynomial| |PowerSeriesCategory| |PowerSeriesCategory&| |PushVariables| |RectangularMatrix| |RectangularMatrixCategory| |RectangularMatrixCategory&| |RectangularMatrixCategoryFunctions2| |RecursivePolynomialCategory| |RecursivePolynomialCategory&| |RepresentationPackage1| |RepresentationPackage2| |RewriteRule| |Ring&| |Ruleset| |SequentialDifferentialPolynomial| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialFunctions2| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SquareMatrix| |SquareMatrixCategory| |SquareMatrixCategory&| |StorageEfficientMatrixOperations| |StreamTaylorSeriesOperations| |SubSpace| |SymmetricFunctions| |SymmetricPolynomial| |TaylorSeries| |ThreeSpace| |ThreeSpaceCategory| |ToolsForSign| |UTSodetools| |UnivariateLaurentSeries| |UnivariateLaurentSeriesCategory| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory| |UnivariateLaurentSeriesConstructorCategory&| |UnivariateLaurentSeriesFunctions2| |UnivariatePolynomial| |UnivariatePolynomialCategory| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialFunctions2| |UnivariatePolynomialMultiplicationPackage| |UnivariatePowerSeriesCategory| |UnivariatePowerSeriesCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesCategory| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesConstructorCategory| |UnivariatePuiseuxSeriesConstructorCategory&| |UnivariatePuiseuxSeriesFunctions2| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategoryOps| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCategory| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesFunctions2| |WeightedPolynomials| |XAlgebra| |XDistributedPolynomial| |XExponentialPackage| |XFreeAlgebra| |XPolynomial| |XPolynomialRing| |XPolynomialsCat| |XRecursivePolynomial|)
+(|AlgebraicIntegrate| |AlgebraicNumber| |AntiSymm| |BoundIntegerRoots| |CardinalNumber| |ComplexTrigonometricManipulations| |ConstantLODE| |DeRhamComplex| |DefiniteIntegrationTools| |DifferentialSparseMultivariatePolynomial| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |ExponentialExpansion| |ExpressionToUnivariatePowerSeries| |FortranExpression| |FractionalIdeal| |FractionalIdealFunctions2| |FreeGroup| |FreeMonoid| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizationUtilities| |GenerateUnivariatePowerSeries| |GenusZeroIntegration| |GosperSummationMethod| |Guess| |InnerAlgebraicNumber| |IntegerRetractions| |IntegrationResult| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |InverseLaplaceTransform| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LinearOrdinaryDifferentialOperatorFactorizer| |ListMonoidOps| |LyndonWord| |MachineFloat| |Magma| |ModuleOperator| |MonoidRing| |MyExpression| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonLinearFirstOrderODESolver| |ODEIntegration| |Operator| |OrderedFreeMonoid| |OrderlyDifferentialPolynomial| |Pattern| |PatternMatchFunctionSpace| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchPushDown| |PatternMatchTools| |Pi| |PoincareBirkhoffWittLyndonBasis| |PointsOfFiniteOrder| |PowerSeriesLimitPackage| |PrimitiveRatDE| |PrimitiveRatRicDE| |PureAlgebraicIntegration| |PureAlgebraicLODE| |RationalFunctionDefiniteIntegration| |RationalFunctionIntegration| |RationalFunctionSum| |RationalIntegration| |RationalLODE| |RationalRetractions| |RationalRicDE| |RecurrenceOperator| |RetractSolvePackage| |RetractableTo&| |RewriteRule| |SequentialDifferentialPolynomial| |SparseUnivariatePuiseuxSeries| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |TranscendentalRischDE| |TranscendentalRischDESystem| |TrigonometricManipulations| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesWithExponentialSingularity|)
+(|AbelianMonoidRing| |AbelianMonoidRing&| |AntiSymm| |ApplyRules| |ApplyUnivariateSkewPolynomial| |Automorphism| |Bezier| |BezoutMatrix| |BiModule| |CliffordAlgebra| |CommuteUnivariatePolynomialCategory| |DeRhamComplex| |DegreeReductionPackage| |DifferentialExtension| |DifferentialExtension&| |DifferentialPolynomialCategory| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DistributedMultivariatePolynomial| |ExpertSystemToolsPackage2| |ExpressionToOpenMath| |FactoringUtilities| |FiniteAbelianMonoidRing| |FiniteAbelianMonoidRing&| |FiniteAbelianMonoidRingFunctions2| |FreeModule| |FreeModule1| |FreeModuleCat| |FullyLinearlyExplicitRingOver| |FullyLinearlyExplicitRingOver&| |FunctionSpaceFunctions2| |GaloisGroupFactorizationUtilities| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GeneralDistributedMultivariatePolynomial| |GeneralPolynomialSet| |GeneralUnivariatePowerSeries| |HomogeneousDistributedMultivariatePolynomial| |IndexedMatrix| |InnerPolySign| |InnerSparseUnivariatePowerSeries| |InnerTaylorSeries| |IntegralBasisPolynomialTools| |LeftAlgebra| |LeftAlgebra&| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperatorCategory| |LinearOrdinaryDifferentialOperatorCategory&| |LinearlyExplicitRingOver| |MPolyCatFunctions2| |MPolyCatFunctions3| |MappingPackage4| |Matrix| |MatrixCategory| |MatrixCategory&| |MatrixCategoryFunctions2| |ModMonic| |ModularRing| |ModuleOperator| |MonogenicLinearOperator| |MonoidRing| |MonoidRingFunctions2| |MultivariatePolynomial| |MultivariateTaylorSeriesCategory| |MyExpression| |MyUnivariatePolynomial| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewSparseUnivariatePolynomialFunctions2| |NewtonPolygon| |Operator| |OppositeMonogenicLinearOperator| |OrderlyDifferentialPolynomial| |OrdinaryWeightedPolynomials| |PackageForPoly| |PatternMatchPolynomialCategory| |PatternMatchTools| |Permanent| |Point| |PointCategory| |PointFunctions2| |PointPackage| |PolToPol| |Polynomial| |PolynomialCategory| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialComposition| |PolynomialFunctions2| |PolynomialRing| |PolynomialSetCategory| |PolynomialSetCategory&| |PolynomialToUnivariatePolynomial| |PowerSeriesCategory| |PowerSeriesCategory&| |PushVariables| |RectangularMatrix| |RectangularMatrixCategory| |RectangularMatrixCategory&| |RectangularMatrixCategoryFunctions2| |RecursivePolynomialCategory| |RecursivePolynomialCategory&| |RepresentationPackage1| |RepresentationPackage2| |RewriteRule| |Ring&| |Ruleset| |SequentialDifferentialPolynomial| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePolynomialFunctions2| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SquareMatrix| |SquareMatrixCategory| |SquareMatrixCategory&| |StorageEfficientMatrixOperations| |StreamTaylorSeriesOperations| |SubSpace| |SymmetricFunctions| |SymmetricPolynomial| |TaylorSeries| |ThreeSpace| |ThreeSpaceCategory| |ToolsForSign| |UTSodetools| |UnivariateFormalPowerSeries| |UnivariateFormalPowerSeriesFunctions| |UnivariateLaurentSeries| |UnivariateLaurentSeriesCategory| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory| |UnivariateLaurentSeriesConstructorCategory&| |UnivariateLaurentSeriesFunctions2| |UnivariatePolynomial| |UnivariatePolynomialCategory| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialFunctions2| |UnivariatePolynomialMultiplicationPackage| |UnivariatePowerSeriesCategory| |UnivariatePowerSeriesCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesCategory| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesConstructorCategory| |UnivariatePuiseuxSeriesConstructorCategory&| |UnivariatePuiseuxSeriesFunctions2| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategoryOps| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesFunctions2| |WeightedPolynomials| |XAlgebra| |XDistributedPolynomial| |XExponentialPackage| |XFreeAlgebra| |XPolynomial| |XPolynomialRing| |XPolynomialsCat| |XRecursivePolynomial|)
 (|LeftModule| |RightModule|)
 (|InputForm|)
 (|InputForm| |SExpression| |SExpressionOf|)
@@ -205,13 +226,15 @@
 (|SemiGroup&|)
 (|SequentialDifferentialPolynomial|)
 (|SetAggregate&|)
-(|AnonymousFunction| |Any| |ApplyRules| |ArrayStack| |AssociationList| |AssociationListAggregate| |AttributeButtons| |BalancedBinaryTree| |BasicFunctions| |BasicOperatorFunctions1| |BinaryTree| |BinaryTreeCategory| |BinaryTreeCategory&| |CharacterClass| |Commutator| |ComplexPattern| |ComplexPatternMatch| |Database| |Dequeue| |Dictionary| |Dictionary&| |DictionaryOperations| |DictionaryOperations&| |DrawOption| |Eltable| |EltableAggregate| |EltableAggregate&| |EqTable| |Evalable| |Evalable&| |Exit| |File| |FileCategory| |FiniteSetAggregate| |FiniteSetAggregate&| |FiniteSetAggregateFunctions2| |FormalFraction| |FortranCode| |FortranType| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeAbelianMonoidCategory| |FreeGroup| |FreeModuleCat| |FreeMonoid| |FullPartialFractionExpansion| |FullyEvalableOver| |FullyEvalableOver&| |FunctionCalled| |GeneralSparseTable| |GenusZeroIntegration| |GraphImage| |HashTable| |IndexedAggregate| |IndexedAggregate&| |IndexedDirectProductCategory| |IndexedDirectProductObject| |InnerEvalable| |InnerEvalable&| |InnerFreeAbelianMonoid| |InnerTable| |KeyedAccessFile| |KeyedDictionary| |KeyedDictionary&| |ListMonoidOps| |ListMultiDictionary| |ListToMap| |MakeCachableSet| |MappingPackage1| |MappingPackage2| |MappingPackage3| |MappingPackageInternalHacks1| |MappingPackageInternalHacks2| |MappingPackageInternalHacks3| |ModuleMonomial| |MultiDictionary| |MultiVariableCalculusFunctions| |Multiset| |MultisetAggregate| |None| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalPDEProblem| |OnePointCompletion| |OnePointCompletionFunctions2| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OrderedCompletion| |OrderedCompletionFunctions2| |OrdinaryDifferentialRing| |OutputForm| |Palette| |PartialDifferentialRing| |PartialDifferentialRing&| |Pattern| |PatternFunctions1| |PatternFunctions2| |PatternMatch| |PatternMatchFunctionSpace| |PatternMatchKernel| |PatternMatchListAggregate| |PatternMatchListResult| |PatternMatchPolynomialCategory| |PatternMatchPushDown| |PatternMatchQuotientFieldCategory| |PatternMatchResult| |PatternMatchResultFunctions2| |PatternMatchSymbol| |PatternMatchTools| |PatternMatchable| |PendantTree| |Permutation| |PermutationCategory| |PermutationGroup| |PolynomialCategoryLifting| |PolynomialIdeals| |Product| |PureAlgebraicIntegration| |QuasiAlgebraicSet| |Queue| |RandomDistributions| |RepeatedDoubling| |RepeatedSquaring| |RewriteRule| |RuleCalled| |Ruleset| |SExpressionCategory| |SExpressionOf| |ScriptFormulaFormat| |ScriptFormulaFormat1| |Set| |SetAggregate| |SetAggregate&| |SetCategory&| |SparseTable| |SplittingNode| |SplittingTree| |Stack| |StringTable| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |Table| |TableAggregate| |TableAggregate&| |Tableau| |TabulatedComputationPackage| |TexFormat| |TexFormat1| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |TopLevelDrawFunctions| |Tree| |TwoDimensionalViewport| |UserDefinedPartialOrdering| |Variable|)
+(|AnonymousFunction| |Any| |ApplyRules| |ArrayStack| |AssociationList| |AssociationListAggregate| |AttributeButtons| |BalancedBinaryTree| |BasicFunctions| |BasicOperatorFunctions1| |BinaryTree| |BinaryTreeCategory| |BinaryTreeCategory&| |CharacterClass| |Commutator| |ComplexPattern| |ComplexPatternMatch| |Database| |Dequeue| |DesingTree| |DesingTreeCategory| |Dictionary| |Dictionary&| |DictionaryOperations| |DictionaryOperations&| |DivisorCategory| |DrawOption| |Eltable| |EltableAggregate| |EltableAggregate&| |EqTable| |Evalable| |Evalable&| |Exit| |File| |FileCategory| |FiniteSetAggregate| |FiniteSetAggregate&| |FiniteSetAggregateFunctions2| |FortranCode| |FortranType| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeAbelianMonoidCategory| |FreeGroup| |FreeModuleCat| |FreeMonoid| |FullPartialFractionExpansion| |FullyEvalableOver| |FullyEvalableOver&| |FunctionCalled| |GeneralSparseTable| |GenusZeroIntegration| |GraphImage| |GuessOption| |GuessOptionFunctions0| |HTMLFormat| |HashTable| |IndexedAggregate| |IndexedAggregate&| |IndexedDirectProductCategory| |IndexedDirectProductObject| |InnerEvalable| |InnerEvalable&| |InnerFreeAbelianMonoid| |InnerTable| |KeyedAccessFile| |KeyedDictionary| |KeyedDictionary&| |ListMonoidOps| |ListMultiDictionary| |ListToMap| |MakeCachableSet| |MappingPackage1| |MappingPackage2| |MappingPackage3| |MappingPackage4| |MappingPackageInternalHacks1| |MappingPackageInternalHacks2| |MappingPackageInternalHacks3| |MathMLFormat| |ModuleMonomial| |MultiDictionary| |MultiVariableCalculusFunctions| |Multiset| |MultisetAggregate| |None| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalPDEProblem| |OnePointCompletion| |OnePointCompletionFunctions2| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OrderedCompletion| |OrderedCompletionFunctions2| |OrdinaryDifferentialRing| |OutputForm| |Palette| |PartialDifferentialRing| |PartialDifferentialRing&| |Pattern| |PatternFunctions1| |PatternFunctions2| |PatternMatch| |PatternMatchFunctionSpace| |PatternMatchKernel| |PatternMatchListAggregate| |PatternMatchListResult| |PatternMatchPolynomialCategory| |PatternMatchPushDown| |PatternMatchQuotientFieldCategory| |PatternMatchResult| |PatternMatchResultFunctions2| |PatternMatchSymbol| |PatternMatchTools| |PatternMatchable| |PendantTree| |Permutation| |PermutationCategory| |PermutationGroup| |PolynomialCategoryLifting| |PolynomialIdeals| |Product| |PureAlgebraicIntegration| |QuasiAlgebraicSet| |Queue| |RandomDistributions| |RepeatedDoubling| |RepeatedSquaring| |RewriteRule| |RuleCalled| |Ruleset| |SExpressionCategory| |SExpressionOf| |ScriptFormulaFormat| |ScriptFormulaFormat1| |Set| |SetAggregate| |SetAggregate&| |SetCategory&| |SparseTable| |SplittingNode| |SplittingTree| |Stack| |StringTable| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |Table| |TableAggregate| |TableAggregate&| |Tableau| |TabulatedComputationPackage| |TexFormat| |TexFormat1| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |TopLevelDrawFunctions| |Tree| |TwoDimensionalViewport| |UserDefinedPartialOrdering| |Variable|)
+(|Divisor|)
 (|BinaryFile| |FiniteFieldNormalBasisExtensionByPolynomial|)
 (|DifferentialSparseMultivariatePolynomial| |NewSparseMultivariatePolynomial| |OrderlyDifferentialPolynomial| |SequentialDifferentialPolynomial|)
 (|SparseUnivariatePuiseuxSeries|)
 (|FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasisExtensionByPolynomial| |NewSparseUnivariatePolynomial| |Pi|)
+(|ExpressionSolve| |TaylorSolve|)
 (|SparseUnivariateLaurentSeries| |SparseUnivariatePuiseuxSeries|)
-(|InverseLaplaceTransform|)
+(|DoubleFloat| |InverseLaplaceTransform|)
 (|SplittingTree|)
 (|InternalRationalUnivariateRepresentationPackage| |LazardSetSolvingPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet|)
 (|AlgebraGivenByStructuralConstants| |GenericNonAssociativeAlgebra|)
@@ -222,7 +245,7 @@
 (|CharacterClass| |Float| |FortranTemplate| |HashTable| |InputForm| |Integer| |KeyedAccessFile| |Library| |SExpression| |StringTable| |TextFile|)
 (|IndexedString| |StringAggregate&|)
 (|String|)
-(|AlgebraGivenByStructuralConstants| |AntiSymm| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |DeRhamComplex| |DistributedMultivariatePolynomial| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |FGLMIfCanPackage| |FortranExpression| |FortranProgram| |FunctionCalled| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GroebnerSolve| |HomogeneousDistributedMultivariatePolynomial| |IdealDecompositionPackage| |InputForm| |LexTriangularPackage| |LinGroebnerPackage| |MultivariatePolynomial| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrdinaryWeightedPolynomials| |PadeApproximantPackage| |ParametricLinearEquations| |Pattern| |PolToPol| |Polynomial| |PolynomialInterpolation| |PolynomialToUnivariatePolynomial| |QuasiAlgebraicSet2| |RationalUnivariateRepresentationPackage| |RegularChain| |Result| |RoutinesTable| |RuleCalled| |SExpression| |SequentialDifferentialPolynomial| |SparseUnivariateLaurentSeries| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |SturmHabichtPackage| |Symbol| |TaylorSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesFunctions2| |UnivariatePolynomial| |UnivariatePolynomialFunctions2| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesFunctions2| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateTaylorSeries| |Variable| |XPolynomial| |ZeroDimensionalSolvePackage|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AlgebraGivenByStructuralConstants| |AntiSymm| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |BlowUpPackage| |DeRhamComplex| |DesingTreePackage| |DistributedMultivariatePolynomial| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |FGLMIfCanPackage| |FortranExpression| |FortranProgram| |FunctionCalled| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GroebnerSolve| |Guess| |GuessUnivariatePolynomial| |HomogeneousDistributedMultivariatePolynomial| |IdealDecompositionPackage| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointCategory| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InputForm| |InterfaceGroebnerPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |LexTriangularPackage| |LinGroebnerPackage| |LocalParametrizationOfSimplePointPackage| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrdinaryWeightedPolynomials| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PadeApproximantPackage| |ParametricLinearEquations| |ParametrizationPackage| |Pattern| |PolToPol| |Polynomial| |PolynomialInterpolation| |PolynomialToUnivariatePolynomial| |ProjectiveAlgebraicSetPackage| |QuasiAlgebraicSet2| |RationalInterpolation| |RationalUnivariateRepresentationPackage| |RecurrenceOperator| |RegularChain| |Result| |RoutinesTable| |RuleCalled| |SExpression| |SequentialDifferentialPolynomial| |SparseUnivariateLaurentSeries| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |SturmHabichtPackage| |Symbol| |TaylorSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesFunctions2| |UnivariatePolynomial| |UnivariatePolynomialFunctions2| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesFunctions2| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |Variable| |XPolynomial| |ZeroDimensionalSolvePackage|)
 (|FortranProgram|)
 (|EqTable| |GeneralSparseTable| |HashTable| |InnerTable| |KeyedAccessFile| |Library| |Result| |RoutinesTable| |SparseTable| |StringTable| |Table| |TableAggregate&|)
 (|ThreeSpace|)
@@ -236,7 +259,7 @@
 (|UnivariatePuiseuxSeries|)
 (|ElementaryFunctionsUnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesConstructorCategory| |UnivariatePuiseuxSeriesConstructorCategory&|)
 (|ElementaryFunctionsUnivariateLaurentSeries| |SparseUnivariateLaurentSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&|)
-(|AlgFactor| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |BalancedFactorisation| |BezoutMatrix| |BoundIntegerRoots| |BrillhartTests| |ChangeOfVariable| |CharacteristicPolynomialInMonogenicalAlgebra| |ChineseRemainderToolsForIntegralBases| |CommuteUnivariatePolynomialCategory| |ComplexFactorization| |ComplexRootFindingPackage| |ComplexRootPackage| |DistinctDegreeFactorize| |DoubleResultantPackage| |EuclideanModularRing| |FindOrderFinite| |FiniteDivisor| |FiniteDivisorCategory| |FiniteDivisorCategory&| |FiniteDivisorFunctions2| |FiniteFieldSolveLinearPolynomialEquation| |FiniteRankAlgebra| |FiniteRankAlgebra&| |FractionalIdeal| |FractionalIdealFunctions2| |FramedAlgebra| |FramedAlgebra&| |FramedModule| |FullPartialFractionExpansion| |FunctionFieldCategory| |FunctionFieldCategory&| |FunctionFieldCategoryFunctions2| |FunctionFieldIntegralBasis| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GenExEuclid| |GeneralHenselPackage| |HeuGcd| |HyperellipticFiniteDivisor| |InfiniteProductFiniteField| |InnerAlgFactor| |InnerModularGcd| |InnerPolySign| |IntegralBasisPolynomialTools| |IntegralBasisTools| |Kovacic| |LaurentPolynomial| |LinearOrdinaryDifferentialOperatorFactorizer| |ModMonic| |ModularDistinctDegreeFactorizer| |MonogenicAlgebra| |MonogenicAlgebra&| |MonomialExtensionTools| |MultipleMap| |NPCoef| |NewSparseUnivariatePolynomial| |NormInMonogenicAlgebra| |NormRetractPackage| |NumberFieldIntegralBasis| |PAdicWildFunctionFieldIntegralBasis| |PadeApproximants| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |PolynomialComposition| |PolynomialDecomposition| |PolynomialFactorizationByRecursionUnivariate| |PolynomialInterpolationAlgorithms| |PolynomialSolveByFormulas| |PrimitiveRatDE| |PrimitiveRatRicDE| |PseudoRemainderSequence| |PureAlgebraicLODE| |RadicalFunctionField| |RationalFactorize| |RationalFunctionFactor| |RationalIntegration| |RationalLODE| |RationalRicDE| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory| |RealRootCharacterizationCategory&| |RealZeroPackage| |RealZeroPackageQ| |ReduceLODE| |ReducedDivisor| |RightOpenIntervalRootCharacterization| |SAERationalFunctionAlgFactor| |SimpleAlgebraicExtension| |SimpleAlgebraicExtensionAlgFactor| |SparseUnivariatePolynomial| |SubResultantPackage| |TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalRischDE| |TranscendentalRischDESystem| |UTSodetools| |UnivariateFactorize| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialCommonDenominator| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePolynomialSquareFree| |WildFunctionFieldIntegralBasis|)
+(|AlgFactor| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |BalancedFactorisation| |BezoutMatrix| |BoundIntegerRoots| |BrillhartTests| |ChangeOfVariable| |CharacteristicPolynomialInMonogenicalAlgebra| |ChineseRemainderToolsForIntegralBases| |CommuteUnivariatePolynomialCategory| |ComplexFactorization| |ComplexRootFindingPackage| |ComplexRootPackage| |DistinctDegreeFactorize| |DoubleResultantPackage| |EuclideanModularRing| |FindOrderFinite| |FiniteDivisor| |FiniteDivisorCategory| |FiniteDivisorCategory&| |FiniteDivisorFunctions2| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteRankAlgebra| |FiniteRankAlgebra&| |FractionalIdeal| |FractionalIdealFunctions2| |FramedAlgebra| |FramedAlgebra&| |FramedModule| |FullPartialFractionExpansion| |FunctionFieldCategory| |FunctionFieldCategory&| |FunctionFieldCategoryFunctions2| |FunctionFieldIntegralBasis| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GenExEuclid| |GeneralHenselPackage| |HeuGcd| |HyperellipticFiniteDivisor| |InfiniteProductFiniteField| |InnerAlgFactor| |InnerModularGcd| |InnerPolySign| |IntegralBasisPolynomialTools| |IntegralBasisTools| |Kovacic| |LaurentPolynomial| |LinearOrdinaryDifferentialOperatorFactorizer| |ModMonic| |ModularDistinctDegreeFactorizer| |MonogenicAlgebra| |MonogenicAlgebra&| |MonomialExtensionTools| |MultipleMap| |MyUnivariatePolynomial| |NPCoef| |NewSparseUnivariatePolynomial| |NormInMonogenicAlgebra| |NormRetractPackage| |NumberFieldIntegralBasis| |PAdicWildFunctionFieldIntegralBasis| |PadeApproximants| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |PolynomialComposition| |PolynomialDecomposition| |PolynomialFactorizationByRecursionUnivariate| |PolynomialInterpolationAlgorithms| |PolynomialSolveByFormulas| |PrimitiveRatDE| |PrimitiveRatRicDE| |PseudoRemainderSequence| |PureAlgebraicLODE| |RadicalFunctionField| |RationalFactorize| |RationalFunctionFactor| |RationalIntegration| |RationalLODE| |RationalRicDE| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory| |RealRootCharacterizationCategory&| |RealZeroPackage| |RealZeroPackageQ| |ReduceLODE| |ReducedDivisor| |RightOpenIntervalRootCharacterization| |SAERationalFunctionAlgFactor| |SimpleAlgebraicExtension| |SimpleAlgebraicExtensionAlgFactor| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SubResultantPackage| |TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalRischDE| |TranscendentalRischDESystem| |UTSodetools| |UnivariateFactorize| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialCommonDenominator| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePolynomialSquareFree| |WildFunctionFieldIntegralBasis|)
 (|FunctionSpaceToUnivariatePowerSeries| |InnerSparseUnivariatePowerSeries| |UnivariatePowerSeriesCategory&|)
 (|ExponentialExpansion| |UnivariatePuiseuxSeriesWithExponentialSingularity|)
 (|ExponentialOfUnivariatePuiseuxSeries| |GeneralUnivariatePowerSeries|)
@@ -244,10 +267,10 @@
 (|ExponentialExpansion|)
 (|ApplyUnivariateSkewPolynomial| |SparseUnivariateSkewPolynomial| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategoryOps|)
 (|UnivariateLaurentSeries| |UnivariatePuiseuxSeries|)
-(|ElementaryFunctionsUnivariateLaurentSeries| |EllipticFunctionsUnivariateTaylorSeries| |InfiniteProductCharacteristicZero| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |PadeApproximants| |SparseUnivariateTaylorSeries| |UTSodetools| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory| |UnivariateLaurentSeriesConstructorCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesFunctions2| |UnivariateTaylorSeriesODESolver|)
+(|ElementaryFunctionsUnivariateLaurentSeries| |EllipticFunctionsUnivariateTaylorSeries| |ExpressionSolve| |InfiniteProductCharacteristicZero| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |PadeApproximants| |SparseUnivariateTaylorSeries| |TaylorSolve| |UTSodetools| |UnivariateFormalPowerSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory| |UnivariateLaurentSeriesConstructorCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesFunctions2| |UnivariateTaylorSeriesODESolver|)
 (|AlgebraGivenByStructuralConstants| |DenavitHartenbergMatrix| |FiniteFieldNormalBasisExtensionByPolynomial| |FramedModule| |GenericNonAssociativeAlgebra| |Matrix| |OrderedDirectProduct|)
-(|IndexedVector| |Vector| |VectorCategory&|)
+(|ComplexDoubleFloatVector| |DoubleFloatVector| |IndexedVector| |Vector| |VectorCategory&|)
 (|CliffordAlgebra| |VectorSpace&|)
 (|XPolynomialRing|)
 (|XDistributedPolynomial| |XExponentialPackage| |XPBWPolynomial| |XPolynomial| |XRecursivePolynomial|)
-(("XPolynomialsCat" 0 67544) ("XAlgebra" 0 67524) ("VectorSpace" 0 67489) ("VectorCategory" 0 67444) ("Vector" 0 67256) ("UnivariateTaylorSeriesCategory" 0 66754) ("UnivariateTaylorSeries" 0 66700) ("UnivariateSkewPolynomialCategory" 0 66532) ("UnivariatePuiseuxSeriesWithExponentialSingularity" 0 66507) ("UnivariatePuiseuxSeriesConstructorCategory" 0 66319) ("UnivariatePuiseuxSeriesCategory" 0 66247) ("UnivariatePuiseuxSeries" 0 66170) ("UnivariatePowerSeriesCategory" 0 66061) ("UnivariatePolynomialCategory" 0 63182) ("UnivariateLaurentSeriesConstructorCategory" 0 62994) ("UnivariateLaurentSeriesCategory" 0 62819) ("UnivariateLaurentSeries" 0 62791) ("UniqueFactorizationDomain" 0 62635) ("UnaryRecursiveAggregate" 0 62606) ("Type" 0 60243) ("TwoDimensionalArrayCategory" 0 60125) ("TrigonometricFunctionCategory" 0 60090) ("TriangularSetCategory" 0 60015) ("TranscendentalFunctionCategory" 0 58861) ("ThreeSpaceCategory" 0 58846) ("TableAggregate" 0 58681) ("SymbolTable" 0 58662) ("Symbol" 0 56943) ("StringCategory" 0 56932) ("StringAggregate" 0 56895) ("String" 0 56749) ("StreamAggregate" 0 56701) ("StepThrough" 0 56686) ("StackAggregate" 0 56663) ("SquareMatrixCategory" 0 56576) ("SquareMatrix" 0 56507) ("SquareFreeRegularTriangularSetCategory" 0 56353) ("SplittingNode" 0 56335) ("SpecialFunctionCategory" 0 56307) ("SparseUnivariateTaylorSeries" 0 56241) ("SparseUnivariatePolynomial" 0 56075) ("SparseUnivariateLaurentSeries" 0 56041) ("SparseMultivariatePolynomial" 0 55895) ("SingleInteger" 0 55834) ("SetCategory" 0 52854) ("SetAggregate" 0 52836) ("SequentialDifferentialVariable" 0 52799) ("SemiGroup" 0 52784) ("SegmentCategory" 0 52753) ("SExpressionCategory" 0 52709) ("SExpression" 0 52695) ("Rng" 0 52666) ("Ring" 0 48470) ("RetractableTo" 0 46211) ("RegularTriangularSetCategory" 0 45923) ("RecursivePolynomialCategory" 0 45108) ("RecursiveAggregate" 0 45061) ("RectangularMatrixCategory" 0 44972) ("RealRootCharacterizationCategory" 0 44894) ("RealNumberSystem" 0 44872) ("RealConstant" 0 44780) ("RealClosedField" 0 44745) ("RadicalCategory" 0 44627) ("QuotientFieldCategory" 0 44144) ("QueueAggregate" 0 44134) ("QuaternionCategory" 0 44066) ("Quaternion" 0 44053) ("QuadraticForm" 0 44033) ("PriorityQueueAggregate" 0 44024) ("PrimitiveFunctionCategory" 0 43786) ("PrimitiveArray" 0 43776) ("PrimeField" 0 43710) ("PowerSeriesCategory" 0 43685) ("PositiveInteger" 0 43231) ("PolynomialSetCategory" 0 43181) ("PolynomialFactorizationExplicit" 0 42992) ("PolynomialCategory" 0 41817) ("Polynomial" 0 41650) ("PointCategory" 0 41640) ("PoincareBirkhoffWittLyndonBasis" 0 41621) ("PlottableSpaceCurveCategory" 0 41581) ("PlottablePlaneCurveCategory" 0 41546) ("PermutationCategory" 0 41530) ("Patternable" 0 41519) ("PatternMatchable" 0 41265) ("Pattern" 0 41025) ("Partition" 0 41001) ("PartialTranscendentalFunctions" 0 40870) ("PartialDifferentialRing" 0 40761) ("PartialDifferentialEquationsSolverCategory" 0 40725) ("PAdicIntegerCategory" 0 40638) ("PAdicInteger" 0 40620) ("OutputForm" 0 40461) ("OrdinaryDifferentialEquationsSolverCategory" 0 40391) ("OrderlyDifferentialVariable" 0 40357) ("OrderedVariableList" 0 40163) ("OrderedSet" 0 35140) ("OrderedRing" 0 34664) ("OrderedMonoid" 0 34624) ("OrderedIntegralDomain" 0 34600) ("OrderedFreeMonoid" 0 34573) ("OrderedFinite" 0 34537) ("OrderedCancellationAbelianMonoid" 0 34523) ("OrderedAbelianMonoidSup" 0 32537) ("OrderedAbelianMonoid" 0 32212) ("OpenMath" 0 32130) ("OneDimensionalArrayAggregate" 0 31989) ("OneDimensionalArray" 0 31965) ("OctonionCategory" 0 31903) ("NumericalOptimizationCategory" 0 31782) ("NumericalIntegrationCategory" 0 31583) ("NonNegativeInteger" 0 30774) ("NonAssociativeRng" 0 30751) ("NonAssociativeRing" 0 30727) ("NonAssociativeAlgebra" 0 30632) ("NewSparseMultivariatePolynomial" 0 30615) ("MultivariateTaylorSeriesCategory" 0 30565) ("MultisetAggregate" 0 30552) ("MultiDictionary" 0 30528) ("Monoid" 0 30324) ("MonogenicLinearOperator" 0 30255) ("MonogenicAlgebra" 0 29970) ("MonadWithUnit" 0 29951) ("Monad" 0 29940) ("Module" 0 29812) ("MatrixCategory" 0 29521) ("Matrix" 0 29399) ("MachineFloat" 0 29380) ("LyndonWord" 0 29328) ("Logic" 0 29291) ("ListAggregate" 0 29187) ("List" 0 28488) ("LinearlyExplicitRingOver" 0 27481) ("LinearOrdinaryDifferentialOperatorCategory" 0 27066) ("LinearAggregate" 0 27019) ("LieAlgebra" 0 27003) ("LeftModule" 0 26797) ("LeftAlgebra" 0 26753) ("LazyStreamAggregate" 0 26699) ("KeyedDictionary" 0 26678) ("Kernel" 0 26627) ("IntervalCategory" 0 26614) ("IntegralDomain" 0 24606) ("IntegerNumberSystem" 0 24344) ("Integer" 0 21427) ("InputForm" 0 21189) ("InnerPrimeField" 0 21168) ("InnerEvalable" 0 21149) ("IndexedVector" 0 21131) ("IndexedOneDimensionalArray" 0 21100) ("IndexedExponents" 0 20837) ("IndexedDirectProductCategory" 0 20614) ("IndexedAggregate" 0 20578) ("IVNodeCategory" 0 20523) ("IVLeafNodeCategory" 0 20418) ("HyperbolicFunctionCategory" 0 20386) ("HomogeneousDirectProduct" 0 20337) ("HomogeneousAggregate" 0 20286) ("Group" 0 20193) ("GradedModule" 0 20157) ("GradedAlgebra" 0 20120) ("GcdDomain" 0 18705) ("FunctionSpace" 0 17534) ("FunctionFieldCategory" 0 17122) ("FullyRetractableTo" 0 17001) ("FullyLinearlyExplicitRingOver" 0 16966) ("FullyEvalableOver" 0 16932) ("FreeModuleCat" 0 16840) ("FreeLieAlgebra" 0 16822) ("FreeAbelianMonoidCategory" 0 16756) ("FramedNonAssociativeAlgebra" 0 16581) ("FramedAlgebra" 0 16391) ("Fraction" 0 15031) ("FortranVectorFunctionCategory" 0 14935) ("FortranVectorCategory" 0 14926) ("FortranScalarType" 0 14907) ("FortranProgramCategory" 0 14841) ("FortranMatrixFunctionCategory" 0 14807) ("FortranMatrixCategory" 0 14773) ("FortranMachineTypeCategory" 0 14702) ("FortranFunctionCategory" 0 14663) ("FloatingPointSystem" 0 14508) ("Float" 0 14386) ("FiniteSetAggregate" 0 14308) ("FiniteRankNonAssociativeAlgebra" 0 14271) ("FiniteRankAlgebra" 0 14248) ("FiniteLinearAggregate" 0 13731) ("FiniteFieldCategory" 0 13046) ("FiniteDivisorCategory" 0 12974) ("FiniteAlgebraicExtensionField" 0 12559) ("FiniteAbelianMonoidRing" 0 12439) ("Finite" 0 12270) ("FileNameCategory" 0 12257) ("FileName" 0 12188) ("FileCategory" 0 12119) ("FieldOfPrimeCharacteristic" 0 12055) ("Field" 0 9746) ("ExtensionField" 0 9726) ("ExtensibleLinearAggregate" 0 9656) ("ExpressionSpace" 0 9493) ("Expression" 0 9475) ("ExponentialOfUnivariatePuiseuxSeries" 0 9421) ("Evalable" 0 9407) ("EuclideanDomain" 0 8249) ("Equation" 0 8233) ("EltableAggregate" 0 8211) ("Eltable" 0 8104) ("ElementaryFunctionCategory" 0 8036) ("DoubleFloat" 0 7962) ("DivisionRing" 0 7944) ("DirectProductCategory" 0 7558) ("DirectProduct" 0 7439) ("DifferentialVariableCategory" 0 7232) ("DifferentialRing" 0 7044) ("DifferentialPolynomialCategory" 0 6898) ("DifferentialExtension" 0 6840) ("DictionaryOperations" 0 6814) ("Dictionary" 0 6798) ("DequeueAggregate" 0 6786) ("ConvertibleTo" 0 6041) ("ComplexCategory" 0 5908) ("Complex" 0 5723) ("CommutativeRing" 0 4346) ("CombinatorialOpsCategory" 0 4325) ("Collection" 0 4309) ("CoercibleTo" 0 3958) ("CharacteristicZero" 0 2614) ("Character" 0 2595) ("CancellationAbelianMonoid" 0 2540) ("CachableSet" 0 2497) ("Boolean" 0 2409) ("BitAggregate" 0 2370) ("BinaryTreeCategory" 0 2274) ("BinaryRecursiveAggregate" 0 2230) ("BiModule" 0 2188) ("BasicType" 0 2145) ("BasicOperator" 0 2115) ("BalancedPAdicInteger" 0 2089) ("BagAggregate" 0 2071) ("Automorphism" 0 2009) ("AssociationListAggregate" 0 1989) ("ArcTrigonometricFunctionCategory" 0 1951) ("Any" 0 1914) ("AlgebraicallyClosedFunctionSpace" 0 1549) ("AlgebraicallyClosedField" 0 886) ("AlgebraicNumber" 0 852) ("Algebra" 0 465) ("Aggregate" 0 418) ("AbelianSemiGroup" 0 351) ("AbelianMonoidRing" 0 328) ("AbelianMonoid" 0 124) ("AbelianGroup" 0 20))
\ No newline at end of file
+(("XPolynomialsCat" 0 76741) ("XAlgebra" 0 76721) ("VectorSpace" 0 76686) ("VectorCategory" 0 76594) ("Vector" 0 76406) ("UnivariateTaylorSeriesCategory" 0 75812) ("UnivariateTaylorSeries" 0 75758) ("UnivariateSkewPolynomialCategory" 0 75590) ("UnivariatePuiseuxSeriesWithExponentialSingularity" 0 75565) ("UnivariatePuiseuxSeriesConstructorCategory" 0 75377) ("UnivariatePuiseuxSeriesCategory" 0 75305) ("UnivariatePuiseuxSeries" 0 75228) ("UnivariatePowerSeriesCategory" 0 75119) ("UnivariatePolynomialCategory" 0 72086) ("UnivariateLaurentSeriesConstructorCategory" 0 71898) ("UnivariateLaurentSeriesCategory" 0 71723) ("UnivariateLaurentSeries" 0 71695) ("UniqueFactorizationDomain" 0 71539) ("UnaryRecursiveAggregate" 0 71510) ("Type" 0 69147) ("TwoDimensionalArrayCategory" 0 69029) ("TrigonometricFunctionCategory" 0 68994) ("TriangularSetCategory" 0 68919) ("TranscendentalFunctionCategory" 0 67765) ("ThreeSpaceCategory" 0 67750) ("TableAggregate" 0 67585) ("SymbolTable" 0 67566) ("Symbol" 0 65141) ("StringCategory" 0 65130) ("StringAggregate" 0 65093) ("String" 0 64947) ("StreamAggregate" 0 64899) ("StepThrough" 0 64884) ("StackAggregate" 0 64861) ("SquareMatrixCategory" 0 64774) ("SquareMatrix" 0 64705) ("SquareFreeRegularTriangularSetCategory" 0 64551) ("SplittingNode" 0 64533) ("SpecialFunctionCategory" 0 64491) ("SparseUnivariateTaylorSeries" 0 64425) ("SparseUnivariatePolynomialExpressions" 0 64391) ("SparseUnivariatePolynomial" 0 64225) ("SparseUnivariateLaurentSeries" 0 64191) ("SparseMultivariatePolynomial" 0 64045) ("SingleInteger" 0 63984) ("SetCategoryWithDegree" 0 63972) ("SetCategory" 0 60873) ("SetAggregate" 0 60855) ("SequentialDifferentialVariable" 0 60818) ("SemiGroup" 0 60803) ("SegmentCategory" 0 60772) ("SExpressionCategory" 0 60728) ("SExpression" 0 60714) ("Rng" 0 60685) ("Ring" 0 56198) ("RetractableTo" 0 53895) ("RegularTriangularSetCategory" 0 53607) ("RecursivePolynomialCategory" 0 52792) ("RecursiveAggregate" 0 52745) ("RectangularMatrixCategory" 0 52656) ("RealRootCharacterizationCategory" 0 52578) ("RealNumberSystem" 0 52556) ("RealConstant" 0 52464) ("RealClosedField" 0 52429) ("RadicalCategory" 0 52311) ("QuotientFieldCategory" 0 51828) ("QueueAggregate" 0 51818) ("QuaternionCategory" 0 51750) ("Quaternion" 0 51737) ("QuadraticForm" 0 51717) ("PseudoAlgebraicClosureOfRationalNumberCategory" 0 51616) ("PseudoAlgebraicClosureOfRationalNumber" 0 51565) ("PseudoAlgebraicClosureOfFiniteFieldCategory" 0 51525) ("PseudoAlgebraicClosureOfFiniteField" 0 51304) ("PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory" 0 51187) ("ProjectiveSpaceCategory" 0 50709) ("ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField" 0 50646) ("ProjectivePlane" 0 50633) ("PriorityQueueAggregate" 0 50624) ("PrimitiveFunctionCategory" 0 50386) ("PrimitiveArray" 0 50376) ("PrimeField" 0 50310) ("PowerSeriesCategory" 0 50285) ("PositiveInteger" 0 49815) ("PolynomialSetCategory" 0 49765) ("PolynomialFactorizationExplicit" 0 49576) ("PolynomialCategory" 0 48019) ("Polynomial" 0 47852) ("PointCategory" 0 47842) ("PoincareBirkhoffWittLyndonBasis" 0 47823) ("PlottableSpaceCurveCategory" 0 47783) ("PlottablePlaneCurveCategory" 0 47748) ("PlacesOverPseudoAlgebraicClosureOfFiniteField" 0 47685) ("PlacesCategory" 0 47382) ("Places" 0 47369) ("PermutationCategory" 0 47353) ("Patternable" 0 47342) ("PatternMatchable" 0 47088) ("Pattern" 0 46848) ("Partition" 0 46824) ("PartialTranscendentalFunctions" 0 46693) ("PartialDifferentialRing" 0 46540) ("PartialDifferentialEquationsSolverCategory" 0 46504) ("PAdicIntegerCategory" 0 46417) ("PAdicInteger" 0 46399) ("OutputForm" 0 46259) ("OrdinaryDifferentialEquationsSolverCategory" 0 46189) ("OrderlyDifferentialVariable" 0 46155) ("OrderedVariableList" 0 45606) ("OrderedSet" 0 40494) ("OrderedRing" 0 40018) ("OrderedMonoid" 0 39978) ("OrderedIntegralDomain" 0 39954) ("OrderedFreeMonoid" 0 39927) ("OrderedFinite" 0 39891) ("OrderedCancellationAbelianMonoid" 0 39877) ("OrderedAbelianMonoidSup" 0 37864) ("OrderedAbelianMonoid" 0 37503) ("OpenMath" 0 37421) ("OneDimensionalArrayAggregate" 0 37280) ("OneDimensionalArray" 0 37256) ("OctonionCategory" 0 37194) ("NumericalOptimizationCategory" 0 37073) ("NumericalIntegrationCategory" 0 36874) ("NonNegativeInteger" 0 35466) ("NonAssociativeRng" 0 35443) ("NonAssociativeRing" 0 35419) ("NonAssociativeAlgebra" 0 35324) ("NewSparseMultivariatePolynomial" 0 35307) ("NeitherSparseOrDensePowerSeries" 0 35176) ("MyUnivariatePolynomial" 0 35159) ("MultivariateTaylorSeriesCategory" 0 35109) ("MultisetAggregate" 0 35096) ("MultiDictionary" 0 35072) ("Monoid" 0 34868) ("MonogenicLinearOperator" 0 34799) ("MonogenicAlgebra" 0 34514) ("MonadWithUnit" 0 34495) ("Monad" 0 34484) ("Module" 0 34356) ("MatrixCategory" 0 34018) ("Matrix" 0 33896) ("MachineFloat" 0 33877) ("LyndonWord" 0 33825) ("Logic" 0 33788) ("LocalPowerSeriesCategory" 0 33454) ("ListAggregate" 0 33350) ("List" 0 32096) ("LinearlyExplicitRingOver" 0 31089) ("LinearOrdinaryDifferentialOperatorCategory" 0 30674) ("LinearAggregate" 0 30653) ("LieAlgebra" 0 30637) ("LeftModule" 0 30431) ("LeftAlgebra" 0 30387) ("LazyStreamAggregate" 0 30299) ("KeyedDictionary" 0 30278) ("Kernel" 0 30227) ("IntervalCategory" 0 30214) ("IntegralDomain" 0 28076) ("IntegerNumberSystem" 0 27814) ("Integer" 0 24782) ("InputForm" 0 24505) ("InnerPrimeField" 0 24484) ("InnerEvalable" 0 24465) ("InfinitlyClosePointCategory" 0 24278) ("IndexedVector" 0 24260) ("IndexedOneDimensionalArray" 0 24229) ("IndexedExponents" 0 23966) ("IndexedDirectProductCategory" 0 23743) ("IndexedAggregate" 0 23707) ("HyperbolicFunctionCategory" 0 23675) ("HomogeneousDirectProduct" 0 23626) ("HomogeneousAggregate" 0 23575) ("Group" 0 23464) ("GradedModule" 0 23428) ("GradedAlgebra" 0 23391) ("GcdDomain" 0 21905) ("FunctionSpace" 0 20672) ("FunctionFieldCategory" 0 20260) ("FullyRetractableTo" 0 20139) ("FullyLinearlyExplicitRingOver" 0 20104) ("FullyEvalableOver" 0 20070) ("FreeModuleCat" 0 19978) ("FreeLieAlgebra" 0 19960) ("FreeAbelianMonoidCategory" 0 19894) ("FramedNonAssociativeAlgebra" 0 19719) ("FramedAlgebra" 0 19529) ("Fraction" 0 18150) ("FortranVectorFunctionCategory" 0 18054) ("FortranVectorCategory" 0 18045) ("FortranScalarType" 0 18026) ("FortranProgramCategory" 0 17960) ("FortranMatrixFunctionCategory" 0 17926) ("FortranMatrixCategory" 0 17892) ("FortranMachineTypeCategory" 0 17821) ("FortranFunctionCategory" 0 17782) ("FloatingPointSystem" 0 17627) ("Float" 0 17505) ("FiniteSetAggregate" 0 17427) ("FiniteRankNonAssociativeAlgebra" 0 17390) ("FiniteRankAlgebra" 0 17367) ("FiniteLinearAggregate" 0 16850) ("FiniteFieldCategory" 0 15714) ("FiniteDivisorCategory" 0 15642) ("FiniteAlgebraicExtensionField" 0 15227) ("FiniteAbelianMonoidRing" 0 14958) ("Finite" 0 14789) ("FileNameCategory" 0 14776) ("FileName" 0 14707) ("FileCategory" 0 14638) ("FieldOfPrimeCharacteristic" 0 14574) ("Field" 0 11485) ("ExtensionField" 0 11427) ("ExtensibleLinearAggregate" 0 11357) ("ExpressionSpace" 0 11194) ("Expression" 0 11176) ("ExponentialOfUnivariatePuiseuxSeries" 0 11122) ("Evalable" 0 11108) ("EuclideanDomain" 0 9950) ("Equation" 0 9934) ("EltableAggregate" 0 9912) ("Eltable" 0 9789) ("ElementaryFunctionCategory" 0 9721) ("DoubleFloatVector" 0 9699) ("DoubleFloat" 0 9531) ("DivisorCategory" 0 9350) ("Divisor" 0 9276) ("DivisionRing" 0 9258) ("DistributedMultivariatePolynomial" 0 9184) ("DirectProductCategory" 0 8366) ("DirectProduct" 0 8175) ("DifferentialVariableCategory" 0 7968) ("DifferentialRing" 0 7780) ("DifferentialPolynomialCategory" 0 7634) ("DifferentialExtension" 0 7576) ("DictionaryOperations" 0 7550) ("Dictionary" 0 7534) ("DesingTreeCategory" 0 7428) ("DequeueAggregate" 0 7416) ("ConvertibleTo" 0 6595) ("ComplexDoubleFloatVector" 0 6566) ("ComplexCategory" 0 6433) ("Complex" 0 6194) ("CommutativeRing" 0 4843) ("CombinatorialOpsCategory" 0 4778) ("Collection" 0 4762) ("CoercibleTo" 0 4430) ("CharacteristicZero" 0 3086) ("Character" 0 3067) ("CancellationAbelianMonoid" 0 3012) ("CachableSet" 0 2969) ("Boolean" 0 2881) ("BlowUpMethodCategory" 0 2512) ("BitAggregate" 0 2473) ("BinaryTreeCategory" 0 2377) ("BinaryRecursiveAggregate" 0 2333) ("BiModule" 0 2291) ("BasicType" 0 2276) ("BasicOperator" 0 2246) ("BalancedPAdicInteger" 0 2220) ("BagAggregate" 0 2202) ("Automorphism" 0 2140) ("AssociationListAggregate" 0 2120) ("ArcTrigonometricFunctionCategory" 0 2082) ("Any" 0 2045) ("AlgebraicallyClosedFunctionSpace" 0 1680) ("AlgebraicallyClosedField" 0 1017) ("AlgebraicNumber" 0 983) ("Algebra" 0 596) ("Aggregate" 0 549) ("AffineSpaceCategory" 0 466) ("AbelianSemiGroup" 0 399) ("AbelianMonoidRing" 0 349) ("AbelianMonoid" 0 124) ("AbelianGroup" 0 20))
\ No newline at end of file
diff --git a/src/share/algebra/interp.daase b/src/share/algebra/interp.daase
index ac2cc3f..68e349e 100644
--- a/src/share/algebra/interp.daase
+++ b/src/share/algebra/interp.daase
@@ -1,1183 +1,1183 @@
 
-(3579021 . 3487447499)       
-((-2016 (((-121) (-1 (-121) |#2| |#2|) $) 62) (((-121) $) NIL)) (-3908 (($ (-1 (-121) |#2| |#2|) $) 17) (($ $) NIL)) (-2436 ((|#2| $ (-568) |#2|) NIL) ((|#2| $ (-1210 (-568)) |#2|) 34)) (-1578 (($ $) 58)) (-3092 ((|#2| (-1 |#2| |#2| |#2|) $ |#2| |#2|) 40) ((|#2| (-1 |#2| |#2| |#2|) $ |#2|) 38) ((|#2| (-1 |#2| |#2| |#2|) $) 37)) (-2764 (((-568) (-1 (-121) |#2|) $) 22) (((-568) |#2| $) NIL) (((-568) |#2| $ (-568)) 70)) (-4360 (((-634 |#2|) $) 13)) (-1347 (($ (-1 (-121) |#2| |#2|) $ $) 47) (($ $ $) NIL)) (-3674 (($ (-1 |#2| |#2|) $) 29)) (-2795 (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) 44)) (-4122 (($ |#2| $ (-568)) NIL) (($ $ $ (-568)) 49)) (-3775 (((-3 |#2| "failed") (-1 (-121) |#2|) $) 24)) (-1387 (((-121) (-1 (-121) |#2|) $) 21)) (-2779 ((|#2| $ (-568) |#2|) NIL) ((|#2| $ (-568)) NIL) (($ $ (-1210 (-568))) 48)) (-2826 (($ $ (-568)) 55) (($ $ (-1210 (-568))) 54)) (-4168 (((-763) (-1 (-121) |#2|) $) 26) (((-763) |#2| $) NIL)) (-2256 (($ $ $ (-568)) 51)) (-3863 (($ $) 50)) (-4287 (($ (-634 |#2|)) 52)) (-2768 (($ $ |#2|) NIL) (($ |#2| $) NIL) (($ $ $) 63) (($ (-634 $)) 61)) (-2745 (((-850) $) 69)) (-1319 (((-121) (-1 (-121) |#2|) $) 20)) (-1717 (((-121) $ $) 64)) (-1732 (((-121) $ $) 72))) 
-(((-18 |#1| |#2|) (-10 -8 (-15 -1717 ((-121) |#1| |#1|)) (-15 -2745 ((-850) |#1|)) (-15 -1732 ((-121) |#1| |#1|)) (-15 -3908 (|#1| |#1|)) (-15 -3908 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -1578 (|#1| |#1|)) (-15 -2256 (|#1| |#1| |#1| (-568))) (-15 -2016 ((-121) |#1|)) (-15 -1347 (|#1| |#1| |#1|)) (-15 -2764 ((-568) |#2| |#1| (-568))) (-15 -2764 ((-568) |#2| |#1|)) (-15 -2764 ((-568) (-1 (-121) |#2|) |#1|)) (-15 -2016 ((-121) (-1 (-121) |#2| |#2|) |#1|)) (-15 -1347 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -2436 (|#2| |#1| (-1210 (-568)) |#2|)) (-15 -4122 (|#1| |#1| |#1| (-568))) (-15 -4122 (|#1| |#2| |#1| (-568))) (-15 -2826 (|#1| |#1| (-1210 (-568)))) (-15 -2826 (|#1| |#1| (-568))) (-15 -2779 (|#1| |#1| (-1210 (-568)))) (-15 -2795 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -2768 (|#1| (-634 |#1|))) (-15 -2768 (|#1| |#1| |#1|)) (-15 -2768 (|#1| |#2| |#1|)) (-15 -2768 (|#1| |#1| |#2|)) (-15 -4287 (|#1| (-634 |#2|))) (-15 -3775 ((-3 |#2| "failed") (-1 (-121) |#2|) |#1|)) (-15 -3092 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -3092 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3092 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -2779 (|#2| |#1| (-568))) (-15 -2779 (|#2| |#1| (-568) |#2|)) (-15 -2436 (|#2| |#1| (-568) |#2|)) (-15 -4168 ((-763) |#2| |#1|)) (-15 -4360 ((-634 |#2|) |#1|)) (-15 -4168 ((-763) (-1 (-121) |#2|) |#1|)) (-15 -1387 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -1319 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3674 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2795 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -3863 (|#1| |#1|))) (-19 |#2|) (-1195)) (T -18)) 
+(3579618 . 3488060061)       
+((-1324 (((-121) (-1 (-121) |#2| |#2|) $) 62) (((-121) $) NIL)) (-2109 (($ (-1 (-121) |#2| |#2|) $) 17) (($ $) NIL)) (-2438 ((|#2| $ (-568) |#2|) NIL) ((|#2| $ (-1210 (-568)) |#2|) 34)) (-4452 (($ $) 58)) (-3094 ((|#2| (-1 |#2| |#2| |#2|) $ |#2| |#2|) 40) ((|#2| (-1 |#2| |#2| |#2|) $ |#2|) 38) ((|#2| (-1 |#2| |#2| |#2|) $) 37)) (-2766 (((-568) (-1 (-121) |#2|) $) 22) (((-568) |#2| $) NIL) (((-568) |#2| $ (-568)) 70)) (-3317 (((-634 |#2|) $) 13)) (-3645 (($ (-1 (-121) |#2| |#2|) $ $) 47) (($ $ $) NIL)) (-2253 (($ (-1 |#2| |#2|) $) 29)) (-2797 (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) 44)) (-4124 (($ |#2| $ (-568)) NIL) (($ $ $ (-568)) 49)) (-2712 (((-3 |#2| "failed") (-1 (-121) |#2|) $) 24)) (-3951 (((-121) (-1 (-121) |#2|) $) 21)) (-2781 ((|#2| $ (-568) |#2|) NIL) ((|#2| $ (-568)) NIL) (($ $ (-1210 (-568))) 48)) (-2828 (($ $ (-568)) 55) (($ $ (-1210 (-568))) 54)) (-4170 (((-763) (-1 (-121) |#2|) $) 26) (((-763) |#2| $) NIL)) (-3306 (($ $ $ (-568)) 51)) (-3865 (($ $) 50)) (-4289 (($ (-634 |#2|)) 52)) (-2770 (($ $ |#2|) NIL) (($ |#2| $) NIL) (($ $ $) 63) (($ (-634 $)) 61)) (-2747 (((-850) $) 69)) (-3437 (((-121) (-1 (-121) |#2|) $) 20)) (-1719 (((-121) $ $) 64)) (-1734 (((-121) $ $) 72))) 
+(((-18 |#1| |#2|) (-10 -8 (-15 -1719 ((-121) |#1| |#1|)) (-15 -2747 ((-850) |#1|)) (-15 -1734 ((-121) |#1| |#1|)) (-15 -2109 (|#1| |#1|)) (-15 -2109 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -4452 (|#1| |#1|)) (-15 -3306 (|#1| |#1| |#1| (-568))) (-15 -1324 ((-121) |#1|)) (-15 -3645 (|#1| |#1| |#1|)) (-15 -2766 ((-568) |#2| |#1| (-568))) (-15 -2766 ((-568) |#2| |#1|)) (-15 -2766 ((-568) (-1 (-121) |#2|) |#1|)) (-15 -1324 ((-121) (-1 (-121) |#2| |#2|) |#1|)) (-15 -3645 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -2438 (|#2| |#1| (-1210 (-568)) |#2|)) (-15 -4124 (|#1| |#1| |#1| (-568))) (-15 -4124 (|#1| |#2| |#1| (-568))) (-15 -2828 (|#1| |#1| (-1210 (-568)))) (-15 -2828 (|#1| |#1| (-568))) (-15 -2781 (|#1| |#1| (-1210 (-568)))) (-15 -2797 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -2770 (|#1| (-634 |#1|))) (-15 -2770 (|#1| |#1| |#1|)) (-15 -2770 (|#1| |#2| |#1|)) (-15 -2770 (|#1| |#1| |#2|)) (-15 -4289 (|#1| (-634 |#2|))) (-15 -2712 ((-3 |#2| "failed") (-1 (-121) |#2|) |#1|)) (-15 -3094 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -3094 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3094 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -2781 (|#2| |#1| (-568))) (-15 -2781 (|#2| |#1| (-568) |#2|)) (-15 -2438 (|#2| |#1| (-568) |#2|)) (-15 -4170 ((-763) |#2| |#1|)) (-15 -3317 ((-634 |#2|) |#1|)) (-15 -4170 ((-763) (-1 (-121) |#2|) |#1|)) (-15 -3951 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3437 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -2253 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2797 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -3865 (|#1| |#1|))) (-19 |#2|) (-1195)) (T -18)) 
 NIL 
-(-10 -8 (-15 -1717 ((-121) |#1| |#1|)) (-15 -2745 ((-850) |#1|)) (-15 -1732 ((-121) |#1| |#1|)) (-15 -3908 (|#1| |#1|)) (-15 -3908 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -1578 (|#1| |#1|)) (-15 -2256 (|#1| |#1| |#1| (-568))) (-15 -2016 ((-121) |#1|)) (-15 -1347 (|#1| |#1| |#1|)) (-15 -2764 ((-568) |#2| |#1| (-568))) (-15 -2764 ((-568) |#2| |#1|)) (-15 -2764 ((-568) (-1 (-121) |#2|) |#1|)) (-15 -2016 ((-121) (-1 (-121) |#2| |#2|) |#1|)) (-15 -1347 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -2436 (|#2| |#1| (-1210 (-568)) |#2|)) (-15 -4122 (|#1| |#1| |#1| (-568))) (-15 -4122 (|#1| |#2| |#1| (-568))) (-15 -2826 (|#1| |#1| (-1210 (-568)))) (-15 -2826 (|#1| |#1| (-568))) (-15 -2779 (|#1| |#1| (-1210 (-568)))) (-15 -2795 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -2768 (|#1| (-634 |#1|))) (-15 -2768 (|#1| |#1| |#1|)) (-15 -2768 (|#1| |#2| |#1|)) (-15 -2768 (|#1| |#1| |#2|)) (-15 -4287 (|#1| (-634 |#2|))) (-15 -3775 ((-3 |#2| "failed") (-1 (-121) |#2|) |#1|)) (-15 -3092 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -3092 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3092 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -2779 (|#2| |#1| (-568))) (-15 -2779 (|#2| |#1| (-568) |#2|)) (-15 -2436 (|#2| |#1| (-568) |#2|)) (-15 -4168 ((-763) |#2| |#1|)) (-15 -4360 ((-634 |#2|) |#1|)) (-15 -4168 ((-763) (-1 (-121) |#2|) |#1|)) (-15 -1387 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -1319 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3674 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2795 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -3863 (|#1| |#1|))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-1868 (((-1249) $ (-568) (-568)) 37 (|has| $ (-6 -4520)))) (-2016 (((-121) (-1 (-121) |#1| |#1|) $) 91) (((-121) $) 85 (|has| |#1| (-842)))) (-3908 (($ (-1 (-121) |#1| |#1|) $) 82 (|has| $ (-6 -4520))) (($ $) 81 (-12 (|has| |#1| (-842)) (|has| $ (-6 -4520))))) (-3644 (($ (-1 (-121) |#1| |#1|) $) 92) (($ $) 86 (|has| |#1| (-842)))) (-2510 (((-121) $ (-763)) 8)) (-2436 ((|#1| $ (-568) |#1|) 49 (|has| $ (-6 -4520))) ((|#1| $ (-1210 (-568)) |#1|) 53 (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) |#1|) $) 70 (|has| $ (-6 -4519)))) (-2671 (($) 7 T CONST)) (-1578 (($ $) 83 (|has| $ (-6 -4520)))) (-3943 (($ $) 93)) (-3924 (($ $) 73 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-4328 (($ |#1| $) 72 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) |#1|) $) 69 (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4519)))) (-3989 ((|#1| $ (-568) |#1|) 50 (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-568)) 48)) (-2764 (((-568) (-1 (-121) |#1|) $) 90) (((-568) |#1| $) 89 (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) 88 (|has| |#1| (-1090)))) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-1849 (($ (-763) |#1|) 64)) (-1737 (((-121) $ (-763)) 9)) (-1881 (((-568) $) 40 (|has| (-568) (-842)))) (-2521 (($ $ $) 80 (|has| |#1| (-842)))) (-1347 (($ (-1 (-121) |#1| |#1|) $ $) 94) (($ $ $) 87 (|has| |#1| (-842)))) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-2223 (((-568) $) 41 (|has| (-568) (-842)))) (-3268 (($ $ $) 79 (|has| |#1| (-842)))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-2166 (((-121) $ (-763)) 10)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4122 (($ |#1| $ (-568)) 55) (($ $ $ (-568)) 54)) (-4174 (((-634 (-568)) $) 43)) (-3578 (((-121) (-568) $) 44)) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3876 ((|#1| $) 39 (|has| (-568) (-842)))) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 66)) (-3724 (($ $ |#1|) 38 (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-4467 (((-121) |#1| $) 42 (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) 45)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 ((|#1| $ (-568) |#1|) 47) ((|#1| $ (-568)) 46) (($ $ (-1210 (-568))) 58)) (-2826 (($ $ (-568)) 57) (($ $ (-1210 (-568))) 56)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-2256 (($ $ $ (-568)) 84 (|has| $ (-6 -4520)))) (-3863 (($ $) 13)) (-4278 (((-541) $) 74 (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) 65)) (-2768 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-634 $)) 60)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1751 (((-121) $ $) 77 (|has| |#1| (-842)))) (-1738 (((-121) $ $) 76 (|has| |#1| (-842)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1745 (((-121) $ $) 78 (|has| |#1| (-842)))) (-1732 (((-121) $ $) 75 (|has| |#1| (-842)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+(-10 -8 (-15 -1719 ((-121) |#1| |#1|)) (-15 -2747 ((-850) |#1|)) (-15 -1734 ((-121) |#1| |#1|)) (-15 -2109 (|#1| |#1|)) (-15 -2109 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -4452 (|#1| |#1|)) (-15 -3306 (|#1| |#1| |#1| (-568))) (-15 -1324 ((-121) |#1|)) (-15 -3645 (|#1| |#1| |#1|)) (-15 -2766 ((-568) |#2| |#1| (-568))) (-15 -2766 ((-568) |#2| |#1|)) (-15 -2766 ((-568) (-1 (-121) |#2|) |#1|)) (-15 -1324 ((-121) (-1 (-121) |#2| |#2|) |#1|)) (-15 -3645 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -2438 (|#2| |#1| (-1210 (-568)) |#2|)) (-15 -4124 (|#1| |#1| |#1| (-568))) (-15 -4124 (|#1| |#2| |#1| (-568))) (-15 -2828 (|#1| |#1| (-1210 (-568)))) (-15 -2828 (|#1| |#1| (-568))) (-15 -2781 (|#1| |#1| (-1210 (-568)))) (-15 -2797 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -2770 (|#1| (-634 |#1|))) (-15 -2770 (|#1| |#1| |#1|)) (-15 -2770 (|#1| |#2| |#1|)) (-15 -2770 (|#1| |#1| |#2|)) (-15 -4289 (|#1| (-634 |#2|))) (-15 -2712 ((-3 |#2| "failed") (-1 (-121) |#2|) |#1|)) (-15 -3094 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -3094 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3094 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -2781 (|#2| |#1| (-568))) (-15 -2781 (|#2| |#1| (-568) |#2|)) (-15 -2438 (|#2| |#1| (-568) |#2|)) (-15 -4170 ((-763) |#2| |#1|)) (-15 -3317 ((-634 |#2|) |#1|)) (-15 -4170 ((-763) (-1 (-121) |#2|) |#1|)) (-15 -3951 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3437 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -2253 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2797 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -3865 (|#1| |#1|))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2481 (((-1249) $ (-568) (-568)) 37 (|has| $ (-6 -4522)))) (-1324 (((-121) (-1 (-121) |#1| |#1|) $) 91) (((-121) $) 85 (|has| |#1| (-842)))) (-2109 (($ (-1 (-121) |#1| |#1|) $) 82 (|has| $ (-6 -4522))) (($ $) 81 (-12 (|has| |#1| (-842)) (|has| $ (-6 -4522))))) (-3647 (($ (-1 (-121) |#1| |#1|) $) 92) (($ $) 86 (|has| |#1| (-842)))) (-1667 (((-121) $ (-763)) 8)) (-2438 ((|#1| $ (-568) |#1|) 49 (|has| $ (-6 -4522))) ((|#1| $ (-1210 (-568)) |#1|) 53 (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) |#1|) $) 70 (|has| $ (-6 -4521)))) (-4490 (($) 7 T CONST)) (-4452 (($ $) 83 (|has| $ (-6 -4522)))) (-3945 (($ $) 93)) (-3926 (($ $) 73 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-4330 (($ |#1| $) 72 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) |#1|) $) 69 (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4521)))) (-1292 ((|#1| $ (-568) |#1|) 50 (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-568)) 48)) (-2766 (((-568) (-1 (-121) |#1|) $) 90) (((-568) |#1| $) 89 (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) 88 (|has| |#1| (-1090)))) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-1851 (($ (-763) |#1|) 64)) (-3791 (((-121) $ (-763)) 9)) (-2539 (((-568) $) 40 (|has| (-568) (-842)))) (-1732 (($ $ $) 80 (|has| |#1| (-842)))) (-3645 (($ (-1 (-121) |#1| |#1|) $ $) 94) (($ $ $) 87 (|has| |#1| (-842)))) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3631 (((-568) $) 41 (|has| (-568) (-842)))) (-2047 (($ $ $) 79 (|has| |#1| (-842)))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-3796 (((-121) $ (-763)) 10)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4124 (($ |#1| $ (-568)) 55) (($ $ $ (-568)) 54)) (-3948 (((-634 (-568)) $) 43)) (-2916 (((-121) (-568) $) 44)) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3877 ((|#1| $) 39 (|has| (-568) (-842)))) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 66)) (-2490 (($ $ |#1|) 38 (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-1801 (((-121) |#1| $) 42 (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) 45)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 ((|#1| $ (-568) |#1|) 47) ((|#1| $ (-568)) 46) (($ $ (-1210 (-568))) 58)) (-2828 (($ $ (-568)) 57) (($ $ (-1210 (-568))) 56)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3306 (($ $ $ (-568)) 84 (|has| $ (-6 -4522)))) (-3865 (($ $) 13)) (-4280 (((-541) $) 74 (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) 65)) (-2770 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-634 $)) 60)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1753 (((-121) $ $) 77 (|has| |#1| (-842)))) (-1740 (((-121) $ $) 76 (|has| |#1| (-842)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1747 (((-121) $ $) 78 (|has| |#1| (-842)))) (-1734 (((-121) $ $) 75 (|has| |#1| (-842)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-19 |#1|) (-1275) (-1195)) (T -19)) 
 NIL 
-(-13 (-375 |t#1|) (-10 -7 (-6 -4520))) 
-(((-39) . T) ((-105) -2198 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-608 (-850)) -2198 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-154 |#1|) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-281 (-568) |#1|) . T) ((-283 (-568) |#1|) . T) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-375 |#1|) . T) ((-499 |#1|) . T) ((-601 (-568) |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-640 |#1|) . T) ((-842) |has| |#1| (-842)) ((-1090) -2198 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-1195) . T)) 
-((-3134 (((-3 $ "failed") $ $) 12)) (-1773 (($ $) NIL) (($ $ $) 9)) (* (($ (-917) $) NIL) (($ (-763) $) 16) (($ (-568) $) 21))) 
-(((-20 |#1|) (-10 -8 (-15 * (|#1| (-568) |#1|)) (-15 -1773 (|#1| |#1| |#1|)) (-15 -1773 (|#1| |#1|)) (-15 -3134 ((-3 |#1| "failed") |#1| |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|))) (-21)) (T -20)) 
+(-13 (-375 |t#1|) (-10 -7 (-6 -4522))) 
+(((-39) . T) ((-105) -2199 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-608 (-850)) -2199 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-154 |#1|) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-281 (-568) |#1|) . T) ((-283 (-568) |#1|) . T) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-375 |#1|) . T) ((-499 |#1|) . T) ((-601 (-568) |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-640 |#1|) . T) ((-842) |has| |#1| (-842)) ((-1090) -2199 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-1195) . T)) 
+((-2689 (((-3 $ "failed") $ $) 12)) (-1775 (($ $) NIL) (($ $ $) 9)) (* (($ (-917) $) NIL) (($ (-763) $) 16) (($ (-568) $) 21))) 
+(((-20 |#1|) (-10 -8 (-15 * (|#1| (-568) |#1|)) (-15 -1775 (|#1| |#1| |#1|)) (-15 -1775 (|#1| |#1|)) (-15 -2689 ((-3 |#1| "failed") |#1| |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|))) (-21)) (T -20)) 
 NIL 
-(-10 -8 (-15 * (|#1| (-568) |#1|)) (-15 -1773 (|#1| |#1| |#1|)) (-15 -1773 (|#1| |#1|)) (-15 -3134 ((-3 |#1| "failed") |#1| |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-3056 (($) 17 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19))) 
+(-10 -8 (-15 * (|#1| (-568) |#1|)) (-15 -1775 (|#1| |#1| |#1|)) (-15 -1775 (|#1| |#1|)) (-15 -2689 ((-3 |#1| "failed") |#1| |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-3058 (($) 17 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19))) 
 (((-21) (-1275)) (T -21)) 
-((-1773 (*1 *1 *1) (-4 *1 (-21))) (-1773 (*1 *1 *1 *1) (-4 *1 (-21))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-21)) (-5 *2 (-568))))) 
-(-13 (-137) (-10 -8 (-15 -1773 ($ $)) (-15 -1773 ($ $ $)) (-15 * ($ (-568) $)))) 
+((-1775 (*1 *1 *1) (-4 *1 (-21))) (-1775 (*1 *1 *1 *1) (-4 *1 (-21))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-21)) (-5 *2 (-568))))) 
+(-13 (-137) (-10 -8 (-15 -1775 ($ $)) (-15 -1775 ($ $ $)) (-15 * ($ (-568) $)))) 
 (((-23) . T) ((-25) . T) ((-105) . T) ((-137) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-2537 (((-121) $) 10)) (-2671 (($) 15)) (* (($ (-917) $) 14) (($ (-763) $) 18))) 
-(((-22 |#1|) (-10 -8 (-15 * (|#1| (-763) |#1|)) (-15 -2537 ((-121) |#1|)) (-15 -2671 (|#1|)) (-15 * (|#1| (-917) |#1|))) (-23)) (T -22)) 
+((-1819 (((-121) $) 10)) (-4490 (($) 15)) (* (($ (-917) $) 14) (($ (-763) $) 18))) 
+(((-22 |#1|) (-10 -8 (-15 * (|#1| (-763) |#1|)) (-15 -1819 ((-121) |#1|)) (-15 -4490 (|#1|)) (-15 * (|#1| (-917) |#1|))) (-23)) (T -22)) 
 NIL 
-(-10 -8 (-15 * (|#1| (-763) |#1|)) (-15 -2537 ((-121) |#1|)) (-15 -2671 (|#1|)) (-15 * (|#1| (-917) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-2671 (($) 16 T CONST)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-3056 (($) 17 T CONST)) (-1717 (((-121) $ $) 6)) (-1767 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14))) 
+(-10 -8 (-15 * (|#1| (-763) |#1|)) (-15 -1819 ((-121) |#1|)) (-15 -4490 (|#1|)) (-15 * (|#1| (-917) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-4490 (($) 16 T CONST)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-3058 (($) 17 T CONST)) (-1719 (((-121) $ $) 6)) (-1769 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14))) 
 (((-23) (-1275)) (T -23)) 
-((-3056 (*1 *1) (-4 *1 (-23))) (-2671 (*1 *1) (-4 *1 (-23))) (-2537 (*1 *2 *1) (-12 (-4 *1 (-23)) (-5 *2 (-121)))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-23)) (-5 *2 (-763))))) 
-(-13 (-25) (-10 -8 (-15 (-3056) ($) -3495) (-15 -2671 ($) -3495) (-15 -2537 ((-121) $)) (-15 * ($ (-763) $)))) 
+((-3058 (*1 *1) (-4 *1 (-23))) (-4490 (*1 *1) (-4 *1 (-23))) (-1819 (*1 *2 *1) (-12 (-4 *1 (-23)) (-5 *2 (-121)))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-23)) (-5 *2 (-763))))) 
+(-13 (-25) (-10 -8 (-15 (-3058) ($) -3497) (-15 -4490 ($) -3497) (-15 -1819 ((-121) $)) (-15 * ($ (-763) $)))) 
 (((-25) . T) ((-105) . T) ((-608 (-850)) . T) ((-1090) . T)) 
 ((* (($ (-917) $) 10))) 
 (((-24 |#1|) (-10 -8 (-15 * (|#1| (-917) |#1|))) (-25)) (T -24)) 
 NIL 
 (-10 -8 (-15 * (|#1| (-917) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-1717 (((-121) $ $) 6)) (-1767 (($ $ $) 13)) (* (($ (-917) $) 12))) 
+((-2449 (((-121) $ $) 7)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-1719 (((-121) $ $) 6)) (-1769 (($ $ $) 13)) (* (($ (-917) $) 12))) 
 (((-25) (-1275)) (T -25)) 
-((-1767 (*1 *1 *1 *1) (-4 *1 (-25))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-25)) (-5 *2 (-917))))) 
-(-13 (-1090) (-10 -8 (-15 -1767 ($ $ $)) (-15 * ($ (-917) $)))) 
+((-1769 (*1 *1 *1 *1) (-4 *1 (-25))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-25)) (-5 *2 (-917))))) 
+(-13 (-1090) (-10 -8 (-15 -1769 ($ $ $)) (-15 * ($ (-917) $)))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-2394 (((-634 $) (-953 $)) 29) (((-634 $) (-1157 $)) 16) (((-634 $) (-1157 $) (-1161)) 20)) (-1681 (($ (-953 $)) 27) (($ (-1157 $)) 11) (($ (-1157 $) (-1161)) 54)) (-3214 (((-634 $) (-953 $)) 30) (((-634 $) (-1157 $)) 18) (((-634 $) (-1157 $) (-1161)) 19)) (-2932 (($ (-953 $)) 28) (($ (-1157 $)) 13) (($ (-1157 $) (-1161)) NIL))) 
-(((-26 |#1|) (-10 -8 (-15 -2394 ((-634 |#1|) (-1157 |#1|) (-1161))) (-15 -2394 ((-634 |#1|) (-1157 |#1|))) (-15 -2394 ((-634 |#1|) (-953 |#1|))) (-15 -1681 (|#1| (-1157 |#1|) (-1161))) (-15 -1681 (|#1| (-1157 |#1|))) (-15 -1681 (|#1| (-953 |#1|))) (-15 -3214 ((-634 |#1|) (-1157 |#1|) (-1161))) (-15 -3214 ((-634 |#1|) (-1157 |#1|))) (-15 -3214 ((-634 |#1|) (-953 |#1|))) (-15 -2932 (|#1| (-1157 |#1|) (-1161))) (-15 -2932 (|#1| (-1157 |#1|))) (-15 -2932 (|#1| (-953 |#1|)))) (-27)) (T -26)) 
+((-2251 (((-634 $) (-953 $)) 29) (((-634 $) (-1157 $)) 16) (((-634 $) (-1157 $) (-1161)) 20)) (-3505 (($ (-953 $)) 27) (($ (-1157 $)) 11) (($ (-1157 $) (-1161)) 54)) (-1867 (((-634 $) (-953 $)) 30) (((-634 $) (-1157 $)) 18) (((-634 $) (-1157 $) (-1161)) 19)) (-2919 (($ (-953 $)) 28) (($ (-1157 $)) 13) (($ (-1157 $) (-1161)) NIL))) 
+(((-26 |#1|) (-10 -8 (-15 -2251 ((-634 |#1|) (-1157 |#1|) (-1161))) (-15 -2251 ((-634 |#1|) (-1157 |#1|))) (-15 -2251 ((-634 |#1|) (-953 |#1|))) (-15 -3505 (|#1| (-1157 |#1|) (-1161))) (-15 -3505 (|#1| (-1157 |#1|))) (-15 -3505 (|#1| (-953 |#1|))) (-15 -1867 ((-634 |#1|) (-1157 |#1|) (-1161))) (-15 -1867 ((-634 |#1|) (-1157 |#1|))) (-15 -1867 ((-634 |#1|) (-953 |#1|))) (-15 -2919 (|#1| (-1157 |#1|) (-1161))) (-15 -2919 (|#1| (-1157 |#1|))) (-15 -2919 (|#1| (-953 |#1|)))) (-27)) (T -26)) 
 NIL 
-(-10 -8 (-15 -2394 ((-634 |#1|) (-1157 |#1|) (-1161))) (-15 -2394 ((-634 |#1|) (-1157 |#1|))) (-15 -2394 ((-634 |#1|) (-953 |#1|))) (-15 -1681 (|#1| (-1157 |#1|) (-1161))) (-15 -1681 (|#1| (-1157 |#1|))) (-15 -1681 (|#1| (-953 |#1|))) (-15 -3214 ((-634 |#1|) (-1157 |#1|) (-1161))) (-15 -3214 ((-634 |#1|) (-1157 |#1|))) (-15 -3214 ((-634 |#1|) (-953 |#1|))) (-15 -2932 (|#1| (-1157 |#1|) (-1161))) (-15 -2932 (|#1| (-1157 |#1|))) (-15 -2932 (|#1| (-953 |#1|)))) 
-((-2447 (((-121) $ $) 7)) (-2394 (((-634 $) (-953 $)) 76) (((-634 $) (-1157 $)) 75) (((-634 $) (-1157 $) (-1161)) 74)) (-1681 (($ (-953 $)) 79) (($ (-1157 $)) 78) (($ (-1157 $) (-1161)) 77)) (-2537 (((-121) $) 15)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-3134 (((-3 $ "failed") $ $) 18)) (-4305 (($ $) 71)) (-1678 (((-420 $) $) 70)) (-1902 (($ $) 88)) (-1497 (((-121) $ $) 57)) (-2671 (($) 16 T CONST)) (-3214 (((-634 $) (-953 $)) 82) (((-634 $) (-1157 $)) 81) (((-634 $) (-1157 $) (-1161)) 80)) (-2932 (($ (-953 $)) 85) (($ (-1157 $)) 84) (($ (-1157 $) (-1161)) 83)) (-2401 (($ $ $) 53)) (-2925 (((-3 $ "failed") $) 33)) (-2412 (($ $ $) 54)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 49)) (-3927 (((-121) $) 69)) (-2735 (((-121) $) 30)) (-4044 (($ $ (-568)) 87)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-2081 (($ $) 68)) (-4022 (((-1108) $) 10)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-3848 (((-420 $) $) 72)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2595 (((-3 $ "failed") $ $) 41)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-2709 (((-763) $) 56)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 55)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63)) (-4078 (((-763)) 28)) (-1826 (((-121) $ $) 38)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1779 (($ $ $) 62)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66) (($ $ (-409 (-568))) 86)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64))) 
+(-10 -8 (-15 -2251 ((-634 |#1|) (-1157 |#1|) (-1161))) (-15 -2251 ((-634 |#1|) (-1157 |#1|))) (-15 -2251 ((-634 |#1|) (-953 |#1|))) (-15 -3505 (|#1| (-1157 |#1|) (-1161))) (-15 -3505 (|#1| (-1157 |#1|))) (-15 -3505 (|#1| (-953 |#1|))) (-15 -1867 ((-634 |#1|) (-1157 |#1|) (-1161))) (-15 -1867 ((-634 |#1|) (-1157 |#1|))) (-15 -1867 ((-634 |#1|) (-953 |#1|))) (-15 -2919 (|#1| (-1157 |#1|) (-1161))) (-15 -2919 (|#1| (-1157 |#1|))) (-15 -2919 (|#1| (-953 |#1|)))) 
+((-2449 (((-121) $ $) 7)) (-2251 (((-634 $) (-953 $)) 76) (((-634 $) (-1157 $)) 75) (((-634 $) (-1157 $) (-1161)) 74)) (-3505 (($ (-953 $)) 79) (($ (-1157 $)) 78) (($ (-1157 $) (-1161)) 77)) (-1819 (((-121) $) 15)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-2689 (((-3 $ "failed") $ $) 18)) (-3045 (($ $) 71)) (-3498 (((-420 $) $) 70)) (-1904 (($ $) 88)) (-2589 (((-121) $ $) 57)) (-4490 (($) 16 T CONST)) (-1867 (((-634 $) (-953 $)) 82) (((-634 $) (-1157 $)) 81) (((-634 $) (-1157 $) (-1161)) 80)) (-2919 (($ (-953 $)) 85) (($ (-1157 $)) 84) (($ (-1157 $) (-1161)) 83)) (-2403 (($ $ $) 53)) (-2902 (((-3 $ "failed") $) 33)) (-2414 (($ $ $) 54)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 49)) (-2197 (((-121) $) 69)) (-1598 (((-121) $) 30)) (-1550 (($ $ (-568)) 87)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-2083 (($ $) 68)) (-4025 (((-1108) $) 10)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-3850 (((-420 $) $) 72)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2597 (((-3 $ "failed") $ $) 41)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-1466 (((-763) $) 56)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 55)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63)) (-3425 (((-763)) 28)) (-2273 (((-121) $ $) 38)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1781 (($ $ $) 62)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66) (($ $ (-409 (-568))) 86)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64))) 
 (((-27) (-1275)) (T -27)) 
-((-2932 (*1 *1 *2) (-12 (-5 *2 (-953 *1)) (-4 *1 (-27)))) (-2932 (*1 *1 *2) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-27)))) (-2932 (*1 *1 *2 *3) (-12 (-5 *2 (-1157 *1)) (-5 *3 (-1161)) (-4 *1 (-27)))) (-3214 (*1 *2 *3) (-12 (-5 *3 (-953 *1)) (-4 *1 (-27)) (-5 *2 (-634 *1)))) (-3214 (*1 *2 *3) (-12 (-5 *3 (-1157 *1)) (-4 *1 (-27)) (-5 *2 (-634 *1)))) (-3214 (*1 *2 *3 *4) (-12 (-5 *3 (-1157 *1)) (-5 *4 (-1161)) (-4 *1 (-27)) (-5 *2 (-634 *1)))) (-1681 (*1 *1 *2) (-12 (-5 *2 (-953 *1)) (-4 *1 (-27)))) (-1681 (*1 *1 *2) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-27)))) (-1681 (*1 *1 *2 *3) (-12 (-5 *2 (-1157 *1)) (-5 *3 (-1161)) (-4 *1 (-27)))) (-2394 (*1 *2 *3) (-12 (-5 *3 (-953 *1)) (-4 *1 (-27)) (-5 *2 (-634 *1)))) (-2394 (*1 *2 *3) (-12 (-5 *3 (-1157 *1)) (-4 *1 (-27)) (-5 *2 (-634 *1)))) (-2394 (*1 *2 *3 *4) (-12 (-5 *3 (-1157 *1)) (-5 *4 (-1161)) (-4 *1 (-27)) (-5 *2 (-634 *1))))) 
-(-13 (-365) (-1002) (-10 -8 (-15 -2932 ($ (-953 $))) (-15 -2932 ($ (-1157 $))) (-15 -2932 ($ (-1157 $) (-1161))) (-15 -3214 ((-634 $) (-953 $))) (-15 -3214 ((-634 $) (-1157 $))) (-15 -3214 ((-634 $) (-1157 $) (-1161))) (-15 -1681 ($ (-953 $))) (-15 -1681 ($ (-1157 $))) (-15 -1681 ($ (-1157 $) (-1161))) (-15 -2394 ((-634 $) (-953 $))) (-15 -2394 ((-634 $) (-1157 $))) (-15 -2394 ((-634 $) (-1157 $) (-1161))))) 
+((-2919 (*1 *1 *2) (-12 (-5 *2 (-953 *1)) (-4 *1 (-27)))) (-2919 (*1 *1 *2) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-27)))) (-2919 (*1 *1 *2 *3) (-12 (-5 *2 (-1157 *1)) (-5 *3 (-1161)) (-4 *1 (-27)))) (-1867 (*1 *2 *3) (-12 (-5 *3 (-953 *1)) (-4 *1 (-27)) (-5 *2 (-634 *1)))) (-1867 (*1 *2 *3) (-12 (-5 *3 (-1157 *1)) (-4 *1 (-27)) (-5 *2 (-634 *1)))) (-1867 (*1 *2 *3 *4) (-12 (-5 *3 (-1157 *1)) (-5 *4 (-1161)) (-4 *1 (-27)) (-5 *2 (-634 *1)))) (-3505 (*1 *1 *2) (-12 (-5 *2 (-953 *1)) (-4 *1 (-27)))) (-3505 (*1 *1 *2) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-27)))) (-3505 (*1 *1 *2 *3) (-12 (-5 *2 (-1157 *1)) (-5 *3 (-1161)) (-4 *1 (-27)))) (-2251 (*1 *2 *3) (-12 (-5 *3 (-953 *1)) (-4 *1 (-27)) (-5 *2 (-634 *1)))) (-2251 (*1 *2 *3) (-12 (-5 *3 (-1157 *1)) (-4 *1 (-27)) (-5 *2 (-634 *1)))) (-2251 (*1 *2 *3 *4) (-12 (-5 *3 (-1157 *1)) (-5 *4 (-1161)) (-4 *1 (-27)) (-5 *2 (-634 *1))))) 
+(-13 (-365) (-1002) (-10 -8 (-15 -2919 ($ (-953 $))) (-15 -2919 ($ (-1157 $))) (-15 -2919 ($ (-1157 $) (-1161))) (-15 -1867 ((-634 $) (-953 $))) (-15 -1867 ((-634 $) (-1157 $))) (-15 -1867 ((-634 $) (-1157 $) (-1161))) (-15 -3505 ($ (-953 $))) (-15 -3505 ($ (-1157 $))) (-15 -3505 ($ (-1157 $) (-1161))) (-15 -2251 ((-634 $) (-953 $))) (-15 -2251 ((-634 $) (-1157 $))) (-15 -2251 ((-634 $) (-1157 $) (-1161))))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 $ $) . T) ((-137) . T) ((-608 (-850)) . T) ((-172) . T) ((-238) . T) ((-285) . T) ((-301) . T) ((-365) . T) ((-453) . T) ((-558) . T) ((-637 (-409 (-568))) . T) ((-637 $) . T) ((-707 (-409 (-568))) . T) ((-707 $) . T) ((-716) . T) ((-916) . T) ((-1002) . T) ((-1053 (-409 (-568))) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1199) . T)) 
-((-2394 (((-634 $) (-953 $)) NIL) (((-634 $) (-1157 $)) NIL) (((-634 $) (-1157 $) (-1161)) 50) (((-634 $) $) 19) (((-634 $) $ (-1161)) 41)) (-1681 (($ (-953 $)) NIL) (($ (-1157 $)) NIL) (($ (-1157 $) (-1161)) 52) (($ $) 17) (($ $ (-1161)) 37)) (-3214 (((-634 $) (-953 $)) NIL) (((-634 $) (-1157 $)) NIL) (((-634 $) (-1157 $) (-1161)) 48) (((-634 $) $) 15) (((-634 $) $ (-1161)) 43)) (-2932 (($ (-953 $)) NIL) (($ (-1157 $)) NIL) (($ (-1157 $) (-1161)) NIL) (($ $) 12) (($ $ (-1161)) 39))) 
-(((-28 |#1| |#2|) (-10 -8 (-15 -2394 ((-634 |#1|) |#1| (-1161))) (-15 -1681 (|#1| |#1| (-1161))) (-15 -2394 ((-634 |#1|) |#1|)) (-15 -1681 (|#1| |#1|)) (-15 -3214 ((-634 |#1|) |#1| (-1161))) (-15 -2932 (|#1| |#1| (-1161))) (-15 -3214 ((-634 |#1|) |#1|)) (-15 -2932 (|#1| |#1|)) (-15 -2394 ((-634 |#1|) (-1157 |#1|) (-1161))) (-15 -2394 ((-634 |#1|) (-1157 |#1|))) (-15 -2394 ((-634 |#1|) (-953 |#1|))) (-15 -1681 (|#1| (-1157 |#1|) (-1161))) (-15 -1681 (|#1| (-1157 |#1|))) (-15 -1681 (|#1| (-953 |#1|))) (-15 -3214 ((-634 |#1|) (-1157 |#1|) (-1161))) (-15 -3214 ((-634 |#1|) (-1157 |#1|))) (-15 -3214 ((-634 |#1|) (-953 |#1|))) (-15 -2932 (|#1| (-1157 |#1|) (-1161))) (-15 -2932 (|#1| (-1157 |#1|))) (-15 -2932 (|#1| (-953 |#1|)))) (-29 |#2|) (-13 (-842) (-558))) (T -28)) 
+((-2251 (((-634 $) (-953 $)) NIL) (((-634 $) (-1157 $)) NIL) (((-634 $) (-1157 $) (-1161)) 50) (((-634 $) $) 19) (((-634 $) $ (-1161)) 41)) (-3505 (($ (-953 $)) NIL) (($ (-1157 $)) NIL) (($ (-1157 $) (-1161)) 52) (($ $) 17) (($ $ (-1161)) 37)) (-1867 (((-634 $) (-953 $)) NIL) (((-634 $) (-1157 $)) NIL) (((-634 $) (-1157 $) (-1161)) 48) (((-634 $) $) 15) (((-634 $) $ (-1161)) 43)) (-2919 (($ (-953 $)) NIL) (($ (-1157 $)) NIL) (($ (-1157 $) (-1161)) NIL) (($ $) 12) (($ $ (-1161)) 39))) 
+(((-28 |#1| |#2|) (-10 -8 (-15 -2251 ((-634 |#1|) |#1| (-1161))) (-15 -3505 (|#1| |#1| (-1161))) (-15 -2251 ((-634 |#1|) |#1|)) (-15 -3505 (|#1| |#1|)) (-15 -1867 ((-634 |#1|) |#1| (-1161))) (-15 -2919 (|#1| |#1| (-1161))) (-15 -1867 ((-634 |#1|) |#1|)) (-15 -2919 (|#1| |#1|)) (-15 -2251 ((-634 |#1|) (-1157 |#1|) (-1161))) (-15 -2251 ((-634 |#1|) (-1157 |#1|))) (-15 -2251 ((-634 |#1|) (-953 |#1|))) (-15 -3505 (|#1| (-1157 |#1|) (-1161))) (-15 -3505 (|#1| (-1157 |#1|))) (-15 -3505 (|#1| (-953 |#1|))) (-15 -1867 ((-634 |#1|) (-1157 |#1|) (-1161))) (-15 -1867 ((-634 |#1|) (-1157 |#1|))) (-15 -1867 ((-634 |#1|) (-953 |#1|))) (-15 -2919 (|#1| (-1157 |#1|) (-1161))) (-15 -2919 (|#1| (-1157 |#1|))) (-15 -2919 (|#1| (-953 |#1|)))) (-29 |#2|) (-13 (-842) (-558))) (T -28)) 
 NIL 
-(-10 -8 (-15 -2394 ((-634 |#1|) |#1| (-1161))) (-15 -1681 (|#1| |#1| (-1161))) (-15 -2394 ((-634 |#1|) |#1|)) (-15 -1681 (|#1| |#1|)) (-15 -3214 ((-634 |#1|) |#1| (-1161))) (-15 -2932 (|#1| |#1| (-1161))) (-15 -3214 ((-634 |#1|) |#1|)) (-15 -2932 (|#1| |#1|)) (-15 -2394 ((-634 |#1|) (-1157 |#1|) (-1161))) (-15 -2394 ((-634 |#1|) (-1157 |#1|))) (-15 -2394 ((-634 |#1|) (-953 |#1|))) (-15 -1681 (|#1| (-1157 |#1|) (-1161))) (-15 -1681 (|#1| (-1157 |#1|))) (-15 -1681 (|#1| (-953 |#1|))) (-15 -3214 ((-634 |#1|) (-1157 |#1|) (-1161))) (-15 -3214 ((-634 |#1|) (-1157 |#1|))) (-15 -3214 ((-634 |#1|) (-953 |#1|))) (-15 -2932 (|#1| (-1157 |#1|) (-1161))) (-15 -2932 (|#1| (-1157 |#1|))) (-15 -2932 (|#1| (-953 |#1|)))) 
-((-2447 (((-121) $ $) 7)) (-2394 (((-634 $) (-953 $)) 76) (((-634 $) (-1157 $)) 75) (((-634 $) (-1157 $) (-1161)) 74) (((-634 $) $) 120) (((-634 $) $ (-1161)) 118)) (-1681 (($ (-953 $)) 79) (($ (-1157 $)) 78) (($ (-1157 $) (-1161)) 77) (($ $) 121) (($ $ (-1161)) 119)) (-2537 (((-121) $) 15)) (-2055 (((-634 (-1161)) $) 195)) (-3839 (((-409 (-1157 $)) $ (-607 $)) 227 (|has| |#1| (-558)))) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-3001 (((-634 (-607 $)) $) 158)) (-3134 (((-3 $ "failed") $ $) 18)) (-2366 (($ $ (-634 (-607 $)) (-634 $)) 148) (($ $ (-634 (-288 $))) 147) (($ $ (-288 $)) 146)) (-4305 (($ $) 71)) (-1678 (((-420 $) $) 70)) (-1902 (($ $) 88)) (-1497 (((-121) $ $) 57)) (-2671 (($) 16 T CONST)) (-3214 (((-634 $) (-953 $)) 82) (((-634 $) (-1157 $)) 81) (((-634 $) (-1157 $) (-1161)) 80) (((-634 $) $) 124) (((-634 $) $ (-1161)) 122)) (-2932 (($ (-953 $)) 85) (($ (-1157 $)) 84) (($ (-1157 $) (-1161)) 83) (($ $) 125) (($ $ (-1161)) 123)) (-3666 (((-3 (-953 |#1|) "failed") $) 245 (|has| |#1| (-1047))) (((-3 (-409 (-953 |#1|)) "failed") $) 229 (|has| |#1| (-558))) (((-3 |#1| "failed") $) 191) (((-3 (-568) "failed") $) 189 (|has| |#1| (-1037 (-568)))) (((-3 (-1161) "failed") $) 182) (((-3 (-607 $) "failed") $) 133) (((-3 (-409 (-568)) "failed") $) 117 (-2198 (-12 (|has| |#1| (-1037 (-568))) (|has| |#1| (-558))) (|has| |#1| (-1037 (-409 (-568))))))) (-2854 (((-953 |#1|) $) 246 (|has| |#1| (-1047))) (((-409 (-953 |#1|)) $) 230 (|has| |#1| (-558))) ((|#1| $) 192) (((-568) $) 188 (|has| |#1| (-1037 (-568)))) (((-1161) $) 183) (((-607 $) $) 134) (((-409 (-568)) $) 116 (-2198 (-12 (|has| |#1| (-1037 (-568))) (|has| |#1| (-558))) (|has| |#1| (-1037 (-409 (-568))))))) (-2401 (($ $ $) 53)) (-3164 (((-679 |#1|) (-679 $)) 235 (|has| |#1| (-1047))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 234 (|has| |#1| (-1047))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 115 (-2198 (-2139 (|has| |#1| (-1047)) (|has| |#1| (-630 (-568)))) (-2139 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))))) (((-679 (-568)) (-679 $)) 114 (-2198 (-2139 (|has| |#1| (-1047)) (|has| |#1| (-630 (-568)))) (-2139 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047)))))) (-2925 (((-3 $ "failed") $) 33)) (-2412 (($ $ $) 54)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 49)) (-3927 (((-121) $) 69)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 187 (|has| |#1| (-881 (-381)))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 186 (|has| |#1| (-881 (-568))))) (-4499 (($ (-634 $)) 152) (($ $) 151)) (-3296 (((-634 (-123)) $) 159)) (-3488 (((-123) (-123)) 160)) (-2735 (((-121) $) 30)) (-1825 (((-121) $) 180 (|has| $ (-1037 (-568))))) (-1332 (($ $) 212 (|has| |#1| (-1047)))) (-2317 (((-1113 |#1| (-607 $)) $) 211 (|has| |#1| (-1047)))) (-4044 (($ $ (-568)) 87)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-3007 (((-1157 $) (-607 $)) 177 (|has| $ (-1047)))) (-2521 (($ $ $) 131)) (-3268 (($ $ $) 130)) (-2795 (($ (-1 $ $) (-607 $)) 166)) (-3693 (((-3 (-607 $) "failed") $) 156)) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-3804 (((-634 (-607 $)) $) 157)) (-3443 (($ (-123) (-634 $)) 165) (($ (-123) $) 164)) (-3324 (((-3 (-634 $) "failed") $) 206 (|has| |#1| (-1102)))) (-2672 (((-3 (-2 (|:| |val| $) (|:| -3438 (-568))) "failed") $) 215 (|has| |#1| (-1047)))) (-1794 (((-3 (-634 $) "failed") $) 208 (|has| |#1| (-25)))) (-2392 (((-3 (-2 (|:| -2348 (-568)) (|:| |var| (-607 $))) "failed") $) 209 (|has| |#1| (-25)))) (-3751 (((-3 (-2 (|:| |var| (-607 $)) (|:| -3438 (-568))) "failed") $ (-1161)) 214 (|has| |#1| (-1047))) (((-3 (-2 (|:| |var| (-607 $)) (|:| -3438 (-568))) "failed") $ (-123)) 213 (|has| |#1| (-1047))) (((-3 (-2 (|:| |var| (-607 $)) (|:| -3438 (-568))) "failed") $) 207 (|has| |#1| (-1102)))) (-2841 (((-121) $ (-1161)) 163) (((-121) $ (-123)) 162)) (-2081 (($ $) 68)) (-2961 (((-763) $) 155)) (-4022 (((-1108) $) 10)) (-2086 (((-121) $) 193)) (-2091 ((|#1| $) 194)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-4059 (((-121) $ (-1161)) 168) (((-121) $ $) 167)) (-3848 (((-420 $) $) 72)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2595 (((-3 $ "failed") $ $) 41)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-3277 (((-121) $) 179 (|has| $ (-1037 (-568))))) (-1339 (($ $ (-1161) (-763) (-1 $ $)) 219 (|has| |#1| (-1047))) (($ $ (-1161) (-763) (-1 $ (-634 $))) 218 (|has| |#1| (-1047))) (($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ (-634 $)))) 217 (|has| |#1| (-1047))) (($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ $))) 216 (|has| |#1| (-1047))) (($ $ (-634 (-123)) (-634 $) (-1161)) 205 (|has| |#1| (-609 (-541)))) (($ $ (-123) $ (-1161)) 204 (|has| |#1| (-609 (-541)))) (($ $) 203 (|has| |#1| (-609 (-541)))) (($ $ (-634 (-1161))) 202 (|has| |#1| (-609 (-541)))) (($ $ (-1161)) 201 (|has| |#1| (-609 (-541)))) (($ $ (-123) (-1 $ $)) 176) (($ $ (-123) (-1 $ (-634 $))) 175) (($ $ (-634 (-123)) (-634 (-1 $ (-634 $)))) 174) (($ $ (-634 (-123)) (-634 (-1 $ $))) 173) (($ $ (-1161) (-1 $ $)) 172) (($ $ (-1161) (-1 $ (-634 $))) 171) (($ $ (-634 (-1161)) (-634 (-1 $ (-634 $)))) 170) (($ $ (-634 (-1161)) (-634 (-1 $ $))) 169) (($ $ (-634 $) (-634 $)) 140) (($ $ $ $) 139) (($ $ (-288 $)) 138) (($ $ (-634 (-288 $))) 137) (($ $ (-634 (-607 $)) (-634 $)) 136) (($ $ (-607 $) $) 135)) (-2709 (((-763) $) 56)) (-2779 (($ (-123) (-634 $)) 145) (($ (-123) $ $ $ $) 144) (($ (-123) $ $ $) 143) (($ (-123) $ $) 142) (($ (-123) $) 141)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 55)) (-3502 (($ $ $) 154) (($ $) 153)) (-4189 (($ $ (-1161)) 243 (|has| |#1| (-1047))) (($ $ (-634 (-1161))) 242 (|has| |#1| (-1047))) (($ $ (-1161) (-763)) 241 (|has| |#1| (-1047))) (($ $ (-634 (-1161)) (-634 (-763))) 240 (|has| |#1| (-1047)))) (-3013 (($ $) 222 (|has| |#1| (-558)))) (-2324 (((-1113 |#1| (-607 $)) $) 221 (|has| |#1| (-558)))) (-1626 (($ $) 178 (|has| $ (-1047)))) (-4278 (((-541) $) 249 (|has| |#1| (-609 (-541)))) (($ (-420 $)) 220 (|has| |#1| (-558))) (((-887 (-381)) $) 185 (|has| |#1| (-609 (-887 (-381))))) (((-887 (-568)) $) 184 (|has| |#1| (-609 (-887 (-568)))))) (-1458 (($ $ $) 248 (|has| |#1| (-478)))) (-2353 (($ $ $) 247 (|has| |#1| (-478)))) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63) (($ (-953 |#1|)) 244 (|has| |#1| (-1047))) (($ (-409 (-953 |#1|))) 228 (|has| |#1| (-558))) (($ (-409 (-953 (-409 |#1|)))) 226 (|has| |#1| (-558))) (($ (-953 (-409 |#1|))) 225 (|has| |#1| (-558))) (($ (-409 |#1|)) 224 (|has| |#1| (-558))) (($ (-1113 |#1| (-607 $))) 210 (|has| |#1| (-1047))) (($ |#1|) 190) (($ (-1161)) 181) (($ (-607 $)) 132)) (-4371 (((-3 $ "failed") $) 233 (|has| |#1| (-148)))) (-4078 (((-763)) 28)) (-2092 (($ (-634 $)) 150) (($ $) 149)) (-2887 (((-121) (-123)) 161)) (-1826 (((-121) $ $) 38)) (-3058 (($ (-1161) (-634 $)) 200) (($ (-1161) $ $ $ $) 199) (($ (-1161) $ $ $) 198) (($ (-1161) $ $) 197) (($ (-1161) $) 196)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $ (-1161)) 239 (|has| |#1| (-1047))) (($ $ (-634 (-1161))) 238 (|has| |#1| (-1047))) (($ $ (-1161) (-763)) 237 (|has| |#1| (-1047))) (($ $ (-634 (-1161)) (-634 (-763))) 236 (|has| |#1| (-1047)))) (-1751 (((-121) $ $) 128)) (-1738 (((-121) $ $) 127)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 129)) (-1732 (((-121) $ $) 126)) (-1779 (($ $ $) 62) (($ (-1113 |#1| (-607 $)) (-1113 |#1| (-607 $))) 223 (|has| |#1| (-558)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66) (($ $ (-409 (-568))) 86)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64) (($ $ |#1|) 232 (|has| |#1| (-172))) (($ |#1| $) 231 (|has| |#1| (-172))))) 
+(-10 -8 (-15 -2251 ((-634 |#1|) |#1| (-1161))) (-15 -3505 (|#1| |#1| (-1161))) (-15 -2251 ((-634 |#1|) |#1|)) (-15 -3505 (|#1| |#1|)) (-15 -1867 ((-634 |#1|) |#1| (-1161))) (-15 -2919 (|#1| |#1| (-1161))) (-15 -1867 ((-634 |#1|) |#1|)) (-15 -2919 (|#1| |#1|)) (-15 -2251 ((-634 |#1|) (-1157 |#1|) (-1161))) (-15 -2251 ((-634 |#1|) (-1157 |#1|))) (-15 -2251 ((-634 |#1|) (-953 |#1|))) (-15 -3505 (|#1| (-1157 |#1|) (-1161))) (-15 -3505 (|#1| (-1157 |#1|))) (-15 -3505 (|#1| (-953 |#1|))) (-15 -1867 ((-634 |#1|) (-1157 |#1|) (-1161))) (-15 -1867 ((-634 |#1|) (-1157 |#1|))) (-15 -1867 ((-634 |#1|) (-953 |#1|))) (-15 -2919 (|#1| (-1157 |#1|) (-1161))) (-15 -2919 (|#1| (-1157 |#1|))) (-15 -2919 (|#1| (-953 |#1|)))) 
+((-2449 (((-121) $ $) 7)) (-2251 (((-634 $) (-953 $)) 76) (((-634 $) (-1157 $)) 75) (((-634 $) (-1157 $) (-1161)) 74) (((-634 $) $) 120) (((-634 $) $ (-1161)) 118)) (-3505 (($ (-953 $)) 79) (($ (-1157 $)) 78) (($ (-1157 $) (-1161)) 77) (($ $) 121) (($ $ (-1161)) 119)) (-1819 (((-121) $) 15)) (-2057 (((-634 (-1161)) $) 195)) (-3840 (((-409 (-1157 $)) $ (-607 $)) 227 (|has| |#1| (-558)))) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-3145 (((-634 (-607 $)) $) 158)) (-2689 (((-3 $ "failed") $ $) 18)) (-4069 (($ $ (-634 (-607 $)) (-634 $)) 148) (($ $ (-634 (-288 $))) 147) (($ $ (-288 $)) 146)) (-3045 (($ $) 71)) (-3498 (((-420 $) $) 70)) (-1904 (($ $) 88)) (-2589 (((-121) $ $) 57)) (-4490 (($) 16 T CONST)) (-1867 (((-634 $) (-953 $)) 82) (((-634 $) (-1157 $)) 81) (((-634 $) (-1157 $) (-1161)) 80) (((-634 $) $) 124) (((-634 $) $ (-1161)) 122)) (-2919 (($ (-953 $)) 85) (($ (-1157 $)) 84) (($ (-1157 $) (-1161)) 83) (($ $) 125) (($ $ (-1161)) 123)) (-3668 (((-3 (-953 |#1|) "failed") $) 245 (|has| |#1| (-1047))) (((-3 (-409 (-953 |#1|)) "failed") $) 229 (|has| |#1| (-558))) (((-3 |#1| "failed") $) 191) (((-3 (-568) "failed") $) 189 (|has| |#1| (-1037 (-568)))) (((-3 (-1161) "failed") $) 182) (((-3 (-607 $) "failed") $) 133) (((-3 (-409 (-568)) "failed") $) 117 (-2199 (-12 (|has| |#1| (-1037 (-568))) (|has| |#1| (-558))) (|has| |#1| (-1037 (-409 (-568))))))) (-2857 (((-953 |#1|) $) 246 (|has| |#1| (-1047))) (((-409 (-953 |#1|)) $) 230 (|has| |#1| (-558))) ((|#1| $) 192) (((-568) $) 188 (|has| |#1| (-1037 (-568)))) (((-1161) $) 183) (((-607 $) $) 134) (((-409 (-568)) $) 116 (-2199 (-12 (|has| |#1| (-1037 (-568))) (|has| |#1| (-558))) (|has| |#1| (-1037 (-409 (-568))))))) (-2403 (($ $ $) 53)) (-1668 (((-679 |#1|) (-679 $)) 235 (|has| |#1| (-1047))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 234 (|has| |#1| (-1047))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 115 (-2199 (-2141 (|has| |#1| (-1047)) (|has| |#1| (-630 (-568)))) (-2141 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))))) (((-679 (-568)) (-679 $)) 114 (-2199 (-2141 (|has| |#1| (-1047)) (|has| |#1| (-630 (-568)))) (-2141 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047)))))) (-2902 (((-3 $ "failed") $) 33)) (-2414 (($ $ $) 54)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 49)) (-2197 (((-121) $) 69)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 187 (|has| |#1| (-881 (-381)))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 186 (|has| |#1| (-881 (-568))))) (-3855 (($ (-634 $)) 152) (($ $) 151)) (-2160 (((-634 (-123)) $) 159)) (-3842 (((-123) (-123)) 160)) (-1598 (((-121) $) 30)) (-2268 (((-121) $) 180 (|has| $ (-1037 (-568))))) (-3539 (($ $) 212 (|has| |#1| (-1047)))) (-2319 (((-1113 |#1| (-607 $)) $) 211 (|has| |#1| (-1047)))) (-1550 (($ $ (-568)) 87)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-3170 (((-1157 $) (-607 $)) 177 (|has| $ (-1047)))) (-1732 (($ $ $) 131)) (-2047 (($ $ $) 130)) (-2797 (($ (-1 $ $) (-607 $)) 166)) (-2337 (((-3 (-607 $) "failed") $) 156)) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-3832 (((-634 (-607 $)) $) 157)) (-3446 (($ (-123) (-634 $)) 165) (($ (-123) $) 164)) (-4362 (((-3 (-634 $) "failed") $) 206 (|has| |#1| (-1102)))) (-4495 (((-3 (-2 (|:| |val| $) (|:| -3483 (-568))) "failed") $) 215 (|has| |#1| (-1047)))) (-2112 (((-3 (-634 $) "failed") $) 208 (|has| |#1| (-25)))) (-2240 (((-3 (-2 (|:| -2350 (-568)) (|:| |var| (-607 $))) "failed") $) 209 (|has| |#1| (-25)))) (-2617 (((-3 (-2 (|:| |var| (-607 $)) (|:| -3483 (-568))) "failed") $ (-1161)) 214 (|has| |#1| (-1047))) (((-3 (-2 (|:| |var| (-607 $)) (|:| -3483 (-568))) "failed") $ (-123)) 213 (|has| |#1| (-1047))) (((-3 (-2 (|:| |var| (-607 $)) (|:| -3483 (-568))) "failed") $) 207 (|has| |#1| (-1102)))) (-3910 (((-121) $ (-1161)) 163) (((-121) $ (-123)) 162)) (-2083 (($ $) 68)) (-2963 (((-763) $) 155)) (-4025 (((-1108) $) 10)) (-2088 (((-121) $) 193)) (-2093 ((|#1| $) 194)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-1609 (((-121) $ (-1161)) 168) (((-121) $ $) 167)) (-3850 (((-420 $) $) 72)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2597 (((-3 $ "failed") $ $) 41)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-2080 (((-121) $) 179 (|has| $ (-1037 (-568))))) (-1339 (($ $ (-1161) (-763) (-1 $ $)) 219 (|has| |#1| (-1047))) (($ $ (-1161) (-763) (-1 $ (-634 $))) 218 (|has| |#1| (-1047))) (($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ (-634 $)))) 217 (|has| |#1| (-1047))) (($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ $))) 216 (|has| |#1| (-1047))) (($ $ (-634 (-123)) (-634 $) (-1161)) 205 (|has| |#1| (-609 (-541)))) (($ $ (-123) $ (-1161)) 204 (|has| |#1| (-609 (-541)))) (($ $) 203 (|has| |#1| (-609 (-541)))) (($ $ (-634 (-1161))) 202 (|has| |#1| (-609 (-541)))) (($ $ (-1161)) 201 (|has| |#1| (-609 (-541)))) (($ $ (-123) (-1 $ $)) 176) (($ $ (-123) (-1 $ (-634 $))) 175) (($ $ (-634 (-123)) (-634 (-1 $ (-634 $)))) 174) (($ $ (-634 (-123)) (-634 (-1 $ $))) 173) (($ $ (-1161) (-1 $ $)) 172) (($ $ (-1161) (-1 $ (-634 $))) 171) (($ $ (-634 (-1161)) (-634 (-1 $ (-634 $)))) 170) (($ $ (-634 (-1161)) (-634 (-1 $ $))) 169) (($ $ (-634 $) (-634 $)) 140) (($ $ $ $) 139) (($ $ (-288 $)) 138) (($ $ (-634 (-288 $))) 137) (($ $ (-634 (-607 $)) (-634 $)) 136) (($ $ (-607 $) $) 135)) (-1466 (((-763) $) 56)) (-2781 (($ (-123) (-634 $)) 145) (($ (-123) $ $ $ $) 144) (($ (-123) $ $ $) 143) (($ (-123) $ $) 142) (($ (-123) $) 141)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 55)) (-3924 (($ $ $) 154) (($ $) 153)) (-4191 (($ $ (-1161)) 243 (|has| |#1| (-1047))) (($ $ (-634 (-1161))) 242 (|has| |#1| (-1047))) (($ $ (-1161) (-763)) 241 (|has| |#1| (-1047))) (($ $ (-634 (-1161)) (-634 (-763))) 240 (|has| |#1| (-1047)))) (-3210 (($ $) 222 (|has| |#1| (-558)))) (-2326 (((-1113 |#1| (-607 $)) $) 221 (|has| |#1| (-558)))) (-1492 (($ $) 178 (|has| $ (-1047)))) (-4280 (((-541) $) 249 (|has| |#1| (-609 (-541)))) (($ (-420 $)) 220 (|has| |#1| (-558))) (((-887 (-381)) $) 185 (|has| |#1| (-609 (-887 (-381))))) (((-887 (-568)) $) 184 (|has| |#1| (-609 (-887 (-568)))))) (-2387 (($ $ $) 248 (|has| |#1| (-478)))) (-3985 (($ $ $) 247 (|has| |#1| (-478)))) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63) (($ (-953 |#1|)) 244 (|has| |#1| (-1047))) (($ (-409 (-953 |#1|))) 228 (|has| |#1| (-558))) (($ (-409 (-953 (-409 |#1|)))) 226 (|has| |#1| (-558))) (($ (-953 (-409 |#1|))) 225 (|has| |#1| (-558))) (($ (-409 |#1|)) 224 (|has| |#1| (-558))) (($ (-1113 |#1| (-607 $))) 210 (|has| |#1| (-1047))) (($ |#1|) 190) (($ (-1161)) 181) (($ (-607 $)) 132)) (-3385 (((-3 $ "failed") $) 233 (|has| |#1| (-148)))) (-3425 (((-763)) 28)) (-3159 (($ (-634 $)) 150) (($ $) 149)) (-2779 (((-121) (-123)) 161)) (-2273 (((-121) $ $) 38)) (-3060 (($ (-1161) (-634 $)) 200) (($ (-1161) $ $ $ $) 199) (($ (-1161) $ $ $) 198) (($ (-1161) $ $) 197) (($ (-1161) $) 196)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $ (-1161)) 239 (|has| |#1| (-1047))) (($ $ (-634 (-1161))) 238 (|has| |#1| (-1047))) (($ $ (-1161) (-763)) 237 (|has| |#1| (-1047))) (($ $ (-634 (-1161)) (-634 (-763))) 236 (|has| |#1| (-1047)))) (-1753 (((-121) $ $) 128)) (-1740 (((-121) $ $) 127)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 129)) (-1734 (((-121) $ $) 126)) (-1781 (($ $ $) 62) (($ (-1113 |#1| (-607 $)) (-1113 |#1| (-607 $))) 223 (|has| |#1| (-558)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66) (($ $ (-409 (-568))) 86)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64) (($ $ |#1|) 232 (|has| |#1| (-172))) (($ |#1| $) 231 (|has| |#1| (-172))))) 
 (((-29 |#1|) (-1275) (-13 (-842) (-558))) (T -29)) 
-((-2932 (*1 *1 *1) (-12 (-4 *1 (-29 *2)) (-4 *2 (-13 (-842) (-558))))) (-3214 (*1 *2 *1) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *2 (-634 *1)) (-4 *1 (-29 *3)))) (-2932 (*1 *1 *1 *2) (-12 (-5 *2 (-1161)) (-4 *1 (-29 *3)) (-4 *3 (-13 (-842) (-558))))) (-3214 (*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-634 *1)) (-4 *1 (-29 *4)))) (-1681 (*1 *1 *1) (-12 (-4 *1 (-29 *2)) (-4 *2 (-13 (-842) (-558))))) (-2394 (*1 *2 *1) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *2 (-634 *1)) (-4 *1 (-29 *3)))) (-1681 (*1 *1 *1 *2) (-12 (-5 *2 (-1161)) (-4 *1 (-29 *3)) (-4 *3 (-13 (-842) (-558))))) (-2394 (*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-634 *1)) (-4 *1 (-29 *4))))) 
-(-13 (-27) (-432 |t#1|) (-10 -8 (-15 -2932 ($ $)) (-15 -3214 ((-634 $) $)) (-15 -2932 ($ $ (-1161))) (-15 -3214 ((-634 $) $ (-1161))) (-15 -1681 ($ $)) (-15 -2394 ((-634 $) $)) (-15 -1681 ($ $ (-1161))) (-15 -2394 ((-634 $) $ (-1161))))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) . T) ((-27) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 |#1| |#1|) |has| |#1| (-172)) ((-120 $ $) . T) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-609 (-887 (-381))) |has| |#1| (-609 (-887 (-381)))) ((-609 (-887 (-568))) |has| |#1| (-609 (-887 (-568)))) ((-238) . T) ((-285) . T) ((-301) . T) ((-303 $) . T) ((-296) . T) ((-365) . T) ((-379 |#1|) |has| |#1| (-1047)) ((-402 |#1|) . T) ((-413 |#1|) . T) ((-432 |#1|) . T) ((-453) . T) ((-478) |has| |#1| (-478)) ((-523 (-607 $) $) . T) ((-523 $ $) . T) ((-558) . T) ((-637 (-409 (-568))) . T) ((-637 |#1|) |has| |#1| (-172)) ((-637 $) . T) ((-630 (-568)) -12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))) ((-630 |#1|) |has| |#1| (-1047)) ((-707 (-409 (-568))) . T) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) . T) ((-716) . T) ((-842) . T) ((-895 (-1161)) |has| |#1| (-1047)) ((-881 (-381)) |has| |#1| (-881 (-381))) ((-881 (-568)) |has| |#1| (-881 (-568))) ((-879 |#1|) . T) ((-916) . T) ((-1002) . T) ((-1037 (-409 (-568))) -2198 (|has| |#1| (-1037 (-409 (-568)))) (-12 (|has| |#1| (-558)) (|has| |#1| (-1037 (-568))))) ((-1037 (-409 (-953 |#1|))) |has| |#1| (-558)) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 (-607 $)) . T) ((-1037 (-953 |#1|)) |has| |#1| (-1047)) ((-1037 (-1161)) . T) ((-1037 |#1|) . T) ((-1053 (-409 (-568))) . T) ((-1053 |#1|) |has| |#1| (-172)) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1195) . T) ((-1199) . T)) 
-((-4017 (((-1084 (-215)) $) NIL)) (-1351 (((-1084 (-215)) $) NIL)) (-4069 (($ $ (-215)) 122)) (-2378 (($ (-953 (-568)) (-1161) (-1161) (-1084 (-409 (-568))) (-1084 (-409 (-568)))) 84)) (-2550 (((-634 (-634 (-944 (-215)))) $) 134)) (-2745 (((-850) $) 146))) 
-(((-30) (-13 (-955) (-10 -8 (-15 -2378 ($ (-953 (-568)) (-1161) (-1161) (-1084 (-409 (-568))) (-1084 (-409 (-568))))) (-15 -4069 ($ $ (-215)))))) (T -30)) 
-((-2378 (*1 *1 *2 *3 *3 *4 *4) (-12 (-5 *2 (-953 (-568))) (-5 *3 (-1161)) (-5 *4 (-1084 (-409 (-568)))) (-5 *1 (-30)))) (-4069 (*1 *1 *1 *2) (-12 (-5 *2 (-215)) (-5 *1 (-30))))) 
-(-13 (-955) (-10 -8 (-15 -2378 ($ (-953 (-568)) (-1161) (-1161) (-1084 (-409 (-568))) (-1084 (-409 (-568))))) (-15 -4069 ($ $ (-215))))) 
-((-2548 (((-3 (-634 |#5|) "failed" "Infinite" (-568)) |#3|) 38)) (-2667 (((-634 |#5|) |#3| (-917)) 33)) (-1991 (((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-634 |#3|)) 40))) 
-(((-31 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1991 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-634 |#3|))) (-15 -2548 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) |#3|)) (-15 -2667 ((-634 |#5|) |#3| (-917)))) (-365) (-634 (-1161)) (-950 |#1| |#4| (-852 |#2|)) (-230 (-1697 |#2|) (-763)) (-971 |#1|)) (T -31)) 
-((-2667 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1697 *6) (-763))) (-5 *2 (-634 *8)) (-5 *1 (-31 *5 *6 *3 *7 *8)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5)))) (-2548 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-230 (-1697 *5) (-763))) (-5 *2 (-3 (-634 *7) "failed" "Infinite" (-568))) (-5 *1 (-31 *4 *5 *3 *6 *7)) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *7 (-971 *4)))) (-1991 (*1 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *2 (-3 (-634 *8) "failed" "Infinite" (-568))) (-5 *1 (-31 *4 *5 *6 *7 *8)) (-4 *8 (-971 *4))))) 
-(-10 -7 (-15 -1991 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-634 |#3|))) (-15 -2548 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) |#3|)) (-15 -2667 ((-634 |#5|) |#3| (-917)))) 
-((-2152 (((-1157 (-1157 |#1|)) |#3|) 35)) (-2351 (((-634 (-634 (-1157 (-1157 |#1|)))) (-634 (-1157 (-1157 |#1|)))) 54)) (-2548 (((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-1157 (-1157 |#1|))) 56) (((-3 (-634 |#5|) "failed" "Infinite" (-568)) |#3|) 57)) (-2667 (((-3 (-634 |#5|) "failed" "Infinite" (-568)) |#3| (-917)) 51)) (-1832 (((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-634 (-1157 (-1157 |#1|)))) 70)) (-1991 (((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-634 |#3|)) 50))) 
-(((-32 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2548 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) |#3|)) (-15 -2548 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-1157 (-1157 |#1|)))) (-15 -1832 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-634 (-1157 (-1157 |#1|))))) (-15 -1991 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-634 |#3|))) (-15 -2152 ((-1157 (-1157 |#1|)) |#3|)) (-15 -2351 ((-634 (-634 (-1157 (-1157 |#1|)))) (-634 (-1157 (-1157 |#1|))))) (-15 -2667 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) |#3| (-917)))) (-365) (-634 (-1161)) (-950 |#1| |#4| (-852 |#2|)) (-230 (-1697 |#2|) (-763)) (-971 |#1|)) (T -32)) 
-((-2667 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1697 *6) (-763))) (-5 *2 (-3 (-634 *8) "failed" "Infinite" (-568))) (-5 *1 (-32 *5 *6 *3 *7 *8)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5)))) (-2351 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *7 (-230 (-1697 *5) (-763))) (-5 *2 (-634 (-634 (-1157 (-1157 *4))))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-5 *3 (-634 (-1157 (-1157 *4)))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *8 (-971 *4)))) (-2152 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-230 (-1697 *5) (-763))) (-5 *2 (-1157 (-1157 *4))) (-5 *1 (-32 *4 *5 *3 *6 *7)) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *7 (-971 *4)))) (-1991 (*1 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *2 (-3 (-634 *8) "failed" "Infinite" (-568))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *8 (-971 *4)))) (-1832 (*1 *2 *3) (-12 (-5 *3 (-634 (-1157 (-1157 *4)))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *7 (-230 (-1697 *5) (-763))) (-5 *2 (-3 (-634 *8) "failed" "Infinite" (-568))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *8 (-971 *4)))) (-2548 (*1 *2 *3) (-12 (-5 *3 (-1157 (-1157 *4))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *7 (-230 (-1697 *5) (-763))) (-5 *2 (-3 (-634 *8) "failed" "Infinite" (-568))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *8 (-971 *4)))) (-2548 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-230 (-1697 *5) (-763))) (-5 *2 (-3 (-634 *7) "failed" "Infinite" (-568))) (-5 *1 (-32 *4 *5 *3 *6 *7)) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *7 (-971 *4))))) 
-(-10 -7 (-15 -2548 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) |#3|)) (-15 -2548 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-1157 (-1157 |#1|)))) (-15 -1832 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-634 (-1157 (-1157 |#1|))))) (-15 -1991 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-634 |#3|))) (-15 -2152 ((-1157 (-1157 |#1|)) |#3|)) (-15 -2351 ((-634 (-634 (-1157 (-1157 |#1|)))) (-634 (-1157 (-1157 |#1|))))) (-15 -2667 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) |#3| (-917)))) 
-((-2447 (((-121) $ $) NIL)) (-2436 ((|#1| $ (-568) |#1|) NIL)) (-1501 (((-634 $) (-634 $) (-763)) NIL) (((-634 $) (-634 $)) NIL)) (-2688 (((-121) $ (-763)) NIL) (((-121) $) NIL)) (-3890 (((-634 |#1|) $) NIL)) (-2476 (($) NIL)) (-3340 (((-634 $) $) NIL) (((-634 $) $ (-763)) NIL)) (-3896 (((-634 |#1|) $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2779 ((|#1| $ (-568)) NIL)) (-3206 (((-917) $) NIL)) (-3233 ((|#1| $) NIL)) (-1458 (($ $ (-763)) NIL) (($ $) NIL)) (-2745 (((-850) $) NIL) (((-634 |#1|) $) NIL) (($ (-634 |#1|)) NIL)) (-2637 (($ (-634 |#1|)) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2919 (*1 *1 *1) (-12 (-4 *1 (-29 *2)) (-4 *2 (-13 (-842) (-558))))) (-1867 (*1 *2 *1) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *2 (-634 *1)) (-4 *1 (-29 *3)))) (-2919 (*1 *1 *1 *2) (-12 (-5 *2 (-1161)) (-4 *1 (-29 *3)) (-4 *3 (-13 (-842) (-558))))) (-1867 (*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-634 *1)) (-4 *1 (-29 *4)))) (-3505 (*1 *1 *1) (-12 (-4 *1 (-29 *2)) (-4 *2 (-13 (-842) (-558))))) (-2251 (*1 *2 *1) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *2 (-634 *1)) (-4 *1 (-29 *3)))) (-3505 (*1 *1 *1 *2) (-12 (-5 *2 (-1161)) (-4 *1 (-29 *3)) (-4 *3 (-13 (-842) (-558))))) (-2251 (*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-634 *1)) (-4 *1 (-29 *4))))) 
+(-13 (-27) (-432 |t#1|) (-10 -8 (-15 -2919 ($ $)) (-15 -1867 ((-634 $) $)) (-15 -2919 ($ $ (-1161))) (-15 -1867 ((-634 $) $ (-1161))) (-15 -3505 ($ $)) (-15 -2251 ((-634 $) $)) (-15 -3505 ($ $ (-1161))) (-15 -2251 ((-634 $) $ (-1161))))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) . T) ((-27) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 |#1| |#1|) |has| |#1| (-172)) ((-120 $ $) . T) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-609 (-887 (-381))) |has| |#1| (-609 (-887 (-381)))) ((-609 (-887 (-568))) |has| |#1| (-609 (-887 (-568)))) ((-238) . T) ((-285) . T) ((-301) . T) ((-303 $) . T) ((-296) . T) ((-365) . T) ((-379 |#1|) |has| |#1| (-1047)) ((-402 |#1|) . T) ((-413 |#1|) . T) ((-432 |#1|) . T) ((-453) . T) ((-478) |has| |#1| (-478)) ((-523 (-607 $) $) . T) ((-523 $ $) . T) ((-558) . T) ((-637 (-409 (-568))) . T) ((-637 |#1|) |has| |#1| (-172)) ((-637 $) . T) ((-630 (-568)) -12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))) ((-630 |#1|) |has| |#1| (-1047)) ((-707 (-409 (-568))) . T) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) . T) ((-716) . T) ((-842) . T) ((-895 (-1161)) |has| |#1| (-1047)) ((-881 (-381)) |has| |#1| (-881 (-381))) ((-881 (-568)) |has| |#1| (-881 (-568))) ((-879 |#1|) . T) ((-916) . T) ((-1002) . T) ((-1037 (-409 (-568))) -2199 (|has| |#1| (-1037 (-409 (-568)))) (-12 (|has| |#1| (-558)) (|has| |#1| (-1037 (-568))))) ((-1037 (-409 (-953 |#1|))) |has| |#1| (-558)) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 (-607 $)) . T) ((-1037 (-953 |#1|)) |has| |#1| (-1047)) ((-1037 (-1161)) . T) ((-1037 |#1|) . T) ((-1053 (-409 (-568))) . T) ((-1053 |#1|) |has| |#1| (-172)) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1195) . T) ((-1199) . T)) 
+((-1421 (((-1084 (-215)) $) NIL)) (-3679 (((-1084 (-215)) $) NIL)) (-1642 (($ $ (-215)) 122)) (-2164 (($ (-953 (-568)) (-1161) (-1161) (-1084 (-409 (-568))) (-1084 (-409 (-568)))) 84)) (-1878 (((-634 (-634 (-944 (-215)))) $) 134)) (-2747 (((-850) $) 146))) 
+(((-30) (-13 (-955) (-10 -8 (-15 -2164 ($ (-953 (-568)) (-1161) (-1161) (-1084 (-409 (-568))) (-1084 (-409 (-568))))) (-15 -1642 ($ $ (-215)))))) (T -30)) 
+((-2164 (*1 *1 *2 *3 *3 *4 *4) (-12 (-5 *2 (-953 (-568))) (-5 *3 (-1161)) (-5 *4 (-1084 (-409 (-568)))) (-5 *1 (-30)))) (-1642 (*1 *1 *1 *2) (-12 (-5 *2 (-215)) (-5 *1 (-30))))) 
+(-13 (-955) (-10 -8 (-15 -2164 ($ (-953 (-568)) (-1161) (-1161) (-1084 (-409 (-568))) (-1084 (-409 (-568))))) (-15 -1642 ($ $ (-215))))) 
+((-1868 (((-3 (-634 |#5|) "failed" "Infinite" (-568)) |#3|) 38)) (-4470 (((-634 |#5|) |#3| (-917)) 33)) (-4453 (((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-634 |#3|)) 40))) 
+(((-31 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -4453 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-634 |#3|))) (-15 -1868 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) |#3|)) (-15 -4470 ((-634 |#5|) |#3| (-917)))) (-365) (-634 (-1161)) (-950 |#1| |#4| (-852 |#2|)) (-230 (-1699 |#2|) (-763)) (-971 |#1|)) (T -31)) 
+((-4470 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1699 *6) (-763))) (-5 *2 (-634 *8)) (-5 *1 (-31 *5 *6 *3 *7 *8)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5)))) (-1868 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-230 (-1699 *5) (-763))) (-5 *2 (-3 (-634 *7) "failed" "Infinite" (-568))) (-5 *1 (-31 *4 *5 *3 *6 *7)) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *7 (-971 *4)))) (-4453 (*1 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *2 (-3 (-634 *8) "failed" "Infinite" (-568))) (-5 *1 (-31 *4 *5 *6 *7 *8)) (-4 *8 (-971 *4))))) 
+(-10 -7 (-15 -4453 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-634 |#3|))) (-15 -1868 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) |#3|)) (-15 -4470 ((-634 |#5|) |#3| (-917)))) 
+((-3580 (((-1157 (-1157 |#1|)) |#3|) 35)) (-3968 (((-634 (-634 (-1157 (-1157 |#1|)))) (-634 (-1157 (-1157 |#1|)))) 54)) (-1868 (((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-1157 (-1157 |#1|))) 56) (((-3 (-634 |#5|) "failed" "Infinite" (-568)) |#3|) 57)) (-4470 (((-3 (-634 |#5|) "failed" "Infinite" (-568)) |#3| (-917)) 51)) (-2304 (((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-634 (-1157 (-1157 |#1|)))) 70)) (-4453 (((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-634 |#3|)) 50))) 
+(((-32 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1868 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) |#3|)) (-15 -1868 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-1157 (-1157 |#1|)))) (-15 -2304 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-634 (-1157 (-1157 |#1|))))) (-15 -4453 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-634 |#3|))) (-15 -3580 ((-1157 (-1157 |#1|)) |#3|)) (-15 -3968 ((-634 (-634 (-1157 (-1157 |#1|)))) (-634 (-1157 (-1157 |#1|))))) (-15 -4470 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) |#3| (-917)))) (-365) (-634 (-1161)) (-950 |#1| |#4| (-852 |#2|)) (-230 (-1699 |#2|) (-763)) (-971 |#1|)) (T -32)) 
+((-4470 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1699 *6) (-763))) (-5 *2 (-3 (-634 *8) "failed" "Infinite" (-568))) (-5 *1 (-32 *5 *6 *3 *7 *8)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5)))) (-3968 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *7 (-230 (-1699 *5) (-763))) (-5 *2 (-634 (-634 (-1157 (-1157 *4))))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-5 *3 (-634 (-1157 (-1157 *4)))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *8 (-971 *4)))) (-3580 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-230 (-1699 *5) (-763))) (-5 *2 (-1157 (-1157 *4))) (-5 *1 (-32 *4 *5 *3 *6 *7)) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *7 (-971 *4)))) (-4453 (*1 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *2 (-3 (-634 *8) "failed" "Infinite" (-568))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *8 (-971 *4)))) (-2304 (*1 *2 *3) (-12 (-5 *3 (-634 (-1157 (-1157 *4)))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *7 (-230 (-1699 *5) (-763))) (-5 *2 (-3 (-634 *8) "failed" "Infinite" (-568))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *8 (-971 *4)))) (-1868 (*1 *2 *3) (-12 (-5 *3 (-1157 (-1157 *4))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *7 (-230 (-1699 *5) (-763))) (-5 *2 (-3 (-634 *8) "failed" "Infinite" (-568))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *8 (-971 *4)))) (-1868 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-230 (-1699 *5) (-763))) (-5 *2 (-3 (-634 *7) "failed" "Infinite" (-568))) (-5 *1 (-32 *4 *5 *3 *6 *7)) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *7 (-971 *4))))) 
+(-10 -7 (-15 -1868 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) |#3|)) (-15 -1868 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-1157 (-1157 |#1|)))) (-15 -2304 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-634 (-1157 (-1157 |#1|))))) (-15 -4453 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) (-634 |#3|))) (-15 -3580 ((-1157 (-1157 |#1|)) |#3|)) (-15 -3968 ((-634 (-634 (-1157 (-1157 |#1|)))) (-634 (-1157 (-1157 |#1|))))) (-15 -4470 ((-3 (-634 |#5|) "failed" "Infinite" (-568)) |#3| (-917)))) 
+((-2449 (((-121) $ $) NIL)) (-2438 ((|#1| $ (-568) |#1|) NIL)) (-2613 (((-634 $) (-634 $) (-763)) NIL) (((-634 $) (-634 $)) NIL)) (-1338 (((-121) $ (-763)) NIL) (((-121) $) NIL)) (-2034 (((-634 |#1|) $) NIL)) (-2649 (($) NIL)) (-4450 (((-634 $) $) NIL) (((-634 $) $ (-763)) NIL)) (-3897 (((-634 |#1|) $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2781 ((|#1| $ (-568)) NIL)) (-1836 (((-917) $) NIL)) (-1937 ((|#1| $) NIL)) (-2387 (($ $ (-763)) NIL) (($ $) NIL)) (-2747 (((-850) $) NIL) (((-634 |#1|) $) NIL) (($ (-634 |#1|)) NIL)) (-4299 (($ (-634 |#1|)) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-33 |#1|) (-37 |#1|) (-365)) (T -33)) 
 NIL 
 (-37 |#1|) 
-((-2447 (((-121) $ $) NIL)) (-2436 (((-857 |#1|) $ (-568) (-857 |#1|)) NIL)) (-1501 (((-634 $) (-634 $) (-763)) NIL) (((-634 $) (-634 $)) NIL)) (-2688 (((-121) $ (-763)) NIL) (((-121) $) NIL)) (-3890 (((-634 (-857 |#1|)) $) NIL)) (-2476 (($) NIL)) (-3340 (((-634 $) $) NIL) (((-634 $) $ (-763)) NIL)) (-3896 (((-634 (-857 |#1|)) $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2779 (((-857 |#1|) $ (-568)) NIL)) (-3206 (((-917) $) NIL)) (-3233 (((-857 |#1|) $) NIL)) (-1458 (($ $ (-763)) NIL) (($ $) NIL)) (-2745 (((-850) $) NIL) (((-634 (-857 |#1|)) $) NIL) (($ (-634 (-857 |#1|))) NIL)) (-2637 (($ (-634 (-857 |#1|))) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-2438 (((-857 |#1|) $ (-568) (-857 |#1|)) NIL)) (-2613 (((-634 $) (-634 $) (-763)) NIL) (((-634 $) (-634 $)) NIL)) (-1338 (((-121) $ (-763)) NIL) (((-121) $) NIL)) (-2034 (((-634 (-857 |#1|)) $) NIL)) (-2649 (($) NIL)) (-4450 (((-634 $) $) NIL) (((-634 $) $ (-763)) NIL)) (-3897 (((-634 (-857 |#1|)) $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2781 (((-857 |#1|) $ (-568)) NIL)) (-1836 (((-917) $) NIL)) (-1937 (((-857 |#1|) $) NIL)) (-2387 (($ $ (-763)) NIL) (($ $) NIL)) (-2747 (((-850) $) NIL) (((-634 (-857 |#1|)) $) NIL) (($ (-634 (-857 |#1|))) NIL)) (-4299 (($ (-634 (-857 |#1|))) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-34 |#1|) (-37 (-857 |#1|)) (-350)) (T -34)) 
 NIL 
 (-37 (-857 |#1|)) 
-((-2447 (((-121) $ $) NIL)) (-2436 ((|#2| $ (-568) |#2|) NIL)) (-1501 (((-634 $) (-634 $) (-763)) 39) (((-634 $) (-634 $)) 40)) (-2688 (((-121) $ (-763)) 36) (((-121) $) 38)) (-3890 (((-634 |#2|) $) 31)) (-2476 (($) 12)) (-3340 (((-634 $) $) 48) (((-634 $) $ (-763)) 45)) (-3896 (((-634 |#2|) $) 30)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2779 ((|#2| $ (-568)) NIL)) (-3206 (((-917) $) 20)) (-3233 ((|#2| $) 26)) (-1458 (($ $ (-763)) 33) (($ $) 47)) (-2745 (((-850) $) 23) (((-634 |#2|) $) 28) (($ (-634 |#2|)) 51)) (-2637 (($ (-634 |#2|)) 29)) (-1717 (((-121) $ $) 35))) 
+((-2449 (((-121) $ $) NIL)) (-2438 ((|#2| $ (-568) |#2|) NIL)) (-2613 (((-634 $) (-634 $) (-763)) 39) (((-634 $) (-634 $)) 40)) (-1338 (((-121) $ (-763)) 36) (((-121) $) 38)) (-2034 (((-634 |#2|) $) 31)) (-2649 (($) 12)) (-4450 (((-634 $) $) 48) (((-634 $) $ (-763)) 45)) (-3897 (((-634 |#2|) $) 30)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2781 ((|#2| $ (-568)) NIL)) (-1836 (((-917) $) 20)) (-1937 ((|#2| $) 26)) (-2387 (($ $ (-763)) 33) (($ $) 47)) (-2747 (((-850) $) 23) (((-634 |#2|) $) 28) (($ (-634 |#2|)) 51)) (-4299 (($ (-634 |#2|)) 29)) (-1719 (((-121) $ $) 35))) 
 (((-35 |#1| |#2|) (-37 |#2|) (-763) (-365)) (T -35)) 
 NIL 
 (-37 |#2|) 
-((-2932 ((|#2| (-1157 |#2|) (-1161)) 42)) (-3488 (((-123) (-123)) 54)) (-3007 (((-1157 |#2|) (-607 |#2|)) 129 (|has| |#1| (-1037 (-568))))) (-4033 ((|#2| |#1| (-568)) 108 (|has| |#1| (-1037 (-568))))) (-3207 ((|#2| (-1157 |#2|) |#2|) 30)) (-1875 (((-850) (-634 |#2|)) 84)) (-1626 ((|#2| |#2|) 125 (|has| |#1| (-1037 (-568))))) (-2887 (((-121) (-123)) 18)) (** ((|#2| |#2| (-409 (-568))) 89 (|has| |#1| (-1037 (-568)))))) 
-(((-36 |#1| |#2|) (-10 -7 (-15 -2932 (|#2| (-1157 |#2|) (-1161))) (-15 -3488 ((-123) (-123))) (-15 -2887 ((-121) (-123))) (-15 -3207 (|#2| (-1157 |#2|) |#2|)) (-15 -1875 ((-850) (-634 |#2|))) (IF (|has| |#1| (-1037 (-568))) (PROGN (-15 ** (|#2| |#2| (-409 (-568)))) (-15 -3007 ((-1157 |#2|) (-607 |#2|))) (-15 -1626 (|#2| |#2|)) (-15 -4033 (|#2| |#1| (-568)))) |noBranch|)) (-13 (-842) (-558)) (-432 |#1|)) (T -36)) 
-((-4033 (*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *2 (-432 *3)) (-5 *1 (-36 *3 *2)) (-4 *3 (-1037 *4)) (-4 *3 (-13 (-842) (-558))))) (-1626 (*1 *2 *2) (-12 (-4 *3 (-1037 (-568))) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-36 *3 *2)) (-4 *2 (-432 *3)))) (-3007 (*1 *2 *3) (-12 (-5 *3 (-607 *5)) (-4 *5 (-432 *4)) (-4 *4 (-1037 (-568))) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-1157 *5)) (-5 *1 (-36 *4 *5)))) (** (*1 *2 *2 *3) (-12 (-5 *3 (-409 (-568))) (-4 *4 (-1037 (-568))) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-36 *4 *2)) (-4 *2 (-432 *4)))) (-1875 (*1 *2 *3) (-12 (-5 *3 (-634 *5)) (-4 *5 (-432 *4)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-850)) (-5 *1 (-36 *4 *5)))) (-3207 (*1 *2 *3 *2) (-12 (-5 *3 (-1157 *2)) (-4 *2 (-432 *4)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-36 *4 *2)))) (-2887 (*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-36 *4 *5)) (-4 *5 (-432 *4)))) (-3488 (*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-36 *3 *4)) (-4 *4 (-432 *3)))) (-2932 (*1 *2 *3 *4) (-12 (-5 *3 (-1157 *2)) (-5 *4 (-1161)) (-4 *2 (-432 *5)) (-5 *1 (-36 *5 *2)) (-4 *5 (-13 (-842) (-558)))))) 
-(-10 -7 (-15 -2932 (|#2| (-1157 |#2|) (-1161))) (-15 -3488 ((-123) (-123))) (-15 -2887 ((-121) (-123))) (-15 -3207 (|#2| (-1157 |#2|) |#2|)) (-15 -1875 ((-850) (-634 |#2|))) (IF (|has| |#1| (-1037 (-568))) (PROGN (-15 ** (|#2| |#2| (-409 (-568)))) (-15 -3007 ((-1157 |#2|) (-607 |#2|))) (-15 -1626 (|#2| |#2|)) (-15 -4033 (|#2| |#1| (-568)))) |noBranch|)) 
-((-2447 (((-121) $ $) 7)) (-2436 ((|#1| $ (-568) |#1|) 14)) (-1501 (((-634 $) (-634 $) (-763)) 20) (((-634 $) (-634 $)) 19)) (-2688 (((-121) $ (-763)) 18) (((-121) $) 17)) (-3890 (((-634 |#1|) $) 13)) (-2476 (($) 29)) (-3340 (((-634 $) $) 24) (((-634 $) $ (-763)) 23)) (-3896 (((-634 |#1|) $) 16)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2779 ((|#1| $ (-568)) 15)) (-3206 (((-917) $) 12)) (-3233 ((|#1| $) 27)) (-1458 (($ $ (-763)) 22) (($ $) 21)) (-2745 (((-850) $) 11) (((-634 |#1|) $) 26) (($ (-634 |#1|)) 25)) (-2637 (($ (-634 |#1|)) 28)) (-1717 (((-121) $ $) 6))) 
+((-2919 ((|#2| (-1157 |#2|) (-1161)) 42)) (-3842 (((-123) (-123)) 54)) (-3170 (((-1157 |#2|) (-607 |#2|)) 129 (|has| |#1| (-1037 (-568))))) (-1496 ((|#2| |#1| (-568)) 108 (|has| |#1| (-1037 (-568))))) (-1838 ((|#2| (-1157 |#2|) |#2|) 30)) (-2509 (((-850) (-634 |#2|)) 84)) (-1492 ((|#2| |#2|) 125 (|has| |#1| (-1037 (-568))))) (-2779 (((-121) (-123)) 18)) (** ((|#2| |#2| (-409 (-568))) 89 (|has| |#1| (-1037 (-568)))))) 
+(((-36 |#1| |#2|) (-10 -7 (-15 -2919 (|#2| (-1157 |#2|) (-1161))) (-15 -3842 ((-123) (-123))) (-15 -2779 ((-121) (-123))) (-15 -1838 (|#2| (-1157 |#2|) |#2|)) (-15 -2509 ((-850) (-634 |#2|))) (IF (|has| |#1| (-1037 (-568))) (PROGN (-15 ** (|#2| |#2| (-409 (-568)))) (-15 -3170 ((-1157 |#2|) (-607 |#2|))) (-15 -1492 (|#2| |#2|)) (-15 -1496 (|#2| |#1| (-568)))) |noBranch|)) (-13 (-842) (-558)) (-432 |#1|)) (T -36)) 
+((-1496 (*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *2 (-432 *3)) (-5 *1 (-36 *3 *2)) (-4 *3 (-1037 *4)) (-4 *3 (-13 (-842) (-558))))) (-1492 (*1 *2 *2) (-12 (-4 *3 (-1037 (-568))) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-36 *3 *2)) (-4 *2 (-432 *3)))) (-3170 (*1 *2 *3) (-12 (-5 *3 (-607 *5)) (-4 *5 (-432 *4)) (-4 *4 (-1037 (-568))) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-1157 *5)) (-5 *1 (-36 *4 *5)))) (** (*1 *2 *2 *3) (-12 (-5 *3 (-409 (-568))) (-4 *4 (-1037 (-568))) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-36 *4 *2)) (-4 *2 (-432 *4)))) (-2509 (*1 *2 *3) (-12 (-5 *3 (-634 *5)) (-4 *5 (-432 *4)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-850)) (-5 *1 (-36 *4 *5)))) (-1838 (*1 *2 *3 *2) (-12 (-5 *3 (-1157 *2)) (-4 *2 (-432 *4)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-36 *4 *2)))) (-2779 (*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-36 *4 *5)) (-4 *5 (-432 *4)))) (-3842 (*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-36 *3 *4)) (-4 *4 (-432 *3)))) (-2919 (*1 *2 *3 *4) (-12 (-5 *3 (-1157 *2)) (-5 *4 (-1161)) (-4 *2 (-432 *5)) (-5 *1 (-36 *5 *2)) (-4 *5 (-13 (-842) (-558)))))) 
+(-10 -7 (-15 -2919 (|#2| (-1157 |#2|) (-1161))) (-15 -3842 ((-123) (-123))) (-15 -2779 ((-121) (-123))) (-15 -1838 (|#2| (-1157 |#2|) |#2|)) (-15 -2509 ((-850) (-634 |#2|))) (IF (|has| |#1| (-1037 (-568))) (PROGN (-15 ** (|#2| |#2| (-409 (-568)))) (-15 -3170 ((-1157 |#2|) (-607 |#2|))) (-15 -1492 (|#2| |#2|)) (-15 -1496 (|#2| |#1| (-568)))) |noBranch|)) 
+((-2449 (((-121) $ $) 7)) (-2438 ((|#1| $ (-568) |#1|) 14)) (-2613 (((-634 $) (-634 $) (-763)) 20) (((-634 $) (-634 $)) 19)) (-1338 (((-121) $ (-763)) 18) (((-121) $) 17)) (-2034 (((-634 |#1|) $) 13)) (-2649 (($) 29)) (-4450 (((-634 $) $) 24) (((-634 $) $ (-763)) 23)) (-3897 (((-634 |#1|) $) 16)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2781 ((|#1| $ (-568)) 15)) (-1836 (((-917) $) 12)) (-1937 ((|#1| $) 27)) (-2387 (($ $ (-763)) 22) (($ $) 21)) (-2747 (((-850) $) 11) (((-634 |#1|) $) 26) (($ (-634 |#1|)) 25)) (-4299 (($ (-634 |#1|)) 28)) (-1719 (((-121) $ $) 6))) 
 (((-37 |#1|) (-1275) (-365)) (T -37)) 
-((-2476 (*1 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-365)))) (-2637 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-4 *1 (-37 *3)))) (-3233 (*1 *2 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-365)))) (-2745 (*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-365)) (-5 *2 (-634 *3)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-4 *1 (-37 *3)))) (-3340 (*1 *2 *1) (-12 (-4 *3 (-365)) (-5 *2 (-634 *1)) (-4 *1 (-37 *3)))) (-3340 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *4 (-365)) (-5 *2 (-634 *1)) (-4 *1 (-37 *4)))) (-1458 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-37 *3)) (-4 *3 (-365)))) (-1458 (*1 *1 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-365)))) (-1501 (*1 *2 *2 *3) (-12 (-5 *2 (-634 *1)) (-5 *3 (-763)) (-4 *1 (-37 *4)) (-4 *4 (-365)))) (-1501 (*1 *2 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-37 *3)) (-4 *3 (-365)))) (-2688 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-37 *4)) (-4 *4 (-365)) (-5 *2 (-121)))) (-2688 (*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-365)) (-5 *2 (-121)))) (-3896 (*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-365)) (-5 *2 (-634 *3)))) (-2779 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-37 *2)) (-4 *2 (-365)))) (-2436 (*1 *2 *1 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-37 *2)) (-4 *2 (-365)))) (-3890 (*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-365)) (-5 *2 (-634 *3))))) 
-(-13 (-1088) (-10 -8 (-15 -2476 ($)) (-15 -2637 ($ (-634 |t#1|))) (-15 -3233 (|t#1| $)) (-15 -2745 ((-634 |t#1|) $)) (-15 -2745 ($ (-634 |t#1|))) (-15 -3340 ((-634 $) $)) (-15 -3340 ((-634 $) $ (-763))) (-15 -1458 ($ $ (-763))) (-15 -1458 ($ $)) (-15 -1501 ((-634 $) (-634 $) (-763))) (-15 -1501 ((-634 $) (-634 $))) (-15 -2688 ((-121) $ (-763))) (-15 -2688 ((-121) $)) (-15 -3896 ((-634 |t#1|) $)) (-15 -2779 (|t#1| $ (-568))) (-15 -2436 (|t#1| $ (-568) |t#1|)) (-15 -3890 ((-634 |t#1|) $)))) 
+((-2649 (*1 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-365)))) (-4299 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-4 *1 (-37 *3)))) (-1937 (*1 *2 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-365)))) (-2747 (*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-365)) (-5 *2 (-634 *3)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-4 *1 (-37 *3)))) (-4450 (*1 *2 *1) (-12 (-4 *3 (-365)) (-5 *2 (-634 *1)) (-4 *1 (-37 *3)))) (-4450 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *4 (-365)) (-5 *2 (-634 *1)) (-4 *1 (-37 *4)))) (-2387 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-37 *3)) (-4 *3 (-365)))) (-2387 (*1 *1 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-365)))) (-2613 (*1 *2 *2 *3) (-12 (-5 *2 (-634 *1)) (-5 *3 (-763)) (-4 *1 (-37 *4)) (-4 *4 (-365)))) (-2613 (*1 *2 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-37 *3)) (-4 *3 (-365)))) (-1338 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-37 *4)) (-4 *4 (-365)) (-5 *2 (-121)))) (-1338 (*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-365)) (-5 *2 (-121)))) (-3897 (*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-365)) (-5 *2 (-634 *3)))) (-2781 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-37 *2)) (-4 *2 (-365)))) (-2438 (*1 *2 *1 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-37 *2)) (-4 *2 (-365)))) (-2034 (*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-365)) (-5 *2 (-634 *3))))) 
+(-13 (-1088) (-10 -8 (-15 -2649 ($)) (-15 -4299 ($ (-634 |t#1|))) (-15 -1937 (|t#1| $)) (-15 -2747 ((-634 |t#1|) $)) (-15 -2747 ($ (-634 |t#1|))) (-15 -4450 ((-634 $) $)) (-15 -4450 ((-634 $) $ (-763))) (-15 -2387 ($ $ (-763))) (-15 -2387 ($ $)) (-15 -2613 ((-634 $) (-634 $) (-763))) (-15 -2613 ((-634 $) (-634 $))) (-15 -1338 ((-121) $ (-763))) (-15 -1338 ((-121) $)) (-15 -3897 ((-634 |t#1|) $)) (-15 -2781 (|t#1| $ (-568))) (-15 -2438 (|t#1| $ (-568) |t#1|)) (-15 -2034 ((-634 |t#1|) $)))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T) ((-1088) . T)) 
-((-2510 (((-121) $ (-763)) 16)) (-2671 (($) 10)) (-1737 (((-121) $ (-763)) 15)) (-2166 (((-121) $ (-763)) 14)) (-3171 (((-121) $ $) 8)) (-3084 (((-121) $) 13))) 
-(((-38 |#1|) (-10 -8 (-15 -2671 (|#1|)) (-15 -2510 ((-121) |#1| (-763))) (-15 -1737 ((-121) |#1| (-763))) (-15 -2166 ((-121) |#1| (-763))) (-15 -3084 ((-121) |#1|)) (-15 -3171 ((-121) |#1| |#1|))) (-39)) (T -38)) 
+((-1667 (((-121) $ (-763)) 16)) (-4490 (($) 10)) (-3791 (((-121) $ (-763)) 15)) (-3796 (((-121) $ (-763)) 14)) (-1702 (((-121) $ $) 8)) (-2436 (((-121) $) 13))) 
+(((-38 |#1|) (-10 -8 (-15 -4490 (|#1|)) (-15 -1667 ((-121) |#1| (-763))) (-15 -3791 ((-121) |#1| (-763))) (-15 -3796 ((-121) |#1| (-763))) (-15 -2436 ((-121) |#1|)) (-15 -1702 ((-121) |#1| |#1|))) (-39)) (T -38)) 
 NIL 
-(-10 -8 (-15 -2671 (|#1|)) (-15 -2510 ((-121) |#1| (-763))) (-15 -1737 ((-121) |#1| (-763))) (-15 -2166 ((-121) |#1| (-763))) (-15 -3084 ((-121) |#1|)) (-15 -3171 ((-121) |#1| |#1|))) 
-((-2510 (((-121) $ (-763)) 8)) (-2671 (($) 7 T CONST)) (-1737 (((-121) $ (-763)) 9)) (-2166 (((-121) $ (-763)) 10)) (-3171 (((-121) $ $) 14)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-3863 (($ $) 13)) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+(-10 -8 (-15 -4490 (|#1|)) (-15 -1667 ((-121) |#1| (-763))) (-15 -3791 ((-121) |#1| (-763))) (-15 -3796 ((-121) |#1| (-763))) (-15 -2436 ((-121) |#1|)) (-15 -1702 ((-121) |#1| |#1|))) 
+((-1667 (((-121) $ (-763)) 8)) (-4490 (($) 7 T CONST)) (-3791 (((-121) $ (-763)) 9)) (-3796 (((-121) $ (-763)) 10)) (-1702 (((-121) $ $) 14)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-3865 (($ $) 13)) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-39) (-1275)) (T -39)) 
-((-3171 (*1 *2 *1 *1) (-12 (-4 *1 (-39)) (-5 *2 (-121)))) (-3863 (*1 *1 *1) (-4 *1 (-39))) (-3248 (*1 *1) (-4 *1 (-39))) (-3084 (*1 *2 *1) (-12 (-4 *1 (-39)) (-5 *2 (-121)))) (-2166 (*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-763)) (-5 *2 (-121)))) (-1737 (*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-763)) (-5 *2 (-121)))) (-2510 (*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-763)) (-5 *2 (-121)))) (-2671 (*1 *1) (-4 *1 (-39))) (-1697 (*1 *2 *1) (-12 (|has| *1 (-6 -4519)) (-4 *1 (-39)) (-5 *2 (-763))))) 
-(-13 (-1195) (-10 -8 (-15 -3171 ((-121) $ $)) (-15 -3863 ($ $)) (-15 -3248 ($)) (-15 -3084 ((-121) $)) (-15 -2166 ((-121) $ (-763))) (-15 -1737 ((-121) $ (-763))) (-15 -2510 ((-121) $ (-763))) (-15 -2671 ($) -3495) (IF (|has| $ (-6 -4519)) (-15 -1697 ((-763) $)) |noBranch|))) 
+((-1702 (*1 *2 *1 *1) (-12 (-4 *1 (-39)) (-5 *2 (-121)))) (-3865 (*1 *1 *1) (-4 *1 (-39))) (-1990 (*1 *1) (-4 *1 (-39))) (-2436 (*1 *2 *1) (-12 (-4 *1 (-39)) (-5 *2 (-121)))) (-3796 (*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-763)) (-5 *2 (-121)))) (-3791 (*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-763)) (-5 *2 (-121)))) (-1667 (*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-763)) (-5 *2 (-121)))) (-4490 (*1 *1) (-4 *1 (-39))) (-1699 (*1 *2 *1) (-12 (|has| *1 (-6 -4521)) (-4 *1 (-39)) (-5 *2 (-763))))) 
+(-13 (-1195) (-10 -8 (-15 -1702 ((-121) $ $)) (-15 -3865 ($ $)) (-15 -1990 ($)) (-15 -2436 ((-121) $)) (-15 -3796 ((-121) $ (-763))) (-15 -3791 ((-121) $ (-763))) (-15 -1667 ((-121) $ (-763))) (-15 -4490 ($) -3497) (IF (|has| $ (-6 -4521)) (-15 -1699 ((-763) $)) |noBranch|))) 
 (((-1195) . T)) 
-((-2006 (($ $) 11)) (-1998 (($ $) 10)) (-2014 (($ $) 9)) (-4023 (($ $) 8)) (-2010 (($ $) 7)) (-2002 (($ $) 6))) 
+((-2008 (($ $) 11)) (-2000 (($ $) 10)) (-2016 (($ $) 9)) (-1439 (($ $) 8)) (-2012 (($ $) 7)) (-2004 (($ $) 6))) 
 (((-40) (-1275)) (T -40)) 
-((-2006 (*1 *1 *1) (-4 *1 (-40))) (-1998 (*1 *1 *1) (-4 *1 (-40))) (-2014 (*1 *1 *1) (-4 *1 (-40))) (-4023 (*1 *1 *1) (-4 *1 (-40))) (-2010 (*1 *1 *1) (-4 *1 (-40))) (-2002 (*1 *1 *1) (-4 *1 (-40)))) 
-(-13 (-10 -8 (-15 -2002 ($ $)) (-15 -2010 ($ $)) (-15 -4023 ($ $)) (-15 -2014 ($ $)) (-15 -1998 ($ $)) (-15 -2006 ($ $)))) 
-((-2447 (((-121) $ $) 18 (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-2850 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 117)) (-2235 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 140)) (-2796 (($ $) 138)) (-2986 (($) 66) (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) 65)) (-1868 (((-1249) $ |#1| |#1|) 93 (|has| $ (-6 -4520))) (((-1249) $ (-568) (-568)) 170 (|has| $ (-6 -4520)))) (-3910 (($ $ (-568)) 151 (|has| $ (-6 -4520)))) (-2016 (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 201) (((-121) $) 195 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842)))) (-3908 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 192 (|has| $ (-6 -4520))) (($ $) 191 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842)) (|has| $ (-6 -4520))))) (-3644 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 202) (($ $) 196 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842)))) (-2510 (((-121) $ (-763)) 8)) (-1659 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 126 (|has| $ (-6 -4520)))) (-3869 (($ $ $) 147 (|has| $ (-6 -4520)))) (-2395 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 149 (|has| $ (-6 -4520)))) (-2517 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 145 (|has| $ (-6 -4520)))) (-2436 ((|#2| $ |#1| |#2|) 67) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-568) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 181 (|has| $ (-6 -4520))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-1210 (-568)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 152 (|has| $ (-6 -4520))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ "last" (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 150 (|has| $ (-6 -4520))) (($ $ "rest" $) 148 (|has| $ (-6 -4520))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ "first" (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 146 (|has| $ (-6 -4520))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ "value" (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 125 (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) 124 (|has| $ (-6 -4520)))) (-3507 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 42 (|has| $ (-6 -4519))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 208)) (-2801 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 52 (|has| $ (-6 -4519))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 167 (|has| $ (-6 -4519)))) (-1679 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 139)) (-2674 (((-3 |#2| "failed") |#1| $) 57)) (-2671 (($) 7 T CONST)) (-1578 (($ $) 193 (|has| $ (-6 -4520)))) (-3943 (($ $) 203)) (-3935 (($ $ (-763)) 134) (($ $) 132)) (-3369 (($ $) 206 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (-3924 (($ $) 55 (-2198 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| $ (-6 -4519))) (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| $ (-6 -4519)))))) (-3405 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 44 (|has| $ (-6 -4519))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 43 (|has| $ (-6 -4519))) (((-3 |#2| "failed") |#1| $) 58) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 212) (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 207 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (-4328 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 54 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 51 (|has| $ (-6 -4519))) (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 169 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 166 (|has| $ (-6 -4519)))) (-3092 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 53 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| $ (-6 -4519)))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 50 (|has| $ (-6 -4519))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 49 (|has| $ (-6 -4519))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 168 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| $ (-6 -4519)))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 165 (|has| $ (-6 -4519))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 164 (|has| $ (-6 -4519)))) (-3989 ((|#2| $ |#1| |#2|) 81 (|has| $ (-6 -4520))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-568) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 182 (|has| $ (-6 -4520)))) (-2602 ((|#2| $ |#1|) 82) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-568)) 180)) (-1601 (((-121) $) 184)) (-2764 (((-568) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 200) (((-568) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 199 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))) (((-568) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-568)) 198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (-4360 (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 30 (|has| $ (-6 -4519))) (((-634 |#2|) $) 73 (|has| $ (-6 -4519))) (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 106 (|has| $ (-6 -4519)))) (-2287 (((-634 $) $) 115)) (-1700 (((-121) $ $) 123 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (-1849 (($ (-763) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 161)) (-1737 (((-121) $ (-763)) 9)) (-1881 ((|#1| $) 90 (|has| |#1| (-842))) (((-568) $) 172 (|has| (-568) (-842)))) (-2521 (($ $ $) 190 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842)))) (-3349 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ $) 209) (($ $ $) 205 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842)))) (-1347 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ $) 204) (($ $ $) 197 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842)))) (-1979 (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 29 (|has| $ (-6 -4519))) (((-634 |#2|) $) 74 (|has| $ (-6 -4519))) (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 107 (|has| $ (-6 -4519)))) (-3109 (((-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 27 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| $ (-6 -4519)))) (((-121) |#2| $) 76 (-12 (|has| |#2| (-1090)) (|has| $ (-6 -4519)))) (((-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 109 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| $ (-6 -4519))))) (-2223 ((|#1| $) 89 (|has| |#1| (-842))) (((-568) $) 173 (|has| (-568) (-842)))) (-3268 (($ $ $) 189 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842)))) (-3674 (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 34 (|has| $ (-6 -4520))) (($ (-1 |#2| |#2|) $) 69 (|has| $ (-6 -4520))) (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 102 (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 35) (($ (-1 |#2| |#2|) $) 68) (($ (-1 |#2| |#2| |#2|) $ $) 64) (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ $) 158) (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 101)) (-3896 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 217)) (-2166 (((-121) $ (-763)) 10)) (-2869 (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 120)) (-1651 (((-121) $) 116)) (-4487 (((-1143) $) 22 (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-4162 (($ $ (-763)) 137) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 135)) (-1946 (((-634 |#1|) $) 59)) (-3548 (((-121) |#1| $) 60)) (-1890 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 36)) (-4450 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 37) (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-568)) 211) (($ $ $ (-568)) 210)) (-4122 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-568)) 154) (($ $ $ (-568)) 153)) (-4174 (((-634 |#1|) $) 87) (((-634 (-568)) $) 175)) (-3578 (((-121) |#1| $) 86) (((-121) (-568) $) 176)) (-4022 (((-1108) $) 21 (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-3876 ((|#2| $) 91 (|has| |#1| (-842))) (($ $ (-763)) 131) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 129)) (-3775 (((-3 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) "failed") (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 48) (((-3 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) "failed") (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 163)) (-3724 (($ $ |#2|) 92 (|has| $ (-6 -4520))) (($ $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 171 (|has| $ (-6 -4520)))) (-1315 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 38)) (-1786 (((-121) $) 183)) (-1387 (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 32 (|has| $ (-6 -4519))) (((-121) (-1 (-121) |#2|) $) 71 (|has| $ (-6 -4519))) (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 104 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) 26 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) 25 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 24 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) 23 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) 80 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) 79 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) 78 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 (-288 |#2|))) 77 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) 113 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 112 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) 111 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-634 (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) 110 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-3171 (((-121) $ $) 14)) (-4467 (((-121) |#2| $) 88 (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090)))) (((-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 174 (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-2041 (((-634 |#2|) $) 85) (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 177)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 ((|#2| $ |#1|) 84) ((|#2| $ |#1| |#2|) 83) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-568) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 179) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-568)) 178) (($ $ (-1210 (-568))) 157) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ "last") 136) (($ $ "rest") 133) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ "first") 130) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ "value") 118)) (-4075 (((-568) $ $) 121)) (-2085 (($) 46) (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) 45)) (-1783 (($ $ (-568)) 214) (($ $ (-1210 (-568))) 213)) (-2826 (($ $ (-568)) 156) (($ $ (-1210 (-568))) 155)) (-3790 (((-121) $) 119)) (-2340 (($ $) 143)) (-2714 (($ $) 144 (|has| $ (-6 -4520)))) (-2775 (((-763) $) 142)) (-3335 (($ $) 141)) (-4168 (((-763) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 31 (|has| $ (-6 -4519))) (((-763) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 28 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| $ (-6 -4519)))) (((-763) |#2| $) 75 (-12 (|has| |#2| (-1090)) (|has| $ (-6 -4519)))) (((-763) (-1 (-121) |#2|) $) 72 (|has| $ (-6 -4519))) (((-763) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 108 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| $ (-6 -4519)))) (((-763) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 105 (|has| $ (-6 -4519)))) (-2256 (($ $ $ (-568)) 194 (|has| $ (-6 -4520)))) (-3863 (($ $) 13)) (-4278 (((-541) $) 56 (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-609 (-541))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-609 (-541)))))) (-4287 (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) 47) (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) 162)) (-3845 (($ $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 216) (($ $ $) 215)) (-2768 (($ $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 160) (($ (-634 $)) 159) (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 128) (($ $ $) 127)) (-2745 (((-850) $) 20 (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-4339 (((-634 $) $) 114)) (-3491 (((-121) $ $) 122 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (-2367 (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) 39)) (-2802 (((-3 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) "failed") |#1| $) 100)) (-1319 (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 33 (|has| $ (-6 -4519))) (((-121) (-1 (-121) |#2|) $) 70 (|has| $ (-6 -4519))) (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 103 (|has| $ (-6 -4519)))) (-1751 (((-121) $ $) 187 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842)))) (-1738 (((-121) $ $) 186 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842)))) (-1717 (((-121) $ $) 19 (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-1745 (((-121) $ $) 188 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842)))) (-1732 (((-121) $ $) 185 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-2008 (*1 *1 *1) (-4 *1 (-40))) (-2000 (*1 *1 *1) (-4 *1 (-40))) (-2016 (*1 *1 *1) (-4 *1 (-40))) (-1439 (*1 *1 *1) (-4 *1 (-40))) (-2012 (*1 *1 *1) (-4 *1 (-40))) (-2004 (*1 *1 *1) (-4 *1 (-40)))) 
+(-13 (-10 -8 (-15 -2004 ($ $)) (-15 -2012 ($ $)) (-15 -1439 ($ $)) (-15 -2016 ($ $)) (-15 -2000 ($ $)) (-15 -2008 ($ $)))) 
+((-2449 (((-121) $ $) 18 (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-2852 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 117)) (-2237 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 140)) (-3623 (($ $) 138)) (-2988 (($) 66) (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) 65)) (-2481 (((-1249) $ |#1| |#1|) 93 (|has| $ (-6 -4522))) (((-1249) $ (-568) (-568)) 170 (|has| $ (-6 -4522)))) (-2121 (($ $ (-568)) 151 (|has| $ (-6 -4522)))) (-1324 (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 201) (((-121) $) 195 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842)))) (-2109 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 192 (|has| $ (-6 -4522))) (($ $) 191 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842)) (|has| $ (-6 -4522))))) (-3647 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 202) (($ $) 196 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842)))) (-1667 (((-121) $ (-763)) 8)) (-3370 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 126 (|has| $ (-6 -4522)))) (-1958 (($ $ $) 147 (|has| $ (-6 -4522)))) (-2257 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 149 (|has| $ (-6 -4522)))) (-1706 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 145 (|has| $ (-6 -4522)))) (-2438 ((|#2| $ |#1| |#2|) 67) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-568) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 181 (|has| $ (-6 -4522))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-1210 (-568)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 152 (|has| $ (-6 -4522))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ "last" (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 150 (|has| $ (-6 -4522))) (($ $ "rest" $) 148 (|has| $ (-6 -4522))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ "first" (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 146 (|has| $ (-6 -4522))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ "value" (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 125 (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) 124 (|has| $ (-6 -4522)))) (-3963 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 42 (|has| $ (-6 -4521))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 208)) (-2803 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 52 (|has| $ (-6 -4521))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 167 (|has| $ (-6 -4521)))) (-1681 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 139)) (-2678 (((-3 |#2| "failed") |#1| $) 57)) (-4490 (($) 7 T CONST)) (-4452 (($ $) 193 (|has| $ (-6 -4522)))) (-3945 (($ $) 203)) (-3936 (($ $ (-763)) 134) (($ $) 132)) (-1377 (($ $) 206 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (-3926 (($ $) 55 (-2199 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| $ (-6 -4521))) (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| $ (-6 -4521)))))) (-1568 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 44 (|has| $ (-6 -4521))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 43 (|has| $ (-6 -4521))) (((-3 |#2| "failed") |#1| $) 58) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 212) (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 207 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (-4330 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 54 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 51 (|has| $ (-6 -4521))) (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 169 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 166 (|has| $ (-6 -4521)))) (-3094 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 53 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| $ (-6 -4521)))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 50 (|has| $ (-6 -4521))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 49 (|has| $ (-6 -4521))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 168 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| $ (-6 -4521)))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 165 (|has| $ (-6 -4521))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 164 (|has| $ (-6 -4521)))) (-1292 ((|#2| $ |#1| |#2|) 81 (|has| $ (-6 -4522))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-568) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 182 (|has| $ (-6 -4522)))) (-2069 ((|#2| $ |#1|) 82) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-568)) 180)) (-1340 (((-121) $) 184)) (-2766 (((-568) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 200) (((-568) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))) (((-568) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-568)) 198 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (-3317 (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 30 (|has| $ (-6 -4521))) (((-634 |#2|) $) 73 (|has| $ (-6 -4521))) (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 106 (|has| $ (-6 -4521)))) (-3534 (((-634 $) $) 115)) (-3606 (((-121) $ $) 123 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (-1851 (($ (-763) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 161)) (-3791 (((-121) $ (-763)) 9)) (-2539 ((|#1| $) 90 (|has| |#1| (-842))) (((-568) $) 172 (|has| (-568) (-842)))) (-1732 (($ $ $) 190 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842)))) (-4496 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ $) 209) (($ $ $) 205 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842)))) (-3645 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ $) 204) (($ $ $) 197 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842)))) (-4406 (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 29 (|has| $ (-6 -4521))) (((-634 |#2|) $) 74 (|has| $ (-6 -4521))) (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 107 (|has| $ (-6 -4521)))) (-2551 (((-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 27 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| $ (-6 -4521)))) (((-121) |#2| $) 76 (-12 (|has| |#2| (-1090)) (|has| $ (-6 -4521)))) (((-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 109 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| $ (-6 -4521))))) (-3631 ((|#1| $) 89 (|has| |#1| (-842))) (((-568) $) 173 (|has| (-568) (-842)))) (-2047 (($ $ $) 189 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842)))) (-2253 (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 34 (|has| $ (-6 -4522))) (($ (-1 |#2| |#2|) $) 69 (|has| $ (-6 -4522))) (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 102 (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 35) (($ (-1 |#2| |#2|) $) 68) (($ (-1 |#2| |#2| |#2|) $ $) 64) (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ $) 158) (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 101)) (-3897 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 217)) (-3796 (((-121) $ (-763)) 10)) (-4081 (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 120)) (-3319 (((-121) $) 116)) (-1893 (((-1143) $) 22 (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-4164 (($ $ (-763)) 137) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 135)) (-4253 (((-634 |#1|) $) 59)) (-2807 (((-121) |#1| $) 60)) (-2580 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 36)) (-1708 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 37) (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-568)) 211) (($ $ $ (-568)) 210)) (-4124 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-568)) 154) (($ $ $ (-568)) 153)) (-3948 (((-634 |#1|) $) 87) (((-634 (-568)) $) 175)) (-2916 (((-121) |#1| $) 86) (((-121) (-568) $) 176)) (-4025 (((-1108) $) 21 (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-3877 ((|#2| $) 91 (|has| |#1| (-842))) (($ $ (-763)) 131) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 129)) (-2712 (((-3 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) "failed") (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 48) (((-3 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) "failed") (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 163)) (-2490 (($ $ |#2|) 92 (|has| $ (-6 -4522))) (($ $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 171 (|has| $ (-6 -4522)))) (-3403 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 38)) (-4049 (((-121) $) 183)) (-3951 (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 32 (|has| $ (-6 -4521))) (((-121) (-1 (-121) |#2|) $) 71 (|has| $ (-6 -4521))) (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 104 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) 26 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) 25 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 24 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) 23 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) 80 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) 79 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) 78 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 (-288 |#2|))) 77 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) 113 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 112 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) 111 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-634 (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) 110 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-1702 (((-121) $ $) 14)) (-1801 (((-121) |#2| $) 88 (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090)))) (((-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 174 (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-1480 (((-634 |#2|) $) 85) (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 177)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 ((|#2| $ |#1|) 84) ((|#2| $ |#1| |#2|) 83) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-568) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 179) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-568)) 178) (($ $ (-1210 (-568))) 157) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ "last") 136) (($ $ "rest") 133) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ "first") 130) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ "value") 118)) (-1665 (((-568) $ $) 121)) (-3132 (($) 46) (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) 45)) (-4031 (($ $ (-568)) 214) (($ $ (-1210 (-568))) 213)) (-2828 (($ $ (-568)) 156) (($ $ (-1210 (-568))) 155)) (-2763 (((-121) $) 119)) (-3903 (($ $) 143)) (-1499 (($ $) 144 (|has| $ (-6 -4522)))) (-3535 (((-763) $) 142)) (-4424 (($ $) 141)) (-4170 (((-763) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 31 (|has| $ (-6 -4521))) (((-763) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 28 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| $ (-6 -4521)))) (((-763) |#2| $) 75 (-12 (|has| |#2| (-1090)) (|has| $ (-6 -4521)))) (((-763) (-1 (-121) |#2|) $) 72 (|has| $ (-6 -4521))) (((-763) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 108 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| $ (-6 -4521)))) (((-763) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 105 (|has| $ (-6 -4521)))) (-3306 (($ $ $ (-568)) 194 (|has| $ (-6 -4522)))) (-3865 (($ $) 13)) (-4280 (((-541) $) 56 (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-609 (-541))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-609 (-541)))))) (-4289 (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) 47) (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) 162)) (-1876 (($ $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 216) (($ $ $) 215)) (-2770 (($ $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 160) (($ (-634 $)) 159) (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 128) (($ $ $) 127)) (-2747 (((-850) $) 20 (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-3180 (((-634 $) $) 114)) (-3873 (((-121) $ $) 122 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (-4074 (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) 39)) (-2804 (((-3 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) "failed") |#1| $) 100)) (-3437 (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 33 (|has| $ (-6 -4521))) (((-121) (-1 (-121) |#2|) $) 70 (|has| $ (-6 -4521))) (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 103 (|has| $ (-6 -4521)))) (-1753 (((-121) $ $) 187 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842)))) (-1740 (((-121) $ $) 186 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842)))) (-1719 (((-121) $ $) 19 (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-1747 (((-121) $ $) 188 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842)))) (-1734 (((-121) $ $) 185 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-41 |#1| |#2|) (-1275) (-1090) (-1090)) (T -41)) 
-((-2802 (*1 *2 *3 *1) (|partial| -12 (-4 *1 (-41 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-5 *2 (-2 (|:| -3649 *3) (|:| -4083 *4)))))) 
-(-13 (-1172 |t#1| |t#2|) (-658 (-2 (|:| -3649 |t#1|) (|:| -4083 |t#2|))) (-10 -8 (-15 -2802 ((-3 (-2 (|:| -3649 |t#1|) (|:| -4083 |t#2|)) "failed") |t#1| $)))) 
-(((-39) . T) ((-111 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-105) -2198 (|has| |#2| (-1090)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842))) ((-608 (-850)) -2198 (|has| |#2| (-1090)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842))) ((-154 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-609 (-541)) |has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-609 (-541))) ((-221 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-227 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-281 (-568) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-281 |#1| |#2|) . T) ((-283 (-568) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-283 |#1| |#2|) . T) ((-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) -12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))) ((-303 |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) ((-277 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-375 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-499 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-499 |#2|) . T) ((-601 (-568) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-601 |#1| |#2|) . T) ((-523 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) -12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))) ((-523 |#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) ((-605 |#1| |#2|) . T) ((-640 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-658 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-842) |has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842)) ((-1010 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-1090) -2198 (|has| |#2| (-1090)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842))) ((-1134 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-1172 |#1| |#2|) . T) ((-1195) . T) ((-1231 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T)) 
-((-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#2|) 10))) 
-(((-42 |#1| |#2|) (-10 -8 (-15 -2745 (|#1| |#2|)) (-15 -2745 (|#1| (-568))) (-15 -2745 ((-850) |#1|))) (-43 |#2|) (-172)) (T -42)) 
-NIL 
-(-10 -8 (-15 -2745 (|#1| |#2|)) (-15 -2745 (|#1| (-568))) (-15 -2745 ((-850) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-2925 (((-3 $ "failed") $) 33)) (-2735 (((-121) $) 30)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 36)) (-4078 (((-763)) 28)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37))) 
+((-2804 (*1 *2 *3 *1) (|partial| -12 (-4 *1 (-41 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-5 *2 (-2 (|:| -3651 *3) (|:| -4085 *4)))))) 
+(-13 (-1172 |t#1| |t#2|) (-658 (-2 (|:| -3651 |t#1|) (|:| -4085 |t#2|))) (-10 -8 (-15 -2804 ((-3 (-2 (|:| -3651 |t#1|) (|:| -4085 |t#2|)) "failed") |t#1| $)))) 
+(((-39) . T) ((-111 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-105) -2199 (|has| |#2| (-1090)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842))) ((-608 (-850)) -2199 (|has| |#2| (-1090)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842))) ((-154 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-609 (-541)) |has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-609 (-541))) ((-221 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-227 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-281 (-568) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-281 |#1| |#2|) . T) ((-283 (-568) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-283 |#1| |#2|) . T) ((-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) -12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))) ((-303 |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) ((-277 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-375 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-499 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-499 |#2|) . T) ((-601 (-568) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-601 |#1| |#2|) . T) ((-523 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) -12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))) ((-523 |#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) ((-605 |#1| |#2|) . T) ((-640 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-658 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-842) |has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842)) ((-1010 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-1090) -2199 (|has| |#2| (-1090)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842))) ((-1134 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-1172 |#1| |#2|) . T) ((-1195) . T) ((-1231 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T)) 
+((-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#2|) 10))) 
+(((-42 |#1| |#2|) (-10 -8 (-15 -2747 (|#1| |#2|)) (-15 -2747 (|#1| (-568))) (-15 -2747 ((-850) |#1|))) (-43 |#2|) (-172)) (T -42)) 
+NIL 
+(-10 -8 (-15 -2747 (|#1| |#2|)) (-15 -2747 (|#1| (-568))) (-15 -2747 ((-850) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-2902 (((-3 $ "failed") $) 33)) (-1598 (((-121) $) 30)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 36)) (-3425 (((-763)) 28)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37))) 
 (((-43 |#1|) (-1275) (-172)) (T -43)) 
-((-2745 (*1 *1 *2) (-12 (-4 *1 (-43 *2)) (-4 *2 (-172))))) 
-(-13 (-1047) (-707 |t#1|) (-10 -8 (-15 -2745 ($ |t#1|)))) 
+((-2747 (*1 *1 *2) (-12 (-4 *1 (-43 *2)) (-4 *2 (-172))))) 
+(-13 (-1047) (-707 |t#1|) (-10 -8 (-15 -2747 ($ |t#1|)))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 |#1| |#1|) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 |#1|) . T) ((-637 $) . T) ((-707 |#1|) . T) ((-716) . T) ((-1053 |#1|) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-3969 (((-420 |#1|) |#1|) 38)) (-3848 (((-420 |#1|) |#1|) 27) (((-420 |#1|) |#1| (-634 (-53))) 30)) (-1395 (((-121) |#1|) 54))) 
-(((-44 |#1|) (-10 -7 (-15 -3848 ((-420 |#1|) |#1| (-634 (-53)))) (-15 -3848 ((-420 |#1|) |#1|)) (-15 -3969 ((-420 |#1|) |#1|)) (-15 -1395 ((-121) |#1|))) (-1219 (-53))) (T -44)) 
-((-1395 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-44 *3)) (-4 *3 (-1219 (-53))))) (-3969 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1219 (-53))))) (-3848 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1219 (-53))))) (-3848 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-53))) (-5 *2 (-420 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1219 (-53)))))) 
-(-10 -7 (-15 -3848 ((-420 |#1|) |#1| (-634 (-53)))) (-15 -3848 ((-420 |#1|) |#1|)) (-15 -3969 ((-420 |#1|) |#1|)) (-15 -1395 ((-121) |#1|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2646 (((-2 (|:| |num| (-1244 |#2|)) (|:| |den| |#2|)) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| (-409 |#2|) (-365)))) (-2227 (($ $) NIL (|has| (-409 |#2|) (-365)))) (-1573 (((-121) $) NIL (|has| (-409 |#2|) (-365)))) (-4255 (((-679 (-409 |#2|)) (-1244 $)) NIL) (((-679 (-409 |#2|))) NIL)) (-1932 (((-409 |#2|) $) NIL)) (-3211 (((-1169 (-917) (-763)) (-568)) NIL (|has| (-409 |#2|) (-350)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL (|has| (-409 |#2|) (-365)))) (-1678 (((-420 $) $) NIL (|has| (-409 |#2|) (-365)))) (-1497 (((-121) $ $) NIL (|has| (-409 |#2|) (-365)))) (-3983 (((-763)) NIL (|has| (-409 |#2|) (-370)))) (-3926 (((-121)) NIL)) (-1965 (((-121) |#1|) NIL) (((-121) |#2|) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) NIL (|has| (-409 |#2|) (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| (-409 |#2|) (-1037 (-409 (-568))))) (((-3 (-409 |#2|) "failed") $) NIL)) (-2854 (((-568) $) NIL (|has| (-409 |#2|) (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| (-409 |#2|) (-1037 (-409 (-568))))) (((-409 |#2|) $) NIL)) (-3498 (($ (-1244 (-409 |#2|)) (-1244 $)) NIL) (($ (-1244 (-409 |#2|))) 57) (($ (-1244 |#2|) |#2|) 124)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-409 |#2|) (-350)))) (-2401 (($ $ $) NIL (|has| (-409 |#2|) (-365)))) (-1709 (((-679 (-409 |#2|)) $ (-1244 $)) NIL) (((-679 (-409 |#2|)) $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| (-409 |#2|) (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| (-409 |#2|) (-630 (-568)))) (((-2 (|:| -2928 (-679 (-409 |#2|))) (|:| |vec| (-1244 (-409 |#2|)))) (-679 $) (-1244 $)) NIL) (((-679 (-409 |#2|)) (-679 $)) NIL)) (-3692 (((-1244 $) (-1244 $)) NIL)) (-3092 (($ |#3|) NIL) (((-3 $ "failed") (-409 |#3|)) NIL (|has| (-409 |#2|) (-365)))) (-2925 (((-3 $ "failed") $) NIL)) (-1895 (((-634 (-634 |#1|))) NIL (|has| |#1| (-370)))) (-2234 (((-121) |#1| |#1|) NIL)) (-3700 (((-917)) NIL)) (-1731 (($) NIL (|has| (-409 |#2|) (-370)))) (-4449 (((-121)) NIL)) (-4481 (((-121) |#1|) NIL) (((-121) |#2|) NIL)) (-2412 (($ $ $) NIL (|has| (-409 |#2|) (-365)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| (-409 |#2|) (-365)))) (-3250 (($ $) NIL)) (-4220 (($) NIL (|has| (-409 |#2|) (-350)))) (-4456 (((-121) $) NIL (|has| (-409 |#2|) (-350)))) (-3218 (($ $ (-763)) NIL (|has| (-409 |#2|) (-350))) (($ $) NIL (|has| (-409 |#2|) (-350)))) (-3927 (((-121) $) NIL (|has| (-409 |#2|) (-365)))) (-4477 (((-917) $) NIL (|has| (-409 |#2|) (-350))) (((-828 (-917)) $) NIL (|has| (-409 |#2|) (-350)))) (-2735 (((-121) $) NIL)) (-3900 (((-763)) NIL)) (-3017 (((-1244 $) (-1244 $)) 100)) (-2657 (((-409 |#2|) $) NIL)) (-1296 (((-634 (-953 |#1|)) (-1161)) NIL (|has| |#1| (-365)))) (-3038 (((-3 $ "failed") $) NIL (|has| (-409 |#2|) (-350)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| (-409 |#2|) (-365)))) (-2045 ((|#3| $) NIL (|has| (-409 |#2|) (-365)))) (-3683 (((-917) $) NIL (|has| (-409 |#2|) (-370)))) (-3085 ((|#3| $) NIL)) (-2495 (($ (-634 $)) NIL (|has| (-409 |#2|) (-365))) (($ $ $) NIL (|has| (-409 |#2|) (-365)))) (-4487 (((-1143) $) NIL)) (-4383 (((-1249) (-763)) 78)) (-1300 (((-679 (-409 |#2|))) 51)) (-4472 (((-679 (-409 |#2|))) 44)) (-2081 (($ $) NIL (|has| (-409 |#2|) (-365)))) (-4368 (($ (-1244 |#2|) |#2|) 125)) (-3036 (((-679 (-409 |#2|))) 45)) (-1630 (((-679 (-409 |#2|))) 43)) (-1557 (((-2 (|:| |num| (-679 |#2|)) (|:| |den| |#2|)) (-1 |#2| |#2|)) 122)) (-1658 (((-2 (|:| |num| (-1244 |#2|)) (|:| |den| |#2|)) $) 63)) (-1820 (((-1244 $)) 42)) (-3661 (((-1244 $)) 41)) (-3874 (((-121) $) NIL)) (-1489 (((-121) $) NIL) (((-121) $ |#1|) NIL) (((-121) $ |#2|) NIL)) (-4434 (($) NIL (|has| (-409 |#2|) (-350)) CONST)) (-4355 (($ (-917)) NIL (|has| (-409 |#2|) (-370)))) (-3541 (((-3 |#2| "failed")) NIL)) (-4022 (((-1108) $) NIL)) (-2126 (((-763)) NIL)) (-2704 (($) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| (-409 |#2|) (-365)))) (-2721 (($ (-634 $)) NIL (|has| (-409 |#2|) (-365))) (($ $ $) NIL (|has| (-409 |#2|) (-365)))) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) NIL (|has| (-409 |#2|) (-350)))) (-3848 (((-420 $) $) NIL (|has| (-409 |#2|) (-365)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| (-409 |#2|) (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| (-409 |#2|) (-365)))) (-2595 (((-3 $ "failed") $ $) NIL (|has| (-409 |#2|) (-365)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| (-409 |#2|) (-365)))) (-2709 (((-763) $) NIL (|has| (-409 |#2|) (-365)))) (-2779 ((|#1| $ |#1| |#1|) NIL)) (-3633 (((-3 |#2| "failed")) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| (-409 |#2|) (-365)))) (-2217 (((-409 |#2|) (-1244 $)) NIL) (((-409 |#2|)) 39)) (-3143 (((-763) $) NIL (|has| (-409 |#2|) (-350))) (((-3 (-763) "failed") $ $) NIL (|has| (-409 |#2|) (-350)))) (-4189 (($ $ (-1 (-409 |#2|) (-409 |#2|)) (-763)) NIL (|has| (-409 |#2|) (-365))) (($ $ (-1 (-409 |#2|) (-409 |#2|))) NIL (|has| (-409 |#2|) (-365))) (($ $ (-1 |#2| |#2|)) 118) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-763)) NIL (-2198 (-12 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350)))) (($ $) NIL (-2198 (-12 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350))))) (-4387 (((-679 (-409 |#2|)) (-1244 $) (-1 (-409 |#2|) (-409 |#2|))) NIL (|has| (-409 |#2|) (-365)))) (-1626 ((|#3|) 50)) (-3065 (($) NIL (|has| (-409 |#2|) (-350)))) (-4073 (((-1244 (-409 |#2|)) $ (-1244 $)) NIL) (((-679 (-409 |#2|)) (-1244 $) (-1244 $)) NIL) (((-1244 (-409 |#2|)) $) 58) (((-679 (-409 |#2|)) (-1244 $)) 101)) (-4278 (((-1244 (-409 |#2|)) $) NIL) (($ (-1244 (-409 |#2|))) NIL) ((|#3| $) NIL) (($ |#3|) NIL)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| (-409 |#2|) (-350)))) (-3016 (((-1244 $) (-1244 $)) NIL)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ (-409 |#2|)) NIL) (($ (-409 (-568))) NIL (-2198 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-1037 (-409 (-568)))))) (($ $) NIL (|has| (-409 |#2|) (-365)))) (-4371 (($ $) NIL (|has| (-409 |#2|) (-350))) (((-3 $ "failed") $) NIL (|has| (-409 |#2|) (-148)))) (-2678 ((|#3| $) NIL)) (-4078 (((-763)) NIL)) (-4199 (((-121)) 37)) (-2712 (((-121) |#1|) 49) (((-121) |#2|) 130)) (-3746 (((-1244 $)) 91)) (-1826 (((-121) $ $) NIL (|has| (-409 |#2|) (-365)))) (-3223 (((-2 (|:| |num| $) (|:| |den| |#2|) (|:| |derivden| |#2|) (|:| |gd| |#2|)) $ (-1 |#2| |#2|)) NIL)) (-2262 (((-121)) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| (-409 |#2|) (-365)))) (-3056 (($) 16 T CONST)) (-1556 (($) 26 T CONST)) (-3190 (($ $ (-1 (-409 |#2|) (-409 |#2|)) (-763)) NIL (|has| (-409 |#2|) (-365))) (($ $ (-1 (-409 |#2|) (-409 |#2|))) NIL (|has| (-409 |#2|) (-365))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-763)) NIL (-2198 (-12 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350)))) (($ $) NIL (-2198 (-12 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350))))) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ $) NIL (|has| (-409 |#2|) (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| (-409 |#2|) (-365)))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 |#2|)) NIL) (($ (-409 |#2|) $) NIL) (($ (-409 (-568)) $) NIL (|has| (-409 |#2|) (-365))) (($ $ (-409 (-568))) NIL (|has| (-409 |#2|) (-365))))) 
-(((-45 |#1| |#2| |#3| |#4|) (-13 (-340 |#1| |#2| |#3|) (-10 -7 (-15 -4383 ((-1249) (-763))))) (-365) (-1219 |#1|) (-1219 (-409 |#2|)) |#3|) (T -45)) 
-((-4383 (*1 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-365)) (-4 *5 (-1219 *4)) (-5 *2 (-1249)) (-5 *1 (-45 *4 *5 *6 *7)) (-4 *6 (-1219 (-409 *5))) (-14 *7 *6)))) 
-(-13 (-340 |#1| |#2| |#3|) (-10 -7 (-15 -4383 ((-1249) (-763))))) 
-((-3621 ((|#2| |#2|) 47)) (-2669 ((|#2| |#2|) 116 (-12 (|has| |#2| (-432 |#1|)) (|has| |#1| (-453)) (|has| |#1| (-842)) (|has| |#1| (-1037 (-568)))))) (-3278 ((|#2| |#2|) 85 (-12 (|has| |#2| (-432 |#1|)) (|has| |#1| (-453)) (|has| |#1| (-842)) (|has| |#1| (-1037 (-568)))))) (-2670 ((|#2| |#2|) 86 (-12 (|has| |#2| (-432 |#1|)) (|has| |#1| (-453)) (|has| |#1| (-842)) (|has| |#1| (-1037 (-568)))))) (-1438 ((|#2| (-123) |#2| (-763)) 73 (-12 (|has| |#2| (-432 |#1|)) (|has| |#1| (-453)) (|has| |#1| (-842)) (|has| |#1| (-1037 (-568)))))) (-2391 (((-1157 |#2|) |#2|) 44)) (-4013 ((|#2| |#2| (-634 (-607 |#2|))) 17) ((|#2| |#2| (-634 |#2|)) 19) ((|#2| |#2| |#2|) 20) ((|#2| |#2|) 15))) 
-(((-46 |#1| |#2|) (-10 -7 (-15 -3621 (|#2| |#2|)) (-15 -4013 (|#2| |#2|)) (-15 -4013 (|#2| |#2| |#2|)) (-15 -4013 (|#2| |#2| (-634 |#2|))) (-15 -4013 (|#2| |#2| (-634 (-607 |#2|)))) (-15 -2391 ((-1157 |#2|) |#2|)) (IF (|has| |#1| (-842)) (IF (|has| |#1| (-453)) (IF (|has| |#1| (-1037 (-568))) (IF (|has| |#2| (-432 |#1|)) (PROGN (-15 -2670 (|#2| |#2|)) (-15 -3278 (|#2| |#2|)) (-15 -2669 (|#2| |#2|)) (-15 -1438 (|#2| (-123) |#2| (-763)))) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) (-558) (-13 (-365) (-296) (-10 -8 (-15 -2317 ((-1113 |#1| (-607 $)) $)) (-15 -2324 ((-1113 |#1| (-607 $)) $)) (-15 -2745 ($ (-1113 |#1| (-607 $))))))) (T -46)) 
-((-1438 (*1 *2 *3 *2 *4) (-12 (-5 *3 (-123)) (-5 *4 (-763)) (-4 *5 (-453)) (-4 *5 (-842)) (-4 *5 (-1037 (-568))) (-4 *5 (-558)) (-5 *1 (-46 *5 *2)) (-4 *2 (-432 *5)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2317 ((-1113 *5 (-607 $)) $)) (-15 -2324 ((-1113 *5 (-607 $)) $)) (-15 -2745 ($ (-1113 *5 (-607 $))))))))) (-2669 (*1 *2 *2) (-12 (-4 *3 (-453)) (-4 *3 (-842)) (-4 *3 (-1037 (-568))) (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-432 *3)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2317 ((-1113 *3 (-607 $)) $)) (-15 -2324 ((-1113 *3 (-607 $)) $)) (-15 -2745 ($ (-1113 *3 (-607 $))))))))) (-3278 (*1 *2 *2) (-12 (-4 *3 (-453)) (-4 *3 (-842)) (-4 *3 (-1037 (-568))) (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-432 *3)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2317 ((-1113 *3 (-607 $)) $)) (-15 -2324 ((-1113 *3 (-607 $)) $)) (-15 -2745 ($ (-1113 *3 (-607 $))))))))) (-2670 (*1 *2 *2) (-12 (-4 *3 (-453)) (-4 *3 (-842)) (-4 *3 (-1037 (-568))) (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-432 *3)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2317 ((-1113 *3 (-607 $)) $)) (-15 -2324 ((-1113 *3 (-607 $)) $)) (-15 -2745 ($ (-1113 *3 (-607 $))))))))) (-2391 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-1157 *3)) (-5 *1 (-46 *4 *3)) (-4 *3 (-13 (-365) (-296) (-10 -8 (-15 -2317 ((-1113 *4 (-607 $)) $)) (-15 -2324 ((-1113 *4 (-607 $)) $)) (-15 -2745 ($ (-1113 *4 (-607 $))))))))) (-4013 (*1 *2 *2 *3) (-12 (-5 *3 (-634 (-607 *2))) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2317 ((-1113 *4 (-607 $)) $)) (-15 -2324 ((-1113 *4 (-607 $)) $)) (-15 -2745 ($ (-1113 *4 (-607 $))))))) (-4 *4 (-558)) (-5 *1 (-46 *4 *2)))) (-4013 (*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2317 ((-1113 *4 (-607 $)) $)) (-15 -2324 ((-1113 *4 (-607 $)) $)) (-15 -2745 ($ (-1113 *4 (-607 $))))))) (-4 *4 (-558)) (-5 *1 (-46 *4 *2)))) (-4013 (*1 *2 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2317 ((-1113 *3 (-607 $)) $)) (-15 -2324 ((-1113 *3 (-607 $)) $)) (-15 -2745 ($ (-1113 *3 (-607 $))))))))) (-4013 (*1 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2317 ((-1113 *3 (-607 $)) $)) (-15 -2324 ((-1113 *3 (-607 $)) $)) (-15 -2745 ($ (-1113 *3 (-607 $))))))))) (-3621 (*1 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2317 ((-1113 *3 (-607 $)) $)) (-15 -2324 ((-1113 *3 (-607 $)) $)) (-15 -2745 ($ (-1113 *3 (-607 $)))))))))) 
-(-10 -7 (-15 -3621 (|#2| |#2|)) (-15 -4013 (|#2| |#2|)) (-15 -4013 (|#2| |#2| |#2|)) (-15 -4013 (|#2| |#2| (-634 |#2|))) (-15 -4013 (|#2| |#2| (-634 (-607 |#2|)))) (-15 -2391 ((-1157 |#2|) |#2|)) (IF (|has| |#1| (-842)) (IF (|has| |#1| (-453)) (IF (|has| |#1| (-1037 (-568))) (IF (|has| |#2| (-432 |#1|)) (PROGN (-15 -2670 (|#2| |#2|)) (-15 -3278 (|#2| |#2|)) (-15 -2669 (|#2| |#2|)) (-15 -1438 (|#2| (-123) |#2| (-763)))) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) 
-((-3848 (((-420 (-1157 |#3|)) (-1157 |#3|) (-634 (-53))) 22) (((-420 |#3|) |#3| (-634 (-53))) 18))) 
-(((-47 |#1| |#2| |#3|) (-10 -7 (-15 -3848 ((-420 |#3|) |#3| (-634 (-53)))) (-15 -3848 ((-420 (-1157 |#3|)) (-1157 |#3|) (-634 (-53))))) (-842) (-788) (-950 (-53) |#2| |#1|)) (T -47)) 
-((-3848 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-53))) (-4 *5 (-842)) (-4 *6 (-788)) (-4 *7 (-950 (-53) *6 *5)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-47 *5 *6 *7)) (-5 *3 (-1157 *7)))) (-3848 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-53))) (-4 *5 (-842)) (-4 *6 (-788)) (-5 *2 (-420 *3)) (-5 *1 (-47 *5 *6 *3)) (-4 *3 (-950 (-53) *6 *5))))) 
-(-10 -7 (-15 -3848 ((-420 |#3|) |#3| (-634 (-53)))) (-15 -3848 ((-420 (-1157 |#3|)) (-1157 |#3|) (-634 (-53))))) 
-((-2895 (((-763) |#2|) 65)) (-1416 (((-763) |#2|) 68)) (-2945 (((-634 |#2|)) 33)) (-3238 (((-763) |#2|) 67)) (-2218 (((-763) |#2|) 64)) (-2898 (((-763) |#2|) 66)) (-2328 (((-634 (-679 |#1|))) 60)) (-3916 (((-634 |#2|)) 55)) (-1555 (((-634 |#2|) |#2|) 43)) (-1943 (((-634 |#2|)) 57)) (-1313 (((-634 |#2|)) 56)) (-3759 (((-634 (-679 |#1|))) 48)) (-2202 (((-634 |#2|)) 54)) (-1610 (((-634 |#2|) |#2|) 42)) (-3907 (((-634 |#2|)) 50)) (-1995 (((-634 (-679 |#1|))) 61)) (-3955 (((-634 |#2|)) 59)) (-3746 (((-1244 |#2|) (-1244 |#2|)) 83 (|has| |#1| (-301))))) 
-(((-48 |#1| |#2|) (-10 -7 (-15 -3238 ((-763) |#2|)) (-15 -1416 ((-763) |#2|)) (-15 -2218 ((-763) |#2|)) (-15 -2895 ((-763) |#2|)) (-15 -2898 ((-763) |#2|)) (-15 -3907 ((-634 |#2|))) (-15 -1610 ((-634 |#2|) |#2|)) (-15 -1555 ((-634 |#2|) |#2|)) (-15 -2202 ((-634 |#2|))) (-15 -3916 ((-634 |#2|))) (-15 -1313 ((-634 |#2|))) (-15 -1943 ((-634 |#2|))) (-15 -3955 ((-634 |#2|))) (-15 -3759 ((-634 (-679 |#1|)))) (-15 -2328 ((-634 (-679 |#1|)))) (-15 -1995 ((-634 (-679 |#1|)))) (-15 -2945 ((-634 |#2|))) (IF (|has| |#1| (-301)) (-15 -3746 ((-1244 |#2|) (-1244 |#2|))) |noBranch|)) (-558) (-419 |#1|)) (T -48)) 
-((-3746 (*1 *2 *2) (-12 (-5 *2 (-1244 *4)) (-4 *4 (-419 *3)) (-4 *3 (-301)) (-4 *3 (-558)) (-5 *1 (-48 *3 *4)))) (-2945 (*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3)))) (-1995 (*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 (-679 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3)))) (-2328 (*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 (-679 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3)))) (-3759 (*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 (-679 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3)))) (-3955 (*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3)))) (-1943 (*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3)))) (-1313 (*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3)))) (-3916 (*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3)))) (-2202 (*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3)))) (-1555 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 *3)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4)))) (-1610 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 *3)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4)))) (-3907 (*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3)))) (-2898 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-763)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4)))) (-2895 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-763)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4)))) (-2218 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-763)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4)))) (-1416 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-763)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4)))) (-3238 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-763)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4))))) 
-(-10 -7 (-15 -3238 ((-763) |#2|)) (-15 -1416 ((-763) |#2|)) (-15 -2218 ((-763) |#2|)) (-15 -2895 ((-763) |#2|)) (-15 -2898 ((-763) |#2|)) (-15 -3907 ((-634 |#2|))) (-15 -1610 ((-634 |#2|) |#2|)) (-15 -1555 ((-634 |#2|) |#2|)) (-15 -2202 ((-634 |#2|))) (-15 -3916 ((-634 |#2|))) (-15 -1313 ((-634 |#2|))) (-15 -1943 ((-634 |#2|))) (-15 -3955 ((-634 |#2|))) (-15 -3759 ((-634 (-679 |#1|)))) (-15 -2328 ((-634 (-679 |#1|)))) (-15 -1995 ((-634 (-679 |#1|)))) (-15 -2945 ((-634 |#2|))) (IF (|has| |#1| (-301)) (-15 -3746 ((-1244 |#2|) (-1244 |#2|))) |noBranch|)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2295 (((-3 $ "failed")) NIL (|has| |#1| (-558)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-2776 (((-1244 (-679 |#1|)) (-1244 $)) NIL) (((-1244 (-679 |#1|))) 24)) (-1741 (((-1244 $)) 50)) (-2671 (($) NIL T CONST)) (-1309 (((-3 (-2 (|:| |particular| $) (|:| -3746 (-634 $))) "failed")) NIL (|has| |#1| (-558)))) (-2593 (((-3 $ "failed")) NIL (|has| |#1| (-558)))) (-1631 (((-679 |#1|) (-1244 $)) NIL) (((-679 |#1|)) NIL)) (-1866 ((|#1| $) NIL)) (-3042 (((-679 |#1|) $ (-1244 $)) NIL) (((-679 |#1|) $) NIL)) (-3550 (((-3 $ "failed") $) NIL (|has| |#1| (-558)))) (-4408 (((-1157 (-953 |#1|))) NIL (|has| |#1| (-365)))) (-3551 (($ $ (-917)) NIL)) (-4409 ((|#1| $) NIL)) (-1371 (((-1157 |#1|) $) NIL (|has| |#1| (-558)))) (-3569 ((|#1| (-1244 $)) NIL) ((|#1|) NIL)) (-2989 (((-1157 |#1|) $) NIL)) (-3384 (((-121)) 86)) (-3498 (($ (-1244 |#1|) (-1244 $)) NIL) (($ (-1244 |#1|)) NIL)) (-2925 (((-3 $ "failed") $) 14 (|has| |#1| (-558)))) (-3700 (((-917)) 51)) (-4370 (((-121)) NIL)) (-4373 (($ $ (-917)) NIL)) (-1537 (((-121)) NIL)) (-1580 (((-121)) NIL)) (-1695 (((-121)) 88)) (-3116 (((-3 (-2 (|:| |particular| $) (|:| -3746 (-634 $))) "failed")) NIL (|has| |#1| (-558)))) (-2599 (((-3 $ "failed")) NIL (|has| |#1| (-558)))) (-4210 (((-679 |#1|) (-1244 $)) NIL) (((-679 |#1|)) NIL)) (-2889 ((|#1| $) NIL)) (-4333 (((-679 |#1|) $ (-1244 $)) NIL) (((-679 |#1|) $) NIL)) (-3243 (((-3 $ "failed") $) NIL (|has| |#1| (-558)))) (-4454 (((-1157 (-953 |#1|))) NIL (|has| |#1| (-365)))) (-4222 (($ $ (-917)) NIL)) (-3329 ((|#1| $) NIL)) (-2265 (((-1157 |#1|) $) NIL (|has| |#1| (-558)))) (-3898 ((|#1| (-1244 $)) NIL) ((|#1|) NIL)) (-3626 (((-1157 |#1|) $) NIL)) (-2767 (((-121)) 85)) (-4487 (((-1143) $) NIL)) (-1804 (((-121)) 92)) (-2919 (((-121)) 91)) (-3840 (((-121)) 93)) (-4022 (((-1108) $) NIL)) (-1346 (((-121)) 87)) (-2779 ((|#1| $ (-568)) 53)) (-4073 (((-1244 |#1|) $ (-1244 $)) 47) (((-679 |#1|) (-1244 $) (-1244 $)) NIL) (((-1244 |#1|) $) 28) (((-679 |#1|) (-1244 $)) NIL)) (-4278 (((-1244 |#1|) $) NIL) (($ (-1244 |#1|)) NIL)) (-3295 (((-634 (-953 |#1|)) (-1244 $)) NIL) (((-634 (-953 |#1|))) NIL)) (-2353 (($ $ $) NIL)) (-3433 (((-121)) 83)) (-2745 (((-850) $) 68) (($ (-1244 |#1|)) 22)) (-3746 (((-1244 $)) 44)) (-1509 (((-634 (-1244 |#1|))) NIL (|has| |#1| (-558)))) (-3882 (($ $ $ $) NIL)) (-4177 (((-121)) 81)) (-3823 (($ (-679 |#1|) $) 18)) (-3500 (($ $ $) NIL)) (-2433 (((-121)) 84)) (-2189 (((-121)) 82)) (-4107 (((-121)) 80)) (-3056 (($) NIL T CONST)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 75) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-1127 |#2| |#1|) $) 19))) 
-(((-49 |#1| |#2| |#3| |#4|) (-13 (-419 |#1|) (-637 (-1127 |#2| |#1|)) (-10 -8 (-15 -2745 ($ (-1244 |#1|))))) (-365) (-917) (-634 (-1161)) (-1244 (-679 |#1|))) (T -49)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-365)) (-14 *6 (-1244 (-679 *3))) (-5 *1 (-49 *3 *4 *5 *6)) (-14 *4 (-917)) (-14 *5 (-634 (-1161)))))) 
-(-13 (-419 |#1|) (-637 (-1127 |#2| |#1|)) (-10 -8 (-15 -2745 ($ (-1244 |#1|))))) 
-((-2447 (((-121) $ $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-2850 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-2235 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-2796 (($ $) NIL)) (-2986 (($) NIL) (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-1868 (((-1249) $ |#1| |#1|) NIL (|has| $ (-6 -4520))) (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-3910 (($ $ (-568)) NIL (|has| $ (-6 -4520)))) (-2016 (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL) (((-121) $) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842)))) (-3908 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4520))) (($ $) NIL (-12 (|has| $ (-6 -4520)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842))))) (-3644 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL) (($ $) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842)))) (-2510 (((-121) $ (-763)) NIL)) (-1659 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (|has| $ (-6 -4520)))) (-3869 (($ $ $) 27 (|has| $ (-6 -4520)))) (-2395 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (|has| $ (-6 -4520)))) (-2517 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 29 (|has| $ (-6 -4520)))) (-2436 ((|#2| $ |#1| |#2|) 45) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-568) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (|has| $ (-6 -4520))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-1210 (-568)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (|has| $ (-6 -4520))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ "last" (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (|has| $ (-6 -4520))) (($ $ "rest" $) NIL (|has| $ (-6 -4520))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ "first" (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (|has| $ (-6 -4520))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ "value" (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) NIL (|has| $ (-6 -4520)))) (-3507 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL)) (-2801 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-1679 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-2674 (((-3 |#2| "failed") |#1| $) 37)) (-2671 (($) NIL T CONST)) (-1578 (($ $) NIL (|has| $ (-6 -4520)))) (-3943 (($ $) NIL)) (-3935 (($ $ (-763)) NIL) (($ $) 24)) (-3369 (($ $) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-3405 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (|has| $ (-6 -4519))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-3 |#2| "failed") |#1| $) 46) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL) (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (-4328 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-3092 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (|has| $ (-6 -4519))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (|has| $ (-6 -4519))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-3989 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4520))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-568) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (|has| $ (-6 -4520)))) (-2602 ((|#2| $ |#1|) NIL) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-568)) NIL)) (-1601 (((-121) $) NIL)) (-2764 (((-568) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL) (((-568) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))) (((-568) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-568)) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (-4360 (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 18 (|has| $ (-6 -4519))) (((-634 |#2|) $) NIL (|has| $ (-6 -4519))) (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 18 (|has| $ (-6 -4519)))) (-2287 (((-634 $) $) NIL)) (-1700 (((-121) $ $) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (-1849 (($ (-763) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL)) (-1737 (((-121) $ (-763)) NIL)) (-1881 ((|#1| $) NIL (|has| |#1| (-842))) (((-568) $) 32 (|has| (-568) (-842)))) (-2521 (($ $ $) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842)))) (-3349 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ $) NIL) (($ $ $) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842)))) (-1347 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ $) NIL) (($ $ $) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842)))) (-1979 (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-634 |#2|) $) NIL (|has| $ (-6 -4519))) (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090)))) (((-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-2223 ((|#1| $) NIL (|has| |#1| (-842))) (((-568) $) 34 (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842)))) (-3674 (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4520))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4520))) (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL) (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ $) NIL) (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL)) (-3896 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-2869 (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL)) (-1651 (((-121) $) NIL)) (-4487 (((-1143) $) 41 (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-4162 (($ $ (-763)) NIL) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-1946 (((-634 |#1|) $) 20)) (-3548 (((-121) |#1| $) NIL)) (-1890 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-4450 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL) (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-4122 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-4174 (((-634 |#1|) $) NIL) (((-634 (-568)) $) NIL)) (-3578 (((-121) |#1| $) NIL) (((-121) (-568) $) NIL)) (-4022 (((-1108) $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-3876 ((|#2| $) NIL (|has| |#1| (-842))) (($ $ (-763)) NIL) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 23)) (-3775 (((-3 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) "failed") (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL) (((-3 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) "failed") (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL)) (-3724 (($ $ |#2|) NIL (|has| $ (-6 -4520))) (($ $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (|has| $ (-6 -4520)))) (-1315 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-1786 (((-121) $) NIL)) (-1387 (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-634 (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090)))) (((-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-2041 (((-634 |#2|) $) NIL) (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 17)) (-3084 (((-121) $) 16)) (-3248 (($) 13)) (-2779 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-568) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ (-568)) NIL) (($ $ (-1210 (-568))) NIL) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ "last") NIL) (($ $ "rest") NIL) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ "first") NIL) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $ "value") NIL)) (-4075 (((-568) $ $) NIL)) (-2085 (($) 12) (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-1783 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-2826 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-3790 (((-121) $) NIL)) (-2340 (($ $) NIL)) (-2714 (($ $) NIL (|has| $ (-6 -4520)))) (-2775 (((-763) $) NIL)) (-3335 (($ $) NIL)) (-4168 (((-763) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-763) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090)))) (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519))) (((-763) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-763) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-2256 (($ $ $ (-568)) NIL (|has| $ (-6 -4520)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-609 (-541))))) (-4287 (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL) (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-3845 (($ $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL) (($ $ $) NIL)) (-2768 (($ $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL) (($ (-634 $)) NIL) (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 25) (($ $ $) NIL)) (-2745 (((-850) $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-4339 (((-634 $) $) NIL)) (-3491 (((-121) $ $) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (-2367 (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-2802 (((-3 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) "failed") |#1| $) 43)) (-1319 (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-1751 (((-121) $ $) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842)))) (-1738 (((-121) $ $) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842)))) (-1717 (((-121) $ $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-1745 (((-121) $ $) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842)))) (-1732 (((-121) $ $) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-842)))) (-1697 (((-763) $) 22 (|has| $ (-6 -4519))))) 
+((-4446 (((-420 |#1|) |#1|) 38)) (-3850 (((-420 |#1|) |#1|) 27) (((-420 |#1|) |#1| (-634 (-53))) 30)) (-4015 (((-121) |#1|) 54))) 
+(((-44 |#1|) (-10 -7 (-15 -3850 ((-420 |#1|) |#1| (-634 (-53)))) (-15 -3850 ((-420 |#1|) |#1|)) (-15 -4446 ((-420 |#1|) |#1|)) (-15 -4015 ((-121) |#1|))) (-1219 (-53))) (T -44)) 
+((-4015 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-44 *3)) (-4 *3 (-1219 (-53))))) (-4446 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1219 (-53))))) (-3850 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1219 (-53))))) (-3850 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-53))) (-5 *2 (-420 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1219 (-53)))))) 
+(-10 -7 (-15 -3850 ((-420 |#1|) |#1| (-634 (-53)))) (-15 -3850 ((-420 |#1|) |#1|)) (-15 -4446 ((-420 |#1|) |#1|)) (-15 -4015 ((-121) |#1|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-4354 (((-2 (|:| |num| (-1244 |#2|)) (|:| |den| |#2|)) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| (-409 |#2|) (-365)))) (-3661 (($ $) NIL (|has| (-409 |#2|) (-365)))) (-4426 (((-121) $) NIL (|has| (-409 |#2|) (-365)))) (-2883 (((-679 (-409 |#2|)) (-1244 $)) NIL) (((-679 (-409 |#2|))) NIL)) (-1934 (((-409 |#2|) $) NIL)) (-1856 (((-1169 (-917) (-763)) (-568)) NIL (|has| (-409 |#2|) (-350)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL (|has| (-409 |#2|) (-365)))) (-3498 (((-420 $) $) NIL (|has| (-409 |#2|) (-365)))) (-2589 (((-121) $ $) NIL (|has| (-409 |#2|) (-365)))) (-3986 (((-763)) NIL (|has| (-409 |#2|) (-370)))) (-2191 (((-121)) NIL)) (-4347 (((-121) |#1|) NIL) (((-121) |#2|) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) NIL (|has| (-409 |#2|) (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| (-409 |#2|) (-1037 (-409 (-568))))) (((-3 (-409 |#2|) "failed") $) NIL)) (-2857 (((-568) $) NIL (|has| (-409 |#2|) (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| (-409 |#2|) (-1037 (-409 (-568))))) (((-409 |#2|) $) NIL)) (-3899 (($ (-1244 (-409 |#2|)) (-1244 $)) NIL) (($ (-1244 (-409 |#2|))) 57) (($ (-1244 |#2|) |#2|) 124)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-409 |#2|) (-350)))) (-2403 (($ $ $) NIL (|has| (-409 |#2|) (-365)))) (-3653 (((-679 (-409 |#2|)) $ (-1244 $)) NIL) (((-679 (-409 |#2|)) $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| (-409 |#2|) (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| (-409 |#2|) (-630 (-568)))) (((-2 (|:| -2908 (-679 (-409 |#2|))) (|:| |vec| (-1244 (-409 |#2|)))) (-679 $) (-1244 $)) NIL) (((-679 (-409 |#2|)) (-679 $)) NIL)) (-2331 (((-1244 $) (-1244 $)) NIL)) (-3094 (($ |#3|) NIL) (((-3 $ "failed") (-409 |#3|)) NIL (|has| (-409 |#2|) (-365)))) (-2902 (((-3 $ "failed") $) NIL)) (-2603 (((-634 (-634 |#1|))) NIL (|has| |#1| (-370)))) (-2679 (((-121) |#1| |#1|) NIL)) (-2371 (((-917)) NIL)) (-1733 (($) NIL (|has| (-409 |#2|) (-370)))) (-1700 (((-121)) NIL)) (-1862 (((-121) |#1|) NIL) (((-121) |#2|) NIL)) (-2414 (($ $ $) NIL (|has| (-409 |#2|) (-365)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| (-409 |#2|) (-365)))) (-1998 (($ $) NIL)) (-4188 (($) NIL (|has| (-409 |#2|) (-350)))) (-1748 (((-121) $) NIL (|has| (-409 |#2|) (-350)))) (-1887 (($ $ (-763)) NIL (|has| (-409 |#2|) (-350))) (($ $) NIL (|has| (-409 |#2|) (-350)))) (-2197 (((-121) $) NIL (|has| (-409 |#2|) (-365)))) (-1844 (((-917) $) NIL (|has| (-409 |#2|) (-350))) (((-828 (-917)) $) NIL (|has| (-409 |#2|) (-350)))) (-1598 (((-121) $) NIL)) (-2066 (((-763)) NIL)) (-3233 (((-1244 $) (-1244 $)) 100)) (-4417 (((-409 |#2|) $) NIL)) (-3247 (((-634 (-953 |#1|)) (-1161)) NIL (|has| |#1| (-365)))) (-2214 (((-3 $ "failed") $) NIL (|has| (-409 |#2|) (-350)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| (-409 |#2|) (-365)))) (-1497 ((|#3| $) NIL (|has| (-409 |#2|) (-365)))) (-2291 (((-917) $) NIL (|has| (-409 |#2|) (-370)))) (-3087 ((|#3| $) NIL)) (-2498 (($ (-634 $)) NIL (|has| (-409 |#2|) (-365))) (($ $ $) NIL (|has| (-409 |#2|) (-365)))) (-1893 (((-1143) $) NIL)) (-1366 (((-1249) (-763)) 78)) (-3281 (((-679 (-409 |#2|))) 51)) (-1822 (((-679 (-409 |#2|))) 44)) (-2083 (($ $) NIL (|has| (-409 |#2|) (-365)))) (-3368 (($ (-1244 |#2|) |#2|) 125)) (-2208 (((-679 (-409 |#2|))) 45)) (-1515 (((-679 (-409 |#2|))) 43)) (-4339 (((-2 (|:| |num| (-679 |#2|)) (|:| |den| |#2|)) (-1 |#2| |#2|)) 122)) (-3363 (((-2 (|:| |num| (-1244 |#2|)) (|:| |den| |#2|)) $) 63)) (-2239 (((-1244 $)) 42)) (-3330 (((-1244 $)) 41)) (-1979 (((-121) $) NIL)) (-2548 (((-121) $) NIL) (((-121) $ |#1|) NIL) (((-121) $ |#2|) NIL)) (-4436 (($) NIL (|has| (-409 |#2|) (-350)) CONST)) (-4357 (($ (-917)) NIL (|has| (-409 |#2|) (-370)))) (-4201 (((-3 |#2| "failed")) NIL)) (-4025 (((-1108) $) NIL)) (-3383 (((-763)) NIL)) (-2707 (($) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| (-409 |#2|) (-365)))) (-2723 (($ (-634 $)) NIL (|has| (-409 |#2|) (-365))) (($ $ $) NIL (|has| (-409 |#2|) (-365)))) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) NIL (|has| (-409 |#2|) (-350)))) (-3850 (((-420 $) $) NIL (|has| (-409 |#2|) (-365)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| (-409 |#2|) (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| (-409 |#2|) (-365)))) (-2597 (((-3 $ "failed") $ $) NIL (|has| (-409 |#2|) (-365)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| (-409 |#2|) (-365)))) (-1466 (((-763) $) NIL (|has| (-409 |#2|) (-365)))) (-2781 ((|#1| $ |#1| |#1|) NIL)) (-3146 (((-3 |#2| "failed")) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| (-409 |#2|) (-365)))) (-3440 (((-409 |#2|) (-1244 $)) NIL) (((-409 |#2|)) 39)) (-2721 (((-763) $) NIL (|has| (-409 |#2|) (-350))) (((-3 (-763) "failed") $ $) NIL (|has| (-409 |#2|) (-350)))) (-4191 (($ $ (-1 (-409 |#2|) (-409 |#2|)) (-763)) NIL (|has| (-409 |#2|) (-365))) (($ $ (-1 (-409 |#2|) (-409 |#2|))) NIL (|has| (-409 |#2|) (-365))) (($ $ (-1 |#2| |#2|)) 118) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-763)) NIL (-2199 (-12 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350)))) (($ $) NIL (-2199 (-12 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350))))) (-1391 (((-679 (-409 |#2|)) (-1244 $) (-1 (-409 |#2|) (-409 |#2|))) NIL (|has| (-409 |#2|) (-365)))) (-1492 ((|#3|) 50)) (-2330 (($) NIL (|has| (-409 |#2|) (-350)))) (-1656 (((-1244 (-409 |#2|)) $ (-1244 $)) NIL) (((-679 (-409 |#2|)) (-1244 $) (-1244 $)) NIL) (((-1244 (-409 |#2|)) $) 58) (((-679 (-409 |#2|)) (-1244 $)) 101)) (-4280 (((-1244 (-409 |#2|)) $) NIL) (($ (-1244 (-409 |#2|))) NIL) ((|#3| $) NIL) (($ |#3|) NIL)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| (-409 |#2|) (-350)))) (-3224 (((-1244 $) (-1244 $)) NIL)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ (-409 |#2|)) NIL) (($ (-409 (-568))) NIL (-2199 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-1037 (-409 (-568)))))) (($ $) NIL (|has| (-409 |#2|) (-365)))) (-3385 (($ $) NIL (|has| (-409 |#2|) (-350))) (((-3 $ "failed") $) NIL (|has| (-409 |#2|) (-148)))) (-1295 ((|#3| $) NIL)) (-3425 (((-763)) NIL)) (-4077 (((-121)) 37)) (-1487 (((-121) |#1|) 49) (((-121) |#2|) 130)) (-2588 (((-1244 $)) 91)) (-2273 (((-121) $ $) NIL (|has| (-409 |#2|) (-365)))) (-1900 (((-2 (|:| |num| $) (|:| |den| |#2|) (|:| |derivden| |#2|) (|:| |gd| |#2|)) $ (-1 |#2| |#2|)) NIL)) (-3341 (((-121)) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| (-409 |#2|) (-365)))) (-3058 (($) 16 T CONST)) (-1557 (($) 26 T CONST)) (-3192 (($ $ (-1 (-409 |#2|) (-409 |#2|)) (-763)) NIL (|has| (-409 |#2|) (-365))) (($ $ (-1 (-409 |#2|) (-409 |#2|))) NIL (|has| (-409 |#2|) (-365))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-763)) NIL (-2199 (-12 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350)))) (($ $) NIL (-2199 (-12 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350))))) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ $) NIL (|has| (-409 |#2|) (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| (-409 |#2|) (-365)))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 |#2|)) NIL) (($ (-409 |#2|) $) NIL) (($ (-409 (-568)) $) NIL (|has| (-409 |#2|) (-365))) (($ $ (-409 (-568))) NIL (|has| (-409 |#2|) (-365))))) 
+(((-45 |#1| |#2| |#3| |#4|) (-13 (-340 |#1| |#2| |#3|) (-10 -7 (-15 -1366 ((-1249) (-763))))) (-365) (-1219 |#1|) (-1219 (-409 |#2|)) |#3|) (T -45)) 
+((-1366 (*1 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-365)) (-4 *5 (-1219 *4)) (-5 *2 (-1249)) (-5 *1 (-45 *4 *5 *6 *7)) (-4 *6 (-1219 (-409 *5))) (-14 *7 *6)))) 
+(-13 (-340 |#1| |#2| |#3|) (-10 -7 (-15 -1366 ((-1249) (-763))))) 
+((-3085 ((|#2| |#2|) 47)) (-4480 ((|#2| |#2|) 116 (-12 (|has| |#2| (-432 |#1|)) (|has| |#1| (-453)) (|has| |#1| (-842)) (|has| |#1| (-1037 (-568)))))) (-2086 ((|#2| |#2|) 85 (-12 (|has| |#2| (-432 |#1|)) (|has| |#1| (-453)) (|has| |#1| (-842)) (|has| |#1| (-1037 (-568)))))) (-4485 ((|#2| |#2|) 86 (-12 (|has| |#2| (-432 |#1|)) (|has| |#1| (-453)) (|has| |#1| (-842)) (|has| |#1| (-1037 (-568)))))) (-2282 ((|#2| (-123) |#2| (-763)) 73 (-12 (|has| |#2| (-432 |#1|)) (|has| |#1| (-453)) (|has| |#1| (-842)) (|has| |#1| (-1037 (-568)))))) (-2234 (((-1157 |#2|) |#2|) 44)) (-1396 ((|#2| |#2| (-634 (-607 |#2|))) 17) ((|#2| |#2| (-634 |#2|)) 19) ((|#2| |#2| |#2|) 20) ((|#2| |#2|) 15))) 
+(((-46 |#1| |#2|) (-10 -7 (-15 -3085 (|#2| |#2|)) (-15 -1396 (|#2| |#2|)) (-15 -1396 (|#2| |#2| |#2|)) (-15 -1396 (|#2| |#2| (-634 |#2|))) (-15 -1396 (|#2| |#2| (-634 (-607 |#2|)))) (-15 -2234 ((-1157 |#2|) |#2|)) (IF (|has| |#1| (-842)) (IF (|has| |#1| (-453)) (IF (|has| |#1| (-1037 (-568))) (IF (|has| |#2| (-432 |#1|)) (PROGN (-15 -4485 (|#2| |#2|)) (-15 -2086 (|#2| |#2|)) (-15 -4480 (|#2| |#2|)) (-15 -2282 (|#2| (-123) |#2| (-763)))) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) (-558) (-13 (-365) (-296) (-10 -8 (-15 -2319 ((-1113 |#1| (-607 $)) $)) (-15 -2326 ((-1113 |#1| (-607 $)) $)) (-15 -2747 ($ (-1113 |#1| (-607 $))))))) (T -46)) 
+((-2282 (*1 *2 *3 *2 *4) (-12 (-5 *3 (-123)) (-5 *4 (-763)) (-4 *5 (-453)) (-4 *5 (-842)) (-4 *5 (-1037 (-568))) (-4 *5 (-558)) (-5 *1 (-46 *5 *2)) (-4 *2 (-432 *5)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2319 ((-1113 *5 (-607 $)) $)) (-15 -2326 ((-1113 *5 (-607 $)) $)) (-15 -2747 ($ (-1113 *5 (-607 $))))))))) (-4480 (*1 *2 *2) (-12 (-4 *3 (-453)) (-4 *3 (-842)) (-4 *3 (-1037 (-568))) (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-432 *3)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2319 ((-1113 *3 (-607 $)) $)) (-15 -2326 ((-1113 *3 (-607 $)) $)) (-15 -2747 ($ (-1113 *3 (-607 $))))))))) (-2086 (*1 *2 *2) (-12 (-4 *3 (-453)) (-4 *3 (-842)) (-4 *3 (-1037 (-568))) (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-432 *3)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2319 ((-1113 *3 (-607 $)) $)) (-15 -2326 ((-1113 *3 (-607 $)) $)) (-15 -2747 ($ (-1113 *3 (-607 $))))))))) (-4485 (*1 *2 *2) (-12 (-4 *3 (-453)) (-4 *3 (-842)) (-4 *3 (-1037 (-568))) (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-432 *3)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2319 ((-1113 *3 (-607 $)) $)) (-15 -2326 ((-1113 *3 (-607 $)) $)) (-15 -2747 ($ (-1113 *3 (-607 $))))))))) (-2234 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-1157 *3)) (-5 *1 (-46 *4 *3)) (-4 *3 (-13 (-365) (-296) (-10 -8 (-15 -2319 ((-1113 *4 (-607 $)) $)) (-15 -2326 ((-1113 *4 (-607 $)) $)) (-15 -2747 ($ (-1113 *4 (-607 $))))))))) (-1396 (*1 *2 *2 *3) (-12 (-5 *3 (-634 (-607 *2))) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2319 ((-1113 *4 (-607 $)) $)) (-15 -2326 ((-1113 *4 (-607 $)) $)) (-15 -2747 ($ (-1113 *4 (-607 $))))))) (-4 *4 (-558)) (-5 *1 (-46 *4 *2)))) (-1396 (*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2319 ((-1113 *4 (-607 $)) $)) (-15 -2326 ((-1113 *4 (-607 $)) $)) (-15 -2747 ($ (-1113 *4 (-607 $))))))) (-4 *4 (-558)) (-5 *1 (-46 *4 *2)))) (-1396 (*1 *2 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2319 ((-1113 *3 (-607 $)) $)) (-15 -2326 ((-1113 *3 (-607 $)) $)) (-15 -2747 ($ (-1113 *3 (-607 $))))))))) (-1396 (*1 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2319 ((-1113 *3 (-607 $)) $)) (-15 -2326 ((-1113 *3 (-607 $)) $)) (-15 -2747 ($ (-1113 *3 (-607 $))))))))) (-3085 (*1 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2319 ((-1113 *3 (-607 $)) $)) (-15 -2326 ((-1113 *3 (-607 $)) $)) (-15 -2747 ($ (-1113 *3 (-607 $)))))))))) 
+(-10 -7 (-15 -3085 (|#2| |#2|)) (-15 -1396 (|#2| |#2|)) (-15 -1396 (|#2| |#2| |#2|)) (-15 -1396 (|#2| |#2| (-634 |#2|))) (-15 -1396 (|#2| |#2| (-634 (-607 |#2|)))) (-15 -2234 ((-1157 |#2|) |#2|)) (IF (|has| |#1| (-842)) (IF (|has| |#1| (-453)) (IF (|has| |#1| (-1037 (-568))) (IF (|has| |#2| (-432 |#1|)) (PROGN (-15 -4485 (|#2| |#2|)) (-15 -2086 (|#2| |#2|)) (-15 -4480 (|#2| |#2|)) (-15 -2282 (|#2| (-123) |#2| (-763)))) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) 
+((-3850 (((-420 (-1157 |#3|)) (-1157 |#3|) (-634 (-53))) 22) (((-420 |#3|) |#3| (-634 (-53))) 18))) 
+(((-47 |#1| |#2| |#3|) (-10 -7 (-15 -3850 ((-420 |#3|) |#3| (-634 (-53)))) (-15 -3850 ((-420 (-1157 |#3|)) (-1157 |#3|) (-634 (-53))))) (-842) (-788) (-950 (-53) |#2| |#1|)) (T -47)) 
+((-3850 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-53))) (-4 *5 (-842)) (-4 *6 (-788)) (-4 *7 (-950 (-53) *6 *5)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-47 *5 *6 *7)) (-5 *3 (-1157 *7)))) (-3850 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-53))) (-4 *5 (-842)) (-4 *6 (-788)) (-5 *2 (-420 *3)) (-5 *1 (-47 *5 *6 *3)) (-4 *3 (-950 (-53) *6 *5))))) 
+(-10 -7 (-15 -3850 ((-420 |#3|) |#3| (-634 (-53)))) (-15 -3850 ((-420 (-1157 |#3|)) (-1157 |#3|) (-634 (-53))))) 
+((-2809 (((-763) |#2|) 65)) (-2162 (((-763) |#2|) 68)) (-2959 (((-634 |#2|)) 33)) (-1953 (((-763) |#2|) 67)) (-3443 (((-763) |#2|) 64)) (-2813 (((-763) |#2|) 66)) (-3779 (((-634 (-679 |#1|))) 60)) (-2146 (((-634 |#2|)) 55)) (-4333 (((-634 |#2|) |#2|) 43)) (-4241 (((-634 |#2|)) 57)) (-3374 (((-634 |#2|)) 56)) (-2656 (((-634 (-679 |#1|))) 48)) (-3118 (((-634 |#2|)) 54)) (-1397 (((-634 |#2|) |#2|) 42)) (-2103 (((-634 |#2|)) 50)) (-4469 (((-634 (-679 |#1|))) 61)) (-4386 (((-634 |#2|)) 59)) (-2588 (((-1244 |#2|) (-1244 |#2|)) 83 (|has| |#1| (-301))))) 
+(((-48 |#1| |#2|) (-10 -7 (-15 -1953 ((-763) |#2|)) (-15 -2162 ((-763) |#2|)) (-15 -3443 ((-763) |#2|)) (-15 -2809 ((-763) |#2|)) (-15 -2813 ((-763) |#2|)) (-15 -2103 ((-634 |#2|))) (-15 -1397 ((-634 |#2|) |#2|)) (-15 -4333 ((-634 |#2|) |#2|)) (-15 -3118 ((-634 |#2|))) (-15 -2146 ((-634 |#2|))) (-15 -3374 ((-634 |#2|))) (-15 -4241 ((-634 |#2|))) (-15 -4386 ((-634 |#2|))) (-15 -2656 ((-634 (-679 |#1|)))) (-15 -3779 ((-634 (-679 |#1|)))) (-15 -4469 ((-634 (-679 |#1|)))) (-15 -2959 ((-634 |#2|))) (IF (|has| |#1| (-301)) (-15 -2588 ((-1244 |#2|) (-1244 |#2|))) |noBranch|)) (-558) (-419 |#1|)) (T -48)) 
+((-2588 (*1 *2 *2) (-12 (-5 *2 (-1244 *4)) (-4 *4 (-419 *3)) (-4 *3 (-301)) (-4 *3 (-558)) (-5 *1 (-48 *3 *4)))) (-2959 (*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3)))) (-4469 (*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 (-679 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3)))) (-3779 (*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 (-679 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3)))) (-2656 (*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 (-679 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3)))) (-4386 (*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3)))) (-4241 (*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3)))) (-3374 (*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3)))) (-2146 (*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3)))) (-3118 (*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3)))) (-4333 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 *3)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4)))) (-1397 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 *3)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4)))) (-2103 (*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3)))) (-2813 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-763)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4)))) (-2809 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-763)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4)))) (-3443 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-763)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4)))) (-2162 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-763)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4)))) (-1953 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-763)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4))))) 
+(-10 -7 (-15 -1953 ((-763) |#2|)) (-15 -2162 ((-763) |#2|)) (-15 -3443 ((-763) |#2|)) (-15 -2809 ((-763) |#2|)) (-15 -2813 ((-763) |#2|)) (-15 -2103 ((-634 |#2|))) (-15 -1397 ((-634 |#2|) |#2|)) (-15 -4333 ((-634 |#2|) |#2|)) (-15 -3118 ((-634 |#2|))) (-15 -2146 ((-634 |#2|))) (-15 -3374 ((-634 |#2|))) (-15 -4241 ((-634 |#2|))) (-15 -4386 ((-634 |#2|))) (-15 -2656 ((-634 (-679 |#1|)))) (-15 -3779 ((-634 (-679 |#1|)))) (-15 -4469 ((-634 (-679 |#1|)))) (-15 -2959 ((-634 |#2|))) (IF (|has| |#1| (-301)) (-15 -2588 ((-1244 |#2|) (-1244 |#2|))) |noBranch|)) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-3591 (((-3 $ "failed")) NIL (|has| |#1| (-558)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3542 (((-1244 (-679 |#1|)) (-1244 $)) NIL) (((-1244 (-679 |#1|))) 24)) (-3818 (((-1244 $)) 50)) (-4490 (($) NIL T CONST)) (-3354 (((-3 (-2 (|:| |particular| $) (|:| -2588 (-634 $))) "failed")) NIL (|has| |#1| (-558)))) (-2046 (((-3 $ "failed")) NIL (|has| |#1| (-558)))) (-1524 (((-679 |#1|) (-1244 $)) NIL) (((-679 |#1|)) NIL)) (-2467 ((|#1| $) NIL)) (-2235 (((-679 |#1|) $ (-1244 $)) NIL) (((-679 |#1|) $) NIL)) (-2812 (((-3 $ "failed") $) NIL (|has| |#1| (-558)))) (-1503 (((-1157 (-953 |#1|))) NIL (|has| |#1| (-365)))) (-2815 (($ $ (-917)) NIL)) (-1509 ((|#1| $) NIL)) (-3839 (((-1157 |#1|) $) NIL (|has| |#1| (-558)))) (-2886 ((|#1| (-1244 $)) NIL) ((|#1|) NIL)) (-3105 (((-1157 |#1|) $) NIL)) (-1463 (((-121)) 86)) (-3899 (($ (-1244 |#1|) (-1244 $)) NIL) (($ (-1244 |#1|)) NIL)) (-2902 (((-3 $ "failed") $) 14 (|has| |#1| (-558)))) (-2371 (((-917)) 51)) (-3375 (((-121)) NIL)) (-3402 (($ $ (-917)) NIL)) (-4221 (((-121)) NIL)) (-4463 (((-121)) NIL)) (-3582 (((-121)) 88)) (-2587 (((-3 (-2 (|:| |particular| $) (|:| -2588 (-634 $))) "failed")) NIL (|has| |#1| (-558)))) (-2061 (((-3 $ "failed")) NIL (|has| |#1| (-558)))) (-4134 (((-679 |#1|) (-1244 $)) NIL) (((-679 |#1|)) NIL)) (-2786 ((|#1| $) NIL)) (-3147 (((-679 |#1|) $ (-1244 $)) NIL) (((-679 |#1|) $) NIL)) (-1974 (((-3 $ "failed") $) NIL (|has| |#1| (-558)))) (-1730 (((-1157 (-953 |#1|))) NIL (|has| |#1| (-365)))) (-4202 (($ $ (-917)) NIL)) (-4390 ((|#1| $) NIL)) (-3364 (((-1157 |#1|) $) NIL (|has| |#1| (-558)))) (-2060 ((|#1| (-1244 $)) NIL) ((|#1|) NIL)) (-3114 (((-1157 |#1|) $) NIL)) (-3487 (((-121)) 85)) (-1893 (((-1143) $) NIL)) (-2153 (((-121)) 92)) (-2889 (((-121)) 91)) (-1852 (((-121)) 93)) (-4025 (((-1108) $) NIL)) (-3636 (((-121)) 87)) (-2781 ((|#1| $ (-568)) 53)) (-1656 (((-1244 |#1|) $ (-1244 $)) 47) (((-679 |#1|) (-1244 $) (-1244 $)) NIL) (((-1244 |#1|) $) 28) (((-679 |#1|) (-1244 $)) NIL)) (-4280 (((-1244 |#1|) $) NIL) (($ (-1244 |#1|)) NIL)) (-2155 (((-634 (-953 |#1|)) (-1244 $)) NIL) (((-634 (-953 |#1|))) NIL)) (-3985 (($ $ $) NIL)) (-3441 (((-121)) 83)) (-2747 (((-850) $) 68) (($ (-1244 |#1|)) 22)) (-2588 (((-1244 $)) 44)) (-2657 (((-634 (-1244 |#1|))) NIL (|has| |#1| (-558)))) (-2007 (($ $ $ $) NIL)) (-3964 (((-121)) 81)) (-3828 (($ (-679 |#1|) $) 18)) (-3911 (($ $ $) NIL)) (-2435 (((-121)) 84)) (-2984 (((-121)) 82)) (-3579 (((-121)) 80)) (-3058 (($) NIL T CONST)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 75) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-1127 |#2| |#1|) $) 19))) 
+(((-49 |#1| |#2| |#3| |#4|) (-13 (-419 |#1|) (-637 (-1127 |#2| |#1|)) (-10 -8 (-15 -2747 ($ (-1244 |#1|))))) (-365) (-917) (-634 (-1161)) (-1244 (-679 |#1|))) (T -49)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-365)) (-14 *6 (-1244 (-679 *3))) (-5 *1 (-49 *3 *4 *5 *6)) (-14 *4 (-917)) (-14 *5 (-634 (-1161)))))) 
+(-13 (-419 |#1|) (-637 (-1127 |#2| |#1|)) (-10 -8 (-15 -2747 ($ (-1244 |#1|))))) 
+((-2449 (((-121) $ $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-2852 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-2237 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-3623 (($ $) NIL)) (-2988 (($) NIL) (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-2481 (((-1249) $ |#1| |#1|) NIL (|has| $ (-6 -4522))) (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-2121 (($ $ (-568)) NIL (|has| $ (-6 -4522)))) (-1324 (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL) (((-121) $) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842)))) (-2109 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4522))) (($ $) NIL (-12 (|has| $ (-6 -4522)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842))))) (-3647 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL) (($ $) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842)))) (-1667 (((-121) $ (-763)) NIL)) (-3370 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (|has| $ (-6 -4522)))) (-1958 (($ $ $) 27 (|has| $ (-6 -4522)))) (-2257 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (|has| $ (-6 -4522)))) (-1706 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 29 (|has| $ (-6 -4522)))) (-2438 ((|#2| $ |#1| |#2|) 45) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-568) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (|has| $ (-6 -4522))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-1210 (-568)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (|has| $ (-6 -4522))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ "last" (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (|has| $ (-6 -4522))) (($ $ "rest" $) NIL (|has| $ (-6 -4522))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ "first" (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (|has| $ (-6 -4522))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ "value" (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) NIL (|has| $ (-6 -4522)))) (-3963 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL)) (-2803 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-1681 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-2678 (((-3 |#2| "failed") |#1| $) 37)) (-4490 (($) NIL T CONST)) (-4452 (($ $) NIL (|has| $ (-6 -4522)))) (-3945 (($ $) NIL)) (-3936 (($ $ (-763)) NIL) (($ $) 24)) (-1377 (($ $) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-1568 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (|has| $ (-6 -4521))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-3 |#2| "failed") |#1| $) 46) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL) (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (-4330 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-3094 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (|has| $ (-6 -4521))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (|has| $ (-6 -4521))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-1292 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4522))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-568) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (|has| $ (-6 -4522)))) (-2069 ((|#2| $ |#1|) NIL) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-568)) NIL)) (-1340 (((-121) $) NIL)) (-2766 (((-568) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL) (((-568) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))) (((-568) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-568)) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (-3317 (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 18 (|has| $ (-6 -4521))) (((-634 |#2|) $) NIL (|has| $ (-6 -4521))) (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 18 (|has| $ (-6 -4521)))) (-3534 (((-634 $) $) NIL)) (-3606 (((-121) $ $) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (-1851 (($ (-763) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL)) (-3791 (((-121) $ (-763)) NIL)) (-2539 ((|#1| $) NIL (|has| |#1| (-842))) (((-568) $) 32 (|has| (-568) (-842)))) (-1732 (($ $ $) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842)))) (-4496 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ $) NIL) (($ $ $) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842)))) (-3645 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ $) NIL) (($ $ $) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842)))) (-4406 (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-634 |#2|) $) NIL (|has| $ (-6 -4521))) (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090)))) (((-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-3631 ((|#1| $) NIL (|has| |#1| (-842))) (((-568) $) 34 (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842)))) (-2253 (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4522))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4522))) (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL) (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ $) NIL) (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL)) (-3897 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-4081 (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL)) (-3319 (((-121) $) NIL)) (-1893 (((-1143) $) 41 (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-4164 (($ $ (-763)) NIL) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-4253 (((-634 |#1|) $) 20)) (-2807 (((-121) |#1| $) NIL)) (-2580 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-1708 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL) (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-4124 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-3948 (((-634 |#1|) $) NIL) (((-634 (-568)) $) NIL)) (-2916 (((-121) |#1| $) NIL) (((-121) (-568) $) NIL)) (-4025 (((-1108) $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-3877 ((|#2| $) NIL (|has| |#1| (-842))) (($ $ (-763)) NIL) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 23)) (-2712 (((-3 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) "failed") (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL) (((-3 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) "failed") (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL)) (-2490 (($ $ |#2|) NIL (|has| $ (-6 -4522))) (($ $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (|has| $ (-6 -4522)))) (-3403 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-4049 (((-121) $) NIL)) (-3951 (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-634 (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090)))) (((-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-1480 (((-634 |#2|) $) NIL) (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 17)) (-2436 (((-121) $) 16)) (-1990 (($) 13)) (-2781 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-568) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ (-568)) NIL) (($ $ (-1210 (-568))) NIL) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ "last") NIL) (($ $ "rest") NIL) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ "first") NIL) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $ "value") NIL)) (-1665 (((-568) $ $) NIL)) (-3132 (($) 12) (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-4031 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-2828 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-2763 (((-121) $) NIL)) (-3903 (($ $) NIL)) (-1499 (($ $) NIL (|has| $ (-6 -4522)))) (-3535 (((-763) $) NIL)) (-4424 (($ $) NIL)) (-4170 (((-763) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-763) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090)))) (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521))) (((-763) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-763) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-3306 (($ $ $ (-568)) NIL (|has| $ (-6 -4522)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-609 (-541))))) (-4289 (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL) (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-1876 (($ $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL) (($ $ $) NIL)) (-2770 (($ $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL) (($ (-634 $)) NIL) (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 25) (($ $ $) NIL)) (-2747 (((-850) $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-3180 (((-634 $) $) NIL)) (-3873 (((-121) $ $) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (-4074 (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-2804 (((-3 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) "failed") |#1| $) 43)) (-3437 (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-1753 (((-121) $ $) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842)))) (-1740 (((-121) $ $) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842)))) (-1719 (((-121) $ $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-1747 (((-121) $ $) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842)))) (-1734 (((-121) $ $) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-842)))) (-1699 (((-763) $) 22 (|has| $ (-6 -4521))))) 
 (((-50 |#1| |#2|) (-41 |#1| |#2|) (-1090) (-1090)) (T -50)) 
 NIL 
 (-41 |#1| |#2|) 
-((-3921 (((-121) $) 12)) (-2795 (($ (-1 |#2| |#2|) $) 21)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) NIL) (($ (-409 (-568)) $) 24) (($ $ (-409 (-568))) NIL))) 
-(((-51 |#1| |#2| |#3|) (-10 -8 (-15 * (|#1| |#1| (-409 (-568)))) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 -3921 ((-121) |#1|)) (-15 -2795 (|#1| (-1 |#2| |#2|) |#1|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|))) (-52 |#2| |#3|) (-1047) (-787)) (T -51)) 
+((-2171 (((-121) $) 12)) (-2797 (($ (-1 |#2| |#2|) $) 21)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) NIL) (($ (-409 (-568)) $) 24) (($ $ (-409 (-568))) NIL))) 
+(((-51 |#1| |#2| |#3|) (-10 -8 (-15 * (|#1| |#1| (-409 (-568)))) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 -2171 ((-121) |#1|)) (-15 -2797 (|#1| (-1 |#2| |#2|) |#1|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|))) (-52 |#2| |#3|) (-1047) (-787)) (T -51)) 
 NIL 
-(-10 -8 (-15 * (|#1| |#1| (-409 (-568)))) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 -3921 ((-121) |#1|)) (-15 -2795 (|#1| (-1 |#2| |#2|) |#1|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 50 (|has| |#1| (-558)))) (-2227 (($ $) 51 (|has| |#1| (-558)))) (-1573 (((-121) $) 53 (|has| |#1| (-558)))) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-2114 (($ $) 59)) (-2925 (((-3 $ "failed") $) 33)) (-2735 (((-121) $) 30)) (-3921 (((-121) $) 61)) (-2047 (($ |#1| |#2|) 60)) (-2795 (($ (-1 |#1| |#1|) $) 62)) (-2097 (($ $) 64)) (-2102 ((|#1| $) 65)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2595 (((-3 $ "failed") $ $) 49 (|has| |#1| (-558)))) (-3206 ((|#2| $) 63)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ (-409 (-568))) 56 (|has| |#1| (-43 (-409 (-568))))) (($ $) 48 (|has| |#1| (-558))) (($ |#1|) 46 (|has| |#1| (-172)))) (-2604 ((|#1| $ |#2|) 58)) (-4371 (((-3 $ "failed") $) 47 (|has| |#1| (-148)))) (-4078 (((-763)) 28)) (-1826 (((-121) $ $) 52 (|has| |#1| (-558)))) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1779 (($ $ |#1|) 57 (|has| |#1| (-365)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-409 (-568)) $) 55 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 54 (|has| |#1| (-43 (-409 (-568))))))) 
+(-10 -8 (-15 * (|#1| |#1| (-409 (-568)))) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 -2171 ((-121) |#1|)) (-15 -2797 (|#1| (-1 |#2| |#2|) |#1|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 50 (|has| |#1| (-558)))) (-3661 (($ $) 51 (|has| |#1| (-558)))) (-4426 (((-121) $) 53 (|has| |#1| (-558)))) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-2116 (($ $) 59)) (-2902 (((-3 $ "failed") $) 33)) (-1598 (((-121) $) 30)) (-2171 (((-121) $) 61)) (-2049 (($ |#1| |#2|) 60)) (-2797 (($ (-1 |#1| |#1|) $) 62)) (-2099 (($ $) 64)) (-2104 ((|#1| $) 65)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2597 (((-3 $ "failed") $ $) 49 (|has| |#1| (-558)))) (-1836 ((|#2| $) 63)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ (-409 (-568))) 56 (|has| |#1| (-43 (-409 (-568))))) (($ $) 48 (|has| |#1| (-558))) (($ |#1|) 46 (|has| |#1| (-172)))) (-2079 ((|#1| $ |#2|) 58)) (-3385 (((-3 $ "failed") $) 47 (|has| |#1| (-148)))) (-3425 (((-763)) 28)) (-2273 (((-121) $ $) 52 (|has| |#1| (-558)))) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1781 (($ $ |#1|) 57 (|has| |#1| (-365)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-409 (-568)) $) 55 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 54 (|has| |#1| (-43 (-409 (-568))))))) 
 (((-52 |#1| |#2|) (-1275) (-1047) (-787)) (T -52)) 
-((-2102 (*1 *2 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047)))) (-2097 (*1 *1 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)))) (-3206 (*1 *2 *1) (-12 (-4 *1 (-52 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787)))) (-2795 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-52 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)))) (-3921 (*1 *2 *1) (-12 (-4 *1 (-52 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-121)))) (-2047 (*1 *1 *2 *3) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)))) (-2114 (*1 *1 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)))) (-2604 (*1 *2 *1 *3) (-12 (-4 *1 (-52 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047)))) (-1779 (*1 *1 *1 *2) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)) (-4 *2 (-365))))) 
-(-13 (-1047) (-120 |t#1| |t#1|) (-10 -8 (-15 -2102 (|t#1| $)) (-15 -2097 ($ $)) (-15 -3206 (|t#2| $)) (-15 -2795 ($ (-1 |t#1| |t#1|) $)) (-15 -3921 ((-121) $)) (-15 -2047 ($ |t#1| |t#2|)) (-15 -2114 ($ $)) (-15 -2604 (|t#1| $ |t#2|)) (IF (|has| |t#1| (-365)) (-15 -1779 ($ $ |t#1|)) |noBranch|) (IF (|has| |t#1| (-172)) (PROGN (-6 (-172)) (-6 (-43 |t#1|))) |noBranch|) (IF (|has| |t#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |t#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |t#1| (-558)) (-6 (-558)) |noBranch|) (IF (|has| |t#1| (-43 (-409 (-568)))) (-6 (-43 (-409 (-568)))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) |has| |#1| (-558)) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2198 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2198 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-285) |has| |#1| (-558)) ((-558) |has| |#1| (-558)) ((-637 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) |has| |#1| (-558)) ((-716) . T) ((-1053 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-1053 |#1|) . T) ((-1053 $) -2198 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2394 (((-634 $) (-1157 $) (-1161)) NIL) (((-634 $) (-1157 $)) NIL) (((-634 $) (-953 $)) NIL)) (-1681 (($ (-1157 $) (-1161)) NIL) (($ (-1157 $)) NIL) (($ (-953 $)) NIL)) (-2537 (((-121) $) 11)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-3001 (((-634 (-607 $)) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2366 (($ $ (-288 $)) NIL) (($ $ (-634 (-288 $))) NIL) (($ $ (-634 (-607 $)) (-634 $)) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1902 (($ $) NIL)) (-1497 (((-121) $ $) NIL)) (-2671 (($) NIL T CONST)) (-3214 (((-634 $) (-1157 $) (-1161)) NIL) (((-634 $) (-1157 $)) NIL) (((-634 $) (-953 $)) NIL)) (-2932 (($ (-1157 $) (-1161)) NIL) (($ (-1157 $)) NIL) (($ (-953 $)) NIL)) (-3666 (((-3 (-607 $) "failed") $) NIL) (((-3 (-568) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL)) (-2854 (((-607 $) $) NIL) (((-568) $) NIL) (((-409 (-568)) $) NIL)) (-2401 (($ $ $) NIL)) (-3164 (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-679 (-568)) (-679 $)) NIL) (((-2 (|:| -2928 (-679 (-409 (-568)))) (|:| |vec| (-1244 (-409 (-568))))) (-679 $) (-1244 $)) NIL) (((-679 (-409 (-568))) (-679 $)) NIL)) (-3092 (($ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-4499 (($ $) NIL) (($ (-634 $)) NIL)) (-3296 (((-634 (-123)) $) NIL)) (-3488 (((-123) (-123)) NIL)) (-2735 (((-121) $) 14)) (-1825 (((-121) $) NIL (|has| $ (-1037 (-568))))) (-2317 (((-1113 (-568) (-607 $)) $) NIL)) (-4044 (($ $ (-568)) NIL)) (-2657 (((-1157 $) (-1157 $) (-607 $)) NIL) (((-1157 $) (-1157 $) (-634 (-607 $))) NIL) (($ $ (-607 $)) NIL) (($ $ (-634 (-607 $))) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3007 (((-1157 $) (-607 $)) NIL (|has| $ (-1047)))) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-2795 (($ (-1 $ $) (-607 $)) NIL)) (-3693 (((-3 (-607 $) "failed") $) NIL)) (-2495 (($ (-634 $)) NIL) (($ $ $) NIL)) (-4487 (((-1143) $) NIL)) (-3804 (((-634 (-607 $)) $) NIL)) (-3443 (($ (-123) $) NIL) (($ (-123) (-634 $)) NIL)) (-2841 (((-121) $ (-123)) NIL) (((-121) $ (-1161)) NIL)) (-2081 (($ $) NIL)) (-2961 (((-763) $) NIL)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ (-634 $)) NIL) (($ $ $) NIL)) (-4059 (((-121) $ $) NIL) (((-121) $ (-1161)) NIL)) (-3848 (((-420 $) $) NIL)) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3277 (((-121) $) NIL (|has| $ (-1037 (-568))))) (-1339 (($ $ (-607 $) $) NIL) (($ $ (-634 (-607 $)) (-634 $)) NIL) (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ $))) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-1161) (-1 $ (-634 $))) NIL) (($ $ (-1161) (-1 $ $)) NIL) (($ $ (-634 (-123)) (-634 (-1 $ $))) NIL) (($ $ (-634 (-123)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-123) (-1 $ (-634 $))) NIL) (($ $ (-123) (-1 $ $)) NIL)) (-2709 (((-763) $) NIL)) (-2779 (($ (-123) $) NIL) (($ (-123) $ $) NIL) (($ (-123) $ $ $) NIL) (($ (-123) $ $ $ $) NIL) (($ (-123) (-634 $)) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3502 (($ $) NIL) (($ $ $) NIL)) (-4189 (($ $ (-763)) NIL) (($ $) NIL)) (-2324 (((-1113 (-568) (-607 $)) $) NIL)) (-1626 (($ $) NIL (|has| $ (-1047)))) (-4278 (((-381) $) NIL) (((-215) $) NIL) (((-169 (-381)) $) NIL)) (-2745 (((-850) $) NIL) (($ (-607 $)) NIL) (($ (-409 (-568))) NIL) (($ $) NIL) (($ (-568)) NIL) (($ (-1113 (-568) (-607 $))) NIL)) (-4078 (((-763)) NIL)) (-2092 (($ $) NIL) (($ (-634 $)) NIL)) (-2887 (((-121) (-123)) NIL)) (-1826 (((-121) $ $) NIL)) (-1887 (($ $ (-568)) NIL) (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (-3056 (($) 7 T CONST)) (-1556 (($) 12 T CONST)) (-3190 (($ $ (-763)) NIL) (($ $) NIL)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 16)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) NIL)) (-1779 (($ $ $) NIL)) (-1773 (($ $ $) 15) (($ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-409 (-568))) NIL) (($ $ (-568)) NIL) (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (* (($ (-409 (-568)) $) NIL) (($ $ (-409 (-568))) NIL) (($ $ $) NIL) (($ (-568) $) NIL) (($ (-763) $) NIL) (($ (-917) $) NIL))) 
-(((-53) (-13 (-296) (-27) (-1037 (-568)) (-1037 (-409 (-568))) (-630 (-568)) (-1021) (-630 (-409 (-568))) (-150) (-609 (-169 (-381))) (-225) (-10 -8 (-15 -2745 ($ (-1113 (-568) (-607 $)))) (-15 -2317 ((-1113 (-568) (-607 $)) $)) (-15 -2324 ((-1113 (-568) (-607 $)) $)) (-15 -3092 ($ $)) (-15 -2657 ((-1157 $) (-1157 $) (-607 $))) (-15 -2657 ((-1157 $) (-1157 $) (-634 (-607 $)))) (-15 -2657 ($ $ (-607 $))) (-15 -2657 ($ $ (-634 (-607 $))))))) (T -53)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1113 (-568) (-607 (-53)))) (-5 *1 (-53)))) (-2317 (*1 *2 *1) (-12 (-5 *2 (-1113 (-568) (-607 (-53)))) (-5 *1 (-53)))) (-2324 (*1 *2 *1) (-12 (-5 *2 (-1113 (-568) (-607 (-53)))) (-5 *1 (-53)))) (-3092 (*1 *1 *1) (-5 *1 (-53))) (-2657 (*1 *2 *2 *3) (-12 (-5 *2 (-1157 (-53))) (-5 *3 (-607 (-53))) (-5 *1 (-53)))) (-2657 (*1 *2 *2 *3) (-12 (-5 *2 (-1157 (-53))) (-5 *3 (-634 (-607 (-53)))) (-5 *1 (-53)))) (-2657 (*1 *1 *1 *2) (-12 (-5 *2 (-607 (-53))) (-5 *1 (-53)))) (-2657 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-607 (-53)))) (-5 *1 (-53))))) 
-(-13 (-296) (-27) (-1037 (-568)) (-1037 (-409 (-568))) (-630 (-568)) (-1021) (-630 (-409 (-568))) (-150) (-609 (-169 (-381))) (-225) (-10 -8 (-15 -2745 ($ (-1113 (-568) (-607 $)))) (-15 -2317 ((-1113 (-568) (-607 $)) $)) (-15 -2324 ((-1113 (-568) (-607 $)) $)) (-15 -3092 ($ $)) (-15 -2657 ((-1157 $) (-1157 $) (-607 $))) (-15 -2657 ((-1157 $) (-1157 $) (-634 (-607 $)))) (-15 -2657 ($ $ (-607 $))) (-15 -2657 ($ $ (-634 (-607 $)))))) 
-((-2447 (((-121) $ $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 7)) (-1717 (((-121) $ $) NIL))) 
+((-2104 (*1 *2 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047)))) (-2099 (*1 *1 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)))) (-1836 (*1 *2 *1) (-12 (-4 *1 (-52 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787)))) (-2797 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-52 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)))) (-2171 (*1 *2 *1) (-12 (-4 *1 (-52 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-121)))) (-2049 (*1 *1 *2 *3) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)))) (-2116 (*1 *1 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)))) (-2079 (*1 *2 *1 *3) (-12 (-4 *1 (-52 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047)))) (-1781 (*1 *1 *1 *2) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)) (-4 *2 (-365))))) 
+(-13 (-1047) (-120 |t#1| |t#1|) (-10 -8 (-15 -2104 (|t#1| $)) (-15 -2099 ($ $)) (-15 -1836 (|t#2| $)) (-15 -2797 ($ (-1 |t#1| |t#1|) $)) (-15 -2171 ((-121) $)) (-15 -2049 ($ |t#1| |t#2|)) (-15 -2116 ($ $)) (-15 -2079 (|t#1| $ |t#2|)) (IF (|has| |t#1| (-365)) (-15 -1781 ($ $ |t#1|)) |noBranch|) (IF (|has| |t#1| (-172)) (PROGN (-6 (-172)) (-6 (-43 |t#1|))) |noBranch|) (IF (|has| |t#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |t#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |t#1| (-558)) (-6 (-558)) |noBranch|) (IF (|has| |t#1| (-43 (-409 (-568)))) (-6 (-43 (-409 (-568)))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) |has| |#1| (-558)) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2199 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2199 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-285) |has| |#1| (-558)) ((-558) |has| |#1| (-558)) ((-637 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) |has| |#1| (-558)) ((-716) . T) ((-1053 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-1053 |#1|) . T) ((-1053 $) -2199 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
+((-2449 (((-121) $ $) NIL)) (-2251 (((-634 $) (-1157 $) (-1161)) NIL) (((-634 $) (-1157 $)) NIL) (((-634 $) (-953 $)) NIL)) (-3505 (($ (-1157 $) (-1161)) NIL) (($ (-1157 $)) NIL) (($ (-953 $)) NIL)) (-1819 (((-121) $) 11)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-3145 (((-634 (-607 $)) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4069 (($ $ (-288 $)) NIL) (($ $ (-634 (-288 $))) NIL) (($ $ (-634 (-607 $)) (-634 $)) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-1904 (($ $) NIL)) (-2589 (((-121) $ $) NIL)) (-4490 (($) NIL T CONST)) (-1867 (((-634 $) (-1157 $) (-1161)) NIL) (((-634 $) (-1157 $)) NIL) (((-634 $) (-953 $)) NIL)) (-2919 (($ (-1157 $) (-1161)) NIL) (($ (-1157 $)) NIL) (($ (-953 $)) NIL)) (-3668 (((-3 (-607 $) "failed") $) NIL) (((-3 (-568) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL)) (-2857 (((-607 $) $) NIL) (((-568) $) NIL) (((-409 (-568)) $) NIL)) (-2403 (($ $ $) NIL)) (-1668 (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-679 (-568)) (-679 $)) NIL) (((-2 (|:| -2908 (-679 (-409 (-568)))) (|:| |vec| (-1244 (-409 (-568))))) (-679 $) (-1244 $)) NIL) (((-679 (-409 (-568))) (-679 $)) NIL)) (-3094 (($ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-3855 (($ $) NIL) (($ (-634 $)) NIL)) (-2160 (((-634 (-123)) $) NIL)) (-3842 (((-123) (-123)) NIL)) (-1598 (((-121) $) 14)) (-2268 (((-121) $) NIL (|has| $ (-1037 (-568))))) (-2319 (((-1113 (-568) (-607 $)) $) NIL)) (-1550 (($ $ (-568)) NIL)) (-4417 (((-1157 $) (-1157 $) (-607 $)) NIL) (((-1157 $) (-1157 $) (-634 (-607 $))) NIL) (($ $ (-607 $)) NIL) (($ $ (-634 (-607 $))) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3170 (((-1157 $) (-607 $)) NIL (|has| $ (-1047)))) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-2797 (($ (-1 $ $) (-607 $)) NIL)) (-2337 (((-3 (-607 $) "failed") $) NIL)) (-2498 (($ (-634 $)) NIL) (($ $ $) NIL)) (-1893 (((-1143) $) NIL)) (-3832 (((-634 (-607 $)) $) NIL)) (-3446 (($ (-123) $) NIL) (($ (-123) (-634 $)) NIL)) (-3910 (((-121) $ (-123)) NIL) (((-121) $ (-1161)) NIL)) (-2083 (($ $) NIL)) (-2963 (((-763) $) NIL)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ (-634 $)) NIL) (($ $ $) NIL)) (-1609 (((-121) $ $) NIL) (((-121) $ (-1161)) NIL)) (-3850 (((-420 $) $) NIL)) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2080 (((-121) $) NIL (|has| $ (-1037 (-568))))) (-1339 (($ $ (-607 $) $) NIL) (($ $ (-634 (-607 $)) (-634 $)) NIL) (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ $))) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-1161) (-1 $ (-634 $))) NIL) (($ $ (-1161) (-1 $ $)) NIL) (($ $ (-634 (-123)) (-634 (-1 $ $))) NIL) (($ $ (-634 (-123)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-123) (-1 $ (-634 $))) NIL) (($ $ (-123) (-1 $ $)) NIL)) (-1466 (((-763) $) NIL)) (-2781 (($ (-123) $) NIL) (($ (-123) $ $) NIL) (($ (-123) $ $ $) NIL) (($ (-123) $ $ $ $) NIL) (($ (-123) (-634 $)) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-3924 (($ $) NIL) (($ $ $) NIL)) (-4191 (($ $ (-763)) NIL) (($ $) NIL)) (-2326 (((-1113 (-568) (-607 $)) $) NIL)) (-1492 (($ $) NIL (|has| $ (-1047)))) (-4280 (((-381) $) NIL) (((-215) $) NIL) (((-169 (-381)) $) NIL)) (-2747 (((-850) $) NIL) (($ (-607 $)) NIL) (($ (-409 (-568))) NIL) (($ $) NIL) (($ (-568)) NIL) (($ (-1113 (-568) (-607 $))) NIL)) (-3425 (((-763)) NIL)) (-3159 (($ $) NIL) (($ (-634 $)) NIL)) (-2779 (((-121) (-123)) NIL)) (-2273 (((-121) $ $) NIL)) (-1889 (($ $ (-568)) NIL) (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (-3058 (($) 7 T CONST)) (-1557 (($) 12 T CONST)) (-3192 (($ $ (-763)) NIL) (($ $) NIL)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 16)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) NIL)) (-1781 (($ $ $) NIL)) (-1775 (($ $ $) 15) (($ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-409 (-568))) NIL) (($ $ (-568)) NIL) (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (* (($ (-409 (-568)) $) NIL) (($ $ (-409 (-568))) NIL) (($ $ $) NIL) (($ (-568) $) NIL) (($ (-763) $) NIL) (($ (-917) $) NIL))) 
+(((-53) (-13 (-296) (-27) (-1037 (-568)) (-1037 (-409 (-568))) (-630 (-568)) (-1021) (-630 (-409 (-568))) (-150) (-609 (-169 (-381))) (-225) (-10 -8 (-15 -2747 ($ (-1113 (-568) (-607 $)))) (-15 -2319 ((-1113 (-568) (-607 $)) $)) (-15 -2326 ((-1113 (-568) (-607 $)) $)) (-15 -3094 ($ $)) (-15 -4417 ((-1157 $) (-1157 $) (-607 $))) (-15 -4417 ((-1157 $) (-1157 $) (-634 (-607 $)))) (-15 -4417 ($ $ (-607 $))) (-15 -4417 ($ $ (-634 (-607 $))))))) (T -53)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1113 (-568) (-607 (-53)))) (-5 *1 (-53)))) (-2319 (*1 *2 *1) (-12 (-5 *2 (-1113 (-568) (-607 (-53)))) (-5 *1 (-53)))) (-2326 (*1 *2 *1) (-12 (-5 *2 (-1113 (-568) (-607 (-53)))) (-5 *1 (-53)))) (-3094 (*1 *1 *1) (-5 *1 (-53))) (-4417 (*1 *2 *2 *3) (-12 (-5 *2 (-1157 (-53))) (-5 *3 (-607 (-53))) (-5 *1 (-53)))) (-4417 (*1 *2 *2 *3) (-12 (-5 *2 (-1157 (-53))) (-5 *3 (-634 (-607 (-53)))) (-5 *1 (-53)))) (-4417 (*1 *1 *1 *2) (-12 (-5 *2 (-607 (-53))) (-5 *1 (-53)))) (-4417 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-607 (-53)))) (-5 *1 (-53))))) 
+(-13 (-296) (-27) (-1037 (-568)) (-1037 (-409 (-568))) (-630 (-568)) (-1021) (-630 (-409 (-568))) (-150) (-609 (-169 (-381))) (-225) (-10 -8 (-15 -2747 ($ (-1113 (-568) (-607 $)))) (-15 -2319 ((-1113 (-568) (-607 $)) $)) (-15 -2326 ((-1113 (-568) (-607 $)) $)) (-15 -3094 ($ $)) (-15 -4417 ((-1157 $) (-1157 $) (-607 $))) (-15 -4417 ((-1157 $) (-1157 $) (-634 (-607 $)))) (-15 -4417 ($ $ (-607 $))) (-15 -4417 ($ $ (-634 (-607 $)))))) 
+((-2449 (((-121) $ $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 7)) (-1719 (((-121) $ $) NIL))) 
 (((-54) (-1090)) (T -54)) 
 NIL 
 (-1090) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 60)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-3374 (((-121) $) 20)) (-3666 (((-3 |#1| "failed") $) 23)) (-2854 ((|#1| $) 24)) (-2114 (($ $) 27)) (-2925 (((-3 $ "failed") $) NIL)) (-2735 (((-121) $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-2102 ((|#1| $) 21)) (-3939 (($ $) 49)) (-4487 (((-1143) $) NIL)) (-4494 (((-121) $) 28)) (-4022 (((-1108) $) NIL)) (-2704 (($ (-763)) 47)) (-1892 (($ (-634 (-568))) 48)) (-3206 (((-763) $) 29)) (-2745 (((-850) $) 63) (($ (-568)) 44) (($ |#1|) 42)) (-2604 ((|#1| $ $) 19)) (-4078 (((-763)) 46)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 30 T CONST)) (-1556 (($) 14 T CONST)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) 40)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 41) (($ |#1| $) 35))) 
-(((-55 |#1| |#2|) (-13 (-612 |#1|) (-1037 |#1|) (-10 -8 (-15 -2102 (|#1| $)) (-15 -3939 ($ $)) (-15 -2114 ($ $)) (-15 -2604 (|#1| $ $)) (-15 -2704 ($ (-763))) (-15 -1892 ($ (-634 (-568)))) (-15 -4494 ((-121) $)) (-15 -3374 ((-121) $)) (-15 -3206 ((-763) $)) (-15 -2795 ($ (-1 |#1| |#1|) $)))) (-1047) (-634 (-1161))) (T -55)) 
-((-2102 (*1 *2 *1) (-12 (-4 *2 (-1047)) (-5 *1 (-55 *2 *3)) (-14 *3 (-634 (-1161))))) (-3939 (*1 *1 *1) (-12 (-5 *1 (-55 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-634 (-1161))))) (-2114 (*1 *1 *1) (-12 (-5 *1 (-55 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-634 (-1161))))) (-2604 (*1 *2 *1 *1) (-12 (-4 *2 (-1047)) (-5 *1 (-55 *2 *3)) (-14 *3 (-634 (-1161))))) (-2704 (*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))))) (-1892 (*1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-55 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))))) (-4494 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))))) (-3374 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))))) (-3206 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))))) (-2795 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-55 *3 *4)) (-14 *4 (-634 (-1161)))))) 
-(-13 (-612 |#1|) (-1037 |#1|) (-10 -8 (-15 -2102 (|#1| $)) (-15 -3939 ($ $)) (-15 -2114 ($ $)) (-15 -2604 (|#1| $ $)) (-15 -2704 ($ (-763))) (-15 -1892 ($ (-634 (-568)))) (-15 -4494 ((-121) $)) (-15 -3374 ((-121) $)) (-15 -3206 ((-763) $)) (-15 -2795 ($ (-1 |#1| |#1|) $)))) 
-((-3374 (((-121) (-57)) 13)) (-3666 (((-3 |#1| "failed") (-57)) 21)) (-2854 ((|#1| (-57)) 22)) (-2745 (((-57) |#1|) 18))) 
-(((-56 |#1|) (-10 -7 (-15 -2745 ((-57) |#1|)) (-15 -3666 ((-3 |#1| "failed") (-57))) (-15 -3374 ((-121) (-57))) (-15 -2854 (|#1| (-57)))) (-1195)) (T -56)) 
-((-2854 (*1 *2 *3) (-12 (-5 *3 (-57)) (-5 *1 (-56 *2)) (-4 *2 (-1195)))) (-3374 (*1 *2 *3) (-12 (-5 *3 (-57)) (-5 *2 (-121)) (-5 *1 (-56 *4)) (-4 *4 (-1195)))) (-3666 (*1 *2 *3) (|partial| -12 (-5 *3 (-57)) (-5 *1 (-56 *2)) (-4 *2 (-1195)))) (-2745 (*1 *2 *3) (-12 (-5 *2 (-57)) (-5 *1 (-56 *3)) (-4 *3 (-1195))))) 
-(-10 -7 (-15 -2745 ((-57) |#1|)) (-15 -3666 ((-3 |#1| "failed") (-57))) (-15 -3374 ((-121) (-57))) (-15 -2854 (|#1| (-57)))) 
-((-2447 (((-121) $ $) NIL)) (-2702 (((-1143) (-121)) 25)) (-4186 (((-850) $) 24)) (-4422 (((-766) $) 12)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-3222 (((-850) $) 16)) (-2400 (((-1094) $) 14)) (-2745 (((-850) $) 32)) (-3465 (($ (-1094) (-766)) 33)) (-1717 (((-121) $ $) 18))) 
-(((-57) (-13 (-1090) (-10 -8 (-15 -3465 ($ (-1094) (-766))) (-15 -3222 ((-850) $)) (-15 -4186 ((-850) $)) (-15 -2400 ((-1094) $)) (-15 -4422 ((-766) $)) (-15 -2702 ((-1143) (-121)))))) (T -57)) 
-((-3465 (*1 *1 *2 *3) (-12 (-5 *2 (-1094)) (-5 *3 (-766)) (-5 *1 (-57)))) (-3222 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-57)))) (-4186 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-57)))) (-2400 (*1 *2 *1) (-12 (-5 *2 (-1094)) (-5 *1 (-57)))) (-4422 (*1 *2 *1) (-12 (-5 *2 (-766)) (-5 *1 (-57)))) (-2702 (*1 *2 *3) (-12 (-5 *3 (-121)) (-5 *2 (-1143)) (-5 *1 (-57))))) 
-(-13 (-1090) (-10 -8 (-15 -3465 ($ (-1094) (-766))) (-15 -3222 ((-850) $)) (-15 -4186 ((-850) $)) (-15 -2400 ((-1094) $)) (-15 -4422 ((-766) $)) (-15 -2702 ((-1143) (-121))))) 
-((-1641 (((-1249)) 19)) (-1483 (((-1092 (-1161)) (-1161)) 15)) (-1691 (((-1249)) 18))) 
-(((-58) (-10 -7 (-15 -1483 ((-1092 (-1161)) (-1161))) (-15 -1691 ((-1249))) (-15 -1641 ((-1249))))) (T -58)) 
-((-1641 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-58)))) (-1691 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-58)))) (-1483 (*1 *2 *3) (-12 (-5 *2 (-1092 (-1161))) (-5 *1 (-58)) (-5 *3 (-1161))))) 
-(-10 -7 (-15 -1483 ((-1092 (-1161)) (-1161))) (-15 -1691 ((-1249))) (-15 -1641 ((-1249)))) 
-((-3823 ((|#2| |#3| (-1 |#2| |#2|) |#2|) 16))) 
-(((-59 |#1| |#2| |#3|) (-10 -7 (-15 -3823 (|#2| |#3| (-1 |#2| |#2|) |#2|))) (-1047) (-637 |#1|) (-844 |#1|)) (T -59)) 
-((-3823 (*1 *2 *3 *4 *2) (-12 (-5 *4 (-1 *2 *2)) (-4 *2 (-637 *5)) (-4 *5 (-1047)) (-5 *1 (-59 *5 *2 *3)) (-4 *3 (-844 *5))))) 
-(-10 -7 (-15 -3823 (|#2| |#3| (-1 |#2| |#2|) |#2|))) 
-((-1748 ((|#3| |#3| (-634 (-1161))) 35)) (-1568 ((|#3| (-634 (-1069 |#1| |#2| |#3|)) |#3| (-917)) 22) ((|#3| (-634 (-1069 |#1| |#2| |#3|)) |#3|) 20))) 
-(((-60 |#1| |#2| |#3|) (-10 -7 (-15 -1568 (|#3| (-634 (-1069 |#1| |#2| |#3|)) |#3|)) (-15 -1568 (|#3| (-634 (-1069 |#1| |#2| |#3|)) |#3| (-917))) (-15 -1748 (|#3| |#3| (-634 (-1161))))) (-1090) (-13 (-1047) (-881 |#1|) (-842) (-609 (-887 |#1|))) (-13 (-432 |#2|) (-881 |#1|) (-609 (-887 |#1|)))) (T -60)) 
-((-1748 (*1 *2 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-5 *1 (-60 *4 *5 *2)) (-4 *2 (-13 (-432 *5) (-881 *4) (-609 (-887 *4)))))) (-1568 (*1 *2 *3 *2 *4) (-12 (-5 *3 (-634 (-1069 *5 *6 *2))) (-5 *4 (-917)) (-4 *5 (-1090)) (-4 *6 (-13 (-1047) (-881 *5) (-842) (-609 (-887 *5)))) (-4 *2 (-13 (-432 *6) (-881 *5) (-609 (-887 *5)))) (-5 *1 (-60 *5 *6 *2)))) (-1568 (*1 *2 *3 *2) (-12 (-5 *3 (-634 (-1069 *4 *5 *2))) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-4 *2 (-13 (-432 *5) (-881 *4) (-609 (-887 *4)))) (-5 *1 (-60 *4 *5 *2))))) 
-(-10 -7 (-15 -1568 (|#3| (-634 (-1069 |#1| |#2| |#3|)) |#3|)) (-15 -1568 (|#3| (-634 (-1069 |#1| |#2| |#3|)) |#3| (-917))) (-15 -1748 (|#3| |#3| (-634 (-1161))))) 
-((-2510 (((-121) $ (-763)) 23)) (-4159 (($ $ (-568) |#3|) 45)) (-2451 (($ $ (-568) |#4|) 49)) (-1818 ((|#3| $ (-568)) 58)) (-4360 (((-634 |#2|) $) 30)) (-1737 (((-121) $ (-763)) 25)) (-3109 (((-121) |#2| $) 53)) (-3674 (($ (-1 |#2| |#2|) $) 37)) (-2795 (($ (-1 |#2| |#2|) $) 36) (($ (-1 |#2| |#2| |#2|) $ $) 39) (($ (-1 |#2| |#2| |#2|) $ $ |#2|) 41)) (-2166 (((-121) $ (-763)) 24)) (-3724 (($ $ |#2|) 34)) (-1387 (((-121) (-1 (-121) |#2|) $) 19)) (-2779 ((|#2| $ (-568) (-568)) NIL) ((|#2| $ (-568) (-568) |#2|) 27)) (-4168 (((-763) (-1 (-121) |#2|) $) 28) (((-763) |#2| $) 55)) (-3863 (($ $) 33)) (-3731 ((|#4| $ (-568)) 61)) (-2745 (((-850) $) 66)) (-1319 (((-121) (-1 (-121) |#2|) $) 18)) (-1717 (((-121) $ $) 52)) (-1697 (((-763) $) 26))) 
-(((-61 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -2795 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1| |#2|)) (-15 -2795 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -3674 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2451 (|#1| |#1| (-568) |#4|)) (-15 -4159 (|#1| |#1| (-568) |#3|)) (-15 -4360 ((-634 |#2|) |#1|)) (-15 -3731 (|#4| |#1| (-568))) (-15 -1818 (|#3| |#1| (-568))) (-15 -2779 (|#2| |#1| (-568) (-568) |#2|)) (-15 -2779 (|#2| |#1| (-568) (-568))) (-15 -3724 (|#1| |#1| |#2|)) (-15 -1717 ((-121) |#1| |#1|)) (-15 -2745 ((-850) |#1|)) (-15 -3109 ((-121) |#2| |#1|)) (-15 -4168 ((-763) |#2| |#1|)) (-15 -4168 ((-763) (-1 (-121) |#2|) |#1|)) (-15 -1387 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -1319 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -2795 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -1697 ((-763) |#1|)) (-15 -2510 ((-121) |#1| (-763))) (-15 -1737 ((-121) |#1| (-763))) (-15 -2166 ((-121) |#1| (-763))) (-15 -3863 (|#1| |#1|))) (-62 |#2| |#3| |#4|) (-1195) (-375 |#2|) (-375 |#2|)) (T -61)) 
-NIL 
-(-10 -8 (-15 -2795 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1| |#2|)) (-15 -2795 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -3674 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2451 (|#1| |#1| (-568) |#4|)) (-15 -4159 (|#1| |#1| (-568) |#3|)) (-15 -4360 ((-634 |#2|) |#1|)) (-15 -3731 (|#4| |#1| (-568))) (-15 -1818 (|#3| |#1| (-568))) (-15 -2779 (|#2| |#1| (-568) (-568) |#2|)) (-15 -2779 (|#2| |#1| (-568) (-568))) (-15 -3724 (|#1| |#1| |#2|)) (-15 -1717 ((-121) |#1| |#1|)) (-15 -2745 ((-850) |#1|)) (-15 -3109 ((-121) |#2| |#1|)) (-15 -4168 ((-763) |#2| |#1|)) (-15 -4168 ((-763) (-1 (-121) |#2|) |#1|)) (-15 -1387 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -1319 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -2795 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -1697 ((-763) |#1|)) (-15 -2510 ((-121) |#1| (-763))) (-15 -1737 ((-121) |#1| (-763))) (-15 -2166 ((-121) |#1| (-763))) (-15 -3863 (|#1| |#1|))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2510 (((-121) $ (-763)) 8)) (-2436 ((|#1| $ (-568) (-568) |#1|) 41)) (-4159 (($ $ (-568) |#2|) 39)) (-2451 (($ $ (-568) |#3|) 38)) (-2671 (($) 7 T CONST)) (-1818 ((|#2| $ (-568)) 43)) (-3989 ((|#1| $ (-568) (-568) |#1|) 40)) (-2602 ((|#1| $ (-568) (-568)) 45)) (-4360 (((-634 |#1|) $) 30)) (-3043 (((-763) $) 48)) (-1849 (($ (-763) (-763) |#1|) 54)) (-2555 (((-763) $) 47)) (-1737 (((-121) $ (-763)) 9)) (-2087 (((-568) $) 52)) (-3364 (((-568) $) 50)) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-1663 (((-568) $) 51)) (-2893 (((-568) $) 49)) (-3674 (($ (-1 |#1| |#1|) $) 34)) (-2795 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 37) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) 36)) (-2166 (((-121) $ (-763)) 10)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3724 (($ $ |#1|) 53)) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 ((|#1| $ (-568) (-568)) 46) ((|#1| $ (-568) (-568) |#1|) 44)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-3731 ((|#3| $ (-568)) 42)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 60)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-1407 (((-121) $) 20)) (-3668 (((-3 |#1| "failed") $) 23)) (-2857 ((|#1| $) 24)) (-2116 (($ $) 27)) (-2902 (((-3 $ "failed") $) NIL)) (-1598 (((-121) $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-2104 ((|#1| $) 21)) (-4313 (($ $) 49)) (-1893 (((-1143) $) NIL)) (-1923 (((-121) $) 28)) (-4025 (((-1108) $) NIL)) (-2707 (($ (-763)) 47)) (-1894 (($ (-634 (-568))) 48)) (-1836 (((-763) $) 29)) (-2747 (((-850) $) 63) (($ (-568)) 44) (($ |#1|) 42)) (-2079 ((|#1| $ $) 19)) (-3425 (((-763)) 46)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 30 T CONST)) (-1557 (($) 14 T CONST)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) 40)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 41) (($ |#1| $) 35))) 
+(((-55 |#1| |#2|) (-13 (-612 |#1|) (-1037 |#1|) (-10 -8 (-15 -2104 (|#1| $)) (-15 -4313 ($ $)) (-15 -2116 ($ $)) (-15 -2079 (|#1| $ $)) (-15 -2707 ($ (-763))) (-15 -1894 ($ (-634 (-568)))) (-15 -1923 ((-121) $)) (-15 -1407 ((-121) $)) (-15 -1836 ((-763) $)) (-15 -2797 ($ (-1 |#1| |#1|) $)))) (-1047) (-634 (-1161))) (T -55)) 
+((-2104 (*1 *2 *1) (-12 (-4 *2 (-1047)) (-5 *1 (-55 *2 *3)) (-14 *3 (-634 (-1161))))) (-4313 (*1 *1 *1) (-12 (-5 *1 (-55 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-634 (-1161))))) (-2116 (*1 *1 *1) (-12 (-5 *1 (-55 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-634 (-1161))))) (-2079 (*1 *2 *1 *1) (-12 (-4 *2 (-1047)) (-5 *1 (-55 *2 *3)) (-14 *3 (-634 (-1161))))) (-2707 (*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))))) (-1894 (*1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-55 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))))) (-1923 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))))) (-1407 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))))) (-1836 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))))) (-2797 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-55 *3 *4)) (-14 *4 (-634 (-1161)))))) 
+(-13 (-612 |#1|) (-1037 |#1|) (-10 -8 (-15 -2104 (|#1| $)) (-15 -4313 ($ $)) (-15 -2116 ($ $)) (-15 -2079 (|#1| $ $)) (-15 -2707 ($ (-763))) (-15 -1894 ($ (-634 (-568)))) (-15 -1923 ((-121) $)) (-15 -1407 ((-121) $)) (-15 -1836 ((-763) $)) (-15 -2797 ($ (-1 |#1| |#1|) $)))) 
+((-1407 (((-121) (-57)) 13)) (-3668 (((-3 |#1| "failed") (-57)) 21)) (-2857 ((|#1| (-57)) 22)) (-2747 (((-57) |#1|) 18))) 
+(((-56 |#1|) (-10 -7 (-15 -2747 ((-57) |#1|)) (-15 -3668 ((-3 |#1| "failed") (-57))) (-15 -1407 ((-121) (-57))) (-15 -2857 (|#1| (-57)))) (-1195)) (T -56)) 
+((-2857 (*1 *2 *3) (-12 (-5 *3 (-57)) (-5 *1 (-56 *2)) (-4 *2 (-1195)))) (-1407 (*1 *2 *3) (-12 (-5 *3 (-57)) (-5 *2 (-121)) (-5 *1 (-56 *4)) (-4 *4 (-1195)))) (-3668 (*1 *2 *3) (|partial| -12 (-5 *3 (-57)) (-5 *1 (-56 *2)) (-4 *2 (-1195)))) (-2747 (*1 *2 *3) (-12 (-5 *2 (-57)) (-5 *1 (-56 *3)) (-4 *3 (-1195))))) 
+(-10 -7 (-15 -2747 ((-57) |#1|)) (-15 -3668 ((-3 |#1| "failed") (-57))) (-15 -1407 ((-121) (-57))) (-15 -2857 (|#1| (-57)))) 
+((-2449 (((-121) $ $) NIL)) (-1428 (((-1143) (-121)) 25)) (-4020 (((-850) $) 24)) (-1580 (((-766) $) 12)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-1895 (((-850) $) 16)) (-2402 (((-1094) $) 14)) (-2747 (((-850) $) 32)) (-3467 (($ (-1094) (-766)) 33)) (-1719 (((-121) $ $) 18))) 
+(((-57) (-13 (-1090) (-10 -8 (-15 -3467 ($ (-1094) (-766))) (-15 -1895 ((-850) $)) (-15 -4020 ((-850) $)) (-15 -2402 ((-1094) $)) (-15 -1580 ((-766) $)) (-15 -1428 ((-1143) (-121)))))) (T -57)) 
+((-3467 (*1 *1 *2 *3) (-12 (-5 *2 (-1094)) (-5 *3 (-766)) (-5 *1 (-57)))) (-1895 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-57)))) (-4020 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-57)))) (-2402 (*1 *2 *1) (-12 (-5 *2 (-1094)) (-5 *1 (-57)))) (-1580 (*1 *2 *1) (-12 (-5 *2 (-766)) (-5 *1 (-57)))) (-1428 (*1 *2 *3) (-12 (-5 *3 (-121)) (-5 *2 (-1143)) (-5 *1 (-57))))) 
+(-13 (-1090) (-10 -8 (-15 -3467 ($ (-1094) (-766))) (-15 -1895 ((-850) $)) (-15 -4020 ((-850) $)) (-15 -2402 ((-1094) $)) (-15 -1580 ((-766) $)) (-15 -1428 ((-1143) (-121))))) 
+((-1643 (((-1249)) 19)) (-2523 (((-1092 (-1161)) (-1161)) 15)) (-1693 (((-1249)) 18))) 
+(((-58) (-10 -7 (-15 -2523 ((-1092 (-1161)) (-1161))) (-15 -1693 ((-1249))) (-15 -1643 ((-1249))))) (T -58)) 
+((-1643 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-58)))) (-1693 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-58)))) (-2523 (*1 *2 *3) (-12 (-5 *2 (-1092 (-1161))) (-5 *1 (-58)) (-5 *3 (-1161))))) 
+(-10 -7 (-15 -2523 ((-1092 (-1161)) (-1161))) (-15 -1693 ((-1249))) (-15 -1643 ((-1249)))) 
+((-3828 ((|#2| |#3| (-1 |#2| |#2|) |#2|) 16))) 
+(((-59 |#1| |#2| |#3|) (-10 -7 (-15 -3828 (|#2| |#3| (-1 |#2| |#2|) |#2|))) (-1047) (-637 |#1|) (-844 |#1|)) (T -59)) 
+((-3828 (*1 *2 *3 *4 *2) (-12 (-5 *4 (-1 *2 *2)) (-4 *2 (-637 *5)) (-4 *5 (-1047)) (-5 *1 (-59 *5 *2 *3)) (-4 *3 (-844 *5))))) 
+(-10 -7 (-15 -3828 (|#2| |#3| (-1 |#2| |#2|) |#2|))) 
+((-3788 ((|#3| |#3| (-634 (-1161))) 35)) (-4398 ((|#3| (-634 (-1069 |#1| |#2| |#3|)) |#3| (-917)) 22) ((|#3| (-634 (-1069 |#1| |#2| |#3|)) |#3|) 20))) 
+(((-60 |#1| |#2| |#3|) (-10 -7 (-15 -4398 (|#3| (-634 (-1069 |#1| |#2| |#3|)) |#3|)) (-15 -4398 (|#3| (-634 (-1069 |#1| |#2| |#3|)) |#3| (-917))) (-15 -3788 (|#3| |#3| (-634 (-1161))))) (-1090) (-13 (-1047) (-881 |#1|) (-842) (-609 (-887 |#1|))) (-13 (-432 |#2|) (-881 |#1|) (-609 (-887 |#1|)))) (T -60)) 
+((-3788 (*1 *2 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-5 *1 (-60 *4 *5 *2)) (-4 *2 (-13 (-432 *5) (-881 *4) (-609 (-887 *4)))))) (-4398 (*1 *2 *3 *2 *4) (-12 (-5 *3 (-634 (-1069 *5 *6 *2))) (-5 *4 (-917)) (-4 *5 (-1090)) (-4 *6 (-13 (-1047) (-881 *5) (-842) (-609 (-887 *5)))) (-4 *2 (-13 (-432 *6) (-881 *5) (-609 (-887 *5)))) (-5 *1 (-60 *5 *6 *2)))) (-4398 (*1 *2 *3 *2) (-12 (-5 *3 (-634 (-1069 *4 *5 *2))) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-4 *2 (-13 (-432 *5) (-881 *4) (-609 (-887 *4)))) (-5 *1 (-60 *4 *5 *2))))) 
+(-10 -7 (-15 -4398 (|#3| (-634 (-1069 |#1| |#2| |#3|)) |#3|)) (-15 -4398 (|#3| (-634 (-1069 |#1| |#2| |#3|)) |#3| (-917))) (-15 -3788 (|#3| |#3| (-634 (-1161))))) 
+((-1667 (((-121) $ (-763)) 23)) (-3874 (($ $ (-568) |#3|) 45)) (-2525 (($ $ (-568) |#4|) 49)) (-2228 ((|#3| $ (-568)) 58)) (-3317 (((-634 |#2|) $) 30)) (-3791 (((-121) $ (-763)) 25)) (-2551 (((-121) |#2| $) 53)) (-2253 (($ (-1 |#2| |#2|) $) 37)) (-2797 (($ (-1 |#2| |#2|) $) 36) (($ (-1 |#2| |#2| |#2|) $ $) 39) (($ (-1 |#2| |#2| |#2|) $ $ |#2|) 41)) (-3796 (((-121) $ (-763)) 24)) (-2490 (($ $ |#2|) 34)) (-3951 (((-121) (-1 (-121) |#2|) $) 19)) (-2781 ((|#2| $ (-568) (-568)) NIL) ((|#2| $ (-568) (-568) |#2|) 27)) (-4170 (((-763) (-1 (-121) |#2|) $) 28) (((-763) |#2| $) 55)) (-3865 (($ $) 33)) (-2522 ((|#4| $ (-568)) 61)) (-2747 (((-850) $) 66)) (-3437 (((-121) (-1 (-121) |#2|) $) 18)) (-1719 (((-121) $ $) 52)) (-1699 (((-763) $) 26))) 
+(((-61 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -2797 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1| |#2|)) (-15 -2797 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -2253 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2525 (|#1| |#1| (-568) |#4|)) (-15 -3874 (|#1| |#1| (-568) |#3|)) (-15 -3317 ((-634 |#2|) |#1|)) (-15 -2522 (|#4| |#1| (-568))) (-15 -2228 (|#3| |#1| (-568))) (-15 -2781 (|#2| |#1| (-568) (-568) |#2|)) (-15 -2781 (|#2| |#1| (-568) (-568))) (-15 -2490 (|#1| |#1| |#2|)) (-15 -1719 ((-121) |#1| |#1|)) (-15 -2747 ((-850) |#1|)) (-15 -2551 ((-121) |#2| |#1|)) (-15 -4170 ((-763) |#2| |#1|)) (-15 -4170 ((-763) (-1 (-121) |#2|) |#1|)) (-15 -3951 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3437 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -2797 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -1699 ((-763) |#1|)) (-15 -1667 ((-121) |#1| (-763))) (-15 -3791 ((-121) |#1| (-763))) (-15 -3796 ((-121) |#1| (-763))) (-15 -3865 (|#1| |#1|))) (-62 |#2| |#3| |#4|) (-1195) (-375 |#2|) (-375 |#2|)) (T -61)) 
+NIL 
+(-10 -8 (-15 -2797 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1| |#2|)) (-15 -2797 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -2253 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2525 (|#1| |#1| (-568) |#4|)) (-15 -3874 (|#1| |#1| (-568) |#3|)) (-15 -3317 ((-634 |#2|) |#1|)) (-15 -2522 (|#4| |#1| (-568))) (-15 -2228 (|#3| |#1| (-568))) (-15 -2781 (|#2| |#1| (-568) (-568) |#2|)) (-15 -2781 (|#2| |#1| (-568) (-568))) (-15 -2490 (|#1| |#1| |#2|)) (-15 -1719 ((-121) |#1| |#1|)) (-15 -2747 ((-850) |#1|)) (-15 -2551 ((-121) |#2| |#1|)) (-15 -4170 ((-763) |#2| |#1|)) (-15 -4170 ((-763) (-1 (-121) |#2|) |#1|)) (-15 -3951 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3437 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -2797 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -1699 ((-763) |#1|)) (-15 -1667 ((-121) |#1| (-763))) (-15 -3791 ((-121) |#1| (-763))) (-15 -3796 ((-121) |#1| (-763))) (-15 -3865 (|#1| |#1|))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-1667 (((-121) $ (-763)) 8)) (-2438 ((|#1| $ (-568) (-568) |#1|) 41)) (-3874 (($ $ (-568) |#2|) 39)) (-2525 (($ $ (-568) |#3|) 38)) (-4490 (($) 7 T CONST)) (-2228 ((|#2| $ (-568)) 43)) (-1292 ((|#1| $ (-568) (-568) |#1|) 40)) (-2069 ((|#1| $ (-568) (-568)) 45)) (-3317 (((-634 |#1|) $) 30)) (-2241 (((-763) $) 48)) (-1851 (($ (-763) (-763) |#1|) 54)) (-1901 (((-763) $) 47)) (-3791 (((-121) $ (-763)) 9)) (-3139 (((-568) $) 52)) (-1343 (((-568) $) 50)) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3405 (((-568) $) 51)) (-2801 (((-568) $) 49)) (-2253 (($ (-1 |#1| |#1|) $) 34)) (-2797 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 37) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) 36)) (-3796 (((-121) $ (-763)) 10)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-2490 (($ $ |#1|) 53)) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 ((|#1| $ (-568) (-568)) 46) ((|#1| $ (-568) (-568) |#1|) 44)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-2522 ((|#3| $ (-568)) 42)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-62 |#1| |#2| |#3|) (-1275) (-1195) (-375 |t#1|) (-375 |t#1|)) (T -62)) 
-((-2795 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-1849 (*1 *1 *2 *2 *3) (-12 (-5 *2 (-763)) (-4 *3 (-1195)) (-4 *1 (-62 *3 *4 *5)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-3724 (*1 *1 *1 *2) (-12 (-4 *1 (-62 *2 *3 *4)) (-4 *2 (-1195)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) (-2087 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-568)))) (-1663 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-568)))) (-3364 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-568)))) (-2893 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-568)))) (-3043 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-763)))) (-2555 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-763)))) (-2779 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *1 (-62 *2 *4 *5)) (-4 *4 (-375 *2)) (-4 *5 (-375 *2)) (-4 *2 (-1195)))) (-2602 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *1 (-62 *2 *4 *5)) (-4 *4 (-375 *2)) (-4 *5 (-375 *2)) (-4 *2 (-1195)))) (-2779 (*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1195)) (-4 *4 (-375 *2)) (-4 *5 (-375 *2)))) (-1818 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-62 *4 *2 *5)) (-4 *4 (-1195)) (-4 *5 (-375 *4)) (-4 *2 (-375 *4)))) (-3731 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-62 *4 *5 *2)) (-4 *4 (-1195)) (-4 *5 (-375 *4)) (-4 *2 (-375 *4)))) (-4360 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-634 *3)))) (-2436 (*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1195)) (-4 *4 (-375 *2)) (-4 *5 (-375 *2)))) (-3989 (*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1195)) (-4 *4 (-375 *2)) (-4 *5 (-375 *2)))) (-4159 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-568)) (-4 *1 (-62 *4 *3 *5)) (-4 *4 (-1195)) (-4 *3 (-375 *4)) (-4 *5 (-375 *4)))) (-2451 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-568)) (-4 *1 (-62 *4 *5 *3)) (-4 *4 (-1195)) (-4 *5 (-375 *4)) (-4 *3 (-375 *4)))) (-3674 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-2795 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-2795 (*1 *1 *2 *1 *1 *3) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3))))) 
-(-13 (-499 |t#1|) (-10 -8 (-6 -4520) (-6 -4519) (-15 -1849 ($ (-763) (-763) |t#1|)) (-15 -3724 ($ $ |t#1|)) (-15 -2087 ((-568) $)) (-15 -1663 ((-568) $)) (-15 -3364 ((-568) $)) (-15 -2893 ((-568) $)) (-15 -3043 ((-763) $)) (-15 -2555 ((-763) $)) (-15 -2779 (|t#1| $ (-568) (-568))) (-15 -2602 (|t#1| $ (-568) (-568))) (-15 -2779 (|t#1| $ (-568) (-568) |t#1|)) (-15 -1818 (|t#2| $ (-568))) (-15 -3731 (|t#3| $ (-568))) (-15 -4360 ((-634 |t#1|) $)) (-15 -2436 (|t#1| $ (-568) (-568) |t#1|)) (-15 -3989 (|t#1| $ (-568) (-568) |t#1|)) (-15 -4159 ($ $ (-568) |t#2|)) (-15 -2451 ($ $ (-568) |t#3|)) (-15 -2795 ($ (-1 |t#1| |t#1|) $)) (-15 -3674 ($ (-1 |t#1| |t#1|) $)) (-15 -2795 ($ (-1 |t#1| |t#1| |t#1|) $ $)) (-15 -2795 ($ (-1 |t#1| |t#1| |t#1|) $ $ |t#1|)))) 
+((-2797 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-1851 (*1 *1 *2 *2 *3) (-12 (-5 *2 (-763)) (-4 *3 (-1195)) (-4 *1 (-62 *3 *4 *5)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-2490 (*1 *1 *1 *2) (-12 (-4 *1 (-62 *2 *3 *4)) (-4 *2 (-1195)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) (-3139 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-568)))) (-3405 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-568)))) (-1343 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-568)))) (-2801 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-568)))) (-2241 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-763)))) (-1901 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-763)))) (-2781 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *1 (-62 *2 *4 *5)) (-4 *4 (-375 *2)) (-4 *5 (-375 *2)) (-4 *2 (-1195)))) (-2069 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *1 (-62 *2 *4 *5)) (-4 *4 (-375 *2)) (-4 *5 (-375 *2)) (-4 *2 (-1195)))) (-2781 (*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1195)) (-4 *4 (-375 *2)) (-4 *5 (-375 *2)))) (-2228 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-62 *4 *2 *5)) (-4 *4 (-1195)) (-4 *5 (-375 *4)) (-4 *2 (-375 *4)))) (-2522 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-62 *4 *5 *2)) (-4 *4 (-1195)) (-4 *5 (-375 *4)) (-4 *2 (-375 *4)))) (-3317 (*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-634 *3)))) (-2438 (*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1195)) (-4 *4 (-375 *2)) (-4 *5 (-375 *2)))) (-1292 (*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1195)) (-4 *4 (-375 *2)) (-4 *5 (-375 *2)))) (-3874 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-568)) (-4 *1 (-62 *4 *3 *5)) (-4 *4 (-1195)) (-4 *3 (-375 *4)) (-4 *5 (-375 *4)))) (-2525 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-568)) (-4 *1 (-62 *4 *5 *3)) (-4 *4 (-1195)) (-4 *5 (-375 *4)) (-4 *3 (-375 *4)))) (-2253 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-2797 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-2797 (*1 *1 *2 *1 *1 *3) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3))))) 
+(-13 (-499 |t#1|) (-10 -8 (-6 -4522) (-6 -4521) (-15 -1851 ($ (-763) (-763) |t#1|)) (-15 -2490 ($ $ |t#1|)) (-15 -3139 ((-568) $)) (-15 -3405 ((-568) $)) (-15 -1343 ((-568) $)) (-15 -2801 ((-568) $)) (-15 -2241 ((-763) $)) (-15 -1901 ((-763) $)) (-15 -2781 (|t#1| $ (-568) (-568))) (-15 -2069 (|t#1| $ (-568) (-568))) (-15 -2781 (|t#1| $ (-568) (-568) |t#1|)) (-15 -2228 (|t#2| $ (-568))) (-15 -2522 (|t#3| $ (-568))) (-15 -3317 ((-634 |t#1|) $)) (-15 -2438 (|t#1| $ (-568) (-568) |t#1|)) (-15 -1292 (|t#1| $ (-568) (-568) |t#1|)) (-15 -3874 ($ $ (-568) |t#2|)) (-15 -2525 ($ $ (-568) |t#3|)) (-15 -2797 ($ (-1 |t#1| |t#1|) $)) (-15 -2253 ($ (-1 |t#1| |t#1|) $)) (-15 -2797 ($ (-1 |t#1| |t#1| |t#1|) $ $)) (-15 -2797 ($ (-1 |t#1| |t#1| |t#1|) $ $ |t#1|)))) 
 (((-39) . T) ((-105) |has| |#1| (-1090)) ((-608 (-850)) |has| |#1| (-1090)) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-1090) |has| |#1| (-1090)) ((-1195) . T)) 
-((-2512 (((-64 |#2|) (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|) 16)) (-3092 ((|#2| (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|) 18)) (-2795 (((-64 |#2|) (-1 |#2| |#1|) (-64 |#1|)) 13))) 
-(((-63 |#1| |#2|) (-10 -7 (-15 -2512 ((-64 |#2|) (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|)) (-15 -3092 (|#2| (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|)) (-15 -2795 ((-64 |#2|) (-1 |#2| |#1|) (-64 |#1|)))) (-1195) (-1195)) (T -63)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-64 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-64 *6)) (-5 *1 (-63 *5 *6)))) (-3092 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-64 *5)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-63 *5 *2)))) (-2512 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-64 *6)) (-4 *6 (-1195)) (-4 *5 (-1195)) (-5 *2 (-64 *5)) (-5 *1 (-63 *6 *5))))) 
-(-10 -7 (-15 -2512 ((-64 |#2|) (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|)) (-15 -3092 (|#2| (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|)) (-15 -2795 ((-64 |#2|) (-1 |#2| |#1|) (-64 |#1|)))) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-2016 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-842)))) (-3908 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4520))) (($ $) NIL (-12 (|has| $ (-6 -4520)) (|has| |#1| (-842))))) (-3644 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-842)))) (-2510 (((-121) $ (-763)) NIL)) (-2436 ((|#1| $ (-568) |#1|) 11 (|has| $ (-6 -4520))) ((|#1| $ (-1210 (-568)) |#1|) NIL (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-2671 (($) NIL T CONST)) (-1578 (($ $) NIL (|has| $ (-6 -4520)))) (-3943 (($ $) NIL)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-4328 (($ |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4519)))) (-3989 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-568)) NIL)) (-2764 (((-568) (-1 (-121) |#1|) $) NIL) (((-568) |#1| $) NIL (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) NIL (|has| |#1| (-1090)))) (-4360 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-1434 (($ (-634 |#1|)) 13) (($ (-763) |#1|) 14)) (-1849 (($ (-763) |#1|) 9)) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) NIL (|has| (-568) (-842)))) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-1347 (($ (-1 (-121) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-842)))) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2223 (((-568) $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-3674 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4122 (($ |#1| $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3876 ((|#1| $) NIL (|has| (-568) (-842)))) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3724 (($ $ |#1|) NIL (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) 7)) (-2779 ((|#1| $ (-568) |#1|) NIL) ((|#1| $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-2826 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2256 (($ $ $ (-568)) NIL (|has| $ (-6 -4520)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) NIL)) (-2768 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-634 $)) NIL)) (-2745 (((-850) $) NIL (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-64 |#1|) (-13 (-19 |#1|) (-10 -8 (-15 -1434 ($ (-634 |#1|))) (-15 -1434 ($ (-763) |#1|)))) (-1195)) (T -64)) 
-((-1434 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-64 *3)))) (-1434 (*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *1 (-64 *3)) (-4 *3 (-1195))))) 
-(-13 (-19 |#1|) (-10 -8 (-15 -1434 ($ (-634 |#1|))) (-15 -1434 ($ (-763) |#1|)))) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2510 (((-121) $ (-763)) NIL)) (-2436 ((|#1| $ (-568) (-568) |#1|) NIL)) (-4159 (($ $ (-568) (-64 |#1|)) NIL)) (-2451 (($ $ (-568) (-64 |#1|)) NIL)) (-2671 (($) NIL T CONST)) (-1818 (((-64 |#1|) $ (-568)) NIL)) (-3989 ((|#1| $ (-568) (-568) |#1|) NIL)) (-2602 ((|#1| $ (-568) (-568)) NIL)) (-4360 (((-634 |#1|) $) NIL)) (-3043 (((-763) $) NIL)) (-1849 (($ (-763) (-763) |#1|) NIL)) (-2555 (((-763) $) NIL)) (-1737 (((-121) $ (-763)) NIL)) (-2087 (((-568) $) NIL)) (-3364 (((-568) $) NIL)) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-1663 (((-568) $) NIL)) (-2893 (((-568) $) NIL)) (-3674 (($ (-1 |#1| |#1|) $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3724 (($ $ |#1|) NIL)) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#1| $ (-568) (-568)) NIL) ((|#1| $ (-568) (-568) |#1|) NIL)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) NIL)) (-3731 (((-64 |#1|) $ (-568)) NIL)) (-2745 (((-850) $) NIL (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-65 |#1|) (-13 (-62 |#1| (-64 |#1|) (-64 |#1|)) (-10 -7 (-6 -4520))) (-1195)) (T -65)) 
-NIL 
-(-13 (-62 |#1| (-64 |#1|) (-64 |#1|)) (-10 -7 (-6 -4520))) 
-((-3666 (((-3 $ "failed") (-1244 (-310 (-381)))) 69) (((-3 $ "failed") (-1244 (-310 (-568)))) 58) (((-3 $ "failed") (-1244 (-953 (-381)))) 91) (((-3 $ "failed") (-1244 (-953 (-568)))) 80) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 47) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 36)) (-2854 (($ (-1244 (-310 (-381)))) 65) (($ (-1244 (-310 (-568)))) 54) (($ (-1244 (-953 (-381)))) 87) (($ (-1244 (-953 (-568)))) 76) (($ (-1244 (-409 (-953 (-381))))) 43) (($ (-1244 (-409 (-953 (-568))))) 29)) (-4128 (((-1249) $) 118)) (-2745 (((-850) $) 111) (($ (-634 (-328))) 100) (($ (-328)) 94) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 97) (($ (-1244 (-337 (-4287 (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (-4287) (-688)))) 28))) 
-(((-66 |#1|) (-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287 (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (-4287) (-688))))))) (-1161)) (T -66)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287 (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (-4287) (-688)))) (-5 *1 (-66 *3)) (-14 *3 (-1161))))) 
-(-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287 (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (-4287) (-688))))))) 
-((-4128 (((-1249) $) 48) (((-1249)) 49)) (-2745 (((-850) $) 45))) 
-(((-67 |#1|) (-13 (-397) (-10 -7 (-15 -4128 ((-1249))))) (-1161)) (T -67)) 
-((-4128 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-67 *3)) (-14 *3 (-1161))))) 
-(-13 (-397) (-10 -7 (-15 -4128 ((-1249))))) 
-((-3666 (((-3 $ "failed") (-1244 (-310 (-381)))) 142) (((-3 $ "failed") (-1244 (-310 (-568)))) 132) (((-3 $ "failed") (-1244 (-953 (-381)))) 163) (((-3 $ "failed") (-1244 (-953 (-568)))) 152) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 121) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 110)) (-2854 (($ (-1244 (-310 (-381)))) 138) (($ (-1244 (-310 (-568)))) 128) (($ (-1244 (-953 (-381)))) 159) (($ (-1244 (-953 (-568)))) 148) (($ (-1244 (-409 (-953 (-381))))) 117) (($ (-1244 (-409 (-953 (-568))))) 103)) (-4128 (((-1249) $) 96)) (-2745 (((-850) $) 90) (($ (-634 (-328))) 28) (($ (-328)) 34) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 31) (($ (-1244 (-337 (-4287) (-4287 (QUOTE XC)) (-688)))) 88))) 
-(((-68 |#1|) (-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287) (-4287 (QUOTE XC)) (-688))))))) (-1161)) (T -68)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287) (-4287 (QUOTE XC)) (-688)))) (-5 *1 (-68 *3)) (-14 *3 (-1161))))) 
-(-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287) (-4287 (QUOTE XC)) (-688))))))) 
-((-3666 (((-3 $ "failed") (-310 (-381))) 36) (((-3 $ "failed") (-310 (-568))) 41) (((-3 $ "failed") (-953 (-381))) 46) (((-3 $ "failed") (-953 (-568))) 51) (((-3 $ "failed") (-409 (-953 (-381)))) 31) (((-3 $ "failed") (-409 (-953 (-568)))) 26)) (-2854 (($ (-310 (-381))) 34) (($ (-310 (-568))) 39) (($ (-953 (-381))) 44) (($ (-953 (-568))) 49) (($ (-409 (-953 (-381)))) 29) (($ (-409 (-953 (-568)))) 23)) (-4128 (((-1249) $) 73)) (-2745 (((-850) $) 66) (($ (-634 (-328))) 57) (($ (-328)) 63) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 60) (($ (-337 (-4287 (QUOTE X)) (-4287) (-688))) 22))) 
-(((-69 |#1|) (-13 (-398) (-10 -8 (-15 -2745 ($ (-337 (-4287 (QUOTE X)) (-4287) (-688)))))) (-1161)) (T -69)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-337 (-4287 (QUOTE X)) (-4287) (-688))) (-5 *1 (-69 *3)) (-14 *3 (-1161))))) 
-(-13 (-398) (-10 -8 (-15 -2745 ($ (-337 (-4287 (QUOTE X)) (-4287) (-688)))))) 
-((-3666 (((-3 $ "failed") (-679 (-310 (-381)))) 100) (((-3 $ "failed") (-679 (-310 (-568)))) 89) (((-3 $ "failed") (-679 (-953 (-381)))) 122) (((-3 $ "failed") (-679 (-953 (-568)))) 111) (((-3 $ "failed") (-679 (-409 (-953 (-381))))) 78) (((-3 $ "failed") (-679 (-409 (-953 (-568))))) 67)) (-2854 (($ (-679 (-310 (-381)))) 96) (($ (-679 (-310 (-568)))) 85) (($ (-679 (-953 (-381)))) 118) (($ (-679 (-953 (-568)))) 107) (($ (-679 (-409 (-953 (-381))))) 74) (($ (-679 (-409 (-953 (-568))))) 60)) (-4128 (((-1249) $) 130)) (-2745 (((-850) $) 124) (($ (-634 (-328))) 27) (($ (-328)) 33) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 30) (($ (-679 (-337 (-4287) (-4287 (QUOTE X) (QUOTE HESS)) (-688)))) 53))) 
-(((-70 |#1|) (-13 (-386) (-10 -8 (-15 -2745 ($ (-679 (-337 (-4287) (-4287 (QUOTE X) (QUOTE HESS)) (-688))))))) (-1161)) (T -70)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-679 (-337 (-4287) (-4287 (QUOTE X) (QUOTE HESS)) (-688)))) (-5 *1 (-70 *3)) (-14 *3 (-1161))))) 
-(-13 (-386) (-10 -8 (-15 -2745 ($ (-679 (-337 (-4287) (-4287 (QUOTE X) (QUOTE HESS)) (-688))))))) 
-((-3666 (((-3 $ "failed") (-310 (-381))) 54) (((-3 $ "failed") (-310 (-568))) 59) (((-3 $ "failed") (-953 (-381))) 64) (((-3 $ "failed") (-953 (-568))) 69) (((-3 $ "failed") (-409 (-953 (-381)))) 49) (((-3 $ "failed") (-409 (-953 (-568)))) 44)) (-2854 (($ (-310 (-381))) 52) (($ (-310 (-568))) 57) (($ (-953 (-381))) 62) (($ (-953 (-568))) 67) (($ (-409 (-953 (-381)))) 47) (($ (-409 (-953 (-568)))) 41)) (-4128 (((-1249) $) 78)) (-2745 (((-850) $) 72) (($ (-634 (-328))) 27) (($ (-328)) 33) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 30) (($ (-337 (-4287) (-4287 (QUOTE XC)) (-688))) 38))) 
-(((-71 |#1|) (-13 (-398) (-10 -8 (-15 -2745 ($ (-337 (-4287) (-4287 (QUOTE XC)) (-688)))))) (-1161)) (T -71)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-337 (-4287) (-4287 (QUOTE XC)) (-688))) (-5 *1 (-71 *3)) (-14 *3 (-1161))))) 
-(-13 (-398) (-10 -8 (-15 -2745 ($ (-337 (-4287) (-4287 (QUOTE XC)) (-688)))))) 
-((-4128 (((-1249) $) 63)) (-2745 (((-850) $) 57) (($ (-679 (-688))) 49) (($ (-634 (-328))) 48) (($ (-328)) 55) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 53))) 
+((-1678 (((-64 |#2|) (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|) 16)) (-3094 ((|#2| (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|) 18)) (-2797 (((-64 |#2|) (-1 |#2| |#1|) (-64 |#1|)) 13))) 
+(((-63 |#1| |#2|) (-10 -7 (-15 -1678 ((-64 |#2|) (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|)) (-15 -3094 (|#2| (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|)) (-15 -2797 ((-64 |#2|) (-1 |#2| |#1|) (-64 |#1|)))) (-1195) (-1195)) (T -63)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-64 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-64 *6)) (-5 *1 (-63 *5 *6)))) (-3094 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-64 *5)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-63 *5 *2)))) (-1678 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-64 *6)) (-4 *6 (-1195)) (-4 *5 (-1195)) (-5 *2 (-64 *5)) (-5 *1 (-63 *6 *5))))) 
+(-10 -7 (-15 -1678 ((-64 |#2|) (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|)) (-15 -3094 (|#2| (-1 |#2| |#1| |#2|) (-64 |#1|) |#2|)) (-15 -2797 ((-64 |#2|) (-1 |#2| |#1|) (-64 |#1|)))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-1324 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-842)))) (-2109 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4522))) (($ $) NIL (-12 (|has| $ (-6 -4522)) (|has| |#1| (-842))))) (-3647 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-842)))) (-1667 (((-121) $ (-763)) NIL)) (-2438 ((|#1| $ (-568) |#1|) 11 (|has| $ (-6 -4522))) ((|#1| $ (-1210 (-568)) |#1|) NIL (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-4490 (($) NIL T CONST)) (-4452 (($ $) NIL (|has| $ (-6 -4522)))) (-3945 (($ $) NIL)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-4330 (($ |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4521)))) (-1292 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-568)) NIL)) (-2766 (((-568) (-1 (-121) |#1|) $) NIL) (((-568) |#1| $) NIL (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) NIL (|has| |#1| (-1090)))) (-3317 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2261 (($ (-634 |#1|)) 13) (($ (-763) |#1|) 14)) (-1851 (($ (-763) |#1|) 9)) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) NIL (|has| (-568) (-842)))) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-3645 (($ (-1 (-121) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-842)))) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3631 (((-568) $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-2253 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4124 (($ |#1| $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3877 ((|#1| $) NIL (|has| (-568) (-842)))) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-2490 (($ $ |#1|) NIL (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) 7)) (-2781 ((|#1| $ (-568) |#1|) NIL) ((|#1| $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-2828 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3306 (($ $ $ (-568)) NIL (|has| $ (-6 -4522)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) NIL)) (-2770 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-634 $)) NIL)) (-2747 (((-850) $) NIL (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-64 |#1|) (-13 (-19 |#1|) (-10 -8 (-15 -2261 ($ (-634 |#1|))) (-15 -2261 ($ (-763) |#1|)))) (-1195)) (T -64)) 
+((-2261 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-64 *3)))) (-2261 (*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *1 (-64 *3)) (-4 *3 (-1195))))) 
+(-13 (-19 |#1|) (-10 -8 (-15 -2261 ($ (-634 |#1|))) (-15 -2261 ($ (-763) |#1|)))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1667 (((-121) $ (-763)) NIL)) (-2438 ((|#1| $ (-568) (-568) |#1|) NIL)) (-3874 (($ $ (-568) (-64 |#1|)) NIL)) (-2525 (($ $ (-568) (-64 |#1|)) NIL)) (-4490 (($) NIL T CONST)) (-2228 (((-64 |#1|) $ (-568)) NIL)) (-1292 ((|#1| $ (-568) (-568) |#1|) NIL)) (-2069 ((|#1| $ (-568) (-568)) NIL)) (-3317 (((-634 |#1|) $) NIL)) (-2241 (((-763) $) NIL)) (-1851 (($ (-763) (-763) |#1|) NIL)) (-1901 (((-763) $) NIL)) (-3791 (((-121) $ (-763)) NIL)) (-3139 (((-568) $) NIL)) (-1343 (((-568) $) NIL)) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3405 (((-568) $) NIL)) (-2801 (((-568) $) NIL)) (-2253 (($ (-1 |#1| |#1|) $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-2490 (($ $ |#1|) NIL)) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#1| $ (-568) (-568)) NIL) ((|#1| $ (-568) (-568) |#1|) NIL)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) NIL)) (-2522 (((-64 |#1|) $ (-568)) NIL)) (-2747 (((-850) $) NIL (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-65 |#1|) (-13 (-62 |#1| (-64 |#1|) (-64 |#1|)) (-10 -7 (-6 -4522))) (-1195)) (T -65)) 
+NIL 
+(-13 (-62 |#1| (-64 |#1|) (-64 |#1|)) (-10 -7 (-6 -4522))) 
+((-3668 (((-3 $ "failed") (-1244 (-310 (-381)))) 69) (((-3 $ "failed") (-1244 (-310 (-568)))) 58) (((-3 $ "failed") (-1244 (-953 (-381)))) 91) (((-3 $ "failed") (-1244 (-953 (-568)))) 80) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 47) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 36)) (-2857 (($ (-1244 (-310 (-381)))) 65) (($ (-1244 (-310 (-568)))) 54) (($ (-1244 (-953 (-381)))) 87) (($ (-1244 (-953 (-568)))) 76) (($ (-1244 (-409 (-953 (-381))))) 43) (($ (-1244 (-409 (-953 (-568))))) 29)) (-4130 (((-1249) $) 118)) (-2747 (((-850) $) 111) (($ (-634 (-328))) 100) (($ (-328)) 94) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 97) (($ (-1244 (-337 (-4289 (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (-4289) (-688)))) 28))) 
+(((-66 |#1|) (-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289 (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (-4289) (-688))))))) (-1161)) (T -66)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289 (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (-4289) (-688)))) (-5 *1 (-66 *3)) (-14 *3 (-1161))))) 
+(-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289 (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (-4289) (-688))))))) 
+((-4130 (((-1249) $) 48) (((-1249)) 49)) (-2747 (((-850) $) 45))) 
+(((-67 |#1|) (-13 (-397) (-10 -7 (-15 -4130 ((-1249))))) (-1161)) (T -67)) 
+((-4130 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-67 *3)) (-14 *3 (-1161))))) 
+(-13 (-397) (-10 -7 (-15 -4130 ((-1249))))) 
+((-3668 (((-3 $ "failed") (-1244 (-310 (-381)))) 142) (((-3 $ "failed") (-1244 (-310 (-568)))) 132) (((-3 $ "failed") (-1244 (-953 (-381)))) 163) (((-3 $ "failed") (-1244 (-953 (-568)))) 152) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 121) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 110)) (-2857 (($ (-1244 (-310 (-381)))) 138) (($ (-1244 (-310 (-568)))) 128) (($ (-1244 (-953 (-381)))) 159) (($ (-1244 (-953 (-568)))) 148) (($ (-1244 (-409 (-953 (-381))))) 117) (($ (-1244 (-409 (-953 (-568))))) 103)) (-4130 (((-1249) $) 96)) (-2747 (((-850) $) 90) (($ (-634 (-328))) 28) (($ (-328)) 34) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 31) (($ (-1244 (-337 (-4289) (-4289 (QUOTE XC)) (-688)))) 88))) 
+(((-68 |#1|) (-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289) (-4289 (QUOTE XC)) (-688))))))) (-1161)) (T -68)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289) (-4289 (QUOTE XC)) (-688)))) (-5 *1 (-68 *3)) (-14 *3 (-1161))))) 
+(-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289) (-4289 (QUOTE XC)) (-688))))))) 
+((-3668 (((-3 $ "failed") (-310 (-381))) 36) (((-3 $ "failed") (-310 (-568))) 41) (((-3 $ "failed") (-953 (-381))) 46) (((-3 $ "failed") (-953 (-568))) 51) (((-3 $ "failed") (-409 (-953 (-381)))) 31) (((-3 $ "failed") (-409 (-953 (-568)))) 26)) (-2857 (($ (-310 (-381))) 34) (($ (-310 (-568))) 39) (($ (-953 (-381))) 44) (($ (-953 (-568))) 49) (($ (-409 (-953 (-381)))) 29) (($ (-409 (-953 (-568)))) 23)) (-4130 (((-1249) $) 73)) (-2747 (((-850) $) 66) (($ (-634 (-328))) 57) (($ (-328)) 63) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 60) (($ (-337 (-4289 (QUOTE X)) (-4289) (-688))) 22))) 
+(((-69 |#1|) (-13 (-398) (-10 -8 (-15 -2747 ($ (-337 (-4289 (QUOTE X)) (-4289) (-688)))))) (-1161)) (T -69)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-337 (-4289 (QUOTE X)) (-4289) (-688))) (-5 *1 (-69 *3)) (-14 *3 (-1161))))) 
+(-13 (-398) (-10 -8 (-15 -2747 ($ (-337 (-4289 (QUOTE X)) (-4289) (-688)))))) 
+((-3668 (((-3 $ "failed") (-679 (-310 (-381)))) 100) (((-3 $ "failed") (-679 (-310 (-568)))) 89) (((-3 $ "failed") (-679 (-953 (-381)))) 122) (((-3 $ "failed") (-679 (-953 (-568)))) 111) (((-3 $ "failed") (-679 (-409 (-953 (-381))))) 78) (((-3 $ "failed") (-679 (-409 (-953 (-568))))) 67)) (-2857 (($ (-679 (-310 (-381)))) 96) (($ (-679 (-310 (-568)))) 85) (($ (-679 (-953 (-381)))) 118) (($ (-679 (-953 (-568)))) 107) (($ (-679 (-409 (-953 (-381))))) 74) (($ (-679 (-409 (-953 (-568))))) 60)) (-4130 (((-1249) $) 130)) (-2747 (((-850) $) 124) (($ (-634 (-328))) 27) (($ (-328)) 33) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 30) (($ (-679 (-337 (-4289) (-4289 (QUOTE X) (QUOTE HESS)) (-688)))) 53))) 
+(((-70 |#1|) (-13 (-386) (-10 -8 (-15 -2747 ($ (-679 (-337 (-4289) (-4289 (QUOTE X) (QUOTE HESS)) (-688))))))) (-1161)) (T -70)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-679 (-337 (-4289) (-4289 (QUOTE X) (QUOTE HESS)) (-688)))) (-5 *1 (-70 *3)) (-14 *3 (-1161))))) 
+(-13 (-386) (-10 -8 (-15 -2747 ($ (-679 (-337 (-4289) (-4289 (QUOTE X) (QUOTE HESS)) (-688))))))) 
+((-3668 (((-3 $ "failed") (-310 (-381))) 54) (((-3 $ "failed") (-310 (-568))) 59) (((-3 $ "failed") (-953 (-381))) 64) (((-3 $ "failed") (-953 (-568))) 69) (((-3 $ "failed") (-409 (-953 (-381)))) 49) (((-3 $ "failed") (-409 (-953 (-568)))) 44)) (-2857 (($ (-310 (-381))) 52) (($ (-310 (-568))) 57) (($ (-953 (-381))) 62) (($ (-953 (-568))) 67) (($ (-409 (-953 (-381)))) 47) (($ (-409 (-953 (-568)))) 41)) (-4130 (((-1249) $) 78)) (-2747 (((-850) $) 72) (($ (-634 (-328))) 27) (($ (-328)) 33) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 30) (($ (-337 (-4289) (-4289 (QUOTE XC)) (-688))) 38))) 
+(((-71 |#1|) (-13 (-398) (-10 -8 (-15 -2747 ($ (-337 (-4289) (-4289 (QUOTE XC)) (-688)))))) (-1161)) (T -71)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-337 (-4289) (-4289 (QUOTE XC)) (-688))) (-5 *1 (-71 *3)) (-14 *3 (-1161))))) 
+(-13 (-398) (-10 -8 (-15 -2747 ($ (-337 (-4289) (-4289 (QUOTE XC)) (-688)))))) 
+((-4130 (((-1249) $) 63)) (-2747 (((-850) $) 57) (($ (-679 (-688))) 49) (($ (-634 (-328))) 48) (($ (-328)) 55) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 53))) 
 (((-72 |#1|) (-385) (-1161)) (T -72)) 
 NIL 
 (-385) 
-((-4128 (((-1249) $) 64)) (-2745 (((-850) $) 58) (($ (-679 (-688))) 50) (($ (-634 (-328))) 49) (($ (-328)) 52) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 55))) 
+((-4130 (((-1249) $) 64)) (-2747 (((-850) $) 58) (($ (-679 (-688))) 50) (($ (-634 (-328))) 49) (($ (-328)) 52) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 55))) 
 (((-73 |#1|) (-385) (-1161)) (T -73)) 
 NIL 
 (-385) 
-((-4128 (((-1249) $) NIL) (((-1249)) 32)) (-2745 (((-850) $) NIL))) 
-(((-74 |#1|) (-13 (-397) (-10 -7 (-15 -4128 ((-1249))))) (-1161)) (T -74)) 
-((-4128 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-74 *3)) (-14 *3 (-1161))))) 
-(-13 (-397) (-10 -7 (-15 -4128 ((-1249))))) 
-((-4128 (((-1249) $) 68)) (-2745 (((-850) $) 62) (($ (-679 (-688))) 53) (($ (-634 (-328))) 56) (($ (-328)) 59) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 52))) 
+((-4130 (((-1249) $) NIL) (((-1249)) 32)) (-2747 (((-850) $) NIL))) 
+(((-74 |#1|) (-13 (-397) (-10 -7 (-15 -4130 ((-1249))))) (-1161)) (T -74)) 
+((-4130 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-74 *3)) (-14 *3 (-1161))))) 
+(-13 (-397) (-10 -7 (-15 -4130 ((-1249))))) 
+((-4130 (((-1249) $) 68)) (-2747 (((-850) $) 62) (($ (-679 (-688))) 53) (($ (-634 (-328))) 56) (($ (-328)) 59) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 52))) 
 (((-75 |#1|) (-385) (-1161)) (T -75)) 
 NIL 
 (-385) 
-((-3666 (((-3 $ "failed") (-1244 (-310 (-381)))) 98) (((-3 $ "failed") (-1244 (-310 (-568)))) 87) (((-3 $ "failed") (-1244 (-953 (-381)))) 119) (((-3 $ "failed") (-1244 (-953 (-568)))) 108) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 76) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 65)) (-2854 (($ (-1244 (-310 (-381)))) 94) (($ (-1244 (-310 (-568)))) 83) (($ (-1244 (-953 (-381)))) 115) (($ (-1244 (-953 (-568)))) 104) (($ (-1244 (-409 (-953 (-381))))) 72) (($ (-1244 (-409 (-953 (-568))))) 58)) (-4128 (((-1249) $) 133)) (-2745 (((-850) $) 127) (($ (-634 (-328))) 122) (($ (-328)) 125) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 50) (($ (-1244 (-337 (-4287 (QUOTE X)) (-4287 (QUOTE -2926)) (-688)))) 51))) 
-(((-76 |#1|) (-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287 (QUOTE X)) (-4287 (QUOTE -2926)) (-688))))))) (-1161)) (T -76)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287 (QUOTE X)) (-4287 (QUOTE -2926)) (-688)))) (-5 *1 (-76 *3)) (-14 *3 (-1161))))) 
-(-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287 (QUOTE X)) (-4287 (QUOTE -2926)) (-688))))))) 
-((-4128 (((-1249) $) 32) (((-1249)) 31)) (-2745 (((-850) $) 35))) 
-(((-77 |#1|) (-13 (-397) (-10 -7 (-15 -4128 ((-1249))))) (-1161)) (T -77)) 
-((-4128 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-77 *3)) (-14 *3 (-1161))))) 
-(-13 (-397) (-10 -7 (-15 -4128 ((-1249))))) 
-((-4128 (((-1249) $) 62)) (-2745 (((-850) $) 56) (($ (-679 (-688))) 47) (($ (-634 (-328))) 50) (($ (-328)) 53) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 46))) 
+((-3668 (((-3 $ "failed") (-1244 (-310 (-381)))) 98) (((-3 $ "failed") (-1244 (-310 (-568)))) 87) (((-3 $ "failed") (-1244 (-953 (-381)))) 119) (((-3 $ "failed") (-1244 (-953 (-568)))) 108) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 76) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 65)) (-2857 (($ (-1244 (-310 (-381)))) 94) (($ (-1244 (-310 (-568)))) 83) (($ (-1244 (-953 (-381)))) 115) (($ (-1244 (-953 (-568)))) 104) (($ (-1244 (-409 (-953 (-381))))) 72) (($ (-1244 (-409 (-953 (-568))))) 58)) (-4130 (((-1249) $) 133)) (-2747 (((-850) $) 127) (($ (-634 (-328))) 122) (($ (-328)) 125) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 50) (($ (-1244 (-337 (-4289 (QUOTE X)) (-4289 (QUOTE -2928)) (-688)))) 51))) 
+(((-76 |#1|) (-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289 (QUOTE X)) (-4289 (QUOTE -2928)) (-688))))))) (-1161)) (T -76)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289 (QUOTE X)) (-4289 (QUOTE -2928)) (-688)))) (-5 *1 (-76 *3)) (-14 *3 (-1161))))) 
+(-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289 (QUOTE X)) (-4289 (QUOTE -2928)) (-688))))))) 
+((-4130 (((-1249) $) 32) (((-1249)) 31)) (-2747 (((-850) $) 35))) 
+(((-77 |#1|) (-13 (-397) (-10 -7 (-15 -4130 ((-1249))))) (-1161)) (T -77)) 
+((-4130 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-77 *3)) (-14 *3 (-1161))))) 
+(-13 (-397) (-10 -7 (-15 -4130 ((-1249))))) 
+((-4130 (((-1249) $) 62)) (-2747 (((-850) $) 56) (($ (-679 (-688))) 47) (($ (-634 (-328))) 50) (($ (-328)) 53) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 46))) 
 (((-78 |#1|) (-385) (-1161)) (T -78)) 
 NIL 
 (-385) 
-((-3666 (((-3 $ "failed") (-1244 (-310 (-381)))) 119) (((-3 $ "failed") (-1244 (-310 (-568)))) 108) (((-3 $ "failed") (-1244 (-953 (-381)))) 141) (((-3 $ "failed") (-1244 (-953 (-568)))) 130) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 98) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 87)) (-2854 (($ (-1244 (-310 (-381)))) 115) (($ (-1244 (-310 (-568)))) 104) (($ (-1244 (-953 (-381)))) 137) (($ (-1244 (-953 (-568)))) 126) (($ (-1244 (-409 (-953 (-381))))) 94) (($ (-1244 (-409 (-953 (-568))))) 80)) (-4128 (((-1249) $) 73)) (-2745 (((-850) $) 27) (($ (-634 (-328))) 63) (($ (-328)) 59) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 66) (($ (-1244 (-337 (-4287) (-4287 (QUOTE X)) (-688)))) 60))) 
-(((-79 |#1|) (-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287) (-4287 (QUOTE X)) (-688))))))) (-1161)) (T -79)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287) (-4287 (QUOTE X)) (-688)))) (-5 *1 (-79 *3)) (-14 *3 (-1161))))) 
-(-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287) (-4287 (QUOTE X)) (-688))))))) 
-((-3666 (((-3 $ "failed") (-1244 (-310 (-381)))) 125) (((-3 $ "failed") (-1244 (-310 (-568)))) 114) (((-3 $ "failed") (-1244 (-953 (-381)))) 147) (((-3 $ "failed") (-1244 (-953 (-568)))) 136) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 103) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 92)) (-2854 (($ (-1244 (-310 (-381)))) 121) (($ (-1244 (-310 (-568)))) 110) (($ (-1244 (-953 (-381)))) 143) (($ (-1244 (-953 (-568)))) 132) (($ (-1244 (-409 (-953 (-381))))) 99) (($ (-1244 (-409 (-953 (-568))))) 85)) (-4128 (((-1249) $) 78)) (-2745 (((-850) $) 70) (($ (-634 (-328))) NIL) (($ (-328)) NIL) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) NIL) (($ (-1244 (-337 (-4287 (QUOTE X) (QUOTE EPS)) (-4287 (QUOTE -2926)) (-688)))) 65))) 
-(((-80 |#1| |#2| |#3|) (-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287 (QUOTE X) (QUOTE EPS)) (-4287 (QUOTE -2926)) (-688))))))) (-1161) (-1161) (-1161)) (T -80)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287 (QUOTE X) (QUOTE EPS)) (-4287 (QUOTE -2926)) (-688)))) (-5 *1 (-80 *3 *4 *5)) (-14 *3 (-1161)) (-14 *4 (-1161)) (-14 *5 (-1161))))) 
-(-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287 (QUOTE X) (QUOTE EPS)) (-4287 (QUOTE -2926)) (-688))))))) 
-((-3666 (((-3 $ "failed") (-1244 (-310 (-381)))) 129) (((-3 $ "failed") (-1244 (-310 (-568)))) 118) (((-3 $ "failed") (-1244 (-953 (-381)))) 151) (((-3 $ "failed") (-1244 (-953 (-568)))) 140) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 107) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 96)) (-2854 (($ (-1244 (-310 (-381)))) 125) (($ (-1244 (-310 (-568)))) 114) (($ (-1244 (-953 (-381)))) 147) (($ (-1244 (-953 (-568)))) 136) (($ (-1244 (-409 (-953 (-381))))) 103) (($ (-1244 (-409 (-953 (-568))))) 89)) (-4128 (((-1249) $) 82)) (-2745 (((-850) $) 74) (($ (-634 (-328))) NIL) (($ (-328)) NIL) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) NIL) (($ (-1244 (-337 (-4287 (QUOTE EPS)) (-4287 (QUOTE YA) (QUOTE YB)) (-688)))) 69))) 
-(((-81 |#1| |#2| |#3|) (-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287 (QUOTE EPS)) (-4287 (QUOTE YA) (QUOTE YB)) (-688))))))) (-1161) (-1161) (-1161)) (T -81)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287 (QUOTE EPS)) (-4287 (QUOTE YA) (QUOTE YB)) (-688)))) (-5 *1 (-81 *3 *4 *5)) (-14 *3 (-1161)) (-14 *4 (-1161)) (-14 *5 (-1161))))) 
-(-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287 (QUOTE EPS)) (-4287 (QUOTE YA) (QUOTE YB)) (-688))))))) 
-((-3666 (((-3 $ "failed") (-310 (-381))) 77) (((-3 $ "failed") (-310 (-568))) 82) (((-3 $ "failed") (-953 (-381))) 87) (((-3 $ "failed") (-953 (-568))) 92) (((-3 $ "failed") (-409 (-953 (-381)))) 72) (((-3 $ "failed") (-409 (-953 (-568)))) 67)) (-2854 (($ (-310 (-381))) 75) (($ (-310 (-568))) 80) (($ (-953 (-381))) 85) (($ (-953 (-568))) 90) (($ (-409 (-953 (-381)))) 70) (($ (-409 (-953 (-568)))) 64)) (-4128 (((-1249) $) 61)) (-2745 (((-850) $) 49) (($ (-634 (-328))) 45) (($ (-328)) 55) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 53) (($ (-337 (-4287) (-4287 (QUOTE X)) (-688))) 46))) 
-(((-82 |#1|) (-13 (-398) (-10 -8 (-15 -2745 ($ (-337 (-4287) (-4287 (QUOTE X)) (-688)))))) (-1161)) (T -82)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-337 (-4287) (-4287 (QUOTE X)) (-688))) (-5 *1 (-82 *3)) (-14 *3 (-1161))))) 
-(-13 (-398) (-10 -8 (-15 -2745 ($ (-337 (-4287) (-4287 (QUOTE X)) (-688)))))) 
-((-3666 (((-3 $ "failed") (-310 (-381))) 41) (((-3 $ "failed") (-310 (-568))) 46) (((-3 $ "failed") (-953 (-381))) 51) (((-3 $ "failed") (-953 (-568))) 56) (((-3 $ "failed") (-409 (-953 (-381)))) 36) (((-3 $ "failed") (-409 (-953 (-568)))) 31)) (-2854 (($ (-310 (-381))) 39) (($ (-310 (-568))) 44) (($ (-953 (-381))) 49) (($ (-953 (-568))) 54) (($ (-409 (-953 (-381)))) 34) (($ (-409 (-953 (-568)))) 28)) (-4128 (((-1249) $) 77)) (-2745 (((-850) $) 71) (($ (-634 (-328))) 62) (($ (-328)) 68) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 65) (($ (-337 (-4287) (-4287 (QUOTE X)) (-688))) 27))) 
-(((-83 |#1|) (-13 (-398) (-10 -8 (-15 -2745 ($ (-337 (-4287) (-4287 (QUOTE X)) (-688)))))) (-1161)) (T -83)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-337 (-4287) (-4287 (QUOTE X)) (-688))) (-5 *1 (-83 *3)) (-14 *3 (-1161))))) 
-(-13 (-398) (-10 -8 (-15 -2745 ($ (-337 (-4287) (-4287 (QUOTE X)) (-688)))))) 
-((-3666 (((-3 $ "failed") (-1244 (-310 (-381)))) 84) (((-3 $ "failed") (-1244 (-310 (-568)))) 73) (((-3 $ "failed") (-1244 (-953 (-381)))) 106) (((-3 $ "failed") (-1244 (-953 (-568)))) 95) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 62) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 51)) (-2854 (($ (-1244 (-310 (-381)))) 80) (($ (-1244 (-310 (-568)))) 69) (($ (-1244 (-953 (-381)))) 102) (($ (-1244 (-953 (-568)))) 91) (($ (-1244 (-409 (-953 (-381))))) 58) (($ (-1244 (-409 (-953 (-568))))) 44)) (-4128 (((-1249) $) 122)) (-2745 (((-850) $) 116) (($ (-634 (-328))) 109) (($ (-328)) 36) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 112) (($ (-1244 (-337 (-4287) (-4287 (QUOTE XC)) (-688)))) 37))) 
-(((-84 |#1|) (-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287) (-4287 (QUOTE XC)) (-688))))))) (-1161)) (T -84)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287) (-4287 (QUOTE XC)) (-688)))) (-5 *1 (-84 *3)) (-14 *3 (-1161))))) 
-(-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287) (-4287 (QUOTE XC)) (-688))))))) 
-((-3666 (((-3 $ "failed") (-1244 (-310 (-381)))) 137) (((-3 $ "failed") (-1244 (-310 (-568)))) 126) (((-3 $ "failed") (-1244 (-953 (-381)))) 158) (((-3 $ "failed") (-1244 (-953 (-568)))) 147) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 116) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 105)) (-2854 (($ (-1244 (-310 (-381)))) 133) (($ (-1244 (-310 (-568)))) 122) (($ (-1244 (-953 (-381)))) 154) (($ (-1244 (-953 (-568)))) 143) (($ (-1244 (-409 (-953 (-381))))) 112) (($ (-1244 (-409 (-953 (-568))))) 98)) (-4128 (((-1249) $) 91)) (-2745 (((-850) $) 85) (($ (-634 (-328))) 76) (($ (-328)) 83) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 81) (($ (-1244 (-337 (-4287) (-4287 (QUOTE X)) (-688)))) 77))) 
-(((-85 |#1|) (-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287) (-4287 (QUOTE X)) (-688))))))) (-1161)) (T -85)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287) (-4287 (QUOTE X)) (-688)))) (-5 *1 (-85 *3)) (-14 *3 (-1161))))) 
-(-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287) (-4287 (QUOTE X)) (-688))))))) 
-((-3666 (((-3 $ "failed") (-1244 (-310 (-381)))) 73) (((-3 $ "failed") (-1244 (-310 (-568)))) 62) (((-3 $ "failed") (-1244 (-953 (-381)))) 95) (((-3 $ "failed") (-1244 (-953 (-568)))) 84) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 51) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 40)) (-2854 (($ (-1244 (-310 (-381)))) 69) (($ (-1244 (-310 (-568)))) 58) (($ (-1244 (-953 (-381)))) 91) (($ (-1244 (-953 (-568)))) 80) (($ (-1244 (-409 (-953 (-381))))) 47) (($ (-1244 (-409 (-953 (-568))))) 33)) (-4128 (((-1249) $) 121)) (-2745 (((-850) $) 115) (($ (-634 (-328))) 106) (($ (-328)) 112) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 110) (($ (-1244 (-337 (-4287) (-4287 (QUOTE X)) (-688)))) 32))) 
-(((-86 |#1|) (-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287) (-4287 (QUOTE X)) (-688))))))) (-1161)) (T -86)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287) (-4287 (QUOTE X)) (-688)))) (-5 *1 (-86 *3)) (-14 *3 (-1161))))) 
-(-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287) (-4287 (QUOTE X)) (-688))))))) 
-((-3666 (((-3 $ "failed") (-1244 (-310 (-381)))) 90) (((-3 $ "failed") (-1244 (-310 (-568)))) 79) (((-3 $ "failed") (-1244 (-953 (-381)))) 112) (((-3 $ "failed") (-1244 (-953 (-568)))) 101) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 68) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 57)) (-2854 (($ (-1244 (-310 (-381)))) 86) (($ (-1244 (-310 (-568)))) 75) (($ (-1244 (-953 (-381)))) 108) (($ (-1244 (-953 (-568)))) 97) (($ (-1244 (-409 (-953 (-381))))) 64) (($ (-1244 (-409 (-953 (-568))))) 50)) (-4128 (((-1249) $) 43)) (-2745 (((-850) $) 36) (($ (-634 (-328))) 26) (($ (-328)) 29) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 32) (($ (-1244 (-337 (-4287 (QUOTE X) (QUOTE -2926)) (-4287) (-688)))) 27))) 
-(((-87 |#1|) (-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287 (QUOTE X) (QUOTE -2926)) (-4287) (-688))))))) (-1161)) (T -87)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287 (QUOTE X) (QUOTE -2926)) (-4287) (-688)))) (-5 *1 (-87 *3)) (-14 *3 (-1161))))) 
-(-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287 (QUOTE X) (QUOTE -2926)) (-4287) (-688))))))) 
-((-3666 (((-3 $ "failed") (-679 (-310 (-381)))) 103) (((-3 $ "failed") (-679 (-310 (-568)))) 92) (((-3 $ "failed") (-679 (-953 (-381)))) 125) (((-3 $ "failed") (-679 (-953 (-568)))) 114) (((-3 $ "failed") (-679 (-409 (-953 (-381))))) 82) (((-3 $ "failed") (-679 (-409 (-953 (-568))))) 71)) (-2854 (($ (-679 (-310 (-381)))) 99) (($ (-679 (-310 (-568)))) 88) (($ (-679 (-953 (-381)))) 121) (($ (-679 (-953 (-568)))) 110) (($ (-679 (-409 (-953 (-381))))) 78) (($ (-679 (-409 (-953 (-568))))) 64)) (-4128 (((-1249) $) 57)) (-2745 (((-850) $) 43) (($ (-634 (-328))) 50) (($ (-328)) 39) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 47) (($ (-679 (-337 (-4287 (QUOTE X) (QUOTE -2926)) (-4287) (-688)))) 40))) 
-(((-88 |#1|) (-13 (-386) (-10 -8 (-15 -2745 ($ (-679 (-337 (-4287 (QUOTE X) (QUOTE -2926)) (-4287) (-688))))))) (-1161)) (T -88)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-679 (-337 (-4287 (QUOTE X) (QUOTE -2926)) (-4287) (-688)))) (-5 *1 (-88 *3)) (-14 *3 (-1161))))) 
-(-13 (-386) (-10 -8 (-15 -2745 ($ (-679 (-337 (-4287 (QUOTE X) (QUOTE -2926)) (-4287) (-688))))))) 
-((-3666 (((-3 $ "failed") (-679 (-310 (-381)))) 103) (((-3 $ "failed") (-679 (-310 (-568)))) 92) (((-3 $ "failed") (-679 (-953 (-381)))) 124) (((-3 $ "failed") (-679 (-953 (-568)))) 113) (((-3 $ "failed") (-679 (-409 (-953 (-381))))) 81) (((-3 $ "failed") (-679 (-409 (-953 (-568))))) 70)) (-2854 (($ (-679 (-310 (-381)))) 99) (($ (-679 (-310 (-568)))) 88) (($ (-679 (-953 (-381)))) 120) (($ (-679 (-953 (-568)))) 109) (($ (-679 (-409 (-953 (-381))))) 77) (($ (-679 (-409 (-953 (-568))))) 63)) (-4128 (((-1249) $) 56)) (-2745 (((-850) $) 50) (($ (-634 (-328))) 44) (($ (-328)) 47) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 40) (($ (-679 (-337 (-4287 (QUOTE X)) (-4287) (-688)))) 41))) 
-(((-89 |#1|) (-13 (-386) (-10 -8 (-15 -2745 ($ (-679 (-337 (-4287 (QUOTE X)) (-4287) (-688))))))) (-1161)) (T -89)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-679 (-337 (-4287 (QUOTE X)) (-4287) (-688)))) (-5 *1 (-89 *3)) (-14 *3 (-1161))))) 
-(-13 (-386) (-10 -8 (-15 -2745 ($ (-679 (-337 (-4287 (QUOTE X)) (-4287) (-688))))))) 
-((-3666 (((-3 $ "failed") (-1244 (-310 (-381)))) 99) (((-3 $ "failed") (-1244 (-310 (-568)))) 88) (((-3 $ "failed") (-1244 (-953 (-381)))) 121) (((-3 $ "failed") (-1244 (-953 (-568)))) 110) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 77) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 66)) (-2854 (($ (-1244 (-310 (-381)))) 95) (($ (-1244 (-310 (-568)))) 84) (($ (-1244 (-953 (-381)))) 117) (($ (-1244 (-953 (-568)))) 106) (($ (-1244 (-409 (-953 (-381))))) 73) (($ (-1244 (-409 (-953 (-568))))) 59)) (-4128 (((-1249) $) 45)) (-2745 (((-850) $) 39) (($ (-634 (-328))) 48) (($ (-328)) 35) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 51) (($ (-1244 (-337 (-4287 (QUOTE X)) (-4287) (-688)))) 36))) 
-(((-90 |#1|) (-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287 (QUOTE X)) (-4287) (-688))))))) (-1161)) (T -90)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287 (QUOTE X)) (-4287) (-688)))) (-5 *1 (-90 *3)) (-14 *3 (-1161))))) 
-(-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287 (QUOTE X)) (-4287) (-688))))))) 
-((-3666 (((-3 $ "failed") (-1244 (-310 (-381)))) 74) (((-3 $ "failed") (-1244 (-310 (-568)))) 63) (((-3 $ "failed") (-1244 (-953 (-381)))) 96) (((-3 $ "failed") (-1244 (-953 (-568)))) 85) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 52) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 41)) (-2854 (($ (-1244 (-310 (-381)))) 70) (($ (-1244 (-310 (-568)))) 59) (($ (-1244 (-953 (-381)))) 92) (($ (-1244 (-953 (-568)))) 81) (($ (-1244 (-409 (-953 (-381))))) 48) (($ (-1244 (-409 (-953 (-568))))) 34)) (-4128 (((-1249) $) 122)) (-2745 (((-850) $) 116) (($ (-634 (-328))) 107) (($ (-328)) 113) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 111) (($ (-1244 (-337 (-4287 (QUOTE X)) (-4287 (QUOTE -2926)) (-688)))) 33))) 
-(((-91 |#1|) (-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287 (QUOTE X)) (-4287 (QUOTE -2926)) (-688))))))) (-1161)) (T -91)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287 (QUOTE X)) (-4287 (QUOTE -2926)) (-688)))) (-5 *1 (-91 *3)) (-14 *3 (-1161))))) 
-(-13 (-442) (-10 -8 (-15 -2745 ($ (-1244 (-337 (-4287 (QUOTE X)) (-4287 (QUOTE -2926)) (-688))))))) 
-((-3666 (((-3 $ "failed") (-679 (-310 (-381)))) 105) (((-3 $ "failed") (-679 (-310 (-568)))) 94) (((-3 $ "failed") (-679 (-953 (-381)))) 127) (((-3 $ "failed") (-679 (-953 (-568)))) 116) (((-3 $ "failed") (-679 (-409 (-953 (-381))))) 83) (((-3 $ "failed") (-679 (-409 (-953 (-568))))) 72)) (-2854 (($ (-679 (-310 (-381)))) 101) (($ (-679 (-310 (-568)))) 90) (($ (-679 (-953 (-381)))) 123) (($ (-679 (-953 (-568)))) 112) (($ (-679 (-409 (-953 (-381))))) 79) (($ (-679 (-409 (-953 (-568))))) 65)) (-4128 (((-1249) $) 58)) (-2745 (((-850) $) 52) (($ (-634 (-328))) 42) (($ (-328)) 49) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 47) (($ (-679 (-337 (-4287 (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (-4287) (-688)))) 43))) 
-(((-92 |#1|) (-13 (-386) (-10 -8 (-15 -2745 ($ (-679 (-337 (-4287 (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (-4287) (-688))))))) (-1161)) (T -92)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-679 (-337 (-4287 (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (-4287) (-688)))) (-5 *1 (-92 *3)) (-14 *3 (-1161))))) 
-(-13 (-386) (-10 -8 (-15 -2745 ($ (-679 (-337 (-4287 (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (-4287) (-688))))))) 
-((-4128 (((-1249) $) 44)) (-2745 (((-850) $) 38) (($ (-1244 (-688))) 88) (($ (-634 (-328))) 29) (($ (-328)) 35) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 32))) 
+((-3668 (((-3 $ "failed") (-1244 (-310 (-381)))) 119) (((-3 $ "failed") (-1244 (-310 (-568)))) 108) (((-3 $ "failed") (-1244 (-953 (-381)))) 141) (((-3 $ "failed") (-1244 (-953 (-568)))) 130) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 98) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 87)) (-2857 (($ (-1244 (-310 (-381)))) 115) (($ (-1244 (-310 (-568)))) 104) (($ (-1244 (-953 (-381)))) 137) (($ (-1244 (-953 (-568)))) 126) (($ (-1244 (-409 (-953 (-381))))) 94) (($ (-1244 (-409 (-953 (-568))))) 80)) (-4130 (((-1249) $) 73)) (-2747 (((-850) $) 27) (($ (-634 (-328))) 63) (($ (-328)) 59) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 66) (($ (-1244 (-337 (-4289) (-4289 (QUOTE X)) (-688)))) 60))) 
+(((-79 |#1|) (-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289) (-4289 (QUOTE X)) (-688))))))) (-1161)) (T -79)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289) (-4289 (QUOTE X)) (-688)))) (-5 *1 (-79 *3)) (-14 *3 (-1161))))) 
+(-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289) (-4289 (QUOTE X)) (-688))))))) 
+((-3668 (((-3 $ "failed") (-1244 (-310 (-381)))) 125) (((-3 $ "failed") (-1244 (-310 (-568)))) 114) (((-3 $ "failed") (-1244 (-953 (-381)))) 147) (((-3 $ "failed") (-1244 (-953 (-568)))) 136) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 103) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 92)) (-2857 (($ (-1244 (-310 (-381)))) 121) (($ (-1244 (-310 (-568)))) 110) (($ (-1244 (-953 (-381)))) 143) (($ (-1244 (-953 (-568)))) 132) (($ (-1244 (-409 (-953 (-381))))) 99) (($ (-1244 (-409 (-953 (-568))))) 85)) (-4130 (((-1249) $) 78)) (-2747 (((-850) $) 70) (($ (-634 (-328))) NIL) (($ (-328)) NIL) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) NIL) (($ (-1244 (-337 (-4289 (QUOTE X) (QUOTE EPS)) (-4289 (QUOTE -2928)) (-688)))) 65))) 
+(((-80 |#1| |#2| |#3|) (-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289 (QUOTE X) (QUOTE EPS)) (-4289 (QUOTE -2928)) (-688))))))) (-1161) (-1161) (-1161)) (T -80)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289 (QUOTE X) (QUOTE EPS)) (-4289 (QUOTE -2928)) (-688)))) (-5 *1 (-80 *3 *4 *5)) (-14 *3 (-1161)) (-14 *4 (-1161)) (-14 *5 (-1161))))) 
+(-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289 (QUOTE X) (QUOTE EPS)) (-4289 (QUOTE -2928)) (-688))))))) 
+((-3668 (((-3 $ "failed") (-1244 (-310 (-381)))) 129) (((-3 $ "failed") (-1244 (-310 (-568)))) 118) (((-3 $ "failed") (-1244 (-953 (-381)))) 151) (((-3 $ "failed") (-1244 (-953 (-568)))) 140) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 107) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 96)) (-2857 (($ (-1244 (-310 (-381)))) 125) (($ (-1244 (-310 (-568)))) 114) (($ (-1244 (-953 (-381)))) 147) (($ (-1244 (-953 (-568)))) 136) (($ (-1244 (-409 (-953 (-381))))) 103) (($ (-1244 (-409 (-953 (-568))))) 89)) (-4130 (((-1249) $) 82)) (-2747 (((-850) $) 74) (($ (-634 (-328))) NIL) (($ (-328)) NIL) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) NIL) (($ (-1244 (-337 (-4289 (QUOTE EPS)) (-4289 (QUOTE YA) (QUOTE YB)) (-688)))) 69))) 
+(((-81 |#1| |#2| |#3|) (-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289 (QUOTE EPS)) (-4289 (QUOTE YA) (QUOTE YB)) (-688))))))) (-1161) (-1161) (-1161)) (T -81)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289 (QUOTE EPS)) (-4289 (QUOTE YA) (QUOTE YB)) (-688)))) (-5 *1 (-81 *3 *4 *5)) (-14 *3 (-1161)) (-14 *4 (-1161)) (-14 *5 (-1161))))) 
+(-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289 (QUOTE EPS)) (-4289 (QUOTE YA) (QUOTE YB)) (-688))))))) 
+((-3668 (((-3 $ "failed") (-310 (-381))) 77) (((-3 $ "failed") (-310 (-568))) 82) (((-3 $ "failed") (-953 (-381))) 87) (((-3 $ "failed") (-953 (-568))) 92) (((-3 $ "failed") (-409 (-953 (-381)))) 72) (((-3 $ "failed") (-409 (-953 (-568)))) 67)) (-2857 (($ (-310 (-381))) 75) (($ (-310 (-568))) 80) (($ (-953 (-381))) 85) (($ (-953 (-568))) 90) (($ (-409 (-953 (-381)))) 70) (($ (-409 (-953 (-568)))) 64)) (-4130 (((-1249) $) 61)) (-2747 (((-850) $) 49) (($ (-634 (-328))) 45) (($ (-328)) 55) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 53) (($ (-337 (-4289) (-4289 (QUOTE X)) (-688))) 46))) 
+(((-82 |#1|) (-13 (-398) (-10 -8 (-15 -2747 ($ (-337 (-4289) (-4289 (QUOTE X)) (-688)))))) (-1161)) (T -82)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-337 (-4289) (-4289 (QUOTE X)) (-688))) (-5 *1 (-82 *3)) (-14 *3 (-1161))))) 
+(-13 (-398) (-10 -8 (-15 -2747 ($ (-337 (-4289) (-4289 (QUOTE X)) (-688)))))) 
+((-3668 (((-3 $ "failed") (-310 (-381))) 41) (((-3 $ "failed") (-310 (-568))) 46) (((-3 $ "failed") (-953 (-381))) 51) (((-3 $ "failed") (-953 (-568))) 56) (((-3 $ "failed") (-409 (-953 (-381)))) 36) (((-3 $ "failed") (-409 (-953 (-568)))) 31)) (-2857 (($ (-310 (-381))) 39) (($ (-310 (-568))) 44) (($ (-953 (-381))) 49) (($ (-953 (-568))) 54) (($ (-409 (-953 (-381)))) 34) (($ (-409 (-953 (-568)))) 28)) (-4130 (((-1249) $) 77)) (-2747 (((-850) $) 71) (($ (-634 (-328))) 62) (($ (-328)) 68) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 65) (($ (-337 (-4289) (-4289 (QUOTE X)) (-688))) 27))) 
+(((-83 |#1|) (-13 (-398) (-10 -8 (-15 -2747 ($ (-337 (-4289) (-4289 (QUOTE X)) (-688)))))) (-1161)) (T -83)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-337 (-4289) (-4289 (QUOTE X)) (-688))) (-5 *1 (-83 *3)) (-14 *3 (-1161))))) 
+(-13 (-398) (-10 -8 (-15 -2747 ($ (-337 (-4289) (-4289 (QUOTE X)) (-688)))))) 
+((-3668 (((-3 $ "failed") (-1244 (-310 (-381)))) 84) (((-3 $ "failed") (-1244 (-310 (-568)))) 73) (((-3 $ "failed") (-1244 (-953 (-381)))) 106) (((-3 $ "failed") (-1244 (-953 (-568)))) 95) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 62) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 51)) (-2857 (($ (-1244 (-310 (-381)))) 80) (($ (-1244 (-310 (-568)))) 69) (($ (-1244 (-953 (-381)))) 102) (($ (-1244 (-953 (-568)))) 91) (($ (-1244 (-409 (-953 (-381))))) 58) (($ (-1244 (-409 (-953 (-568))))) 44)) (-4130 (((-1249) $) 122)) (-2747 (((-850) $) 116) (($ (-634 (-328))) 109) (($ (-328)) 36) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 112) (($ (-1244 (-337 (-4289) (-4289 (QUOTE XC)) (-688)))) 37))) 
+(((-84 |#1|) (-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289) (-4289 (QUOTE XC)) (-688))))))) (-1161)) (T -84)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289) (-4289 (QUOTE XC)) (-688)))) (-5 *1 (-84 *3)) (-14 *3 (-1161))))) 
+(-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289) (-4289 (QUOTE XC)) (-688))))))) 
+((-3668 (((-3 $ "failed") (-1244 (-310 (-381)))) 137) (((-3 $ "failed") (-1244 (-310 (-568)))) 126) (((-3 $ "failed") (-1244 (-953 (-381)))) 158) (((-3 $ "failed") (-1244 (-953 (-568)))) 147) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 116) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 105)) (-2857 (($ (-1244 (-310 (-381)))) 133) (($ (-1244 (-310 (-568)))) 122) (($ (-1244 (-953 (-381)))) 154) (($ (-1244 (-953 (-568)))) 143) (($ (-1244 (-409 (-953 (-381))))) 112) (($ (-1244 (-409 (-953 (-568))))) 98)) (-4130 (((-1249) $) 91)) (-2747 (((-850) $) 85) (($ (-634 (-328))) 76) (($ (-328)) 83) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 81) (($ (-1244 (-337 (-4289) (-4289 (QUOTE X)) (-688)))) 77))) 
+(((-85 |#1|) (-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289) (-4289 (QUOTE X)) (-688))))))) (-1161)) (T -85)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289) (-4289 (QUOTE X)) (-688)))) (-5 *1 (-85 *3)) (-14 *3 (-1161))))) 
+(-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289) (-4289 (QUOTE X)) (-688))))))) 
+((-3668 (((-3 $ "failed") (-1244 (-310 (-381)))) 73) (((-3 $ "failed") (-1244 (-310 (-568)))) 62) (((-3 $ "failed") (-1244 (-953 (-381)))) 95) (((-3 $ "failed") (-1244 (-953 (-568)))) 84) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 51) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 40)) (-2857 (($ (-1244 (-310 (-381)))) 69) (($ (-1244 (-310 (-568)))) 58) (($ (-1244 (-953 (-381)))) 91) (($ (-1244 (-953 (-568)))) 80) (($ (-1244 (-409 (-953 (-381))))) 47) (($ (-1244 (-409 (-953 (-568))))) 33)) (-4130 (((-1249) $) 121)) (-2747 (((-850) $) 115) (($ (-634 (-328))) 106) (($ (-328)) 112) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 110) (($ (-1244 (-337 (-4289) (-4289 (QUOTE X)) (-688)))) 32))) 
+(((-86 |#1|) (-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289) (-4289 (QUOTE X)) (-688))))))) (-1161)) (T -86)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289) (-4289 (QUOTE X)) (-688)))) (-5 *1 (-86 *3)) (-14 *3 (-1161))))) 
+(-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289) (-4289 (QUOTE X)) (-688))))))) 
+((-3668 (((-3 $ "failed") (-1244 (-310 (-381)))) 90) (((-3 $ "failed") (-1244 (-310 (-568)))) 79) (((-3 $ "failed") (-1244 (-953 (-381)))) 112) (((-3 $ "failed") (-1244 (-953 (-568)))) 101) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 68) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 57)) (-2857 (($ (-1244 (-310 (-381)))) 86) (($ (-1244 (-310 (-568)))) 75) (($ (-1244 (-953 (-381)))) 108) (($ (-1244 (-953 (-568)))) 97) (($ (-1244 (-409 (-953 (-381))))) 64) (($ (-1244 (-409 (-953 (-568))))) 50)) (-4130 (((-1249) $) 43)) (-2747 (((-850) $) 36) (($ (-634 (-328))) 26) (($ (-328)) 29) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 32) (($ (-1244 (-337 (-4289 (QUOTE X) (QUOTE -2928)) (-4289) (-688)))) 27))) 
+(((-87 |#1|) (-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289 (QUOTE X) (QUOTE -2928)) (-4289) (-688))))))) (-1161)) (T -87)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289 (QUOTE X) (QUOTE -2928)) (-4289) (-688)))) (-5 *1 (-87 *3)) (-14 *3 (-1161))))) 
+(-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289 (QUOTE X) (QUOTE -2928)) (-4289) (-688))))))) 
+((-3668 (((-3 $ "failed") (-679 (-310 (-381)))) 103) (((-3 $ "failed") (-679 (-310 (-568)))) 92) (((-3 $ "failed") (-679 (-953 (-381)))) 125) (((-3 $ "failed") (-679 (-953 (-568)))) 114) (((-3 $ "failed") (-679 (-409 (-953 (-381))))) 82) (((-3 $ "failed") (-679 (-409 (-953 (-568))))) 71)) (-2857 (($ (-679 (-310 (-381)))) 99) (($ (-679 (-310 (-568)))) 88) (($ (-679 (-953 (-381)))) 121) (($ (-679 (-953 (-568)))) 110) (($ (-679 (-409 (-953 (-381))))) 78) (($ (-679 (-409 (-953 (-568))))) 64)) (-4130 (((-1249) $) 57)) (-2747 (((-850) $) 43) (($ (-634 (-328))) 50) (($ (-328)) 39) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 47) (($ (-679 (-337 (-4289 (QUOTE X) (QUOTE -2928)) (-4289) (-688)))) 40))) 
+(((-88 |#1|) (-13 (-386) (-10 -8 (-15 -2747 ($ (-679 (-337 (-4289 (QUOTE X) (QUOTE -2928)) (-4289) (-688))))))) (-1161)) (T -88)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-679 (-337 (-4289 (QUOTE X) (QUOTE -2928)) (-4289) (-688)))) (-5 *1 (-88 *3)) (-14 *3 (-1161))))) 
+(-13 (-386) (-10 -8 (-15 -2747 ($ (-679 (-337 (-4289 (QUOTE X) (QUOTE -2928)) (-4289) (-688))))))) 
+((-3668 (((-3 $ "failed") (-679 (-310 (-381)))) 103) (((-3 $ "failed") (-679 (-310 (-568)))) 92) (((-3 $ "failed") (-679 (-953 (-381)))) 124) (((-3 $ "failed") (-679 (-953 (-568)))) 113) (((-3 $ "failed") (-679 (-409 (-953 (-381))))) 81) (((-3 $ "failed") (-679 (-409 (-953 (-568))))) 70)) (-2857 (($ (-679 (-310 (-381)))) 99) (($ (-679 (-310 (-568)))) 88) (($ (-679 (-953 (-381)))) 120) (($ (-679 (-953 (-568)))) 109) (($ (-679 (-409 (-953 (-381))))) 77) (($ (-679 (-409 (-953 (-568))))) 63)) (-4130 (((-1249) $) 56)) (-2747 (((-850) $) 50) (($ (-634 (-328))) 44) (($ (-328)) 47) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 40) (($ (-679 (-337 (-4289 (QUOTE X)) (-4289) (-688)))) 41))) 
+(((-89 |#1|) (-13 (-386) (-10 -8 (-15 -2747 ($ (-679 (-337 (-4289 (QUOTE X)) (-4289) (-688))))))) (-1161)) (T -89)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-679 (-337 (-4289 (QUOTE X)) (-4289) (-688)))) (-5 *1 (-89 *3)) (-14 *3 (-1161))))) 
+(-13 (-386) (-10 -8 (-15 -2747 ($ (-679 (-337 (-4289 (QUOTE X)) (-4289) (-688))))))) 
+((-3668 (((-3 $ "failed") (-1244 (-310 (-381)))) 99) (((-3 $ "failed") (-1244 (-310 (-568)))) 88) (((-3 $ "failed") (-1244 (-953 (-381)))) 121) (((-3 $ "failed") (-1244 (-953 (-568)))) 110) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 77) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 66)) (-2857 (($ (-1244 (-310 (-381)))) 95) (($ (-1244 (-310 (-568)))) 84) (($ (-1244 (-953 (-381)))) 117) (($ (-1244 (-953 (-568)))) 106) (($ (-1244 (-409 (-953 (-381))))) 73) (($ (-1244 (-409 (-953 (-568))))) 59)) (-4130 (((-1249) $) 45)) (-2747 (((-850) $) 39) (($ (-634 (-328))) 48) (($ (-328)) 35) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 51) (($ (-1244 (-337 (-4289 (QUOTE X)) (-4289) (-688)))) 36))) 
+(((-90 |#1|) (-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289 (QUOTE X)) (-4289) (-688))))))) (-1161)) (T -90)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289 (QUOTE X)) (-4289) (-688)))) (-5 *1 (-90 *3)) (-14 *3 (-1161))))) 
+(-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289 (QUOTE X)) (-4289) (-688))))))) 
+((-3668 (((-3 $ "failed") (-1244 (-310 (-381)))) 74) (((-3 $ "failed") (-1244 (-310 (-568)))) 63) (((-3 $ "failed") (-1244 (-953 (-381)))) 96) (((-3 $ "failed") (-1244 (-953 (-568)))) 85) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 52) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 41)) (-2857 (($ (-1244 (-310 (-381)))) 70) (($ (-1244 (-310 (-568)))) 59) (($ (-1244 (-953 (-381)))) 92) (($ (-1244 (-953 (-568)))) 81) (($ (-1244 (-409 (-953 (-381))))) 48) (($ (-1244 (-409 (-953 (-568))))) 34)) (-4130 (((-1249) $) 122)) (-2747 (((-850) $) 116) (($ (-634 (-328))) 107) (($ (-328)) 113) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 111) (($ (-1244 (-337 (-4289 (QUOTE X)) (-4289 (QUOTE -2928)) (-688)))) 33))) 
+(((-91 |#1|) (-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289 (QUOTE X)) (-4289 (QUOTE -2928)) (-688))))))) (-1161)) (T -91)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289 (QUOTE X)) (-4289 (QUOTE -2928)) (-688)))) (-5 *1 (-91 *3)) (-14 *3 (-1161))))) 
+(-13 (-442) (-10 -8 (-15 -2747 ($ (-1244 (-337 (-4289 (QUOTE X)) (-4289 (QUOTE -2928)) (-688))))))) 
+((-3668 (((-3 $ "failed") (-679 (-310 (-381)))) 105) (((-3 $ "failed") (-679 (-310 (-568)))) 94) (((-3 $ "failed") (-679 (-953 (-381)))) 127) (((-3 $ "failed") (-679 (-953 (-568)))) 116) (((-3 $ "failed") (-679 (-409 (-953 (-381))))) 83) (((-3 $ "failed") (-679 (-409 (-953 (-568))))) 72)) (-2857 (($ (-679 (-310 (-381)))) 101) (($ (-679 (-310 (-568)))) 90) (($ (-679 (-953 (-381)))) 123) (($ (-679 (-953 (-568)))) 112) (($ (-679 (-409 (-953 (-381))))) 79) (($ (-679 (-409 (-953 (-568))))) 65)) (-4130 (((-1249) $) 58)) (-2747 (((-850) $) 52) (($ (-634 (-328))) 42) (($ (-328)) 49) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 47) (($ (-679 (-337 (-4289 (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (-4289) (-688)))) 43))) 
+(((-92 |#1|) (-13 (-386) (-10 -8 (-15 -2747 ($ (-679 (-337 (-4289 (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (-4289) (-688))))))) (-1161)) (T -92)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-679 (-337 (-4289 (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (-4289) (-688)))) (-5 *1 (-92 *3)) (-14 *3 (-1161))))) 
+(-13 (-386) (-10 -8 (-15 -2747 ($ (-679 (-337 (-4289 (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (-4289) (-688))))))) 
+((-4130 (((-1249) $) 44)) (-2747 (((-850) $) 38) (($ (-1244 (-688))) 88) (($ (-634 (-328))) 29) (($ (-328)) 35) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 32))) 
 (((-93 |#1|) (-441) (-1161)) (T -93)) 
 NIL 
 (-441) 
-((-3666 (((-3 $ "failed") (-310 (-381))) 42) (((-3 $ "failed") (-310 (-568))) 47) (((-3 $ "failed") (-953 (-381))) 52) (((-3 $ "failed") (-953 (-568))) 57) (((-3 $ "failed") (-409 (-953 (-381)))) 37) (((-3 $ "failed") (-409 (-953 (-568)))) 32)) (-2854 (($ (-310 (-381))) 40) (($ (-310 (-568))) 45) (($ (-953 (-381))) 50) (($ (-953 (-568))) 55) (($ (-409 (-953 (-381)))) 35) (($ (-409 (-953 (-568)))) 29)) (-4128 (((-1249) $) 88)) (-2745 (((-850) $) 82) (($ (-634 (-328))) 76) (($ (-328)) 79) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 73) (($ (-337 (-4287 (QUOTE X)) (-4287 (QUOTE -2926)) (-688))) 28))) 
-(((-94 |#1|) (-13 (-398) (-10 -8 (-15 -2745 ($ (-337 (-4287 (QUOTE X)) (-4287 (QUOTE -2926)) (-688)))))) (-1161)) (T -94)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-337 (-4287 (QUOTE X)) (-4287 (QUOTE -2926)) (-688))) (-5 *1 (-94 *3)) (-14 *3 (-1161))))) 
-(-13 (-398) (-10 -8 (-15 -2745 ($ (-337 (-4287 (QUOTE X)) (-4287 (QUOTE -2926)) (-688)))))) 
-((-3970 (((-1244 (-679 |#1|)) (-679 |#1|)) 54)) (-1366 (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 (-634 (-917))))) |#2| (-917)) 44)) (-3316 (((-2 (|:| |minor| (-634 (-917))) (|:| -1853 |#2|) (|:| |minors| (-634 (-634 (-917)))) (|:| |ops| (-634 |#2|))) |#2| (-917)) 62 (|has| |#1| (-365))))) 
-(((-95 |#1| |#2|) (-10 -7 (-15 -1366 ((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 (-634 (-917))))) |#2| (-917))) (-15 -3970 ((-1244 (-679 |#1|)) (-679 |#1|))) (IF (|has| |#1| (-365)) (-15 -3316 ((-2 (|:| |minor| (-634 (-917))) (|:| -1853 |#2|) (|:| |minors| (-634 (-634 (-917)))) (|:| |ops| (-634 |#2|))) |#2| (-917))) |noBranch|)) (-558) (-646 |#1|)) (T -95)) 
-((-3316 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *5 (-558)) (-5 *2 (-2 (|:| |minor| (-634 (-917))) (|:| -1853 *3) (|:| |minors| (-634 (-634 (-917)))) (|:| |ops| (-634 *3)))) (-5 *1 (-95 *5 *3)) (-5 *4 (-917)) (-4 *3 (-646 *5)))) (-3970 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-1244 (-679 *4))) (-5 *1 (-95 *4 *5)) (-5 *3 (-679 *4)) (-4 *5 (-646 *4)))) (-1366 (*1 *2 *3 *4) (-12 (-4 *5 (-558)) (-5 *2 (-2 (|:| -2928 (-679 *5)) (|:| |vec| (-1244 (-634 (-917)))))) (-5 *1 (-95 *5 *3)) (-5 *4 (-917)) (-4 *3 (-646 *5))))) 
-(-10 -7 (-15 -1366 ((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 (-634 (-917))))) |#2| (-917))) (-15 -3970 ((-1244 (-679 |#1|)) (-679 |#1|))) (IF (|has| |#1| (-365)) (-15 -3316 ((-2 (|:| |minor| (-634 (-917))) (|:| -1853 |#2|) (|:| |minors| (-634 (-634 (-917)))) (|:| |ops| (-634 |#2|))) |#2| (-917))) |noBranch|)) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2616 ((|#1| $) 34)) (-2510 (((-121) $ (-763)) NIL)) (-2671 (($) NIL T CONST)) (-2918 ((|#1| |#1| $) 30)) (-2899 ((|#1| $) 28)) (-4360 (((-634 |#1|) $) 39 (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) NIL)) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3674 (($ (-1 |#1| |#1|) $) 43 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 41)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-1890 ((|#1| $) 45)) (-4450 (($ |#1| $) 31)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-1315 ((|#1| $) 29)) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) 16)) (-3248 (($) 38)) (-4154 (((-763) $) 26)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) 15)) (-2745 (((-850) $) 25 (|has| |#1| (-1090)))) (-2367 (($ (-634 |#1|)) NIL)) (-3609 (($ (-634 |#1|)) 36)) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 13 (|has| |#1| (-1090)))) (-1697 (((-763) $) 10 (|has| $ (-6 -4519))))) 
-(((-96 |#1|) (-13 (-1109 |#1|) (-10 -8 (-15 -3609 ($ (-634 |#1|))) (-15 -2899 (|#1| $)) (-15 -1315 (|#1| $)) (-15 -2918 (|#1| |#1| $)) (-15 -4450 ($ |#1| $)) (-15 -1890 (|#1| $)) (-15 -2616 (|#1| $)) (-15 -4154 ((-763) $)) (-15 -2166 ((-121) $ (-763))) (-15 -1737 ((-121) $ (-763))) (-15 -2510 ((-121) $ (-763))) (-15 -2367 ($ (-634 |#1|))) (-15 -3084 ((-121) $)) (-15 -3248 ($)) (-15 -2671 ($)) (-15 -3863 ($ $)) (-15 -3171 ((-121) $ $)) (-15 -2795 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4520)) (-15 -3674 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-15 -4487 ((-1143) $)) (-15 -4022 ((-1108) $)) (-15 -2745 ((-850) $)) (-15 -1717 ((-121) $ $)) (-15 -2447 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4519)) (PROGN (-15 -1387 ((-121) (-1 (-121) |#1|) $)) (-15 -1319 ((-121) (-1 (-121) |#1|) $)) (-15 -4168 ((-763) (-1 (-121) |#1|) $)) (-15 -1697 ((-763) $)) (-15 -4360 ((-634 |#1|) $)) (-15 -1979 ((-634 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4519)) (IF (|has| |#1| (-1090)) (PROGN (-15 -3109 ((-121) |#1| $)) (-15 -4168 ((-763) |#1| $))) |noBranch|) |noBranch|))) (-1090)) (T -96)) 
-((-3171 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) (-3863 (*1 *1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) (-3248 (*1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) (-3084 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) (-2166 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-96 *4)) (-4 *4 (-1090)))) (-1737 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-96 *4)) (-4 *4 (-1090)))) (-2510 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-96 *4)) (-4 *4 (-1090)))) (-2671 (*1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) (-1697 (*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-763)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) (-2795 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-96 *3)))) (-3674 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4520)) (-4 *3 (-1090)) (-5 *1 (-96 *3)))) (-1319 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-96 *4)))) (-1387 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-96 *4)))) (-4168 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-763)) (-5 *1 (-96 *4)))) (-4360 (*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-634 *3)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) (-1979 (*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-634 *3)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) (-4168 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-763)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-3109 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-4487 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-4022 (*1 *2 *1) (-12 (-5 *2 (-1108)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-1717 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2447 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2367 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-96 *3)))) (-1315 (*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) (-4450 (*1 *1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) (-1890 (*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) (-2918 (*1 *2 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) (-2899 (*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) (-2616 (*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) (-4154 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) (-3609 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-96 *3))))) 
-(-13 (-1109 |#1|) (-10 -8 (-15 -3609 ($ (-634 |#1|))) (-15 -2899 (|#1| $)) (-15 -1315 (|#1| $)) (-15 -2918 (|#1| |#1| $)) (-15 -4450 ($ |#1| $)) (-15 -1890 (|#1| $)) (-15 -2616 (|#1| $)) (-15 -4154 ((-763) $)) (-15 -2166 ((-121) $ (-763))) (-15 -1737 ((-121) $ (-763))) (-15 -2510 ((-121) $ (-763))) (-15 -2367 ($ (-634 |#1|))) (-15 -3084 ((-121) $)) (-15 -3248 ($)) (-15 -2671 ($)) (-15 -3863 ($ $)) (-15 -3171 ((-121) $ $)) (-15 -2795 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4520)) (-15 -3674 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-15 -4487 ((-1143) $)) (-15 -4022 ((-1108) $)) (-15 -2745 ((-850) $)) (-15 -1717 ((-121) $ $)) (-15 -2447 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4519)) (PROGN (-15 -1387 ((-121) (-1 (-121) |#1|) $)) (-15 -1319 ((-121) (-1 (-121) |#1|) $)) (-15 -4168 ((-763) (-1 (-121) |#1|) $)) (-15 -1697 ((-763) $)) (-15 -4360 ((-634 |#1|) $)) (-15 -1979 ((-634 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4519)) (IF (|has| |#1| (-1090)) (PROGN (-15 -3109 ((-121) |#1| $)) (-15 -4168 ((-763) |#1| $))) |noBranch|) |noBranch|))) 
-((-1966 (($ $) 10)) (-1970 (($ $) 12))) 
-(((-97 |#1|) (-10 -8 (-15 -1970 (|#1| |#1|)) (-15 -1966 (|#1| |#1|))) (-98)) (T -97)) 
-NIL 
-(-10 -8 (-15 -1970 (|#1| |#1|)) (-15 -1966 (|#1| |#1|))) 
-((-1958 (($ $) 11)) (-1949 (($ $) 10)) (-1966 (($ $) 9)) (-1970 (($ $) 8)) (-1962 (($ $) 7)) (-1953 (($ $) 6))) 
+((-3668 (((-3 $ "failed") (-310 (-381))) 42) (((-3 $ "failed") (-310 (-568))) 47) (((-3 $ "failed") (-953 (-381))) 52) (((-3 $ "failed") (-953 (-568))) 57) (((-3 $ "failed") (-409 (-953 (-381)))) 37) (((-3 $ "failed") (-409 (-953 (-568)))) 32)) (-2857 (($ (-310 (-381))) 40) (($ (-310 (-568))) 45) (($ (-953 (-381))) 50) (($ (-953 (-568))) 55) (($ (-409 (-953 (-381)))) 35) (($ (-409 (-953 (-568)))) 29)) (-4130 (((-1249) $) 88)) (-2747 (((-850) $) 82) (($ (-634 (-328))) 76) (($ (-328)) 79) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 73) (($ (-337 (-4289 (QUOTE X)) (-4289 (QUOTE -2928)) (-688))) 28))) 
+(((-94 |#1|) (-13 (-398) (-10 -8 (-15 -2747 ($ (-337 (-4289 (QUOTE X)) (-4289 (QUOTE -2928)) (-688)))))) (-1161)) (T -94)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-337 (-4289 (QUOTE X)) (-4289 (QUOTE -2928)) (-688))) (-5 *1 (-94 *3)) (-14 *3 (-1161))))) 
+(-13 (-398) (-10 -8 (-15 -2747 ($ (-337 (-4289 (QUOTE X)) (-4289 (QUOTE -2928)) (-688)))))) 
+((-4451 (((-1244 (-679 |#1|)) (-679 |#1|)) 54)) (-3789 (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 (-634 (-917))))) |#2| (-917)) 44)) (-4312 (((-2 (|:| |minor| (-634 (-917))) (|:| -2410 |#2|) (|:| |minors| (-634 (-634 (-917)))) (|:| |ops| (-634 |#2|))) |#2| (-917)) 62 (|has| |#1| (-365))))) 
+(((-95 |#1| |#2|) (-10 -7 (-15 -3789 ((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 (-634 (-917))))) |#2| (-917))) (-15 -4451 ((-1244 (-679 |#1|)) (-679 |#1|))) (IF (|has| |#1| (-365)) (-15 -4312 ((-2 (|:| |minor| (-634 (-917))) (|:| -2410 |#2|) (|:| |minors| (-634 (-634 (-917)))) (|:| |ops| (-634 |#2|))) |#2| (-917))) |noBranch|)) (-558) (-646 |#1|)) (T -95)) 
+((-4312 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *5 (-558)) (-5 *2 (-2 (|:| |minor| (-634 (-917))) (|:| -2410 *3) (|:| |minors| (-634 (-634 (-917)))) (|:| |ops| (-634 *3)))) (-5 *1 (-95 *5 *3)) (-5 *4 (-917)) (-4 *3 (-646 *5)))) (-4451 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-1244 (-679 *4))) (-5 *1 (-95 *4 *5)) (-5 *3 (-679 *4)) (-4 *5 (-646 *4)))) (-3789 (*1 *2 *3 *4) (-12 (-4 *5 (-558)) (-5 *2 (-2 (|:| -2908 (-679 *5)) (|:| |vec| (-1244 (-634 (-917)))))) (-5 *1 (-95 *5 *3)) (-5 *4 (-917)) (-4 *3 (-646 *5))))) 
+(-10 -7 (-15 -3789 ((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 (-634 (-917))))) |#2| (-917))) (-15 -4451 ((-1244 (-679 |#1|)) (-679 |#1|))) (IF (|has| |#1| (-365)) (-15 -4312 ((-2 (|:| |minor| (-634 (-917))) (|:| -2410 |#2|) (|:| |minors| (-634 (-634 (-917)))) (|:| |ops| (-634 |#2|))) |#2| (-917))) |noBranch|)) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2618 ((|#1| $) 34)) (-1667 (((-121) $ (-763)) NIL)) (-4490 (($) NIL T CONST)) (-2885 ((|#1| |#1| $) 30)) (-2819 ((|#1| $) 28)) (-3317 (((-634 |#1|) $) 39 (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) NIL)) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-2253 (($ (-1 |#1| |#1|) $) 43 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 41)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-2580 ((|#1| $) 45)) (-1708 (($ |#1| $) 31)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3403 ((|#1| $) 29)) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) 16)) (-1990 (($) 38)) (-4156 (((-763) $) 26)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) 15)) (-2747 (((-850) $) 25 (|has| |#1| (-1090)))) (-4074 (($ (-634 |#1|)) NIL)) (-3041 (($ (-634 |#1|)) 36)) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 13 (|has| |#1| (-1090)))) (-1699 (((-763) $) 10 (|has| $ (-6 -4521))))) 
+(((-96 |#1|) (-13 (-1109 |#1|) (-10 -8 (-15 -3041 ($ (-634 |#1|))) (-15 -2819 (|#1| $)) (-15 -3403 (|#1| $)) (-15 -2885 (|#1| |#1| $)) (-15 -1708 ($ |#1| $)) (-15 -2580 (|#1| $)) (-15 -2618 (|#1| $)) (-15 -4156 ((-763) $)) (-15 -3796 ((-121) $ (-763))) (-15 -3791 ((-121) $ (-763))) (-15 -1667 ((-121) $ (-763))) (-15 -4074 ($ (-634 |#1|))) (-15 -2436 ((-121) $)) (-15 -1990 ($)) (-15 -4490 ($)) (-15 -3865 ($ $)) (-15 -1702 ((-121) $ $)) (-15 -2797 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4522)) (-15 -2253 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-15 -1893 ((-1143) $)) (-15 -4025 ((-1108) $)) (-15 -2747 ((-850) $)) (-15 -1719 ((-121) $ $)) (-15 -2449 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4521)) (PROGN (-15 -3951 ((-121) (-1 (-121) |#1|) $)) (-15 -3437 ((-121) (-1 (-121) |#1|) $)) (-15 -4170 ((-763) (-1 (-121) |#1|) $)) (-15 -1699 ((-763) $)) (-15 -3317 ((-634 |#1|) $)) (-15 -4406 ((-634 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4521)) (IF (|has| |#1| (-1090)) (PROGN (-15 -2551 ((-121) |#1| $)) (-15 -4170 ((-763) |#1| $))) |noBranch|) |noBranch|))) (-1090)) (T -96)) 
+((-1702 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) (-3865 (*1 *1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) (-1990 (*1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) (-2436 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) (-3796 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-96 *4)) (-4 *4 (-1090)))) (-3791 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-96 *4)) (-4 *4 (-1090)))) (-1667 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-96 *4)) (-4 *4 (-1090)))) (-4490 (*1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) (-1699 (*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-763)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) (-2797 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-96 *3)))) (-2253 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4522)) (-4 *3 (-1090)) (-5 *1 (-96 *3)))) (-3437 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-96 *4)))) (-3951 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-96 *4)))) (-4170 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-763)) (-5 *1 (-96 *4)))) (-3317 (*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-634 *3)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) (-4406 (*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-634 *3)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) (-4170 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-763)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2551 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-1893 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-4025 (*1 *2 *1) (-12 (-5 *2 (-1108)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-1719 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2449 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-4074 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-96 *3)))) (-3403 (*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) (-1708 (*1 *1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) (-2580 (*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) (-2885 (*1 *2 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) (-2819 (*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) (-2618 (*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) (-4156 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) (-3041 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-96 *3))))) 
+(-13 (-1109 |#1|) (-10 -8 (-15 -3041 ($ (-634 |#1|))) (-15 -2819 (|#1| $)) (-15 -3403 (|#1| $)) (-15 -2885 (|#1| |#1| $)) (-15 -1708 ($ |#1| $)) (-15 -2580 (|#1| $)) (-15 -2618 (|#1| $)) (-15 -4156 ((-763) $)) (-15 -3796 ((-121) $ (-763))) (-15 -3791 ((-121) $ (-763))) (-15 -1667 ((-121) $ (-763))) (-15 -4074 ($ (-634 |#1|))) (-15 -2436 ((-121) $)) (-15 -1990 ($)) (-15 -4490 ($)) (-15 -3865 ($ $)) (-15 -1702 ((-121) $ $)) (-15 -2797 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4522)) (-15 -2253 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-15 -1893 ((-1143) $)) (-15 -4025 ((-1108) $)) (-15 -2747 ((-850) $)) (-15 -1719 ((-121) $ $)) (-15 -2449 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4521)) (PROGN (-15 -3951 ((-121) (-1 (-121) |#1|) $)) (-15 -3437 ((-121) (-1 (-121) |#1|) $)) (-15 -4170 ((-763) (-1 (-121) |#1|) $)) (-15 -1699 ((-763) $)) (-15 -3317 ((-634 |#1|) $)) (-15 -4406 ((-634 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4521)) (IF (|has| |#1| (-1090)) (PROGN (-15 -2551 ((-121) |#1| $)) (-15 -4170 ((-763) |#1| $))) |noBranch|) |noBranch|))) 
+((-1968 (($ $) 10)) (-1972 (($ $) 12))) 
+(((-97 |#1|) (-10 -8 (-15 -1972 (|#1| |#1|)) (-15 -1968 (|#1| |#1|))) (-98)) (T -97)) 
+NIL 
+(-10 -8 (-15 -1972 (|#1| |#1|)) (-15 -1968 (|#1| |#1|))) 
+((-1959 (($ $) 11)) (-1951 (($ $) 10)) (-1968 (($ $) 9)) (-1972 (($ $) 8)) (-1964 (($ $) 7)) (-1955 (($ $) 6))) 
 (((-98) (-1275)) (T -98)) 
-((-1958 (*1 *1 *1) (-4 *1 (-98))) (-1949 (*1 *1 *1) (-4 *1 (-98))) (-1966 (*1 *1 *1) (-4 *1 (-98))) (-1970 (*1 *1 *1) (-4 *1 (-98))) (-1962 (*1 *1 *1) (-4 *1 (-98))) (-1953 (*1 *1 *1) (-4 *1 (-98)))) 
-(-13 (-10 -8 (-15 -1953 ($ $)) (-15 -1962 ($ $)) (-15 -1970 ($ $)) (-15 -1966 ($ $)) (-15 -1949 ($ $)) (-15 -1958 ($ $)))) 
-((-2447 (((-121) $ $) NIL)) (-4126 (((-381) (-1143) (-381)) 42) (((-381) (-1143) (-1143) (-381)) 41)) (-4051 (((-381) (-381)) 33)) (-2019 (((-1249)) 36)) (-4487 (((-1143) $) NIL)) (-2490 (((-381) (-1143) (-1143)) 46) (((-381) (-1143)) 48)) (-4022 (((-1108) $) NIL)) (-4193 (((-381) (-1143) (-1143)) 47)) (-2718 (((-381) (-1143) (-1143)) 49) (((-381) (-1143)) 50)) (-2745 (((-850) $) NIL)) (-1717 (((-121) $ $) NIL))) 
-(((-99) (-13 (-1090) (-10 -7 (-15 -2490 ((-381) (-1143) (-1143))) (-15 -2490 ((-381) (-1143))) (-15 -2718 ((-381) (-1143) (-1143))) (-15 -2718 ((-381) (-1143))) (-15 -4193 ((-381) (-1143) (-1143))) (-15 -2019 ((-1249))) (-15 -4051 ((-381) (-381))) (-15 -4126 ((-381) (-1143) (-381))) (-15 -4126 ((-381) (-1143) (-1143) (-381))) (-6 -4519)))) (T -99)) 
-((-2490 (*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-99)))) (-2490 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-99)))) (-2718 (*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-99)))) (-2718 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-99)))) (-4193 (*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-99)))) (-2019 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-99)))) (-4051 (*1 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-99)))) (-4126 (*1 *2 *3 *2) (-12 (-5 *2 (-381)) (-5 *3 (-1143)) (-5 *1 (-99)))) (-4126 (*1 *2 *3 *3 *2) (-12 (-5 *2 (-381)) (-5 *3 (-1143)) (-5 *1 (-99))))) 
-(-13 (-1090) (-10 -7 (-15 -2490 ((-381) (-1143) (-1143))) (-15 -2490 ((-381) (-1143))) (-15 -2718 ((-381) (-1143) (-1143))) (-15 -2718 ((-381) (-1143))) (-15 -4193 ((-381) (-1143) (-1143))) (-15 -2019 ((-1249))) (-15 -4051 ((-381) (-381))) (-15 -4126 ((-381) (-1143) (-381))) (-15 -4126 ((-381) (-1143) (-1143) (-381))) (-6 -4519))) 
+((-1959 (*1 *1 *1) (-4 *1 (-98))) (-1951 (*1 *1 *1) (-4 *1 (-98))) (-1968 (*1 *1 *1) (-4 *1 (-98))) (-1972 (*1 *1 *1) (-4 *1 (-98))) (-1964 (*1 *1 *1) (-4 *1 (-98))) (-1955 (*1 *1 *1) (-4 *1 (-98)))) 
+(-13 (-10 -8 (-15 -1955 ($ $)) (-15 -1964 ($ $)) (-15 -1972 ($ $)) (-15 -1968 ($ $)) (-15 -1951 ($ $)) (-15 -1959 ($ $)))) 
+((-2449 (((-121) $ $) NIL)) (-3685 (((-381) (-1143) (-381)) 42) (((-381) (-1143) (-1143) (-381)) 41)) (-1583 (((-381) (-381)) 33)) (-1346 (((-1249)) 36)) (-1893 (((-1143) $) NIL)) (-2717 (((-381) (-1143) (-1143)) 46) (((-381) (-1143)) 48)) (-4025 (((-1108) $) NIL)) (-4047 (((-381) (-1143) (-1143)) 47)) (-1522 (((-381) (-1143) (-1143)) 49) (((-381) (-1143)) 50)) (-2747 (((-850) $) NIL)) (-1719 (((-121) $ $) NIL))) 
+(((-99) (-13 (-1090) (-10 -7 (-15 -2717 ((-381) (-1143) (-1143))) (-15 -2717 ((-381) (-1143))) (-15 -1522 ((-381) (-1143) (-1143))) (-15 -1522 ((-381) (-1143))) (-15 -4047 ((-381) (-1143) (-1143))) (-15 -1346 ((-1249))) (-15 -1583 ((-381) (-381))) (-15 -3685 ((-381) (-1143) (-381))) (-15 -3685 ((-381) (-1143) (-1143) (-381))) (-6 -4521)))) (T -99)) 
+((-2717 (*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-99)))) (-2717 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-99)))) (-1522 (*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-99)))) (-1522 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-99)))) (-4047 (*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-99)))) (-1346 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-99)))) (-1583 (*1 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-99)))) (-3685 (*1 *2 *3 *2) (-12 (-5 *2 (-381)) (-5 *3 (-1143)) (-5 *1 (-99)))) (-3685 (*1 *2 *3 *3 *2) (-12 (-5 *2 (-381)) (-5 *3 (-1143)) (-5 *1 (-99))))) 
+(-13 (-1090) (-10 -7 (-15 -2717 ((-381) (-1143) (-1143))) (-15 -2717 ((-381) (-1143))) (-15 -1522 ((-381) (-1143) (-1143))) (-15 -1522 ((-381) (-1143))) (-15 -4047 ((-381) (-1143) (-1143))) (-15 -1346 ((-1249))) (-15 -1583 ((-381) (-381))) (-15 -3685 ((-381) (-1143) (-381))) (-15 -3685 ((-381) (-1143) (-1143) (-381))) (-6 -4521))) 
 NIL 
 (((-100) (-1275)) (T -100)) 
 NIL 
-(-13 (-10 -7 (-6 -4519) (-6 (-4521 "*")) (-6 -4520) (-6 -4516) (-6 -4514) (-6 -4513) (-6 -4512) (-6 -4517) (-6 -4511) (-6 -4510) (-6 -4509) (-6 -4508) (-6 -4507) (-6 -4515) (-6 -4518) (-6 |NullSquare|) (-6 |JacobiIdentity|) (-6 -4506) (-6 -3996))) 
-((-2447 (((-121) $ $) NIL)) (-2671 (($) NIL T CONST)) (-2925 (((-3 $ "failed") $) NIL)) (-2735 (((-121) $) NIL)) (-4471 (($ (-1 |#1| |#1|)) 25) (($ (-1 |#1| |#1|) (-1 |#1| |#1|)) 24) (($ (-1 |#1| |#1| (-568))) 22)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) 14)) (-4022 (((-1108) $) NIL)) (-2779 ((|#1| $ |#1|) 11)) (-1458 (($ $ $) NIL)) (-2353 (($ $ $) NIL)) (-2745 (((-850) $) 20)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-1556 (($) 8 T CONST)) (-1717 (((-121) $ $) 10)) (-1779 (($ $ $) NIL)) (** (($ $ (-917)) 28) (($ $ (-763)) NIL) (($ $ (-568)) 16)) (* (($ $ $) 29))) 
-(((-101 |#1|) (-13 (-478) (-281 |#1| |#1|) (-10 -8 (-15 -4471 ($ (-1 |#1| |#1|))) (-15 -4471 ($ (-1 |#1| |#1|) (-1 |#1| |#1|))) (-15 -4471 ($ (-1 |#1| |#1| (-568)))))) (-1047)) (T -101)) 
-((-4471 (*1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-101 *3)))) (-4471 (*1 *1 *2 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-101 *3)))) (-4471 (*1 *1 *2) (-12 (-5 *2 (-1 *3 *3 (-568))) (-4 *3 (-1047)) (-5 *1 (-101 *3))))) 
-(-13 (-478) (-281 |#1| |#1|) (-10 -8 (-15 -4471 ($ (-1 |#1| |#1|))) (-15 -4471 ($ (-1 |#1| |#1|) (-1 |#1| |#1|))) (-15 -4471 ($ (-1 |#1| |#1| (-568)))))) 
-((-2292 (((-1249) (-1094)) 20)) (-3457 (((-1143) (-1143) (-1143)) 7)) (-2498 (((-1249) (-568) (-1 (-1249) (-1094))) 14))) 
-(((-102) (-10 -7 (-15 -2498 ((-1249) (-568) (-1 (-1249) (-1094)))) (-15 -2292 ((-1249) (-1094))) (-15 -3457 ((-1143) (-1143) (-1143))))) (T -102)) 
-((-3457 (*1 *2 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-102)))) (-2292 (*1 *2 *3) (-12 (-5 *3 (-1094)) (-5 *2 (-1249)) (-5 *1 (-102)))) (-2498 (*1 *2 *3 *4) (-12 (-5 *3 (-568)) (-5 *4 (-1 (-1249) (-1094))) (-5 *2 (-1249)) (-5 *1 (-102))))) 
-(-10 -7 (-15 -2498 ((-1249) (-568) (-1 (-1249) (-1094)))) (-15 -2292 ((-1249) (-1094))) (-15 -3457 ((-1143) (-1143) (-1143)))) 
-((-2025 (((-420 |#2|) |#2| (-634 |#2|)) 10) (((-420 |#2|) |#2| |#2|) 11))) 
-(((-103 |#1| |#2|) (-10 -7 (-15 -2025 ((-420 |#2|) |#2| |#2|)) (-15 -2025 ((-420 |#2|) |#2| (-634 |#2|)))) (-13 (-453) (-150)) (-1219 |#1|)) (T -103)) 
-((-2025 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-13 (-453) (-150))) (-5 *2 (-420 *3)) (-5 *1 (-103 *5 *3)))) (-2025 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-453) (-150))) (-5 *2 (-420 *3)) (-5 *1 (-103 *4 *3)) (-4 *3 (-1219 *4))))) 
-(-10 -7 (-15 -2025 ((-420 |#2|) |#2| |#2|)) (-15 -2025 ((-420 |#2|) |#2| (-634 |#2|)))) 
-((-2447 (((-121) $ $) 9))) 
-(((-104 |#1|) (-10 -8 (-15 -2447 ((-121) |#1| |#1|))) (-105)) (T -104)) 
-NIL 
-(-10 -8 (-15 -2447 ((-121) |#1| |#1|))) 
-((-2447 (((-121) $ $) 7)) (-1717 (((-121) $ $) 6))) 
+(-13 (-10 -7 (-6 -4521) (-6 (-4523 "*")) (-6 -4522) (-6 -4518) (-6 -4516) (-6 -4515) (-6 -4514) (-6 -4519) (-6 -4513) (-6 -4512) (-6 -4511) (-6 -4510) (-6 -4509) (-6 -4517) (-6 -4520) (-6 |NullSquare|) (-6 |JacobiIdentity|) (-6 -4508) (-6 -3999))) 
+((-2449 (((-121) $ $) NIL)) (-4490 (($) NIL T CONST)) (-2902 (((-3 $ "failed") $) NIL)) (-1598 (((-121) $) NIL)) (-1818 (($ (-1 |#1| |#1|)) 25) (($ (-1 |#1| |#1|) (-1 |#1| |#1|)) 24) (($ (-1 |#1| |#1| (-568))) 22)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) 14)) (-4025 (((-1108) $) NIL)) (-2781 ((|#1| $ |#1|) 11)) (-2387 (($ $ $) NIL)) (-3985 (($ $ $) NIL)) (-2747 (((-850) $) 20)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-1557 (($) 8 T CONST)) (-1719 (((-121) $ $) 10)) (-1781 (($ $ $) NIL)) (** (($ $ (-917)) 28) (($ $ (-763)) NIL) (($ $ (-568)) 16)) (* (($ $ $) 29))) 
+(((-101 |#1|) (-13 (-478) (-281 |#1| |#1|) (-10 -8 (-15 -1818 ($ (-1 |#1| |#1|))) (-15 -1818 ($ (-1 |#1| |#1|) (-1 |#1| |#1|))) (-15 -1818 ($ (-1 |#1| |#1| (-568)))))) (-1047)) (T -101)) 
+((-1818 (*1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-101 *3)))) (-1818 (*1 *1 *2 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-101 *3)))) (-1818 (*1 *1 *2) (-12 (-5 *2 (-1 *3 *3 (-568))) (-4 *3 (-1047)) (-5 *1 (-101 *3))))) 
+(-13 (-478) (-281 |#1| |#1|) (-10 -8 (-15 -1818 ($ (-1 |#1| |#1|))) (-15 -1818 ($ (-1 |#1| |#1|) (-1 |#1| |#1|))) (-15 -1818 ($ (-1 |#1| |#1| (-568)))))) 
+((-3569 (((-1249) (-1094)) 20)) (-3617 (((-1143) (-1143) (-1143)) 7)) (-1614 (((-1249) (-568) (-1 (-1249) (-1094))) 14))) 
+(((-102) (-10 -7 (-15 -1614 ((-1249) (-568) (-1 (-1249) (-1094)))) (-15 -3569 ((-1249) (-1094))) (-15 -3617 ((-1143) (-1143) (-1143))))) (T -102)) 
+((-3617 (*1 *2 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-102)))) (-3569 (*1 *2 *3) (-12 (-5 *3 (-1094)) (-5 *2 (-1249)) (-5 *1 (-102)))) (-1614 (*1 *2 *3 *4) (-12 (-5 *3 (-568)) (-5 *4 (-1 (-1249) (-1094))) (-5 *2 (-1249)) (-5 *1 (-102))))) 
+(-10 -7 (-15 -1614 ((-1249) (-568) (-1 (-1249) (-1094)))) (-15 -3569 ((-1249) (-1094))) (-15 -3617 ((-1143) (-1143) (-1143)))) 
+((-1385 (((-420 |#2|) |#2| (-634 |#2|)) 10) (((-420 |#2|) |#2| |#2|) 11))) 
+(((-103 |#1| |#2|) (-10 -7 (-15 -1385 ((-420 |#2|) |#2| |#2|)) (-15 -1385 ((-420 |#2|) |#2| (-634 |#2|)))) (-13 (-453) (-150)) (-1219 |#1|)) (T -103)) 
+((-1385 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-13 (-453) (-150))) (-5 *2 (-420 *3)) (-5 *1 (-103 *5 *3)))) (-1385 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-453) (-150))) (-5 *2 (-420 *3)) (-5 *1 (-103 *4 *3)) (-4 *3 (-1219 *4))))) 
+(-10 -7 (-15 -1385 ((-420 |#2|) |#2| |#2|)) (-15 -1385 ((-420 |#2|) |#2| (-634 |#2|)))) 
+((-2449 (((-121) $ $) 9))) 
+(((-104 |#1|) (-10 -8 (-15 -2449 ((-121) |#1| |#1|))) (-105)) (T -104)) 
+NIL 
+(-10 -8 (-15 -2449 ((-121) |#1| |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1719 (((-121) $ $) 6))) 
 (((-105) (-1275)) (T -105)) 
-((-2447 (*1 *2 *1 *1) (-12 (-4 *1 (-105)) (-5 *2 (-121)))) (-1717 (*1 *2 *1 *1) (-12 (-4 *1 (-105)) (-5 *2 (-121))))) 
-(-13 (-10 -8 (-15 -1717 ((-121) $ $)) (-15 -2447 ((-121) $ $)))) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2850 ((|#1| $) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-1659 ((|#1| $ |#1|) 13 (|has| $ (-6 -4520)))) (-3497 (($ $ $) NIL (|has| $ (-6 -4520)))) (-3089 (($ $ $) NIL (|has| $ (-6 -4520)))) (-2243 (($ $ (-634 |#1|)) 15)) (-2436 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4520))) (($ $ "left" $) NIL (|has| $ (-6 -4520))) (($ $ "right" $) NIL (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) NIL (|has| $ (-6 -4520)))) (-2671 (($) NIL T CONST)) (-3284 (($ $) 11)) (-4360 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-2287 (((-634 $) $) NIL)) (-1700 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3341 (($ $ |#1| $) 17)) (-1737 (((-121) $ (-763)) NIL)) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-1503 ((|#1| $ (-1 |#1| |#1| |#1|)) 25) (($ $ $ (-1 |#1| |#1| |#1| |#1| |#1|)) 30)) (-4280 (($ $ |#1| (-1 |#1| |#1| |#1|)) 31) (($ $ |#1| (-1 (-634 |#1|) |#1| |#1| |#1|)) 35)) (-3674 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-3028 (($ $) 10)) (-2869 (((-634 |#1|) $) NIL)) (-1651 (((-121) $) 12)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) 9)) (-3248 (($) 16)) (-2779 ((|#1| $ "value") NIL) (($ $ "left") NIL) (($ $ "right") NIL)) (-4075 (((-568) $ $) NIL)) (-3790 (((-121) $) NIL)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) NIL)) (-2745 (((-850) $) NIL (|has| |#1| (-1090)))) (-4339 (((-634 $) $) NIL)) (-3491 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2203 (($ (-763) |#1|) 19)) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-106 |#1|) (-13 (-134 |#1|) (-10 -8 (-6 -4519) (-6 -4520) (-15 -2203 ($ (-763) |#1|)) (-15 -2243 ($ $ (-634 |#1|))) (-15 -1503 (|#1| $ (-1 |#1| |#1| |#1|))) (-15 -1503 ($ $ $ (-1 |#1| |#1| |#1| |#1| |#1|))) (-15 -4280 ($ $ |#1| (-1 |#1| |#1| |#1|))) (-15 -4280 ($ $ |#1| (-1 (-634 |#1|) |#1| |#1| |#1|))))) (-1090)) (T -106)) 
-((-2203 (*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *1 (-106 *3)) (-4 *3 (-1090)))) (-2243 (*1 *1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-106 *3)))) (-1503 (*1 *2 *1 *3) (-12 (-5 *3 (-1 *2 *2 *2)) (-5 *1 (-106 *2)) (-4 *2 (-1090)))) (-1503 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3 *3 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-106 *3)))) (-4280 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1090)) (-5 *1 (-106 *2)))) (-4280 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-1 (-634 *2) *2 *2 *2)) (-4 *2 (-1090)) (-5 *1 (-106 *2))))) 
-(-13 (-134 |#1|) (-10 -8 (-6 -4519) (-6 -4520) (-15 -2203 ($ (-763) |#1|)) (-15 -2243 ($ $ (-634 |#1|))) (-15 -1503 (|#1| $ (-1 |#1| |#1| |#1|))) (-15 -1503 ($ $ $ (-1 |#1| |#1| |#1| |#1| |#1|))) (-15 -4280 ($ $ |#1| (-1 |#1| |#1| |#1|))) (-15 -4280 ($ $ |#1| (-1 (-634 |#1|) |#1| |#1| |#1|))))) 
-((-2747 (((-1 (-634 |#1|) |#1|) (-634 |#1|) (-634 |#1|) (-634 |#1|)) 20)) (-3617 (((-1 (-634 |#1|) |#1|) (-634 |#1|) (-634 |#1|)) 17)) (-2973 (((-1 (-634 |#1|) |#1|) (-634 |#1|) (-634 |#1|) (-634 |#1|) (-634 |#1|)) 21))) 
-(((-107 |#1|) (-10 -7 (-15 -3617 ((-1 (-634 |#1|) |#1|) (-634 |#1|) (-634 |#1|))) (-15 -2747 ((-1 (-634 |#1|) |#1|) (-634 |#1|) (-634 |#1|) (-634 |#1|))) (-15 -2973 ((-1 (-634 |#1|) |#1|) (-634 |#1|) (-634 |#1|) (-634 |#1|) (-634 |#1|)))) (-1047)) (T -107)) 
-((-2973 (*1 *2 *3 *3 *3 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-1 (-634 *4) *4)) (-5 *1 (-107 *4)) (-5 *3 (-634 *4)))) (-2747 (*1 *2 *3 *3 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-1 (-634 *4) *4)) (-5 *1 (-107 *4)) (-5 *3 (-634 *4)))) (-3617 (*1 *2 *3 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-1 (-634 *4) *4)) (-5 *1 (-107 *4)) (-5 *3 (-634 *4))))) 
-(-10 -7 (-15 -3617 ((-1 (-634 |#1|) |#1|) (-634 |#1|) (-634 |#1|))) (-15 -2747 ((-1 (-634 |#1|) |#1|) (-634 |#1|) (-634 |#1|) (-634 |#1|))) (-15 -2973 ((-1 (-634 |#1|) |#1|) (-634 |#1|) (-634 |#1|) (-634 |#1|) (-634 |#1|)))) 
-((-1522 ((|#3| |#2| |#2|) 28)) (-3467 ((|#1| |#2| |#2|) 36 (|has| |#1| (-6 (-4521 "*"))))) (-2318 ((|#3| |#2| |#2|) 29)) (-2732 ((|#1| |#2|) 40 (|has| |#1| (-6 (-4521 "*")))))) 
-(((-108 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1522 (|#3| |#2| |#2|)) (-15 -2318 (|#3| |#2| |#2|)) (IF (|has| |#1| (-6 (-4521 "*"))) (PROGN (-15 -3467 (|#1| |#2| |#2|)) (-15 -2732 (|#1| |#2|))) |noBranch|)) (-1047) (-1219 |#1|) (-677 |#1| |#4| |#5|) (-375 |#1|) (-375 |#1|)) (T -108)) 
-((-2732 (*1 *2 *3) (-12 (|has| *2 (-6 (-4521 "*"))) (-4 *5 (-375 *2)) (-4 *6 (-375 *2)) (-4 *2 (-1047)) (-5 *1 (-108 *2 *3 *4 *5 *6)) (-4 *3 (-1219 *2)) (-4 *4 (-677 *2 *5 *6)))) (-3467 (*1 *2 *3 *3) (-12 (|has| *2 (-6 (-4521 "*"))) (-4 *5 (-375 *2)) (-4 *6 (-375 *2)) (-4 *2 (-1047)) (-5 *1 (-108 *2 *3 *4 *5 *6)) (-4 *3 (-1219 *2)) (-4 *4 (-677 *2 *5 *6)))) (-2318 (*1 *2 *3 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-677 *4 *5 *6)) (-5 *1 (-108 *4 *3 *2 *5 *6)) (-4 *3 (-1219 *4)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)))) (-1522 (*1 *2 *3 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-677 *4 *5 *6)) (-5 *1 (-108 *4 *3 *2 *5 *6)) (-4 *3 (-1219 *4)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4))))) 
-(-10 -7 (-15 -1522 (|#3| |#2| |#2|)) (-15 -2318 (|#3| |#2| |#2|)) (IF (|has| |#1| (-6 (-4521 "*"))) (PROGN (-15 -3467 (|#1| |#2| |#2|)) (-15 -2732 (|#1| |#2|))) |noBranch|)) 
-((-2447 (((-121) $ $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-1967 (((-634 (-1161))) 32)) (-4195 (((-2 (|:| |zeros| (-1141 (-215))) (|:| |ones| (-1141 (-215))) (|:| |singularities| (-1141 (-215)))) (-1161)) 35)) (-1717 (((-121) $ $) NIL))) 
-(((-109) (-13 (-1090) (-10 -7 (-15 -1967 ((-634 (-1161)))) (-15 -4195 ((-2 (|:| |zeros| (-1141 (-215))) (|:| |ones| (-1141 (-215))) (|:| |singularities| (-1141 (-215)))) (-1161))) (-6 -4519)))) (T -109)) 
-((-1967 (*1 *2) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-109)))) (-4195 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-2 (|:| |zeros| (-1141 (-215))) (|:| |ones| (-1141 (-215))) (|:| |singularities| (-1141 (-215))))) (-5 *1 (-109))))) 
-(-13 (-1090) (-10 -7 (-15 -1967 ((-634 (-1161)))) (-15 -4195 ((-2 (|:| |zeros| (-1141 (-215))) (|:| |ones| (-1141 (-215))) (|:| |singularities| (-1141 (-215)))) (-1161))) (-6 -4519))) 
-((-2367 (($ (-634 |#2|)) 11))) 
-(((-110 |#1| |#2|) (-10 -8 (-15 -2367 (|#1| (-634 |#2|)))) (-111 |#2|) (-1195)) (T -110)) 
-NIL 
-(-10 -8 (-15 -2367 (|#1| (-634 |#2|)))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2510 (((-121) $ (-763)) 8)) (-2671 (($) 7 T CONST)) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) 9)) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35)) (-2166 (((-121) $ (-763)) 10)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-1890 ((|#1| $) 36)) (-4450 (($ |#1| $) 37)) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-1315 ((|#1| $) 38)) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-2367 (($ (-634 |#1|)) 39)) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-2449 (*1 *2 *1 *1) (-12 (-4 *1 (-105)) (-5 *2 (-121)))) (-1719 (*1 *2 *1 *1) (-12 (-4 *1 (-105)) (-5 *2 (-121))))) 
+(-13 (-10 -8 (-15 -1719 ((-121) $ $)) (-15 -2449 ((-121) $ $)))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2852 ((|#1| $) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-3370 ((|#1| $ |#1|) 13 (|has| $ (-6 -4522)))) (-3892 (($ $ $) NIL (|has| $ (-6 -4522)))) (-2458 (($ $ $) NIL (|has| $ (-6 -4522)))) (-2750 (($ $ (-634 |#1|)) 15)) (-2438 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4522))) (($ $ "left" $) NIL (|has| $ (-6 -4522))) (($ $ "right" $) NIL (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) NIL (|has| $ (-6 -4522)))) (-4490 (($) NIL T CONST)) (-3286 (($ $) 11)) (-3317 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-3534 (((-634 $) $) NIL)) (-3606 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-4455 (($ $ |#1| $) 17)) (-3791 (((-121) $ (-763)) NIL)) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-2624 ((|#1| $ (-1 |#1| |#1| |#1|)) 25) (($ $ $ (-1 |#1| |#1| |#1| |#1| |#1|)) 30)) (-2957 (($ $ |#1| (-1 |#1| |#1| |#1|)) 31) (($ $ |#1| (-1 (-634 |#1|) |#1| |#1| |#1|)) 35)) (-2253 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-3030 (($ $) 10)) (-4081 (((-634 |#1|) $) NIL)) (-3319 (((-121) $) 12)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) 9)) (-1990 (($) 16)) (-2781 ((|#1| $ "value") NIL) (($ $ "left") NIL) (($ $ "right") NIL)) (-1665 (((-568) $ $) NIL)) (-2763 (((-121) $) NIL)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) NIL)) (-2747 (((-850) $) NIL (|has| |#1| (-1090)))) (-3180 (((-634 $) $) NIL)) (-3873 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3123 (($ (-763) |#1|) 19)) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-106 |#1|) (-13 (-134 |#1|) (-10 -8 (-6 -4521) (-6 -4522) (-15 -3123 ($ (-763) |#1|)) (-15 -2750 ($ $ (-634 |#1|))) (-15 -2624 (|#1| $ (-1 |#1| |#1| |#1|))) (-15 -2624 ($ $ $ (-1 |#1| |#1| |#1| |#1| |#1|))) (-15 -2957 ($ $ |#1| (-1 |#1| |#1| |#1|))) (-15 -2957 ($ $ |#1| (-1 (-634 |#1|) |#1| |#1| |#1|))))) (-1090)) (T -106)) 
+((-3123 (*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *1 (-106 *3)) (-4 *3 (-1090)))) (-2750 (*1 *1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-106 *3)))) (-2624 (*1 *2 *1 *3) (-12 (-5 *3 (-1 *2 *2 *2)) (-5 *1 (-106 *2)) (-4 *2 (-1090)))) (-2624 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3 *3 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-106 *3)))) (-2957 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1090)) (-5 *1 (-106 *2)))) (-2957 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-1 (-634 *2) *2 *2 *2)) (-4 *2 (-1090)) (-5 *1 (-106 *2))))) 
+(-13 (-134 |#1|) (-10 -8 (-6 -4521) (-6 -4522) (-15 -3123 ($ (-763) |#1|)) (-15 -2750 ($ $ (-634 |#1|))) (-15 -2624 (|#1| $ (-1 |#1| |#1| |#1|))) (-15 -2624 ($ $ $ (-1 |#1| |#1| |#1| |#1| |#1|))) (-15 -2957 ($ $ |#1| (-1 |#1| |#1| |#1|))) (-15 -2957 ($ $ |#1| (-1 (-634 |#1|) |#1| |#1| |#1|))))) 
+((-3365 (((-1 (-634 |#1|) |#1|) (-634 |#1|) (-634 |#1|) (-634 |#1|)) 20)) (-3071 (((-1 (-634 |#1|) |#1|) (-634 |#1|) (-634 |#1|)) 17)) (-3048 (((-1 (-634 |#1|) |#1|) (-634 |#1|) (-634 |#1|) (-634 |#1|) (-634 |#1|)) 21))) 
+(((-107 |#1|) (-10 -7 (-15 -3071 ((-1 (-634 |#1|) |#1|) (-634 |#1|) (-634 |#1|))) (-15 -3365 ((-1 (-634 |#1|) |#1|) (-634 |#1|) (-634 |#1|) (-634 |#1|))) (-15 -3048 ((-1 (-634 |#1|) |#1|) (-634 |#1|) (-634 |#1|) (-634 |#1|) (-634 |#1|)))) (-1047)) (T -107)) 
+((-3048 (*1 *2 *3 *3 *3 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-1 (-634 *4) *4)) (-5 *1 (-107 *4)) (-5 *3 (-634 *4)))) (-3365 (*1 *2 *3 *3 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-1 (-634 *4) *4)) (-5 *1 (-107 *4)) (-5 *3 (-634 *4)))) (-3071 (*1 *2 *3 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-1 (-634 *4) *4)) (-5 *1 (-107 *4)) (-5 *3 (-634 *4))))) 
+(-10 -7 (-15 -3071 ((-1 (-634 |#1|) |#1|) (-634 |#1|) (-634 |#1|))) (-15 -3365 ((-1 (-634 |#1|) |#1|) (-634 |#1|) (-634 |#1|) (-634 |#1|))) (-15 -3048 ((-1 (-634 |#1|) |#1|) (-634 |#1|) (-634 |#1|) (-634 |#1|) (-634 |#1|)))) 
+((-4128 ((|#3| |#2| |#2|) 28)) (-3693 ((|#1| |#2| |#2|) 36 (|has| |#1| (-6 (-4523 "*"))))) (-3757 ((|#3| |#2| |#2|) 29)) (-1590 ((|#1| |#2|) 40 (|has| |#1| (-6 (-4523 "*")))))) 
+(((-108 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -4128 (|#3| |#2| |#2|)) (-15 -3757 (|#3| |#2| |#2|)) (IF (|has| |#1| (-6 (-4523 "*"))) (PROGN (-15 -3693 (|#1| |#2| |#2|)) (-15 -1590 (|#1| |#2|))) |noBranch|)) (-1047) (-1219 |#1|) (-677 |#1| |#4| |#5|) (-375 |#1|) (-375 |#1|)) (T -108)) 
+((-1590 (*1 *2 *3) (-12 (|has| *2 (-6 (-4523 "*"))) (-4 *5 (-375 *2)) (-4 *6 (-375 *2)) (-4 *2 (-1047)) (-5 *1 (-108 *2 *3 *4 *5 *6)) (-4 *3 (-1219 *2)) (-4 *4 (-677 *2 *5 *6)))) (-3693 (*1 *2 *3 *3) (-12 (|has| *2 (-6 (-4523 "*"))) (-4 *5 (-375 *2)) (-4 *6 (-375 *2)) (-4 *2 (-1047)) (-5 *1 (-108 *2 *3 *4 *5 *6)) (-4 *3 (-1219 *2)) (-4 *4 (-677 *2 *5 *6)))) (-3757 (*1 *2 *3 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-677 *4 *5 *6)) (-5 *1 (-108 *4 *3 *2 *5 *6)) (-4 *3 (-1219 *4)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)))) (-4128 (*1 *2 *3 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-677 *4 *5 *6)) (-5 *1 (-108 *4 *3 *2 *5 *6)) (-4 *3 (-1219 *4)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4))))) 
+(-10 -7 (-15 -4128 (|#3| |#2| |#2|)) (-15 -3757 (|#3| |#2| |#2|)) (IF (|has| |#1| (-6 (-4523 "*"))) (PROGN (-15 -3693 (|#1| |#2| |#2|)) (-15 -1590 (|#1| |#2|))) |noBranch|)) 
+((-2449 (((-121) $ $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-4353 (((-634 (-1161))) 32)) (-4059 (((-2 (|:| |zeros| (-1141 (-215))) (|:| |ones| (-1141 (-215))) (|:| |singularities| (-1141 (-215)))) (-1161)) 35)) (-1719 (((-121) $ $) NIL))) 
+(((-109) (-13 (-1090) (-10 -7 (-15 -4353 ((-634 (-1161)))) (-15 -4059 ((-2 (|:| |zeros| (-1141 (-215))) (|:| |ones| (-1141 (-215))) (|:| |singularities| (-1141 (-215)))) (-1161))) (-6 -4521)))) (T -109)) 
+((-4353 (*1 *2) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-109)))) (-4059 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-2 (|:| |zeros| (-1141 (-215))) (|:| |ones| (-1141 (-215))) (|:| |singularities| (-1141 (-215))))) (-5 *1 (-109))))) 
+(-13 (-1090) (-10 -7 (-15 -4353 ((-634 (-1161)))) (-15 -4059 ((-2 (|:| |zeros| (-1141 (-215))) (|:| |ones| (-1141 (-215))) (|:| |singularities| (-1141 (-215)))) (-1161))) (-6 -4521))) 
+((-4074 (($ (-634 |#2|)) 11))) 
+(((-110 |#1| |#2|) (-10 -8 (-15 -4074 (|#1| (-634 |#2|)))) (-111 |#2|) (-1195)) (T -110)) 
+NIL 
+(-10 -8 (-15 -4074 (|#1| (-634 |#2|)))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-1667 (((-121) $ (-763)) 8)) (-4490 (($) 7 T CONST)) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) 9)) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35)) (-3796 (((-121) $ (-763)) 10)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-2580 ((|#1| $) 36)) (-1708 (($ |#1| $) 37)) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3403 ((|#1| $) 38)) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-4074 (($ (-634 |#1|)) 39)) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-111 |#1|) (-1275) (-1195)) (T -111)) 
-((-2367 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-4 *1 (-111 *3)))) (-1315 (*1 *2 *1) (-12 (-4 *1 (-111 *2)) (-4 *2 (-1195)))) (-4450 (*1 *1 *2 *1) (-12 (-4 *1 (-111 *2)) (-4 *2 (-1195)))) (-1890 (*1 *2 *1) (-12 (-4 *1 (-111 *2)) (-4 *2 (-1195))))) 
-(-13 (-499 |t#1|) (-10 -8 (-6 -4520) (-15 -2367 ($ (-634 |t#1|))) (-15 -1315 (|t#1| $)) (-15 -4450 ($ |t#1| $)) (-15 -1890 (|t#1| $)))) 
+((-4074 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-4 *1 (-111 *3)))) (-3403 (*1 *2 *1) (-12 (-4 *1 (-111 *2)) (-4 *2 (-1195)))) (-1708 (*1 *1 *2 *1) (-12 (-4 *1 (-111 *2)) (-4 *2 (-1195)))) (-2580 (*1 *2 *1) (-12 (-4 *1 (-111 *2)) (-4 *2 (-1195))))) 
+(-13 (-499 |t#1|) (-10 -8 (-6 -4522) (-15 -4074 ($ (-634 |t#1|))) (-15 -3403 (|t#1| $)) (-15 -1708 ($ |t#1| $)) (-15 -2580 (|t#1| $)))) 
 (((-39) . T) ((-105) |has| |#1| (-1090)) ((-608 (-850)) |has| |#1| (-1090)) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-1090) |has| |#1| (-1090)) ((-1195) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-1492 (((-568) $) NIL (|has| (-568) (-301)))) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-1497 (((-121) $ $) NIL)) (-3662 (((-568) $) NIL (|has| (-568) (-815)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) NIL) (((-3 (-1161) "failed") $) NIL (|has| (-568) (-1037 (-1161)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| (-568) (-1037 (-568)))) (((-3 (-568) "failed") $) NIL (|has| (-568) (-1037 (-568))))) (-2854 (((-568) $) NIL) (((-1161) $) NIL (|has| (-568) (-1037 (-1161)))) (((-409 (-568)) $) NIL (|has| (-568) (-1037 (-568)))) (((-568) $) NIL (|has| (-568) (-1037 (-568))))) (-2401 (($ $ $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| (-568) (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| (-568) (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-679 (-568)) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1731 (($) NIL (|has| (-568) (-550)))) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-2033 (((-121) $) NIL (|has| (-568) (-815)))) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| (-568) (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| (-568) (-881 (-381))))) (-2735 (((-121) $) NIL)) (-1332 (($ $) NIL)) (-2317 (((-568) $) NIL)) (-3038 (((-3 $ "failed") $) NIL (|has| (-568) (-1136)))) (-2245 (((-121) $) NIL (|has| (-568) (-815)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2521 (($ $ $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (|has| (-568) (-842)))) (-2795 (($ (-1 (-568) (-568)) $) NIL)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4434 (($) NIL (|has| (-568) (-1136)) CONST)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3880 (($ $) NIL (|has| (-568) (-301))) (((-409 (-568)) $) NIL)) (-1519 (((-568) $) NIL (|has| (-568) (-550)))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-3848 (((-420 $) $) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1339 (($ $ (-634 (-568)) (-634 (-568))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-568) (-568)) NIL (|has| (-568) (-303 (-568)))) (($ $ (-288 (-568))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-634 (-288 (-568)))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-634 (-1161)) (-634 (-568))) NIL (|has| (-568) (-523 (-1161) (-568)))) (($ $ (-1161) (-568)) NIL (|has| (-568) (-523 (-1161) (-568))))) (-2709 (((-763) $) NIL)) (-2779 (($ $ (-568)) NIL (|has| (-568) (-281 (-568) (-568))))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-4189 (($ $) NIL (|has| (-568) (-225))) (($ $ (-763)) NIL (|has| (-568) (-225))) (($ $ (-1161)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1 (-568) (-568)) (-763)) NIL) (($ $ (-1 (-568) (-568))) NIL)) (-3013 (($ $) NIL)) (-2324 (((-568) $) NIL)) (-4278 (((-887 (-568)) $) NIL (|has| (-568) (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| (-568) (-609 (-887 (-381))))) (((-541) $) NIL (|has| (-568) (-609 (-541)))) (((-381) $) NIL (|has| (-568) (-1021))) (((-215) $) NIL (|has| (-568) (-1021)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| (-568) (-904))))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) 7) (($ (-568)) NIL) (($ (-1161)) NIL (|has| (-568) (-1037 (-1161)))) (((-409 (-568)) $) NIL) (((-1004 2) $) 9)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| (-568) (-904))) (|has| (-568) (-148))))) (-4078 (((-763)) NIL)) (-2285 (((-568) $) NIL (|has| (-568) (-550)))) (-2494 (($ (-409 (-568))) 8)) (-1826 (((-121) $ $) NIL)) (-2897 (($ $) NIL (|has| (-568) (-815)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $) NIL (|has| (-568) (-225))) (($ $ (-763)) NIL (|has| (-568) (-225))) (($ $ (-1161)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1 (-568) (-568)) (-763)) NIL) (($ $ (-1 (-568) (-568))) NIL)) (-1751 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1738 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1732 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1779 (($ $ $) NIL) (($ (-568) (-568)) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ (-568) $) NIL) (($ $ (-568)) NIL))) 
-(((-112) (-13 (-993 (-568)) (-10 -8 (-15 -2745 ((-409 (-568)) $)) (-15 -2745 ((-1004 2) $)) (-15 -3880 ((-409 (-568)) $)) (-15 -2494 ($ (-409 (-568))))))) (T -112)) 
-((-2745 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-112)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-1004 2)) (-5 *1 (-112)))) (-3880 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-112)))) (-2494 (*1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-112))))) 
-(-13 (-993 (-568)) (-10 -8 (-15 -2745 ((-409 (-568)) $)) (-15 -2745 ((-1004 2) $)) (-15 -3880 ((-409 (-568)) $)) (-15 -2494 ($ (-409 (-568)))))) 
-((-2447 (((-121) $ $) NIL)) (-1705 (((-1108) $ (-1108)) 23)) (-2511 (($ $ (-1143)) 17)) (-3861 (((-3 (-1108) "failed") $) 22)) (-3327 (((-1108) $) 20)) (-4031 (((-1108) $ (-1108)) 25)) (-2764 (((-1108) $) 24)) (-1798 (($ (-390)) NIL) (($ (-390) (-1143)) 16)) (-3391 (((-390) $) NIL)) (-4487 (((-1143) $) NIL)) (-3305 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-4169 (((-1249) $) NIL)) (-2745 (((-850) $) NIL)) (-3637 (($ $) 18)) (-1717 (((-121) $ $) NIL))) 
-(((-113) (-13 (-366 (-390) (-1108)) (-10 -8 (-15 -3861 ((-3 (-1108) "failed") $)) (-15 -2764 ((-1108) $)) (-15 -4031 ((-1108) $ (-1108)))))) (T -113)) 
-((-3861 (*1 *2 *1) (|partial| -12 (-5 *2 (-1108)) (-5 *1 (-113)))) (-2764 (*1 *2 *1) (-12 (-5 *2 (-1108)) (-5 *1 (-113)))) (-4031 (*1 *2 *1 *2) (-12 (-5 *2 (-1108)) (-5 *1 (-113))))) 
-(-13 (-366 (-390) (-1108)) (-10 -8 (-15 -3861 ((-3 (-1108) "failed") $)) (-15 -2764 ((-1108) $)) (-15 -4031 ((-1108) $ (-1108))))) 
-((-2447 (((-121) $ $) NIL)) (-1611 (($ $) NIL)) (-3091 (($ $ $) NIL)) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-2016 (((-121) $) NIL (|has| (-121) (-842))) (((-121) (-1 (-121) (-121) (-121)) $) NIL)) (-3908 (($ $) NIL (-12 (|has| $ (-6 -4520)) (|has| (-121) (-842)))) (($ (-1 (-121) (-121) (-121)) $) NIL (|has| $ (-6 -4520)))) (-3644 (($ $) NIL (|has| (-121) (-842))) (($ (-1 (-121) (-121) (-121)) $) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-2436 (((-121) $ (-1210 (-568)) (-121)) NIL (|has| $ (-6 -4520))) (((-121) $ (-568) (-121)) NIL (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4519)))) (-2671 (($) NIL T CONST)) (-1578 (($ $) NIL (|has| $ (-6 -4520)))) (-3943 (($ $) NIL)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-121) (-1090))))) (-4328 (($ (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4519))) (($ (-121) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-121) (-1090))))) (-3092 (((-121) (-1 (-121) (-121) (-121)) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) (-121) (-121)) $ (-121)) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) (-121) (-121)) $ (-121) (-121)) NIL (-12 (|has| $ (-6 -4519)) (|has| (-121) (-1090))))) (-3989 (((-121) $ (-568) (-121)) NIL (|has| $ (-6 -4520)))) (-2602 (((-121) $ (-568)) NIL)) (-2764 (((-568) (-121) $ (-568)) NIL (|has| (-121) (-1090))) (((-568) (-121) $) NIL (|has| (-121) (-1090))) (((-568) (-1 (-121) (-121)) $) NIL)) (-4360 (((-634 (-121)) $) NIL (|has| $ (-6 -4519)))) (-3104 (($ $ $) NIL)) (-3044 (($ $) NIL)) (-2460 (($ $ $) NIL)) (-1849 (($ (-763) (-121)) 8)) (-3339 (($ $ $) NIL)) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) NIL (|has| (-568) (-842)))) (-2521 (($ $ $) NIL)) (-1347 (($ $ $) NIL (|has| (-121) (-842))) (($ (-1 (-121) (-121) (-121)) $ $) NIL)) (-1979 (((-634 (-121)) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) (-121) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-121) (-1090))))) (-2223 (((-568) $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL)) (-3674 (($ (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-121) (-121) (-121)) $ $) NIL) (($ (-1 (-121) (-121)) $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL)) (-4122 (($ $ $ (-568)) NIL) (($ (-121) $ (-568)) NIL)) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4022 (((-1108) $) NIL)) (-3876 (((-121) $) NIL (|has| (-568) (-842)))) (-3775 (((-3 (-121) "failed") (-1 (-121) (-121)) $) NIL)) (-3724 (($ $ (-121)) NIL (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-121)) (-634 (-121))) NIL (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090)))) (($ $ (-121) (-121)) NIL (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090)))) (($ $ (-288 (-121))) NIL (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090)))) (($ $ (-634 (-288 (-121)))) NIL (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) (-121) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-121) (-1090))))) (-2041 (((-634 (-121)) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 (($ $ (-1210 (-568))) NIL) (((-121) $ (-568)) NIL) (((-121) $ (-568) (-121)) NIL)) (-2826 (($ $ (-1210 (-568))) NIL) (($ $ (-568)) NIL)) (-4168 (((-763) (-121) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-121) (-1090)))) (((-763) (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4519)))) (-2256 (($ $ $ (-568)) NIL (|has| $ (-6 -4520)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| (-121) (-609 (-541))))) (-4287 (($ (-634 (-121))) NIL)) (-2768 (($ (-634 $)) NIL) (($ $ $) NIL) (($ (-121) $) NIL) (($ $ (-121)) NIL)) (-2745 (((-850) $) NIL)) (-4042 (($ (-763) (-121)) 9)) (-1319 (((-121) (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4519)))) (-2139 (($ $ $) NIL)) (-1887 (($ $) NIL)) (-2430 (($ $ $) NIL)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) NIL)) (-2424 (($ $ $) NIL)) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-114) (-13 (-132) (-10 -8 (-15 -4042 ($ (-763) (-121)))))) (T -114)) 
-((-4042 (*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *3 (-121)) (-5 *1 (-114))))) 
-(-13 (-132) (-10 -8 (-15 -4042 ($ (-763) (-121))))) 
-((-4427 (((-958 (-215)) (-1108) (-958 (-215)) (-1108) (-958 (-215)) (-1108)) 13)) (-1401 (((-215) (-169 (-215))) 8)) (-3398 (((-958 (-215)) (-1108) (-215) (-958 (-215)) (-1108) (-958 (-215)) (-1108)) 12)) (-3658 (((-215) (-1108) (-958 (-215)) (-1108)) 11))) 
-(((-115) (-10 -7 (-15 -1401 ((-215) (-169 (-215)))) (-15 -3658 ((-215) (-1108) (-958 (-215)) (-1108))) (-15 -3398 ((-958 (-215)) (-1108) (-215) (-958 (-215)) (-1108) (-958 (-215)) (-1108))) (-15 -4427 ((-958 (-215)) (-1108) (-958 (-215)) (-1108) (-958 (-215)) (-1108))))) (T -115)) 
-((-4427 (*1 *2 *3 *2 *3 *2 *3) (-12 (-5 *2 (-958 (-215))) (-5 *3 (-1108)) (-5 *1 (-115)))) (-3398 (*1 *2 *3 *4 *2 *3 *2 *3) (-12 (-5 *2 (-958 (-215))) (-5 *3 (-1108)) (-5 *4 (-215)) (-5 *1 (-115)))) (-3658 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-1108)) (-5 *4 (-958 (-215))) (-5 *2 (-215)) (-5 *1 (-115)))) (-1401 (*1 *2 *3) (-12 (-5 *3 (-169 (-215))) (-5 *2 (-215)) (-5 *1 (-115))))) 
-(-10 -7 (-15 -1401 ((-215) (-169 (-215)))) (-15 -3658 ((-215) (-1108) (-958 (-215)) (-1108))) (-15 -3398 ((-958 (-215)) (-1108) (-215) (-958 (-215)) (-1108) (-958 (-215)) (-1108))) (-15 -4427 ((-958 (-215)) (-1108) (-958 (-215)) (-1108) (-958 (-215)) (-1108)))) 
-((-2447 (((-121) $ $) NIL)) (-2219 (((-3 "left" "center" "right" "vertical" "horizontal") $) 17)) (-2259 (((-568) $) 14)) (-2458 (((-568) $) 15)) (-2655 (((-568) $) 16)) (-4487 (((-1143) $) NIL)) (-4288 (((-121) $) 8)) (-4022 (((-1108) $) NIL)) (-4486 (((-568) $) 12)) (-1485 (($ (-568) (-568) (-568) (-568) (-568) (-121) (-3 "left" "center" "right" "vertical" "horizontal")) 11)) (-2745 (((-850) $) 19) (($ (-634 (-568))) NIL)) (-2456 (((-568) $) 13)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2563 (((-568) $) NIL (|has| (-568) (-301)))) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-2589 (((-121) $ $) NIL)) (-3337 (((-568) $) NIL (|has| (-568) (-815)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) NIL) (((-3 (-1161) "failed") $) NIL (|has| (-568) (-1037 (-1161)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| (-568) (-1037 (-568)))) (((-3 (-568) "failed") $) NIL (|has| (-568) (-1037 (-568))))) (-2857 (((-568) $) NIL) (((-1161) $) NIL (|has| (-568) (-1037 (-1161)))) (((-409 (-568)) $) NIL (|has| (-568) (-1037 (-568)))) (((-568) $) NIL (|has| (-568) (-1037 (-568))))) (-2403 (($ $ $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| (-568) (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| (-568) (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-679 (-568)) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1733 (($) NIL (|has| (-568) (-550)))) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-1436 (((-121) $) NIL (|has| (-568) (-815)))) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| (-568) (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| (-568) (-881 (-381))))) (-1598 (((-121) $) NIL)) (-3539 (($ $) NIL)) (-2319 (((-568) $) NIL)) (-2214 (((-3 $ "failed") $) NIL (|has| (-568) (-1136)))) (-2859 (((-121) $) NIL (|has| (-568) (-815)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1732 (($ $ $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (|has| (-568) (-842)))) (-2797 (($ (-1 (-568) (-568)) $) NIL)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4436 (($) NIL (|has| (-568) (-1136)) CONST)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1999 (($ $) NIL (|has| (-568) (-301))) (((-409 (-568)) $) NIL)) (-4115 (((-568) $) NIL (|has| (-568) (-550)))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-3850 (((-420 $) $) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1339 (($ $ (-634 (-568)) (-634 (-568))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-568) (-568)) NIL (|has| (-568) (-303 (-568)))) (($ $ (-288 (-568))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-634 (-288 (-568)))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-634 (-1161)) (-634 (-568))) NIL (|has| (-568) (-523 (-1161) (-568)))) (($ $ (-1161) (-568)) NIL (|has| (-568) (-523 (-1161) (-568))))) (-1466 (((-763) $) NIL)) (-2781 (($ $ (-568)) NIL (|has| (-568) (-281 (-568) (-568))))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-4191 (($ $) NIL (|has| (-568) (-225))) (($ $ (-763)) NIL (|has| (-568) (-225))) (($ $ (-1161)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1 (-568) (-568)) (-763)) NIL) (($ $ (-1 (-568) (-568))) NIL)) (-3210 (($ $) NIL)) (-2326 (((-568) $) NIL)) (-4280 (((-887 (-568)) $) NIL (|has| (-568) (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| (-568) (-609 (-887 (-381))))) (((-541) $) NIL (|has| (-568) (-609 (-541)))) (((-381) $) NIL (|has| (-568) (-1021))) (((-215) $) NIL (|has| (-568) (-1021)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| (-568) (-904))))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) 7) (($ (-568)) NIL) (($ (-1161)) NIL (|has| (-568) (-1037 (-1161)))) (((-409 (-568)) $) NIL) (((-1004 2) $) 9)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| (-568) (-904))) (|has| (-568) (-148))))) (-3425 (((-763)) NIL)) (-3520 (((-568) $) NIL (|has| (-568) (-550)))) (-2735 (($ (-409 (-568))) 8)) (-2273 (((-121) $ $) NIL)) (-2811 (($ $) NIL (|has| (-568) (-815)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $) NIL (|has| (-568) (-225))) (($ $ (-763)) NIL (|has| (-568) (-225))) (($ $ (-1161)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1 (-568) (-568)) (-763)) NIL) (($ $ (-1 (-568) (-568))) NIL)) (-1753 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1740 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1734 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1781 (($ $ $) NIL) (($ (-568) (-568)) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ (-568) $) NIL) (($ $ (-568)) NIL))) 
+(((-112) (-13 (-993 (-568)) (-10 -8 (-15 -2747 ((-409 (-568)) $)) (-15 -2747 ((-1004 2) $)) (-15 -1999 ((-409 (-568)) $)) (-15 -2735 ($ (-409 (-568))))))) (T -112)) 
+((-2747 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-112)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-1004 2)) (-5 *1 (-112)))) (-1999 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-112)))) (-2735 (*1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-112))))) 
+(-13 (-993 (-568)) (-10 -8 (-15 -2747 ((-409 (-568)) $)) (-15 -2747 ((-1004 2) $)) (-15 -1999 ((-409 (-568)) $)) (-15 -2735 ($ (-409 (-568)))))) 
+((-2449 (((-121) $ $) NIL)) (-3637 (((-1108) $ (-1108)) 23)) (-1672 (($ $ (-1143)) 17)) (-1933 (((-3 (-1108) "failed") $) 22)) (-4379 (((-1108) $) 20)) (-1483 (((-1108) $ (-1108)) 25)) (-2766 (((-1108) $) 24)) (-2133 (($ (-390)) NIL) (($ (-390) (-1143)) 16)) (-3393 (((-390) $) NIL)) (-1893 (((-1143) $) NIL)) (-4249 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-3919 (((-1249) $) NIL)) (-2747 (((-850) $) NIL)) (-3171 (($ $) 18)) (-1719 (((-121) $ $) NIL))) 
+(((-113) (-13 (-366 (-390) (-1108)) (-10 -8 (-15 -1933 ((-3 (-1108) "failed") $)) (-15 -2766 ((-1108) $)) (-15 -1483 ((-1108) $ (-1108)))))) (T -113)) 
+((-1933 (*1 *2 *1) (|partial| -12 (-5 *2 (-1108)) (-5 *1 (-113)))) (-2766 (*1 *2 *1) (-12 (-5 *2 (-1108)) (-5 *1 (-113)))) (-1483 (*1 *2 *1 *2) (-12 (-5 *2 (-1108)) (-5 *1 (-113))))) 
+(-13 (-366 (-390) (-1108)) (-10 -8 (-15 -1933 ((-3 (-1108) "failed") $)) (-15 -2766 ((-1108) $)) (-15 -1483 ((-1108) $ (-1108))))) 
+((-2449 (((-121) $ $) NIL)) (-1613 (($ $) NIL)) (-3093 (($ $ $) NIL)) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-1324 (((-121) $) NIL (|has| (-121) (-842))) (((-121) (-1 (-121) (-121) (-121)) $) NIL)) (-2109 (($ $) NIL (-12 (|has| $ (-6 -4522)) (|has| (-121) (-842)))) (($ (-1 (-121) (-121) (-121)) $) NIL (|has| $ (-6 -4522)))) (-3647 (($ $) NIL (|has| (-121) (-842))) (($ (-1 (-121) (-121) (-121)) $) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-2438 (((-121) $ (-1210 (-568)) (-121)) NIL (|has| $ (-6 -4522))) (((-121) $ (-568) (-121)) NIL (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4521)))) (-4490 (($) NIL T CONST)) (-4452 (($ $) NIL (|has| $ (-6 -4522)))) (-3945 (($ $) NIL)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-121) (-1090))))) (-4330 (($ (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4521))) (($ (-121) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-121) (-1090))))) (-3094 (((-121) (-1 (-121) (-121) (-121)) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) (-121) (-121)) $ (-121)) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) (-121) (-121)) $ (-121) (-121)) NIL (-12 (|has| $ (-6 -4521)) (|has| (-121) (-1090))))) (-1292 (((-121) $ (-568) (-121)) NIL (|has| $ (-6 -4522)))) (-2069 (((-121) $ (-568)) NIL)) (-2766 (((-568) (-121) $ (-568)) NIL (|has| (-121) (-1090))) (((-568) (-121) $) NIL (|has| (-121) (-1090))) (((-568) (-1 (-121) (-121)) $) NIL)) (-3317 (((-634 (-121)) $) NIL (|has| $ (-6 -4521)))) (-3107 (($ $ $) NIL)) (-3046 (($ $) NIL)) (-2570 (($ $ $) NIL)) (-1851 (($ (-763) (-121)) 8)) (-4445 (($ $ $) NIL)) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) NIL (|has| (-568) (-842)))) (-1732 (($ $ $) NIL)) (-3645 (($ $ $) NIL (|has| (-121) (-842))) (($ (-1 (-121) (-121) (-121)) $ $) NIL)) (-4406 (((-634 (-121)) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) (-121) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-121) (-1090))))) (-3631 (((-568) $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL)) (-2253 (($ (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-121) (-121) (-121)) $ $) NIL) (($ (-1 (-121) (-121)) $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL)) (-4124 (($ $ $ (-568)) NIL) (($ (-121) $ (-568)) NIL)) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4025 (((-1108) $) NIL)) (-3877 (((-121) $) NIL (|has| (-568) (-842)))) (-2712 (((-3 (-121) "failed") (-1 (-121) (-121)) $) NIL)) (-2490 (($ $ (-121)) NIL (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-121)) (-634 (-121))) NIL (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090)))) (($ $ (-121) (-121)) NIL (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090)))) (($ $ (-288 (-121))) NIL (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090)))) (($ $ (-634 (-288 (-121)))) NIL (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) (-121) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-121) (-1090))))) (-1480 (((-634 (-121)) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 (($ $ (-1210 (-568))) NIL) (((-121) $ (-568)) NIL) (((-121) $ (-568) (-121)) NIL)) (-2828 (($ $ (-1210 (-568))) NIL) (($ $ (-568)) NIL)) (-4170 (((-763) (-121) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-121) (-1090)))) (((-763) (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4521)))) (-3306 (($ $ $ (-568)) NIL (|has| $ (-6 -4522)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| (-121) (-609 (-541))))) (-4289 (($ (-634 (-121))) NIL)) (-2770 (($ (-634 $)) NIL) (($ $ $) NIL) (($ (-121) $) NIL) (($ $ (-121)) NIL)) (-2747 (((-850) $) NIL)) (-1540 (($ (-763) (-121)) 9)) (-3437 (((-121) (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4521)))) (-2141 (($ $ $) NIL)) (-1889 (($ $) NIL)) (-2432 (($ $ $) NIL)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) NIL)) (-2426 (($ $ $) NIL)) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-114) (-13 (-132) (-10 -8 (-15 -1540 ($ (-763) (-121)))))) (T -114)) 
+((-1540 (*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *3 (-121)) (-5 *1 (-114))))) 
+(-13 (-132) (-10 -8 (-15 -1540 ($ (-763) (-121))))) 
+((-1602 (((-958 (-215)) (-1108) (-958 (-215)) (-1108) (-958 (-215)) (-1108)) 13)) (-2089 (((-215) (-169 (-215))) 8)) (-1523 (((-958 (-215)) (-1108) (-215) (-958 (-215)) (-1108) (-958 (-215)) (-1108)) 12)) (-3307 (((-215) (-1108) (-958 (-215)) (-1108)) 11))) 
+(((-115) (-10 -7 (-15 -2089 ((-215) (-169 (-215)))) (-15 -3307 ((-215) (-1108) (-958 (-215)) (-1108))) (-15 -1523 ((-958 (-215)) (-1108) (-215) (-958 (-215)) (-1108) (-958 (-215)) (-1108))) (-15 -1602 ((-958 (-215)) (-1108) (-958 (-215)) (-1108) (-958 (-215)) (-1108))))) (T -115)) 
+((-1602 (*1 *2 *3 *2 *3 *2 *3) (-12 (-5 *2 (-958 (-215))) (-5 *3 (-1108)) (-5 *1 (-115)))) (-1523 (*1 *2 *3 *4 *2 *3 *2 *3) (-12 (-5 *2 (-958 (-215))) (-5 *3 (-1108)) (-5 *4 (-215)) (-5 *1 (-115)))) (-3307 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-1108)) (-5 *4 (-958 (-215))) (-5 *2 (-215)) (-5 *1 (-115)))) (-2089 (*1 *2 *3) (-12 (-5 *3 (-169 (-215))) (-5 *2 (-215)) (-5 *1 (-115))))) 
+(-10 -7 (-15 -2089 ((-215) (-169 (-215)))) (-15 -3307 ((-215) (-1108) (-958 (-215)) (-1108))) (-15 -1523 ((-958 (-215)) (-1108) (-215) (-958 (-215)) (-1108) (-958 (-215)) (-1108))) (-15 -1602 ((-958 (-215)) (-1108) (-958 (-215)) (-1108) (-958 (-215)) (-1108)))) 
+((-2449 (((-121) $ $) NIL)) (-2221 (((-3 "left" "center" "right" "vertical" "horizontal") $) 17)) (-3320 (((-568) $) 14)) (-2560 (((-568) $) 15)) (-4404 (((-568) $) 16)) (-1893 (((-1143) $) NIL)) (-2982 (((-121) $) 8)) (-4025 (((-1108) $) NIL)) (-1885 (((-568) $) 12)) (-2528 (($ (-568) (-568) (-568) (-568) (-568) (-121) (-3 "left" "center" "right" "vertical" "horizontal")) 11)) (-2747 (((-850) $) 19) (($ (-634 (-568))) NIL)) (-2550 (((-568) $) 13)) (-1719 (((-121) $ $) NIL))) 
 (((-116) (-13 (-117) (-10 -7 (-6 |HamburgerNoether|)))) (T -116)) 
 NIL 
 (-13 (-117) (-10 -7 (-6 |HamburgerNoether|))) 
-((-2447 (((-121) $ $) 7)) (-2219 (((-3 "left" "center" "right" "vertical" "horizontal") $) 12)) (-2259 (((-568) $) 17)) (-2458 (((-568) $) 15)) (-2655 (((-568) $) 13)) (-4487 (((-1143) $) 9)) (-4288 (((-121) $) 14)) (-4022 (((-1108) $) 10)) (-4486 (((-568) $) 19)) (-1485 (($ (-568) (-568) (-568) (-568) (-568) (-121) (-3 "left" "center" "right" "vertical" "horizontal")) 16)) (-2745 (((-850) $) 11) (($ (-634 (-568))) 20)) (-2456 (((-568) $) 18)) (-1717 (((-121) $ $) 6))) 
+((-2449 (((-121) $ $) 7)) (-2221 (((-3 "left" "center" "right" "vertical" "horizontal") $) 12)) (-3320 (((-568) $) 17)) (-2560 (((-568) $) 15)) (-4404 (((-568) $) 13)) (-1893 (((-1143) $) 9)) (-2982 (((-121) $) 14)) (-4025 (((-1108) $) 10)) (-1885 (((-568) $) 19)) (-2528 (($ (-568) (-568) (-568) (-568) (-568) (-121) (-3 "left" "center" "right" "vertical" "horizontal")) 16)) (-2747 (((-850) $) 11) (($ (-634 (-568))) 20)) (-2550 (((-568) $) 18)) (-1719 (((-121) $ $) 6))) 
 (((-117) (-1275)) (T -117)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-4 *1 (-117)))) (-4486 (*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-568)))) (-2456 (*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-568)))) (-2259 (*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-568)))) (-1485 (*1 *1 *2 *2 *2 *2 *2 *3 *4) (-12 (-5 *2 (-568)) (-5 *3 (-121)) (-5 *4 (-3 "left" "center" "right" "vertical" "horizontal")) (-4 *1 (-117)))) (-2458 (*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-568)))) (-4288 (*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-121)))) (-2655 (*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-568)))) (-2219 (*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-3 "left" "center" "right" "vertical" "horizontal"))))) 
-(-13 (-1090) (-10 -8 (-15 -2745 ($ (-634 (-568)))) (-15 -4486 ((-568) $)) (-15 -2456 ((-568) $)) (-15 -2259 ((-568) $)) (-15 -1485 ($ (-568) (-568) (-568) (-568) (-568) (-121) (-3 "left" "center" "right" "vertical" "horizontal"))) (-15 -2458 ((-568) $)) (-15 -4288 ((-121) $)) (-15 -2655 ((-568) $)) (-15 -2219 ((-3 "left" "center" "right" "vertical" "horizontal") $)))) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-4 *1 (-117)))) (-1885 (*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-568)))) (-2550 (*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-568)))) (-3320 (*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-568)))) (-2528 (*1 *1 *2 *2 *2 *2 *2 *3 *4) (-12 (-5 *2 (-568)) (-5 *3 (-121)) (-5 *4 (-3 "left" "center" "right" "vertical" "horizontal")) (-4 *1 (-117)))) (-2560 (*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-568)))) (-2982 (*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-121)))) (-4404 (*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-568)))) (-2221 (*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-3 "left" "center" "right" "vertical" "horizontal"))))) 
+(-13 (-1090) (-10 -8 (-15 -2747 ($ (-634 (-568)))) (-15 -1885 ((-568) $)) (-15 -2550 ((-568) $)) (-15 -3320 ((-568) $)) (-15 -2528 ($ (-568) (-568) (-568) (-568) (-568) (-121) (-3 "left" "center" "right" "vertical" "horizontal"))) (-15 -2560 ((-568) $)) (-15 -2982 ((-121) $)) (-15 -4404 ((-568) $)) (-15 -2221 ((-3 "left" "center" "right" "vertical" "horizontal") $)))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2219 (((-3 "left" "center" "right" "vertical" "horizontal") $) NIL)) (-2259 (((-568) $) 14)) (-2458 (((-568) $) 11)) (-2655 (((-568) $) 15)) (-4487 (((-1143) $) NIL)) (-4288 (((-121) $) NIL)) (-4022 (((-1108) $) NIL)) (-4486 (((-568) $) 12)) (-1485 (($ (-568) (-568) (-568) (-568) (-568) (-121) (-3 "left" "center" "right" "vertical" "horizontal")) NIL)) (-2745 (((-850) $) 17) (($ (-634 (-568))) 10)) (-2456 (((-568) $) 13)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-2221 (((-3 "left" "center" "right" "vertical" "horizontal") $) NIL)) (-3320 (((-568) $) 14)) (-2560 (((-568) $) 11)) (-4404 (((-568) $) 15)) (-1893 (((-1143) $) NIL)) (-2982 (((-121) $) NIL)) (-4025 (((-1108) $) NIL)) (-1885 (((-568) $) 12)) (-2528 (($ (-568) (-568) (-568) (-568) (-568) (-121) (-3 "left" "center" "right" "vertical" "horizontal")) NIL)) (-2747 (((-850) $) 17) (($ (-634 (-568))) 10)) (-2550 (((-568) $) 13)) (-1719 (((-121) $ $) NIL))) 
 (((-118) (-13 (-117) (-10 -7 (-6 |QuadraticTransform|)))) (T -118)) 
 NIL 
 (-13 (-117) (-10 -7 (-6 |QuadraticTransform|))) 
-((-3107 (((-2 (|:| |mult| (-763)) (|:| |subMult| (-763)) (|:| |blUpRec| (-634 (-2 (|:| |recTransStr| (-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|)) (|:| |recPoint| (-33 |#1|)) (|:| |recChart| |#5|) (|:| |definingExtension| |#1|))))) (-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) (-33 |#1|) |#5| |#1|) 70)) (-1850 (((-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) (-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) (-763) |#5|) 54)) (-3172 (((-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) |#3| |#5|) 99)) (-3409 (((-634 (-634 (-763))) (-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|)) NIL)) (-3640 ((|#3| (-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) |#5|) 105)) (-3886 ((|#3| |#3| |#5|) 107))) 
-(((-119 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3886 (|#3| |#3| |#5|)) (-15 -1850 ((-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) (-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) (-763) |#5|)) (-15 -3107 ((-2 (|:| |mult| (-763)) (|:| |subMult| (-763)) (|:| |blUpRec| (-634 (-2 (|:| |recTransStr| (-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|)) (|:| |recPoint| (-33 |#1|)) (|:| |recChart| |#5|) (|:| |definingExtension| |#1|))))) (-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) (-33 |#1|) |#5| |#1|)) (-15 -3409 ((-634 (-634 (-763))) (-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|))) (-15 -3172 ((-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) |#3| |#5|)) (-15 -3640 (|#3| (-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) |#5|))) (-365) (-634 (-1161)) (-324 |#1| |#4|) (-230 (-1697 |#2|) (-763)) (-117)) (T -119)) 
-((-3640 (*1 *2 *3 *4) (-12 (-5 *3 (-242 (-4287 (QUOTE X) (QUOTE -2926)) *5)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *2 (-324 *5 *7)) (-5 *1 (-119 *5 *6 *2 *7 *4)) (-4 *7 (-230 (-1697 *6) (-763))) (-4 *4 (-117)))) (-3172 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1697 *6) (-763))) (-5 *2 (-242 (-4287 (QUOTE X) (QUOTE -2926)) *5)) (-5 *1 (-119 *5 *6 *3 *7 *4)) (-4 *3 (-324 *5 *7)) (-4 *4 (-117)))) (-3409 (*1 *2 *3) (-12 (-5 *3 (-242 (-4287 (QUOTE X) (QUOTE -2926)) *4)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *7 (-230 (-1697 *5) (-763))) (-5 *2 (-634 (-634 (-763)))) (-5 *1 (-119 *4 *5 *6 *7 *8)) (-4 *6 (-324 *4 *7)) (-4 *8 (-117)))) (-3107 (*1 *2 *3 *4 *5 *6) (-12 (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *9 (-230 (-1697 *7) (-763))) (-5 *2 (-2 (|:| |mult| (-763)) (|:| |subMult| (-763)) (|:| |blUpRec| (-634 (-2 (|:| |recTransStr| (-242 (-4287 (QUOTE X) (QUOTE -2926)) *6)) (|:| |recPoint| (-33 *6)) (|:| |recChart| *5) (|:| |definingExtension| *6)))))) (-5 *1 (-119 *6 *7 *8 *9 *5)) (-5 *3 (-242 (-4287 (QUOTE X) (QUOTE -2926)) *6)) (-5 *4 (-33 *6)) (-4 *8 (-324 *6 *9)) (-4 *5 (-117)))) (-1850 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-242 (-4287 (QUOTE X) (QUOTE -2926)) *5)) (-4 *5 (-365)) (-5 *3 (-763)) (-14 *6 (-634 (-1161))) (-4 *8 (-230 (-1697 *6) *3)) (-5 *1 (-119 *5 *6 *7 *8 *4)) (-4 *7 (-324 *5 *8)) (-4 *4 (-117)))) (-3886 (*1 *2 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-230 (-1697 *5) (-763))) (-5 *1 (-119 *4 *5 *2 *6 *3)) (-4 *2 (-324 *4 *6)) (-4 *3 (-117))))) 
-(-10 -7 (-15 -3886 (|#3| |#3| |#5|)) (-15 -1850 ((-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) (-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) (-763) |#5|)) (-15 -3107 ((-2 (|:| |mult| (-763)) (|:| |subMult| (-763)) (|:| |blUpRec| (-634 (-2 (|:| |recTransStr| (-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|)) (|:| |recPoint| (-33 |#1|)) (|:| |recChart| |#5|) (|:| |definingExtension| |#1|))))) (-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) (-33 |#1|) |#5| |#1|)) (-15 -3409 ((-634 (-634 (-763))) (-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|))) (-15 -3172 ((-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) |#3| |#5|)) (-15 -3640 (|#3| (-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) |#5|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-3056 (($) 17 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ |#1| $) 22) (($ $ |#2|) 24))) 
+((-2541 (((-2 (|:| |mult| (-763)) (|:| |subMult| (-763)) (|:| |blUpRec| (-634 (-2 (|:| |recTransStr| (-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|)) (|:| |recPoint| (-33 |#1|)) (|:| |recChart| |#5|) (|:| |definingExtension| |#1|))))) (-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) (-33 |#1|) |#5| |#1|) 70)) (-2393 (((-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) (-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) (-763) |#5|) 54)) (-1705 (((-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) |#3| |#5|) 99)) (-1587 (((-634 (-634 (-763))) (-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|)) NIL)) (-3191 ((|#3| (-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) |#5|) 105)) (-2022 ((|#3| |#3| |#5|) 107))) 
+(((-119 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2022 (|#3| |#3| |#5|)) (-15 -2393 ((-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) (-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) (-763) |#5|)) (-15 -2541 ((-2 (|:| |mult| (-763)) (|:| |subMult| (-763)) (|:| |blUpRec| (-634 (-2 (|:| |recTransStr| (-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|)) (|:| |recPoint| (-33 |#1|)) (|:| |recChart| |#5|) (|:| |definingExtension| |#1|))))) (-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) (-33 |#1|) |#5| |#1|)) (-15 -1587 ((-634 (-634 (-763))) (-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|))) (-15 -1705 ((-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) |#3| |#5|)) (-15 -3191 (|#3| (-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) |#5|))) (-365) (-634 (-1161)) (-324 |#1| |#4|) (-230 (-1699 |#2|) (-763)) (-117)) (T -119)) 
+((-3191 (*1 *2 *3 *4) (-12 (-5 *3 (-242 (-4289 (QUOTE X) (QUOTE -2928)) *5)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *2 (-324 *5 *7)) (-5 *1 (-119 *5 *6 *2 *7 *4)) (-4 *7 (-230 (-1699 *6) (-763))) (-4 *4 (-117)))) (-1705 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1699 *6) (-763))) (-5 *2 (-242 (-4289 (QUOTE X) (QUOTE -2928)) *5)) (-5 *1 (-119 *5 *6 *3 *7 *4)) (-4 *3 (-324 *5 *7)) (-4 *4 (-117)))) (-1587 (*1 *2 *3) (-12 (-5 *3 (-242 (-4289 (QUOTE X) (QUOTE -2928)) *4)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *7 (-230 (-1699 *5) (-763))) (-5 *2 (-634 (-634 (-763)))) (-5 *1 (-119 *4 *5 *6 *7 *8)) (-4 *6 (-324 *4 *7)) (-4 *8 (-117)))) (-2541 (*1 *2 *3 *4 *5 *6) (-12 (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *9 (-230 (-1699 *7) (-763))) (-5 *2 (-2 (|:| |mult| (-763)) (|:| |subMult| (-763)) (|:| |blUpRec| (-634 (-2 (|:| |recTransStr| (-242 (-4289 (QUOTE X) (QUOTE -2928)) *6)) (|:| |recPoint| (-33 *6)) (|:| |recChart| *5) (|:| |definingExtension| *6)))))) (-5 *1 (-119 *6 *7 *8 *9 *5)) (-5 *3 (-242 (-4289 (QUOTE X) (QUOTE -2928)) *6)) (-5 *4 (-33 *6)) (-4 *8 (-324 *6 *9)) (-4 *5 (-117)))) (-2393 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-242 (-4289 (QUOTE X) (QUOTE -2928)) *5)) (-4 *5 (-365)) (-5 *3 (-763)) (-14 *6 (-634 (-1161))) (-4 *8 (-230 (-1699 *6) *3)) (-5 *1 (-119 *5 *6 *7 *8 *4)) (-4 *7 (-324 *5 *8)) (-4 *4 (-117)))) (-2022 (*1 *2 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-230 (-1699 *5) (-763))) (-5 *1 (-119 *4 *5 *2 *6 *3)) (-4 *2 (-324 *4 *6)) (-4 *3 (-117))))) 
+(-10 -7 (-15 -2022 (|#3| |#3| |#5|)) (-15 -2393 ((-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) (-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) (-763) |#5|)) (-15 -2541 ((-2 (|:| |mult| (-763)) (|:| |subMult| (-763)) (|:| |blUpRec| (-634 (-2 (|:| |recTransStr| (-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|)) (|:| |recPoint| (-33 |#1|)) (|:| |recChart| |#5|) (|:| |definingExtension| |#1|))))) (-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) (-33 |#1|) |#5| |#1|)) (-15 -1587 ((-634 (-634 (-763))) (-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|))) (-15 -1705 ((-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) |#3| |#5|)) (-15 -3191 (|#3| (-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) |#5|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-3058 (($) 17 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ |#1| $) 22) (($ $ |#2|) 24))) 
 (((-120 |#1| |#2|) (-1275) (-1047) (-1047)) (T -120)) 
 NIL 
-(-13 (-637 |t#1|) (-1053 |t#2|) (-10 -7 (-6 -4514) (-6 -4513))) 
+(-13 (-637 |t#1|) (-1053 |t#2|) (-10 -7 (-6 -4516) (-6 -4515))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 |#1|) . T) ((-1053 |#2|) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-1611 (($ $) 12)) (-3091 (($ $ $) 17)) (-2080 (($) 8 T CONST)) (-4401 (((-121) $) 7)) (-3983 (((-763)) 24)) (-1731 (($) 30)) (-3104 (($ $ $) 15)) (-3044 (($ $) 10)) (-2460 (($ $ $) 18)) (-3339 (($ $ $) 19)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-3683 (((-917) $) 29)) (-4487 (((-1143) $) NIL)) (-4355 (($ (-917)) 28)) (-2872 (($ $ $) 21)) (-4022 (((-1108) $) NIL)) (-3911 (($) 9 T CONST)) (-4278 (((-541) $) 36)) (-2745 (((-850) $) 39)) (-2139 (($ $ $) 13)) (-1887 (($ $) 11)) (-2430 (($ $ $) 16)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 20)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 22)) (-2424 (($ $ $) 14))) 
-(((-121) (-13 (-842) (-370) (-651) (-609 (-541)) (-10 -8 (-15 -2080 ($) -3495) (-15 -3911 ($) -3495) (-15 -1887 ($ $)) (-15 -3044 ($ $)) (-15 -2139 ($ $ $)) (-15 -3104 ($ $ $)) (-15 -3091 ($ $ $)) (-15 -3339 ($ $ $)) (-15 -2460 ($ $ $)) (-15 -2872 ($ $ $)) (-15 -4401 ((-121) $))))) (T -121)) 
-((-2080 (*1 *1) (-5 *1 (-121))) (-3911 (*1 *1) (-5 *1 (-121))) (-1887 (*1 *1 *1) (-5 *1 (-121))) (-3044 (*1 *1 *1) (-5 *1 (-121))) (-2139 (*1 *1 *1 *1) (-5 *1 (-121))) (-3104 (*1 *1 *1 *1) (-5 *1 (-121))) (-3091 (*1 *1 *1 *1) (-5 *1 (-121))) (-3339 (*1 *1 *1 *1) (-5 *1 (-121))) (-2460 (*1 *1 *1 *1) (-5 *1 (-121))) (-2872 (*1 *1 *1 *1) (-5 *1 (-121))) (-4401 (*1 *1 *1) (-5 *1 (-121)))) 
-(-13 (-842) (-370) (-651) (-609 (-541)) (-10 -8 (-15 -2080 ($) -3495) (-15 -3911 ($) -3495) (-15 -1887 ($ $)) (-15 -3044 ($ $)) (-15 -2139 ($ $ $)) (-15 -3104 ($ $ $)) (-15 -3091 ($ $ $)) (-15 -3339 ($ $ $)) (-15 -2460 ($ $ $)) (-15 -2872 ($ $ $)) (-15 -4401 ((-121) $)))) 
-((-1481 (((-3 (-1 |#1| (-634 |#1|)) "failed") (-123)) 18) (((-123) (-123) (-1 |#1| |#1|)) 13) (((-123) (-123) (-1 |#1| (-634 |#1|))) 11) (((-3 |#1| "failed") (-123) (-634 |#1|)) 20)) (-1692 (((-3 (-634 (-1 |#1| (-634 |#1|))) "failed") (-123)) 24) (((-123) (-123) (-1 |#1| |#1|)) 30) (((-123) (-123) (-634 (-1 |#1| (-634 |#1|)))) 26)) (-1540 (((-123) |#1|) 53 (|has| |#1| (-842)))) (-2621 (((-3 |#1| "failed") (-123)) 48 (|has| |#1| (-842))))) 
-(((-122 |#1|) (-10 -7 (-15 -1481 ((-3 |#1| "failed") (-123) (-634 |#1|))) (-15 -1481 ((-123) (-123) (-1 |#1| (-634 |#1|)))) (-15 -1481 ((-123) (-123) (-1 |#1| |#1|))) (-15 -1481 ((-3 (-1 |#1| (-634 |#1|)) "failed") (-123))) (-15 -1692 ((-123) (-123) (-634 (-1 |#1| (-634 |#1|))))) (-15 -1692 ((-123) (-123) (-1 |#1| |#1|))) (-15 -1692 ((-3 (-634 (-1 |#1| (-634 |#1|))) "failed") (-123))) (IF (|has| |#1| (-842)) (PROGN (-15 -1540 ((-123) |#1|)) (-15 -2621 ((-3 |#1| "failed") (-123)))) |noBranch|)) (-1090)) (T -122)) 
-((-2621 (*1 *2 *3) (|partial| -12 (-5 *3 (-123)) (-4 *2 (-1090)) (-4 *2 (-842)) (-5 *1 (-122 *2)))) (-1540 (*1 *2 *3) (-12 (-5 *2 (-123)) (-5 *1 (-122 *3)) (-4 *3 (-842)) (-4 *3 (-1090)))) (-1692 (*1 *2 *3) (|partial| -12 (-5 *3 (-123)) (-5 *2 (-634 (-1 *4 (-634 *4)))) (-5 *1 (-122 *4)) (-4 *4 (-1090)))) (-1692 (*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *4 *4)) (-4 *4 (-1090)) (-5 *1 (-122 *4)))) (-1692 (*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-634 (-1 *4 (-634 *4)))) (-4 *4 (-1090)) (-5 *1 (-122 *4)))) (-1481 (*1 *2 *3) (|partial| -12 (-5 *3 (-123)) (-5 *2 (-1 *4 (-634 *4))) (-5 *1 (-122 *4)) (-4 *4 (-1090)))) (-1481 (*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *4 *4)) (-4 *4 (-1090)) (-5 *1 (-122 *4)))) (-1481 (*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *4 (-634 *4))) (-4 *4 (-1090)) (-5 *1 (-122 *4)))) (-1481 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-634 *2)) (-5 *1 (-122 *2)) (-4 *2 (-1090))))) 
-(-10 -7 (-15 -1481 ((-3 |#1| "failed") (-123) (-634 |#1|))) (-15 -1481 ((-123) (-123) (-1 |#1| (-634 |#1|)))) (-15 -1481 ((-123) (-123) (-1 |#1| |#1|))) (-15 -1481 ((-3 (-1 |#1| (-634 |#1|)) "failed") (-123))) (-15 -1692 ((-123) (-123) (-634 (-1 |#1| (-634 |#1|))))) (-15 -1692 ((-123) (-123) (-1 |#1| |#1|))) (-15 -1692 ((-3 (-634 (-1 |#1| (-634 |#1|))) "failed") (-123))) (IF (|has| |#1| (-842)) (PROGN (-15 -1540 ((-123) |#1|)) (-15 -2621 ((-3 |#1| "failed") (-123)))) |noBranch|)) 
-((-2447 (((-121) $ $) NIL)) (-1551 (((-763) $) 68) (($ $ (-763)) 30)) (-1638 (((-121) $) 32)) (-3873 (($ $ (-1143) (-766)) 26)) (-3568 (($ $ (-50 (-1143) (-766))) 13)) (-2823 (((-3 (-766) "failed") $ (-1143)) 24)) (-2862 (((-50 (-1143) (-766)) $) 12)) (-3488 (($ (-1161)) 15) (($ (-1161) (-763)) 20)) (-1299 (((-121) $) 31)) (-2130 (((-121) $) 33)) (-3391 (((-1161) $) 8)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-4487 (((-1143) $) NIL)) (-2841 (((-121) $ (-1161)) 10)) (-4395 (($ $ (-1 (-541) (-634 (-541)))) 50) (((-3 (-1 (-541) (-634 (-541))) "failed") $) 54)) (-4022 (((-1108) $) NIL)) (-3372 (((-121) $ (-1143)) 29)) (-1515 (($ $ (-1 (-121) $ $)) 35)) (-4125 (((-3 (-1 (-850) (-634 (-850))) "failed") $) 52) (($ $ (-1 (-850) (-634 (-850)))) 41) (($ $ (-1 (-850) (-850))) 43)) (-1808 (($ $ (-1143)) 45)) (-3863 (($ $) 61)) (-2800 (($ $ (-1 (-121) $ $)) 36)) (-2745 (((-850) $) 48)) (-2209 (($ $ (-1143)) 27)) (-1860 (((-3 (-763) "failed") $) 56)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 67)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 72))) 
-(((-123) (-13 (-842) (-10 -8 (-15 -3391 ((-1161) $)) (-15 -2862 ((-50 (-1143) (-766)) $)) (-15 -3863 ($ $)) (-15 -3488 ($ (-1161))) (-15 -3488 ($ (-1161) (-763))) (-15 -1860 ((-3 (-763) "failed") $)) (-15 -1299 ((-121) $)) (-15 -1638 ((-121) $)) (-15 -2130 ((-121) $)) (-15 -1551 ((-763) $)) (-15 -1551 ($ $ (-763))) (-15 -1515 ($ $ (-1 (-121) $ $))) (-15 -2800 ($ $ (-1 (-121) $ $))) (-15 -4125 ((-3 (-1 (-850) (-634 (-850))) "failed") $)) (-15 -4125 ($ $ (-1 (-850) (-634 (-850))))) (-15 -4125 ($ $ (-1 (-850) (-850)))) (-15 -4395 ($ $ (-1 (-541) (-634 (-541))))) (-15 -4395 ((-3 (-1 (-541) (-634 (-541))) "failed") $)) (-15 -2841 ((-121) $ (-1161))) (-15 -3372 ((-121) $ (-1143))) (-15 -2209 ($ $ (-1143))) (-15 -1808 ($ $ (-1143))) (-15 -2823 ((-3 (-766) "failed") $ (-1143))) (-15 -3873 ($ $ (-1143) (-766))) (-15 -3568 ($ $ (-50 (-1143) (-766))))))) (T -123)) 
-((-3391 (*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-123)))) (-2862 (*1 *2 *1) (-12 (-5 *2 (-50 (-1143) (-766))) (-5 *1 (-123)))) (-3863 (*1 *1 *1) (-5 *1 (-123))) (-3488 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-123)))) (-3488 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-763)) (-5 *1 (-123)))) (-1860 (*1 *2 *1) (|partial| -12 (-5 *2 (-763)) (-5 *1 (-123)))) (-1299 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-123)))) (-1638 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-123)))) (-2130 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-123)))) (-1551 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-123)))) (-1551 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-123)))) (-1515 (*1 *1 *1 *2) (-12 (-5 *2 (-1 (-121) (-123) (-123))) (-5 *1 (-123)))) (-2800 (*1 *1 *1 *2) (-12 (-5 *2 (-1 (-121) (-123) (-123))) (-5 *1 (-123)))) (-4125 (*1 *2 *1) (|partial| -12 (-5 *2 (-1 (-850) (-634 (-850)))) (-5 *1 (-123)))) (-4125 (*1 *1 *1 *2) (-12 (-5 *2 (-1 (-850) (-634 (-850)))) (-5 *1 (-123)))) (-4125 (*1 *1 *1 *2) (-12 (-5 *2 (-1 (-850) (-850))) (-5 *1 (-123)))) (-4395 (*1 *1 *1 *2) (-12 (-5 *2 (-1 (-541) (-634 (-541)))) (-5 *1 (-123)))) (-4395 (*1 *2 *1) (|partial| -12 (-5 *2 (-1 (-541) (-634 (-541)))) (-5 *1 (-123)))) (-2841 (*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-121)) (-5 *1 (-123)))) (-3372 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-121)) (-5 *1 (-123)))) (-2209 (*1 *1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-123)))) (-1808 (*1 *1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-123)))) (-2823 (*1 *2 *1 *3) (|partial| -12 (-5 *3 (-1143)) (-5 *2 (-766)) (-5 *1 (-123)))) (-3873 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1143)) (-5 *3 (-766)) (-5 *1 (-123)))) (-3568 (*1 *1 *1 *2) (-12 (-5 *2 (-50 (-1143) (-766))) (-5 *1 (-123))))) 
-(-13 (-842) (-10 -8 (-15 -3391 ((-1161) $)) (-15 -2862 ((-50 (-1143) (-766)) $)) (-15 -3863 ($ $)) (-15 -3488 ($ (-1161))) (-15 -3488 ($ (-1161) (-763))) (-15 -1860 ((-3 (-763) "failed") $)) (-15 -1299 ((-121) $)) (-15 -1638 ((-121) $)) (-15 -2130 ((-121) $)) (-15 -1551 ((-763) $)) (-15 -1551 ($ $ (-763))) (-15 -1515 ($ $ (-1 (-121) $ $))) (-15 -2800 ($ $ (-1 (-121) $ $))) (-15 -4125 ((-3 (-1 (-850) (-634 (-850))) "failed") $)) (-15 -4125 ($ $ (-1 (-850) (-634 (-850))))) (-15 -4125 ($ $ (-1 (-850) (-850)))) (-15 -4395 ($ $ (-1 (-541) (-634 (-541))))) (-15 -4395 ((-3 (-1 (-541) (-634 (-541))) "failed") $)) (-15 -2841 ((-121) $ (-1161))) (-15 -3372 ((-121) $ (-1143))) (-15 -2209 ($ $ (-1143))) (-15 -1808 ($ $ (-1143))) (-15 -2823 ((-3 (-766) "failed") $ (-1143))) (-15 -3873 ($ $ (-1143) (-766))) (-15 -3568 ($ $ (-50 (-1143) (-766)))))) 
-((-2878 (((-568) |#2|) 36))) 
-(((-124 |#1| |#2|) (-10 -7 (-15 -2878 ((-568) |#2|))) (-13 (-365) (-1037 (-409 (-568)))) (-1219 |#1|)) (T -124)) 
-((-2878 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-1037 (-409 *2)))) (-5 *2 (-568)) (-5 *1 (-124 *4 *3)) (-4 *3 (-1219 *4))))) 
-(-10 -7 (-15 -2878 ((-568) |#2|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1902 (($ $ (-568)) NIL)) (-1497 (((-121) $ $) NIL)) (-2671 (($) NIL T CONST)) (-2143 (($ (-1157 (-568)) (-568)) NIL)) (-2401 (($ $ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3974 (($ $) NIL)) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-4477 (((-763) $) NIL)) (-2735 (((-121) $) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3094 (((-568)) NIL)) (-1914 (((-568) $) NIL)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1807 (($ $ (-568)) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3396 (((-1141 (-568)) $) NIL)) (-1811 (($ $) NIL)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL)) (-4078 (((-763)) NIL)) (-1826 (((-121) $ $) NIL)) (-3996 (((-568) $ (-568)) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-1613 (($ $) 12)) (-3093 (($ $ $) 17)) (-2082 (($) 8 T CONST)) (-4403 (((-121) $) 7)) (-3986 (((-763)) 24)) (-1733 (($) 30)) (-3107 (($ $ $) 15)) (-3046 (($ $) 10)) (-2570 (($ $ $) 18)) (-4445 (($ $ $) 19)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-2291 (((-917) $) 29)) (-1893 (((-1143) $) NIL)) (-4357 (($ (-917)) 28)) (-2874 (($ $ $) 21)) (-4025 (((-1108) $) NIL)) (-3913 (($) 9 T CONST)) (-4280 (((-541) $) 36)) (-2747 (((-850) $) 39)) (-2141 (($ $ $) 13)) (-1889 (($ $) 11)) (-2432 (($ $ $) 16)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 20)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 22)) (-2426 (($ $ $) 14))) 
+(((-121) (-13 (-842) (-370) (-651) (-609 (-541)) (-10 -8 (-15 -2082 ($) -3497) (-15 -3913 ($) -3497) (-15 -1889 ($ $)) (-15 -3046 ($ $)) (-15 -2141 ($ $ $)) (-15 -3107 ($ $ $)) (-15 -3093 ($ $ $)) (-15 -4445 ($ $ $)) (-15 -2570 ($ $ $)) (-15 -2874 ($ $ $)) (-15 -4403 ((-121) $))))) (T -121)) 
+((-2082 (*1 *1) (-5 *1 (-121))) (-3913 (*1 *1) (-5 *1 (-121))) (-1889 (*1 *1 *1) (-5 *1 (-121))) (-3046 (*1 *1 *1) (-5 *1 (-121))) (-2141 (*1 *1 *1 *1) (-5 *1 (-121))) (-3107 (*1 *1 *1 *1) (-5 *1 (-121))) (-3093 (*1 *1 *1 *1) (-5 *1 (-121))) (-4445 (*1 *1 *1 *1) (-5 *1 (-121))) (-2570 (*1 *1 *1 *1) (-5 *1 (-121))) (-2874 (*1 *1 *1 *1) (-5 *1 (-121))) (-4403 (*1 *1 *1) (-5 *1 (-121)))) 
+(-13 (-842) (-370) (-651) (-609 (-541)) (-10 -8 (-15 -2082 ($) -3497) (-15 -3913 ($) -3497) (-15 -1889 ($ $)) (-15 -3046 ($ $)) (-15 -2141 ($ $ $)) (-15 -3107 ($ $ $)) (-15 -3093 ($ $ $)) (-15 -4445 ($ $ $)) (-15 -2570 ($ $ $)) (-15 -2874 ($ $ $)) (-15 -4403 ((-121) $)))) 
+((-2513 (((-3 (-1 |#1| (-634 |#1|)) "failed") (-123)) 18) (((-123) (-123) (-1 |#1| |#1|)) 13) (((-123) (-123) (-1 |#1| (-634 |#1|))) 11) (((-3 |#1| "failed") (-123) (-634 |#1|)) 20)) (-3561 (((-3 (-634 (-1 |#1| (-634 |#1|))) "failed") (-123)) 24) (((-123) (-123) (-1 |#1| |#1|)) 30) (((-123) (-123) (-634 (-1 |#1| (-634 |#1|)))) 26)) (-4239 (((-123) |#1|) 53 (|has| |#1| (-842)))) (-4206 (((-3 |#1| "failed") (-123)) 48 (|has| |#1| (-842))))) 
+(((-122 |#1|) (-10 -7 (-15 -2513 ((-3 |#1| "failed") (-123) (-634 |#1|))) (-15 -2513 ((-123) (-123) (-1 |#1| (-634 |#1|)))) (-15 -2513 ((-123) (-123) (-1 |#1| |#1|))) (-15 -2513 ((-3 (-1 |#1| (-634 |#1|)) "failed") (-123))) (-15 -3561 ((-123) (-123) (-634 (-1 |#1| (-634 |#1|))))) (-15 -3561 ((-123) (-123) (-1 |#1| |#1|))) (-15 -3561 ((-3 (-634 (-1 |#1| (-634 |#1|))) "failed") (-123))) (IF (|has| |#1| (-842)) (PROGN (-15 -4239 ((-123) |#1|)) (-15 -4206 ((-3 |#1| "failed") (-123)))) |noBranch|)) (-1090)) (T -122)) 
+((-4206 (*1 *2 *3) (|partial| -12 (-5 *3 (-123)) (-4 *2 (-1090)) (-4 *2 (-842)) (-5 *1 (-122 *2)))) (-4239 (*1 *2 *3) (-12 (-5 *2 (-123)) (-5 *1 (-122 *3)) (-4 *3 (-842)) (-4 *3 (-1090)))) (-3561 (*1 *2 *3) (|partial| -12 (-5 *3 (-123)) (-5 *2 (-634 (-1 *4 (-634 *4)))) (-5 *1 (-122 *4)) (-4 *4 (-1090)))) (-3561 (*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *4 *4)) (-4 *4 (-1090)) (-5 *1 (-122 *4)))) (-3561 (*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-634 (-1 *4 (-634 *4)))) (-4 *4 (-1090)) (-5 *1 (-122 *4)))) (-2513 (*1 *2 *3) (|partial| -12 (-5 *3 (-123)) (-5 *2 (-1 *4 (-634 *4))) (-5 *1 (-122 *4)) (-4 *4 (-1090)))) (-2513 (*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *4 *4)) (-4 *4 (-1090)) (-5 *1 (-122 *4)))) (-2513 (*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *4 (-634 *4))) (-4 *4 (-1090)) (-5 *1 (-122 *4)))) (-2513 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-634 *2)) (-5 *1 (-122 *2)) (-4 *2 (-1090))))) 
+(-10 -7 (-15 -2513 ((-3 |#1| "failed") (-123) (-634 |#1|))) (-15 -2513 ((-123) (-123) (-1 |#1| (-634 |#1|)))) (-15 -2513 ((-123) (-123) (-1 |#1| |#1|))) (-15 -2513 ((-3 (-1 |#1| (-634 |#1|)) "failed") (-123))) (-15 -3561 ((-123) (-123) (-634 (-1 |#1| (-634 |#1|))))) (-15 -3561 ((-123) (-123) (-1 |#1| |#1|))) (-15 -3561 ((-3 (-634 (-1 |#1| (-634 |#1|))) "failed") (-123))) (IF (|has| |#1| (-842)) (PROGN (-15 -4239 ((-123) |#1|)) (-15 -4206 ((-3 |#1| "failed") (-123)))) |noBranch|)) 
+((-2449 (((-121) $ $) NIL)) (-4308 (((-763) $) 68) (($ $ (-763)) 30)) (-3228 (((-121) $) 32)) (-1975 (($ $ (-1143) (-766)) 26)) (-2882 (($ $ (-50 (-1143) (-766))) 13)) (-2825 (((-3 (-766) "failed") $ (-1143)) 24)) (-2864 (((-50 (-1143) (-766)) $) 12)) (-3842 (($ (-1161)) 15) (($ (-1161) (-763)) 20)) (-3276 (((-121) $) 31)) (-3417 (((-121) $) 33)) (-3393 (((-1161) $) 8)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-1893 (((-1143) $) NIL)) (-3910 (((-121) $ (-1161)) 10)) (-4397 (($ $ (-1 (-541) (-634 (-541)))) 50) (((-3 (-1 (-541) (-634 (-541))) "failed") $) 54)) (-4025 (((-1108) $) NIL)) (-1395 (((-121) $ (-1143)) 29)) (-4084 (($ $ (-1 (-121) $ $)) 35)) (-4127 (((-3 (-1 (-850) (-634 (-850))) "failed") $) 52) (($ $ (-1 (-850) (-634 (-850)))) 41) (($ $ (-1 (-850) (-850))) 43)) (-2173 (($ $ (-1143)) 45)) (-3865 (($ $) 61)) (-3642 (($ $ (-1 (-121) $ $)) 36)) (-2747 (((-850) $) 48)) (-2211 (($ $ (-1143)) 27)) (-2440 (((-3 (-763) "failed") $) 56)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 67)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 72))) 
+(((-123) (-13 (-842) (-10 -8 (-15 -3393 ((-1161) $)) (-15 -2864 ((-50 (-1143) (-766)) $)) (-15 -3865 ($ $)) (-15 -3842 ($ (-1161))) (-15 -3842 ($ (-1161) (-763))) (-15 -2440 ((-3 (-763) "failed") $)) (-15 -3276 ((-121) $)) (-15 -3228 ((-121) $)) (-15 -3417 ((-121) $)) (-15 -4308 ((-763) $)) (-15 -4308 ($ $ (-763))) (-15 -4084 ($ $ (-1 (-121) $ $))) (-15 -3642 ($ $ (-1 (-121) $ $))) (-15 -4127 ((-3 (-1 (-850) (-634 (-850))) "failed") $)) (-15 -4127 ($ $ (-1 (-850) (-634 (-850))))) (-15 -4127 ($ $ (-1 (-850) (-850)))) (-15 -4397 ($ $ (-1 (-541) (-634 (-541))))) (-15 -4397 ((-3 (-1 (-541) (-634 (-541))) "failed") $)) (-15 -3910 ((-121) $ (-1161))) (-15 -1395 ((-121) $ (-1143))) (-15 -2211 ($ $ (-1143))) (-15 -2173 ($ $ (-1143))) (-15 -2825 ((-3 (-766) "failed") $ (-1143))) (-15 -1975 ($ $ (-1143) (-766))) (-15 -2882 ($ $ (-50 (-1143) (-766))))))) (T -123)) 
+((-3393 (*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-123)))) (-2864 (*1 *2 *1) (-12 (-5 *2 (-50 (-1143) (-766))) (-5 *1 (-123)))) (-3865 (*1 *1 *1) (-5 *1 (-123))) (-3842 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-123)))) (-3842 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-763)) (-5 *1 (-123)))) (-2440 (*1 *2 *1) (|partial| -12 (-5 *2 (-763)) (-5 *1 (-123)))) (-3276 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-123)))) (-3228 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-123)))) (-3417 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-123)))) (-4308 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-123)))) (-4308 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-123)))) (-4084 (*1 *1 *1 *2) (-12 (-5 *2 (-1 (-121) (-123) (-123))) (-5 *1 (-123)))) (-3642 (*1 *1 *1 *2) (-12 (-5 *2 (-1 (-121) (-123) (-123))) (-5 *1 (-123)))) (-4127 (*1 *2 *1) (|partial| -12 (-5 *2 (-1 (-850) (-634 (-850)))) (-5 *1 (-123)))) (-4127 (*1 *1 *1 *2) (-12 (-5 *2 (-1 (-850) (-634 (-850)))) (-5 *1 (-123)))) (-4127 (*1 *1 *1 *2) (-12 (-5 *2 (-1 (-850) (-850))) (-5 *1 (-123)))) (-4397 (*1 *1 *1 *2) (-12 (-5 *2 (-1 (-541) (-634 (-541)))) (-5 *1 (-123)))) (-4397 (*1 *2 *1) (|partial| -12 (-5 *2 (-1 (-541) (-634 (-541)))) (-5 *1 (-123)))) (-3910 (*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-121)) (-5 *1 (-123)))) (-1395 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-121)) (-5 *1 (-123)))) (-2211 (*1 *1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-123)))) (-2173 (*1 *1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-123)))) (-2825 (*1 *2 *1 *3) (|partial| -12 (-5 *3 (-1143)) (-5 *2 (-766)) (-5 *1 (-123)))) (-1975 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1143)) (-5 *3 (-766)) (-5 *1 (-123)))) (-2882 (*1 *1 *1 *2) (-12 (-5 *2 (-50 (-1143) (-766))) (-5 *1 (-123))))) 
+(-13 (-842) (-10 -8 (-15 -3393 ((-1161) $)) (-15 -2864 ((-50 (-1143) (-766)) $)) (-15 -3865 ($ $)) (-15 -3842 ($ (-1161))) (-15 -3842 ($ (-1161) (-763))) (-15 -2440 ((-3 (-763) "failed") $)) (-15 -3276 ((-121) $)) (-15 -3228 ((-121) $)) (-15 -3417 ((-121) $)) (-15 -4308 ((-763) $)) (-15 -4308 ($ $ (-763))) (-15 -4084 ($ $ (-1 (-121) $ $))) (-15 -3642 ($ $ (-1 (-121) $ $))) (-15 -4127 ((-3 (-1 (-850) (-634 (-850))) "failed") $)) (-15 -4127 ($ $ (-1 (-850) (-634 (-850))))) (-15 -4127 ($ $ (-1 (-850) (-850)))) (-15 -4397 ($ $ (-1 (-541) (-634 (-541))))) (-15 -4397 ((-3 (-1 (-541) (-634 (-541))) "failed") $)) (-15 -3910 ((-121) $ (-1161))) (-15 -1395 ((-121) $ (-1143))) (-15 -2211 ($ $ (-1143))) (-15 -2173 ($ $ (-1143))) (-15 -2825 ((-3 (-766) "failed") $ (-1143))) (-15 -1975 ($ $ (-1143) (-766))) (-15 -2882 ($ $ (-50 (-1143) (-766)))))) 
+((-4139 (((-568) |#2|) 36))) 
+(((-124 |#1| |#2|) (-10 -7 (-15 -4139 ((-568) |#2|))) (-13 (-365) (-1037 (-409 (-568)))) (-1219 |#1|)) (T -124)) 
+((-4139 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-1037 (-409 *2)))) (-5 *2 (-568)) (-5 *1 (-124 *4 *3)) (-4 *3 (-1219 *4))))) 
+(-10 -7 (-15 -4139 ((-568) |#2|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-1904 (($ $ (-568)) NIL)) (-2589 (((-121) $ $) NIL)) (-4490 (($) NIL T CONST)) (-3517 (($ (-1157 (-568)) (-568)) NIL)) (-2403 (($ $ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-4456 (($ $) NIL)) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-1844 (((-763) $) NIL)) (-1598 (((-121) $) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2477 (((-568)) NIL)) (-2691 (((-568) $) NIL)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2168 (($ $ (-568)) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-1513 (((-1141 (-568)) $) NIL)) (-2188 (($ $) NIL)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL)) (-3425 (((-763)) NIL)) (-2273 (((-121) $ $) NIL)) (-3999 (((-568) $ (-568)) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL))) 
 (((-125 |#1|) (-863 |#1|) (-568)) (T -125)) 
 NIL 
 (-863 |#1|) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-1492 (((-125 |#1|) $) NIL (|has| (-125 |#1|) (-301)))) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-125 |#1|) (-904)))) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| (-125 |#1|) (-904)))) (-1497 (((-121) $ $) NIL)) (-3662 (((-568) $) NIL (|has| (-125 |#1|) (-815)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-125 |#1|) "failed") $) NIL) (((-3 (-1161) "failed") $) NIL (|has| (-125 |#1|) (-1037 (-1161)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| (-125 |#1|) (-1037 (-568)))) (((-3 (-568) "failed") $) NIL (|has| (-125 |#1|) (-1037 (-568))))) (-2854 (((-125 |#1|) $) NIL) (((-1161) $) NIL (|has| (-125 |#1|) (-1037 (-1161)))) (((-409 (-568)) $) NIL (|has| (-125 |#1|) (-1037 (-568)))) (((-568) $) NIL (|has| (-125 |#1|) (-1037 (-568))))) (-1429 (($ $) NIL) (($ (-568) $) NIL)) (-2401 (($ $ $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| (-125 |#1|) (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| (-125 |#1|) (-630 (-568)))) (((-2 (|:| -2928 (-679 (-125 |#1|))) (|:| |vec| (-1244 (-125 |#1|)))) (-679 $) (-1244 $)) NIL) (((-679 (-125 |#1|)) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1731 (($) NIL (|has| (-125 |#1|) (-550)))) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-2033 (((-121) $) NIL (|has| (-125 |#1|) (-815)))) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| (-125 |#1|) (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| (-125 |#1|) (-881 (-381))))) (-2735 (((-121) $) NIL)) (-1332 (($ $) NIL)) (-2317 (((-125 |#1|) $) NIL)) (-3038 (((-3 $ "failed") $) NIL (|has| (-125 |#1|) (-1136)))) (-2245 (((-121) $) NIL (|has| (-125 |#1|) (-815)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2521 (($ $ $) NIL (|has| (-125 |#1|) (-842)))) (-3268 (($ $ $) NIL (|has| (-125 |#1|) (-842)))) (-2795 (($ (-1 (-125 |#1|) (-125 |#1|)) $) NIL)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4434 (($) NIL (|has| (-125 |#1|) (-1136)) CONST)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3880 (($ $) NIL (|has| (-125 |#1|) (-301)))) (-1519 (((-125 |#1|) $) NIL (|has| (-125 |#1|) (-550)))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-125 |#1|) (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-125 |#1|) (-904)))) (-3848 (((-420 $) $) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1339 (($ $ (-634 (-125 |#1|)) (-634 (-125 |#1|))) NIL (|has| (-125 |#1|) (-303 (-125 |#1|)))) (($ $ (-125 |#1|) (-125 |#1|)) NIL (|has| (-125 |#1|) (-303 (-125 |#1|)))) (($ $ (-288 (-125 |#1|))) NIL (|has| (-125 |#1|) (-303 (-125 |#1|)))) (($ $ (-634 (-288 (-125 |#1|)))) NIL (|has| (-125 |#1|) (-303 (-125 |#1|)))) (($ $ (-634 (-1161)) (-634 (-125 |#1|))) NIL (|has| (-125 |#1|) (-523 (-1161) (-125 |#1|)))) (($ $ (-1161) (-125 |#1|)) NIL (|has| (-125 |#1|) (-523 (-1161) (-125 |#1|))))) (-2709 (((-763) $) NIL)) (-2779 (($ $ (-125 |#1|)) NIL (|has| (-125 |#1|) (-281 (-125 |#1|) (-125 |#1|))))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-4189 (($ $) NIL (|has| (-125 |#1|) (-225))) (($ $ (-763)) NIL (|has| (-125 |#1|) (-225))) (($ $ (-1161)) NIL (|has| (-125 |#1|) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-125 |#1|) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-125 |#1|) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-125 |#1|) (-895 (-1161)))) (($ $ (-1 (-125 |#1|) (-125 |#1|)) (-763)) NIL) (($ $ (-1 (-125 |#1|) (-125 |#1|))) NIL)) (-3013 (($ $) NIL)) (-2324 (((-125 |#1|) $) NIL)) (-4278 (((-887 (-568)) $) NIL (|has| (-125 |#1|) (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| (-125 |#1|) (-609 (-887 (-381))))) (((-541) $) NIL (|has| (-125 |#1|) (-609 (-541)))) (((-381) $) NIL (|has| (-125 |#1|) (-1021))) (((-215) $) NIL (|has| (-125 |#1|) (-1021)))) (-3878 (((-173 (-409 (-568))) $) NIL)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| (-125 |#1|) (-904))))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ (-125 |#1|)) NIL) (($ (-1161)) NIL (|has| (-125 |#1|) (-1037 (-1161))))) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| (-125 |#1|) (-904))) (|has| (-125 |#1|) (-148))))) (-4078 (((-763)) NIL)) (-2285 (((-125 |#1|) $) NIL (|has| (-125 |#1|) (-550)))) (-1826 (((-121) $ $) NIL)) (-3996 (((-409 (-568)) $ (-568)) NIL)) (-2897 (($ $) NIL (|has| (-125 |#1|) (-815)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $) NIL (|has| (-125 |#1|) (-225))) (($ $ (-763)) NIL (|has| (-125 |#1|) (-225))) (($ $ (-1161)) NIL (|has| (-125 |#1|) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-125 |#1|) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-125 |#1|) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-125 |#1|) (-895 (-1161)))) (($ $ (-1 (-125 |#1|) (-125 |#1|)) (-763)) NIL) (($ $ (-1 (-125 |#1|) (-125 |#1|))) NIL)) (-1751 (((-121) $ $) NIL (|has| (-125 |#1|) (-842)))) (-1738 (((-121) $ $) NIL (|has| (-125 |#1|) (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| (-125 |#1|) (-842)))) (-1732 (((-121) $ $) NIL (|has| (-125 |#1|) (-842)))) (-1779 (($ $ $) NIL) (($ (-125 |#1|) (-125 |#1|)) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ (-125 |#1|) $) NIL) (($ $ (-125 |#1|)) NIL))) 
-(((-126 |#1|) (-13 (-993 (-125 |#1|)) (-10 -8 (-15 -3996 ((-409 (-568)) $ (-568))) (-15 -3878 ((-173 (-409 (-568))) $)) (-15 -1429 ($ $)) (-15 -1429 ($ (-568) $)))) (-568)) (T -126)) 
-((-3996 (*1 *2 *1 *3) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-126 *4)) (-14 *4 *3) (-5 *3 (-568)))) (-3878 (*1 *2 *1) (-12 (-5 *2 (-173 (-409 (-568)))) (-5 *1 (-126 *3)) (-14 *3 (-568)))) (-1429 (*1 *1 *1) (-12 (-5 *1 (-126 *2)) (-14 *2 (-568)))) (-1429 (*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-126 *3)) (-14 *3 *2)))) 
-(-13 (-993 (-125 |#1|)) (-10 -8 (-15 -3996 ((-409 (-568)) $ (-568))) (-15 -3878 ((-173 (-409 (-568))) $)) (-15 -1429 ($ $)) (-15 -1429 ($ (-568) $)))) 
-((-2436 ((|#2| $ "value" |#2|) NIL) (($ $ "left" $) 48) (($ $ "right" $) 50)) (-2287 (((-634 $) $) 27)) (-1700 (((-121) $ $) 32)) (-3109 (((-121) |#2| $) 36)) (-2869 (((-634 |#2|) $) 22)) (-1651 (((-121) $) 16)) (-2779 ((|#2| $ "value") NIL) (($ $ "left") 10) (($ $ "right") 13)) (-3790 (((-121) $) 45)) (-2745 (((-850) $) 41)) (-4339 (((-634 $) $) 28)) (-1717 (((-121) $ $) 34)) (-1697 (((-763) $) 43))) 
-(((-127 |#1| |#2|) (-10 -8 (-15 -2436 (|#1| |#1| "right" |#1|)) (-15 -2436 (|#1| |#1| "left" |#1|)) (-15 -2779 (|#1| |#1| "right")) (-15 -2779 (|#1| |#1| "left")) (-15 -2436 (|#2| |#1| "value" |#2|)) (-15 -1700 ((-121) |#1| |#1|)) (-15 -2869 ((-634 |#2|) |#1|)) (-15 -3790 ((-121) |#1|)) (-15 -2779 (|#2| |#1| "value")) (-15 -1651 ((-121) |#1|)) (-15 -2287 ((-634 |#1|) |#1|)) (-15 -4339 ((-634 |#1|) |#1|)) (-15 -1717 ((-121) |#1| |#1|)) (-15 -2745 ((-850) |#1|)) (-15 -3109 ((-121) |#2| |#1|)) (-15 -1697 ((-763) |#1|))) (-128 |#2|) (-1195)) (T -127)) 
-NIL 
-(-10 -8 (-15 -2436 (|#1| |#1| "right" |#1|)) (-15 -2436 (|#1| |#1| "left" |#1|)) (-15 -2779 (|#1| |#1| "right")) (-15 -2779 (|#1| |#1| "left")) (-15 -2436 (|#2| |#1| "value" |#2|)) (-15 -1700 ((-121) |#1| |#1|)) (-15 -2869 ((-634 |#2|) |#1|)) (-15 -3790 ((-121) |#1|)) (-15 -2779 (|#2| |#1| "value")) (-15 -1651 ((-121) |#1|)) (-15 -2287 ((-634 |#1|) |#1|)) (-15 -4339 ((-634 |#1|) |#1|)) (-15 -1717 ((-121) |#1| |#1|)) (-15 -2745 ((-850) |#1|)) (-15 -3109 ((-121) |#2| |#1|)) (-15 -1697 ((-763) |#1|))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2850 ((|#1| $) 45)) (-2510 (((-121) $ (-763)) 8)) (-1659 ((|#1| $ |#1|) 36 (|has| $ (-6 -4520)))) (-3497 (($ $ $) 49 (|has| $ (-6 -4520)))) (-3089 (($ $ $) 51 (|has| $ (-6 -4520)))) (-2436 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4520))) (($ $ "left" $) 52 (|has| $ (-6 -4520))) (($ $ "right" $) 50 (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) 38 (|has| $ (-6 -4520)))) (-2671 (($) 7 T CONST)) (-3284 (($ $) 54)) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-2287 (((-634 $) $) 47)) (-1700 (((-121) $ $) 39 (|has| |#1| (-1090)))) (-1737 (((-121) $ (-763)) 9)) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35)) (-2166 (((-121) $ (-763)) 10)) (-3028 (($ $) 56)) (-2869 (((-634 |#1|) $) 42)) (-1651 (((-121) $) 46)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 ((|#1| $ "value") 44) (($ $ "left") 55) (($ $ "right") 53)) (-4075 (((-568) $ $) 41)) (-3790 (((-121) $) 43)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-4339 (((-634 $) $) 48)) (-3491 (((-121) $ $) 40 (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2563 (((-125 |#1|) $) NIL (|has| (-125 |#1|) (-301)))) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-125 |#1|) (-904)))) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| (-125 |#1|) (-904)))) (-2589 (((-121) $ $) NIL)) (-3337 (((-568) $) NIL (|has| (-125 |#1|) (-815)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-125 |#1|) "failed") $) NIL) (((-3 (-1161) "failed") $) NIL (|has| (-125 |#1|) (-1037 (-1161)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| (-125 |#1|) (-1037 (-568)))) (((-3 (-568) "failed") $) NIL (|has| (-125 |#1|) (-1037 (-568))))) (-2857 (((-125 |#1|) $) NIL) (((-1161) $) NIL (|has| (-125 |#1|) (-1037 (-1161)))) (((-409 (-568)) $) NIL (|has| (-125 |#1|) (-1037 (-568)))) (((-568) $) NIL (|has| (-125 |#1|) (-1037 (-568))))) (-2232 (($ $) NIL) (($ (-568) $) NIL)) (-2403 (($ $ $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| (-125 |#1|) (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| (-125 |#1|) (-630 (-568)))) (((-2 (|:| -2908 (-679 (-125 |#1|))) (|:| |vec| (-1244 (-125 |#1|)))) (-679 $) (-1244 $)) NIL) (((-679 (-125 |#1|)) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1733 (($) NIL (|has| (-125 |#1|) (-550)))) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-1436 (((-121) $) NIL (|has| (-125 |#1|) (-815)))) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| (-125 |#1|) (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| (-125 |#1|) (-881 (-381))))) (-1598 (((-121) $) NIL)) (-3539 (($ $) NIL)) (-2319 (((-125 |#1|) $) NIL)) (-2214 (((-3 $ "failed") $) NIL (|has| (-125 |#1|) (-1136)))) (-2859 (((-121) $) NIL (|has| (-125 |#1|) (-815)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1732 (($ $ $) NIL (|has| (-125 |#1|) (-842)))) (-2047 (($ $ $) NIL (|has| (-125 |#1|) (-842)))) (-2797 (($ (-1 (-125 |#1|) (-125 |#1|)) $) NIL)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4436 (($) NIL (|has| (-125 |#1|) (-1136)) CONST)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1999 (($ $) NIL (|has| (-125 |#1|) (-301)))) (-4115 (((-125 |#1|) $) NIL (|has| (-125 |#1|) (-550)))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-125 |#1|) (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-125 |#1|) (-904)))) (-3850 (((-420 $) $) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1339 (($ $ (-634 (-125 |#1|)) (-634 (-125 |#1|))) NIL (|has| (-125 |#1|) (-303 (-125 |#1|)))) (($ $ (-125 |#1|) (-125 |#1|)) NIL (|has| (-125 |#1|) (-303 (-125 |#1|)))) (($ $ (-288 (-125 |#1|))) NIL (|has| (-125 |#1|) (-303 (-125 |#1|)))) (($ $ (-634 (-288 (-125 |#1|)))) NIL (|has| (-125 |#1|) (-303 (-125 |#1|)))) (($ $ (-634 (-1161)) (-634 (-125 |#1|))) NIL (|has| (-125 |#1|) (-523 (-1161) (-125 |#1|)))) (($ $ (-1161) (-125 |#1|)) NIL (|has| (-125 |#1|) (-523 (-1161) (-125 |#1|))))) (-1466 (((-763) $) NIL)) (-2781 (($ $ (-125 |#1|)) NIL (|has| (-125 |#1|) (-281 (-125 |#1|) (-125 |#1|))))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-4191 (($ $) NIL (|has| (-125 |#1|) (-225))) (($ $ (-763)) NIL (|has| (-125 |#1|) (-225))) (($ $ (-1161)) NIL (|has| (-125 |#1|) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-125 |#1|) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-125 |#1|) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-125 |#1|) (-895 (-1161)))) (($ $ (-1 (-125 |#1|) (-125 |#1|)) (-763)) NIL) (($ $ (-1 (-125 |#1|) (-125 |#1|))) NIL)) (-3210 (($ $) NIL)) (-2326 (((-125 |#1|) $) NIL)) (-4280 (((-887 (-568)) $) NIL (|has| (-125 |#1|) (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| (-125 |#1|) (-609 (-887 (-381))))) (((-541) $) NIL (|has| (-125 |#1|) (-609 (-541)))) (((-381) $) NIL (|has| (-125 |#1|) (-1021))) (((-215) $) NIL (|has| (-125 |#1|) (-1021)))) (-1991 (((-173 (-409 (-568))) $) NIL)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| (-125 |#1|) (-904))))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ (-125 |#1|)) NIL) (($ (-1161)) NIL (|has| (-125 |#1|) (-1037 (-1161))))) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| (-125 |#1|) (-904))) (|has| (-125 |#1|) (-148))))) (-3425 (((-763)) NIL)) (-3520 (((-125 |#1|) $) NIL (|has| (-125 |#1|) (-550)))) (-2273 (((-121) $ $) NIL)) (-3999 (((-409 (-568)) $ (-568)) NIL)) (-2811 (($ $) NIL (|has| (-125 |#1|) (-815)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $) NIL (|has| (-125 |#1|) (-225))) (($ $ (-763)) NIL (|has| (-125 |#1|) (-225))) (($ $ (-1161)) NIL (|has| (-125 |#1|) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-125 |#1|) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-125 |#1|) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-125 |#1|) (-895 (-1161)))) (($ $ (-1 (-125 |#1|) (-125 |#1|)) (-763)) NIL) (($ $ (-1 (-125 |#1|) (-125 |#1|))) NIL)) (-1753 (((-121) $ $) NIL (|has| (-125 |#1|) (-842)))) (-1740 (((-121) $ $) NIL (|has| (-125 |#1|) (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| (-125 |#1|) (-842)))) (-1734 (((-121) $ $) NIL (|has| (-125 |#1|) (-842)))) (-1781 (($ $ $) NIL) (($ (-125 |#1|) (-125 |#1|)) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ (-125 |#1|) $) NIL) (($ $ (-125 |#1|)) NIL))) 
+(((-126 |#1|) (-13 (-993 (-125 |#1|)) (-10 -8 (-15 -3999 ((-409 (-568)) $ (-568))) (-15 -1991 ((-173 (-409 (-568))) $)) (-15 -2232 ($ $)) (-15 -2232 ($ (-568) $)))) (-568)) (T -126)) 
+((-3999 (*1 *2 *1 *3) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-126 *4)) (-14 *4 *3) (-5 *3 (-568)))) (-1991 (*1 *2 *1) (-12 (-5 *2 (-173 (-409 (-568)))) (-5 *1 (-126 *3)) (-14 *3 (-568)))) (-2232 (*1 *1 *1) (-12 (-5 *1 (-126 *2)) (-14 *2 (-568)))) (-2232 (*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-126 *3)) (-14 *3 *2)))) 
+(-13 (-993 (-125 |#1|)) (-10 -8 (-15 -3999 ((-409 (-568)) $ (-568))) (-15 -1991 ((-173 (-409 (-568))) $)) (-15 -2232 ($ $)) (-15 -2232 ($ (-568) $)))) 
+((-2438 ((|#2| $ "value" |#2|) NIL) (($ $ "left" $) 48) (($ $ "right" $) 50)) (-3534 (((-634 $) $) 27)) (-3606 (((-121) $ $) 32)) (-2551 (((-121) |#2| $) 36)) (-4081 (((-634 |#2|) $) 22)) (-3319 (((-121) $) 16)) (-2781 ((|#2| $ "value") NIL) (($ $ "left") 10) (($ $ "right") 13)) (-2763 (((-121) $) 45)) (-2747 (((-850) $) 41)) (-3180 (((-634 $) $) 28)) (-1719 (((-121) $ $) 34)) (-1699 (((-763) $) 43))) 
+(((-127 |#1| |#2|) (-10 -8 (-15 -2438 (|#1| |#1| "right" |#1|)) (-15 -2438 (|#1| |#1| "left" |#1|)) (-15 -2781 (|#1| |#1| "right")) (-15 -2781 (|#1| |#1| "left")) (-15 -2438 (|#2| |#1| "value" |#2|)) (-15 -3606 ((-121) |#1| |#1|)) (-15 -4081 ((-634 |#2|) |#1|)) (-15 -2763 ((-121) |#1|)) (-15 -2781 (|#2| |#1| "value")) (-15 -3319 ((-121) |#1|)) (-15 -3534 ((-634 |#1|) |#1|)) (-15 -3180 ((-634 |#1|) |#1|)) (-15 -1719 ((-121) |#1| |#1|)) (-15 -2747 ((-850) |#1|)) (-15 -2551 ((-121) |#2| |#1|)) (-15 -1699 ((-763) |#1|))) (-128 |#2|) (-1195)) (T -127)) 
+NIL 
+(-10 -8 (-15 -2438 (|#1| |#1| "right" |#1|)) (-15 -2438 (|#1| |#1| "left" |#1|)) (-15 -2781 (|#1| |#1| "right")) (-15 -2781 (|#1| |#1| "left")) (-15 -2438 (|#2| |#1| "value" |#2|)) (-15 -3606 ((-121) |#1| |#1|)) (-15 -4081 ((-634 |#2|) |#1|)) (-15 -2763 ((-121) |#1|)) (-15 -2781 (|#2| |#1| "value")) (-15 -3319 ((-121) |#1|)) (-15 -3534 ((-634 |#1|) |#1|)) (-15 -3180 ((-634 |#1|) |#1|)) (-15 -1719 ((-121) |#1| |#1|)) (-15 -2747 ((-850) |#1|)) (-15 -2551 ((-121) |#2| |#1|)) (-15 -1699 ((-763) |#1|))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2852 ((|#1| $) 45)) (-1667 (((-121) $ (-763)) 8)) (-3370 ((|#1| $ |#1|) 36 (|has| $ (-6 -4522)))) (-3892 (($ $ $) 49 (|has| $ (-6 -4522)))) (-2458 (($ $ $) 51 (|has| $ (-6 -4522)))) (-2438 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4522))) (($ $ "left" $) 52 (|has| $ (-6 -4522))) (($ $ "right" $) 50 (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) 38 (|has| $ (-6 -4522)))) (-4490 (($) 7 T CONST)) (-3286 (($ $) 54)) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-3534 (((-634 $) $) 47)) (-3606 (((-121) $ $) 39 (|has| |#1| (-1090)))) (-3791 (((-121) $ (-763)) 9)) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35)) (-3796 (((-121) $ (-763)) 10)) (-3030 (($ $) 56)) (-4081 (((-634 |#1|) $) 42)) (-3319 (((-121) $) 46)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 ((|#1| $ "value") 44) (($ $ "left") 55) (($ $ "right") 53)) (-1665 (((-568) $ $) 41)) (-2763 (((-121) $) 43)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-3180 (((-634 $) $) 48)) (-3873 (((-121) $ $) 40 (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-128 |#1|) (-1275) (-1195)) (T -128)) 
-((-3028 (*1 *1 *1) (-12 (-4 *1 (-128 *2)) (-4 *2 (-1195)))) (-2779 (*1 *1 *1 *2) (-12 (-5 *2 "left") (-4 *1 (-128 *3)) (-4 *3 (-1195)))) (-3284 (*1 *1 *1) (-12 (-4 *1 (-128 *2)) (-4 *2 (-1195)))) (-2779 (*1 *1 *1 *2) (-12 (-5 *2 "right") (-4 *1 (-128 *3)) (-4 *3 (-1195)))) (-2436 (*1 *1 *1 *2 *1) (-12 (-5 *2 "left") (|has| *1 (-6 -4520)) (-4 *1 (-128 *3)) (-4 *3 (-1195)))) (-3089 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-128 *2)) (-4 *2 (-1195)))) (-2436 (*1 *1 *1 *2 *1) (-12 (-5 *2 "right") (|has| *1 (-6 -4520)) (-4 *1 (-128 *3)) (-4 *3 (-1195)))) (-3497 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-128 *2)) (-4 *2 (-1195))))) 
-(-13 (-1010 |t#1|) (-10 -8 (-15 -3028 ($ $)) (-15 -2779 ($ $ "left")) (-15 -3284 ($ $)) (-15 -2779 ($ $ "right")) (IF (|has| $ (-6 -4520)) (PROGN (-15 -2436 ($ $ "left" $)) (-15 -3089 ($ $ $)) (-15 -2436 ($ $ "right" $)) (-15 -3497 ($ $ $))) |noBranch|))) 
+((-3030 (*1 *1 *1) (-12 (-4 *1 (-128 *2)) (-4 *2 (-1195)))) (-2781 (*1 *1 *1 *2) (-12 (-5 *2 "left") (-4 *1 (-128 *3)) (-4 *3 (-1195)))) (-3286 (*1 *1 *1) (-12 (-4 *1 (-128 *2)) (-4 *2 (-1195)))) (-2781 (*1 *1 *1 *2) (-12 (-5 *2 "right") (-4 *1 (-128 *3)) (-4 *3 (-1195)))) (-2438 (*1 *1 *1 *2 *1) (-12 (-5 *2 "left") (|has| *1 (-6 -4522)) (-4 *1 (-128 *3)) (-4 *3 (-1195)))) (-2458 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-128 *2)) (-4 *2 (-1195)))) (-2438 (*1 *1 *1 *2 *1) (-12 (-5 *2 "right") (|has| *1 (-6 -4522)) (-4 *1 (-128 *3)) (-4 *3 (-1195)))) (-3892 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-128 *2)) (-4 *2 (-1195))))) 
+(-13 (-1010 |t#1|) (-10 -8 (-15 -3030 ($ $)) (-15 -2781 ($ $ "left")) (-15 -3286 ($ $)) (-15 -2781 ($ $ "right")) (IF (|has| $ (-6 -4522)) (PROGN (-15 -2438 ($ $ "left" $)) (-15 -2458 ($ $ $)) (-15 -2438 ($ $ "right" $)) (-15 -3892 ($ $ $))) |noBranch|))) 
 (((-39) . T) ((-105) |has| |#1| (-1090)) ((-608 (-850)) |has| |#1| (-1090)) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-1010 |#1|) . T) ((-1090) |has| |#1| (-1090)) ((-1195) . T)) 
-((-1516 (((-121) |#1|) 24)) (-3375 (((-763) (-763)) 23) (((-763)) 22)) (-2663 (((-121) |#1| (-121)) 25) (((-121) |#1|) 26))) 
-(((-129 |#1|) (-10 -7 (-15 -2663 ((-121) |#1|)) (-15 -2663 ((-121) |#1| (-121))) (-15 -3375 ((-763))) (-15 -3375 ((-763) (-763))) (-15 -1516 ((-121) |#1|))) (-1219 (-568))) (T -129)) 
-((-1516 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-129 *3)) (-4 *3 (-1219 (-568))))) (-3375 (*1 *2 *2) (-12 (-5 *2 (-763)) (-5 *1 (-129 *3)) (-4 *3 (-1219 (-568))))) (-3375 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-129 *3)) (-4 *3 (-1219 (-568))))) (-2663 (*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *1 (-129 *3)) (-4 *3 (-1219 (-568))))) (-2663 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-129 *3)) (-4 *3 (-1219 (-568)))))) 
-(-10 -7 (-15 -2663 ((-121) |#1|)) (-15 -2663 ((-121) |#1| (-121))) (-15 -3375 ((-763))) (-15 -3375 ((-763) (-763))) (-15 -1516 ((-121) |#1|))) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2850 ((|#1| $) 15)) (-3969 (((-2 (|:| |less| $) (|:| |greater| $)) |#1| $) 22)) (-2510 (((-121) $ (-763)) NIL)) (-1659 ((|#1| $ |#1|) NIL (|has| $ (-6 -4520)))) (-3497 (($ $ $) 18 (|has| $ (-6 -4520)))) (-3089 (($ $ $) 20 (|has| $ (-6 -4520)))) (-2436 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4520))) (($ $ "left" $) NIL (|has| $ (-6 -4520))) (($ $ "right" $) NIL (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) NIL (|has| $ (-6 -4520)))) (-2671 (($) NIL T CONST)) (-3284 (($ $) 17)) (-4360 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-2287 (((-634 $) $) NIL)) (-1700 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3341 (($ $ |#1| $) 23)) (-1737 (((-121) $ (-763)) NIL)) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3674 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-3028 (($ $) 19)) (-2869 (((-634 |#1|) $) NIL)) (-1651 (((-121) $) NIL)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-1358 (($ |#1| $) 24)) (-4450 (($ |#1| $) 10)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) 14)) (-3248 (($) 8)) (-2779 ((|#1| $ "value") NIL) (($ $ "left") NIL) (($ $ "right") NIL)) (-4075 (((-568) $ $) NIL)) (-3790 (((-121) $) NIL)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) NIL)) (-2745 (((-850) $) NIL (|has| |#1| (-1090)))) (-4339 (((-634 $) $) NIL)) (-3491 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1698 (($ (-634 |#1|)) 12)) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-130 |#1|) (-13 (-134 |#1|) (-10 -8 (-6 -4520) (-6 -4519) (-15 -1698 ($ (-634 |#1|))) (-15 -4450 ($ |#1| $)) (-15 -1358 ($ |#1| $)) (-15 -3969 ((-2 (|:| |less| $) (|:| |greater| $)) |#1| $)))) (-842)) (T -130)) 
-((-1698 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-130 *3)))) (-4450 (*1 *1 *2 *1) (-12 (-5 *1 (-130 *2)) (-4 *2 (-842)))) (-1358 (*1 *1 *2 *1) (-12 (-5 *1 (-130 *2)) (-4 *2 (-842)))) (-3969 (*1 *2 *3 *1) (-12 (-5 *2 (-2 (|:| |less| (-130 *3)) (|:| |greater| (-130 *3)))) (-5 *1 (-130 *3)) (-4 *3 (-842))))) 
-(-13 (-134 |#1|) (-10 -8 (-6 -4520) (-6 -4519) (-15 -1698 ($ (-634 |#1|))) (-15 -4450 ($ |#1| $)) (-15 -1358 ($ |#1| $)) (-15 -3969 ((-2 (|:| |less| $) (|:| |greater| $)) |#1| $)))) 
-((-1611 (($ $) 14)) (-3044 (($ $) 11)) (-2460 (($ $ $) 24)) (-3339 (($ $ $) 22)) (-1887 (($ $) 12)) (-2430 (($ $ $) 20)) (-2424 (($ $ $) 18))) 
-(((-131 |#1|) (-10 -8 (-15 -2460 (|#1| |#1| |#1|)) (-15 -3339 (|#1| |#1| |#1|)) (-15 -1887 (|#1| |#1|)) (-15 -3044 (|#1| |#1|)) (-15 -1611 (|#1| |#1|)) (-15 -2424 (|#1| |#1| |#1|)) (-15 -2430 (|#1| |#1| |#1|))) (-132)) (T -131)) 
-NIL 
-(-10 -8 (-15 -2460 (|#1| |#1| |#1|)) (-15 -3339 (|#1| |#1| |#1|)) (-15 -1887 (|#1| |#1|)) (-15 -3044 (|#1| |#1|)) (-15 -1611 (|#1| |#1|)) (-15 -2424 (|#1| |#1| |#1|)) (-15 -2430 (|#1| |#1| |#1|))) 
-((-2447 (((-121) $ $) 7)) (-1611 (($ $) 103)) (-3091 (($ $ $) 24)) (-1868 (((-1249) $ (-568) (-568)) 66 (|has| $ (-6 -4520)))) (-2016 (((-121) $) 98 (|has| (-121) (-842))) (((-121) (-1 (-121) (-121) (-121)) $) 92)) (-3908 (($ $) 102 (-12 (|has| (-121) (-842)) (|has| $ (-6 -4520)))) (($ (-1 (-121) (-121) (-121)) $) 101 (|has| $ (-6 -4520)))) (-3644 (($ $) 97 (|has| (-121) (-842))) (($ (-1 (-121) (-121) (-121)) $) 91)) (-2510 (((-121) $ (-763)) 37)) (-2436 (((-121) $ (-1210 (-568)) (-121)) 88 (|has| $ (-6 -4520))) (((-121) $ (-568) (-121)) 54 (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) (-121)) $) 71 (|has| $ (-6 -4519)))) (-2671 (($) 38 T CONST)) (-1578 (($ $) 100 (|has| $ (-6 -4520)))) (-3943 (($ $) 90)) (-3924 (($ $) 68 (-12 (|has| (-121) (-1090)) (|has| $ (-6 -4519))))) (-4328 (($ (-1 (-121) (-121)) $) 72 (|has| $ (-6 -4519))) (($ (-121) $) 69 (-12 (|has| (-121) (-1090)) (|has| $ (-6 -4519))))) (-3092 (((-121) (-1 (-121) (-121) (-121)) $) 74 (|has| $ (-6 -4519))) (((-121) (-1 (-121) (-121) (-121)) $ (-121)) 73 (|has| $ (-6 -4519))) (((-121) (-1 (-121) (-121) (-121)) $ (-121) (-121)) 70 (-12 (|has| (-121) (-1090)) (|has| $ (-6 -4519))))) (-3989 (((-121) $ (-568) (-121)) 53 (|has| $ (-6 -4520)))) (-2602 (((-121) $ (-568)) 55)) (-2764 (((-568) (-121) $ (-568)) 95 (|has| (-121) (-1090))) (((-568) (-121) $) 94 (|has| (-121) (-1090))) (((-568) (-1 (-121) (-121)) $) 93)) (-4360 (((-634 (-121)) $) 45 (|has| $ (-6 -4519)))) (-3104 (($ $ $) 25)) (-3044 (($ $) 30)) (-2460 (($ $ $) 27)) (-1849 (($ (-763) (-121)) 77)) (-3339 (($ $ $) 28)) (-1737 (((-121) $ (-763)) 36)) (-1881 (((-568) $) 63 (|has| (-568) (-842)))) (-2521 (($ $ $) 12)) (-1347 (($ $ $) 96 (|has| (-121) (-842))) (($ (-1 (-121) (-121) (-121)) $ $) 89)) (-1979 (((-634 (-121)) $) 46 (|has| $ (-6 -4519)))) (-3109 (((-121) (-121) $) 48 (-12 (|has| (-121) (-1090)) (|has| $ (-6 -4519))))) (-2223 (((-568) $) 62 (|has| (-568) (-842)))) (-3268 (($ $ $) 13)) (-3674 (($ (-1 (-121) (-121)) $) 41 (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-121) (-121) (-121)) $ $) 82) (($ (-1 (-121) (-121)) $) 40)) (-2166 (((-121) $ (-763)) 35)) (-4487 (((-1143) $) 9)) (-4122 (($ $ $ (-568)) 87) (($ (-121) $ (-568)) 86)) (-4174 (((-634 (-568)) $) 60)) (-3578 (((-121) (-568) $) 59)) (-4022 (((-1108) $) 10)) (-3876 (((-121) $) 64 (|has| (-568) (-842)))) (-3775 (((-3 (-121) "failed") (-1 (-121) (-121)) $) 75)) (-3724 (($ $ (-121)) 65 (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) (-121)) $) 43 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-121)) (-634 (-121))) 52 (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090)))) (($ $ (-121) (-121)) 51 (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090)))) (($ $ (-288 (-121))) 50 (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090)))) (($ $ (-634 (-288 (-121)))) 49 (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090))))) (-3171 (((-121) $ $) 31)) (-4467 (((-121) (-121) $) 61 (-12 (|has| $ (-6 -4519)) (|has| (-121) (-1090))))) (-2041 (((-634 (-121)) $) 58)) (-3084 (((-121) $) 34)) (-3248 (($) 33)) (-2779 (($ $ (-1210 (-568))) 83) (((-121) $ (-568)) 57) (((-121) $ (-568) (-121)) 56)) (-2826 (($ $ (-1210 (-568))) 85) (($ $ (-568)) 84)) (-4168 (((-763) (-121) $) 47 (-12 (|has| (-121) (-1090)) (|has| $ (-6 -4519)))) (((-763) (-1 (-121) (-121)) $) 44 (|has| $ (-6 -4519)))) (-2256 (($ $ $ (-568)) 99 (|has| $ (-6 -4520)))) (-3863 (($ $) 32)) (-4278 (((-541) $) 67 (|has| (-121) (-609 (-541))))) (-4287 (($ (-634 (-121))) 76)) (-2768 (($ (-634 $)) 81) (($ $ $) 80) (($ (-121) $) 79) (($ $ (-121)) 78)) (-2745 (((-850) $) 11)) (-1319 (((-121) (-1 (-121) (-121)) $) 42 (|has| $ (-6 -4519)))) (-2139 (($ $ $) 26)) (-1887 (($ $) 29)) (-2430 (($ $ $) 105)) (-1751 (((-121) $ $) 15)) (-1738 (((-121) $ $) 16)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 14)) (-1732 (((-121) $ $) 17)) (-2424 (($ $ $) 104)) (-1697 (((-763) $) 39 (|has| $ (-6 -4519))))) 
+((-4092 (((-121) |#1|) 24)) (-1414 (((-763) (-763)) 23) (((-763)) 22)) (-4449 (((-121) |#1| (-121)) 25) (((-121) |#1|) 26))) 
+(((-129 |#1|) (-10 -7 (-15 -4449 ((-121) |#1|)) (-15 -4449 ((-121) |#1| (-121))) (-15 -1414 ((-763))) (-15 -1414 ((-763) (-763))) (-15 -4092 ((-121) |#1|))) (-1219 (-568))) (T -129)) 
+((-4092 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-129 *3)) (-4 *3 (-1219 (-568))))) (-1414 (*1 *2 *2) (-12 (-5 *2 (-763)) (-5 *1 (-129 *3)) (-4 *3 (-1219 (-568))))) (-1414 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-129 *3)) (-4 *3 (-1219 (-568))))) (-4449 (*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *1 (-129 *3)) (-4 *3 (-1219 (-568))))) (-4449 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-129 *3)) (-4 *3 (-1219 (-568)))))) 
+(-10 -7 (-15 -4449 ((-121) |#1|)) (-15 -4449 ((-121) |#1| (-121))) (-15 -1414 ((-763))) (-15 -1414 ((-763) (-763))) (-15 -4092 ((-121) |#1|))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2852 ((|#1| $) 15)) (-4446 (((-2 (|:| |less| $) (|:| |greater| $)) |#1| $) 22)) (-1667 (((-121) $ (-763)) NIL)) (-3370 ((|#1| $ |#1|) NIL (|has| $ (-6 -4522)))) (-3892 (($ $ $) 18 (|has| $ (-6 -4522)))) (-2458 (($ $ $) 20 (|has| $ (-6 -4522)))) (-2438 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4522))) (($ $ "left" $) NIL (|has| $ (-6 -4522))) (($ $ "right" $) NIL (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) NIL (|has| $ (-6 -4522)))) (-4490 (($) NIL T CONST)) (-3286 (($ $) 17)) (-3317 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-3534 (((-634 $) $) NIL)) (-3606 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-4455 (($ $ |#1| $) 23)) (-3791 (((-121) $ (-763)) NIL)) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-2253 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-3030 (($ $) 19)) (-4081 (((-634 |#1|) $) NIL)) (-3319 (((-121) $) NIL)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-3732 (($ |#1| $) 24)) (-1708 (($ |#1| $) 10)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) 14)) (-1990 (($) 8)) (-2781 ((|#1| $ "value") NIL) (($ $ "left") NIL) (($ $ "right") NIL)) (-1665 (((-568) $ $) NIL)) (-2763 (((-121) $) NIL)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) NIL)) (-2747 (((-850) $) NIL (|has| |#1| (-1090)))) (-3180 (((-634 $) $) NIL)) (-3873 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3590 (($ (-634 |#1|)) 12)) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-130 |#1|) (-13 (-134 |#1|) (-10 -8 (-6 -4522) (-6 -4521) (-15 -3590 ($ (-634 |#1|))) (-15 -1708 ($ |#1| $)) (-15 -3732 ($ |#1| $)) (-15 -4446 ((-2 (|:| |less| $) (|:| |greater| $)) |#1| $)))) (-842)) (T -130)) 
+((-3590 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-130 *3)))) (-1708 (*1 *1 *2 *1) (-12 (-5 *1 (-130 *2)) (-4 *2 (-842)))) (-3732 (*1 *1 *2 *1) (-12 (-5 *1 (-130 *2)) (-4 *2 (-842)))) (-4446 (*1 *2 *3 *1) (-12 (-5 *2 (-2 (|:| |less| (-130 *3)) (|:| |greater| (-130 *3)))) (-5 *1 (-130 *3)) (-4 *3 (-842))))) 
+(-13 (-134 |#1|) (-10 -8 (-6 -4522) (-6 -4521) (-15 -3590 ($ (-634 |#1|))) (-15 -1708 ($ |#1| $)) (-15 -3732 ($ |#1| $)) (-15 -4446 ((-2 (|:| |less| $) (|:| |greater| $)) |#1| $)))) 
+((-1613 (($ $) 14)) (-3046 (($ $) 11)) (-2570 (($ $ $) 24)) (-4445 (($ $ $) 22)) (-1889 (($ $) 12)) (-2432 (($ $ $) 20)) (-2426 (($ $ $) 18))) 
+(((-131 |#1|) (-10 -8 (-15 -2570 (|#1| |#1| |#1|)) (-15 -4445 (|#1| |#1| |#1|)) (-15 -1889 (|#1| |#1|)) (-15 -3046 (|#1| |#1|)) (-15 -1613 (|#1| |#1|)) (-15 -2426 (|#1| |#1| |#1|)) (-15 -2432 (|#1| |#1| |#1|))) (-132)) (T -131)) 
+NIL 
+(-10 -8 (-15 -2570 (|#1| |#1| |#1|)) (-15 -4445 (|#1| |#1| |#1|)) (-15 -1889 (|#1| |#1|)) (-15 -3046 (|#1| |#1|)) (-15 -1613 (|#1| |#1|)) (-15 -2426 (|#1| |#1| |#1|)) (-15 -2432 (|#1| |#1| |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1613 (($ $) 103)) (-3093 (($ $ $) 24)) (-2481 (((-1249) $ (-568) (-568)) 66 (|has| $ (-6 -4522)))) (-1324 (((-121) $) 98 (|has| (-121) (-842))) (((-121) (-1 (-121) (-121) (-121)) $) 92)) (-2109 (($ $) 102 (-12 (|has| (-121) (-842)) (|has| $ (-6 -4522)))) (($ (-1 (-121) (-121) (-121)) $) 101 (|has| $ (-6 -4522)))) (-3647 (($ $) 97 (|has| (-121) (-842))) (($ (-1 (-121) (-121) (-121)) $) 91)) (-1667 (((-121) $ (-763)) 37)) (-2438 (((-121) $ (-1210 (-568)) (-121)) 88 (|has| $ (-6 -4522))) (((-121) $ (-568) (-121)) 54 (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) (-121)) $) 71 (|has| $ (-6 -4521)))) (-4490 (($) 38 T CONST)) (-4452 (($ $) 100 (|has| $ (-6 -4522)))) (-3945 (($ $) 90)) (-3926 (($ $) 68 (-12 (|has| (-121) (-1090)) (|has| $ (-6 -4521))))) (-4330 (($ (-1 (-121) (-121)) $) 72 (|has| $ (-6 -4521))) (($ (-121) $) 69 (-12 (|has| (-121) (-1090)) (|has| $ (-6 -4521))))) (-3094 (((-121) (-1 (-121) (-121) (-121)) $) 74 (|has| $ (-6 -4521))) (((-121) (-1 (-121) (-121) (-121)) $ (-121)) 73 (|has| $ (-6 -4521))) (((-121) (-1 (-121) (-121) (-121)) $ (-121) (-121)) 70 (-12 (|has| (-121) (-1090)) (|has| $ (-6 -4521))))) (-1292 (((-121) $ (-568) (-121)) 53 (|has| $ (-6 -4522)))) (-2069 (((-121) $ (-568)) 55)) (-2766 (((-568) (-121) $ (-568)) 95 (|has| (-121) (-1090))) (((-568) (-121) $) 94 (|has| (-121) (-1090))) (((-568) (-1 (-121) (-121)) $) 93)) (-3317 (((-634 (-121)) $) 45 (|has| $ (-6 -4521)))) (-3107 (($ $ $) 25)) (-3046 (($ $) 30)) (-2570 (($ $ $) 27)) (-1851 (($ (-763) (-121)) 77)) (-4445 (($ $ $) 28)) (-3791 (((-121) $ (-763)) 36)) (-2539 (((-568) $) 63 (|has| (-568) (-842)))) (-1732 (($ $ $) 12)) (-3645 (($ $ $) 96 (|has| (-121) (-842))) (($ (-1 (-121) (-121) (-121)) $ $) 89)) (-4406 (((-634 (-121)) $) 46 (|has| $ (-6 -4521)))) (-2551 (((-121) (-121) $) 48 (-12 (|has| (-121) (-1090)) (|has| $ (-6 -4521))))) (-3631 (((-568) $) 62 (|has| (-568) (-842)))) (-2047 (($ $ $) 13)) (-2253 (($ (-1 (-121) (-121)) $) 41 (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-121) (-121) (-121)) $ $) 82) (($ (-1 (-121) (-121)) $) 40)) (-3796 (((-121) $ (-763)) 35)) (-1893 (((-1143) $) 9)) (-4124 (($ $ $ (-568)) 87) (($ (-121) $ (-568)) 86)) (-3948 (((-634 (-568)) $) 60)) (-2916 (((-121) (-568) $) 59)) (-4025 (((-1108) $) 10)) (-3877 (((-121) $) 64 (|has| (-568) (-842)))) (-2712 (((-3 (-121) "failed") (-1 (-121) (-121)) $) 75)) (-2490 (($ $ (-121)) 65 (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) (-121)) $) 43 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-121)) (-634 (-121))) 52 (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090)))) (($ $ (-121) (-121)) 51 (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090)))) (($ $ (-288 (-121))) 50 (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090)))) (($ $ (-634 (-288 (-121)))) 49 (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090))))) (-1702 (((-121) $ $) 31)) (-1801 (((-121) (-121) $) 61 (-12 (|has| $ (-6 -4521)) (|has| (-121) (-1090))))) (-1480 (((-634 (-121)) $) 58)) (-2436 (((-121) $) 34)) (-1990 (($) 33)) (-2781 (($ $ (-1210 (-568))) 83) (((-121) $ (-568)) 57) (((-121) $ (-568) (-121)) 56)) (-2828 (($ $ (-1210 (-568))) 85) (($ $ (-568)) 84)) (-4170 (((-763) (-121) $) 47 (-12 (|has| (-121) (-1090)) (|has| $ (-6 -4521)))) (((-763) (-1 (-121) (-121)) $) 44 (|has| $ (-6 -4521)))) (-3306 (($ $ $ (-568)) 99 (|has| $ (-6 -4522)))) (-3865 (($ $) 32)) (-4280 (((-541) $) 67 (|has| (-121) (-609 (-541))))) (-4289 (($ (-634 (-121))) 76)) (-2770 (($ (-634 $)) 81) (($ $ $) 80) (($ (-121) $) 79) (($ $ (-121)) 78)) (-2747 (((-850) $) 11)) (-3437 (((-121) (-1 (-121) (-121)) $) 42 (|has| $ (-6 -4521)))) (-2141 (($ $ $) 26)) (-1889 (($ $) 29)) (-2432 (($ $ $) 105)) (-1753 (((-121) $ $) 15)) (-1740 (((-121) $ $) 16)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 14)) (-1734 (((-121) $ $) 17)) (-2426 (($ $ $) 104)) (-1699 (((-763) $) 39 (|has| $ (-6 -4521))))) 
 (((-132) (-1275)) (T -132)) 
-((-3044 (*1 *1 *1) (-4 *1 (-132))) (-1887 (*1 *1 *1) (-4 *1 (-132))) (-3339 (*1 *1 *1 *1) (-4 *1 (-132))) (-2460 (*1 *1 *1 *1) (-4 *1 (-132))) (-2139 (*1 *1 *1 *1) (-4 *1 (-132))) (-3104 (*1 *1 *1 *1) (-4 *1 (-132))) (-3091 (*1 *1 *1 *1) (-4 *1 (-132)))) 
-(-13 (-842) (-651) (-19 (-121)) (-10 -8 (-15 -3044 ($ $)) (-15 -1887 ($ $)) (-15 -3339 ($ $ $)) (-15 -2460 ($ $ $)) (-15 -2139 ($ $ $)) (-15 -3104 ($ $ $)) (-15 -3091 ($ $ $)))) 
+((-3046 (*1 *1 *1) (-4 *1 (-132))) (-1889 (*1 *1 *1) (-4 *1 (-132))) (-4445 (*1 *1 *1 *1) (-4 *1 (-132))) (-2570 (*1 *1 *1 *1) (-4 *1 (-132))) (-2141 (*1 *1 *1 *1) (-4 *1 (-132))) (-3107 (*1 *1 *1 *1) (-4 *1 (-132))) (-3093 (*1 *1 *1 *1) (-4 *1 (-132)))) 
+(-13 (-842) (-651) (-19 (-121)) (-10 -8 (-15 -3046 ($ $)) (-15 -1889 ($ $)) (-15 -4445 ($ $ $)) (-15 -2570 ($ $ $)) (-15 -2141 ($ $ $)) (-15 -3107 ($ $ $)) (-15 -3093 ($ $ $)))) 
 (((-39) . T) ((-105) . T) ((-608 (-850)) . T) ((-154 (-121)) . T) ((-609 (-541)) |has| (-121) (-609 (-541))) ((-281 (-568) (-121)) . T) ((-283 (-568) (-121)) . T) ((-303 (-121)) -12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090))) ((-375 (-121)) . T) ((-499 (-121)) . T) ((-601 (-568) (-121)) . T) ((-523 (-121) (-121)) -12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090))) ((-640 (-121)) . T) ((-651) . T) ((-19 (-121)) . T) ((-842) . T) ((-1090) . T) ((-1195) . T)) 
-((-3674 (($ (-1 |#2| |#2|) $) 22)) (-3863 (($ $) 16)) (-1697 (((-763) $) 24))) 
-(((-133 |#1| |#2|) (-10 -8 (-15 -3674 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -1697 ((-763) |#1|)) (-15 -3863 (|#1| |#1|))) (-134 |#2|) (-1090)) (T -133)) 
+((-2253 (($ (-1 |#2| |#2|) $) 22)) (-3865 (($ $) 16)) (-1699 (((-763) $) 24))) 
+(((-133 |#1| |#2|) (-10 -8 (-15 -2253 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -1699 ((-763) |#1|)) (-15 -3865 (|#1| |#1|))) (-134 |#2|) (-1090)) (T -133)) 
 NIL 
-(-10 -8 (-15 -3674 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -1697 ((-763) |#1|)) (-15 -3863 (|#1| |#1|))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2850 ((|#1| $) 45)) (-2510 (((-121) $ (-763)) 8)) (-1659 ((|#1| $ |#1|) 36 (|has| $ (-6 -4520)))) (-3497 (($ $ $) 49 (|has| $ (-6 -4520)))) (-3089 (($ $ $) 51 (|has| $ (-6 -4520)))) (-2436 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4520))) (($ $ "left" $) 52 (|has| $ (-6 -4520))) (($ $ "right" $) 50 (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) 38 (|has| $ (-6 -4520)))) (-2671 (($) 7 T CONST)) (-3284 (($ $) 54)) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-2287 (((-634 $) $) 47)) (-1700 (((-121) $ $) 39 (|has| |#1| (-1090)))) (-3341 (($ $ |#1| $) 57)) (-1737 (((-121) $ (-763)) 9)) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35)) (-2166 (((-121) $ (-763)) 10)) (-3028 (($ $) 56)) (-2869 (((-634 |#1|) $) 42)) (-1651 (((-121) $) 46)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 ((|#1| $ "value") 44) (($ $ "left") 55) (($ $ "right") 53)) (-4075 (((-568) $ $) 41)) (-3790 (((-121) $) 43)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-4339 (((-634 $) $) 48)) (-3491 (((-121) $ $) 40 (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+(-10 -8 (-15 -2253 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -1699 ((-763) |#1|)) (-15 -3865 (|#1| |#1|))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2852 ((|#1| $) 45)) (-1667 (((-121) $ (-763)) 8)) (-3370 ((|#1| $ |#1|) 36 (|has| $ (-6 -4522)))) (-3892 (($ $ $) 49 (|has| $ (-6 -4522)))) (-2458 (($ $ $) 51 (|has| $ (-6 -4522)))) (-2438 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4522))) (($ $ "left" $) 52 (|has| $ (-6 -4522))) (($ $ "right" $) 50 (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) 38 (|has| $ (-6 -4522)))) (-4490 (($) 7 T CONST)) (-3286 (($ $) 54)) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-3534 (((-634 $) $) 47)) (-3606 (((-121) $ $) 39 (|has| |#1| (-1090)))) (-4455 (($ $ |#1| $) 57)) (-3791 (((-121) $ (-763)) 9)) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35)) (-3796 (((-121) $ (-763)) 10)) (-3030 (($ $) 56)) (-4081 (((-634 |#1|) $) 42)) (-3319 (((-121) $) 46)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 ((|#1| $ "value") 44) (($ $ "left") 55) (($ $ "right") 53)) (-1665 (((-568) $ $) 41)) (-2763 (((-121) $) 43)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-3180 (((-634 $) $) 48)) (-3873 (((-121) $ $) 40 (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-134 |#1|) (-1275) (-1090)) (T -134)) 
-((-3341 (*1 *1 *1 *2 *1) (-12 (-4 *1 (-134 *2)) (-4 *2 (-1090))))) 
-(-13 (-128 |t#1|) (-10 -8 (-6 -4520) (-6 -4519) (-15 -3341 ($ $ |t#1| $)))) 
+((-4455 (*1 *1 *1 *2 *1) (-12 (-4 *1 (-134 *2)) (-4 *2 (-1090))))) 
+(-13 (-128 |t#1|) (-10 -8 (-6 -4522) (-6 -4521) (-15 -4455 ($ $ |t#1| $)))) 
 (((-39) . T) ((-105) |has| |#1| (-1090)) ((-128 |#1|) . T) ((-608 (-850)) |has| |#1| (-1090)) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-1010 |#1|) . T) ((-1090) |has| |#1| (-1090)) ((-1195) . T)) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2850 ((|#1| $) 15)) (-2510 (((-121) $ (-763)) NIL)) (-1659 ((|#1| $ |#1|) 19 (|has| $ (-6 -4520)))) (-3497 (($ $ $) 20 (|has| $ (-6 -4520)))) (-3089 (($ $ $) 18 (|has| $ (-6 -4520)))) (-2436 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4520))) (($ $ "left" $) NIL (|has| $ (-6 -4520))) (($ $ "right" $) NIL (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) NIL (|has| $ (-6 -4520)))) (-2671 (($) NIL T CONST)) (-3284 (($ $) 21)) (-4360 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-2287 (((-634 $) $) NIL)) (-1700 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3341 (($ $ |#1| $) NIL)) (-1737 (((-121) $ (-763)) NIL)) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3674 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-3028 (($ $) NIL)) (-2869 (((-634 |#1|) $) NIL)) (-1651 (((-121) $) NIL)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4450 (($ |#1| $) 10)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) 14)) (-3248 (($) 8)) (-2779 ((|#1| $ "value") NIL) (($ $ "left") NIL) (($ $ "right") NIL)) (-4075 (((-568) $ $) NIL)) (-3790 (((-121) $) NIL)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) 17)) (-2745 (((-850) $) NIL (|has| |#1| (-1090)))) (-4339 (((-634 $) $) NIL)) (-3491 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1417 (($ (-634 |#1|)) 12)) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-135 |#1|) (-13 (-134 |#1|) (-10 -8 (-6 -4520) (-15 -1417 ($ (-634 |#1|))) (-15 -4450 ($ |#1| $)))) (-842)) (T -135)) 
-((-1417 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-135 *3)))) (-4450 (*1 *1 *2 *1) (-12 (-5 *1 (-135 *2)) (-4 *2 (-842))))) 
-(-13 (-134 |#1|) (-10 -8 (-6 -4520) (-15 -1417 ($ (-634 |#1|))) (-15 -4450 ($ |#1| $)))) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2850 ((|#1| $) 24)) (-2510 (((-121) $ (-763)) NIL)) (-1659 ((|#1| $ |#1|) 26 (|has| $ (-6 -4520)))) (-3497 (($ $ $) 30 (|has| $ (-6 -4520)))) (-3089 (($ $ $) 28 (|has| $ (-6 -4520)))) (-2436 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4520))) (($ $ "left" $) NIL (|has| $ (-6 -4520))) (($ $ "right" $) NIL (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) NIL (|has| $ (-6 -4520)))) (-2671 (($) NIL T CONST)) (-3284 (($ $) 20)) (-4360 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-2287 (((-634 $) $) NIL)) (-1700 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3341 (($ $ |#1| $) 15)) (-1737 (((-121) $ (-763)) NIL)) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3674 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-3028 (($ $) 19)) (-2869 (((-634 |#1|) $) NIL)) (-1651 (((-121) $) 21)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) 18)) (-3248 (($) 11)) (-2779 ((|#1| $ "value") NIL) (($ $ "left") NIL) (($ $ "right") NIL)) (-4075 (((-568) $ $) NIL)) (-3790 (((-121) $) NIL)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) NIL)) (-2745 (((-850) $) NIL (|has| |#1| (-1090)))) (-4339 (((-634 $) $) NIL)) (-3491 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-4121 (($ |#1|) 17) (($ $ |#1| $) 16)) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 10 (|has| |#1| (-1090)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-136 |#1|) (-13 (-134 |#1|) (-10 -8 (-15 -4121 ($ |#1|)) (-15 -4121 ($ $ |#1| $)))) (-1090)) (T -136)) 
-((-4121 (*1 *1 *2) (-12 (-5 *1 (-136 *2)) (-4 *2 (-1090)))) (-4121 (*1 *1 *1 *2 *1) (-12 (-5 *1 (-136 *2)) (-4 *2 (-1090))))) 
-(-13 (-134 |#1|) (-10 -8 (-15 -4121 ($ |#1|)) (-15 -4121 ($ $ |#1| $)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-3056 (($) 17 T CONST)) (-1717 (((-121) $ $) 6)) (-1767 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2852 ((|#1| $) 15)) (-1667 (((-121) $ (-763)) NIL)) (-3370 ((|#1| $ |#1|) 19 (|has| $ (-6 -4522)))) (-3892 (($ $ $) 20 (|has| $ (-6 -4522)))) (-2458 (($ $ $) 18 (|has| $ (-6 -4522)))) (-2438 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4522))) (($ $ "left" $) NIL (|has| $ (-6 -4522))) (($ $ "right" $) NIL (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) NIL (|has| $ (-6 -4522)))) (-4490 (($) NIL T CONST)) (-3286 (($ $) 21)) (-3317 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-3534 (((-634 $) $) NIL)) (-3606 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-4455 (($ $ |#1| $) NIL)) (-3791 (((-121) $ (-763)) NIL)) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-2253 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-3030 (($ $) NIL)) (-4081 (((-634 |#1|) $) NIL)) (-3319 (((-121) $) NIL)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-1708 (($ |#1| $) 10)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) 14)) (-1990 (($) 8)) (-2781 ((|#1| $ "value") NIL) (($ $ "left") NIL) (($ $ "right") NIL)) (-1665 (((-568) $ $) NIL)) (-2763 (((-121) $) NIL)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) 17)) (-2747 (((-850) $) NIL (|has| |#1| (-1090)))) (-3180 (((-634 $) $) NIL)) (-3873 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2167 (($ (-634 |#1|)) 12)) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-135 |#1|) (-13 (-134 |#1|) (-10 -8 (-6 -4522) (-15 -2167 ($ (-634 |#1|))) (-15 -1708 ($ |#1| $)))) (-842)) (T -135)) 
+((-2167 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-135 *3)))) (-1708 (*1 *1 *2 *1) (-12 (-5 *1 (-135 *2)) (-4 *2 (-842))))) 
+(-13 (-134 |#1|) (-10 -8 (-6 -4522) (-15 -2167 ($ (-634 |#1|))) (-15 -1708 ($ |#1| $)))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2852 ((|#1| $) 24)) (-1667 (((-121) $ (-763)) NIL)) (-3370 ((|#1| $ |#1|) 26 (|has| $ (-6 -4522)))) (-3892 (($ $ $) 30 (|has| $ (-6 -4522)))) (-2458 (($ $ $) 28 (|has| $ (-6 -4522)))) (-2438 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4522))) (($ $ "left" $) NIL (|has| $ (-6 -4522))) (($ $ "right" $) NIL (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) NIL (|has| $ (-6 -4522)))) (-4490 (($) NIL T CONST)) (-3286 (($ $) 20)) (-3317 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-3534 (((-634 $) $) NIL)) (-3606 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-4455 (($ $ |#1| $) 15)) (-3791 (((-121) $ (-763)) NIL)) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-2253 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-3030 (($ $) 19)) (-4081 (((-634 |#1|) $) NIL)) (-3319 (((-121) $) 21)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) 18)) (-1990 (($) 11)) (-2781 ((|#1| $ "value") NIL) (($ $ "left") NIL) (($ $ "right") NIL)) (-1665 (((-568) $ $) NIL)) (-2763 (((-121) $) NIL)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) NIL)) (-2747 (((-850) $) NIL (|has| |#1| (-1090)))) (-3180 (((-634 $) $) NIL)) (-3873 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3659 (($ |#1|) 17) (($ $ |#1| $) 16)) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 10 (|has| |#1| (-1090)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-136 |#1|) (-13 (-134 |#1|) (-10 -8 (-15 -3659 ($ |#1|)) (-15 -3659 ($ $ |#1| $)))) (-1090)) (T -136)) 
+((-3659 (*1 *1 *2) (-12 (-5 *1 (-136 *2)) (-4 *2 (-1090)))) (-3659 (*1 *1 *1 *2 *1) (-12 (-5 *1 (-136 *2)) (-4 *2 (-1090))))) 
+(-13 (-134 |#1|) (-10 -8 (-15 -3659 ($ |#1|)) (-15 -3659 ($ $ |#1| $)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-3058 (($) 17 T CONST)) (-1719 (((-121) $ $) 6)) (-1769 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14))) 
 (((-137) (-1275)) (T -137)) 
-((-3134 (*1 *1 *1 *1) (|partial| -4 *1 (-137)))) 
-(-13 (-23) (-10 -8 (-15 -3134 ((-3 $ "failed") $ $)))) 
+((-2689 (*1 *1 *1 *1) (|partial| -4 *1 (-137)))) 
+(-13 (-23) (-10 -8 (-15 -2689 ((-3 $ "failed") $ $)))) 
 (((-23) . T) ((-25) . T) ((-105) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) 7)) (-3138 (((-1249) $ (-763)) 18)) (-2764 (((-763) $) 19)) (-2521 (($ $ $) 12)) (-3268 (($ $ $) 13)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-1751 (((-121) $ $) 15)) (-1738 (((-121) $ $) 16)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 14)) (-1732 (((-121) $ $) 17))) 
+((-2449 (((-121) $ $) 7)) (-2704 (((-1249) $ (-763)) 18)) (-2766 (((-763) $) 19)) (-1732 (($ $ $) 12)) (-2047 (($ $ $) 13)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-1753 (((-121) $ $) 15)) (-1740 (((-121) $ $) 16)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 14)) (-1734 (((-121) $ $) 17))) 
 (((-138) (-1275)) (T -138)) 
-((-2764 (*1 *2 *1) (-12 (-4 *1 (-138)) (-5 *2 (-763)))) (-3138 (*1 *2 *1 *3) (-12 (-4 *1 (-138)) (-5 *3 (-763)) (-5 *2 (-1249))))) 
-(-13 (-842) (-10 -8 (-15 -2764 ((-763) $)) (-15 -3138 ((-1249) $ (-763))))) 
+((-2766 (*1 *2 *1) (-12 (-4 *1 (-138)) (-5 *2 (-763)))) (-2704 (*1 *2 *1 *3) (-12 (-4 *1 (-138)) (-5 *3 (-763)) (-5 *2 (-1249))))) 
+(-13 (-842) (-10 -8 (-15 -2766 ((-763) $)) (-15 -2704 ((-1249) $ (-763))))) 
 (((-105) . T) ((-608 (-850)) . T) ((-842) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-763) "failed") $) 38)) (-2854 (((-763) $) 36)) (-2925 (((-3 $ "failed") $) NIL)) (-2735 (((-121) $) NIL)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) 26)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-3986 (((-121)) 39)) (-3090 (((-121) (-121)) 41)) (-3449 (((-121) $) 23)) (-2446 (((-121) $) 35)) (-2745 (((-850) $) 22) (($ (-763)) 14)) (-1887 (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (-3056 (($) 12 T CONST)) (-1556 (($) 11 T CONST)) (-1999 (($ (-763)) 15)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 24)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 25)) (-1773 (((-3 $ "failed") $ $) 29)) (-1767 (($ $ $) 27)) (** (($ $ (-763)) NIL) (($ $ (-917)) NIL) (($ $ $) 34)) (* (($ (-763) $) 32) (($ (-917) $) NIL) (($ $ $) 30))) 
-(((-139) (-13 (-842) (-23) (-716) (-1037 (-763)) (-10 -8 (-6 (-4521 "*")) (-15 -1773 ((-3 $ "failed") $ $)) (-15 ** ($ $ $)) (-15 -1999 ($ (-763))) (-15 -3449 ((-121) $)) (-15 -2446 ((-121) $)) (-15 -3986 ((-121))) (-15 -3090 ((-121) (-121)))))) (T -139)) 
-((-1773 (*1 *1 *1 *1) (|partial| -5 *1 (-139))) (** (*1 *1 *1 *1) (-5 *1 (-139))) (-1999 (*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-139)))) (-3449 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-139)))) (-2446 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-139)))) (-3986 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-139)))) (-3090 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-139))))) 
-(-13 (-842) (-23) (-716) (-1037 (-763)) (-10 -8 (-6 (-4521 "*")) (-15 -1773 ((-3 $ "failed") $ $)) (-15 ** ($ $ $)) (-15 -1999 ($ (-763))) (-15 -3449 ((-121) $)) (-15 -2446 ((-121) $)) (-15 -3986 ((-121))) (-15 -3090 ((-121) (-121))))) 
-((-4183 (((-141 |#1| |#2| |#4|) (-634 |#4|) (-141 |#1| |#2| |#3|)) 14)) (-2795 (((-141 |#1| |#2| |#4|) (-1 |#4| |#3|) (-141 |#1| |#2| |#3|)) 18))) 
-(((-140 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4183 ((-141 |#1| |#2| |#4|) (-634 |#4|) (-141 |#1| |#2| |#3|))) (-15 -2795 ((-141 |#1| |#2| |#4|) (-1 |#4| |#3|) (-141 |#1| |#2| |#3|)))) (-568) (-763) (-172) (-172)) (T -140)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *7)) (-5 *4 (-141 *5 *6 *7)) (-14 *5 (-568)) (-14 *6 (-763)) (-4 *7 (-172)) (-4 *8 (-172)) (-5 *2 (-141 *5 *6 *8)) (-5 *1 (-140 *5 *6 *7 *8)))) (-4183 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-141 *5 *6 *7)) (-14 *5 (-568)) (-14 *6 (-763)) (-4 *7 (-172)) (-4 *8 (-172)) (-5 *2 (-141 *5 *6 *8)) (-5 *1 (-140 *5 *6 *7 *8))))) 
-(-10 -7 (-15 -4183 ((-141 |#1| |#2| |#4|) (-634 |#4|) (-141 |#1| |#2| |#3|))) (-15 -2795 ((-141 |#1| |#2| |#4|) (-1 |#4| |#3|) (-141 |#1| |#2| |#3|)))) 
-((-2447 (((-121) $ $) NIL)) (-1428 (($ (-634 |#3|)) 38)) (-2870 (($ $) 97) (($ $ (-568) (-568)) 96)) (-2671 (($) 17)) (-3666 (((-3 |#3| "failed") $) 58)) (-2854 ((|#3| $) NIL)) (-2170 (($ $ (-634 (-568))) 98)) (-2733 (((-634 |#3|) $) 34)) (-3700 (((-763) $) 42)) (-3272 (($ $ $) 91)) (-4379 (($) 41)) (-4487 (((-1143) $) NIL)) (-3261 (($) 16)) (-4022 (((-1108) $) NIL)) (-2779 ((|#3| $) 44) ((|#3| $ (-568)) 45) ((|#3| $ (-568) (-568)) 46) ((|#3| $ (-568) (-568) (-568)) 47) ((|#3| $ (-568) (-568) (-568) (-568)) 48) ((|#3| $ (-634 (-568))) 50)) (-3206 (((-763) $) 43)) (-2722 (($ $ (-568) $ (-568)) 92) (($ $ (-568) (-568)) 94)) (-2745 (((-850) $) 65) (($ |#3|) 66) (($ (-232 |#2| |#3|)) 73) (($ (-1127 |#2| |#3|)) 76) (($ (-634 |#3|)) 51) (($ (-634 $)) 56)) (-3056 (($) 67 T CONST)) (-1556 (($) 68 T CONST)) (-1717 (((-121) $ $) 78)) (-1773 (($ $) 84) (($ $ $) 82)) (-1767 (($ $ $) 80)) (* (($ |#3| $) 89) (($ $ |#3|) 90) (($ $ (-568)) 87) (($ (-568) $) 86) (($ $ $) 93))) 
-(((-141 |#1| |#2| |#3|) (-13 (-470 |#3| (-763)) (-475 (-568) (-763)) (-10 -8 (-15 -2745 ($ (-232 |#2| |#3|))) (-15 -2745 ($ (-1127 |#2| |#3|))) (-15 -2745 ($ (-634 |#3|))) (-15 -2745 ($ (-634 $))) (-15 -3700 ((-763) $)) (-15 -2779 (|#3| $)) (-15 -2779 (|#3| $ (-568))) (-15 -2779 (|#3| $ (-568) (-568))) (-15 -2779 (|#3| $ (-568) (-568) (-568))) (-15 -2779 (|#3| $ (-568) (-568) (-568) (-568))) (-15 -2779 (|#3| $ (-634 (-568)))) (-15 -3272 ($ $ $)) (-15 * ($ $ $)) (-15 -2722 ($ $ (-568) $ (-568))) (-15 -2722 ($ $ (-568) (-568))) (-15 -2870 ($ $)) (-15 -2870 ($ $ (-568) (-568))) (-15 -2170 ($ $ (-634 (-568)))) (-15 -3261 ($)) (-15 -4379 ($)) (-15 -2733 ((-634 |#3|) $)) (-15 -1428 ($ (-634 |#3|))) (-15 -2671 ($)))) (-568) (-763) (-172)) (T -141)) 
-((-3272 (*1 *1 *1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-232 *4 *5)) (-14 *4 (-763)) (-4 *5 (-172)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-1127 *4 *5)) (-14 *4 (-763)) (-4 *5 (-172)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-634 *5)) (-4 *5 (-172)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 (-763)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-634 (-141 *3 *4 *5))) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 (-763)) (-4 *5 (-172)))) (-3700 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 *2) (-4 *5 (-172)))) (-2779 (*1 *2 *1) (-12 (-4 *2 (-172)) (-5 *1 (-141 *3 *4 *2)) (-14 *3 (-568)) (-14 *4 (-763)))) (-2779 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *2 (-172)) (-5 *1 (-141 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-763)))) (-2779 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *2 (-172)) (-5 *1 (-141 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-763)))) (-2779 (*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-568)) (-4 *2 (-172)) (-5 *1 (-141 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-763)))) (-2779 (*1 *2 *1 *3 *3 *3 *3) (-12 (-5 *3 (-568)) (-4 *2 (-172)) (-5 *1 (-141 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-763)))) (-2779 (*1 *2 *1 *3) (-12 (-5 *3 (-634 (-568))) (-4 *2 (-172)) (-5 *1 (-141 *4 *5 *2)) (-14 *4 (-568)) (-14 *5 (-763)))) (* (*1 *1 *1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172)))) (-2722 (*1 *1 *1 *2 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-763)) (-4 *5 (-172)))) (-2722 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-763)) (-4 *5 (-172)))) (-2870 (*1 *1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172)))) (-2870 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-763)) (-4 *5 (-172)))) (-2170 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 (-763)) (-4 *5 (-172)))) (-3261 (*1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172)))) (-4379 (*1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172)))) (-2733 (*1 *2 *1) (-12 (-5 *2 (-634 *5)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 (-763)) (-4 *5 (-172)))) (-1428 (*1 *1 *2) (-12 (-5 *2 (-634 *5)) (-4 *5 (-172)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 (-763)))) (-2671 (*1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172))))) 
-(-13 (-470 |#3| (-763)) (-475 (-568) (-763)) (-10 -8 (-15 -2745 ($ (-232 |#2| |#3|))) (-15 -2745 ($ (-1127 |#2| |#3|))) (-15 -2745 ($ (-634 |#3|))) (-15 -2745 ($ (-634 $))) (-15 -3700 ((-763) $)) (-15 -2779 (|#3| $)) (-15 -2779 (|#3| $ (-568))) (-15 -2779 (|#3| $ (-568) (-568))) (-15 -2779 (|#3| $ (-568) (-568) (-568))) (-15 -2779 (|#3| $ (-568) (-568) (-568) (-568))) (-15 -2779 (|#3| $ (-634 (-568)))) (-15 -3272 ($ $ $)) (-15 * ($ $ $)) (-15 -2722 ($ $ (-568) $ (-568))) (-15 -2722 ($ $ (-568) (-568))) (-15 -2870 ($ $)) (-15 -2870 ($ $ (-568) (-568))) (-15 -2170 ($ $ (-634 (-568)))) (-15 -3261 ($)) (-15 -4379 ($)) (-15 -2733 ((-634 |#3|) $)) (-15 -1428 ($ (-634 |#3|))) (-15 -2671 ($)))) 
-((-2447 (((-121) $ $) NIL)) (-2072 (($) 15 T CONST)) (-3415 (($) NIL (|has| (-147) (-370)))) (-1791 (($ $ $) 17) (($ $ (-147)) NIL) (($ (-147) $) NIL)) (-1536 (($ $ $) NIL)) (-2032 (((-121) $ $) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-3983 (((-763)) NIL (|has| (-147) (-370)))) (-2749 (($) NIL) (($ (-634 (-147))) NIL)) (-3507 (($ (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4519)))) (-2671 (($) NIL T CONST)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-147) (-1090))))) (-3405 (($ (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4519))) (($ (-147) $) 51 (|has| $ (-6 -4519)))) (-4328 (($ (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4519))) (($ (-147) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-147) (-1090))))) (-3092 (((-147) (-1 (-147) (-147) (-147)) $) NIL (|has| $ (-6 -4519))) (((-147) (-1 (-147) (-147) (-147)) $ (-147)) NIL (|has| $ (-6 -4519))) (((-147) (-1 (-147) (-147) (-147)) $ (-147) (-147)) NIL (-12 (|has| $ (-6 -4519)) (|has| (-147) (-1090))))) (-1731 (($) NIL (|has| (-147) (-370)))) (-4360 (((-634 (-147)) $) 60 (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) NIL)) (-2521 (((-147) $) NIL (|has| (-147) (-842)))) (-1979 (((-634 (-147)) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) (-147) $) 26 (-12 (|has| $ (-6 -4519)) (|has| (-147) (-1090))))) (-3268 (((-147) $) NIL (|has| (-147) (-842)))) (-3674 (($ (-1 (-147) (-147)) $) 59 (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-147) (-147)) $) 55)) (-2003 (($) 16 T CONST)) (-3683 (((-917) $) NIL (|has| (-147) (-370)))) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL)) (-3212 (($ $ $) 29)) (-1890 (((-147) $) 52)) (-4450 (($ (-147) $) 50)) (-4355 (($ (-917)) NIL (|has| (-147) (-370)))) (-3659 (($) 14 T CONST)) (-4022 (((-1108) $) NIL)) (-3775 (((-3 (-147) "failed") (-1 (-121) (-147)) $) NIL)) (-1315 (((-147) $) 53)) (-1387 (((-121) (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-147)) (-634 (-147))) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-147) (-147)) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-288 (-147))) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-634 (-288 (-147)))) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) 48)) (-1723 (($) 13 T CONST)) (-4382 (($ $ $) 31) (($ $ (-147)) NIL)) (-2085 (($ (-634 (-147))) NIL) (($) NIL)) (-4168 (((-763) (-147) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-147) (-1090)))) (((-763) (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4519)))) (-3863 (($ $) NIL)) (-4278 (((-1143) $) 36) (((-541) $) NIL (|has| (-147) (-609 (-541)))) (((-634 (-147)) $) 34)) (-4287 (($ (-634 (-147))) NIL)) (-2160 (($ $) 32 (|has| (-147) (-370)))) (-2745 (((-850) $) 46)) (-3565 (($ (-1143)) 12) (($ (-634 (-147))) 43)) (-2432 (((-763) $) NIL)) (-3844 (($) 49) (($ (-634 (-147))) NIL)) (-2367 (($ (-634 (-147))) NIL)) (-1319 (((-121) (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4519)))) (-3135 (($) 19 T CONST)) (-2208 (($) 18 T CONST)) (-1717 (((-121) $ $) 22)) (-1732 (((-121) $ $) NIL)) (-1697 (((-763) $) 47 (|has| $ (-6 -4519))))) 
-(((-142) (-13 (-1090) (-609 (-1143)) (-427 (-147)) (-609 (-634 (-147))) (-10 -8 (-15 -3565 ($ (-1143))) (-15 -3565 ($ (-634 (-147)))) (-15 -1723 ($) -3495) (-15 -3659 ($) -3495) (-15 -2072 ($) -3495) (-15 -2003 ($) -3495) (-15 -2208 ($) -3495) (-15 -3135 ($) -3495)))) (T -142)) 
-((-3565 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-142)))) (-3565 (*1 *1 *2) (-12 (-5 *2 (-634 (-147))) (-5 *1 (-142)))) (-1723 (*1 *1) (-5 *1 (-142))) (-3659 (*1 *1) (-5 *1 (-142))) (-2072 (*1 *1) (-5 *1 (-142))) (-2003 (*1 *1) (-5 *1 (-142))) (-2208 (*1 *1) (-5 *1 (-142))) (-3135 (*1 *1) (-5 *1 (-142)))) 
-(-13 (-1090) (-609 (-1143)) (-427 (-147)) (-609 (-634 (-147))) (-10 -8 (-15 -3565 ($ (-1143))) (-15 -3565 ($ (-634 (-147)))) (-15 -1723 ($) -3495) (-15 -3659 ($) -3495) (-15 -2072 ($) -3495) (-15 -2003 ($) -3495) (-15 -2208 ($) -3495) (-15 -3135 ($) -3495))) 
-((-4114 (((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|) 17)) (-3093 ((|#1| |#3|) 9)) (-2469 ((|#3| |#3|) 15))) 
-(((-143 |#1| |#2| |#3|) (-10 -7 (-15 -3093 (|#1| |#3|)) (-15 -2469 (|#3| |#3|)) (-15 -4114 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|))) (-558) (-993 |#1|) (-375 |#2|)) (T -143)) 
-((-4114 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-993 *4)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4))) (-5 *1 (-143 *4 *5 *3)) (-4 *3 (-375 *5)))) (-2469 (*1 *2 *2) (-12 (-4 *3 (-558)) (-4 *4 (-993 *3)) (-5 *1 (-143 *3 *4 *2)) (-4 *2 (-375 *4)))) (-3093 (*1 *2 *3) (-12 (-4 *4 (-993 *2)) (-4 *2 (-558)) (-5 *1 (-143 *2 *4 *3)) (-4 *3 (-375 *4))))) 
-(-10 -7 (-15 -3093 (|#1| |#3|)) (-15 -2469 (|#3| |#3|)) (-15 -4114 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|))) 
-((-2447 (((-121) $ $) NIL (|has| (-169 (-215)) (-1090)))) (-3205 (($ (-763) (-763)) NIL)) (-3347 (($ $ $) NIL)) (-2870 (($ (-145)) NIL) (($ $) NIL)) (-1335 (((-121) $) NIL)) (-4343 (($ $ (-568) (-568)) NIL)) (-3622 (($ $ (-568) (-568)) NIL)) (-3676 (($ $ (-568) (-568) (-568) (-568)) NIL)) (-3976 (($ $) NIL)) (-2230 (((-121) $) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-1785 (($ $ (-568) (-568) $) NIL)) (-2436 (((-169 (-215)) $ (-568) (-568) (-169 (-215))) NIL) (($ $ (-634 (-568)) (-634 (-568)) $) NIL)) (-4159 (($ $ (-568) (-145)) NIL)) (-2451 (($ $ (-568) (-145)) NIL)) (-3422 (($ (-763) (-169 (-215))) NIL)) (-2671 (($) NIL T CONST)) (-4167 (($ $) NIL (|has| (-169 (-215)) (-301)))) (-1818 (((-145) $ (-568)) NIL)) (-3700 (((-763) $) NIL (|has| (-169 (-215)) (-558)))) (-3989 (((-169 (-215)) $ (-568) (-568) (-169 (-215))) 16)) (-3615 (($ (-568) (-568)) 18)) (-2602 (((-169 (-215)) $ (-568) (-568)) 15)) (-2076 (((-169 (-215)) $) NIL (|has| (-169 (-215)) (-172)))) (-4360 (((-634 (-169 (-215))) $) NIL)) (-2121 (((-763) $) NIL (|has| (-169 (-215)) (-558)))) (-4272 (((-634 (-145)) $) NIL (|has| (-169 (-215)) (-558)))) (-3043 (((-763) $) 10)) (-1849 (($ (-763) (-763) (-169 (-215))) 19)) (-2555 (((-763) $) 11)) (-1737 (((-121) $ (-763)) NIL)) (-3082 (((-169 (-215)) $) NIL (|has| (-169 (-215)) (-6 (-4521 "*"))))) (-2087 (((-568) $) 7)) (-3364 (((-568) $) 8)) (-1979 (((-634 (-169 (-215))) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) (-169 (-215)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-169 (-215)) (-1090))))) (-1663 (((-568) $) 12)) (-2893 (((-568) $) 13)) (-2269 (($ (-634 (-634 (-169 (-215))))) NIL)) (-3674 (($ (-1 (-169 (-215)) (-169 (-215))) $) NIL)) (-2795 (($ (-1 (-169 (-215)) (-169 (-215))) $) NIL) (($ (-1 (-169 (-215)) (-169 (-215)) (-169 (-215))) $ $) NIL) (($ (-1 (-169 (-215)) (-169 (-215)) (-169 (-215))) $ $ (-169 (-215))) NIL)) (-3208 (((-634 (-634 (-169 (-215)))) $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (|has| (-169 (-215)) (-1090)))) (-3140 (((-3 $ "failed") $) NIL (|has| (-169 (-215)) (-365)))) (-2858 (($ $ $) NIL)) (-4022 (((-1108) $) NIL (|has| (-169 (-215)) (-1090)))) (-3724 (($ $ (-169 (-215))) NIL)) (-2595 (((-3 $ "failed") $ (-169 (-215))) NIL (|has| (-169 (-215)) (-558)))) (-1387 (((-121) (-1 (-121) (-169 (-215))) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-169 (-215))))) NIL (-12 (|has| (-169 (-215)) (-303 (-169 (-215)))) (|has| (-169 (-215)) (-1090)))) (($ $ (-288 (-169 (-215)))) NIL (-12 (|has| (-169 (-215)) (-303 (-169 (-215)))) (|has| (-169 (-215)) (-1090)))) (($ $ (-169 (-215)) (-169 (-215))) NIL (-12 (|has| (-169 (-215)) (-303 (-169 (-215)))) (|has| (-169 (-215)) (-1090)))) (($ $ (-634 (-169 (-215))) (-634 (-169 (-215)))) NIL (-12 (|has| (-169 (-215)) (-303 (-169 (-215)))) (|has| (-169 (-215)) (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) 17)) (-2779 (((-169 (-215)) $ (-568) (-568)) NIL) (((-169 (-215)) $ (-568) (-568) (-169 (-215))) NIL) (($ $ (-634 (-568)) (-634 (-568))) NIL)) (-2282 (($ (-634 (-169 (-215)))) NIL) (($ (-634 $)) NIL)) (-1960 (((-121) $) NIL)) (-2465 (((-169 (-215)) $) NIL (|has| (-169 (-215)) (-6 (-4521 "*"))))) (-4168 (((-763) (-1 (-121) (-169 (-215))) $) NIL (|has| $ (-6 -4519))) (((-763) (-169 (-215)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-169 (-215)) (-1090))))) (-3863 (($ $) NIL)) (-2365 (((-634 (-145)) $) NIL (|has| (-169 (-215)) (-301)))) (-3731 (((-145) $ (-568)) NIL)) (-2745 (((-850) $) NIL (|has| (-169 (-215)) (-1090))) (($ (-145)) NIL)) (-1319 (((-121) (-1 (-121) (-169 (-215))) $) NIL (|has| $ (-6 -4519)))) (-1910 (((-121) $) NIL)) (-1717 (((-121) $ $) NIL (|has| (-169 (-215)) (-1090)))) (-1779 (($ $ (-169 (-215))) NIL (|has| (-169 (-215)) (-365)))) (-1773 (($ $ $) NIL) (($ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| (-169 (-215)) (-365)))) (* (($ $ $) NIL) (($ (-169 (-215)) $) NIL) (($ $ (-169 (-215))) NIL) (($ (-568) $) NIL) (((-145) $ (-145)) NIL) (((-145) (-145) $) NIL)) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-144) (-13 (-677 (-169 (-215)) (-145) (-145)) (-10 -8 (-15 -3615 ($ (-568) (-568)))))) (T -144)) 
-((-3615 (*1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-144))))) 
-(-13 (-677 (-169 (-215)) (-145) (-145)) (-10 -8 (-15 -3615 ($ (-568) (-568))))) 
-((-2447 (((-121) $ $) NIL (|has| (-169 (-215)) (-1090)))) (-3205 (($ (-763)) NIL (|has| (-169 (-215)) (-23)))) (-4209 (($ (-634 (-169 (-215)))) NIL)) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-2016 (((-121) (-1 (-121) (-169 (-215)) (-169 (-215))) $) NIL) (((-121) $) NIL (|has| (-169 (-215)) (-842)))) (-3908 (($ (-1 (-121) (-169 (-215)) (-169 (-215))) $) NIL (|has| $ (-6 -4520))) (($ $) NIL (-12 (|has| $ (-6 -4520)) (|has| (-169 (-215)) (-842))))) (-3644 (($ (-1 (-121) (-169 (-215)) (-169 (-215))) $) NIL) (($ $) NIL (|has| (-169 (-215)) (-842)))) (-2510 (((-121) $ (-763)) NIL)) (-2436 (((-169 (-215)) $ (-568) (-169 (-215))) 18 (|has| $ (-6 -4520))) (((-169 (-215)) $ (-1210 (-568)) (-169 (-215))) NIL (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) (-169 (-215))) $) NIL (|has| $ (-6 -4519)))) (-2671 (($) NIL T CONST)) (-1578 (($ $) NIL (|has| $ (-6 -4520)))) (-3943 (($ $) NIL)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-169 (-215)) (-1090))))) (-4328 (($ (-169 (-215)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-169 (-215)) (-1090)))) (($ (-1 (-121) (-169 (-215))) $) NIL (|has| $ (-6 -4519)))) (-3092 (((-169 (-215)) (-1 (-169 (-215)) (-169 (-215)) (-169 (-215))) $ (-169 (-215)) (-169 (-215))) NIL (-12 (|has| $ (-6 -4519)) (|has| (-169 (-215)) (-1090)))) (((-169 (-215)) (-1 (-169 (-215)) (-169 (-215)) (-169 (-215))) $ (-169 (-215))) NIL (|has| $ (-6 -4519))) (((-169 (-215)) (-1 (-169 (-215)) (-169 (-215)) (-169 (-215))) $) NIL (|has| $ (-6 -4519)))) (-3989 (((-169 (-215)) $ (-568) (-169 (-215))) 9 (|has| $ (-6 -4520)))) (-3615 (($ (-568)) 14)) (-2602 (((-169 (-215)) $ (-568)) 8)) (-2764 (((-568) (-1 (-121) (-169 (-215))) $) NIL) (((-568) (-169 (-215)) $) NIL (|has| (-169 (-215)) (-1090))) (((-568) (-169 (-215)) $ (-568)) NIL (|has| (-169 (-215)) (-1090)))) (-4360 (((-634 (-169 (-215))) $) NIL (|has| $ (-6 -4519)))) (-1802 (((-679 (-169 (-215))) $ $) NIL (|has| (-169 (-215)) (-1047)))) (-1849 (($ (-763) (-169 (-215))) 16)) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) 12 (|has| (-568) (-842)))) (-2521 (($ $ $) NIL (|has| (-169 (-215)) (-842)))) (-1347 (($ (-1 (-121) (-169 (-215)) (-169 (-215))) $ $) NIL) (($ $ $) NIL (|has| (-169 (-215)) (-842)))) (-1979 (((-634 (-169 (-215))) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) (-169 (-215)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-169 (-215)) (-1090))))) (-2223 (((-568) $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (|has| (-169 (-215)) (-842)))) (-3674 (($ (-1 (-169 (-215)) (-169 (-215))) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-169 (-215)) (-169 (-215))) $) NIL) (($ (-1 (-169 (-215)) (-169 (-215)) (-169 (-215))) $ $) NIL)) (-1550 (((-169 (-215)) $) NIL (-12 (|has| (-169 (-215)) (-1002)) (|has| (-169 (-215)) (-1047))))) (-2166 (((-121) $ (-763)) NIL)) (-3678 (((-169 (-215)) $) NIL (-12 (|has| (-169 (-215)) (-1002)) (|has| (-169 (-215)) (-1047))))) (-4487 (((-1143) $) NIL (|has| (-169 (-215)) (-1090)))) (-4122 (($ (-169 (-215)) $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4022 (((-1108) $) NIL (|has| (-169 (-215)) (-1090)))) (-3876 (((-169 (-215)) $) NIL (|has| (-568) (-842)))) (-3775 (((-3 (-169 (-215)) "failed") (-1 (-121) (-169 (-215))) $) NIL)) (-3724 (($ $ (-169 (-215))) 15 (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) (-169 (-215))) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-169 (-215))))) NIL (-12 (|has| (-169 (-215)) (-303 (-169 (-215)))) (|has| (-169 (-215)) (-1090)))) (($ $ (-288 (-169 (-215)))) NIL (-12 (|has| (-169 (-215)) (-303 (-169 (-215)))) (|has| (-169 (-215)) (-1090)))) (($ $ (-169 (-215)) (-169 (-215))) NIL (-12 (|has| (-169 (-215)) (-303 (-169 (-215)))) (|has| (-169 (-215)) (-1090)))) (($ $ (-634 (-169 (-215))) (-634 (-169 (-215)))) NIL (-12 (|has| (-169 (-215)) (-303 (-169 (-215)))) (|has| (-169 (-215)) (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) (-169 (-215)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-169 (-215)) (-1090))))) (-2041 (((-634 (-169 (-215))) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) 13)) (-2779 (((-169 (-215)) $ (-568) (-169 (-215))) NIL) (((-169 (-215)) $ (-568)) 17) (($ $ (-1210 (-568))) NIL)) (-3682 (((-169 (-215)) $ $) NIL (|has| (-169 (-215)) (-1047)))) (-2826 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-2748 (($ $ $) NIL (|has| (-169 (-215)) (-1047)))) (-4168 (((-763) (-1 (-121) (-169 (-215))) $) NIL (|has| $ (-6 -4519))) (((-763) (-169 (-215)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-169 (-215)) (-1090))))) (-2256 (($ $ $ (-568)) NIL (|has| $ (-6 -4520)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| (-169 (-215)) (-609 (-541))))) (-4287 (($ (-634 (-169 (-215)))) NIL)) (-2768 (($ $ (-169 (-215))) NIL) (($ (-169 (-215)) $) NIL) (($ $ $) NIL) (($ (-634 $)) NIL)) (-2745 (((-850) $) NIL (|has| (-169 (-215)) (-1090)))) (-1319 (((-121) (-1 (-121) (-169 (-215))) $) NIL (|has| $ (-6 -4519)))) (-1751 (((-121) $ $) NIL (|has| (-169 (-215)) (-842)))) (-1738 (((-121) $ $) NIL (|has| (-169 (-215)) (-842)))) (-1717 (((-121) $ $) NIL (|has| (-169 (-215)) (-1090)))) (-1745 (((-121) $ $) NIL (|has| (-169 (-215)) (-842)))) (-1732 (((-121) $ $) NIL (|has| (-169 (-215)) (-842)))) (-1773 (($ $) NIL (|has| (-169 (-215)) (-21))) (($ $ $) NIL (|has| (-169 (-215)) (-21)))) (-1767 (($ $ $) NIL (|has| (-169 (-215)) (-25)))) (* (($ (-568) $) NIL (|has| (-169 (-215)) (-21))) (($ (-169 (-215)) $) NIL (|has| (-169 (-215)) (-716))) (($ $ (-169 (-215))) NIL (|has| (-169 (-215)) (-716)))) (-1697 (((-763) $) 11 (|has| $ (-6 -4519))))) 
-(((-145) (-13 (-1242 (-169 (-215))) (-10 -8 (-15 -3615 ($ (-568))) (-15 -4209 ($ (-634 (-169 (-215)))))))) (T -145)) 
-((-3615 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-145)))) (-4209 (*1 *1 *2) (-12 (-5 *2 (-634 (-169 (-215)))) (-5 *1 (-145))))) 
-(-13 (-1242 (-169 (-215))) (-10 -8 (-15 -3615 ($ (-568))) (-15 -4209 ($ (-634 (-169 (-215))))))) 
-((-2413 (($ $ $) 8)) (-2427 (($ $) 7)) (-2787 (($ $ $) 6))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-763) "failed") $) 38)) (-2857 (((-763) $) 36)) (-2902 (((-3 $ "failed") $) NIL)) (-1598 (((-121) $) NIL)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) 26)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-1282 (((-121)) 39)) (-2463 (((-121) (-121)) 41)) (-3557 (((-121) $) 23)) (-2505 (((-121) $) 35)) (-2747 (((-850) $) 22) (($ (-763)) 14)) (-1889 (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (-3058 (($) 12 T CONST)) (-1557 (($) 11 T CONST)) (-4484 (($ (-763)) 15)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 24)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 25)) (-1775 (((-3 $ "failed") $ $) 29)) (-1769 (($ $ $) 27)) (** (($ $ (-763)) NIL) (($ $ (-917)) NIL) (($ $ $) 34)) (* (($ (-763) $) 32) (($ (-917) $) NIL) (($ $ $) 30))) 
+(((-139) (-13 (-842) (-23) (-716) (-1037 (-763)) (-10 -8 (-6 (-4523 "*")) (-15 -1775 ((-3 $ "failed") $ $)) (-15 ** ($ $ $)) (-15 -4484 ($ (-763))) (-15 -3557 ((-121) $)) (-15 -2505 ((-121) $)) (-15 -1282 ((-121))) (-15 -2463 ((-121) (-121)))))) (T -139)) 
+((-1775 (*1 *1 *1 *1) (|partial| -5 *1 (-139))) (** (*1 *1 *1 *1) (-5 *1 (-139))) (-4484 (*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-139)))) (-3557 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-139)))) (-2505 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-139)))) (-1282 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-139)))) (-2463 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-139))))) 
+(-13 (-842) (-23) (-716) (-1037 (-763)) (-10 -8 (-6 (-4523 "*")) (-15 -1775 ((-3 $ "failed") $ $)) (-15 ** ($ $ $)) (-15 -4484 ($ (-763))) (-15 -3557 ((-121) $)) (-15 -2505 ((-121) $)) (-15 -1282 ((-121))) (-15 -2463 ((-121) (-121))))) 
+((-4182 (((-141 |#1| |#2| |#4|) (-634 |#4|) (-141 |#1| |#2| |#3|)) 14)) (-2797 (((-141 |#1| |#2| |#4|) (-1 |#4| |#3|) (-141 |#1| |#2| |#3|)) 18))) 
+(((-140 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4182 ((-141 |#1| |#2| |#4|) (-634 |#4|) (-141 |#1| |#2| |#3|))) (-15 -2797 ((-141 |#1| |#2| |#4|) (-1 |#4| |#3|) (-141 |#1| |#2| |#3|)))) (-568) (-763) (-172) (-172)) (T -140)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *7)) (-5 *4 (-141 *5 *6 *7)) (-14 *5 (-568)) (-14 *6 (-763)) (-4 *7 (-172)) (-4 *8 (-172)) (-5 *2 (-141 *5 *6 *8)) (-5 *1 (-140 *5 *6 *7 *8)))) (-4182 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-141 *5 *6 *7)) (-14 *5 (-568)) (-14 *6 (-763)) (-4 *7 (-172)) (-4 *8 (-172)) (-5 *2 (-141 *5 *6 *8)) (-5 *1 (-140 *5 *6 *7 *8))))) 
+(-10 -7 (-15 -4182 ((-141 |#1| |#2| |#4|) (-634 |#4|) (-141 |#1| |#2| |#3|))) (-15 -2797 ((-141 |#1| |#2| |#4|) (-1 |#4| |#3|) (-141 |#1| |#2| |#3|)))) 
+((-2449 (((-121) $ $) NIL)) (-2227 (($ (-634 |#3|)) 38)) (-4089 (($ $) 97) (($ $ (-568) (-568)) 96)) (-4490 (($) 17)) (-3668 (((-3 |#3| "failed") $) 58)) (-2857 ((|#3| $) NIL)) (-3797 (($ $ (-634 (-568))) 98)) (-2734 (((-634 |#3|) $) 34)) (-2371 (((-763) $) 42)) (-2062 (($ $ $) 91)) (-1348 (($) 41)) (-1893 (((-1143) $) NIL)) (-2027 (($) 16)) (-4025 (((-1108) $) NIL)) (-2781 ((|#3| $) 44) ((|#3| $ (-568)) 45) ((|#3| $ (-568) (-568)) 46) ((|#3| $ (-568) (-568) (-568)) 47) ((|#3| $ (-568) (-568) (-568) (-568)) 48) ((|#3| $ (-634 (-568))) 50)) (-1836 (((-763) $) 43)) (-1543 (($ $ (-568) $ (-568)) 92) (($ $ (-568) (-568)) 94)) (-2747 (((-850) $) 65) (($ |#3|) 66) (($ (-232 |#2| |#3|)) 73) (($ (-1127 |#2| |#3|)) 76) (($ (-634 |#3|)) 51) (($ (-634 $)) 56)) (-3058 (($) 67 T CONST)) (-1557 (($) 68 T CONST)) (-1719 (((-121) $ $) 78)) (-1775 (($ $) 84) (($ $ $) 82)) (-1769 (($ $ $) 80)) (* (($ |#3| $) 89) (($ $ |#3|) 90) (($ $ (-568)) 87) (($ (-568) $) 86) (($ $ $) 93))) 
+(((-141 |#1| |#2| |#3|) (-13 (-470 |#3| (-763)) (-475 (-568) (-763)) (-10 -8 (-15 -2747 ($ (-232 |#2| |#3|))) (-15 -2747 ($ (-1127 |#2| |#3|))) (-15 -2747 ($ (-634 |#3|))) (-15 -2747 ($ (-634 $))) (-15 -2371 ((-763) $)) (-15 -2781 (|#3| $)) (-15 -2781 (|#3| $ (-568))) (-15 -2781 (|#3| $ (-568) (-568))) (-15 -2781 (|#3| $ (-568) (-568) (-568))) (-15 -2781 (|#3| $ (-568) (-568) (-568) (-568))) (-15 -2781 (|#3| $ (-634 (-568)))) (-15 -2062 ($ $ $)) (-15 * ($ $ $)) (-15 -1543 ($ $ (-568) $ (-568))) (-15 -1543 ($ $ (-568) (-568))) (-15 -4089 ($ $)) (-15 -4089 ($ $ (-568) (-568))) (-15 -3797 ($ $ (-634 (-568)))) (-15 -2027 ($)) (-15 -1348 ($)) (-15 -2734 ((-634 |#3|) $)) (-15 -2227 ($ (-634 |#3|))) (-15 -4490 ($)))) (-568) (-763) (-172)) (T -141)) 
+((-2062 (*1 *1 *1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-232 *4 *5)) (-14 *4 (-763)) (-4 *5 (-172)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-1127 *4 *5)) (-14 *4 (-763)) (-4 *5 (-172)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-634 *5)) (-4 *5 (-172)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 (-763)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-634 (-141 *3 *4 *5))) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 (-763)) (-4 *5 (-172)))) (-2371 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 *2) (-4 *5 (-172)))) (-2781 (*1 *2 *1) (-12 (-4 *2 (-172)) (-5 *1 (-141 *3 *4 *2)) (-14 *3 (-568)) (-14 *4 (-763)))) (-2781 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *2 (-172)) (-5 *1 (-141 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-763)))) (-2781 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *2 (-172)) (-5 *1 (-141 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-763)))) (-2781 (*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-568)) (-4 *2 (-172)) (-5 *1 (-141 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-763)))) (-2781 (*1 *2 *1 *3 *3 *3 *3) (-12 (-5 *3 (-568)) (-4 *2 (-172)) (-5 *1 (-141 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-763)))) (-2781 (*1 *2 *1 *3) (-12 (-5 *3 (-634 (-568))) (-4 *2 (-172)) (-5 *1 (-141 *4 *5 *2)) (-14 *4 (-568)) (-14 *5 (-763)))) (* (*1 *1 *1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172)))) (-1543 (*1 *1 *1 *2 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-763)) (-4 *5 (-172)))) (-1543 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-763)) (-4 *5 (-172)))) (-4089 (*1 *1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172)))) (-4089 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-763)) (-4 *5 (-172)))) (-3797 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 (-763)) (-4 *5 (-172)))) (-2027 (*1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172)))) (-1348 (*1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172)))) (-2734 (*1 *2 *1) (-12 (-5 *2 (-634 *5)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 (-763)) (-4 *5 (-172)))) (-2227 (*1 *1 *2) (-12 (-5 *2 (-634 *5)) (-4 *5 (-172)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 (-763)))) (-4490 (*1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172))))) 
+(-13 (-470 |#3| (-763)) (-475 (-568) (-763)) (-10 -8 (-15 -2747 ($ (-232 |#2| |#3|))) (-15 -2747 ($ (-1127 |#2| |#3|))) (-15 -2747 ($ (-634 |#3|))) (-15 -2747 ($ (-634 $))) (-15 -2371 ((-763) $)) (-15 -2781 (|#3| $)) (-15 -2781 (|#3| $ (-568))) (-15 -2781 (|#3| $ (-568) (-568))) (-15 -2781 (|#3| $ (-568) (-568) (-568))) (-15 -2781 (|#3| $ (-568) (-568) (-568) (-568))) (-15 -2781 (|#3| $ (-634 (-568)))) (-15 -2062 ($ $ $)) (-15 * ($ $ $)) (-15 -1543 ($ $ (-568) $ (-568))) (-15 -1543 ($ $ (-568) (-568))) (-15 -4089 ($ $)) (-15 -4089 ($ $ (-568) (-568))) (-15 -3797 ($ $ (-634 (-568)))) (-15 -2027 ($)) (-15 -1348 ($)) (-15 -2734 ((-634 |#3|) $)) (-15 -2227 ($ (-634 |#3|))) (-15 -4490 ($)))) 
+((-2449 (((-121) $ $) NIL)) (-3083 (($) 15 T CONST)) (-1611 (($) NIL (|has| (-147) (-370)))) (-1793 (($ $ $) 17) (($ $ (-147)) NIL) (($ (-147) $) NIL)) (-4217 (($ $ $) NIL)) (-1430 (((-121) $ $) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-3986 (((-763)) NIL (|has| (-147) (-370)))) (-2751 (($) NIL) (($ (-634 (-147))) NIL)) (-3963 (($ (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4521)))) (-4490 (($) NIL T CONST)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-147) (-1090))))) (-1568 (($ (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4521))) (($ (-147) $) 51 (|has| $ (-6 -4521)))) (-4330 (($ (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4521))) (($ (-147) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-147) (-1090))))) (-3094 (((-147) (-1 (-147) (-147) (-147)) $) NIL (|has| $ (-6 -4521))) (((-147) (-1 (-147) (-147) (-147)) $ (-147)) NIL (|has| $ (-6 -4521))) (((-147) (-1 (-147) (-147) (-147)) $ (-147) (-147)) NIL (-12 (|has| $ (-6 -4521)) (|has| (-147) (-1090))))) (-1733 (($) NIL (|has| (-147) (-370)))) (-3317 (((-634 (-147)) $) 60 (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) NIL)) (-1732 (((-147) $) NIL (|has| (-147) (-842)))) (-4406 (((-634 (-147)) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) (-147) $) 26 (-12 (|has| $ (-6 -4521)) (|has| (-147) (-1090))))) (-2047 (((-147) $) NIL (|has| (-147) (-842)))) (-2253 (($ (-1 (-147) (-147)) $) 59 (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-147) (-147)) $) 55)) (-4499 (($) 16 T CONST)) (-2291 (((-917) $) NIL (|has| (-147) (-370)))) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL)) (-1864 (($ $ $) 29)) (-2580 (((-147) $) 52)) (-1708 (($ (-147) $) 50)) (-4357 (($ (-917)) NIL (|has| (-147) (-370)))) (-3315 (($) 14 T CONST)) (-4025 (((-1108) $) NIL)) (-2712 (((-3 (-147) "failed") (-1 (-121) (-147)) $) NIL)) (-3403 (((-147) $) 53)) (-3951 (((-121) (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-147)) (-634 (-147))) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-147) (-147)) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-288 (-147))) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-634 (-288 (-147)))) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) 48)) (-3719 (($) 13 T CONST)) (-1363 (($ $ $) 31) (($ $ (-147)) NIL)) (-3132 (($ (-634 (-147))) NIL) (($) NIL)) (-4170 (((-763) (-147) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-147) (-1090)))) (((-763) (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4521)))) (-3865 (($ $) NIL)) (-4280 (((-1143) $) 36) (((-541) $) NIL (|has| (-147) (-609 (-541)))) (((-634 (-147)) $) 34)) (-4289 (($ (-634 (-147))) NIL)) (-3695 (($ $) 32 (|has| (-147) (-370)))) (-2747 (((-850) $) 46)) (-2872 (($ (-1143)) 12) (($ (-634 (-147))) 43)) (-2429 (((-763) $) NIL)) (-3846 (($) 49) (($ (-634 (-147))) NIL)) (-4074 (($ (-634 (-147))) NIL)) (-3437 (((-121) (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4521)))) (-2693 (($) 19 T CONST)) (-3232 (($) 18 T CONST)) (-1719 (((-121) $ $) 22)) (-1734 (((-121) $ $) NIL)) (-1699 (((-763) $) 47 (|has| $ (-6 -4521))))) 
+(((-142) (-13 (-1090) (-609 (-1143)) (-427 (-147)) (-609 (-634 (-147))) (-10 -8 (-15 -2872 ($ (-1143))) (-15 -2872 ($ (-634 (-147)))) (-15 -3719 ($) -3497) (-15 -3315 ($) -3497) (-15 -3083 ($) -3497) (-15 -4499 ($) -3497) (-15 -3232 ($) -3497) (-15 -2693 ($) -3497)))) (T -142)) 
+((-2872 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-142)))) (-2872 (*1 *1 *2) (-12 (-5 *2 (-634 (-147))) (-5 *1 (-142)))) (-3719 (*1 *1) (-5 *1 (-142))) (-3315 (*1 *1) (-5 *1 (-142))) (-3083 (*1 *1) (-5 *1 (-142))) (-4499 (*1 *1) (-5 *1 (-142))) (-3232 (*1 *1) (-5 *1 (-142))) (-2693 (*1 *1) (-5 *1 (-142)))) 
+(-13 (-1090) (-609 (-1143)) (-427 (-147)) (-609 (-634 (-147))) (-10 -8 (-15 -2872 ($ (-1143))) (-15 -2872 ($ (-634 (-147)))) (-15 -3719 ($) -3497) (-15 -3315 ($) -3497) (-15 -3083 ($) -3497) (-15 -4499 ($) -3497) (-15 -3232 ($) -3497) (-15 -2693 ($) -3497))) 
+((-3618 (((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|) 17)) (-2471 ((|#1| |#3|) 9)) (-2609 ((|#3| |#3|) 15))) 
+(((-143 |#1| |#2| |#3|) (-10 -7 (-15 -2471 (|#1| |#3|)) (-15 -2609 (|#3| |#3|)) (-15 -3618 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|))) (-558) (-993 |#1|) (-375 |#2|)) (T -143)) 
+((-3618 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-993 *4)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4))) (-5 *1 (-143 *4 *5 *3)) (-4 *3 (-375 *5)))) (-2609 (*1 *2 *2) (-12 (-4 *3 (-558)) (-4 *4 (-993 *3)) (-5 *1 (-143 *3 *4 *2)) (-4 *2 (-375 *4)))) (-2471 (*1 *2 *3) (-12 (-4 *4 (-993 *2)) (-4 *2 (-558)) (-5 *1 (-143 *2 *4 *3)) (-4 *3 (-375 *4))))) 
+(-10 -7 (-15 -2471 (|#1| |#3|)) (-15 -2609 (|#3| |#3|)) (-15 -3618 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|))) 
+((-2449 (((-121) $ $) NIL (|has| (-169 (-215)) (-1090)))) (-3207 (($ (-763) (-763)) NIL)) (-4486 (($ $ $) NIL)) (-4089 (($ (-145)) NIL) (($ $) NIL)) (-3560 (((-121) $) NIL)) (-3211 (($ $ (-568) (-568)) NIL)) (-3096 (($ $ (-568) (-568)) NIL)) (-2265 (($ $ (-568) (-568) (-568) (-568)) NIL)) (-4467 (($ $) NIL)) (-3691 (((-121) $) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-4043 (($ $ (-568) (-568) $) NIL)) (-2438 (((-169 (-215)) $ (-568) (-568) (-169 (-215))) NIL) (($ $ (-634 (-568)) (-634 (-568)) $) NIL)) (-3874 (($ $ (-568) (-145)) NIL)) (-2525 (($ $ (-568) (-145)) NIL)) (-1637 (($ (-763) (-169 (-215))) NIL)) (-4490 (($) NIL T CONST)) (-3912 (($ $) NIL (|has| (-169 (-215)) (-301)))) (-2228 (((-145) $ (-568)) NIL)) (-2371 (((-763) $) NIL (|has| (-169 (-215)) (-558)))) (-1292 (((-169 (-215)) $ (-568) (-568) (-169 (-215))) 16)) (-3063 (($ (-568) (-568)) 18)) (-2069 (((-169 (-215)) $ (-568) (-568)) 15)) (-3102 (((-169 (-215)) $) NIL (|has| (-169 (-215)) (-172)))) (-3317 (((-634 (-169 (-215))) $) NIL)) (-3344 (((-763) $) NIL (|has| (-169 (-215)) (-558)))) (-2934 (((-634 (-145)) $) NIL (|has| (-169 (-215)) (-558)))) (-2241 (((-763) $) 10)) (-1851 (($ (-763) (-763) (-169 (-215))) 19)) (-1901 (((-763) $) 11)) (-3791 (((-121) $ (-763)) NIL)) (-2424 (((-169 (-215)) $) NIL (|has| (-169 (-215)) (-6 (-4523 "*"))))) (-3139 (((-568) $) 7)) (-1343 (((-568) $) 8)) (-4406 (((-634 (-169 (-215))) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) (-169 (-215)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-169 (-215)) (-1090))))) (-3405 (((-568) $) 12)) (-2801 (((-568) $) 13)) (-2271 (($ (-634 (-634 (-169 (-215))))) NIL)) (-2253 (($ (-1 (-169 (-215)) (-169 (-215))) $) NIL)) (-2797 (($ (-1 (-169 (-215)) (-169 (-215))) $) NIL) (($ (-1 (-169 (-215)) (-169 (-215)) (-169 (-215))) $ $) NIL) (($ (-1 (-169 (-215)) (-169 (-215)) (-169 (-215))) $ $ (-169 (-215))) NIL)) (-1843 (((-634 (-634 (-169 (-215)))) $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (|has| (-169 (-215)) (-1090)))) (-2715 (((-3 $ "failed") $) NIL (|has| (-169 (-215)) (-365)))) (-4018 (($ $ $) NIL)) (-4025 (((-1108) $) NIL (|has| (-169 (-215)) (-1090)))) (-2490 (($ $ (-169 (-215))) NIL)) (-2597 (((-3 $ "failed") $ (-169 (-215))) NIL (|has| (-169 (-215)) (-558)))) (-3951 (((-121) (-1 (-121) (-169 (-215))) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-169 (-215))))) NIL (-12 (|has| (-169 (-215)) (-303 (-169 (-215)))) (|has| (-169 (-215)) (-1090)))) (($ $ (-288 (-169 (-215)))) NIL (-12 (|has| (-169 (-215)) (-303 (-169 (-215)))) (|has| (-169 (-215)) (-1090)))) (($ $ (-169 (-215)) (-169 (-215))) NIL (-12 (|has| (-169 (-215)) (-303 (-169 (-215)))) (|has| (-169 (-215)) (-1090)))) (($ $ (-634 (-169 (-215))) (-634 (-169 (-215)))) NIL (-12 (|has| (-169 (-215)) (-303 (-169 (-215)))) (|has| (-169 (-215)) (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) 17)) (-2781 (((-169 (-215)) $ (-568) (-568)) NIL) (((-169 (-215)) $ (-568) (-568) (-169 (-215))) NIL) (($ $ (-634 (-568)) (-634 (-568))) NIL)) (-3499 (($ (-634 (-169 (-215)))) NIL) (($ (-634 $)) NIL)) (-4322 (((-121) $) NIL)) (-2591 (((-169 (-215)) $) NIL (|has| (-169 (-215)) (-6 (-4523 "*"))))) (-4170 (((-763) (-1 (-121) (-169 (-215))) $) NIL (|has| $ (-6 -4521))) (((-763) (-169 (-215)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-169 (-215)) (-1090))))) (-3865 (($ $) NIL)) (-4063 (((-634 (-145)) $) NIL (|has| (-169 (-215)) (-301)))) (-2522 (((-145) $ (-568)) NIL)) (-2747 (((-850) $) NIL (|has| (-169 (-215)) (-1090))) (($ (-145)) NIL)) (-3437 (((-121) (-1 (-121) (-169 (-215))) $) NIL (|has| $ (-6 -4521)))) (-2675 (((-121) $) NIL)) (-1719 (((-121) $ $) NIL (|has| (-169 (-215)) (-1090)))) (-1781 (($ $ (-169 (-215))) NIL (|has| (-169 (-215)) (-365)))) (-1775 (($ $ $) NIL) (($ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| (-169 (-215)) (-365)))) (* (($ $ $) NIL) (($ (-169 (-215)) $) NIL) (($ $ (-169 (-215))) NIL) (($ (-568) $) NIL) (((-145) $ (-145)) NIL) (((-145) (-145) $) NIL)) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-144) (-13 (-677 (-169 (-215)) (-145) (-145)) (-10 -8 (-15 -3063 ($ (-568) (-568)))))) (T -144)) 
+((-3063 (*1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-144))))) 
+(-13 (-677 (-169 (-215)) (-145) (-145)) (-10 -8 (-15 -3063 ($ (-568) (-568))))) 
+((-2449 (((-121) $ $) NIL (|has| (-169 (-215)) (-1090)))) (-3207 (($ (-763)) NIL (|has| (-169 (-215)) (-23)))) (-4211 (($ (-634 (-169 (-215)))) NIL)) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-1324 (((-121) (-1 (-121) (-169 (-215)) (-169 (-215))) $) NIL) (((-121) $) NIL (|has| (-169 (-215)) (-842)))) (-2109 (($ (-1 (-121) (-169 (-215)) (-169 (-215))) $) NIL (|has| $ (-6 -4522))) (($ $) NIL (-12 (|has| $ (-6 -4522)) (|has| (-169 (-215)) (-842))))) (-3647 (($ (-1 (-121) (-169 (-215)) (-169 (-215))) $) NIL) (($ $) NIL (|has| (-169 (-215)) (-842)))) (-1667 (((-121) $ (-763)) NIL)) (-2438 (((-169 (-215)) $ (-568) (-169 (-215))) 18 (|has| $ (-6 -4522))) (((-169 (-215)) $ (-1210 (-568)) (-169 (-215))) NIL (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) (-169 (-215))) $) NIL (|has| $ (-6 -4521)))) (-4490 (($) NIL T CONST)) (-4452 (($ $) NIL (|has| $ (-6 -4522)))) (-3945 (($ $) NIL)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-169 (-215)) (-1090))))) (-4330 (($ (-169 (-215)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-169 (-215)) (-1090)))) (($ (-1 (-121) (-169 (-215))) $) NIL (|has| $ (-6 -4521)))) (-3094 (((-169 (-215)) (-1 (-169 (-215)) (-169 (-215)) (-169 (-215))) $ (-169 (-215)) (-169 (-215))) NIL (-12 (|has| $ (-6 -4521)) (|has| (-169 (-215)) (-1090)))) (((-169 (-215)) (-1 (-169 (-215)) (-169 (-215)) (-169 (-215))) $ (-169 (-215))) NIL (|has| $ (-6 -4521))) (((-169 (-215)) (-1 (-169 (-215)) (-169 (-215)) (-169 (-215))) $) NIL (|has| $ (-6 -4521)))) (-1292 (((-169 (-215)) $ (-568) (-169 (-215))) 9 (|has| $ (-6 -4522)))) (-3063 (($ (-568)) 14)) (-2069 (((-169 (-215)) $ (-568)) 8)) (-2766 (((-568) (-1 (-121) (-169 (-215))) $) NIL) (((-568) (-169 (-215)) $) NIL (|has| (-169 (-215)) (-1090))) (((-568) (-169 (-215)) $ (-568)) NIL (|has| (-169 (-215)) (-1090)))) (-3317 (((-634 (-169 (-215))) $) NIL (|has| $ (-6 -4521)))) (-1804 (((-679 (-169 (-215))) $ $) NIL (|has| (-169 (-215)) (-1047)))) (-1851 (($ (-763) (-169 (-215))) 16)) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) 12 (|has| (-568) (-842)))) (-1732 (($ $ $) NIL (|has| (-169 (-215)) (-842)))) (-3645 (($ (-1 (-121) (-169 (-215)) (-169 (-215))) $ $) NIL) (($ $ $) NIL (|has| (-169 (-215)) (-842)))) (-4406 (((-634 (-169 (-215))) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) (-169 (-215)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-169 (-215)) (-1090))))) (-3631 (((-568) $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (|has| (-169 (-215)) (-842)))) (-2253 (($ (-1 (-169 (-215)) (-169 (-215))) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-169 (-215)) (-169 (-215))) $) NIL) (($ (-1 (-169 (-215)) (-169 (-215)) (-169 (-215))) $ $) NIL)) (-4303 (((-169 (-215)) $) NIL (-12 (|has| (-169 (-215)) (-1002)) (|has| (-169 (-215)) (-1047))))) (-3796 (((-121) $ (-763)) NIL)) (-3680 (((-169 (-215)) $) NIL (-12 (|has| (-169 (-215)) (-1002)) (|has| (-169 (-215)) (-1047))))) (-1893 (((-1143) $) NIL (|has| (-169 (-215)) (-1090)))) (-4124 (($ (-169 (-215)) $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4025 (((-1108) $) NIL (|has| (-169 (-215)) (-1090)))) (-3877 (((-169 (-215)) $) NIL (|has| (-568) (-842)))) (-2712 (((-3 (-169 (-215)) "failed") (-1 (-121) (-169 (-215))) $) NIL)) (-2490 (($ $ (-169 (-215))) 15 (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) (-169 (-215))) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-169 (-215))))) NIL (-12 (|has| (-169 (-215)) (-303 (-169 (-215)))) (|has| (-169 (-215)) (-1090)))) (($ $ (-288 (-169 (-215)))) NIL (-12 (|has| (-169 (-215)) (-303 (-169 (-215)))) (|has| (-169 (-215)) (-1090)))) (($ $ (-169 (-215)) (-169 (-215))) NIL (-12 (|has| (-169 (-215)) (-303 (-169 (-215)))) (|has| (-169 (-215)) (-1090)))) (($ $ (-634 (-169 (-215))) (-634 (-169 (-215)))) NIL (-12 (|has| (-169 (-215)) (-303 (-169 (-215)))) (|has| (-169 (-215)) (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) (-169 (-215)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-169 (-215)) (-1090))))) (-1480 (((-634 (-169 (-215))) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) 13)) (-2781 (((-169 (-215)) $ (-568) (-169 (-215))) NIL) (((-169 (-215)) $ (-568)) 17) (($ $ (-1210 (-568))) NIL)) (-2286 (((-169 (-215)) $ $) NIL (|has| (-169 (-215)) (-1047)))) (-2828 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-3372 (($ $ $) NIL (|has| (-169 (-215)) (-1047)))) (-4170 (((-763) (-1 (-121) (-169 (-215))) $) NIL (|has| $ (-6 -4521))) (((-763) (-169 (-215)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-169 (-215)) (-1090))))) (-3306 (($ $ $ (-568)) NIL (|has| $ (-6 -4522)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| (-169 (-215)) (-609 (-541))))) (-4289 (($ (-634 (-169 (-215)))) NIL)) (-2770 (($ $ (-169 (-215))) NIL) (($ (-169 (-215)) $) NIL) (($ $ $) NIL) (($ (-634 $)) NIL)) (-2747 (((-850) $) NIL (|has| (-169 (-215)) (-1090)))) (-3437 (((-121) (-1 (-121) (-169 (-215))) $) NIL (|has| $ (-6 -4521)))) (-1753 (((-121) $ $) NIL (|has| (-169 (-215)) (-842)))) (-1740 (((-121) $ $) NIL (|has| (-169 (-215)) (-842)))) (-1719 (((-121) $ $) NIL (|has| (-169 (-215)) (-1090)))) (-1747 (((-121) $ $) NIL (|has| (-169 (-215)) (-842)))) (-1734 (((-121) $ $) NIL (|has| (-169 (-215)) (-842)))) (-1775 (($ $) NIL (|has| (-169 (-215)) (-21))) (($ $ $) NIL (|has| (-169 (-215)) (-21)))) (-1769 (($ $ $) NIL (|has| (-169 (-215)) (-25)))) (* (($ (-568) $) NIL (|has| (-169 (-215)) (-21))) (($ (-169 (-215)) $) NIL (|has| (-169 (-215)) (-716))) (($ $ (-169 (-215))) NIL (|has| (-169 (-215)) (-716)))) (-1699 (((-763) $) 11 (|has| $ (-6 -4521))))) 
+(((-145) (-13 (-1242 (-169 (-215))) (-10 -8 (-15 -3063 ($ (-568))) (-15 -4211 ($ (-634 (-169 (-215)))))))) (T -145)) 
+((-3063 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-145)))) (-4211 (*1 *1 *2) (-12 (-5 *2 (-634 (-169 (-215)))) (-5 *1 (-145))))) 
+(-13 (-1242 (-169 (-215))) (-10 -8 (-15 -3063 ($ (-568))) (-15 -4211 ($ (-634 (-169 (-215))))))) 
+((-2341 (($ $ $) 8)) (-2406 (($ $) 7)) (-3584 (($ $ $) 6))) 
 (((-146) (-1275)) (T -146)) 
-((-2413 (*1 *1 *1 *1) (-4 *1 (-146))) (-2427 (*1 *1 *1) (-4 *1 (-146))) (-2787 (*1 *1 *1 *1) (-4 *1 (-146)))) 
-(-13 (-10 -8 (-15 -2787 ($ $ $)) (-15 -2427 ($ $)) (-15 -2413 ($ $ $)))) 
-((-2447 (((-121) $ $) NIL)) (-1534 (((-121) $) 38)) (-2072 (($ $) 50)) (-4194 (($) 25)) (-3983 (((-763)) 16)) (-1731 (($) 24)) (-2539 (($) 26)) (-1379 (((-568) $) 21)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-4145 (((-121) $) 40)) (-2003 (($ $) 51)) (-3683 (((-917) $) 22)) (-4487 (((-1143) $) 46)) (-4355 (($ (-917)) 20)) (-3512 (((-121) $) 36)) (-4022 (((-1108) $) NIL)) (-2687 (($) 27)) (-4402 (((-121) $) 34)) (-2745 (((-850) $) 29)) (-2916 (($ (-568)) 18) (($ (-1143)) 49)) (-1776 (((-121) $) 44)) (-4150 (((-121) $) 42)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 13)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 14))) 
-(((-147) (-13 (-836) (-10 -8 (-15 -1379 ((-568) $)) (-15 -2916 ($ (-568))) (-15 -2916 ($ (-1143))) (-15 -4194 ($)) (-15 -2539 ($)) (-15 -2687 ($)) (-15 -2072 ($ $)) (-15 -2003 ($ $)) (-15 -4402 ((-121) $)) (-15 -3512 ((-121) $)) (-15 -4150 ((-121) $)) (-15 -1534 ((-121) $)) (-15 -4145 ((-121) $)) (-15 -1776 ((-121) $))))) (T -147)) 
-((-1379 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-147)))) (-2916 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-147)))) (-2916 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-147)))) (-4194 (*1 *1) (-5 *1 (-147))) (-2539 (*1 *1) (-5 *1 (-147))) (-2687 (*1 *1) (-5 *1 (-147))) (-2072 (*1 *1 *1) (-5 *1 (-147))) (-2003 (*1 *1 *1) (-5 *1 (-147))) (-4402 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147)))) (-3512 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147)))) (-4150 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147)))) (-1534 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147)))) (-4145 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147)))) (-1776 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147))))) 
-(-13 (-836) (-10 -8 (-15 -1379 ((-568) $)) (-15 -2916 ($ (-568))) (-15 -2916 ($ (-1143))) (-15 -4194 ($)) (-15 -2539 ($)) (-15 -2687 ($)) (-15 -2072 ($ $)) (-15 -2003 ($ $)) (-15 -4402 ((-121) $)) (-15 -3512 ((-121) $)) (-15 -4150 ((-121) $)) (-15 -1534 ((-121) $)) (-15 -4145 ((-121) $)) (-15 -1776 ((-121) $)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-2925 (((-3 $ "failed") $) 33)) (-2735 (((-121) $) 30)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11) (($ (-568)) 27)) (-4371 (((-3 $ "failed") $) 34)) (-4078 (((-763)) 28)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
+((-2341 (*1 *1 *1 *1) (-4 *1 (-146))) (-2406 (*1 *1 *1) (-4 *1 (-146))) (-3584 (*1 *1 *1 *1) (-4 *1 (-146)))) 
+(-13 (-10 -8 (-15 -3584 ($ $ $)) (-15 -2406 ($ $)) (-15 -2341 ($ $ $)))) 
+((-2449 (((-121) $ $) NIL)) (-4203 (((-121) $) 38)) (-3083 (($ $) 50)) (-4053 (($) 25)) (-3986 (((-763)) 16)) (-1733 (($) 24)) (-1827 (($) 26)) (-3894 (((-568) $) 21)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-3786 (((-121) $) 40)) (-4499 (($ $) 51)) (-2291 (((-917) $) 22)) (-1893 (((-1143) $) 46)) (-4357 (($ (-917)) 20)) (-4003 (((-121) $) 36)) (-4025 (((-1108) $) NIL)) (-1331 (($) 27)) (-4407 (((-121) $) 34)) (-2747 (((-850) $) 29)) (-2918 (($ (-568)) 18) (($ (-1143)) 49)) (-4000 (((-121) $) 44)) (-3798 (((-121) $) 42)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 13)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 14))) 
+(((-147) (-13 (-836) (-10 -8 (-15 -3894 ((-568) $)) (-15 -2918 ($ (-568))) (-15 -2918 ($ (-1143))) (-15 -4053 ($)) (-15 -1827 ($)) (-15 -1331 ($)) (-15 -3083 ($ $)) (-15 -4499 ($ $)) (-15 -4407 ((-121) $)) (-15 -4003 ((-121) $)) (-15 -3798 ((-121) $)) (-15 -4203 ((-121) $)) (-15 -3786 ((-121) $)) (-15 -4000 ((-121) $))))) (T -147)) 
+((-3894 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-147)))) (-2918 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-147)))) (-2918 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-147)))) (-4053 (*1 *1) (-5 *1 (-147))) (-1827 (*1 *1) (-5 *1 (-147))) (-1331 (*1 *1) (-5 *1 (-147))) (-3083 (*1 *1 *1) (-5 *1 (-147))) (-4499 (*1 *1 *1) (-5 *1 (-147))) (-4407 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147)))) (-4003 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147)))) (-3798 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147)))) (-4203 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147)))) (-3786 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147)))) (-4000 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147))))) 
+(-13 (-836) (-10 -8 (-15 -3894 ((-568) $)) (-15 -2918 ($ (-568))) (-15 -2918 ($ (-1143))) (-15 -4053 ($)) (-15 -1827 ($)) (-15 -1331 ($)) (-15 -3083 ($ $)) (-15 -4499 ($ $)) (-15 -4407 ((-121) $)) (-15 -4003 ((-121) $)) (-15 -3798 ((-121) $)) (-15 -4203 ((-121) $)) (-15 -3786 ((-121) $)) (-15 -4000 ((-121) $)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-2902 (((-3 $ "failed") $) 33)) (-1598 (((-121) $) 30)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11) (($ (-568)) 27)) (-3385 (((-3 $ "failed") $) 34)) (-3425 (((-763)) 28)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
 (((-148) (-1275)) (T -148)) 
-((-4371 (*1 *1 *1) (|partial| -4 *1 (-148)))) 
-(-13 (-1047) (-10 -8 (-15 -4371 ((-3 $ "failed") $)))) 
+((-3385 (*1 *1 *1) (|partial| -4 *1 (-148)))) 
+(-13 (-1047) (-10 -8 (-15 -3385 ((-3 $ "failed") $)))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 $) . T) ((-716) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-2678 ((|#1| (-679 |#1|) |#1|) 17))) 
-(((-149 |#1|) (-10 -7 (-15 -2678 (|#1| (-679 |#1|) |#1|))) (-172)) (T -149)) 
-((-2678 (*1 *2 *3 *2) (-12 (-5 *3 (-679 *2)) (-4 *2 (-172)) (-5 *1 (-149 *2))))) 
-(-10 -7 (-15 -2678 (|#1| (-679 |#1|) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-2925 (((-3 $ "failed") $) 33)) (-2735 (((-121) $) 30)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11) (($ (-568)) 27)) (-4078 (((-763)) 28)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
+((-1295 ((|#1| (-679 |#1|) |#1|) 17))) 
+(((-149 |#1|) (-10 -7 (-15 -1295 (|#1| (-679 |#1|) |#1|))) (-172)) (T -149)) 
+((-1295 (*1 *2 *3 *2) (-12 (-5 *3 (-679 *2)) (-4 *2 (-172)) (-5 *1 (-149 *2))))) 
+(-10 -7 (-15 -1295 (|#1| (-679 |#1|) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-2902 (((-3 $ "failed") $) 33)) (-1598 (((-121) $) 30)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11) (($ (-568)) 27)) (-3425 (((-763)) 28)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
 (((-150) (-1275)) (T -150)) 
 NIL 
 (-13 (-1047)) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 $) . T) ((-716) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-4495 (((-2 (|:| -3438 (-763)) (|:| -2348 (-409 |#2|)) (|:| |radicand| |#2|)) (-409 |#2|) (-763)) 69)) (-2536 (((-3 (-2 (|:| |radicand| (-409 |#2|)) (|:| |deg| (-763))) "failed") |#3|) 51)) (-2177 (((-2 (|:| -2348 (-409 |#2|)) (|:| |poly| |#3|)) |#3|) 36)) (-2650 ((|#1| |#3| |#3|) 39)) (-1339 ((|#3| |#3| (-409 |#2|) (-409 |#2|)) 19)) (-2000 (((-2 (|:| |func| |#3|) (|:| |poly| |#3|) (|:| |c1| (-409 |#2|)) (|:| |c2| (-409 |#2|)) (|:| |deg| (-763))) |#3| |#3|) 48))) 
-(((-151 |#1| |#2| |#3|) (-10 -7 (-15 -2177 ((-2 (|:| -2348 (-409 |#2|)) (|:| |poly| |#3|)) |#3|)) (-15 -2536 ((-3 (-2 (|:| |radicand| (-409 |#2|)) (|:| |deg| (-763))) "failed") |#3|)) (-15 -4495 ((-2 (|:| -3438 (-763)) (|:| -2348 (-409 |#2|)) (|:| |radicand| |#2|)) (-409 |#2|) (-763))) (-15 -2650 (|#1| |#3| |#3|)) (-15 -1339 (|#3| |#3| (-409 |#2|) (-409 |#2|))) (-15 -2000 ((-2 (|:| |func| |#3|) (|:| |poly| |#3|) (|:| |c1| (-409 |#2|)) (|:| |c2| (-409 |#2|)) (|:| |deg| (-763))) |#3| |#3|))) (-1199) (-1219 |#1|) (-1219 (-409 |#2|))) (T -151)) 
-((-2000 (*1 *2 *3 *3) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| |func| *3) (|:| |poly| *3) (|:| |c1| (-409 *5)) (|:| |c2| (-409 *5)) (|:| |deg| (-763)))) (-5 *1 (-151 *4 *5 *3)) (-4 *3 (-1219 (-409 *5))))) (-1339 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-409 *5)) (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-5 *1 (-151 *4 *5 *2)) (-4 *2 (-1219 *3)))) (-2650 (*1 *2 *3 *3) (-12 (-4 *4 (-1219 *2)) (-4 *2 (-1199)) (-5 *1 (-151 *2 *4 *3)) (-4 *3 (-1219 (-409 *4))))) (-4495 (*1 *2 *3 *4) (-12 (-5 *3 (-409 *6)) (-4 *5 (-1199)) (-4 *6 (-1219 *5)) (-5 *2 (-2 (|:| -3438 (-763)) (|:| -2348 *3) (|:| |radicand| *6))) (-5 *1 (-151 *5 *6 *7)) (-5 *4 (-763)) (-4 *7 (-1219 *3)))) (-2536 (*1 *2 *3) (|partial| -12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| |radicand| (-409 *5)) (|:| |deg| (-763)))) (-5 *1 (-151 *4 *5 *3)) (-4 *3 (-1219 (-409 *5))))) (-2177 (*1 *2 *3) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| -2348 (-409 *5)) (|:| |poly| *3))) (-5 *1 (-151 *4 *5 *3)) (-4 *3 (-1219 (-409 *5)))))) 
-(-10 -7 (-15 -2177 ((-2 (|:| -2348 (-409 |#2|)) (|:| |poly| |#3|)) |#3|)) (-15 -2536 ((-3 (-2 (|:| |radicand| (-409 |#2|)) (|:| |deg| (-763))) "failed") |#3|)) (-15 -4495 ((-2 (|:| -3438 (-763)) (|:| -2348 (-409 |#2|)) (|:| |radicand| |#2|)) (-409 |#2|) (-763))) (-15 -2650 (|#1| |#3| |#3|)) (-15 -1339 (|#3| |#3| (-409 |#2|) (-409 |#2|))) (-15 -2000 ((-2 (|:| |func| |#3|) (|:| |poly| |#3|) (|:| |c1| (-409 |#2|)) (|:| |c2| (-409 |#2|)) (|:| |deg| (-763))) |#3| |#3|))) 
-((-1858 (((-3 (-634 (-1157 |#2|)) "failed") (-634 (-1157 |#2|)) (-1157 |#2|)) 31))) 
-(((-152 |#1| |#2|) (-10 -7 (-15 -1858 ((-3 (-634 (-1157 |#2|)) "failed") (-634 (-1157 |#2|)) (-1157 |#2|)))) (-550) (-166 |#1|)) (T -152)) 
-((-1858 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 *5))) (-5 *3 (-1157 *5)) (-4 *5 (-166 *4)) (-4 *4 (-550)) (-5 *1 (-152 *4 *5))))) 
-(-10 -7 (-15 -1858 ((-3 (-634 (-1157 |#2|)) "failed") (-634 (-1157 |#2|)) (-1157 |#2|)))) 
-((-2801 (($ (-1 (-121) |#2|) $) 29)) (-3924 (($ $) 36)) (-4328 (($ (-1 (-121) |#2|) $) 27) (($ |#2| $) 32)) (-3092 ((|#2| (-1 |#2| |#2| |#2|) $) 22) ((|#2| (-1 |#2| |#2| |#2|) $ |#2|) 24) ((|#2| (-1 |#2| |#2| |#2|) $ |#2| |#2|) 34)) (-3775 (((-3 |#2| "failed") (-1 (-121) |#2|) $) 19)) (-1387 (((-121) (-1 (-121) |#2|) $) 16)) (-4168 (((-763) (-1 (-121) |#2|) $) 13) (((-763) |#2| $) NIL)) (-1319 (((-121) (-1 (-121) |#2|) $) 15)) (-1697 (((-763) $) 11))) 
-(((-153 |#1| |#2|) (-10 -8 (-15 -3924 (|#1| |#1|)) (-15 -4328 (|#1| |#2| |#1|)) (-15 -3092 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -2801 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -4328 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -3092 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3092 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -3775 ((-3 |#2| "failed") (-1 (-121) |#2|) |#1|)) (-15 -4168 ((-763) |#2| |#1|)) (-15 -4168 ((-763) (-1 (-121) |#2|) |#1|)) (-15 -1387 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -1319 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -1697 ((-763) |#1|))) (-154 |#2|) (-1195)) (T -153)) 
-NIL 
-(-10 -8 (-15 -3924 (|#1| |#1|)) (-15 -4328 (|#1| |#2| |#1|)) (-15 -3092 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -2801 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -4328 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -3092 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3092 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -3775 ((-3 |#2| "failed") (-1 (-121) |#2|) |#1|)) (-15 -4168 ((-763) |#2| |#1|)) (-15 -4168 ((-763) (-1 (-121) |#2|) |#1|)) (-15 -1387 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -1319 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -1697 ((-763) |#1|))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2510 (((-121) $ (-763)) 8)) (-2801 (($ (-1 (-121) |#1|) $) 41 (|has| $ (-6 -4519)))) (-2671 (($) 7 T CONST)) (-3924 (($ $) 38 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-4328 (($ (-1 (-121) |#1|) $) 42 (|has| $ (-6 -4519))) (($ |#1| $) 39 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $) 44 (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 43 (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 40 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) 9)) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35)) (-2166 (((-121) $ (-763)) 10)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 45)) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-4278 (((-541) $) 37 (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) 46)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-3799 (((-2 (|:| -3483 (-763)) (|:| -2350 (-409 |#2|)) (|:| |radicand| |#2|)) (-409 |#2|) (-763)) 69)) (-1814 (((-3 (-2 (|:| |radicand| (-409 |#2|)) (|:| |deg| (-763))) "failed") |#3|) 51)) (-2466 (((-2 (|:| -2350 (-409 |#2|)) (|:| |poly| |#3|)) |#3|) 36)) (-4378 ((|#1| |#3| |#3|) 39)) (-1339 ((|#3| |#3| (-409 |#2|) (-409 |#2|)) 19)) (-4489 (((-2 (|:| |func| |#3|) (|:| |poly| |#3|) (|:| |c1| (-409 |#2|)) (|:| |c2| (-409 |#2|)) (|:| |deg| (-763))) |#3| |#3|) 48))) 
+(((-151 |#1| |#2| |#3|) (-10 -7 (-15 -2466 ((-2 (|:| -2350 (-409 |#2|)) (|:| |poly| |#3|)) |#3|)) (-15 -1814 ((-3 (-2 (|:| |radicand| (-409 |#2|)) (|:| |deg| (-763))) "failed") |#3|)) (-15 -3799 ((-2 (|:| -3483 (-763)) (|:| -2350 (-409 |#2|)) (|:| |radicand| |#2|)) (-409 |#2|) (-763))) (-15 -4378 (|#1| |#3| |#3|)) (-15 -1339 (|#3| |#3| (-409 |#2|) (-409 |#2|))) (-15 -4489 ((-2 (|:| |func| |#3|) (|:| |poly| |#3|) (|:| |c1| (-409 |#2|)) (|:| |c2| (-409 |#2|)) (|:| |deg| (-763))) |#3| |#3|))) (-1199) (-1219 |#1|) (-1219 (-409 |#2|))) (T -151)) 
+((-4489 (*1 *2 *3 *3) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| |func| *3) (|:| |poly| *3) (|:| |c1| (-409 *5)) (|:| |c2| (-409 *5)) (|:| |deg| (-763)))) (-5 *1 (-151 *4 *5 *3)) (-4 *3 (-1219 (-409 *5))))) (-1339 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-409 *5)) (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-5 *1 (-151 *4 *5 *2)) (-4 *2 (-1219 *3)))) (-4378 (*1 *2 *3 *3) (-12 (-4 *4 (-1219 *2)) (-4 *2 (-1199)) (-5 *1 (-151 *2 *4 *3)) (-4 *3 (-1219 (-409 *4))))) (-3799 (*1 *2 *3 *4) (-12 (-5 *3 (-409 *6)) (-4 *5 (-1199)) (-4 *6 (-1219 *5)) (-5 *2 (-2 (|:| -3483 (-763)) (|:| -2350 *3) (|:| |radicand| *6))) (-5 *1 (-151 *5 *6 *7)) (-5 *4 (-763)) (-4 *7 (-1219 *3)))) (-1814 (*1 *2 *3) (|partial| -12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| |radicand| (-409 *5)) (|:| |deg| (-763)))) (-5 *1 (-151 *4 *5 *3)) (-4 *3 (-1219 (-409 *5))))) (-2466 (*1 *2 *3) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| -2350 (-409 *5)) (|:| |poly| *3))) (-5 *1 (-151 *4 *5 *3)) (-4 *3 (-1219 (-409 *5)))))) 
+(-10 -7 (-15 -2466 ((-2 (|:| -2350 (-409 |#2|)) (|:| |poly| |#3|)) |#3|)) (-15 -1814 ((-3 (-2 (|:| |radicand| (-409 |#2|)) (|:| |deg| (-763))) "failed") |#3|)) (-15 -3799 ((-2 (|:| -3483 (-763)) (|:| -2350 (-409 |#2|)) (|:| |radicand| |#2|)) (-409 |#2|) (-763))) (-15 -4378 (|#1| |#3| |#3|)) (-15 -1339 (|#3| |#3| (-409 |#2|) (-409 |#2|))) (-15 -4489 ((-2 (|:| |func| |#3|) (|:| |poly| |#3|) (|:| |c1| (-409 |#2|)) (|:| |c2| (-409 |#2|)) (|:| |deg| (-763))) |#3| |#3|))) 
+((-2434 (((-3 (-634 (-1157 |#2|)) "failed") (-634 (-1157 |#2|)) (-1157 |#2|)) 31))) 
+(((-152 |#1| |#2|) (-10 -7 (-15 -2434 ((-3 (-634 (-1157 |#2|)) "failed") (-634 (-1157 |#2|)) (-1157 |#2|)))) (-550) (-166 |#1|)) (T -152)) 
+((-2434 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 *5))) (-5 *3 (-1157 *5)) (-4 *5 (-166 *4)) (-4 *4 (-550)) (-5 *1 (-152 *4 *5))))) 
+(-10 -7 (-15 -2434 ((-3 (-634 (-1157 |#2|)) "failed") (-634 (-1157 |#2|)) (-1157 |#2|)))) 
+((-2803 (($ (-1 (-121) |#2|) $) 29)) (-3926 (($ $) 36)) (-4330 (($ (-1 (-121) |#2|) $) 27) (($ |#2| $) 32)) (-3094 ((|#2| (-1 |#2| |#2| |#2|) $) 22) ((|#2| (-1 |#2| |#2| |#2|) $ |#2|) 24) ((|#2| (-1 |#2| |#2| |#2|) $ |#2| |#2|) 34)) (-2712 (((-3 |#2| "failed") (-1 (-121) |#2|) $) 19)) (-3951 (((-121) (-1 (-121) |#2|) $) 16)) (-4170 (((-763) (-1 (-121) |#2|) $) 13) (((-763) |#2| $) NIL)) (-3437 (((-121) (-1 (-121) |#2|) $) 15)) (-1699 (((-763) $) 11))) 
+(((-153 |#1| |#2|) (-10 -8 (-15 -3926 (|#1| |#1|)) (-15 -4330 (|#1| |#2| |#1|)) (-15 -3094 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -2803 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -4330 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -3094 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3094 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -2712 ((-3 |#2| "failed") (-1 (-121) |#2|) |#1|)) (-15 -4170 ((-763) |#2| |#1|)) (-15 -4170 ((-763) (-1 (-121) |#2|) |#1|)) (-15 -3951 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3437 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -1699 ((-763) |#1|))) (-154 |#2|) (-1195)) (T -153)) 
+NIL 
+(-10 -8 (-15 -3926 (|#1| |#1|)) (-15 -4330 (|#1| |#2| |#1|)) (-15 -3094 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -2803 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -4330 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -3094 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3094 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -2712 ((-3 |#2| "failed") (-1 (-121) |#2|) |#1|)) (-15 -4170 ((-763) |#2| |#1|)) (-15 -4170 ((-763) (-1 (-121) |#2|) |#1|)) (-15 -3951 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3437 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -1699 ((-763) |#1|))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-1667 (((-121) $ (-763)) 8)) (-2803 (($ (-1 (-121) |#1|) $) 41 (|has| $ (-6 -4521)))) (-4490 (($) 7 T CONST)) (-3926 (($ $) 38 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-4330 (($ (-1 (-121) |#1|) $) 42 (|has| $ (-6 -4521))) (($ |#1| $) 39 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $) 44 (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 43 (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 40 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) 9)) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35)) (-3796 (((-121) $ (-763)) 10)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 45)) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-4280 (((-541) $) 37 (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) 46)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-154 |#1|) (-1275) (-1195)) (T -154)) 
-((-4287 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-4 *1 (-154 *3)))) (-3775 (*1 *2 *3 *1) (|partial| -12 (-5 *3 (-1 (-121) *2)) (-4 *1 (-154 *2)) (-4 *2 (-1195)))) (-3092 (*1 *2 *3 *1) (-12 (-5 *3 (-1 *2 *2 *2)) (|has| *1 (-6 -4519)) (-4 *1 (-154 *2)) (-4 *2 (-1195)))) (-3092 (*1 *2 *3 *1 *2) (-12 (-5 *3 (-1 *2 *2 *2)) (|has| *1 (-6 -4519)) (-4 *1 (-154 *2)) (-4 *2 (-1195)))) (-4328 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4519)) (-4 *1 (-154 *3)) (-4 *3 (-1195)))) (-2801 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4519)) (-4 *1 (-154 *3)) (-4 *3 (-1195)))) (-3092 (*1 *2 *3 *1 *2 *2) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1090)) (|has| *1 (-6 -4519)) (-4 *1 (-154 *2)) (-4 *2 (-1195)))) (-4328 (*1 *1 *2 *1) (-12 (|has| *1 (-6 -4519)) (-4 *1 (-154 *2)) (-4 *2 (-1195)) (-4 *2 (-1090)))) (-3924 (*1 *1 *1) (-12 (|has| *1 (-6 -4519)) (-4 *1 (-154 *2)) (-4 *2 (-1195)) (-4 *2 (-1090))))) 
-(-13 (-499 |t#1|) (-10 -8 (-15 -4287 ($ (-634 |t#1|))) (-15 -3775 ((-3 |t#1| "failed") (-1 (-121) |t#1|) $)) (IF (|has| $ (-6 -4519)) (PROGN (-15 -3092 (|t#1| (-1 |t#1| |t#1| |t#1|) $)) (-15 -3092 (|t#1| (-1 |t#1| |t#1| |t#1|) $ |t#1|)) (-15 -4328 ($ (-1 (-121) |t#1|) $)) (-15 -2801 ($ (-1 (-121) |t#1|) $)) (IF (|has| |t#1| (-1090)) (PROGN (-15 -3092 (|t#1| (-1 |t#1| |t#1| |t#1|) $ |t#1| |t#1|)) (-15 -4328 ($ |t#1| $)) (-15 -3924 ($ $))) |noBranch|)) |noBranch|) (IF (|has| |t#1| (-609 (-541))) (-6 (-609 (-541))) |noBranch|))) 
+((-4289 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-4 *1 (-154 *3)))) (-2712 (*1 *2 *3 *1) (|partial| -12 (-5 *3 (-1 (-121) *2)) (-4 *1 (-154 *2)) (-4 *2 (-1195)))) (-3094 (*1 *2 *3 *1) (-12 (-5 *3 (-1 *2 *2 *2)) (|has| *1 (-6 -4521)) (-4 *1 (-154 *2)) (-4 *2 (-1195)))) (-3094 (*1 *2 *3 *1 *2) (-12 (-5 *3 (-1 *2 *2 *2)) (|has| *1 (-6 -4521)) (-4 *1 (-154 *2)) (-4 *2 (-1195)))) (-4330 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4521)) (-4 *1 (-154 *3)) (-4 *3 (-1195)))) (-2803 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4521)) (-4 *1 (-154 *3)) (-4 *3 (-1195)))) (-3094 (*1 *2 *3 *1 *2 *2) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1090)) (|has| *1 (-6 -4521)) (-4 *1 (-154 *2)) (-4 *2 (-1195)))) (-4330 (*1 *1 *2 *1) (-12 (|has| *1 (-6 -4521)) (-4 *1 (-154 *2)) (-4 *2 (-1195)) (-4 *2 (-1090)))) (-3926 (*1 *1 *1) (-12 (|has| *1 (-6 -4521)) (-4 *1 (-154 *2)) (-4 *2 (-1195)) (-4 *2 (-1090))))) 
+(-13 (-499 |t#1|) (-10 -8 (-15 -4289 ($ (-634 |t#1|))) (-15 -2712 ((-3 |t#1| "failed") (-1 (-121) |t#1|) $)) (IF (|has| $ (-6 -4521)) (PROGN (-15 -3094 (|t#1| (-1 |t#1| |t#1| |t#1|) $)) (-15 -3094 (|t#1| (-1 |t#1| |t#1| |t#1|) $ |t#1|)) (-15 -4330 ($ (-1 (-121) |t#1|) $)) (-15 -2803 ($ (-1 (-121) |t#1|) $)) (IF (|has| |t#1| (-1090)) (PROGN (-15 -3094 (|t#1| (-1 |t#1| |t#1| |t#1|) $ |t#1| |t#1|)) (-15 -4330 ($ |t#1| $)) (-15 -3926 ($ $))) |noBranch|)) |noBranch|) (IF (|has| |t#1| (-609 (-541))) (-6 (-609 (-541))) |noBranch|))) 
 (((-39) . T) ((-105) |has| |#1| (-1090)) ((-608 (-850)) |has| |#1| (-1090)) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-1090) |has| |#1| (-1090)) ((-1195) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-2925 (((-3 $ "failed") $) 85)) (-2735 (((-121) $) NIL)) (-2047 (($ |#2| (-634 (-917))) 56)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2838 (($ (-917)) 48)) (-4321 (((-139)) 23)) (-2745 (((-850) $) 68) (($ (-568)) 46) (($ |#2|) 47)) (-2604 ((|#2| $ (-634 (-917))) 58)) (-4078 (((-763)) 20)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 40 T CONST)) (-1556 (($) 44 T CONST)) (-1717 (((-121) $ $) 26)) (-1779 (($ $ |#2|) NIL)) (-1773 (($ $) 34) (($ $ $) 32)) (-1767 (($ $ $) 30)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 37) (($ $ $) 52) (($ |#2| $) 39) (($ $ |#2|) NIL))) 
-(((-155 |#1| |#2| |#3|) (-13 (-1047) (-43 |#2|) (-1251 |#2|) (-10 -8 (-15 -2838 ($ (-917))) (-15 -2047 ($ |#2| (-634 (-917)))) (-15 -2604 (|#2| $ (-634 (-917)))) (-15 -2925 ((-3 $ "failed") $)))) (-917) (-365) (-994 |#1| |#2|)) (T -155)) 
-((-2925 (*1 *1 *1) (|partial| -12 (-5 *1 (-155 *2 *3 *4)) (-14 *2 (-917)) (-4 *3 (-365)) (-14 *4 (-994 *2 *3)))) (-2838 (*1 *1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-155 *3 *4 *5)) (-14 *3 *2) (-4 *4 (-365)) (-14 *5 (-994 *3 *4)))) (-2047 (*1 *1 *2 *3) (-12 (-5 *3 (-634 (-917))) (-5 *1 (-155 *4 *2 *5)) (-14 *4 (-917)) (-4 *2 (-365)) (-14 *5 (-994 *4 *2)))) (-2604 (*1 *2 *1 *3) (-12 (-5 *3 (-634 (-917))) (-4 *2 (-365)) (-5 *1 (-155 *4 *2 *5)) (-14 *4 (-917)) (-14 *5 (-994 *4 *2))))) 
-(-13 (-1047) (-43 |#2|) (-1251 |#2|) (-10 -8 (-15 -2838 ($ (-917))) (-15 -2047 ($ |#2| (-634 (-917)))) (-15 -2604 (|#2| $ (-634 (-917)))) (-15 -2925 ((-3 $ "failed") $)))) 
-((-1615 (((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-634 (-634 (-944 (-215)))) (-215) (-215) (-215) (-215)) 38)) (-3648 (((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927) (-409 (-568)) (-409 (-568))) 62) (((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927)) 63)) (-3182 (((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-634 (-634 (-944 (-215))))) 66) (((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-634 (-944 (-215)))) 65) (((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927) (-409 (-568)) (-409 (-568))) 57) (((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927)) 58))) 
-(((-156) (-10 -7 (-15 -3182 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927))) (-15 -3182 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927) (-409 (-568)) (-409 (-568)))) (-15 -3648 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927))) (-15 -3648 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927) (-409 (-568)) (-409 (-568)))) (-15 -1615 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-634 (-634 (-944 (-215)))) (-215) (-215) (-215) (-215))) (-15 -3182 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-634 (-944 (-215))))) (-15 -3182 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-634 (-634 (-944 (-215)))))))) (T -156)) 
-((-3182 (*1 *2 *3) (-12 (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156)) (-5 *3 (-634 (-634 (-944 (-215))))))) (-3182 (*1 *2 *3) (-12 (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156)) (-5 *3 (-634 (-944 (-215)))))) (-1615 (*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *4 (-215)) (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 *4)))) (|:| |xValues| (-1084 *4)) (|:| |yValues| (-1084 *4)))) (-5 *1 (-156)) (-5 *3 (-634 (-634 (-944 *4)))))) (-3648 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-927)) (-5 *4 (-409 (-568))) (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156)))) (-3648 (*1 *2 *3) (-12 (-5 *3 (-927)) (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156)))) (-3182 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-927)) (-5 *4 (-409 (-568))) (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156)))) (-3182 (*1 *2 *3) (-12 (-5 *3 (-927)) (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156))))) 
-(-10 -7 (-15 -3182 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927))) (-15 -3182 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927) (-409 (-568)) (-409 (-568)))) (-15 -3648 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927))) (-15 -3648 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927) (-409 (-568)) (-409 (-568)))) (-15 -1615 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-634 (-634 (-944 (-215)))) (-215) (-215) (-215) (-215))) (-15 -3182 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-634 (-944 (-215))))) (-15 -3182 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-634 (-634 (-944 (-215))))))) 
-((-2385 (((-634 (-169 |#2|)) |#1| |#2|) 45))) 
-(((-157 |#1| |#2|) (-10 -7 (-15 -2385 ((-634 (-169 |#2|)) |#1| |#2|))) (-1219 (-169 (-568))) (-13 (-365) (-840))) (T -157)) 
-((-2385 (*1 *2 *3 *4) (-12 (-5 *2 (-634 (-169 *4))) (-5 *1 (-157 *3 *4)) (-4 *3 (-1219 (-169 (-568)))) (-4 *4 (-13 (-365) (-840)))))) 
-(-10 -7 (-15 -2385 ((-634 (-169 |#2|)) |#1| |#2|))) 
-((-2447 (((-121) $ $) NIL)) (-3871 (($) 15)) (-3476 (($) 14)) (-3067 (((-917)) 22)) (-4487 (((-1143) $) NIL)) (-1819 (((-568) $) 19)) (-4022 (((-1108) $) NIL)) (-3226 (($) 16)) (-1813 (($ (-568)) 23)) (-2745 (((-850) $) 29)) (-1662 (($) 17)) (-1717 (((-121) $ $) 13)) (-1767 (($ $ $) 11)) (* (($ (-917) $) 21) (($ (-215) $) 8))) 
-(((-158) (-13 (-25) (-10 -8 (-15 * ($ (-917) $)) (-15 * ($ (-215) $)) (-15 -1767 ($ $ $)) (-15 -3476 ($)) (-15 -3871 ($)) (-15 -3226 ($)) (-15 -1662 ($)) (-15 -1819 ((-568) $)) (-15 -3067 ((-917))) (-15 -1813 ($ (-568)))))) (T -158)) 
-((-1767 (*1 *1 *1 *1) (-5 *1 (-158))) (* (*1 *1 *2 *1) (-12 (-5 *2 (-917)) (-5 *1 (-158)))) (* (*1 *1 *2 *1) (-12 (-5 *2 (-215)) (-5 *1 (-158)))) (-3476 (*1 *1) (-5 *1 (-158))) (-3871 (*1 *1) (-5 *1 (-158))) (-3226 (*1 *1) (-5 *1 (-158))) (-1662 (*1 *1) (-5 *1 (-158))) (-1819 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-158)))) (-3067 (*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-158)))) (-1813 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-158))))) 
-(-13 (-25) (-10 -8 (-15 * ($ (-917) $)) (-15 * ($ (-215) $)) (-15 -1767 ($ $ $)) (-15 -3476 ($)) (-15 -3871 ($)) (-15 -3226 ($)) (-15 -1662 ($)) (-15 -1819 ((-568) $)) (-15 -3067 ((-917))) (-15 -1813 ($ (-568))))) 
-((-4452 ((|#2| |#2| (-1082 |#2|)) 87) ((|#2| |#2| (-1161)) 67)) (-3272 ((|#2| |#2| (-1082 |#2|)) 86) ((|#2| |#2| (-1161)) 66)) (-2413 ((|#2| |#2| |#2|) 27)) (-3488 (((-123) (-123)) 97)) (-3270 ((|#2| (-634 |#2|)) 116)) (-3558 ((|#2| (-634 |#2|)) 134)) (-3543 ((|#2| (-634 |#2|)) 124)) (-1671 ((|#2| |#2|) 122)) (-3060 ((|#2| (-634 |#2|)) 109)) (-4179 ((|#2| (-634 |#2|)) 110)) (-3130 ((|#2| (-634 |#2|)) 132)) (-2784 ((|#2| |#2| (-1161)) 54) ((|#2| |#2|) 53)) (-2427 ((|#2| |#2|) 23)) (-2787 ((|#2| |#2| |#2|) 26)) (-2887 (((-121) (-123)) 47)) (** ((|#2| |#2| |#2|) 38))) 
-(((-159 |#1| |#2|) (-10 -7 (-15 -2887 ((-121) (-123))) (-15 -3488 ((-123) (-123))) (-15 ** (|#2| |#2| |#2|)) (-15 -2787 (|#2| |#2| |#2|)) (-15 -2413 (|#2| |#2| |#2|)) (-15 -2427 (|#2| |#2|)) (-15 -2784 (|#2| |#2|)) (-15 -2784 (|#2| |#2| (-1161))) (-15 -4452 (|#2| |#2| (-1161))) (-15 -4452 (|#2| |#2| (-1082 |#2|))) (-15 -3272 (|#2| |#2| (-1161))) (-15 -3272 (|#2| |#2| (-1082 |#2|))) (-15 -1671 (|#2| |#2|)) (-15 -3130 (|#2| (-634 |#2|))) (-15 -3543 (|#2| (-634 |#2|))) (-15 -3558 (|#2| (-634 |#2|))) (-15 -3060 (|#2| (-634 |#2|))) (-15 -4179 (|#2| (-634 |#2|))) (-15 -3270 (|#2| (-634 |#2|)))) (-13 (-842) (-558)) (-432 |#1|)) (T -159)) 
-((-3270 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-4179 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-3060 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-3558 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-3543 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-3130 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-1671 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *2)) (-4 *2 (-432 *3)))) (-3272 (*1 *2 *2 *3) (-12 (-5 *3 (-1082 *2)) (-4 *2 (-432 *4)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-159 *4 *2)))) (-3272 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-159 *4 *2)) (-4 *2 (-432 *4)))) (-4452 (*1 *2 *2 *3) (-12 (-5 *3 (-1082 *2)) (-4 *2 (-432 *4)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-159 *4 *2)))) (-4452 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-159 *4 *2)) (-4 *2 (-432 *4)))) (-2784 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-159 *4 *2)) (-4 *2 (-432 *4)))) (-2784 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *2)) (-4 *2 (-432 *3)))) (-2427 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *2)) (-4 *2 (-432 *3)))) (-2413 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *2)) (-4 *2 (-432 *3)))) (-2787 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *2)) (-4 *2 (-432 *3)))) (** (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *2)) (-4 *2 (-432 *3)))) (-3488 (*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *4)) (-4 *4 (-432 *3)))) (-2887 (*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-159 *4 *5)) (-4 *5 (-432 *4))))) 
-(-10 -7 (-15 -2887 ((-121) (-123))) (-15 -3488 ((-123) (-123))) (-15 ** (|#2| |#2| |#2|)) (-15 -2787 (|#2| |#2| |#2|)) (-15 -2413 (|#2| |#2| |#2|)) (-15 -2427 (|#2| |#2|)) (-15 -2784 (|#2| |#2|)) (-15 -2784 (|#2| |#2| (-1161))) (-15 -4452 (|#2| |#2| (-1161))) (-15 -4452 (|#2| |#2| (-1082 |#2|))) (-15 -3272 (|#2| |#2| (-1161))) (-15 -3272 (|#2| |#2| (-1082 |#2|))) (-15 -1671 (|#2| |#2|)) (-15 -3130 (|#2| (-634 |#2|))) (-15 -3543 (|#2| (-634 |#2|))) (-15 -3558 (|#2| (-634 |#2|))) (-15 -3060 (|#2| (-634 |#2|))) (-15 -4179 (|#2| (-634 |#2|))) (-15 -3270 (|#2| (-634 |#2|)))) 
-((-2077 ((|#1| |#1| |#1|) 52)) (-2691 ((|#1| |#1| |#1|) 49)) (-2413 ((|#1| |#1| |#1|) 43)) (-4473 ((|#1| |#1|) 34)) (-2021 ((|#1| |#1| (-634 |#1|)) 42)) (-2427 ((|#1| |#1|) 36)) (-2787 ((|#1| |#1| |#1|) 39))) 
-(((-160 |#1|) (-10 -7 (-15 -2787 (|#1| |#1| |#1|)) (-15 -2427 (|#1| |#1|)) (-15 -2021 (|#1| |#1| (-634 |#1|))) (-15 -4473 (|#1| |#1|)) (-15 -2413 (|#1| |#1| |#1|)) (-15 -2691 (|#1| |#1| |#1|)) (-15 -2077 (|#1| |#1| |#1|))) (-550)) (T -160)) 
-((-2077 (*1 *2 *2 *2) (-12 (-5 *1 (-160 *2)) (-4 *2 (-550)))) (-2691 (*1 *2 *2 *2) (-12 (-5 *1 (-160 *2)) (-4 *2 (-550)))) (-2413 (*1 *2 *2 *2) (-12 (-5 *1 (-160 *2)) (-4 *2 (-550)))) (-4473 (*1 *2 *2) (-12 (-5 *1 (-160 *2)) (-4 *2 (-550)))) (-2021 (*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-550)) (-5 *1 (-160 *2)))) (-2427 (*1 *2 *2) (-12 (-5 *1 (-160 *2)) (-4 *2 (-550)))) (-2787 (*1 *2 *2 *2) (-12 (-5 *1 (-160 *2)) (-4 *2 (-550))))) 
-(-10 -7 (-15 -2787 (|#1| |#1| |#1|)) (-15 -2427 (|#1| |#1|)) (-15 -2021 (|#1| |#1| (-634 |#1|))) (-15 -4473 (|#1| |#1|)) (-15 -2413 (|#1| |#1| |#1|)) (-15 -2691 (|#1| |#1| |#1|)) (-15 -2077 (|#1| |#1| |#1|))) 
-((-4452 (($ $ (-1161)) 12) (($ $ (-1082 $)) 11)) (-3272 (($ $ (-1161)) 10) (($ $ (-1082 $)) 9)) (-2413 (($ $ $) 8)) (-2784 (($ $) 14) (($ $ (-1161)) 13)) (-2427 (($ $) 7)) (-2787 (($ $ $) 6))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-2902 (((-3 $ "failed") $) 85)) (-1598 (((-121) $) NIL)) (-2049 (($ |#2| (-634 (-917))) 56)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2840 (($ (-917)) 48)) (-3108 (((-139)) 23)) (-2747 (((-850) $) 68) (($ (-568)) 46) (($ |#2|) 47)) (-2079 ((|#2| $ (-634 (-917))) 58)) (-3425 (((-763)) 20)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 40 T CONST)) (-1557 (($) 44 T CONST)) (-1719 (((-121) $ $) 26)) (-1781 (($ $ |#2|) NIL)) (-1775 (($ $) 34) (($ $ $) 32)) (-1769 (($ $ $) 30)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 37) (($ $ $) 52) (($ |#2| $) 39) (($ $ |#2|) NIL))) 
+(((-155 |#1| |#2| |#3|) (-13 (-1047) (-43 |#2|) (-1251 |#2|) (-10 -8 (-15 -2840 ($ (-917))) (-15 -2049 ($ |#2| (-634 (-917)))) (-15 -2079 (|#2| $ (-634 (-917)))) (-15 -2902 ((-3 $ "failed") $)))) (-917) (-365) (-994 |#1| |#2|)) (T -155)) 
+((-2902 (*1 *1 *1) (|partial| -12 (-5 *1 (-155 *2 *3 *4)) (-14 *2 (-917)) (-4 *3 (-365)) (-14 *4 (-994 *2 *3)))) (-2840 (*1 *1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-155 *3 *4 *5)) (-14 *3 *2) (-4 *4 (-365)) (-14 *5 (-994 *3 *4)))) (-2049 (*1 *1 *2 *3) (-12 (-5 *3 (-634 (-917))) (-5 *1 (-155 *4 *2 *5)) (-14 *4 (-917)) (-4 *2 (-365)) (-14 *5 (-994 *4 *2)))) (-2079 (*1 *2 *1 *3) (-12 (-5 *3 (-634 (-917))) (-4 *2 (-365)) (-5 *1 (-155 *4 *2 *5)) (-14 *4 (-917)) (-14 *5 (-994 *4 *2))))) 
+(-13 (-1047) (-43 |#2|) (-1251 |#2|) (-10 -8 (-15 -2840 ($ (-917))) (-15 -2049 ($ |#2| (-634 (-917)))) (-15 -2079 (|#2| $ (-634 (-917)))) (-15 -2902 ((-3 $ "failed") $)))) 
+((-1422 (((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-634 (-634 (-944 (-215)))) (-215) (-215) (-215) (-215)) 38)) (-3240 (((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927) (-409 (-568)) (-409 (-568))) 62) (((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927)) 63)) (-1743 (((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-634 (-634 (-944 (-215))))) 66) (((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-634 (-944 (-215)))) 65) (((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927) (-409 (-568)) (-409 (-568))) 57) (((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927)) 58))) 
+(((-156) (-10 -7 (-15 -1743 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927))) (-15 -1743 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927) (-409 (-568)) (-409 (-568)))) (-15 -3240 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927))) (-15 -3240 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927) (-409 (-568)) (-409 (-568)))) (-15 -1422 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-634 (-634 (-944 (-215)))) (-215) (-215) (-215) (-215))) (-15 -1743 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-634 (-944 (-215))))) (-15 -1743 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-634 (-634 (-944 (-215)))))))) (T -156)) 
+((-1743 (*1 *2 *3) (-12 (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156)) (-5 *3 (-634 (-634 (-944 (-215))))))) (-1743 (*1 *2 *3) (-12 (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156)) (-5 *3 (-634 (-944 (-215)))))) (-1422 (*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *4 (-215)) (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 *4)))) (|:| |xValues| (-1084 *4)) (|:| |yValues| (-1084 *4)))) (-5 *1 (-156)) (-5 *3 (-634 (-634 (-944 *4)))))) (-3240 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-927)) (-5 *4 (-409 (-568))) (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156)))) (-3240 (*1 *2 *3) (-12 (-5 *3 (-927)) (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156)))) (-1743 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-927)) (-5 *4 (-409 (-568))) (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156)))) (-1743 (*1 *2 *3) (-12 (-5 *3 (-927)) (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156))))) 
+(-10 -7 (-15 -1743 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927))) (-15 -1743 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927) (-409 (-568)) (-409 (-568)))) (-15 -3240 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927))) (-15 -3240 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-927) (-409 (-568)) (-409 (-568)))) (-15 -1422 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-634 (-634 (-944 (-215)))) (-215) (-215) (-215) (-215))) (-15 -1743 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-634 (-944 (-215))))) (-15 -1743 ((-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215)))) (-634 (-634 (-944 (-215))))))) 
+((-2201 (((-634 (-169 |#2|)) |#1| |#2|) 45))) 
+(((-157 |#1| |#2|) (-10 -7 (-15 -2201 ((-634 (-169 |#2|)) |#1| |#2|))) (-1219 (-169 (-568))) (-13 (-365) (-840))) (T -157)) 
+((-2201 (*1 *2 *3 *4) (-12 (-5 *2 (-634 (-169 *4))) (-5 *1 (-157 *3 *4)) (-4 *3 (-1219 (-169 (-568)))) (-4 *4 (-13 (-365) (-840)))))) 
+(-10 -7 (-15 -2201 ((-634 (-169 |#2|)) |#1| |#2|))) 
+((-2449 (((-121) $ $) NIL)) (-1967 (($) 15)) (-3751 (($) 14)) (-2342 (((-917)) 22)) (-1893 (((-1143) $) NIL)) (-2233 (((-568) $) 19)) (-4025 (((-1108) $) NIL)) (-1914 (($) 16)) (-2200 (($ (-568)) 23)) (-2747 (((-850) $) 29)) (-3395 (($) 17)) (-1719 (((-121) $ $) 13)) (-1769 (($ $ $) 11)) (* (($ (-917) $) 21) (($ (-215) $) 8))) 
+(((-158) (-13 (-25) (-10 -8 (-15 * ($ (-917) $)) (-15 * ($ (-215) $)) (-15 -1769 ($ $ $)) (-15 -3751 ($)) (-15 -1967 ($)) (-15 -1914 ($)) (-15 -3395 ($)) (-15 -2233 ((-568) $)) (-15 -2342 ((-917))) (-15 -2200 ($ (-568)))))) (T -158)) 
+((-1769 (*1 *1 *1 *1) (-5 *1 (-158))) (* (*1 *1 *2 *1) (-12 (-5 *2 (-917)) (-5 *1 (-158)))) (* (*1 *1 *2 *1) (-12 (-5 *2 (-215)) (-5 *1 (-158)))) (-3751 (*1 *1) (-5 *1 (-158))) (-1967 (*1 *1) (-5 *1 (-158))) (-1914 (*1 *1) (-5 *1 (-158))) (-3395 (*1 *1) (-5 *1 (-158))) (-2233 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-158)))) (-2342 (*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-158)))) (-2200 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-158))))) 
+(-13 (-25) (-10 -8 (-15 * ($ (-917) $)) (-15 * ($ (-215) $)) (-15 -1769 ($ $ $)) (-15 -3751 ($)) (-15 -1967 ($)) (-15 -1914 ($)) (-15 -3395 ($)) (-15 -2233 ((-568) $)) (-15 -2342 ((-917))) (-15 -2200 ($ (-568))))) 
+((-1715 ((|#2| |#2| (-1082 |#2|)) 87) ((|#2| |#2| (-1161)) 67)) (-2062 ((|#2| |#2| (-1082 |#2|)) 86) ((|#2| |#2| (-1161)) 66)) (-2341 ((|#2| |#2| |#2|) 27)) (-3842 (((-123) (-123)) 97)) (-2055 ((|#2| (-634 |#2|)) 116)) (-2842 ((|#2| (-634 |#2|)) 134)) (-4214 ((|#2| (-634 |#2|)) 124)) (-3453 ((|#2| |#2|) 122)) (-2306 ((|#2| (-634 |#2|)) 109)) (-3980 ((|#2| (-634 |#2|)) 110)) (-2665 ((|#2| (-634 |#2|)) 132)) (-3577 ((|#2| |#2| (-1161)) 54) ((|#2| |#2|) 53)) (-2406 ((|#2| |#2|) 23)) (-3584 ((|#2| |#2| |#2|) 26)) (-2779 (((-121) (-123)) 47)) (** ((|#2| |#2| |#2|) 38))) 
+(((-159 |#1| |#2|) (-10 -7 (-15 -2779 ((-121) (-123))) (-15 -3842 ((-123) (-123))) (-15 ** (|#2| |#2| |#2|)) (-15 -3584 (|#2| |#2| |#2|)) (-15 -2341 (|#2| |#2| |#2|)) (-15 -2406 (|#2| |#2|)) (-15 -3577 (|#2| |#2|)) (-15 -3577 (|#2| |#2| (-1161))) (-15 -1715 (|#2| |#2| (-1161))) (-15 -1715 (|#2| |#2| (-1082 |#2|))) (-15 -2062 (|#2| |#2| (-1161))) (-15 -2062 (|#2| |#2| (-1082 |#2|))) (-15 -3453 (|#2| |#2|)) (-15 -2665 (|#2| (-634 |#2|))) (-15 -4214 (|#2| (-634 |#2|))) (-15 -2842 (|#2| (-634 |#2|))) (-15 -2306 (|#2| (-634 |#2|))) (-15 -3980 (|#2| (-634 |#2|))) (-15 -2055 (|#2| (-634 |#2|)))) (-13 (-842) (-558)) (-432 |#1|)) (T -159)) 
+((-2055 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-3980 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-2306 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-2842 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-4214 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-2665 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-3453 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *2)) (-4 *2 (-432 *3)))) (-2062 (*1 *2 *2 *3) (-12 (-5 *3 (-1082 *2)) (-4 *2 (-432 *4)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-159 *4 *2)))) (-2062 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-159 *4 *2)) (-4 *2 (-432 *4)))) (-1715 (*1 *2 *2 *3) (-12 (-5 *3 (-1082 *2)) (-4 *2 (-432 *4)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-159 *4 *2)))) (-1715 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-159 *4 *2)) (-4 *2 (-432 *4)))) (-3577 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-159 *4 *2)) (-4 *2 (-432 *4)))) (-3577 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *2)) (-4 *2 (-432 *3)))) (-2406 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *2)) (-4 *2 (-432 *3)))) (-2341 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *2)) (-4 *2 (-432 *3)))) (-3584 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *2)) (-4 *2 (-432 *3)))) (** (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *2)) (-4 *2 (-432 *3)))) (-3842 (*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *4)) (-4 *4 (-432 *3)))) (-2779 (*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-159 *4 *5)) (-4 *5 (-432 *4))))) 
+(-10 -7 (-15 -2779 ((-121) (-123))) (-15 -3842 ((-123) (-123))) (-15 ** (|#2| |#2| |#2|)) (-15 -3584 (|#2| |#2| |#2|)) (-15 -2341 (|#2| |#2| |#2|)) (-15 -2406 (|#2| |#2|)) (-15 -3577 (|#2| |#2|)) (-15 -3577 (|#2| |#2| (-1161))) (-15 -1715 (|#2| |#2| (-1161))) (-15 -1715 (|#2| |#2| (-1082 |#2|))) (-15 -2062 (|#2| |#2| (-1161))) (-15 -2062 (|#2| |#2| (-1082 |#2|))) (-15 -3453 (|#2| |#2|)) (-15 -2665 (|#2| (-634 |#2|))) (-15 -4214 (|#2| (-634 |#2|))) (-15 -2842 (|#2| (-634 |#2|))) (-15 -2306 (|#2| (-634 |#2|))) (-15 -3980 (|#2| (-634 |#2|))) (-15 -2055 (|#2| (-634 |#2|)))) 
+((-3103 ((|#1| |#1| |#1|) 52)) (-1362 ((|#1| |#1| |#1|) 49)) (-2341 ((|#1| |#1| |#1|) 43)) (-1829 ((|#1| |#1|) 34)) (-1360 ((|#1| |#1| (-634 |#1|)) 42)) (-2406 ((|#1| |#1|) 36)) (-3584 ((|#1| |#1| |#1|) 39))) 
+(((-160 |#1|) (-10 -7 (-15 -3584 (|#1| |#1| |#1|)) (-15 -2406 (|#1| |#1|)) (-15 -1360 (|#1| |#1| (-634 |#1|))) (-15 -1829 (|#1| |#1|)) (-15 -2341 (|#1| |#1| |#1|)) (-15 -1362 (|#1| |#1| |#1|)) (-15 -3103 (|#1| |#1| |#1|))) (-550)) (T -160)) 
+((-3103 (*1 *2 *2 *2) (-12 (-5 *1 (-160 *2)) (-4 *2 (-550)))) (-1362 (*1 *2 *2 *2) (-12 (-5 *1 (-160 *2)) (-4 *2 (-550)))) (-2341 (*1 *2 *2 *2) (-12 (-5 *1 (-160 *2)) (-4 *2 (-550)))) (-1829 (*1 *2 *2) (-12 (-5 *1 (-160 *2)) (-4 *2 (-550)))) (-1360 (*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-550)) (-5 *1 (-160 *2)))) (-2406 (*1 *2 *2) (-12 (-5 *1 (-160 *2)) (-4 *2 (-550)))) (-3584 (*1 *2 *2 *2) (-12 (-5 *1 (-160 *2)) (-4 *2 (-550))))) 
+(-10 -7 (-15 -3584 (|#1| |#1| |#1|)) (-15 -2406 (|#1| |#1|)) (-15 -1360 (|#1| |#1| (-634 |#1|))) (-15 -1829 (|#1| |#1|)) (-15 -2341 (|#1| |#1| |#1|)) (-15 -1362 (|#1| |#1| |#1|)) (-15 -3103 (|#1| |#1| |#1|))) 
+((-1715 (($ $ (-1161)) 12) (($ $ (-1082 $)) 11)) (-2062 (($ $ (-1161)) 10) (($ $ (-1082 $)) 9)) (-2341 (($ $ $) 8)) (-3577 (($ $) 14) (($ $ (-1161)) 13)) (-2406 (($ $) 7)) (-3584 (($ $ $) 6))) 
 (((-161) (-1275)) (T -161)) 
-((-2784 (*1 *1 *1) (-4 *1 (-161))) (-2784 (*1 *1 *1 *2) (-12 (-4 *1 (-161)) (-5 *2 (-1161)))) (-4452 (*1 *1 *1 *2) (-12 (-4 *1 (-161)) (-5 *2 (-1161)))) (-4452 (*1 *1 *1 *2) (-12 (-5 *2 (-1082 *1)) (-4 *1 (-161)))) (-3272 (*1 *1 *1 *2) (-12 (-4 *1 (-161)) (-5 *2 (-1161)))) (-3272 (*1 *1 *1 *2) (-12 (-5 *2 (-1082 *1)) (-4 *1 (-161))))) 
-(-13 (-146) (-10 -8 (-15 -2784 ($ $)) (-15 -2784 ($ $ (-1161))) (-15 -4452 ($ $ (-1161))) (-15 -4452 ($ $ (-1082 $))) (-15 -3272 ($ $ (-1161))) (-15 -3272 ($ $ (-1082 $))))) 
+((-3577 (*1 *1 *1) (-4 *1 (-161))) (-3577 (*1 *1 *1 *2) (-12 (-4 *1 (-161)) (-5 *2 (-1161)))) (-1715 (*1 *1 *1 *2) (-12 (-4 *1 (-161)) (-5 *2 (-1161)))) (-1715 (*1 *1 *1 *2) (-12 (-5 *2 (-1082 *1)) (-4 *1 (-161)))) (-2062 (*1 *1 *1 *2) (-12 (-4 *1 (-161)) (-5 *2 (-1161)))) (-2062 (*1 *1 *1 *2) (-12 (-5 *2 (-1082 *1)) (-4 *1 (-161))))) 
+(-13 (-146) (-10 -8 (-15 -3577 ($ $)) (-15 -3577 ($ $ (-1161))) (-15 -1715 ($ $ (-1161))) (-15 -1715 ($ $ (-1082 $))) (-15 -2062 ($ $ (-1161))) (-15 -2062 ($ $ (-1082 $))))) 
 (((-146) . T)) 
-((-2447 (((-121) $ $) NIL)) (-3000 (($ (-568)) 13) (($ $ $) 14)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 17)) (-1717 (((-121) $ $) 9))) 
-(((-162) (-13 (-1090) (-10 -8 (-15 -3000 ($ (-568))) (-15 -3000 ($ $ $))))) (T -162)) 
-((-3000 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-162)))) (-3000 (*1 *1 *1 *1) (-5 *1 (-162)))) 
-(-13 (-1090) (-10 -8 (-15 -3000 ($ (-568))) (-15 -3000 ($ $ $)))) 
-((-3488 (((-123) (-1161)) 97))) 
-(((-163) (-10 -7 (-15 -3488 ((-123) (-1161))))) (T -163)) 
-((-3488 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-123)) (-5 *1 (-163))))) 
-(-10 -7 (-15 -3488 ((-123) (-1161)))) 
-((-2589 ((|#3| |#3|) 19))) 
-(((-164 |#1| |#2| |#3|) (-10 -7 (-15 -2589 (|#3| |#3|))) (-1047) (-1219 |#1|) (-1219 |#2|)) (T -164)) 
-((-2589 (*1 *2 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-1219 *3)) (-5 *1 (-164 *3 *4 *2)) (-4 *2 (-1219 *4))))) 
-(-10 -7 (-15 -2589 (|#3| |#3|))) 
-((-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 215)) (-1932 ((|#2| $) 95)) (-1982 (($ $) 242)) (-1933 (($ $) 236)) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 39)) (-1974 (($ $) 240)) (-2786 (($ $) 234)) (-3666 (((-3 (-568) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 |#2| "failed") $) 139)) (-2854 (((-568) $) NIL) (((-409 (-568)) $) NIL) ((|#2| $) 137)) (-2401 (($ $ $) 220)) (-3164 (((-679 (-568)) (-679 $)) NIL) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) 153) (((-679 |#2|) (-679 $)) 147)) (-3092 (($ (-1157 |#2|)) 118) (((-3 $ "failed") (-409 (-1157 |#2|))) NIL)) (-2925 (((-3 $ "failed") $) 207)) (-1642 (((-3 (-409 (-568)) "failed") $) 197)) (-2688 (((-121) $) 192)) (-2425 (((-409 (-568)) $) 195)) (-3700 (((-917)) 88)) (-2412 (($ $ $) 222)) (-3378 (((-2 (|:| |r| |#2|) (|:| |phi| |#2|)) $) 258)) (-1897 (($) 231)) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 184) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 189)) (-2657 ((|#2| $) 93)) (-2045 (((-1157 |#2|) $) 120)) (-2795 (($ (-1 |#2| |#2|) $) 101)) (-4416 (($ $) 233)) (-3085 (((-1157 |#2|) $) 119)) (-2081 (($ $) 200)) (-3777 (($) 96)) (-2905 (((-420 (-1157 $)) (-1157 $)) 87)) (-3545 (((-420 (-1157 $)) (-1157 $)) 56)) (-2595 (((-3 $ "failed") $ |#2|) 202) (((-3 $ "failed") $ $) 205)) (-1892 (($ $) 232)) (-2709 (((-763) $) 217)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 226)) (-2217 ((|#2| (-1244 $)) NIL) ((|#2|) 90)) (-4189 (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) 112) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) NIL) (($ $ (-763)) NIL) (($ $) NIL)) (-1626 (((-1157 |#2|)) 113)) (-1978 (($ $) 241)) (-2790 (($ $) 235)) (-4073 (((-1244 |#2|) $ (-1244 $)) 126) (((-679 |#2|) (-1244 $) (-1244 $)) NIL) (((-1244 |#2|) $) 109) (((-679 |#2|) (-1244 $)) NIL)) (-4278 (((-1244 |#2|) $) NIL) (($ (-1244 |#2|)) NIL) (((-1157 |#2|) $) NIL) (($ (-1157 |#2|)) NIL) (((-887 (-568)) $) 175) (((-887 (-381)) $) 179) (((-169 (-381)) $) 165) (((-169 (-215)) $) 160) (((-541) $) 171)) (-1458 (($ $) 97)) (-2745 (((-850) $) 136) (($ (-568)) NIL) (($ |#2|) NIL) (($ (-409 (-568))) NIL) (($ $) NIL)) (-2678 (((-1157 |#2|) $) 23)) (-4078 (((-763)) 99)) (-2006 (($ $) 245)) (-1958 (($ $) 239)) (-1998 (($ $) 243)) (-1949 (($ $) 237)) (-3256 ((|#2| $) 230)) (-2002 (($ $) 244)) (-1953 (($ $) 238)) (-2897 (($ $) 155)) (-1717 (((-121) $ $) 103)) (-1732 (((-121) $ $) 191)) (-1773 (($ $) 105) (($ $ $) NIL)) (-1767 (($ $ $) 104)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-409 (-568))) 264) (($ $ $) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 111) (($ $ $) 140) (($ $ |#2|) NIL) (($ |#2| $) 107) (($ (-409 (-568)) $) NIL) (($ $ (-409 (-568))) NIL))) 
-(((-165 |#1| |#2|) (-10 -8 (-15 -4189 (|#1| |#1|)) (-15 -4189 (|#1| |#1| (-763))) (-15 -2745 (|#1| |#1|)) (-15 -2595 ((-3 |#1| "failed") |#1| |#1|)) (-15 -3712 ((-2 (|:| -2295 |#1|) (|:| -4506 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -4189 (|#1| |#1| (-1161))) (-15 -4189 (|#1| |#1| (-634 (-1161)))) (-15 -4189 (|#1| |#1| (-1161) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -2709 ((-763) |#1|)) (-15 -3210 ((-2 (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1|)) (-15 -2412 (|#1| |#1| |#1|)) (-15 -2401 (|#1| |#1| |#1|)) (-15 -2081 (|#1| |#1|)) (-15 ** (|#1| |#1| (-568))) (-15 * (|#1| |#1| (-409 (-568)))) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -1732 ((-121) |#1| |#1|)) (-15 -4278 ((-541) |#1|)) (-15 -4278 ((-169 (-215)) |#1|)) (-15 -4278 ((-169 (-381)) |#1|)) (-15 -1933 (|#1| |#1|)) (-15 -2786 (|#1| |#1|)) (-15 -2790 (|#1| |#1|)) (-15 -1953 (|#1| |#1|)) (-15 -1949 (|#1| |#1|)) (-15 -1958 (|#1| |#1|)) (-15 -1978 (|#1| |#1|)) (-15 -1974 (|#1| |#1|)) (-15 -1982 (|#1| |#1|)) (-15 -2002 (|#1| |#1|)) (-15 -1998 (|#1| |#1|)) (-15 -2006 (|#1| |#1|)) (-15 -4416 (|#1| |#1|)) (-15 -1892 (|#1| |#1|)) (-15 ** (|#1| |#1| |#1|)) (-15 -1897 (|#1|)) (-15 ** (|#1| |#1| (-409 (-568)))) (-15 -3545 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -2905 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -1858 ((-3 (-634 (-1157 |#1|)) "failed") (-634 (-1157 |#1|)) (-1157 |#1|))) (-15 -1642 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2425 ((-409 (-568)) |#1|)) (-15 -2688 ((-121) |#1|)) (-15 -3378 ((-2 (|:| |r| |#2|) (|:| |phi| |#2|)) |#1|)) (-15 -3256 (|#2| |#1|)) (-15 -2897 (|#1| |#1|)) (-15 -2595 ((-3 |#1| "failed") |#1| |#2|)) (-15 -1458 (|#1| |#1|)) (-15 -3777 (|#1|)) (-15 -4278 ((-887 (-381)) |#1|)) (-15 -4278 ((-887 (-568)) |#1|)) (-15 -4410 ((-884 (-381) |#1|) |#1| (-887 (-381)) (-884 (-381) |#1|))) (-15 -4410 ((-884 (-568) |#1|) |#1| (-887 (-568)) (-884 (-568) |#1|))) (-15 -2795 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -3092 ((-3 |#1| "failed") (-409 (-1157 |#2|)))) (-15 -3085 ((-1157 |#2|) |#1|)) (-15 -4278 (|#1| (-1157 |#2|))) (-15 -3092 (|#1| (-1157 |#2|))) (-15 -1626 ((-1157 |#2|))) (-15 -3164 ((-679 |#2|) (-679 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 |#1|) (-1244 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -3164 ((-679 (-568)) (-679 |#1|))) (-15 -2854 (|#2| |#1|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2854 ((-568) |#1|)) (-15 -4278 ((-1157 |#2|) |#1|)) (-15 -2217 (|#2|)) (-15 -4278 (|#1| (-1244 |#2|))) (-15 -4278 ((-1244 |#2|) |#1|)) (-15 -4073 ((-679 |#2|) (-1244 |#1|))) (-15 -4073 ((-1244 |#2|) |#1|)) (-15 -2045 ((-1157 |#2|) |#1|)) (-15 -2678 ((-1157 |#2|) |#1|)) (-15 -2217 (|#2| (-1244 |#1|))) (-15 -4073 ((-679 |#2|) (-1244 |#1|) (-1244 |#1|))) (-15 -4073 ((-1244 |#2|) |#1| (-1244 |#1|))) (-15 -2657 (|#2| |#1|)) (-15 -1932 (|#2| |#1|)) (-15 -3700 ((-917))) (-15 -2745 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -2745 (|#1| (-568))) (-15 -4078 ((-763))) (-15 ** (|#1| |#1| (-763))) (-15 -2925 ((-3 |#1| "failed") |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| (-917))) (-15 * (|#1| (-568) |#1|)) (-15 -1773 (|#1| |#1| |#1|)) (-15 -1773 (|#1| |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|)) (-15 -1767 (|#1| |#1| |#1|)) (-15 -2745 ((-850) |#1|)) (-15 -1717 ((-121) |#1| |#1|))) (-166 |#2|) (-172)) (T -165)) 
-((-4078 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-763)) (-5 *1 (-165 *3 *4)) (-4 *3 (-166 *4)))) (-3700 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-917)) (-5 *1 (-165 *3 *4)) (-4 *3 (-166 *4)))) (-2217 (*1 *2) (-12 (-4 *2 (-172)) (-5 *1 (-165 *3 *2)) (-4 *3 (-166 *2)))) (-1626 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-1157 *4)) (-5 *1 (-165 *3 *4)) (-4 *3 (-166 *4))))) 
-(-10 -8 (-15 -4189 (|#1| |#1|)) (-15 -4189 (|#1| |#1| (-763))) (-15 -2745 (|#1| |#1|)) (-15 -2595 ((-3 |#1| "failed") |#1| |#1|)) (-15 -3712 ((-2 (|:| -2295 |#1|) (|:| -4506 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -4189 (|#1| |#1| (-1161))) (-15 -4189 (|#1| |#1| (-634 (-1161)))) (-15 -4189 (|#1| |#1| (-1161) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -2709 ((-763) |#1|)) (-15 -3210 ((-2 (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1|)) (-15 -2412 (|#1| |#1| |#1|)) (-15 -2401 (|#1| |#1| |#1|)) (-15 -2081 (|#1| |#1|)) (-15 ** (|#1| |#1| (-568))) (-15 * (|#1| |#1| (-409 (-568)))) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -1732 ((-121) |#1| |#1|)) (-15 -4278 ((-541) |#1|)) (-15 -4278 ((-169 (-215)) |#1|)) (-15 -4278 ((-169 (-381)) |#1|)) (-15 -1933 (|#1| |#1|)) (-15 -2786 (|#1| |#1|)) (-15 -2790 (|#1| |#1|)) (-15 -1953 (|#1| |#1|)) (-15 -1949 (|#1| |#1|)) (-15 -1958 (|#1| |#1|)) (-15 -1978 (|#1| |#1|)) (-15 -1974 (|#1| |#1|)) (-15 -1982 (|#1| |#1|)) (-15 -2002 (|#1| |#1|)) (-15 -1998 (|#1| |#1|)) (-15 -2006 (|#1| |#1|)) (-15 -4416 (|#1| |#1|)) (-15 -1892 (|#1| |#1|)) (-15 ** (|#1| |#1| |#1|)) (-15 -1897 (|#1|)) (-15 ** (|#1| |#1| (-409 (-568)))) (-15 -3545 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -2905 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -1858 ((-3 (-634 (-1157 |#1|)) "failed") (-634 (-1157 |#1|)) (-1157 |#1|))) (-15 -1642 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2425 ((-409 (-568)) |#1|)) (-15 -2688 ((-121) |#1|)) (-15 -3378 ((-2 (|:| |r| |#2|) (|:| |phi| |#2|)) |#1|)) (-15 -3256 (|#2| |#1|)) (-15 -2897 (|#1| |#1|)) (-15 -2595 ((-3 |#1| "failed") |#1| |#2|)) (-15 -1458 (|#1| |#1|)) (-15 -3777 (|#1|)) (-15 -4278 ((-887 (-381)) |#1|)) (-15 -4278 ((-887 (-568)) |#1|)) (-15 -4410 ((-884 (-381) |#1|) |#1| (-887 (-381)) (-884 (-381) |#1|))) (-15 -4410 ((-884 (-568) |#1|) |#1| (-887 (-568)) (-884 (-568) |#1|))) (-15 -2795 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -3092 ((-3 |#1| "failed") (-409 (-1157 |#2|)))) (-15 -3085 ((-1157 |#2|) |#1|)) (-15 -4278 (|#1| (-1157 |#2|))) (-15 -3092 (|#1| (-1157 |#2|))) (-15 -1626 ((-1157 |#2|))) (-15 -3164 ((-679 |#2|) (-679 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 |#1|) (-1244 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -3164 ((-679 (-568)) (-679 |#1|))) (-15 -2854 (|#2| |#1|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2854 ((-568) |#1|)) (-15 -4278 ((-1157 |#2|) |#1|)) (-15 -2217 (|#2|)) (-15 -4278 (|#1| (-1244 |#2|))) (-15 -4278 ((-1244 |#2|) |#1|)) (-15 -4073 ((-679 |#2|) (-1244 |#1|))) (-15 -4073 ((-1244 |#2|) |#1|)) (-15 -2045 ((-1157 |#2|) |#1|)) (-15 -2678 ((-1157 |#2|) |#1|)) (-15 -2217 (|#2| (-1244 |#1|))) (-15 -4073 ((-679 |#2|) (-1244 |#1|) (-1244 |#1|))) (-15 -4073 ((-1244 |#2|) |#1| (-1244 |#1|))) (-15 -2657 (|#2| |#1|)) (-15 -1932 (|#2| |#1|)) (-15 -3700 ((-917))) (-15 -2745 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -2745 (|#1| (-568))) (-15 -4078 ((-763))) (-15 ** (|#1| |#1| (-763))) (-15 -2925 ((-3 |#1| "failed") |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| (-917))) (-15 * (|#1| (-568) |#1|)) (-15 -1773 (|#1| |#1| |#1|)) (-15 -1773 (|#1| |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|)) (-15 -1767 (|#1| |#1| |#1|)) (-15 -2745 ((-850) |#1|)) (-15 -1717 ((-121) |#1| |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 87 (-2198 (|has| |#1| (-558)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))))) (-2227 (($ $) 88 (-2198 (|has| |#1| (-558)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))))) (-1573 (((-121) $) 90 (-2198 (|has| |#1| (-558)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))))) (-4255 (((-679 |#1|) (-1244 $)) 44) (((-679 |#1|)) 55)) (-1932 ((|#1| $) 50)) (-1982 (($ $) 212 (|has| |#1| (-1181)))) (-1933 (($ $) 195 (|has| |#1| (-1181)))) (-3211 (((-1169 (-917) (-763)) (-568)) 141 (|has| |#1| (-350)))) (-3134 (((-3 $ "failed") $ $) 18)) (-1750 (((-420 (-1157 $)) (-1157 $)) 226 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))))) (-4305 (($ $) 107 (-2198 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-365))))) (-1678 (((-420 $) $) 108 (-2198 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-365))))) (-1902 (($ $) 225 (-12 (|has| |#1| (-1002)) (|has| |#1| (-1181))))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 229 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))))) (-1497 (((-121) $ $) 98 (|has| |#1| (-301)))) (-3983 (((-763)) 81 (|has| |#1| (-370)))) (-1974 (($ $) 211 (|has| |#1| (-1181)))) (-2786 (($ $) 196 (|has| |#1| (-1181)))) (-1990 (($ $) 210 (|has| |#1| (-1181)))) (-1941 (($ $) 197 (|has| |#1| (-1181)))) (-2671 (($) 16 T CONST)) (-3666 (((-3 (-568) "failed") $) 163 (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) 161 (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 160)) (-2854 (((-568) $) 164 (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) 162 (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) 159)) (-3498 (($ (-1244 |#1|) (-1244 $)) 46) (($ (-1244 |#1|)) 58)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) 147 (|has| |#1| (-350)))) (-2401 (($ $ $) 102 (|has| |#1| (-301)))) (-1709 (((-679 |#1|) $ (-1244 $)) 51) (((-679 |#1|) $) 53)) (-3164 (((-679 (-568)) (-679 $)) 158 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 157 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 156) (((-679 |#1|) (-679 $)) 155)) (-3092 (($ (-1157 |#1|)) 152) (((-3 $ "failed") (-409 (-1157 |#1|))) 149 (|has| |#1| (-365)))) (-2925 (((-3 $ "failed") $) 33)) (-3857 ((|#1| $) 237)) (-1642 (((-3 (-409 (-568)) "failed") $) 230 (|has| |#1| (-550)))) (-2688 (((-121) $) 232 (|has| |#1| (-550)))) (-2425 (((-409 (-568)) $) 231 (|has| |#1| (-550)))) (-3700 (((-917)) 52)) (-1731 (($) 84 (|has| |#1| (-370)))) (-2412 (($ $ $) 101 (|has| |#1| (-301)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 96 (|has| |#1| (-301)))) (-4220 (($) 143 (|has| |#1| (-350)))) (-4456 (((-121) $) 144 (|has| |#1| (-350)))) (-3218 (($ $ (-763)) 135 (|has| |#1| (-350))) (($ $) 134 (|has| |#1| (-350)))) (-3927 (((-121) $) 109 (-2198 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-365))))) (-3378 (((-2 (|:| |r| |#1|) (|:| |phi| |#1|)) $) 233 (-12 (|has| |#1| (-1056)) (|has| |#1| (-1181))))) (-1897 (($) 222 (|has| |#1| (-1181)))) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 245 (|has| |#1| (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 244 (|has| |#1| (-881 (-381))))) (-4477 (((-917) $) 146 (|has| |#1| (-350))) (((-828 (-917)) $) 132 (|has| |#1| (-350)))) (-2735 (((-121) $) 30)) (-4044 (($ $ (-568)) 224 (-12 (|has| |#1| (-1002)) (|has| |#1| (-1181))))) (-2657 ((|#1| $) 49)) (-3038 (((-3 $ "failed") $) 136 (|has| |#1| (-350)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 105 (|has| |#1| (-301)))) (-2045 (((-1157 |#1|) $) 42 (|has| |#1| (-365)))) (-2521 (($ $ $) 191 (|has| |#1| (-842)))) (-3268 (($ $ $) 190 (|has| |#1| (-842)))) (-2795 (($ (-1 |#1| |#1|) $) 246)) (-3683 (((-917) $) 83 (|has| |#1| (-370)))) (-4416 (($ $) 219 (|has| |#1| (-1181)))) (-3085 (((-1157 |#1|) $) 150)) (-2495 (($ (-634 $)) 94 (-2198 (|has| |#1| (-301)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904))))) (($ $ $) 93 (-2198 (|has| |#1| (-301)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))))) (-4487 (((-1143) $) 9)) (-2081 (($ $) 110 (|has| |#1| (-365)))) (-4434 (($) 137 (|has| |#1| (-350)) CONST)) (-4355 (($ (-917)) 82 (|has| |#1| (-370)))) (-3777 (($) 241)) (-3866 ((|#1| $) 238)) (-4022 (((-1108) $) 10)) (-2704 (($) 154)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 95 (-2198 (|has| |#1| (-301)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))))) (-2721 (($ (-634 $)) 92 (-2198 (|has| |#1| (-301)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904))))) (($ $ $) 91 (-2198 (|has| |#1| (-301)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))))) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) 140 (|has| |#1| (-350)))) (-2905 (((-420 (-1157 $)) (-1157 $)) 228 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))))) (-3545 (((-420 (-1157 $)) (-1157 $)) 227 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))))) (-3848 (((-420 $) $) 106 (-2198 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-365))))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 104 (|has| |#1| (-301))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 103 (|has| |#1| (-301)))) (-2595 (((-3 $ "failed") $ |#1|) 236 (|has| |#1| (-558))) (((-3 $ "failed") $ $) 86 (-2198 (|has| |#1| (-558)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 97 (|has| |#1| (-301)))) (-1892 (($ $) 220 (|has| |#1| (-1181)))) (-1339 (($ $ (-634 |#1|) (-634 |#1|)) 252 (|has| |#1| (-303 |#1|))) (($ $ |#1| |#1|) 251 (|has| |#1| (-303 |#1|))) (($ $ (-288 |#1|)) 250 (|has| |#1| (-303 |#1|))) (($ $ (-634 (-288 |#1|))) 249 (|has| |#1| (-303 |#1|))) (($ $ (-634 (-1161)) (-634 |#1|)) 248 (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-1161) |#1|) 247 (|has| |#1| (-523 (-1161) |#1|)))) (-2709 (((-763) $) 99 (|has| |#1| (-301)))) (-2779 (($ $ |#1|) 253 (|has| |#1| (-281 |#1| |#1|)))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 100 (|has| |#1| (-301)))) (-2217 ((|#1| (-1244 $)) 45) ((|#1|) 54)) (-3143 (((-763) $) 145 (|has| |#1| (-350))) (((-3 (-763) "failed") $ $) 133 (|has| |#1| (-350)))) (-4189 (($ $ (-1 |#1| |#1|) (-763)) 117) (($ $ (-1 |#1| |#1|)) 116) (($ $ (-634 (-1161)) (-634 (-763))) 124 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 125 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 126 (|has| |#1| (-895 (-1161)))) (($ $ (-1161)) 127 (|has| |#1| (-895 (-1161)))) (($ $ (-763)) 129 (-2198 (-2139 (|has| |#1| (-365)) (|has| |#1| (-225))) (|has| |#1| (-225)) (-2139 (|has| |#1| (-225)) (|has| |#1| (-365))))) (($ $) 131 (-2198 (-2139 (|has| |#1| (-365)) (|has| |#1| (-225))) (|has| |#1| (-225)) (-2139 (|has| |#1| (-225)) (|has| |#1| (-365)))))) (-4387 (((-679 |#1|) (-1244 $) (-1 |#1| |#1|)) 148 (|has| |#1| (-365)))) (-1626 (((-1157 |#1|)) 153)) (-1994 (($ $) 209 (|has| |#1| (-1181)))) (-1945 (($ $) 198 (|has| |#1| (-1181)))) (-3065 (($) 142 (|has| |#1| (-350)))) (-1986 (($ $) 208 (|has| |#1| (-1181)))) (-1937 (($ $) 199 (|has| |#1| (-1181)))) (-1978 (($ $) 207 (|has| |#1| (-1181)))) (-2790 (($ $) 200 (|has| |#1| (-1181)))) (-4073 (((-1244 |#1|) $ (-1244 $)) 48) (((-679 |#1|) (-1244 $) (-1244 $)) 47) (((-1244 |#1|) $) 60) (((-679 |#1|) (-1244 $)) 59)) (-4278 (((-1244 |#1|) $) 57) (($ (-1244 |#1|)) 56) (((-1157 |#1|) $) 165) (($ (-1157 |#1|)) 151) (((-887 (-568)) $) 243 (|has| |#1| (-609 (-887 (-568))))) (((-887 (-381)) $) 242 (|has| |#1| (-609 (-887 (-381))))) (((-169 (-381)) $) 194 (|has| |#1| (-1021))) (((-169 (-215)) $) 193 (|has| |#1| (-1021))) (((-541) $) 192 (|has| |#1| (-609 (-541))))) (-1458 (($ $) 240)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) 139 (-2198 (-2139 (|has| $ (-148)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))) (|has| |#1| (-350))))) (-4003 (($ |#1| |#1|) 239)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 36) (($ (-409 (-568))) 80 (-2198 (|has| |#1| (-365)) (|has| |#1| (-1037 (-409 (-568)))))) (($ $) 85 (-2198 (|has| |#1| (-558)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))))) (-4371 (($ $) 138 (|has| |#1| (-350))) (((-3 $ "failed") $) 41 (-2198 (-2139 (|has| $ (-148)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))) (|has| |#1| (-148))))) (-2678 (((-1157 |#1|) $) 43)) (-4078 (((-763)) 28)) (-3746 (((-1244 $)) 61)) (-2006 (($ $) 218 (|has| |#1| (-1181)))) (-1958 (($ $) 206 (|has| |#1| (-1181)))) (-1826 (((-121) $ $) 89 (-2198 (|has| |#1| (-558)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))))) (-1998 (($ $) 217 (|has| |#1| (-1181)))) (-1949 (($ $) 205 (|has| |#1| (-1181)))) (-2014 (($ $) 216 (|has| |#1| (-1181)))) (-1966 (($ $) 204 (|has| |#1| (-1181)))) (-3256 ((|#1| $) 234 (|has| |#1| (-1181)))) (-4023 (($ $) 215 (|has| |#1| (-1181)))) (-1970 (($ $) 203 (|has| |#1| (-1181)))) (-2010 (($ $) 214 (|has| |#1| (-1181)))) (-1962 (($ $) 202 (|has| |#1| (-1181)))) (-2002 (($ $) 213 (|has| |#1| (-1181)))) (-1953 (($ $) 201 (|has| |#1| (-1181)))) (-2897 (($ $) 235 (|has| |#1| (-1056)))) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 111 (|has| |#1| (-365)))) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $ (-1 |#1| |#1|) (-763)) 119) (($ $ (-1 |#1| |#1|)) 118) (($ $ (-634 (-1161)) (-634 (-763))) 120 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 121 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 122 (|has| |#1| (-895 (-1161)))) (($ $ (-1161)) 123 (|has| |#1| (-895 (-1161)))) (($ $ (-763)) 128 (-2198 (-2139 (|has| |#1| (-365)) (|has| |#1| (-225))) (|has| |#1| (-225)) (-2139 (|has| |#1| (-225)) (|has| |#1| (-365))))) (($ $) 130 (-2198 (-2139 (|has| |#1| (-365)) (|has| |#1| (-225))) (|has| |#1| (-225)) (-2139 (|has| |#1| (-225)) (|has| |#1| (-365)))))) (-1751 (((-121) $ $) 188 (|has| |#1| (-842)))) (-1738 (((-121) $ $) 187 (|has| |#1| (-842)))) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 189 (|has| |#1| (-842)))) (-1732 (((-121) $ $) 186 (|has| |#1| (-842)))) (-1779 (($ $ $) 115 (|has| |#1| (-365)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-409 (-568))) 223 (-12 (|has| |#1| (-1002)) (|has| |#1| (-1181)))) (($ $ $) 221 (|has| |#1| (-1181))) (($ $ (-568)) 112 (|has| |#1| (-365)))) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37) (($ (-409 (-568)) $) 114 (|has| |#1| (-365))) (($ $ (-409 (-568))) 113 (|has| |#1| (-365))))) 
+((-2449 (((-121) $ $) NIL)) (-3140 (($ (-568)) 13) (($ $ $) 14)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 17)) (-1719 (((-121) $ $) 9))) 
+(((-162) (-13 (-1090) (-10 -8 (-15 -3140 ($ (-568))) (-15 -3140 ($ $ $))))) (T -162)) 
+((-3140 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-162)))) (-3140 (*1 *1 *1 *1) (-5 *1 (-162)))) 
+(-13 (-1090) (-10 -8 (-15 -3140 ($ (-568))) (-15 -3140 ($ $ $)))) 
+((-3842 (((-123) (-1161)) 99))) 
+(((-163) (-10 -7 (-15 -3842 ((-123) (-1161))))) (T -163)) 
+((-3842 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-123)) (-5 *1 (-163))))) 
+(-10 -7 (-15 -3842 ((-123) (-1161)))) 
+((-2032 ((|#3| |#3|) 19))) 
+(((-164 |#1| |#2| |#3|) (-10 -7 (-15 -2032 (|#3| |#3|))) (-1047) (-1219 |#1|) (-1219 |#2|)) (T -164)) 
+((-2032 (*1 *2 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-1219 *3)) (-5 *1 (-164 *3 *4 *2)) (-4 *2 (-1219 *4))))) 
+(-10 -7 (-15 -2032 (|#3| |#3|))) 
+((-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 215)) (-1934 ((|#2| $) 95)) (-1984 (($ $) 242)) (-1935 (($ $) 236)) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 39)) (-1976 (($ $) 240)) (-2788 (($ $) 234)) (-3668 (((-3 (-568) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 |#2| "failed") $) 139)) (-2857 (((-568) $) NIL) (((-409 (-568)) $) NIL) ((|#2| $) 137)) (-2403 (($ $ $) 220)) (-1668 (((-679 (-568)) (-679 $)) NIL) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) 153) (((-679 |#2|) (-679 $)) 147)) (-3094 (($ (-1157 |#2|)) 118) (((-3 $ "failed") (-409 (-1157 |#2|))) NIL)) (-2902 (((-3 $ "failed") $) 207)) (-3254 (((-3 (-409 (-568)) "failed") $) 197)) (-1338 (((-121) $) 192)) (-2394 (((-409 (-568)) $) 195)) (-2371 (((-917)) 88)) (-2414 (($ $ $) 222)) (-1432 (((-2 (|:| |r| |#2|) (|:| |phi| |#2|)) $) 258)) (-1899 (($) 231)) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 184) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 189)) (-4417 ((|#2| $) 93)) (-1497 (((-1157 |#2|) $) 120)) (-2797 (($ (-1 |#2| |#2|) $) 101)) (-4418 (($ $) 233)) (-3087 (((-1157 |#2|) $) 119)) (-2083 (($ $) 200)) (-2719 (($) 96)) (-2841 (((-420 (-1157 $)) (-1157 $)) 87)) (-2795 (((-420 (-1157 $)) (-1157 $)) 56)) (-2597 (((-3 $ "failed") $ |#2|) 202) (((-3 $ "failed") $ $) 205)) (-1894 (($ $) 232)) (-1466 (((-763) $) 217)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 226)) (-3440 ((|#2| (-1244 $)) NIL) ((|#2|) 90)) (-4191 (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) 112) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) NIL) (($ $ (-763)) NIL) (($ $) NIL)) (-1492 (((-1157 |#2|)) 113)) (-1980 (($ $) 241)) (-2792 (($ $) 235)) (-1656 (((-1244 |#2|) $ (-1244 $)) 126) (((-679 |#2|) (-1244 $) (-1244 $)) NIL) (((-1244 |#2|) $) 109) (((-679 |#2|) (-1244 $)) NIL)) (-4280 (((-1244 |#2|) $) NIL) (($ (-1244 |#2|)) NIL) (((-1157 |#2|) $) NIL) (($ (-1157 |#2|)) NIL) (((-887 (-568)) $) 175) (((-887 (-381)) $) 179) (((-169 (-381)) $) 165) (((-169 (-215)) $) 160) (((-541) $) 171)) (-2387 (($ $) 97)) (-2747 (((-850) $) 136) (($ (-568)) NIL) (($ |#2|) NIL) (($ (-409 (-568))) NIL) (($ $) NIL)) (-1295 (((-1157 |#2|) $) 23)) (-3425 (((-763)) 99)) (-2008 (($ $) 245)) (-1959 (($ $) 239)) (-2000 (($ $) 243)) (-1951 (($ $) 237)) (-2014 ((|#2| $) 230)) (-2004 (($ $) 244)) (-1955 (($ $) 238)) (-2811 (($ $) 155)) (-1719 (((-121) $ $) 103)) (-1734 (((-121) $ $) 191)) (-1775 (($ $) 105) (($ $ $) NIL)) (-1769 (($ $ $) 104)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-409 (-568))) 264) (($ $ $) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 111) (($ $ $) 140) (($ $ |#2|) NIL) (($ |#2| $) 107) (($ (-409 (-568)) $) NIL) (($ $ (-409 (-568))) NIL))) 
+(((-165 |#1| |#2|) (-10 -8 (-15 -4191 (|#1| |#1|)) (-15 -4191 (|#1| |#1| (-763))) (-15 -2747 (|#1| |#1|)) (-15 -2597 ((-3 |#1| "failed") |#1| |#1|)) (-15 -2431 ((-2 (|:| -3591 |#1|) (|:| -4508 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -4191 (|#1| |#1| (-1161))) (-15 -4191 (|#1| |#1| (-634 (-1161)))) (-15 -4191 (|#1| |#1| (-1161) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -1466 ((-763) |#1|)) (-15 -1854 ((-2 (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1|)) (-15 -2414 (|#1| |#1| |#1|)) (-15 -2403 (|#1| |#1| |#1|)) (-15 -2083 (|#1| |#1|)) (-15 ** (|#1| |#1| (-568))) (-15 * (|#1| |#1| (-409 (-568)))) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -1734 ((-121) |#1| |#1|)) (-15 -4280 ((-541) |#1|)) (-15 -4280 ((-169 (-215)) |#1|)) (-15 -4280 ((-169 (-381)) |#1|)) (-15 -1935 (|#1| |#1|)) (-15 -2788 (|#1| |#1|)) (-15 -2792 (|#1| |#1|)) (-15 -1955 (|#1| |#1|)) (-15 -1951 (|#1| |#1|)) (-15 -1959 (|#1| |#1|)) (-15 -1980 (|#1| |#1|)) (-15 -1976 (|#1| |#1|)) (-15 -1984 (|#1| |#1|)) (-15 -2004 (|#1| |#1|)) (-15 -2000 (|#1| |#1|)) (-15 -2008 (|#1| |#1|)) (-15 -4418 (|#1| |#1|)) (-15 -1894 (|#1| |#1|)) (-15 ** (|#1| |#1| |#1|)) (-15 -1899 (|#1|)) (-15 ** (|#1| |#1| (-409 (-568)))) (-15 -2795 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -2841 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -2434 ((-3 (-634 (-1157 |#1|)) "failed") (-634 (-1157 |#1|)) (-1157 |#1|))) (-15 -3254 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2394 ((-409 (-568)) |#1|)) (-15 -1338 ((-121) |#1|)) (-15 -1432 ((-2 (|:| |r| |#2|) (|:| |phi| |#2|)) |#1|)) (-15 -2014 (|#2| |#1|)) (-15 -2811 (|#1| |#1|)) (-15 -2597 ((-3 |#1| "failed") |#1| |#2|)) (-15 -2387 (|#1| |#1|)) (-15 -2719 (|#1|)) (-15 -4280 ((-887 (-381)) |#1|)) (-15 -4280 ((-887 (-568)) |#1|)) (-15 -1519 ((-884 (-381) |#1|) |#1| (-887 (-381)) (-884 (-381) |#1|))) (-15 -1519 ((-884 (-568) |#1|) |#1| (-887 (-568)) (-884 (-568) |#1|))) (-15 -2797 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -3094 ((-3 |#1| "failed") (-409 (-1157 |#2|)))) (-15 -3087 ((-1157 |#2|) |#1|)) (-15 -4280 (|#1| (-1157 |#2|))) (-15 -3094 (|#1| (-1157 |#2|))) (-15 -1492 ((-1157 |#2|))) (-15 -1668 ((-679 |#2|) (-679 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 |#1|) (-1244 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -1668 ((-679 (-568)) (-679 |#1|))) (-15 -2857 (|#2| |#1|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2857 ((-568) |#1|)) (-15 -4280 ((-1157 |#2|) |#1|)) (-15 -3440 (|#2|)) (-15 -4280 (|#1| (-1244 |#2|))) (-15 -4280 ((-1244 |#2|) |#1|)) (-15 -1656 ((-679 |#2|) (-1244 |#1|))) (-15 -1656 ((-1244 |#2|) |#1|)) (-15 -1497 ((-1157 |#2|) |#1|)) (-15 -1295 ((-1157 |#2|) |#1|)) (-15 -3440 (|#2| (-1244 |#1|))) (-15 -1656 ((-679 |#2|) (-1244 |#1|) (-1244 |#1|))) (-15 -1656 ((-1244 |#2|) |#1| (-1244 |#1|))) (-15 -4417 (|#2| |#1|)) (-15 -1934 (|#2| |#1|)) (-15 -2371 ((-917))) (-15 -2747 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -2747 (|#1| (-568))) (-15 -3425 ((-763))) (-15 ** (|#1| |#1| (-763))) (-15 -2902 ((-3 |#1| "failed") |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| (-917))) (-15 * (|#1| (-568) |#1|)) (-15 -1775 (|#1| |#1| |#1|)) (-15 -1775 (|#1| |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|)) (-15 -1769 (|#1| |#1| |#1|)) (-15 -2747 ((-850) |#1|)) (-15 -1719 ((-121) |#1| |#1|))) (-166 |#2|) (-172)) (T -165)) 
+((-3425 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-763)) (-5 *1 (-165 *3 *4)) (-4 *3 (-166 *4)))) (-2371 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-917)) (-5 *1 (-165 *3 *4)) (-4 *3 (-166 *4)))) (-3440 (*1 *2) (-12 (-4 *2 (-172)) (-5 *1 (-165 *3 *2)) (-4 *3 (-166 *2)))) (-1492 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-1157 *4)) (-5 *1 (-165 *3 *4)) (-4 *3 (-166 *4))))) 
+(-10 -8 (-15 -4191 (|#1| |#1|)) (-15 -4191 (|#1| |#1| (-763))) (-15 -2747 (|#1| |#1|)) (-15 -2597 ((-3 |#1| "failed") |#1| |#1|)) (-15 -2431 ((-2 (|:| -3591 |#1|) (|:| -4508 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -4191 (|#1| |#1| (-1161))) (-15 -4191 (|#1| |#1| (-634 (-1161)))) (-15 -4191 (|#1| |#1| (-1161) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -1466 ((-763) |#1|)) (-15 -1854 ((-2 (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1|)) (-15 -2414 (|#1| |#1| |#1|)) (-15 -2403 (|#1| |#1| |#1|)) (-15 -2083 (|#1| |#1|)) (-15 ** (|#1| |#1| (-568))) (-15 * (|#1| |#1| (-409 (-568)))) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -1734 ((-121) |#1| |#1|)) (-15 -4280 ((-541) |#1|)) (-15 -4280 ((-169 (-215)) |#1|)) (-15 -4280 ((-169 (-381)) |#1|)) (-15 -1935 (|#1| |#1|)) (-15 -2788 (|#1| |#1|)) (-15 -2792 (|#1| |#1|)) (-15 -1955 (|#1| |#1|)) (-15 -1951 (|#1| |#1|)) (-15 -1959 (|#1| |#1|)) (-15 -1980 (|#1| |#1|)) (-15 -1976 (|#1| |#1|)) (-15 -1984 (|#1| |#1|)) (-15 -2004 (|#1| |#1|)) (-15 -2000 (|#1| |#1|)) (-15 -2008 (|#1| |#1|)) (-15 -4418 (|#1| |#1|)) (-15 -1894 (|#1| |#1|)) (-15 ** (|#1| |#1| |#1|)) (-15 -1899 (|#1|)) (-15 ** (|#1| |#1| (-409 (-568)))) (-15 -2795 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -2841 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -2434 ((-3 (-634 (-1157 |#1|)) "failed") (-634 (-1157 |#1|)) (-1157 |#1|))) (-15 -3254 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2394 ((-409 (-568)) |#1|)) (-15 -1338 ((-121) |#1|)) (-15 -1432 ((-2 (|:| |r| |#2|) (|:| |phi| |#2|)) |#1|)) (-15 -2014 (|#2| |#1|)) (-15 -2811 (|#1| |#1|)) (-15 -2597 ((-3 |#1| "failed") |#1| |#2|)) (-15 -2387 (|#1| |#1|)) (-15 -2719 (|#1|)) (-15 -4280 ((-887 (-381)) |#1|)) (-15 -4280 ((-887 (-568)) |#1|)) (-15 -1519 ((-884 (-381) |#1|) |#1| (-887 (-381)) (-884 (-381) |#1|))) (-15 -1519 ((-884 (-568) |#1|) |#1| (-887 (-568)) (-884 (-568) |#1|))) (-15 -2797 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -3094 ((-3 |#1| "failed") (-409 (-1157 |#2|)))) (-15 -3087 ((-1157 |#2|) |#1|)) (-15 -4280 (|#1| (-1157 |#2|))) (-15 -3094 (|#1| (-1157 |#2|))) (-15 -1492 ((-1157 |#2|))) (-15 -1668 ((-679 |#2|) (-679 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 |#1|) (-1244 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -1668 ((-679 (-568)) (-679 |#1|))) (-15 -2857 (|#2| |#1|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2857 ((-568) |#1|)) (-15 -4280 ((-1157 |#2|) |#1|)) (-15 -3440 (|#2|)) (-15 -4280 (|#1| (-1244 |#2|))) (-15 -4280 ((-1244 |#2|) |#1|)) (-15 -1656 ((-679 |#2|) (-1244 |#1|))) (-15 -1656 ((-1244 |#2|) |#1|)) (-15 -1497 ((-1157 |#2|) |#1|)) (-15 -1295 ((-1157 |#2|) |#1|)) (-15 -3440 (|#2| (-1244 |#1|))) (-15 -1656 ((-679 |#2|) (-1244 |#1|) (-1244 |#1|))) (-15 -1656 ((-1244 |#2|) |#1| (-1244 |#1|))) (-15 -4417 (|#2| |#1|)) (-15 -1934 (|#2| |#1|)) (-15 -2371 ((-917))) (-15 -2747 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -2747 (|#1| (-568))) (-15 -3425 ((-763))) (-15 ** (|#1| |#1| (-763))) (-15 -2902 ((-3 |#1| "failed") |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| (-917))) (-15 * (|#1| (-568) |#1|)) (-15 -1775 (|#1| |#1| |#1|)) (-15 -1775 (|#1| |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|)) (-15 -1769 (|#1| |#1| |#1|)) (-15 -2747 ((-850) |#1|)) (-15 -1719 ((-121) |#1| |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 87 (-2199 (|has| |#1| (-558)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))))) (-3661 (($ $) 88 (-2199 (|has| |#1| (-558)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))))) (-4426 (((-121) $) 90 (-2199 (|has| |#1| (-558)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))))) (-2883 (((-679 |#1|) (-1244 $)) 44) (((-679 |#1|)) 55)) (-1934 ((|#1| $) 50)) (-1984 (($ $) 212 (|has| |#1| (-1181)))) (-1935 (($ $) 195 (|has| |#1| (-1181)))) (-1856 (((-1169 (-917) (-763)) (-568)) 141 (|has| |#1| (-350)))) (-2689 (((-3 $ "failed") $ $) 18)) (-3863 (((-420 (-1157 $)) (-1157 $)) 226 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))))) (-3045 (($ $) 107 (-2199 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-365))))) (-3498 (((-420 $) $) 108 (-2199 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-365))))) (-1904 (($ $) 225 (-12 (|has| |#1| (-1002)) (|has| |#1| (-1181))))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 229 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))))) (-2589 (((-121) $ $) 98 (|has| |#1| (-301)))) (-3986 (((-763)) 81 (|has| |#1| (-370)))) (-1976 (($ $) 211 (|has| |#1| (-1181)))) (-2788 (($ $) 196 (|has| |#1| (-1181)))) (-1992 (($ $) 210 (|has| |#1| (-1181)))) (-1943 (($ $) 197 (|has| |#1| (-1181)))) (-4490 (($) 16 T CONST)) (-3668 (((-3 (-568) "failed") $) 163 (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) 161 (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 160)) (-2857 (((-568) $) 164 (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) 162 (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) 159)) (-3899 (($ (-1244 |#1|) (-1244 $)) 46) (($ (-1244 |#1|)) 58)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) 147 (|has| |#1| (-350)))) (-2403 (($ $ $) 102 (|has| |#1| (-301)))) (-3653 (((-679 |#1|) $ (-1244 $)) 51) (((-679 |#1|) $) 53)) (-1668 (((-679 (-568)) (-679 $)) 158 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 157 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 156) (((-679 |#1|) (-679 $)) 155)) (-3094 (($ (-1157 |#1|)) 152) (((-3 $ "failed") (-409 (-1157 |#1|))) 149 (|has| |#1| (-365)))) (-2902 (((-3 $ "failed") $) 33)) (-3859 ((|#1| $) 237)) (-3254 (((-3 (-409 (-568)) "failed") $) 230 (|has| |#1| (-550)))) (-1338 (((-121) $) 232 (|has| |#1| (-550)))) (-2394 (((-409 (-568)) $) 231 (|has| |#1| (-550)))) (-2371 (((-917)) 52)) (-1733 (($) 84 (|has| |#1| (-370)))) (-2414 (($ $ $) 101 (|has| |#1| (-301)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 96 (|has| |#1| (-301)))) (-4188 (($) 143 (|has| |#1| (-350)))) (-1748 (((-121) $) 144 (|has| |#1| (-350)))) (-1887 (($ $ (-763)) 135 (|has| |#1| (-350))) (($ $) 134 (|has| |#1| (-350)))) (-2197 (((-121) $) 109 (-2199 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-365))))) (-1432 (((-2 (|:| |r| |#1|) (|:| |phi| |#1|)) $) 233 (-12 (|has| |#1| (-1056)) (|has| |#1| (-1181))))) (-1899 (($) 222 (|has| |#1| (-1181)))) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 245 (|has| |#1| (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 244 (|has| |#1| (-881 (-381))))) (-1844 (((-917) $) 146 (|has| |#1| (-350))) (((-828 (-917)) $) 132 (|has| |#1| (-350)))) (-1598 (((-121) $) 30)) (-1550 (($ $ (-568)) 224 (-12 (|has| |#1| (-1002)) (|has| |#1| (-1181))))) (-4417 ((|#1| $) 49)) (-2214 (((-3 $ "failed") $) 136 (|has| |#1| (-350)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 105 (|has| |#1| (-301)))) (-1497 (((-1157 |#1|) $) 42 (|has| |#1| (-365)))) (-1732 (($ $ $) 191 (|has| |#1| (-842)))) (-2047 (($ $ $) 190 (|has| |#1| (-842)))) (-2797 (($ (-1 |#1| |#1|) $) 246)) (-2291 (((-917) $) 83 (|has| |#1| (-370)))) (-4418 (($ $) 219 (|has| |#1| (-1181)))) (-3087 (((-1157 |#1|) $) 150)) (-2498 (($ (-634 $)) 94 (-2199 (|has| |#1| (-301)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904))))) (($ $ $) 93 (-2199 (|has| |#1| (-301)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))))) (-1893 (((-1143) $) 9)) (-2083 (($ $) 110 (|has| |#1| (-365)))) (-4436 (($) 137 (|has| |#1| (-350)) CONST)) (-4357 (($ (-917)) 82 (|has| |#1| (-370)))) (-2719 (($) 241)) (-3868 ((|#1| $) 238)) (-4025 (((-1108) $) 10)) (-2707 (($) 154)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 95 (-2199 (|has| |#1| (-301)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))))) (-2723 (($ (-634 $)) 92 (-2199 (|has| |#1| (-301)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904))))) (($ $ $) 91 (-2199 (|has| |#1| (-301)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))))) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) 140 (|has| |#1| (-350)))) (-2841 (((-420 (-1157 $)) (-1157 $)) 228 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))))) (-2795 (((-420 (-1157 $)) (-1157 $)) 227 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))))) (-3850 (((-420 $) $) 106 (-2199 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-365))))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 104 (|has| |#1| (-301))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 103 (|has| |#1| (-301)))) (-2597 (((-3 $ "failed") $ |#1|) 236 (|has| |#1| (-558))) (((-3 $ "failed") $ $) 86 (-2199 (|has| |#1| (-558)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 97 (|has| |#1| (-301)))) (-1894 (($ $) 220 (|has| |#1| (-1181)))) (-1339 (($ $ (-634 |#1|) (-634 |#1|)) 252 (|has| |#1| (-303 |#1|))) (($ $ |#1| |#1|) 251 (|has| |#1| (-303 |#1|))) (($ $ (-288 |#1|)) 250 (|has| |#1| (-303 |#1|))) (($ $ (-634 (-288 |#1|))) 249 (|has| |#1| (-303 |#1|))) (($ $ (-634 (-1161)) (-634 |#1|)) 248 (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-1161) |#1|) 247 (|has| |#1| (-523 (-1161) |#1|)))) (-1466 (((-763) $) 99 (|has| |#1| (-301)))) (-2781 (($ $ |#1|) 253 (|has| |#1| (-281 |#1| |#1|)))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 100 (|has| |#1| (-301)))) (-3440 ((|#1| (-1244 $)) 45) ((|#1|) 54)) (-2721 (((-763) $) 145 (|has| |#1| (-350))) (((-3 (-763) "failed") $ $) 133 (|has| |#1| (-350)))) (-4191 (($ $ (-1 |#1| |#1|) (-763)) 117) (($ $ (-1 |#1| |#1|)) 116) (($ $ (-634 (-1161)) (-634 (-763))) 124 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 125 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 126 (|has| |#1| (-895 (-1161)))) (($ $ (-1161)) 127 (|has| |#1| (-895 (-1161)))) (($ $ (-763)) 129 (-2199 (-2141 (|has| |#1| (-365)) (|has| |#1| (-225))) (|has| |#1| (-225)) (-2141 (|has| |#1| (-225)) (|has| |#1| (-365))))) (($ $) 131 (-2199 (-2141 (|has| |#1| (-365)) (|has| |#1| (-225))) (|has| |#1| (-225)) (-2141 (|has| |#1| (-225)) (|has| |#1| (-365)))))) (-1391 (((-679 |#1|) (-1244 $) (-1 |#1| |#1|)) 148 (|has| |#1| (-365)))) (-1492 (((-1157 |#1|)) 153)) (-1996 (($ $) 209 (|has| |#1| (-1181)))) (-1947 (($ $) 198 (|has| |#1| (-1181)))) (-2330 (($) 142 (|has| |#1| (-350)))) (-1988 (($ $) 208 (|has| |#1| (-1181)))) (-1939 (($ $) 199 (|has| |#1| (-1181)))) (-1980 (($ $) 207 (|has| |#1| (-1181)))) (-2792 (($ $) 200 (|has| |#1| (-1181)))) (-1656 (((-1244 |#1|) $ (-1244 $)) 48) (((-679 |#1|) (-1244 $) (-1244 $)) 47) (((-1244 |#1|) $) 60) (((-679 |#1|) (-1244 $)) 59)) (-4280 (((-1244 |#1|) $) 57) (($ (-1244 |#1|)) 56) (((-1157 |#1|) $) 165) (($ (-1157 |#1|)) 151) (((-887 (-568)) $) 243 (|has| |#1| (-609 (-887 (-568))))) (((-887 (-381)) $) 242 (|has| |#1| (-609 (-887 (-381))))) (((-169 (-381)) $) 194 (|has| |#1| (-1021))) (((-169 (-215)) $) 193 (|has| |#1| (-1021))) (((-541) $) 192 (|has| |#1| (-609 (-541))))) (-2387 (($ $) 240)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) 139 (-2199 (-2141 (|has| $ (-148)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))) (|has| |#1| (-350))))) (-4005 (($ |#1| |#1|) 239)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 36) (($ (-409 (-568))) 80 (-2199 (|has| |#1| (-365)) (|has| |#1| (-1037 (-409 (-568)))))) (($ $) 85 (-2199 (|has| |#1| (-558)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))))) (-3385 (($ $) 138 (|has| |#1| (-350))) (((-3 $ "failed") $) 41 (-2199 (-2141 (|has| $ (-148)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))) (|has| |#1| (-148))))) (-1295 (((-1157 |#1|) $) 43)) (-3425 (((-763)) 28)) (-2588 (((-1244 $)) 61)) (-2008 (($ $) 218 (|has| |#1| (-1181)))) (-1959 (($ $) 206 (|has| |#1| (-1181)))) (-2273 (((-121) $ $) 89 (-2199 (|has| |#1| (-558)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904)))))) (-2000 (($ $) 217 (|has| |#1| (-1181)))) (-1951 (($ $) 205 (|has| |#1| (-1181)))) (-2016 (($ $) 216 (|has| |#1| (-1181)))) (-1968 (($ $) 204 (|has| |#1| (-1181)))) (-2014 ((|#1| $) 234 (|has| |#1| (-1181)))) (-1439 (($ $) 215 (|has| |#1| (-1181)))) (-1972 (($ $) 203 (|has| |#1| (-1181)))) (-2012 (($ $) 214 (|has| |#1| (-1181)))) (-1964 (($ $) 202 (|has| |#1| (-1181)))) (-2004 (($ $) 213 (|has| |#1| (-1181)))) (-1955 (($ $) 201 (|has| |#1| (-1181)))) (-2811 (($ $) 235 (|has| |#1| (-1056)))) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 111 (|has| |#1| (-365)))) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $ (-1 |#1| |#1|) (-763)) 119) (($ $ (-1 |#1| |#1|)) 118) (($ $ (-634 (-1161)) (-634 (-763))) 120 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 121 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 122 (|has| |#1| (-895 (-1161)))) (($ $ (-1161)) 123 (|has| |#1| (-895 (-1161)))) (($ $ (-763)) 128 (-2199 (-2141 (|has| |#1| (-365)) (|has| |#1| (-225))) (|has| |#1| (-225)) (-2141 (|has| |#1| (-225)) (|has| |#1| (-365))))) (($ $) 130 (-2199 (-2141 (|has| |#1| (-365)) (|has| |#1| (-225))) (|has| |#1| (-225)) (-2141 (|has| |#1| (-225)) (|has| |#1| (-365)))))) (-1753 (((-121) $ $) 188 (|has| |#1| (-842)))) (-1740 (((-121) $ $) 187 (|has| |#1| (-842)))) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 189 (|has| |#1| (-842)))) (-1734 (((-121) $ $) 186 (|has| |#1| (-842)))) (-1781 (($ $ $) 115 (|has| |#1| (-365)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-409 (-568))) 223 (-12 (|has| |#1| (-1002)) (|has| |#1| (-1181)))) (($ $ $) 221 (|has| |#1| (-1181))) (($ $ (-568)) 112 (|has| |#1| (-365)))) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37) (($ (-409 (-568)) $) 114 (|has| |#1| (-365))) (($ $ (-409 (-568))) 113 (|has| |#1| (-365))))) 
 (((-166 |#1|) (-1275) (-172)) (T -166)) 
-((-2657 (*1 *2 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)))) (-3777 (*1 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)))) (-1458 (*1 *1 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)))) (-4003 (*1 *1 *2 *2) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)))) (-3866 (*1 *2 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)))) (-3857 (*1 *2 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)))) (-2595 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-166 *2)) (-4 *2 (-172)) (-4 *2 (-558)))) (-2897 (*1 *1 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)) (-4 *2 (-1056)))) (-3256 (*1 *2 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)) (-4 *2 (-1181)))) (-3378 (*1 *2 *1) (-12 (-4 *1 (-166 *3)) (-4 *3 (-172)) (-4 *3 (-1056)) (-4 *3 (-1181)) (-5 *2 (-2 (|:| |r| *3) (|:| |phi| *3))))) (-2688 (*1 *2 *1) (-12 (-4 *1 (-166 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-121)))) (-2425 (*1 *2 *1) (-12 (-4 *1 (-166 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-409 (-568))))) (-1642 (*1 *2 *1) (|partial| -12 (-4 *1 (-166 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-409 (-568)))))) 
-(-13 (-714 |t#1| (-1157 |t#1|)) (-413 |t#1|) (-223 |t#1|) (-336 |t#1|) (-402 |t#1|) (-879 |t#1|) (-379 |t#1|) (-172) (-10 -8 (-6 -4003) (-15 -3777 ($)) (-15 -1458 ($ $)) (-15 -4003 ($ |t#1| |t#1|)) (-15 -3866 (|t#1| $)) (-15 -3857 (|t#1| $)) (-15 -2657 (|t#1| $)) (IF (|has| |t#1| (-842)) (-6 (-842)) |noBranch|) (IF (|has| |t#1| (-558)) (PROGN (-6 (-558)) (-15 -2595 ((-3 $ "failed") $ |t#1|))) |noBranch|) (IF (|has| |t#1| (-301)) (-6 (-301)) |noBranch|) (IF (|has| |t#1| (-6 -4518)) (-6 -4518) |noBranch|) (IF (|has| |t#1| (-6 -4515)) (-6 -4515) |noBranch|) (IF (|has| |t#1| (-365)) (-6 (-365)) |noBranch|) (IF (|has| |t#1| (-609 (-541))) (-6 (-609 (-541))) |noBranch|) (IF (|has| |t#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |t#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |t#1| (-1021)) (PROGN (-6 (-609 (-169 (-215)))) (-6 (-609 (-169 (-381))))) |noBranch|) (IF (|has| |t#1| (-1056)) (-15 -2897 ($ $)) |noBranch|) (IF (|has| |t#1| (-1181)) (PROGN (-6 (-1181)) (-15 -3256 (|t#1| $)) (IF (|has| |t#1| (-1002)) (-6 (-1002)) |noBranch|) (IF (|has| |t#1| (-1056)) (-15 -3378 ((-2 (|:| |r| |t#1|) (|:| |phi| |t#1|)) $)) |noBranch|)) |noBranch|) (IF (|has| |t#1| (-550)) (PROGN (-15 -2688 ((-121) $)) (-15 -2425 ((-409 (-568)) $)) (-15 -1642 ((-3 (-409 (-568)) "failed") $))) |noBranch|) (IF (|has| |t#1| (-904)) (IF (|has| |t#1| (-301)) (-6 (-904)) |noBranch|) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) -2198 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-43 |#1|) . T) ((-43 $) -2198 (|has| |#1| (-558)) (|has| |#1| (-350)) (|has| |#1| (-365)) (|has| |#1| (-301))) ((-40) |has| |#1| (-1181)) ((-98) |has| |#1| (-1181)) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) -2198 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-120 |#1| |#1|) . T) ((-120 $ $) . T) ((-137) . T) ((-148) -2198 (|has| |#1| (-350)) (|has| |#1| (-148))) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) . T) ((-609 (-169 (-215))) |has| |#1| (-1021)) ((-609 (-169 (-381))) |has| |#1| (-1021)) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-609 (-887 (-381))) |has| |#1| (-609 (-887 (-381)))) ((-609 (-887 (-568))) |has| |#1| (-609 (-887 (-568)))) ((-609 (-1157 |#1|)) . T) ((-223 |#1|) . T) ((-225) -2198 (|has| |#1| (-350)) (|has| |#1| (-225))) ((-238) -2198 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-279) |has| |#1| (-1181)) ((-281 |#1| $) |has| |#1| (-281 |#1| |#1|)) ((-285) -2198 (|has| |#1| (-558)) (|has| |#1| (-350)) (|has| |#1| (-365)) (|has| |#1| (-301))) ((-301) -2198 (|has| |#1| (-350)) (|has| |#1| (-365)) (|has| |#1| (-301))) ((-303 |#1|) |has| |#1| (-303 |#1|)) ((-365) -2198 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-404) |has| |#1| (-350)) ((-370) -2198 (|has| |#1| (-370)) (|has| |#1| (-350))) ((-350) |has| |#1| (-350)) ((-372 |#1| (-1157 |#1|)) . T) ((-411 |#1| (-1157 |#1|)) . T) ((-336 |#1|) . T) ((-379 |#1|) . T) ((-402 |#1|) . T) ((-413 |#1|) . T) ((-453) -2198 (|has| |#1| (-350)) (|has| |#1| (-365)) (|has| |#1| (-301))) ((-502) |has| |#1| (-1181)) ((-523 (-1161) |#1|) |has| |#1| (-523 (-1161) |#1|)) ((-523 |#1| |#1|) |has| |#1| (-303 |#1|)) ((-558) -2198 (|has| |#1| (-558)) (|has| |#1| (-350)) (|has| |#1| (-365)) (|has| |#1| (-301))) ((-637 (-409 (-568))) -2198 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-637 |#1|) . T) ((-637 $) . T) ((-630 (-568)) |has| |#1| (-630 (-568))) ((-630 |#1|) . T) ((-707 (-409 (-568))) -2198 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-707 |#1|) . T) ((-707 $) -2198 (|has| |#1| (-558)) (|has| |#1| (-350)) (|has| |#1| (-365)) (|has| |#1| (-301))) ((-714 |#1| (-1157 |#1|)) . T) ((-716) . T) ((-842) |has| |#1| (-842)) ((-895 (-1161)) |has| |#1| (-895 (-1161))) ((-881 (-381)) |has| |#1| (-881 (-381))) ((-881 (-568)) |has| |#1| (-881 (-568))) ((-879 |#1|) . T) ((-904) -12 (|has| |#1| (-301)) (|has| |#1| (-904))) ((-916) -2198 (|has| |#1| (-350)) (|has| |#1| (-365)) (|has| |#1| (-301))) ((-1002) -12 (|has| |#1| (-1002)) (|has| |#1| (-1181))) ((-1037 (-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 |#1|) . T) ((-1053 (-409 (-568))) -2198 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-1053 |#1|) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1136) |has| |#1| (-350)) ((-1181) |has| |#1| (-1181)) ((-1184) |has| |#1| (-1181)) ((-1195) . T) ((-1199) -2198 (|has| |#1| (-350)) (|has| |#1| (-365)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904))))) 
-((-3848 (((-420 |#2|) |#2|) 63))) 
-(((-167 |#1| |#2|) (-10 -7 (-15 -3848 ((-420 |#2|) |#2|))) (-301) (-1219 (-169 |#1|))) (T -167)) 
-((-3848 (*1 *2 *3) (-12 (-4 *4 (-301)) (-5 *2 (-420 *3)) (-5 *1 (-167 *4 *3)) (-4 *3 (-1219 (-169 *4)))))) 
-(-10 -7 (-15 -3848 ((-420 |#2|) |#2|))) 
-((-2795 (((-169 |#2|) (-1 |#2| |#1|) (-169 |#1|)) 14))) 
-(((-168 |#1| |#2|) (-10 -7 (-15 -2795 ((-169 |#2|) (-1 |#2| |#1|) (-169 |#1|)))) (-172) (-172)) (T -168)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-169 *5)) (-4 *5 (-172)) (-4 *6 (-172)) (-5 *2 (-169 *6)) (-5 *1 (-168 *5 *6))))) 
-(-10 -7 (-15 -2795 ((-169 |#2|) (-1 |#2| |#1|) (-169 |#1|)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 33)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (-2198 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-558))))) (-2227 (($ $) NIL (-2198 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-558))))) (-1573 (((-121) $) NIL (-2198 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-558))))) (-4255 (((-679 |#1|) (-1244 $)) NIL) (((-679 |#1|)) NIL)) (-1932 ((|#1| $) NIL)) (-1982 (($ $) NIL (|has| |#1| (-1181)))) (-1933 (($ $) NIL (|has| |#1| (-1181)))) (-3211 (((-1169 (-917) (-763)) (-568)) NIL (|has| |#1| (-350)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| |#1| (-301)) (|has| |#1| (-904))))) (-4305 (($ $) NIL (-2198 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-365))))) (-1678 (((-420 $) $) NIL (-2198 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-365))))) (-1902 (($ $) NIL (-12 (|has| |#1| (-1002)) (|has| |#1| (-1181))))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (-12 (|has| |#1| (-301)) (|has| |#1| (-904))))) (-1497 (((-121) $ $) NIL (|has| |#1| (-301)))) (-3983 (((-763)) NIL (|has| |#1| (-370)))) (-1974 (($ $) NIL (|has| |#1| (-1181)))) (-2786 (($ $) NIL (|has| |#1| (-1181)))) (-1990 (($ $) NIL (|has| |#1| (-1181)))) (-1941 (($ $) NIL (|has| |#1| (-1181)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) NIL)) (-2854 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) NIL)) (-3498 (($ (-1244 |#1|) (-1244 $)) NIL) (($ (-1244 |#1|)) NIL)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| |#1| (-350)))) (-2401 (($ $ $) NIL (|has| |#1| (-301)))) (-1709 (((-679 |#1|) $ (-1244 $)) NIL) (((-679 |#1|) $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-3092 (($ (-1157 |#1|)) NIL) (((-3 $ "failed") (-409 (-1157 |#1|))) NIL (|has| |#1| (-365)))) (-2925 (((-3 $ "failed") $) NIL)) (-3857 ((|#1| $) 13)) (-1642 (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-550)))) (-2688 (((-121) $) NIL (|has| |#1| (-550)))) (-2425 (((-409 (-568)) $) NIL (|has| |#1| (-550)))) (-3700 (((-917)) NIL)) (-1731 (($) NIL (|has| |#1| (-370)))) (-2412 (($ $ $) NIL (|has| |#1| (-301)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| |#1| (-301)))) (-4220 (($) NIL (|has| |#1| (-350)))) (-4456 (((-121) $) NIL (|has| |#1| (-350)))) (-3218 (($ $ (-763)) NIL (|has| |#1| (-350))) (($ $) NIL (|has| |#1| (-350)))) (-3927 (((-121) $) NIL (-2198 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-365))))) (-3378 (((-2 (|:| |r| |#1|) (|:| |phi| |#1|)) $) NIL (-12 (|has| |#1| (-1056)) (|has| |#1| (-1181))))) (-1897 (($) NIL (|has| |#1| (-1181)))) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| |#1| (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| |#1| (-881 (-381))))) (-4477 (((-917) $) NIL (|has| |#1| (-350))) (((-828 (-917)) $) NIL (|has| |#1| (-350)))) (-2735 (((-121) $) 35)) (-4044 (($ $ (-568)) NIL (-12 (|has| |#1| (-1002)) (|has| |#1| (-1181))))) (-2657 ((|#1| $) 46)) (-3038 (((-3 $ "failed") $) NIL (|has| |#1| (-350)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-301)))) (-2045 (((-1157 |#1|) $) NIL (|has| |#1| (-365)))) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-3683 (((-917) $) NIL (|has| |#1| (-370)))) (-4416 (($ $) NIL (|has| |#1| (-1181)))) (-3085 (((-1157 |#1|) $) NIL)) (-2495 (($ (-634 $)) NIL (|has| |#1| (-301))) (($ $ $) NIL (|has| |#1| (-301)))) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL (|has| |#1| (-365)))) (-4434 (($) NIL (|has| |#1| (-350)) CONST)) (-4355 (($ (-917)) NIL (|has| |#1| (-370)))) (-3777 (($) NIL)) (-3866 ((|#1| $) 15)) (-4022 (((-1108) $) NIL)) (-2704 (($) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-301)))) (-2721 (($ (-634 $)) NIL (|has| |#1| (-301))) (($ $ $) NIL (|has| |#1| (-301)))) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) NIL (|has| |#1| (-350)))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| |#1| (-301)) (|has| |#1| (-904))))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| |#1| (-301)) (|has| |#1| (-904))))) (-3848 (((-420 $) $) NIL (-2198 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-365))))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-301))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-301)))) (-2595 (((-3 $ "failed") $ |#1|) 44 (|has| |#1| (-558))) (((-3 $ "failed") $ $) 47 (-2198 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-558))))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-301)))) (-1892 (($ $) NIL (|has| |#1| (-1181)))) (-1339 (($ $ (-634 |#1|) (-634 |#1|)) NIL (|has| |#1| (-303 |#1|))) (($ $ |#1| |#1|) NIL (|has| |#1| (-303 |#1|))) (($ $ (-288 |#1|)) NIL (|has| |#1| (-303 |#1|))) (($ $ (-634 (-288 |#1|))) NIL (|has| |#1| (-303 |#1|))) (($ $ (-634 (-1161)) (-634 |#1|)) NIL (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-1161) |#1|) NIL (|has| |#1| (-523 (-1161) |#1|)))) (-2709 (((-763) $) NIL (|has| |#1| (-301)))) (-2779 (($ $ |#1|) NIL (|has| |#1| (-281 |#1| |#1|)))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-301)))) (-2217 ((|#1| (-1244 $)) NIL) ((|#1|) NIL)) (-3143 (((-763) $) NIL (|has| |#1| (-350))) (((-3 (-763) "failed") $ $) NIL (|has| |#1| (-350)))) (-4189 (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $) NIL (|has| |#1| (-225)))) (-4387 (((-679 |#1|) (-1244 $) (-1 |#1| |#1|)) NIL (|has| |#1| (-365)))) (-1626 (((-1157 |#1|)) NIL)) (-1994 (($ $) NIL (|has| |#1| (-1181)))) (-1945 (($ $) NIL (|has| |#1| (-1181)))) (-3065 (($) NIL (|has| |#1| (-350)))) (-1986 (($ $) NIL (|has| |#1| (-1181)))) (-1937 (($ $) NIL (|has| |#1| (-1181)))) (-1978 (($ $) NIL (|has| |#1| (-1181)))) (-2790 (($ $) NIL (|has| |#1| (-1181)))) (-4073 (((-1244 |#1|) $ (-1244 $)) NIL) (((-679 |#1|) (-1244 $) (-1244 $)) NIL) (((-1244 |#1|) $) NIL) (((-679 |#1|) (-1244 $)) NIL)) (-4278 (((-1244 |#1|) $) NIL) (($ (-1244 |#1|)) NIL) (((-1157 |#1|) $) NIL) (($ (-1157 |#1|)) NIL) (((-887 (-568)) $) NIL (|has| |#1| (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| |#1| (-609 (-887 (-381))))) (((-169 (-381)) $) NIL (|has| |#1| (-1021))) (((-169 (-215)) $) NIL (|has| |#1| (-1021))) (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-1458 (($ $) 45)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-2198 (-12 (|has| $ (-148)) (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-350))))) (-4003 (($ |#1| |#1|) 37)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) 36) (($ (-409 (-568))) NIL (-2198 (|has| |#1| (-365)) (|has| |#1| (-1037 (-409 (-568)))))) (($ $) NIL (-2198 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-558))))) (-4371 (($ $) NIL (|has| |#1| (-350))) (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-2678 (((-1157 |#1|) $) NIL)) (-4078 (((-763)) NIL)) (-3746 (((-1244 $)) NIL)) (-2006 (($ $) NIL (|has| |#1| (-1181)))) (-1958 (($ $) NIL (|has| |#1| (-1181)))) (-1826 (((-121) $ $) NIL (-2198 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-558))))) (-1998 (($ $) NIL (|has| |#1| (-1181)))) (-1949 (($ $) NIL (|has| |#1| (-1181)))) (-2014 (($ $) NIL (|has| |#1| (-1181)))) (-1966 (($ $) NIL (|has| |#1| (-1181)))) (-3256 ((|#1| $) NIL (|has| |#1| (-1181)))) (-4023 (($ $) NIL (|has| |#1| (-1181)))) (-1970 (($ $) NIL (|has| |#1| (-1181)))) (-2010 (($ $) NIL (|has| |#1| (-1181)))) (-1962 (($ $) NIL (|has| |#1| (-1181)))) (-2002 (($ $) NIL (|has| |#1| (-1181)))) (-1953 (($ $) NIL (|has| |#1| (-1181)))) (-2897 (($ $) NIL (|has| |#1| (-1056)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (-3056 (($) 28 T CONST)) (-1556 (($) 30 T CONST)) (-3754 (((-1143) $) 23 (|has| |#1| (-823))) (((-1143) $ (-121)) 25 (|has| |#1| (-823))) (((-1249) (-817) $) 26 (|has| |#1| (-823))) (((-1249) (-817) $ (-121)) 27 (|has| |#1| (-823)))) (-3190 (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $) NIL (|has| |#1| (-225)))) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1779 (($ $ $) NIL (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) 39)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-409 (-568))) NIL (-12 (|has| |#1| (-1002)) (|has| |#1| (-1181)))) (($ $ $) NIL (|has| |#1| (-1181))) (($ $ (-568)) NIL (|has| |#1| (-365)))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 42) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-409 (-568)) $) NIL (|has| |#1| (-365))) (($ $ (-409 (-568))) NIL (|has| |#1| (-365))))) 
+((-4417 (*1 *2 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)))) (-2719 (*1 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)))) (-2387 (*1 *1 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)))) (-4005 (*1 *1 *2 *2) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)))) (-3868 (*1 *2 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)))) (-3859 (*1 *2 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)))) (-2597 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-166 *2)) (-4 *2 (-172)) (-4 *2 (-558)))) (-2811 (*1 *1 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)) (-4 *2 (-1056)))) (-2014 (*1 *2 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)) (-4 *2 (-1181)))) (-1432 (*1 *2 *1) (-12 (-4 *1 (-166 *3)) (-4 *3 (-172)) (-4 *3 (-1056)) (-4 *3 (-1181)) (-5 *2 (-2 (|:| |r| *3) (|:| |phi| *3))))) (-1338 (*1 *2 *1) (-12 (-4 *1 (-166 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-121)))) (-2394 (*1 *2 *1) (-12 (-4 *1 (-166 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-409 (-568))))) (-3254 (*1 *2 *1) (|partial| -12 (-4 *1 (-166 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-409 (-568)))))) 
+(-13 (-714 |t#1| (-1157 |t#1|)) (-413 |t#1|) (-223 |t#1|) (-336 |t#1|) (-402 |t#1|) (-879 |t#1|) (-379 |t#1|) (-172) (-10 -8 (-6 -4005) (-15 -2719 ($)) (-15 -2387 ($ $)) (-15 -4005 ($ |t#1| |t#1|)) (-15 -3868 (|t#1| $)) (-15 -3859 (|t#1| $)) (-15 -4417 (|t#1| $)) (IF (|has| |t#1| (-842)) (-6 (-842)) |noBranch|) (IF (|has| |t#1| (-558)) (PROGN (-6 (-558)) (-15 -2597 ((-3 $ "failed") $ |t#1|))) |noBranch|) (IF (|has| |t#1| (-301)) (-6 (-301)) |noBranch|) (IF (|has| |t#1| (-6 -4520)) (-6 -4520) |noBranch|) (IF (|has| |t#1| (-6 -4517)) (-6 -4517) |noBranch|) (IF (|has| |t#1| (-365)) (-6 (-365)) |noBranch|) (IF (|has| |t#1| (-609 (-541))) (-6 (-609 (-541))) |noBranch|) (IF (|has| |t#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |t#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |t#1| (-1021)) (PROGN (-6 (-609 (-169 (-215)))) (-6 (-609 (-169 (-381))))) |noBranch|) (IF (|has| |t#1| (-1056)) (-15 -2811 ($ $)) |noBranch|) (IF (|has| |t#1| (-1181)) (PROGN (-6 (-1181)) (-15 -2014 (|t#1| $)) (IF (|has| |t#1| (-1002)) (-6 (-1002)) |noBranch|) (IF (|has| |t#1| (-1056)) (-15 -1432 ((-2 (|:| |r| |t#1|) (|:| |phi| |t#1|)) $)) |noBranch|)) |noBranch|) (IF (|has| |t#1| (-550)) (PROGN (-15 -1338 ((-121) $)) (-15 -2394 ((-409 (-568)) $)) (-15 -3254 ((-3 (-409 (-568)) "failed") $))) |noBranch|) (IF (|has| |t#1| (-904)) (IF (|has| |t#1| (-301)) (-6 (-904)) |noBranch|) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) -2199 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-43 |#1|) . T) ((-43 $) -2199 (|has| |#1| (-558)) (|has| |#1| (-350)) (|has| |#1| (-365)) (|has| |#1| (-301))) ((-40) |has| |#1| (-1181)) ((-98) |has| |#1| (-1181)) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) -2199 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-120 |#1| |#1|) . T) ((-120 $ $) . T) ((-137) . T) ((-148) -2199 (|has| |#1| (-350)) (|has| |#1| (-148))) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) . T) ((-609 (-169 (-215))) |has| |#1| (-1021)) ((-609 (-169 (-381))) |has| |#1| (-1021)) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-609 (-887 (-381))) |has| |#1| (-609 (-887 (-381)))) ((-609 (-887 (-568))) |has| |#1| (-609 (-887 (-568)))) ((-609 (-1157 |#1|)) . T) ((-223 |#1|) . T) ((-225) -2199 (|has| |#1| (-350)) (|has| |#1| (-225))) ((-238) -2199 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-279) |has| |#1| (-1181)) ((-281 |#1| $) |has| |#1| (-281 |#1| |#1|)) ((-285) -2199 (|has| |#1| (-558)) (|has| |#1| (-350)) (|has| |#1| (-365)) (|has| |#1| (-301))) ((-301) -2199 (|has| |#1| (-350)) (|has| |#1| (-365)) (|has| |#1| (-301))) ((-303 |#1|) |has| |#1| (-303 |#1|)) ((-365) -2199 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-404) |has| |#1| (-350)) ((-370) -2199 (|has| |#1| (-370)) (|has| |#1| (-350))) ((-350) |has| |#1| (-350)) ((-372 |#1| (-1157 |#1|)) . T) ((-411 |#1| (-1157 |#1|)) . T) ((-336 |#1|) . T) ((-379 |#1|) . T) ((-402 |#1|) . T) ((-413 |#1|) . T) ((-453) -2199 (|has| |#1| (-350)) (|has| |#1| (-365)) (|has| |#1| (-301))) ((-502) |has| |#1| (-1181)) ((-523 (-1161) |#1|) |has| |#1| (-523 (-1161) |#1|)) ((-523 |#1| |#1|) |has| |#1| (-303 |#1|)) ((-558) -2199 (|has| |#1| (-558)) (|has| |#1| (-350)) (|has| |#1| (-365)) (|has| |#1| (-301))) ((-637 (-409 (-568))) -2199 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-637 |#1|) . T) ((-637 $) . T) ((-630 (-568)) |has| |#1| (-630 (-568))) ((-630 |#1|) . T) ((-707 (-409 (-568))) -2199 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-707 |#1|) . T) ((-707 $) -2199 (|has| |#1| (-558)) (|has| |#1| (-350)) (|has| |#1| (-365)) (|has| |#1| (-301))) ((-714 |#1| (-1157 |#1|)) . T) ((-716) . T) ((-842) |has| |#1| (-842)) ((-895 (-1161)) |has| |#1| (-895 (-1161))) ((-881 (-381)) |has| |#1| (-881 (-381))) ((-881 (-568)) |has| |#1| (-881 (-568))) ((-879 |#1|) . T) ((-904) -12 (|has| |#1| (-301)) (|has| |#1| (-904))) ((-916) -2199 (|has| |#1| (-350)) (|has| |#1| (-365)) (|has| |#1| (-301))) ((-1002) -12 (|has| |#1| (-1002)) (|has| |#1| (-1181))) ((-1037 (-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 |#1|) . T) ((-1053 (-409 (-568))) -2199 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-1053 |#1|) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1136) |has| |#1| (-350)) ((-1181) |has| |#1| (-1181)) ((-1184) |has| |#1| (-1181)) ((-1195) . T) ((-1199) -2199 (|has| |#1| (-350)) (|has| |#1| (-365)) (-12 (|has| |#1| (-301)) (|has| |#1| (-904))))) 
+((-3850 (((-420 |#2|) |#2|) 63))) 
+(((-167 |#1| |#2|) (-10 -7 (-15 -3850 ((-420 |#2|) |#2|))) (-301) (-1219 (-169 |#1|))) (T -167)) 
+((-3850 (*1 *2 *3) (-12 (-4 *4 (-301)) (-5 *2 (-420 *3)) (-5 *1 (-167 *4 *3)) (-4 *3 (-1219 (-169 *4)))))) 
+(-10 -7 (-15 -3850 ((-420 |#2|) |#2|))) 
+((-2797 (((-169 |#2|) (-1 |#2| |#1|) (-169 |#1|)) 14))) 
+(((-168 |#1| |#2|) (-10 -7 (-15 -2797 ((-169 |#2|) (-1 |#2| |#1|) (-169 |#1|)))) (-172) (-172)) (T -168)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-169 *5)) (-4 *5 (-172)) (-4 *6 (-172)) (-5 *2 (-169 *6)) (-5 *1 (-168 *5 *6))))) 
+(-10 -7 (-15 -2797 ((-169 |#2|) (-1 |#2| |#1|) (-169 |#1|)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 33)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (-2199 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-558))))) (-3661 (($ $) NIL (-2199 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-558))))) (-4426 (((-121) $) NIL (-2199 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-558))))) (-2883 (((-679 |#1|) (-1244 $)) NIL) (((-679 |#1|)) NIL)) (-1934 ((|#1| $) NIL)) (-1984 (($ $) NIL (|has| |#1| (-1181)))) (-1935 (($ $) NIL (|has| |#1| (-1181)))) (-1856 (((-1169 (-917) (-763)) (-568)) NIL (|has| |#1| (-350)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| |#1| (-301)) (|has| |#1| (-904))))) (-3045 (($ $) NIL (-2199 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-365))))) (-3498 (((-420 $) $) NIL (-2199 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-365))))) (-1904 (($ $) NIL (-12 (|has| |#1| (-1002)) (|has| |#1| (-1181))))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (-12 (|has| |#1| (-301)) (|has| |#1| (-904))))) (-2589 (((-121) $ $) NIL (|has| |#1| (-301)))) (-3986 (((-763)) NIL (|has| |#1| (-370)))) (-1976 (($ $) NIL (|has| |#1| (-1181)))) (-2788 (($ $) NIL (|has| |#1| (-1181)))) (-1992 (($ $) NIL (|has| |#1| (-1181)))) (-1943 (($ $) NIL (|has| |#1| (-1181)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) NIL)) (-2857 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) NIL)) (-3899 (($ (-1244 |#1|) (-1244 $)) NIL) (($ (-1244 |#1|)) NIL)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| |#1| (-350)))) (-2403 (($ $ $) NIL (|has| |#1| (-301)))) (-3653 (((-679 |#1|) $ (-1244 $)) NIL) (((-679 |#1|) $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-3094 (($ (-1157 |#1|)) NIL) (((-3 $ "failed") (-409 (-1157 |#1|))) NIL (|has| |#1| (-365)))) (-2902 (((-3 $ "failed") $) NIL)) (-3859 ((|#1| $) 13)) (-3254 (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-550)))) (-1338 (((-121) $) NIL (|has| |#1| (-550)))) (-2394 (((-409 (-568)) $) NIL (|has| |#1| (-550)))) (-2371 (((-917)) NIL)) (-1733 (($) NIL (|has| |#1| (-370)))) (-2414 (($ $ $) NIL (|has| |#1| (-301)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| |#1| (-301)))) (-4188 (($) NIL (|has| |#1| (-350)))) (-1748 (((-121) $) NIL (|has| |#1| (-350)))) (-1887 (($ $ (-763)) NIL (|has| |#1| (-350))) (($ $) NIL (|has| |#1| (-350)))) (-2197 (((-121) $) NIL (-2199 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-365))))) (-1432 (((-2 (|:| |r| |#1|) (|:| |phi| |#1|)) $) NIL (-12 (|has| |#1| (-1056)) (|has| |#1| (-1181))))) (-1899 (($) NIL (|has| |#1| (-1181)))) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| |#1| (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| |#1| (-881 (-381))))) (-1844 (((-917) $) NIL (|has| |#1| (-350))) (((-828 (-917)) $) NIL (|has| |#1| (-350)))) (-1598 (((-121) $) 35)) (-1550 (($ $ (-568)) NIL (-12 (|has| |#1| (-1002)) (|has| |#1| (-1181))))) (-4417 ((|#1| $) 46)) (-2214 (((-3 $ "failed") $) NIL (|has| |#1| (-350)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-301)))) (-1497 (((-1157 |#1|) $) NIL (|has| |#1| (-365)))) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-2291 (((-917) $) NIL (|has| |#1| (-370)))) (-4418 (($ $) NIL (|has| |#1| (-1181)))) (-3087 (((-1157 |#1|) $) NIL)) (-2498 (($ (-634 $)) NIL (|has| |#1| (-301))) (($ $ $) NIL (|has| |#1| (-301)))) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL (|has| |#1| (-365)))) (-4436 (($) NIL (|has| |#1| (-350)) CONST)) (-4357 (($ (-917)) NIL (|has| |#1| (-370)))) (-2719 (($) NIL)) (-3868 ((|#1| $) 15)) (-4025 (((-1108) $) NIL)) (-2707 (($) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-301)))) (-2723 (($ (-634 $)) NIL (|has| |#1| (-301))) (($ $ $) NIL (|has| |#1| (-301)))) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) NIL (|has| |#1| (-350)))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| |#1| (-301)) (|has| |#1| (-904))))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| |#1| (-301)) (|has| |#1| (-904))))) (-3850 (((-420 $) $) NIL (-2199 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-365))))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-301))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-301)))) (-2597 (((-3 $ "failed") $ |#1|) 44 (|has| |#1| (-558))) (((-3 $ "failed") $ $) 47 (-2199 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-558))))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-301)))) (-1894 (($ $) NIL (|has| |#1| (-1181)))) (-1339 (($ $ (-634 |#1|) (-634 |#1|)) NIL (|has| |#1| (-303 |#1|))) (($ $ |#1| |#1|) NIL (|has| |#1| (-303 |#1|))) (($ $ (-288 |#1|)) NIL (|has| |#1| (-303 |#1|))) (($ $ (-634 (-288 |#1|))) NIL (|has| |#1| (-303 |#1|))) (($ $ (-634 (-1161)) (-634 |#1|)) NIL (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-1161) |#1|) NIL (|has| |#1| (-523 (-1161) |#1|)))) (-1466 (((-763) $) NIL (|has| |#1| (-301)))) (-2781 (($ $ |#1|) NIL (|has| |#1| (-281 |#1| |#1|)))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-301)))) (-3440 ((|#1| (-1244 $)) NIL) ((|#1|) NIL)) (-2721 (((-763) $) NIL (|has| |#1| (-350))) (((-3 (-763) "failed") $ $) NIL (|has| |#1| (-350)))) (-4191 (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $) NIL (|has| |#1| (-225)))) (-1391 (((-679 |#1|) (-1244 $) (-1 |#1| |#1|)) NIL (|has| |#1| (-365)))) (-1492 (((-1157 |#1|)) NIL)) (-1996 (($ $) NIL (|has| |#1| (-1181)))) (-1947 (($ $) NIL (|has| |#1| (-1181)))) (-2330 (($) NIL (|has| |#1| (-350)))) (-1988 (($ $) NIL (|has| |#1| (-1181)))) (-1939 (($ $) NIL (|has| |#1| (-1181)))) (-1980 (($ $) NIL (|has| |#1| (-1181)))) (-2792 (($ $) NIL (|has| |#1| (-1181)))) (-1656 (((-1244 |#1|) $ (-1244 $)) NIL) (((-679 |#1|) (-1244 $) (-1244 $)) NIL) (((-1244 |#1|) $) NIL) (((-679 |#1|) (-1244 $)) NIL)) (-4280 (((-1244 |#1|) $) NIL) (($ (-1244 |#1|)) NIL) (((-1157 |#1|) $) NIL) (($ (-1157 |#1|)) NIL) (((-887 (-568)) $) NIL (|has| |#1| (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| |#1| (-609 (-887 (-381))))) (((-169 (-381)) $) NIL (|has| |#1| (-1021))) (((-169 (-215)) $) NIL (|has| |#1| (-1021))) (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-2387 (($ $) 45)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-2199 (-12 (|has| $ (-148)) (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-350))))) (-4005 (($ |#1| |#1|) 37)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) 36) (($ (-409 (-568))) NIL (-2199 (|has| |#1| (-365)) (|has| |#1| (-1037 (-409 (-568)))))) (($ $) NIL (-2199 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-558))))) (-3385 (($ $) NIL (|has| |#1| (-350))) (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-1295 (((-1157 |#1|) $) NIL)) (-3425 (((-763)) NIL)) (-2588 (((-1244 $)) NIL)) (-2008 (($ $) NIL (|has| |#1| (-1181)))) (-1959 (($ $) NIL (|has| |#1| (-1181)))) (-2273 (((-121) $ $) NIL (-2199 (-12 (|has| |#1| (-301)) (|has| |#1| (-904))) (|has| |#1| (-558))))) (-2000 (($ $) NIL (|has| |#1| (-1181)))) (-1951 (($ $) NIL (|has| |#1| (-1181)))) (-2016 (($ $) NIL (|has| |#1| (-1181)))) (-1968 (($ $) NIL (|has| |#1| (-1181)))) (-2014 ((|#1| $) NIL (|has| |#1| (-1181)))) (-1439 (($ $) NIL (|has| |#1| (-1181)))) (-1972 (($ $) NIL (|has| |#1| (-1181)))) (-2012 (($ $) NIL (|has| |#1| (-1181)))) (-1964 (($ $) NIL (|has| |#1| (-1181)))) (-2004 (($ $) NIL (|has| |#1| (-1181)))) (-1955 (($ $) NIL (|has| |#1| (-1181)))) (-2811 (($ $) NIL (|has| |#1| (-1056)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (-3058 (($) 28 T CONST)) (-1557 (($) 30 T CONST)) (-2628 (((-1143) $) 23 (|has| |#1| (-823))) (((-1143) $ (-121)) 25 (|has| |#1| (-823))) (((-1249) (-817) $) 26 (|has| |#1| (-823))) (((-1249) (-817) $ (-121)) 27 (|has| |#1| (-823)))) (-3192 (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $) NIL (|has| |#1| (-225)))) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1781 (($ $ $) NIL (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) 39)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-409 (-568))) NIL (-12 (|has| |#1| (-1002)) (|has| |#1| (-1181)))) (($ $ $) NIL (|has| |#1| (-1181))) (($ $ (-568)) NIL (|has| |#1| (-365)))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 42) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-409 (-568)) $) NIL (|has| |#1| (-365))) (($ $ (-409 (-568))) NIL (|has| |#1| (-365))))) 
 (((-169 |#1|) (-13 (-166 |#1|) (-10 -7 (IF (|has| |#1| (-823)) (-6 (-823)) |noBranch|))) (-172)) (T -169)) 
 NIL 
 (-13 (-166 |#1|) (-10 -7 (IF (|has| |#1| (-823)) (-6 (-823)) |noBranch|))) 
-((-4278 (((-887 |#1|) |#3|) 22))) 
-(((-170 |#1| |#2| |#3|) (-10 -7 (-15 -4278 ((-887 |#1|) |#3|))) (-1090) (-13 (-609 (-887 |#1|)) (-172)) (-166 |#2|)) (T -170)) 
-((-4278 (*1 *2 *3) (-12 (-4 *5 (-13 (-609 *2) (-172))) (-5 *2 (-887 *4)) (-5 *1 (-170 *4 *5 *3)) (-4 *4 (-1090)) (-4 *3 (-166 *5))))) 
-(-10 -7 (-15 -4278 ((-887 |#1|) |#3|))) 
-((-2447 (((-121) $ $) NIL)) (-1459 (((-121) $) 9)) (-2289 (((-121) $ (-121)) 11)) (-1849 (($) 12)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-3863 (($ $) 13)) (-2745 (((-850) $) 17)) (-3336 (((-121) $) 8)) (-4092 (((-121) $ (-121)) 10)) (-1717 (((-121) $ $) NIL))) 
-(((-171) (-13 (-1090) (-10 -8 (-15 -1849 ($)) (-15 -3336 ((-121) $)) (-15 -1459 ((-121) $)) (-15 -4092 ((-121) $ (-121))) (-15 -2289 ((-121) $ (-121))) (-15 -3863 ($ $))))) (T -171)) 
-((-1849 (*1 *1) (-5 *1 (-171))) (-3336 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-171)))) (-1459 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-171)))) (-4092 (*1 *2 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-171)))) (-2289 (*1 *2 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-171)))) (-3863 (*1 *1 *1) (-5 *1 (-171)))) 
-(-13 (-1090) (-10 -8 (-15 -1849 ($)) (-15 -3336 ((-121) $)) (-15 -1459 ((-121) $)) (-15 -4092 ((-121) $ (-121))) (-15 -2289 ((-121) $ (-121))) (-15 -3863 ($ $)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-2925 (((-3 $ "failed") $) 33)) (-2735 (((-121) $) 30)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11) (($ (-568)) 27)) (-4078 (((-763)) 28)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
+((-4280 (((-887 |#1|) |#3|) 22))) 
+(((-170 |#1| |#2| |#3|) (-10 -7 (-15 -4280 ((-887 |#1|) |#3|))) (-1090) (-13 (-609 (-887 |#1|)) (-172)) (-166 |#2|)) (T -170)) 
+((-4280 (*1 *2 *3) (-12 (-4 *5 (-13 (-609 *2) (-172))) (-5 *2 (-887 *4)) (-5 *1 (-170 *4 *5 *3)) (-4 *4 (-1090)) (-4 *3 (-166 *5))))) 
+(-10 -7 (-15 -4280 ((-887 |#1|) |#3|))) 
+((-2449 (((-121) $ $) NIL)) (-2392 (((-121) $) 9)) (-3548 (((-121) $ (-121)) 11)) (-1851 (($) 12)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-3865 (($ $) 13)) (-2747 (((-850) $) 17)) (-4429 (((-121) $) 8)) (-4094 (((-121) $ (-121)) 10)) (-1719 (((-121) $ $) NIL))) 
+(((-171) (-13 (-1090) (-10 -8 (-15 -1851 ($)) (-15 -4429 ((-121) $)) (-15 -2392 ((-121) $)) (-15 -4094 ((-121) $ (-121))) (-15 -3548 ((-121) $ (-121))) (-15 -3865 ($ $))))) (T -171)) 
+((-1851 (*1 *1) (-5 *1 (-171))) (-4429 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-171)))) (-2392 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-171)))) (-4094 (*1 *2 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-171)))) (-3548 (*1 *2 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-171)))) (-3865 (*1 *1 *1) (-5 *1 (-171)))) 
+(-13 (-1090) (-10 -8 (-15 -1851 ($)) (-15 -4429 ((-121) $)) (-15 -2392 ((-121) $)) (-15 -4094 ((-121) $ (-121))) (-15 -3548 ((-121) $ (-121))) (-15 -3865 ($ $)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-2902 (((-3 $ "failed") $) 33)) (-1598 (((-121) $) 30)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11) (($ (-568)) 27)) (-3425 (((-763)) 28)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
 (((-172) (-1275)) (T -172)) 
 NIL 
-(-13 (-1047) (-120 $ $) (-10 -7 (-6 (-4521 "*")))) 
+(-13 (-1047) (-120 $ $) (-10 -7 (-6 (-4523 "*")))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 $ $) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 $) . T) ((-716) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-1492 ((|#1| $) 74)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1497 (((-121) $ $) NIL)) (-2671 (($) NIL T CONST)) (-2401 (($ $ $) NIL)) (-1331 (($ $) 19)) (-2983 (($ |#1| (-1141 |#1|)) 47)) (-2925 (((-3 $ "failed") $) 116)) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-3922 (((-1141 |#1|) $) 81)) (-1947 (((-1141 |#1|) $) 78)) (-2874 (((-1141 |#1|) $) 79)) (-2735 (((-121) $) NIL)) (-4423 (((-1141 |#1|) $) 87)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2495 (($ (-634 $)) NIL) (($ $ $) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ (-634 $)) NIL) (($ $ $) NIL)) (-3848 (((-420 $) $) NIL)) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL)) (-1807 (($ $ (-568)) 90)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3434 (((-1141 |#1|) $) 88)) (-1667 (((-1141 (-409 |#1|)) $) 13)) (-3878 (($ (-409 |#1|)) 17) (($ |#1| (-1141 |#1|) (-1141 |#1|)) 37)) (-1811 (($ $) 92)) (-2745 (((-850) $) 126) (($ (-568)) 50) (($ |#1|) 51) (($ (-409 |#1|)) 35) (($ (-409 (-568))) NIL) (($ $) NIL)) (-4078 (((-763)) 63)) (-1826 (((-121) $ $) NIL)) (-4442 (((-1141 (-409 |#1|)) $) 18)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) 25 T CONST)) (-1556 (($) 28 T CONST)) (-1717 (((-121) $ $) 34)) (-1779 (($ $ $) 114)) (-1773 (($ $) 105) (($ $ $) 102)) (-1767 (($ $ $) 100)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 112) (($ $ $) 107) (($ $ |#1|) NIL) (($ |#1| $) 109) (($ (-409 |#1|) $) 110) (($ $ (-409 |#1|)) NIL) (($ (-409 (-568)) $) NIL) (($ $ (-409 (-568))) NIL))) 
-(((-173 |#1|) (-13 (-43 |#1|) (-43 (-409 |#1|)) (-365) (-10 -8 (-15 -3878 ($ (-409 |#1|))) (-15 -3878 ($ |#1| (-1141 |#1|) (-1141 |#1|))) (-15 -2983 ($ |#1| (-1141 |#1|))) (-15 -1947 ((-1141 |#1|) $)) (-15 -2874 ((-1141 |#1|) $)) (-15 -3922 ((-1141 |#1|) $)) (-15 -1492 (|#1| $)) (-15 -1331 ($ $)) (-15 -4442 ((-1141 (-409 |#1|)) $)) (-15 -1667 ((-1141 (-409 |#1|)) $)) (-15 -4423 ((-1141 |#1|) $)) (-15 -3434 ((-1141 |#1|) $)) (-15 -1807 ($ $ (-568))) (-15 -1811 ($ $)))) (-301)) (T -173)) 
-((-3878 (*1 *1 *2) (-12 (-5 *2 (-409 *3)) (-4 *3 (-301)) (-5 *1 (-173 *3)))) (-3878 (*1 *1 *2 *3 *3) (-12 (-5 *3 (-1141 *2)) (-4 *2 (-301)) (-5 *1 (-173 *2)))) (-2983 (*1 *1 *2 *3) (-12 (-5 *3 (-1141 *2)) (-4 *2 (-301)) (-5 *1 (-173 *2)))) (-1947 (*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-173 *3)) (-4 *3 (-301)))) (-2874 (*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-173 *3)) (-4 *3 (-301)))) (-3922 (*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-173 *3)) (-4 *3 (-301)))) (-1492 (*1 *2 *1) (-12 (-5 *1 (-173 *2)) (-4 *2 (-301)))) (-1331 (*1 *1 *1) (-12 (-5 *1 (-173 *2)) (-4 *2 (-301)))) (-4442 (*1 *2 *1) (-12 (-5 *2 (-1141 (-409 *3))) (-5 *1 (-173 *3)) (-4 *3 (-301)))) (-1667 (*1 *2 *1) (-12 (-5 *2 (-1141 (-409 *3))) (-5 *1 (-173 *3)) (-4 *3 (-301)))) (-4423 (*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-173 *3)) (-4 *3 (-301)))) (-3434 (*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-173 *3)) (-4 *3 (-301)))) (-1807 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-173 *3)) (-4 *3 (-301)))) (-1811 (*1 *1 *1) (-12 (-5 *1 (-173 *2)) (-4 *2 (-301))))) 
-(-13 (-43 |#1|) (-43 (-409 |#1|)) (-365) (-10 -8 (-15 -3878 ($ (-409 |#1|))) (-15 -3878 ($ |#1| (-1141 |#1|) (-1141 |#1|))) (-15 -2983 ($ |#1| (-1141 |#1|))) (-15 -1947 ((-1141 |#1|) $)) (-15 -2874 ((-1141 |#1|) $)) (-15 -3922 ((-1141 |#1|) $)) (-15 -1492 (|#1| $)) (-15 -1331 ($ $)) (-15 -4442 ((-1141 (-409 |#1|)) $)) (-15 -1667 ((-1141 (-409 |#1|)) $)) (-15 -4423 ((-1141 |#1|) $)) (-15 -3434 ((-1141 |#1|) $)) (-15 -1807 ($ $ (-568))) (-15 -1811 ($ $)))) 
-((-2325 (((-1 (-944 |#1|) (-944 |#1|)) |#1|) 40)) (-3274 (((-944 |#1|) (-944 |#1|)) 19)) (-2393 (((-1 (-944 |#1|) (-944 |#1|)) |#1|) 36)) (-2007 (((-944 |#1|) (-944 |#1|)) 17)) (-2562 (((-944 |#1|) (-944 |#1|)) 25)) (-4261 (((-944 |#1|) (-944 |#1|)) 24)) (-4413 (((-944 |#1|) (-944 |#1|)) 23)) (-4205 (((-1 (-944 |#1|) (-944 |#1|)) |#1|) 37)) (-1529 (((-1 (-944 |#1|) (-944 |#1|)) |#1|) 35)) (-3633 (((-1 (-944 |#1|) (-944 |#1|)) |#1|) 34)) (-2428 (((-944 |#1|) (-944 |#1|)) 18)) (-3625 (((-1 (-944 |#1|) (-944 |#1|)) |#1| |#1|) 43)) (-1541 (((-944 |#1|) (-944 |#1|)) 8)) (-2863 (((-1 (-944 |#1|) (-944 |#1|)) |#1|) 39)) (-4018 (((-1 (-944 |#1|) (-944 |#1|)) |#1|) 38))) 
-(((-174 |#1|) (-10 -7 (-15 -1541 ((-944 |#1|) (-944 |#1|))) (-15 -2007 ((-944 |#1|) (-944 |#1|))) (-15 -2428 ((-944 |#1|) (-944 |#1|))) (-15 -3274 ((-944 |#1|) (-944 |#1|))) (-15 -4413 ((-944 |#1|) (-944 |#1|))) (-15 -4261 ((-944 |#1|) (-944 |#1|))) (-15 -2562 ((-944 |#1|) (-944 |#1|))) (-15 -3633 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -1529 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -2393 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -4205 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -4018 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -2863 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -2325 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -3625 ((-1 (-944 |#1|) (-944 |#1|)) |#1| |#1|))) (-13 (-365) (-1181) (-1002))) (T -174)) 
-((-3625 (*1 *2 *3 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))))) (-2325 (*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))))) (-2863 (*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))))) (-4018 (*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))))) (-4205 (*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))))) (-2393 (*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))))) (-1529 (*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))))) (-3633 (*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))))) (-2562 (*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3)))) (-4261 (*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3)))) (-4413 (*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3)))) (-3274 (*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3)))) (-2428 (*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3)))) (-2007 (*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3)))) (-1541 (*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3))))) 
-(-10 -7 (-15 -1541 ((-944 |#1|) (-944 |#1|))) (-15 -2007 ((-944 |#1|) (-944 |#1|))) (-15 -2428 ((-944 |#1|) (-944 |#1|))) (-15 -3274 ((-944 |#1|) (-944 |#1|))) (-15 -4413 ((-944 |#1|) (-944 |#1|))) (-15 -4261 ((-944 |#1|) (-944 |#1|))) (-15 -2562 ((-944 |#1|) (-944 |#1|))) (-15 -3633 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -1529 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -2393 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -4205 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -4018 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -2863 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -2325 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -3625 ((-1 (-944 |#1|) (-944 |#1|)) |#1| |#1|))) 
-((-2678 ((|#2| |#3|) 27))) 
-(((-175 |#1| |#2| |#3|) (-10 -7 (-15 -2678 (|#2| |#3|))) (-172) (-1219 |#1|) (-714 |#1| |#2|)) (T -175)) 
-((-2678 (*1 *2 *3) (-12 (-4 *4 (-172)) (-4 *2 (-1219 *4)) (-5 *1 (-175 *4 *2 *3)) (-4 *3 (-714 *4 *2))))) 
-(-10 -7 (-15 -2678 (|#2| |#3|))) 
-((-4410 (((-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|)) 47 (|has| (-953 |#2|) (-881 |#1|))))) 
-(((-176 |#1| |#2| |#3|) (-10 -7 (IF (|has| (-953 |#2|) (-881 |#1|)) (-15 -4410 ((-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|))) |noBranch|)) (-1090) (-13 (-881 |#1|) (-172)) (-166 |#2|)) (T -176)) 
-((-4410 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *3)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-4 *3 (-166 *6)) (-4 (-953 *6) (-881 *5)) (-4 *6 (-13 (-881 *5) (-172))) (-5 *1 (-176 *5 *6 *3))))) 
-(-10 -7 (IF (|has| (-953 |#2|) (-881 |#1|)) (-15 -4410 ((-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|))) |noBranch|)) 
-((-1649 (((-634 |#1|) (-634 |#1|) |#1|) 36)) (-2504 (((-634 |#1|) |#1| (-634 |#1|)) 19)) (-2769 (((-634 |#1|) (-634 (-634 |#1|)) (-634 |#1|)) 31) ((|#1| (-634 |#1|) (-634 |#1|)) 29))) 
-(((-177 |#1|) (-10 -7 (-15 -2504 ((-634 |#1|) |#1| (-634 |#1|))) (-15 -2769 (|#1| (-634 |#1|) (-634 |#1|))) (-15 -2769 ((-634 |#1|) (-634 (-634 |#1|)) (-634 |#1|))) (-15 -1649 ((-634 |#1|) (-634 |#1|) |#1|))) (-301)) (T -177)) 
-((-1649 (*1 *2 *2 *3) (-12 (-5 *2 (-634 *3)) (-4 *3 (-301)) (-5 *1 (-177 *3)))) (-2769 (*1 *2 *3 *2) (-12 (-5 *3 (-634 (-634 *4))) (-5 *2 (-634 *4)) (-4 *4 (-301)) (-5 *1 (-177 *4)))) (-2769 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *2)) (-5 *1 (-177 *2)) (-4 *2 (-301)))) (-2504 (*1 *2 *3 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-301)) (-5 *1 (-177 *3))))) 
-(-10 -7 (-15 -2504 ((-634 |#1|) |#1| (-634 |#1|))) (-15 -2769 (|#1| (-634 |#1|) (-634 |#1|))) (-15 -2769 ((-634 |#1|) (-634 (-634 |#1|)) (-634 |#1|))) (-15 -1649 ((-634 |#1|) (-634 |#1|) |#1|))) 
-((-2506 (((-2 (|:| |start| |#2|) (|:| -3276 (-420 |#2|))) |#2|) 61)) (-3664 ((|#1| |#1|) 54)) (-3698 (((-169 |#1|) |#2|) 82)) (-1533 ((|#1| |#2|) 122) ((|#1| |#2| |#1|) 80)) (-3618 ((|#2| |#2|) 81)) (-3245 (((-420 |#2|) |#2| |#1|) 112) (((-420 |#2|) |#2| |#1| (-121)) 79)) (-2657 ((|#1| |#2|) 111)) (-2622 ((|#2| |#2|) 118)) (-3848 (((-420 |#2|) |#2|) 133) (((-420 |#2|) |#2| |#1|) 32) (((-420 |#2|) |#2| |#1| (-121)) 132)) (-3451 (((-634 (-2 (|:| -3276 (-634 |#2|)) (|:| -2183 |#1|))) |#2| |#2|) 131) (((-634 (-2 (|:| -3276 (-634 |#2|)) (|:| -2183 |#1|))) |#2| |#2| (-121)) 75)) (-2385 (((-634 (-169 |#1|)) |#2| |#1|) 40) (((-634 (-169 |#1|)) |#2|) 41))) 
-(((-178 |#1| |#2|) (-10 -7 (-15 -2385 ((-634 (-169 |#1|)) |#2|)) (-15 -2385 ((-634 (-169 |#1|)) |#2| |#1|)) (-15 -3451 ((-634 (-2 (|:| -3276 (-634 |#2|)) (|:| -2183 |#1|))) |#2| |#2| (-121))) (-15 -3451 ((-634 (-2 (|:| -3276 (-634 |#2|)) (|:| -2183 |#1|))) |#2| |#2|)) (-15 -3848 ((-420 |#2|) |#2| |#1| (-121))) (-15 -3848 ((-420 |#2|) |#2| |#1|)) (-15 -3848 ((-420 |#2|) |#2|)) (-15 -2622 (|#2| |#2|)) (-15 -2657 (|#1| |#2|)) (-15 -3245 ((-420 |#2|) |#2| |#1| (-121))) (-15 -3245 ((-420 |#2|) |#2| |#1|)) (-15 -3618 (|#2| |#2|)) (-15 -1533 (|#1| |#2| |#1|)) (-15 -1533 (|#1| |#2|)) (-15 -3698 ((-169 |#1|) |#2|)) (-15 -3664 (|#1| |#1|)) (-15 -2506 ((-2 (|:| |start| |#2|) (|:| -3276 (-420 |#2|))) |#2|))) (-13 (-365) (-840)) (-1219 (-169 |#1|))) (T -178)) 
-((-2506 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-2 (|:| |start| *3) (|:| -3276 (-420 *3)))) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) (-3664 (*1 *2 *2) (-12 (-4 *2 (-13 (-365) (-840))) (-5 *1 (-178 *2 *3)) (-4 *3 (-1219 (-169 *2))))) (-3698 (*1 *2 *3) (-12 (-5 *2 (-169 *4)) (-5 *1 (-178 *4 *3)) (-4 *4 (-13 (-365) (-840))) (-4 *3 (-1219 *2)))) (-1533 (*1 *2 *3) (-12 (-4 *2 (-13 (-365) (-840))) (-5 *1 (-178 *2 *3)) (-4 *3 (-1219 (-169 *2))))) (-1533 (*1 *2 *3 *2) (-12 (-4 *2 (-13 (-365) (-840))) (-5 *1 (-178 *2 *3)) (-4 *3 (-1219 (-169 *2))))) (-3618 (*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-840))) (-5 *1 (-178 *3 *2)) (-4 *2 (-1219 (-169 *3))))) (-3245 (*1 *2 *3 *4) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-420 *3)) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) (-3245 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-121)) (-4 *4 (-13 (-365) (-840))) (-5 *2 (-420 *3)) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) (-2657 (*1 *2 *3) (-12 (-4 *2 (-13 (-365) (-840))) (-5 *1 (-178 *2 *3)) (-4 *3 (-1219 (-169 *2))))) (-2622 (*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-840))) (-5 *1 (-178 *3 *2)) (-4 *2 (-1219 (-169 *3))))) (-3848 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-420 *3)) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) (-3848 (*1 *2 *3 *4) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-420 *3)) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) (-3848 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-121)) (-4 *4 (-13 (-365) (-840))) (-5 *2 (-420 *3)) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) (-3451 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-634 (-2 (|:| -3276 (-634 *3)) (|:| -2183 *4)))) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) (-3451 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-365) (-840))) (-5 *2 (-634 (-2 (|:| -3276 (-634 *3)) (|:| -2183 *5)))) (-5 *1 (-178 *5 *3)) (-4 *3 (-1219 (-169 *5))))) (-2385 (*1 *2 *3 *4) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-634 (-169 *4))) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) (-2385 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-634 (-169 *4))) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4)))))) 
-(-10 -7 (-15 -2385 ((-634 (-169 |#1|)) |#2|)) (-15 -2385 ((-634 (-169 |#1|)) |#2| |#1|)) (-15 -3451 ((-634 (-2 (|:| -3276 (-634 |#2|)) (|:| -2183 |#1|))) |#2| |#2| (-121))) (-15 -3451 ((-634 (-2 (|:| -3276 (-634 |#2|)) (|:| -2183 |#1|))) |#2| |#2|)) (-15 -3848 ((-420 |#2|) |#2| |#1| (-121))) (-15 -3848 ((-420 |#2|) |#2| |#1|)) (-15 -3848 ((-420 |#2|) |#2|)) (-15 -2622 (|#2| |#2|)) (-15 -2657 (|#1| |#2|)) (-15 -3245 ((-420 |#2|) |#2| |#1| (-121))) (-15 -3245 ((-420 |#2|) |#2| |#1|)) (-15 -3618 (|#2| |#2|)) (-15 -1533 (|#1| |#2| |#1|)) (-15 -1533 (|#1| |#2|)) (-15 -3698 ((-169 |#1|) |#2|)) (-15 -3664 (|#1| |#1|)) (-15 -2506 ((-2 (|:| |start| |#2|) (|:| -3276 (-420 |#2|))) |#2|))) 
-((-2182 (((-3 |#2| "failed") |#2|) 14)) (-1576 (((-763) |#2|) 16)) (-3786 ((|#2| |#2| |#2|) 18))) 
-(((-179 |#1| |#2|) (-10 -7 (-15 -2182 ((-3 |#2| "failed") |#2|)) (-15 -1576 ((-763) |#2|)) (-15 -3786 (|#2| |#2| |#2|))) (-1195) (-665 |#1|)) (T -179)) 
-((-3786 (*1 *2 *2 *2) (-12 (-4 *3 (-1195)) (-5 *1 (-179 *3 *2)) (-4 *2 (-665 *3)))) (-1576 (*1 *2 *3) (-12 (-4 *4 (-1195)) (-5 *2 (-763)) (-5 *1 (-179 *4 *3)) (-4 *3 (-665 *4)))) (-2182 (*1 *2 *2) (|partial| -12 (-4 *3 (-1195)) (-5 *1 (-179 *3 *2)) (-4 *2 (-665 *3))))) 
-(-10 -7 (-15 -2182 ((-3 |#2| "failed") |#2|)) (-15 -1576 ((-763) |#2|)) (-15 -3786 (|#2| |#2| |#2|))) 
-((-3755 ((|#2| |#2|) 28)) (-2636 (((-121) |#2|) 19)) (-3857 (((-310 |#1|) |#2|) 12)) (-3866 (((-310 |#1|) |#2|) 14)) (-2818 ((|#2| |#2| (-1161)) 68) ((|#2| |#2|) 69)) (-3145 (((-169 (-310 |#1|)) |#2|) 9)) (-2582 ((|#2| |#2| (-1161)) 65) ((|#2| |#2|) 58))) 
-(((-180 |#1| |#2|) (-10 -7 (-15 -2818 (|#2| |#2|)) (-15 -2818 (|#2| |#2| (-1161))) (-15 -2582 (|#2| |#2|)) (-15 -2582 (|#2| |#2| (-1161))) (-15 -3857 ((-310 |#1|) |#2|)) (-15 -3866 ((-310 |#1|) |#2|)) (-15 -2636 ((-121) |#2|)) (-15 -3755 (|#2| |#2|)) (-15 -3145 ((-169 (-310 |#1|)) |#2|))) (-13 (-558) (-842) (-1037 (-568))) (-13 (-27) (-1181) (-432 (-169 |#1|)))) (T -180)) 
-((-3145 (*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-169 (-310 *4))) (-5 *1 (-180 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 (-169 *4)))))) (-3755 (*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-842) (-1037 (-568)))) (-5 *1 (-180 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 (-169 *3)))))) (-2636 (*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-121)) (-5 *1 (-180 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 (-169 *4)))))) (-3866 (*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-310 *4)) (-5 *1 (-180 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 (-169 *4)))))) (-3857 (*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-310 *4)) (-5 *1 (-180 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 (-169 *4)))))) (-2582 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-5 *1 (-180 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 (-169 *4)))))) (-2582 (*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-842) (-1037 (-568)))) (-5 *1 (-180 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 (-169 *3)))))) (-2818 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-5 *1 (-180 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 (-169 *4)))))) (-2818 (*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-842) (-1037 (-568)))) (-5 *1 (-180 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 (-169 *3))))))) 
-(-10 -7 (-15 -2818 (|#2| |#2|)) (-15 -2818 (|#2| |#2| (-1161))) (-15 -2582 (|#2| |#2|)) (-15 -2582 (|#2| |#2| (-1161))) (-15 -3857 ((-310 |#1|) |#2|)) (-15 -3866 ((-310 |#1|) |#2|)) (-15 -2636 ((-121) |#2|)) (-15 -3755 (|#2| |#2|)) (-15 -3145 ((-169 (-310 |#1|)) |#2|))) 
-((-1852 (((-1244 (-679 (-953 |#1|))) (-1244 (-679 |#1|))) 22)) (-2745 (((-1244 (-679 (-409 (-953 |#1|)))) (-1244 (-679 |#1|))) 30))) 
-(((-181 |#1|) (-10 -7 (-15 -1852 ((-1244 (-679 (-953 |#1|))) (-1244 (-679 |#1|)))) (-15 -2745 ((-1244 (-679 (-409 (-953 |#1|)))) (-1244 (-679 |#1|))))) (-172)) (T -181)) 
-((-2745 (*1 *2 *3) (-12 (-5 *3 (-1244 (-679 *4))) (-4 *4 (-172)) (-5 *2 (-1244 (-679 (-409 (-953 *4))))) (-5 *1 (-181 *4)))) (-1852 (*1 *2 *3) (-12 (-5 *3 (-1244 (-679 *4))) (-4 *4 (-172)) (-5 *2 (-1244 (-679 (-953 *4)))) (-5 *1 (-181 *4))))) 
-(-10 -7 (-15 -1852 ((-1244 (-679 (-953 |#1|))) (-1244 (-679 |#1|)))) (-15 -2745 ((-1244 (-679 (-409 (-953 |#1|)))) (-1244 (-679 |#1|))))) 
-((-2881 (((-1163 (-409 (-568))) (-1163 (-409 (-568))) (-1163 (-409 (-568)))) 66)) (-1613 (((-1163 (-409 (-568))) (-634 (-568)) (-634 (-568))) 74)) (-3787 (((-1163 (-409 (-568))) (-568)) 40)) (-2978 (((-1163 (-409 (-568))) (-568)) 52)) (-1339 (((-409 (-568)) (-1163 (-409 (-568)))) 62)) (-1535 (((-1163 (-409 (-568))) (-568)) 32)) (-2131 (((-1163 (-409 (-568))) (-568)) 48)) (-2649 (((-1163 (-409 (-568))) (-568)) 46)) (-2326 (((-1163 (-409 (-568))) (-1163 (-409 (-568))) (-1163 (-409 (-568)))) 60)) (-1811 (((-1163 (-409 (-568))) (-568)) 25)) (-2752 (((-409 (-568)) (-1163 (-409 (-568))) (-1163 (-409 (-568)))) 64)) (-3542 (((-1163 (-409 (-568))) (-568)) 30)) (-3198 (((-1163 (-409 (-568))) (-634 (-568))) 71))) 
-(((-182) (-10 -7 (-15 -1811 ((-1163 (-409 (-568))) (-568))) (-15 -3787 ((-1163 (-409 (-568))) (-568))) (-15 -1535 ((-1163 (-409 (-568))) (-568))) (-15 -3542 ((-1163 (-409 (-568))) (-568))) (-15 -2649 ((-1163 (-409 (-568))) (-568))) (-15 -2131 ((-1163 (-409 (-568))) (-568))) (-15 -2978 ((-1163 (-409 (-568))) (-568))) (-15 -2752 ((-409 (-568)) (-1163 (-409 (-568))) (-1163 (-409 (-568))))) (-15 -2326 ((-1163 (-409 (-568))) (-1163 (-409 (-568))) (-1163 (-409 (-568))))) (-15 -1339 ((-409 (-568)) (-1163 (-409 (-568))))) (-15 -2881 ((-1163 (-409 (-568))) (-1163 (-409 (-568))) (-1163 (-409 (-568))))) (-15 -3198 ((-1163 (-409 (-568))) (-634 (-568)))) (-15 -1613 ((-1163 (-409 (-568))) (-634 (-568)) (-634 (-568)))))) (T -182)) 
-((-1613 (*1 *2 *3 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)))) (-3198 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)))) (-2881 (*1 *2 *2 *2) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)))) (-1339 (*1 *2 *3) (-12 (-5 *3 (-1163 (-409 (-568)))) (-5 *2 (-409 (-568))) (-5 *1 (-182)))) (-2326 (*1 *2 *2 *2) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)))) (-2752 (*1 *2 *3 *3) (-12 (-5 *3 (-1163 (-409 (-568)))) (-5 *2 (-409 (-568))) (-5 *1 (-182)))) (-2978 (*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568)))) (-2131 (*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568)))) (-2649 (*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568)))) (-3542 (*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568)))) (-1535 (*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568)))) (-3787 (*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568)))) (-1811 (*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568))))) 
-(-10 -7 (-15 -1811 ((-1163 (-409 (-568))) (-568))) (-15 -3787 ((-1163 (-409 (-568))) (-568))) (-15 -1535 ((-1163 (-409 (-568))) (-568))) (-15 -3542 ((-1163 (-409 (-568))) (-568))) (-15 -2649 ((-1163 (-409 (-568))) (-568))) (-15 -2131 ((-1163 (-409 (-568))) (-568))) (-15 -2978 ((-1163 (-409 (-568))) (-568))) (-15 -2752 ((-409 (-568)) (-1163 (-409 (-568))) (-1163 (-409 (-568))))) (-15 -2326 ((-1163 (-409 (-568))) (-1163 (-409 (-568))) (-1163 (-409 (-568))))) (-15 -1339 ((-409 (-568)) (-1163 (-409 (-568))))) (-15 -2881 ((-1163 (-409 (-568))) (-1163 (-409 (-568))) (-1163 (-409 (-568))))) (-15 -3198 ((-1163 (-409 (-568))) (-634 (-568)))) (-15 -1613 ((-1163 (-409 (-568))) (-634 (-568)) (-634 (-568))))) 
-((-1861 (((-420 (-1157 (-568))) (-568)) 28)) (-2347 (((-634 (-1157 (-568))) (-568)) 23)) (-4411 (((-1157 (-568)) (-568)) 21))) 
-(((-183) (-10 -7 (-15 -2347 ((-634 (-1157 (-568))) (-568))) (-15 -4411 ((-1157 (-568)) (-568))) (-15 -1861 ((-420 (-1157 (-568))) (-568))))) (T -183)) 
-((-1861 (*1 *2 *3) (-12 (-5 *2 (-420 (-1157 (-568)))) (-5 *1 (-183)) (-5 *3 (-568)))) (-4411 (*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-183)) (-5 *3 (-568)))) (-2347 (*1 *2 *3) (-12 (-5 *2 (-634 (-1157 (-568)))) (-5 *1 (-183)) (-5 *3 (-568))))) 
-(-10 -7 (-15 -2347 ((-634 (-1157 (-568))) (-568))) (-15 -4411 ((-1157 (-568)) (-568))) (-15 -1861 ((-420 (-1157 (-568))) (-568)))) 
-((-1539 (((-1141 (-215)) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 101)) (-1903 (((-634 (-1143)) (-1141 (-215))) NIL)) (-1397 (((-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 77)) (-1685 (((-634 (-215)) (-310 (-215)) (-1161) (-1084 (-835 (-215)))) NIL)) (-2309 (((-634 (-1143)) (-634 (-215))) NIL)) (-2066 (((-215) (-1084 (-835 (-215)))) 22)) (-3632 (((-215) (-1084 (-835 (-215)))) 23)) (-3459 (((-381) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 93)) (-2445 (((-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated")) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 40)) (-2281 (((-1143) (-215)) NIL)) (-2199 (((-1143) (-634 (-1143))) 19)) (-3348 (((-1035) (-1161) (-1161) (-1035)) 12))) 
-(((-184) (-10 -7 (-15 -1397 ((-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2445 ((-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated")) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2066 ((-215) (-1084 (-835 (-215))))) (-15 -3632 ((-215) (-1084 (-835 (-215))))) (-15 -3459 ((-381) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -1685 ((-634 (-215)) (-310 (-215)) (-1161) (-1084 (-835 (-215))))) (-15 -1539 ((-1141 (-215)) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2281 ((-1143) (-215))) (-15 -2309 ((-634 (-1143)) (-634 (-215)))) (-15 -1903 ((-634 (-1143)) (-1141 (-215)))) (-15 -2199 ((-1143) (-634 (-1143)))) (-15 -3348 ((-1035) (-1161) (-1161) (-1035))))) (T -184)) 
-((-3348 (*1 *2 *3 *3 *2) (-12 (-5 *2 (-1035)) (-5 *3 (-1161)) (-5 *1 (-184)))) (-2199 (*1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-1143)) (-5 *1 (-184)))) (-1903 (*1 *2 *3) (-12 (-5 *3 (-1141 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-184)))) (-2309 (*1 *2 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-184)))) (-2281 (*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-1143)) (-5 *1 (-184)))) (-1539 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-1141 (-215))) (-5 *1 (-184)))) (-1685 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-215))) (-5 *4 (-1161)) (-5 *5 (-1084 (-835 (-215)))) (-5 *2 (-634 (-215))) (-5 *1 (-184)))) (-3459 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-381)) (-5 *1 (-184)))) (-3632 (*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-184)))) (-2066 (*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-184)))) (-2445 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (-5 *1 (-184)))) (-1397 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))) (-5 *1 (-184))))) 
-(-10 -7 (-15 -1397 ((-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2445 ((-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated")) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2066 ((-215) (-1084 (-835 (-215))))) (-15 -3632 ((-215) (-1084 (-835 (-215))))) (-15 -3459 ((-381) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -1685 ((-634 (-215)) (-310 (-215)) (-1161) (-1084 (-835 (-215))))) (-15 -1539 ((-1141 (-215)) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2281 ((-1143) (-215))) (-15 -2309 ((-634 (-1143)) (-634 (-215)))) (-15 -1903 ((-634 (-1143)) (-1141 (-215)))) (-15 -2199 ((-1143) (-634 (-1143)))) (-15 -3348 ((-1035) (-1161) (-1161) (-1035)))) 
-((-2447 (((-121) $ $) NIL)) (-1304 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 53) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) NIL)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 28) (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2563 ((|#1| $) 74)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2589 (((-121) $ $) NIL)) (-4490 (($) NIL T CONST)) (-2403 (($ $ $) NIL)) (-3532 (($ $) 19)) (-3081 (($ |#1| (-1141 |#1|)) 47)) (-2902 (((-3 $ "failed") $) 116)) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-2175 (((-1141 |#1|) $) 81)) (-4260 (((-1141 |#1|) $) 78)) (-4110 (((-1141 |#1|) $) 79)) (-1598 (((-121) $) NIL)) (-1584 (((-1141 |#1|) $) 87)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2498 (($ (-634 $)) NIL) (($ $ $) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ (-634 $)) NIL) (($ $ $) NIL)) (-3850 (((-420 $) $) NIL)) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL)) (-2168 (($ $ (-568)) 90)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-3450 (((-1141 |#1|) $) 88)) (-3426 (((-1141 (-409 |#1|)) $) 13)) (-1991 (($ (-409 |#1|)) 17) (($ |#1| (-1141 |#1|) (-1141 |#1|)) 37)) (-2188 (($ $) 92)) (-2747 (((-850) $) 126) (($ (-568)) 50) (($ |#1|) 51) (($ (-409 |#1|)) 35) (($ (-409 (-568))) NIL) (($ $) NIL)) (-3425 (((-763)) 63)) (-2273 (((-121) $ $) NIL)) (-1664 (((-1141 (-409 |#1|)) $) 18)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) 25 T CONST)) (-1557 (($) 28 T CONST)) (-1719 (((-121) $ $) 34)) (-1781 (($ $ $) 114)) (-1775 (($ $) 105) (($ $ $) 102)) (-1769 (($ $ $) 100)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 112) (($ $ $) 107) (($ $ |#1|) NIL) (($ |#1| $) 109) (($ (-409 |#1|) $) 110) (($ $ (-409 |#1|)) NIL) (($ (-409 (-568)) $) NIL) (($ $ (-409 (-568))) NIL))) 
+(((-173 |#1|) (-13 (-43 |#1|) (-43 (-409 |#1|)) (-365) (-10 -8 (-15 -1991 ($ (-409 |#1|))) (-15 -1991 ($ |#1| (-1141 |#1|) (-1141 |#1|))) (-15 -3081 ($ |#1| (-1141 |#1|))) (-15 -4260 ((-1141 |#1|) $)) (-15 -4110 ((-1141 |#1|) $)) (-15 -2175 ((-1141 |#1|) $)) (-15 -2563 (|#1| $)) (-15 -3532 ($ $)) (-15 -1664 ((-1141 (-409 |#1|)) $)) (-15 -3426 ((-1141 (-409 |#1|)) $)) (-15 -1584 ((-1141 |#1|) $)) (-15 -3450 ((-1141 |#1|) $)) (-15 -2168 ($ $ (-568))) (-15 -2188 ($ $)))) (-301)) (T -173)) 
+((-1991 (*1 *1 *2) (-12 (-5 *2 (-409 *3)) (-4 *3 (-301)) (-5 *1 (-173 *3)))) (-1991 (*1 *1 *2 *3 *3) (-12 (-5 *3 (-1141 *2)) (-4 *2 (-301)) (-5 *1 (-173 *2)))) (-3081 (*1 *1 *2 *3) (-12 (-5 *3 (-1141 *2)) (-4 *2 (-301)) (-5 *1 (-173 *2)))) (-4260 (*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-173 *3)) (-4 *3 (-301)))) (-4110 (*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-173 *3)) (-4 *3 (-301)))) (-2175 (*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-173 *3)) (-4 *3 (-301)))) (-2563 (*1 *2 *1) (-12 (-5 *1 (-173 *2)) (-4 *2 (-301)))) (-3532 (*1 *1 *1) (-12 (-5 *1 (-173 *2)) (-4 *2 (-301)))) (-1664 (*1 *2 *1) (-12 (-5 *2 (-1141 (-409 *3))) (-5 *1 (-173 *3)) (-4 *3 (-301)))) (-3426 (*1 *2 *1) (-12 (-5 *2 (-1141 (-409 *3))) (-5 *1 (-173 *3)) (-4 *3 (-301)))) (-1584 (*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-173 *3)) (-4 *3 (-301)))) (-3450 (*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-173 *3)) (-4 *3 (-301)))) (-2168 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-173 *3)) (-4 *3 (-301)))) (-2188 (*1 *1 *1) (-12 (-5 *1 (-173 *2)) (-4 *2 (-301))))) 
+(-13 (-43 |#1|) (-43 (-409 |#1|)) (-365) (-10 -8 (-15 -1991 ($ (-409 |#1|))) (-15 -1991 ($ |#1| (-1141 |#1|) (-1141 |#1|))) (-15 -3081 ($ |#1| (-1141 |#1|))) (-15 -4260 ((-1141 |#1|) $)) (-15 -4110 ((-1141 |#1|) $)) (-15 -2175 ((-1141 |#1|) $)) (-15 -2563 (|#1| $)) (-15 -3532 ($ $)) (-15 -1664 ((-1141 (-409 |#1|)) $)) (-15 -3426 ((-1141 (-409 |#1|)) $)) (-15 -1584 ((-1141 |#1|) $)) (-15 -3450 ((-1141 |#1|) $)) (-15 -2168 ($ $ (-568))) (-15 -2188 ($ $)))) 
+((-3801 (((-1 (-944 |#1|) (-944 |#1|)) |#1|) 40)) (-2070 (((-944 |#1|) (-944 |#1|)) 19)) (-2246 (((-1 (-944 |#1|) (-944 |#1|)) |#1|) 36)) (-1289 (((-944 |#1|) (-944 |#1|)) 17)) (-1931 (((-944 |#1|) (-944 |#1|)) 25)) (-2901 (((-944 |#1|) (-944 |#1|)) 24)) (-1535 (((-944 |#1|) (-944 |#1|)) 23)) (-4112 (((-1 (-944 |#1|) (-944 |#1|)) |#1|) 37)) (-4171 (((-1 (-944 |#1|) (-944 |#1|)) |#1|) 35)) (-3146 (((-1 (-944 |#1|) (-944 |#1|)) |#1|) 34)) (-2411 (((-944 |#1|) (-944 |#1|)) 18)) (-3109 (((-1 (-944 |#1|) (-944 |#1|)) |#1| |#1|) 43)) (-4245 (((-944 |#1|) (-944 |#1|)) 8)) (-4045 (((-1 (-944 |#1|) (-944 |#1|)) |#1|) 39)) (-1427 (((-1 (-944 |#1|) (-944 |#1|)) |#1|) 38))) 
+(((-174 |#1|) (-10 -7 (-15 -4245 ((-944 |#1|) (-944 |#1|))) (-15 -1289 ((-944 |#1|) (-944 |#1|))) (-15 -2411 ((-944 |#1|) (-944 |#1|))) (-15 -2070 ((-944 |#1|) (-944 |#1|))) (-15 -1535 ((-944 |#1|) (-944 |#1|))) (-15 -2901 ((-944 |#1|) (-944 |#1|))) (-15 -1931 ((-944 |#1|) (-944 |#1|))) (-15 -3146 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -4171 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -2246 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -4112 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -1427 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -4045 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -3801 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -3109 ((-1 (-944 |#1|) (-944 |#1|)) |#1| |#1|))) (-13 (-365) (-1181) (-1002))) (T -174)) 
+((-3109 (*1 *2 *3 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))))) (-3801 (*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))))) (-4045 (*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))))) (-1427 (*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))))) (-4112 (*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))))) (-2246 (*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))))) (-4171 (*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))))) (-3146 (*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))))) (-1931 (*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3)))) (-2901 (*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3)))) (-1535 (*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3)))) (-2070 (*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3)))) (-2411 (*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3)))) (-1289 (*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3)))) (-4245 (*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3))))) 
+(-10 -7 (-15 -4245 ((-944 |#1|) (-944 |#1|))) (-15 -1289 ((-944 |#1|) (-944 |#1|))) (-15 -2411 ((-944 |#1|) (-944 |#1|))) (-15 -2070 ((-944 |#1|) (-944 |#1|))) (-15 -1535 ((-944 |#1|) (-944 |#1|))) (-15 -2901 ((-944 |#1|) (-944 |#1|))) (-15 -1931 ((-944 |#1|) (-944 |#1|))) (-15 -3146 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -4171 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -2246 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -4112 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -1427 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -4045 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -3801 ((-1 (-944 |#1|) (-944 |#1|)) |#1|)) (-15 -3109 ((-1 (-944 |#1|) (-944 |#1|)) |#1| |#1|))) 
+((-1295 ((|#2| |#3|) 27))) 
+(((-175 |#1| |#2| |#3|) (-10 -7 (-15 -1295 (|#2| |#3|))) (-172) (-1219 |#1|) (-714 |#1| |#2|)) (T -175)) 
+((-1295 (*1 *2 *3) (-12 (-4 *4 (-172)) (-4 *2 (-1219 *4)) (-5 *1 (-175 *4 *2 *3)) (-4 *3 (-714 *4 *2))))) 
+(-10 -7 (-15 -1295 (|#2| |#3|))) 
+((-1519 (((-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|)) 47 (|has| (-953 |#2|) (-881 |#1|))))) 
+(((-176 |#1| |#2| |#3|) (-10 -7 (IF (|has| (-953 |#2|) (-881 |#1|)) (-15 -1519 ((-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|))) |noBranch|)) (-1090) (-13 (-881 |#1|) (-172)) (-166 |#2|)) (T -176)) 
+((-1519 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *3)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-4 *3 (-166 *6)) (-4 (-953 *6) (-881 *5)) (-4 *6 (-13 (-881 *5) (-172))) (-5 *1 (-176 *5 *6 *3))))) 
+(-10 -7 (IF (|has| (-953 |#2|) (-881 |#1|)) (-15 -1519 ((-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|))) |noBranch|)) 
+((-3298 (((-634 |#1|) (-634 |#1|) |#1|) 36)) (-1639 (((-634 |#1|) |#1| (-634 |#1|)) 19)) (-3500 (((-634 |#1|) (-634 (-634 |#1|)) (-634 |#1|)) 31) ((|#1| (-634 |#1|) (-634 |#1|)) 29))) 
+(((-177 |#1|) (-10 -7 (-15 -1639 ((-634 |#1|) |#1| (-634 |#1|))) (-15 -3500 (|#1| (-634 |#1|) (-634 |#1|))) (-15 -3500 ((-634 |#1|) (-634 (-634 |#1|)) (-634 |#1|))) (-15 -3298 ((-634 |#1|) (-634 |#1|) |#1|))) (-301)) (T -177)) 
+((-3298 (*1 *2 *2 *3) (-12 (-5 *2 (-634 *3)) (-4 *3 (-301)) (-5 *1 (-177 *3)))) (-3500 (*1 *2 *3 *2) (-12 (-5 *3 (-634 (-634 *4))) (-5 *2 (-634 *4)) (-4 *4 (-301)) (-5 *1 (-177 *4)))) (-3500 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *2)) (-5 *1 (-177 *2)) (-4 *2 (-301)))) (-1639 (*1 *2 *3 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-301)) (-5 *1 (-177 *3))))) 
+(-10 -7 (-15 -1639 ((-634 |#1|) |#1| (-634 |#1|))) (-15 -3500 (|#1| (-634 |#1|) (-634 |#1|))) (-15 -3500 ((-634 |#1|) (-634 (-634 |#1|)) (-634 |#1|))) (-15 -3298 ((-634 |#1|) (-634 |#1|) |#1|))) 
+((-1648 (((-2 (|:| |start| |#2|) (|:| -2075 (-420 |#2|))) |#2|) 61)) (-3350 ((|#1| |#1|) 54)) (-2361 (((-169 |#1|) |#2|) 82)) (-4197 ((|#1| |#2|) 122) ((|#1| |#2| |#1|) 80)) (-3074 ((|#2| |#2|) 81)) (-1978 (((-420 |#2|) |#2| |#1|) 112) (((-420 |#2|) |#2| |#1| (-121)) 79)) (-4417 ((|#1| |#2|) 111)) (-4213 ((|#2| |#2|) 118)) (-3850 (((-420 |#2|) |#2|) 133) (((-420 |#2|) |#2| |#1|) 32) (((-420 |#2|) |#2| |#1| (-121)) 132)) (-3571 (((-634 (-2 (|:| -2075 (-634 |#2|)) (|:| -2185 |#1|))) |#2| |#2|) 131) (((-634 (-2 (|:| -2075 (-634 |#2|)) (|:| -2185 |#1|))) |#2| |#2| (-121)) 75)) (-2201 (((-634 (-169 |#1|)) |#2| |#1|) 40) (((-634 (-169 |#1|)) |#2|) 41))) 
+(((-178 |#1| |#2|) (-10 -7 (-15 -2201 ((-634 (-169 |#1|)) |#2|)) (-15 -2201 ((-634 (-169 |#1|)) |#2| |#1|)) (-15 -3571 ((-634 (-2 (|:| -2075 (-634 |#2|)) (|:| -2185 |#1|))) |#2| |#2| (-121))) (-15 -3571 ((-634 (-2 (|:| -2075 (-634 |#2|)) (|:| -2185 |#1|))) |#2| |#2|)) (-15 -3850 ((-420 |#2|) |#2| |#1| (-121))) (-15 -3850 ((-420 |#2|) |#2| |#1|)) (-15 -3850 ((-420 |#2|) |#2|)) (-15 -4213 (|#2| |#2|)) (-15 -4417 (|#1| |#2|)) (-15 -1978 ((-420 |#2|) |#2| |#1| (-121))) (-15 -1978 ((-420 |#2|) |#2| |#1|)) (-15 -3074 (|#2| |#2|)) (-15 -4197 (|#1| |#2| |#1|)) (-15 -4197 (|#1| |#2|)) (-15 -2361 ((-169 |#1|) |#2|)) (-15 -3350 (|#1| |#1|)) (-15 -1648 ((-2 (|:| |start| |#2|) (|:| -2075 (-420 |#2|))) |#2|))) (-13 (-365) (-840)) (-1219 (-169 |#1|))) (T -178)) 
+((-1648 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-2 (|:| |start| *3) (|:| -2075 (-420 *3)))) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) (-3350 (*1 *2 *2) (-12 (-4 *2 (-13 (-365) (-840))) (-5 *1 (-178 *2 *3)) (-4 *3 (-1219 (-169 *2))))) (-2361 (*1 *2 *3) (-12 (-5 *2 (-169 *4)) (-5 *1 (-178 *4 *3)) (-4 *4 (-13 (-365) (-840))) (-4 *3 (-1219 *2)))) (-4197 (*1 *2 *3) (-12 (-4 *2 (-13 (-365) (-840))) (-5 *1 (-178 *2 *3)) (-4 *3 (-1219 (-169 *2))))) (-4197 (*1 *2 *3 *2) (-12 (-4 *2 (-13 (-365) (-840))) (-5 *1 (-178 *2 *3)) (-4 *3 (-1219 (-169 *2))))) (-3074 (*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-840))) (-5 *1 (-178 *3 *2)) (-4 *2 (-1219 (-169 *3))))) (-1978 (*1 *2 *3 *4) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-420 *3)) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) (-1978 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-121)) (-4 *4 (-13 (-365) (-840))) (-5 *2 (-420 *3)) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) (-4417 (*1 *2 *3) (-12 (-4 *2 (-13 (-365) (-840))) (-5 *1 (-178 *2 *3)) (-4 *3 (-1219 (-169 *2))))) (-4213 (*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-840))) (-5 *1 (-178 *3 *2)) (-4 *2 (-1219 (-169 *3))))) (-3850 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-420 *3)) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) (-3850 (*1 *2 *3 *4) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-420 *3)) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) (-3850 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-121)) (-4 *4 (-13 (-365) (-840))) (-5 *2 (-420 *3)) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) (-3571 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-634 (-2 (|:| -2075 (-634 *3)) (|:| -2185 *4)))) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) (-3571 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-365) (-840))) (-5 *2 (-634 (-2 (|:| -2075 (-634 *3)) (|:| -2185 *5)))) (-5 *1 (-178 *5 *3)) (-4 *3 (-1219 (-169 *5))))) (-2201 (*1 *2 *3 *4) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-634 (-169 *4))) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) (-2201 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-634 (-169 *4))) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4)))))) 
+(-10 -7 (-15 -2201 ((-634 (-169 |#1|)) |#2|)) (-15 -2201 ((-634 (-169 |#1|)) |#2| |#1|)) (-15 -3571 ((-634 (-2 (|:| -2075 (-634 |#2|)) (|:| -2185 |#1|))) |#2| |#2| (-121))) (-15 -3571 ((-634 (-2 (|:| -2075 (-634 |#2|)) (|:| -2185 |#1|))) |#2| |#2|)) (-15 -3850 ((-420 |#2|) |#2| |#1| (-121))) (-15 -3850 ((-420 |#2|) |#2| |#1|)) (-15 -3850 ((-420 |#2|) |#2|)) (-15 -4213 (|#2| |#2|)) (-15 -4417 (|#1| |#2|)) (-15 -1978 ((-420 |#2|) |#2| |#1| (-121))) (-15 -1978 ((-420 |#2|) |#2| |#1|)) (-15 -3074 (|#2| |#2|)) (-15 -4197 (|#1| |#2| |#1|)) (-15 -4197 (|#1| |#2|)) (-15 -2361 ((-169 |#1|) |#2|)) (-15 -3350 (|#1| |#1|)) (-15 -1648 ((-2 (|:| |start| |#2|) (|:| -2075 (-420 |#2|))) |#2|))) 
+((-2302 (((-3 |#2| "failed") |#2|) 14)) (-4442 (((-763) |#2|) 16)) (-2754 ((|#2| |#2| |#2|) 18))) 
+(((-179 |#1| |#2|) (-10 -7 (-15 -2302 ((-3 |#2| "failed") |#2|)) (-15 -4442 ((-763) |#2|)) (-15 -2754 (|#2| |#2| |#2|))) (-1195) (-665 |#1|)) (T -179)) 
+((-2754 (*1 *2 *2 *2) (-12 (-4 *3 (-1195)) (-5 *1 (-179 *3 *2)) (-4 *2 (-665 *3)))) (-4442 (*1 *2 *3) (-12 (-4 *4 (-1195)) (-5 *2 (-763)) (-5 *1 (-179 *4 *3)) (-4 *3 (-665 *4)))) (-2302 (*1 *2 *2) (|partial| -12 (-4 *3 (-1195)) (-5 *1 (-179 *3 *2)) (-4 *2 (-665 *3))))) 
+(-10 -7 (-15 -2302 ((-3 |#2| "failed") |#2|)) (-15 -4442 ((-763) |#2|)) (-15 -2754 (|#2| |#2| |#2|))) 
+((-2634 ((|#2| |#2|) 28)) (-4293 (((-121) |#2|) 19)) (-3859 (((-310 |#1|) |#2|) 12)) (-3868 (((-310 |#1|) |#2|) 14)) (-3758 ((|#2| |#2| (-1161)) 68) ((|#2| |#2|) 69)) (-2732 (((-169 (-310 |#1|)) |#2|) 9)) (-2009 ((|#2| |#2| (-1161)) 65) ((|#2| |#2|) 58))) 
+(((-180 |#1| |#2|) (-10 -7 (-15 -3758 (|#2| |#2|)) (-15 -3758 (|#2| |#2| (-1161))) (-15 -2009 (|#2| |#2|)) (-15 -2009 (|#2| |#2| (-1161))) (-15 -3859 ((-310 |#1|) |#2|)) (-15 -3868 ((-310 |#1|) |#2|)) (-15 -4293 ((-121) |#2|)) (-15 -2634 (|#2| |#2|)) (-15 -2732 ((-169 (-310 |#1|)) |#2|))) (-13 (-558) (-842) (-1037 (-568))) (-13 (-27) (-1181) (-432 (-169 |#1|)))) (T -180)) 
+((-2732 (*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-169 (-310 *4))) (-5 *1 (-180 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 (-169 *4)))))) (-2634 (*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-842) (-1037 (-568)))) (-5 *1 (-180 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 (-169 *3)))))) (-4293 (*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-121)) (-5 *1 (-180 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 (-169 *4)))))) (-3868 (*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-310 *4)) (-5 *1 (-180 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 (-169 *4)))))) (-3859 (*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-310 *4)) (-5 *1 (-180 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 (-169 *4)))))) (-2009 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-5 *1 (-180 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 (-169 *4)))))) (-2009 (*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-842) (-1037 (-568)))) (-5 *1 (-180 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 (-169 *3)))))) (-3758 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-5 *1 (-180 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 (-169 *4)))))) (-3758 (*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-842) (-1037 (-568)))) (-5 *1 (-180 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 (-169 *3))))))) 
+(-10 -7 (-15 -3758 (|#2| |#2|)) (-15 -3758 (|#2| |#2| (-1161))) (-15 -2009 (|#2| |#2|)) (-15 -2009 (|#2| |#2| (-1161))) (-15 -3859 ((-310 |#1|) |#2|)) (-15 -3868 ((-310 |#1|) |#2|)) (-15 -4293 ((-121) |#2|)) (-15 -2634 (|#2| |#2|)) (-15 -2732 ((-169 (-310 |#1|)) |#2|))) 
+((-2405 (((-1244 (-679 (-953 |#1|))) (-1244 (-679 |#1|))) 22)) (-2747 (((-1244 (-679 (-409 (-953 |#1|)))) (-1244 (-679 |#1|))) 30))) 
+(((-181 |#1|) (-10 -7 (-15 -2405 ((-1244 (-679 (-953 |#1|))) (-1244 (-679 |#1|)))) (-15 -2747 ((-1244 (-679 (-409 (-953 |#1|)))) (-1244 (-679 |#1|))))) (-172)) (T -181)) 
+((-2747 (*1 *2 *3) (-12 (-5 *3 (-1244 (-679 *4))) (-4 *4 (-172)) (-5 *2 (-1244 (-679 (-409 (-953 *4))))) (-5 *1 (-181 *4)))) (-2405 (*1 *2 *3) (-12 (-5 *3 (-1244 (-679 *4))) (-4 *4 (-172)) (-5 *2 (-1244 (-679 (-953 *4)))) (-5 *1 (-181 *4))))) 
+(-10 -7 (-15 -2405 ((-1244 (-679 (-953 |#1|))) (-1244 (-679 |#1|)))) (-15 -2747 ((-1244 (-679 (-409 (-953 |#1|)))) (-1244 (-679 |#1|))))) 
+((-4160 (((-1163 (-409 (-568))) (-1163 (-409 (-568))) (-1163 (-409 (-568)))) 66)) (-1410 (((-1163 (-409 (-568))) (-634 (-568)) (-634 (-568))) 74)) (-2757 (((-1163 (-409 (-568))) (-568)) 40)) (-3066 (((-1163 (-409 (-568))) (-568)) 52)) (-1339 (((-409 (-568)) (-1163 (-409 (-568)))) 62)) (-4209 (((-1163 (-409 (-568))) (-568)) 32)) (-3427 (((-1163 (-409 (-568))) (-568)) 48)) (-4373 (((-1163 (-409 (-568))) (-568)) 46)) (-3806 (((-1163 (-409 (-568))) (-1163 (-409 (-568))) (-1163 (-409 (-568)))) 60)) (-2188 (((-1163 (-409 (-568))) (-568)) 25)) (-3386 (((-409 (-568)) (-1163 (-409 (-568))) (-1163 (-409 (-568)))) 64)) (-4207 (((-1163 (-409 (-568))) (-568)) 30)) (-1810 (((-1163 (-409 (-568))) (-634 (-568))) 71))) 
+(((-182) (-10 -7 (-15 -2188 ((-1163 (-409 (-568))) (-568))) (-15 -2757 ((-1163 (-409 (-568))) (-568))) (-15 -4209 ((-1163 (-409 (-568))) (-568))) (-15 -4207 ((-1163 (-409 (-568))) (-568))) (-15 -4373 ((-1163 (-409 (-568))) (-568))) (-15 -3427 ((-1163 (-409 (-568))) (-568))) (-15 -3066 ((-1163 (-409 (-568))) (-568))) (-15 -3386 ((-409 (-568)) (-1163 (-409 (-568))) (-1163 (-409 (-568))))) (-15 -3806 ((-1163 (-409 (-568))) (-1163 (-409 (-568))) (-1163 (-409 (-568))))) (-15 -1339 ((-409 (-568)) (-1163 (-409 (-568))))) (-15 -4160 ((-1163 (-409 (-568))) (-1163 (-409 (-568))) (-1163 (-409 (-568))))) (-15 -1810 ((-1163 (-409 (-568))) (-634 (-568)))) (-15 -1410 ((-1163 (-409 (-568))) (-634 (-568)) (-634 (-568)))))) (T -182)) 
+((-1410 (*1 *2 *3 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)))) (-1810 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)))) (-4160 (*1 *2 *2 *2) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)))) (-1339 (*1 *2 *3) (-12 (-5 *3 (-1163 (-409 (-568)))) (-5 *2 (-409 (-568))) (-5 *1 (-182)))) (-3806 (*1 *2 *2 *2) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)))) (-3386 (*1 *2 *3 *3) (-12 (-5 *3 (-1163 (-409 (-568)))) (-5 *2 (-409 (-568))) (-5 *1 (-182)))) (-3066 (*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568)))) (-3427 (*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568)))) (-4373 (*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568)))) (-4207 (*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568)))) (-4209 (*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568)))) (-2757 (*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568)))) (-2188 (*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568))))) 
+(-10 -7 (-15 -2188 ((-1163 (-409 (-568))) (-568))) (-15 -2757 ((-1163 (-409 (-568))) (-568))) (-15 -4209 ((-1163 (-409 (-568))) (-568))) (-15 -4207 ((-1163 (-409 (-568))) (-568))) (-15 -4373 ((-1163 (-409 (-568))) (-568))) (-15 -3427 ((-1163 (-409 (-568))) (-568))) (-15 -3066 ((-1163 (-409 (-568))) (-568))) (-15 -3386 ((-409 (-568)) (-1163 (-409 (-568))) (-1163 (-409 (-568))))) (-15 -3806 ((-1163 (-409 (-568))) (-1163 (-409 (-568))) (-1163 (-409 (-568))))) (-15 -1339 ((-409 (-568)) (-1163 (-409 (-568))))) (-15 -4160 ((-1163 (-409 (-568))) (-1163 (-409 (-568))) (-1163 (-409 (-568))))) (-15 -1810 ((-1163 (-409 (-568))) (-634 (-568)))) (-15 -1410 ((-1163 (-409 (-568))) (-634 (-568)) (-634 (-568))))) 
+((-2445 (((-420 (-1157 (-568))) (-568)) 28)) (-3941 (((-634 (-1157 (-568))) (-568)) 23)) (-1526 (((-1157 (-568)) (-568)) 21))) 
+(((-183) (-10 -7 (-15 -3941 ((-634 (-1157 (-568))) (-568))) (-15 -1526 ((-1157 (-568)) (-568))) (-15 -2445 ((-420 (-1157 (-568))) (-568))))) (T -183)) 
+((-2445 (*1 *2 *3) (-12 (-5 *2 (-420 (-1157 (-568)))) (-5 *1 (-183)) (-5 *3 (-568)))) (-1526 (*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-183)) (-5 *3 (-568)))) (-3941 (*1 *2 *3) (-12 (-5 *2 (-634 (-1157 (-568)))) (-5 *1 (-183)) (-5 *3 (-568))))) 
+(-10 -7 (-15 -3941 ((-634 (-1157 (-568))) (-568))) (-15 -1526 ((-1157 (-568)) (-568))) (-15 -2445 ((-420 (-1157 (-568))) (-568)))) 
+((-4233 (((-1141 (-215)) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 101)) (-2636 (((-634 (-1143)) (-1141 (-215))) NIL)) (-2068 (((-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 77)) (-3533 (((-634 (-215)) (-310 (-215)) (-1161) (-1084 (-835 (-215)))) NIL)) (-3706 (((-634 (-1143)) (-634 (-215))) NIL)) (-2793 (((-215) (-1084 (-835 (-215)))) 22)) (-3141 (((-215) (-1084 (-835 (-215)))) 23)) (-3632 (((-381) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 93)) (-2500 (((-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated")) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 40)) (-3486 (((-1143) (-215)) NIL)) (-3098 (((-1143) (-634 (-1143))) 19)) (-4491 (((-1035) (-1161) (-1161) (-1035)) 12))) 
+(((-184) (-10 -7 (-15 -2068 ((-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2500 ((-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated")) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2793 ((-215) (-1084 (-835 (-215))))) (-15 -3141 ((-215) (-1084 (-835 (-215))))) (-15 -3632 ((-381) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -3533 ((-634 (-215)) (-310 (-215)) (-1161) (-1084 (-835 (-215))))) (-15 -4233 ((-1141 (-215)) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -3486 ((-1143) (-215))) (-15 -3706 ((-634 (-1143)) (-634 (-215)))) (-15 -2636 ((-634 (-1143)) (-1141 (-215)))) (-15 -3098 ((-1143) (-634 (-1143)))) (-15 -4491 ((-1035) (-1161) (-1161) (-1035))))) (T -184)) 
+((-4491 (*1 *2 *3 *3 *2) (-12 (-5 *2 (-1035)) (-5 *3 (-1161)) (-5 *1 (-184)))) (-3098 (*1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-1143)) (-5 *1 (-184)))) (-2636 (*1 *2 *3) (-12 (-5 *3 (-1141 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-184)))) (-3706 (*1 *2 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-184)))) (-3486 (*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-1143)) (-5 *1 (-184)))) (-4233 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-1141 (-215))) (-5 *1 (-184)))) (-3533 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-215))) (-5 *4 (-1161)) (-5 *5 (-1084 (-835 (-215)))) (-5 *2 (-634 (-215))) (-5 *1 (-184)))) (-3632 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-381)) (-5 *1 (-184)))) (-3141 (*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-184)))) (-2793 (*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-184)))) (-2500 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (-5 *1 (-184)))) (-2068 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))) (-5 *1 (-184))))) 
+(-10 -7 (-15 -2068 ((-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2500 ((-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated")) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2793 ((-215) (-1084 (-835 (-215))))) (-15 -3141 ((-215) (-1084 (-835 (-215))))) (-15 -3632 ((-381) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -3533 ((-634 (-215)) (-310 (-215)) (-1161) (-1084 (-835 (-215))))) (-15 -4233 ((-1141 (-215)) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -3486 ((-1143) (-215))) (-15 -3706 ((-634 (-1143)) (-634 (-215)))) (-15 -2636 ((-634 (-1143)) (-1141 (-215)))) (-15 -3098 ((-1143) (-634 (-1143)))) (-15 -4491 ((-1035) (-1161) (-1161) (-1035)))) 
+((-2449 (((-121) $ $) NIL)) (-3318 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 53) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) NIL)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 28) (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-185) (-782)) (T -185)) 
 NIL 
 (-782) 
-((-2447 (((-121) $ $) NIL)) (-1304 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 58) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) NIL)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 37) (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-3318 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 58) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) NIL)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 37) (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-186) (-782)) (T -186)) 
 NIL 
 (-782) 
-((-2447 (((-121) $ $) NIL)) (-1304 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 67) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) NIL)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 36) (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-3318 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 67) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) NIL)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 36) (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-187) (-782)) (T -187)) 
 NIL 
 (-782) 
-((-2447 (((-121) $ $) NIL)) (-1304 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 54) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) NIL)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 30) (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-3318 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 54) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) NIL)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 30) (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-188) (-782)) (T -188)) 
 NIL 
 (-782) 
-((-2447 (((-121) $ $) NIL)) (-1304 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 65) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) NIL)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 35) (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-3318 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 65) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) NIL)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 35) (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-189) (-782)) (T -189)) 
 NIL 
 (-782) 
-((-2447 (((-121) $ $) NIL)) (-1304 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 71) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) NIL)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 33) (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-3318 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 71) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) NIL)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 33) (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-190) (-782)) (T -190)) 
 NIL 
 (-782) 
-((-2447 (((-121) $ $) NIL)) (-1304 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 78) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) NIL)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 43) (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-3318 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 78) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) NIL)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 43) (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-191) (-782)) (T -191)) 
 NIL 
 (-782) 
-((-2447 (((-121) $ $) NIL)) (-1304 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 68) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) NIL)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 37) (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-3318 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 68) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) NIL)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 37) (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-192) (-782)) (T -192)) 
 NIL 
 (-782) 
-((-2447 (((-121) $ $) NIL)) (-1304 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) NIL) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 62)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) NIL) (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 29)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-3318 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) NIL) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 62)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) NIL) (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 29)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-193) (-782)) (T -193)) 
 NIL 
 (-782) 
-((-2447 (((-121) $ $) NIL)) (-1304 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) NIL) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 60)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) NIL) (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 32)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-3318 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) NIL) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 60)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) NIL) (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 32)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-194) (-782)) (T -194)) 
 NIL 
 (-782) 
-((-2447 (((-121) $ $) NIL)) (-1304 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 89) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) NIL)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 77) (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-3318 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 89) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) NIL)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 77) (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-195) (-782)) (T -195)) 
 NIL 
 (-782) 
-((-3342 (((-3 (-2 (|:| -4192 (-123)) (|:| |w| (-215))) "failed") (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 80)) (-2782 (((-568) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 39)) (-2122 (((-3 (-634 (-215)) "failed") (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 69))) 
-(((-196) (-10 -7 (-15 -3342 ((-3 (-2 (|:| -4192 (-123)) (|:| |w| (-215))) "failed") (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2122 ((-3 (-634 (-215)) "failed") (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2782 ((-568) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))))) (T -196)) 
-((-2782 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-568)) (-5 *1 (-196)))) (-2122 (*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-634 (-215))) (-5 *1 (-196)))) (-3342 (*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| -4192 (-123)) (|:| |w| (-215)))) (-5 *1 (-196))))) 
-(-10 -7 (-15 -3342 ((-3 (-2 (|:| -4192 (-123)) (|:| |w| (-215))) "failed") (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2122 ((-3 (-634 (-215)) "failed") (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2782 ((-568) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))))) 
-((-3913 (((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 37)) (-3441 (((-2 (|:| |stiffnessFactor| (-381)) (|:| |stabilityFactor| (-381))) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 127)) (-3381 (((-2 (|:| |stiffnessFactor| (-381)) (|:| |stabilityFactor| (-381))) (-679 (-310 (-215)))) 87)) (-3231 (((-381) (-679 (-310 (-215)))) 110)) (-3147 (((-679 (-310 (-215))) (-1244 (-310 (-215))) (-634 (-1161))) 107)) (-2426 (((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 26)) (-3175 (((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 42)) (-1339 (((-679 (-310 (-215))) (-679 (-310 (-215))) (-634 (-1161)) (-1244 (-310 (-215)))) 99)) (-2824 (((-381) (-381) (-634 (-381))) 104) (((-381) (-381) (-381)) 102)) (-3968 (((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 33))) 
-(((-197) (-10 -7 (-15 -2824 ((-381) (-381) (-381))) (-15 -2824 ((-381) (-381) (-634 (-381)))) (-15 -3231 ((-381) (-679 (-310 (-215))))) (-15 -3147 ((-679 (-310 (-215))) (-1244 (-310 (-215))) (-634 (-1161)))) (-15 -1339 ((-679 (-310 (-215))) (-679 (-310 (-215))) (-634 (-1161)) (-1244 (-310 (-215))))) (-15 -3381 ((-2 (|:| |stiffnessFactor| (-381)) (|:| |stabilityFactor| (-381))) (-679 (-310 (-215))))) (-15 -3441 ((-2 (|:| |stiffnessFactor| (-381)) (|:| |stabilityFactor| (-381))) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -3913 ((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -3175 ((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -3968 ((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2426 ((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))))) (T -197)) 
-((-2426 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-381)) (-5 *1 (-197)))) (-3968 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-381)) (-5 *1 (-197)))) (-3175 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-381)) (-5 *1 (-197)))) (-3913 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-381)) (-5 *1 (-197)))) (-3441 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| |stiffnessFactor| (-381)) (|:| |stabilityFactor| (-381)))) (-5 *1 (-197)))) (-3381 (*1 *2 *3) (-12 (-5 *3 (-679 (-310 (-215)))) (-5 *2 (-2 (|:| |stiffnessFactor| (-381)) (|:| |stabilityFactor| (-381)))) (-5 *1 (-197)))) (-1339 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-679 (-310 (-215)))) (-5 *3 (-634 (-1161))) (-5 *4 (-1244 (-310 (-215)))) (-5 *1 (-197)))) (-3147 (*1 *2 *3 *4) (-12 (-5 *3 (-1244 (-310 (-215)))) (-5 *4 (-634 (-1161))) (-5 *2 (-679 (-310 (-215)))) (-5 *1 (-197)))) (-3231 (*1 *2 *3) (-12 (-5 *3 (-679 (-310 (-215)))) (-5 *2 (-381)) (-5 *1 (-197)))) (-2824 (*1 *2 *2 *3) (-12 (-5 *3 (-634 (-381))) (-5 *2 (-381)) (-5 *1 (-197)))) (-2824 (*1 *2 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-197))))) 
-(-10 -7 (-15 -2824 ((-381) (-381) (-381))) (-15 -2824 ((-381) (-381) (-634 (-381)))) (-15 -3231 ((-381) (-679 (-310 (-215))))) (-15 -3147 ((-679 (-310 (-215))) (-1244 (-310 (-215))) (-634 (-1161)))) (-15 -1339 ((-679 (-310 (-215))) (-679 (-310 (-215))) (-634 (-1161)) (-1244 (-310 (-215))))) (-15 -3381 ((-2 (|:| |stiffnessFactor| (-381)) (|:| |stabilityFactor| (-381))) (-679 (-310 (-215))))) (-15 -3441 ((-2 (|:| |stiffnessFactor| (-381)) (|:| |stabilityFactor| (-381))) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -3913 ((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -3175 ((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -3968 ((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2426 ((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))))) 
-((-2447 (((-121) $ $) NIL)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 37)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-4110 (((-1035) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 60)) (-1717 (((-121) $ $) NIL))) 
+((-4457 (((-3 (-2 (|:| -4194 (-123)) (|:| |w| (-215))) "failed") (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 80)) (-3570 (((-568) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 39)) (-3351 (((-3 (-634 (-215)) "failed") (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 69))) 
+(((-196) (-10 -7 (-15 -4457 ((-3 (-2 (|:| -4194 (-123)) (|:| |w| (-215))) "failed") (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -3351 ((-3 (-634 (-215)) "failed") (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -3570 ((-568) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))))) (T -196)) 
+((-3570 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-568)) (-5 *1 (-196)))) (-3351 (*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-634 (-215))) (-5 *1 (-196)))) (-4457 (*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| -4194 (-123)) (|:| |w| (-215)))) (-5 *1 (-196))))) 
+(-10 -7 (-15 -4457 ((-3 (-2 (|:| -4194 (-123)) (|:| |w| (-215))) "failed") (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -3351 ((-3 (-634 (-215)) "failed") (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -3570 ((-568) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))))) 
+((-2131 (((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 37)) (-3508 (((-2 (|:| |stiffnessFactor| (-381)) (|:| |stabilityFactor| (-381))) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 127)) (-1451 (((-2 (|:| |stiffnessFactor| (-381)) (|:| |stabilityFactor| (-381))) (-679 (-310 (-215)))) 87)) (-1928 (((-381) (-679 (-310 (-215)))) 110)) (-2740 (((-679 (-310 (-215))) (-1244 (-310 (-215))) (-634 (-1161))) 107)) (-2399 (((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 26)) (-1711 (((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 42)) (-1339 (((-679 (-310 (-215))) (-679 (-310 (-215))) (-634 (-1161)) (-1244 (-310 (-215)))) 99)) (-3802 (((-381) (-381) (-634 (-381))) 104) (((-381) (-381) (-381)) 102)) (-4441 (((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 33))) 
+(((-197) (-10 -7 (-15 -3802 ((-381) (-381) (-381))) (-15 -3802 ((-381) (-381) (-634 (-381)))) (-15 -1928 ((-381) (-679 (-310 (-215))))) (-15 -2740 ((-679 (-310 (-215))) (-1244 (-310 (-215))) (-634 (-1161)))) (-15 -1339 ((-679 (-310 (-215))) (-679 (-310 (-215))) (-634 (-1161)) (-1244 (-310 (-215))))) (-15 -1451 ((-2 (|:| |stiffnessFactor| (-381)) (|:| |stabilityFactor| (-381))) (-679 (-310 (-215))))) (-15 -3508 ((-2 (|:| |stiffnessFactor| (-381)) (|:| |stabilityFactor| (-381))) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2131 ((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -1711 ((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -4441 ((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2399 ((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))))) (T -197)) 
+((-2399 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-381)) (-5 *1 (-197)))) (-4441 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-381)) (-5 *1 (-197)))) (-1711 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-381)) (-5 *1 (-197)))) (-2131 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-381)) (-5 *1 (-197)))) (-3508 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| |stiffnessFactor| (-381)) (|:| |stabilityFactor| (-381)))) (-5 *1 (-197)))) (-1451 (*1 *2 *3) (-12 (-5 *3 (-679 (-310 (-215)))) (-5 *2 (-2 (|:| |stiffnessFactor| (-381)) (|:| |stabilityFactor| (-381)))) (-5 *1 (-197)))) (-1339 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-679 (-310 (-215)))) (-5 *3 (-634 (-1161))) (-5 *4 (-1244 (-310 (-215)))) (-5 *1 (-197)))) (-2740 (*1 *2 *3 *4) (-12 (-5 *3 (-1244 (-310 (-215)))) (-5 *4 (-634 (-1161))) (-5 *2 (-679 (-310 (-215)))) (-5 *1 (-197)))) (-1928 (*1 *2 *3) (-12 (-5 *3 (-679 (-310 (-215)))) (-5 *2 (-381)) (-5 *1 (-197)))) (-3802 (*1 *2 *2 *3) (-12 (-5 *3 (-634 (-381))) (-5 *2 (-381)) (-5 *1 (-197)))) (-3802 (*1 *2 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-197))))) 
+(-10 -7 (-15 -3802 ((-381) (-381) (-381))) (-15 -3802 ((-381) (-381) (-634 (-381)))) (-15 -1928 ((-381) (-679 (-310 (-215))))) (-15 -2740 ((-679 (-310 (-215))) (-1244 (-310 (-215))) (-634 (-1161)))) (-15 -1339 ((-679 (-310 (-215))) (-679 (-310 (-215))) (-634 (-1161)) (-1244 (-310 (-215))))) (-15 -1451 ((-2 (|:| |stiffnessFactor| (-381)) (|:| |stabilityFactor| (-381))) (-679 (-310 (-215))))) (-15 -3508 ((-2 (|:| |stiffnessFactor| (-381)) (|:| |stabilityFactor| (-381))) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2131 ((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -1711 ((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -4441 ((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2399 ((-381) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))))) 
+((-2449 (((-121) $ $) NIL)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 37)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-3602 (((-1035) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 60)) (-1719 (((-121) $ $) NIL))) 
 (((-198) (-795)) (T -198)) 
 NIL 
 (-795) 
-((-2447 (((-121) $ $) NIL)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 37)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-4110 (((-1035) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 60)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 37)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-3602 (((-1035) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 60)) (-1719 (((-121) $ $) NIL))) 
 (((-199) (-795)) (T -199)) 
 NIL 
 (-795) 
-((-2447 (((-121) $ $) NIL)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 36)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-4110 (((-1035) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 64)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 36)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-3602 (((-1035) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 64)) (-1719 (((-121) $ $) NIL))) 
 (((-200) (-795)) (T -200)) 
 NIL 
 (-795) 
-((-2447 (((-121) $ $) NIL)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 42)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-4110 (((-1035) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 73)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 42)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-3602 (((-1035) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 73)) (-1719 (((-121) $ $) NIL))) 
 (((-201) (-795)) (T -201)) 
 NIL 
 (-795) 
-((-3595 (((-634 (-1161)) (-1161) (-763)) 22)) (-3176 (((-310 (-215)) (-310 (-215))) 29)) (-4118 (((-121) (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) 67)) (-2658 (((-121) (-215) (-215) (-634 (-310 (-215)))) 43))) 
-(((-202) (-10 -7 (-15 -3595 ((-634 (-1161)) (-1161) (-763))) (-15 -3176 ((-310 (-215)) (-310 (-215)))) (-15 -2658 ((-121) (-215) (-215) (-634 (-310 (-215))))) (-15 -4118 ((-121) (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215))))))) (T -202)) 
-((-4118 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) (-5 *2 (-121)) (-5 *1 (-202)))) (-2658 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-634 (-310 (-215)))) (-5 *3 (-215)) (-5 *2 (-121)) (-5 *1 (-202)))) (-3176 (*1 *2 *2) (-12 (-5 *2 (-310 (-215))) (-5 *1 (-202)))) (-3595 (*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-5 *2 (-634 (-1161))) (-5 *1 (-202)) (-5 *3 (-1161))))) 
-(-10 -7 (-15 -3595 ((-634 (-1161)) (-1161) (-763))) (-15 -3176 ((-310 (-215)) (-310 (-215)))) (-15 -2658 ((-121) (-215) (-215) (-634 (-310 (-215))))) (-15 -4118 ((-121) (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))))) 
-((-2447 (((-121) $ $) NIL)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) 17)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-4030 (((-1035) (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) 55)) (-1717 (((-121) $ $) NIL))) 
+((-2981 (((-634 (-1161)) (-1161) (-763)) 22)) (-1720 (((-310 (-215)) (-310 (-215))) 29)) (-3650 (((-121) (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) 67)) (-4423 (((-121) (-215) (-215) (-634 (-310 (-215)))) 43))) 
+(((-202) (-10 -7 (-15 -2981 ((-634 (-1161)) (-1161) (-763))) (-15 -1720 ((-310 (-215)) (-310 (-215)))) (-15 -4423 ((-121) (-215) (-215) (-634 (-310 (-215))))) (-15 -3650 ((-121) (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215))))))) (T -202)) 
+((-3650 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) (-5 *2 (-121)) (-5 *1 (-202)))) (-4423 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-634 (-310 (-215)))) (-5 *3 (-215)) (-5 *2 (-121)) (-5 *1 (-202)))) (-1720 (*1 *2 *2) (-12 (-5 *2 (-310 (-215))) (-5 *1 (-202)))) (-2981 (*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-5 *2 (-634 (-1161))) (-5 *1 (-202)) (-5 *3 (-1161))))) 
+(-10 -7 (-15 -2981 ((-634 (-1161)) (-1161) (-763))) (-15 -1720 ((-310 (-215)) (-310 (-215)))) (-15 -4423 ((-121) (-215) (-215) (-634 (-310 (-215))))) (-15 -3650 ((-121) (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))))) 
+((-2449 (((-121) $ $) NIL)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) 17)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-1476 (((-1035) (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) 55)) (-1719 (((-121) $ $) NIL))) 
 (((-203) (-890)) (T -203)) 
 NIL 
 (-890) 
-((-2447 (((-121) $ $) NIL)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) 12)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-4030 (((-1035) (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) 12)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-1476 (((-1035) (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-204) (-890)) (T -204)) 
 NIL 
 (-890) 
-((-2447 (((-121) $ $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-1352 (((-1249) $) 36) (((-1249) $ (-917) (-917)) 38)) (-2779 (($ $ (-990)) 19) (((-240 (-1143)) $ (-1161)) 15)) (-4125 (((-1249) $) 34)) (-2745 (((-850) $) 31) (($ (-634 |#1|)) 8)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $ $) 27)) (-1767 (($ $ $) 22))) 
-(((-205 |#1|) (-13 (-1090) (-10 -8 (-15 -2779 ($ $ (-990))) (-15 -2779 ((-240 (-1143)) $ (-1161))) (-15 -1767 ($ $ $)) (-15 -1773 ($ $ $)) (-15 -2745 ($ (-634 |#1|))) (-15 -4125 ((-1249) $)) (-15 -1352 ((-1249) $)) (-15 -1352 ((-1249) $ (-917) (-917))))) (-13 (-842) (-10 -8 (-15 -2779 ((-1143) $ (-1161))) (-15 -4125 ((-1249) $)) (-15 -1352 ((-1249) $))))) (T -205)) 
-((-2779 (*1 *1 *1 *2) (-12 (-5 *2 (-990)) (-5 *1 (-205 *3)) (-4 *3 (-13 (-842) (-10 -8 (-15 -2779 ((-1143) $ (-1161))) (-15 -4125 ((-1249) $)) (-15 -1352 ((-1249) $))))))) (-2779 (*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-240 (-1143))) (-5 *1 (-205 *4)) (-4 *4 (-13 (-842) (-10 -8 (-15 -2779 ((-1143) $ *3)) (-15 -4125 ((-1249) $)) (-15 -1352 ((-1249) $))))))) (-1767 (*1 *1 *1 *1) (-12 (-5 *1 (-205 *2)) (-4 *2 (-13 (-842) (-10 -8 (-15 -2779 ((-1143) $ (-1161))) (-15 -4125 ((-1249) $)) (-15 -1352 ((-1249) $))))))) (-1773 (*1 *1 *1 *1) (-12 (-5 *1 (-205 *2)) (-4 *2 (-13 (-842) (-10 -8 (-15 -2779 ((-1143) $ (-1161))) (-15 -4125 ((-1249) $)) (-15 -1352 ((-1249) $))))))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-13 (-842) (-10 -8 (-15 -2779 ((-1143) $ (-1161))) (-15 -4125 ((-1249) $)) (-15 -1352 ((-1249) $))))) (-5 *1 (-205 *3)))) (-4125 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-205 *3)) (-4 *3 (-13 (-842) (-10 -8 (-15 -2779 ((-1143) $ (-1161))) (-15 -4125 (*2 $)) (-15 -1352 (*2 $))))))) (-1352 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-205 *3)) (-4 *3 (-13 (-842) (-10 -8 (-15 -2779 ((-1143) $ (-1161))) (-15 -4125 (*2 $)) (-15 -1352 (*2 $))))))) (-1352 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1249)) (-5 *1 (-205 *4)) (-4 *4 (-13 (-842) (-10 -8 (-15 -2779 ((-1143) $ (-1161))) (-15 -4125 (*2 $)) (-15 -1352 (*2 $)))))))) 
-(-13 (-1090) (-10 -8 (-15 -2779 ($ $ (-990))) (-15 -2779 ((-240 (-1143)) $ (-1161))) (-15 -1767 ($ $ $)) (-15 -1773 ($ $ $)) (-15 -2745 ($ (-634 |#1|))) (-15 -4125 ((-1249) $)) (-15 -1352 ((-1249) $)) (-15 -1352 ((-1249) $ (-917) (-917))))) 
-((-1372 ((|#2| |#4| (-1 |#2| |#2|)) 46))) 
-(((-206 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1372 (|#2| |#4| (-1 |#2| |#2|)))) (-365) (-1219 |#1|) (-1219 (-409 |#2|)) (-340 |#1| |#2| |#3|)) (T -206)) 
-((-1372 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *2 *2)) (-4 *5 (-365)) (-4 *6 (-1219 (-409 *2))) (-4 *2 (-1219 *5)) (-5 *1 (-206 *5 *2 *6 *3)) (-4 *3 (-340 *5 *2 *6))))) 
-(-10 -7 (-15 -1372 (|#2| |#4| (-1 |#2| |#2|)))) 
-((-3344 ((|#2| |#2| (-763) |#2|) 41)) (-2816 ((|#2| |#2| (-763) |#2|) 37)) (-2117 (((-634 |#2|) (-634 (-2 (|:| |deg| (-763)) (|:| -4435 |#2|)))) 55)) (-1879 (((-634 (-2 (|:| |deg| (-763)) (|:| -4435 |#2|))) |#2|) 51)) (-4067 (((-121) |#2|) 48)) (-2630 (((-420 |#2|) |#2|) 74)) (-3848 (((-420 |#2|) |#2|) 73)) (-3333 ((|#2| |#2| (-763) |#2|) 35)) (-3177 (((-2 (|:| |cont| |#1|) (|:| -3276 (-634 (-2 (|:| |irr| |#2|) (|:| -3959 (-568)))))) |#2| (-121)) 66))) 
-(((-207 |#1| |#2|) (-10 -7 (-15 -3848 ((-420 |#2|) |#2|)) (-15 -2630 ((-420 |#2|) |#2|)) (-15 -3177 ((-2 (|:| |cont| |#1|) (|:| -3276 (-634 (-2 (|:| |irr| |#2|) (|:| -3959 (-568)))))) |#2| (-121))) (-15 -1879 ((-634 (-2 (|:| |deg| (-763)) (|:| -4435 |#2|))) |#2|)) (-15 -2117 ((-634 |#2|) (-634 (-2 (|:| |deg| (-763)) (|:| -4435 |#2|))))) (-15 -3333 (|#2| |#2| (-763) |#2|)) (-15 -2816 (|#2| |#2| (-763) |#2|)) (-15 -3344 (|#2| |#2| (-763) |#2|)) (-15 -4067 ((-121) |#2|))) (-350) (-1219 |#1|)) (T -207)) 
-((-4067 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-121)) (-5 *1 (-207 *4 *3)) (-4 *3 (-1219 *4)))) (-3344 (*1 *2 *2 *3 *2) (-12 (-5 *3 (-763)) (-4 *4 (-350)) (-5 *1 (-207 *4 *2)) (-4 *2 (-1219 *4)))) (-2816 (*1 *2 *2 *3 *2) (-12 (-5 *3 (-763)) (-4 *4 (-350)) (-5 *1 (-207 *4 *2)) (-4 *2 (-1219 *4)))) (-3333 (*1 *2 *2 *3 *2) (-12 (-5 *3 (-763)) (-4 *4 (-350)) (-5 *1 (-207 *4 *2)) (-4 *2 (-1219 *4)))) (-2117 (*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| |deg| (-763)) (|:| -4435 *5)))) (-4 *5 (-1219 *4)) (-4 *4 (-350)) (-5 *2 (-634 *5)) (-5 *1 (-207 *4 *5)))) (-1879 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-634 (-2 (|:| |deg| (-763)) (|:| -4435 *3)))) (-5 *1 (-207 *4 *3)) (-4 *3 (-1219 *4)))) (-3177 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-350)) (-5 *2 (-2 (|:| |cont| *5) (|:| -3276 (-634 (-2 (|:| |irr| *3) (|:| -3959 (-568))))))) (-5 *1 (-207 *5 *3)) (-4 *3 (-1219 *5)))) (-2630 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-207 *4 *3)) (-4 *3 (-1219 *4)))) (-3848 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-207 *4 *3)) (-4 *3 (-1219 *4))))) 
-(-10 -7 (-15 -3848 ((-420 |#2|) |#2|)) (-15 -2630 ((-420 |#2|) |#2|)) (-15 -3177 ((-2 (|:| |cont| |#1|) (|:| -3276 (-634 (-2 (|:| |irr| |#2|) (|:| -3959 (-568)))))) |#2| (-121))) (-15 -1879 ((-634 (-2 (|:| |deg| (-763)) (|:| -4435 |#2|))) |#2|)) (-15 -2117 ((-634 |#2|) (-634 (-2 (|:| |deg| (-763)) (|:| -4435 |#2|))))) (-15 -3333 (|#2| |#2| (-763) |#2|)) (-15 -2816 (|#2| |#2| (-763) |#2|)) (-15 -3344 (|#2| |#2| (-763) |#2|)) (-15 -4067 ((-121) |#2|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-1492 (((-568) $) NIL (|has| (-568) (-301)))) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-1497 (((-121) $ $) NIL)) (-3662 (((-568) $) NIL (|has| (-568) (-815)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) NIL) (((-3 (-1161) "failed") $) NIL (|has| (-568) (-1037 (-1161)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| (-568) (-1037 (-568)))) (((-3 (-568) "failed") $) NIL (|has| (-568) (-1037 (-568))))) (-2854 (((-568) $) NIL) (((-1161) $) NIL (|has| (-568) (-1037 (-1161)))) (((-409 (-568)) $) NIL (|has| (-568) (-1037 (-568)))) (((-568) $) NIL (|has| (-568) (-1037 (-568))))) (-2401 (($ $ $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| (-568) (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| (-568) (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-679 (-568)) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1731 (($) NIL (|has| (-568) (-550)))) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-2033 (((-121) $) NIL (|has| (-568) (-815)))) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| (-568) (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| (-568) (-881 (-381))))) (-2735 (((-121) $) NIL)) (-1332 (($ $) NIL)) (-2317 (((-568) $) NIL)) (-3038 (((-3 $ "failed") $) NIL (|has| (-568) (-1136)))) (-2245 (((-121) $) NIL (|has| (-568) (-815)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2521 (($ $ $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (|has| (-568) (-842)))) (-2795 (($ (-1 (-568) (-568)) $) NIL)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4434 (($) NIL (|has| (-568) (-1136)) CONST)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3880 (($ $) NIL (|has| (-568) (-301))) (((-409 (-568)) $) NIL)) (-1519 (((-568) $) NIL (|has| (-568) (-550)))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-3848 (((-420 $) $) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1339 (($ $ (-634 (-568)) (-634 (-568))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-568) (-568)) NIL (|has| (-568) (-303 (-568)))) (($ $ (-288 (-568))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-634 (-288 (-568)))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-634 (-1161)) (-634 (-568))) NIL (|has| (-568) (-523 (-1161) (-568)))) (($ $ (-1161) (-568)) NIL (|has| (-568) (-523 (-1161) (-568))))) (-2709 (((-763) $) NIL)) (-2779 (($ $ (-568)) NIL (|has| (-568) (-281 (-568) (-568))))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-4189 (($ $) NIL (|has| (-568) (-225))) (($ $ (-763)) NIL (|has| (-568) (-225))) (($ $ (-1161)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1 (-568) (-568)) (-763)) NIL) (($ $ (-1 (-568) (-568))) NIL)) (-3013 (($ $) NIL)) (-2324 (((-568) $) NIL)) (-4185 (($ (-409 (-568))) 8)) (-4278 (((-887 (-568)) $) NIL (|has| (-568) (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| (-568) (-609 (-887 (-381))))) (((-541) $) NIL (|has| (-568) (-609 (-541)))) (((-381) $) NIL (|has| (-568) (-1021))) (((-215) $) NIL (|has| (-568) (-1021)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| (-568) (-904))))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) 7) (($ (-568)) NIL) (($ (-1161)) NIL (|has| (-568) (-1037 (-1161)))) (((-409 (-568)) $) NIL) (((-1004 10) $) 9)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| (-568) (-904))) (|has| (-568) (-148))))) (-4078 (((-763)) NIL)) (-2285 (((-568) $) NIL (|has| (-568) (-550)))) (-1826 (((-121) $ $) NIL)) (-2897 (($ $) NIL (|has| (-568) (-815)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $) NIL (|has| (-568) (-225))) (($ $ (-763)) NIL (|has| (-568) (-225))) (($ $ (-1161)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1 (-568) (-568)) (-763)) NIL) (($ $ (-1 (-568) (-568))) NIL)) (-1751 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1738 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1732 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1779 (($ $ $) NIL) (($ (-568) (-568)) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ (-568) $) NIL) (($ $ (-568)) NIL))) 
-(((-208) (-13 (-993 (-568)) (-10 -8 (-15 -2745 ((-409 (-568)) $)) (-15 -2745 ((-1004 10) $)) (-15 -3880 ((-409 (-568)) $)) (-15 -4185 ($ (-409 (-568))))))) (T -208)) 
-((-2745 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-208)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-1004 10)) (-5 *1 (-208)))) (-3880 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-208)))) (-4185 (*1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-208))))) 
-(-13 (-993 (-568)) (-10 -8 (-15 -2745 ((-409 (-568)) $)) (-15 -2745 ((-1004 10) $)) (-15 -3880 ((-409 (-568)) $)) (-15 -4185 ($ (-409 (-568)))))) 
-((-3837 (((-3 (|:| |f1| (-835 |#2|)) (|:| |f2| (-634 (-835 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1082 (-835 |#2|)) (-1143)) 27) (((-3 (|:| |f1| (-835 |#2|)) (|:| |f2| (-634 (-835 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1082 (-835 |#2|))) 23)) (-4097 (((-3 (|:| |f1| (-835 |#2|)) (|:| |f2| (-634 (-835 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1161) (-835 |#2|) (-835 |#2|) (-121)) 16))) 
-(((-209 |#1| |#2|) (-10 -7 (-15 -3837 ((-3 (|:| |f1| (-835 |#2|)) (|:| |f2| (-634 (-835 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1082 (-835 |#2|)))) (-15 -3837 ((-3 (|:| |f1| (-835 |#2|)) (|:| |f2| (-634 (-835 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1082 (-835 |#2|)) (-1143))) (-15 -4097 ((-3 (|:| |f1| (-835 |#2|)) (|:| |f2| (-634 (-835 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1161) (-835 |#2|) (-835 |#2|) (-121)))) (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568))) (-13 (-1181) (-959) (-29 |#1|))) (T -209)) 
-((-4097 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *4 (-1161)) (-5 *6 (-121)) (-4 *7 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-4 *3 (-13 (-1181) (-959) (-29 *7))) (-5 *2 (-3 (|:| |f1| (-835 *3)) (|:| |f2| (-634 (-835 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-209 *7 *3)) (-5 *5 (-835 *3)))) (-3837 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1082 (-835 *3))) (-5 *5 (-1143)) (-4 *3 (-13 (-1181) (-959) (-29 *6))) (-4 *6 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 *3)) (|:| |f2| (-634 (-835 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-209 *6 *3)))) (-3837 (*1 *2 *3 *4) (-12 (-5 *4 (-1082 (-835 *3))) (-4 *3 (-13 (-1181) (-959) (-29 *5))) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 *3)) (|:| |f2| (-634 (-835 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-209 *5 *3))))) 
-(-10 -7 (-15 -3837 ((-3 (|:| |f1| (-835 |#2|)) (|:| |f2| (-634 (-835 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1082 (-835 |#2|)))) (-15 -3837 ((-3 (|:| |f1| (-835 |#2|)) (|:| |f2| (-634 (-835 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1082 (-835 |#2|)) (-1143))) (-15 -4097 ((-3 (|:| |f1| (-835 |#2|)) (|:| |f2| (-634 (-835 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1161) (-835 |#2|) (-835 |#2|) (-121)))) 
-((-3837 (((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-409 (-953 |#1|)))) (-1143)) 44) (((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-409 (-953 |#1|))))) 41) (((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-310 |#1|))) (-1143)) 45) (((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-310 |#1|)))) 17))) 
-(((-210 |#1|) (-10 -7 (-15 -3837 ((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-310 |#1|))))) (-15 -3837 ((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-310 |#1|))) (-1143))) (-15 -3837 ((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-409 (-953 |#1|)))))) (-15 -3837 ((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-409 (-953 |#1|)))) (-1143)))) (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (T -210)) 
-((-3837 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1082 (-835 (-409 (-953 *6))))) (-5 *5 (-1143)) (-5 *3 (-409 (-953 *6))) (-4 *6 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 (-310 *6))) (|:| |f2| (-634 (-835 (-310 *6)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-210 *6)))) (-3837 (*1 *2 *3 *4) (-12 (-5 *4 (-1082 (-835 (-409 (-953 *5))))) (-5 *3 (-409 (-953 *5))) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 (-310 *5))) (|:| |f2| (-634 (-835 (-310 *5)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-210 *5)))) (-3837 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-409 (-953 *6))) (-5 *4 (-1082 (-835 (-310 *6)))) (-5 *5 (-1143)) (-4 *6 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 (-310 *6))) (|:| |f2| (-634 (-835 (-310 *6)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-210 *6)))) (-3837 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1082 (-835 (-310 *5)))) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 (-310 *5))) (|:| |f2| (-634 (-835 (-310 *5)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-210 *5))))) 
-(-10 -7 (-15 -3837 ((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-310 |#1|))))) (-15 -3837 ((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-310 |#1|))) (-1143))) (-15 -3837 ((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-409 (-953 |#1|)))))) (-15 -3837 ((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-409 (-953 |#1|)))) (-1143)))) 
-((-3092 (((-2 (|:| -2700 (-1157 |#1|)) (|:| |deg| (-917))) (-1157 |#1|)) 20)) (-2789 (((-634 (-310 |#2|)) (-310 |#2|) (-917)) 42))) 
-(((-211 |#1| |#2|) (-10 -7 (-15 -3092 ((-2 (|:| -2700 (-1157 |#1|)) (|:| |deg| (-917))) (-1157 |#1|))) (-15 -2789 ((-634 (-310 |#2|)) (-310 |#2|) (-917)))) (-1047) (-13 (-558) (-842))) (T -211)) 
-((-2789 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *6 (-13 (-558) (-842))) (-5 *2 (-634 (-310 *6))) (-5 *1 (-211 *5 *6)) (-5 *3 (-310 *6)) (-4 *5 (-1047)))) (-3092 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-2 (|:| -2700 (-1157 *4)) (|:| |deg| (-917)))) (-5 *1 (-211 *4 *5)) (-5 *3 (-1157 *4)) (-4 *5 (-13 (-558) (-842)))))) 
-(-10 -7 (-15 -3092 ((-2 (|:| -2700 (-1157 |#1|)) (|:| |deg| (-917))) (-1157 |#1|))) (-15 -2789 ((-634 (-310 |#2|)) (-310 |#2|) (-917)))) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1815 ((|#1| $) 25)) (-2616 ((|#1| $) 26)) (-2510 (((-121) $ (-763)) NIL)) (-2671 (($) NIL T CONST)) (-3475 (($ $) NIL)) (-1578 (($ $) 32)) (-2918 ((|#1| |#1| $) NIL)) (-2899 ((|#1| $) NIL)) (-4360 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) NIL)) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3674 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-3678 (((-763) $) NIL)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-1890 ((|#1| $) NIL)) (-1871 ((|#1| |#1| $) 29)) (-4308 ((|#1| |#1| $) 31)) (-4450 (($ |#1| $) NIL)) (-2961 (((-763) $) 27)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3860 ((|#1| $) NIL)) (-2216 ((|#1| $) 24)) (-3923 ((|#1| $) 8)) (-1315 ((|#1| $) NIL)) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-1383 ((|#1| |#1| $) NIL)) (-3084 (((-121) $) 15)) (-3248 (($) NIL)) (-2368 ((|#1| $) NIL)) (-1612 (($) NIL) (($ (-634 |#1|)) 13)) (-4154 (((-763) $) 28)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) NIL)) (-2745 (((-850) $) NIL (|has| |#1| (-1090)))) (-3286 ((|#1| $) 9)) (-2367 (($ (-634 |#1|)) NIL)) (-4190 ((|#1| $) NIL)) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-212 |#1|) (-13 (-247 |#1|) (-10 -8 (-15 -1612 ($ (-634 |#1|))) (-15 -2368 (|#1| $)) (-15 -1315 (|#1| $)) (-15 -1383 (|#1| |#1| $)) (-15 -4450 ($ |#1| $)) (-15 -1890 (|#1| $)) (-15 -3860 (|#1| $)) (-15 -4190 (|#1| $)) (-15 -3475 ($ $)) (-15 -3678 ((-763) $)) (-15 -2166 ((-121) $ (-763))) (-15 -1737 ((-121) $ (-763))) (-15 -2510 ((-121) $ (-763))) (-15 -2367 ($ (-634 |#1|))) (-15 -3084 ((-121) $)) (-15 -3248 ($)) (-15 -2671 ($)) (-15 -3863 ($ $)) (-15 -3171 ((-121) $ $)) (-15 -2795 ($ (-1 |#1| |#1|) $)) (-15 -4154 ((-763) $)) (-15 -1612 ($)) (-15 -2961 ((-763) $)) (-15 -2616 (|#1| $)) (-15 -3286 (|#1| $)) (-15 -3923 (|#1| $)) (-15 -2216 (|#1| $)) (-15 -4308 (|#1| |#1| $)) (-15 -1871 (|#1| |#1| $)) (-15 -2899 (|#1| $)) (-15 -2918 (|#1| |#1| $)) (-15 -1578 ($ $)) (-15 -1815 (|#1| $)) (IF (|has| $ (-6 -4520)) (-15 -3674 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-15 -4487 ((-1143) $)) (-15 -4022 ((-1108) $)) (-15 -2745 ((-850) $)) (-15 -1717 ((-121) $ $)) (-15 -2447 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4519)) (PROGN (-15 -1387 ((-121) (-1 (-121) |#1|) $)) (-15 -1319 ((-121) (-1 (-121) |#1|) $)) (-15 -4168 ((-763) (-1 (-121) |#1|) $)) (-15 -1697 ((-763) $)) (-15 -4360 ((-634 |#1|) $)) (-15 -1979 ((-634 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4519)) (IF (|has| |#1| (-1090)) (PROGN (-15 -3109 ((-121) |#1| $)) (-15 -4168 ((-763) |#1| $))) |noBranch|) |noBranch|))) (-1090)) (T -212)) 
-((-3171 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) (-3863 (*1 *1 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-3248 (*1 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-3084 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) (-2166 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-212 *4)) (-4 *4 (-1090)))) (-1737 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-212 *4)) (-4 *4 (-1090)))) (-2510 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-212 *4)) (-4 *4 (-1090)))) (-2671 (*1 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-1697 (*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-763)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) (-2795 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-212 *3)))) (-3674 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4520)) (-4 *3 (-1090)) (-5 *1 (-212 *3)))) (-1319 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-212 *4)))) (-1387 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-212 *4)))) (-4168 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-763)) (-5 *1 (-212 *4)))) (-4360 (*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-634 *3)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) (-1979 (*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-634 *3)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) (-4168 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-763)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-3109 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-121)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-4487 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-4022 (*1 *2 *1) (-12 (-5 *2 (-1108)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-1717 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2447 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2367 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-212 *3)))) (-1315 (*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-4450 (*1 *1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-1890 (*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-2918 (*1 *2 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-2899 (*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-2616 (*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-4154 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) (-4190 (*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-3860 (*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-3678 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) (-3475 (*1 *1 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-2368 (*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-1383 (*1 *2 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-1612 (*1 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-1612 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-212 *3)))) (-2961 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) (-1815 (*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-3286 (*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-1871 (*1 *2 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-4308 (*1 *2 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-2216 (*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-3923 (*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-1578 (*1 *1 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090))))) 
-(-13 (-247 |#1|) (-10 -8 (-15 -1612 ($ (-634 |#1|))) (-15 -2368 (|#1| $)) (-15 -1315 (|#1| $)) (-15 -1383 (|#1| |#1| $)) (-15 -4450 ($ |#1| $)) (-15 -1890 (|#1| $)) (-15 -3860 (|#1| $)) (-15 -4190 (|#1| $)) (-15 -3475 ($ $)) (-15 -3678 ((-763) $)) (-15 -2166 ((-121) $ (-763))) (-15 -1737 ((-121) $ (-763))) (-15 -2510 ((-121) $ (-763))) (-15 -2367 ($ (-634 |#1|))) (-15 -3084 ((-121) $)) (-15 -3248 ($)) (-15 -2671 ($)) (-15 -3863 ($ $)) (-15 -3171 ((-121) $ $)) (-15 -2795 ($ (-1 |#1| |#1|) $)) (-15 -4154 ((-763) $)) (-15 -1612 ($)) (-15 -2961 ((-763) $)) (-15 -2616 (|#1| $)) (-15 -3286 (|#1| $)) (-15 -3923 (|#1| $)) (-15 -2216 (|#1| $)) (-15 -4308 (|#1| |#1| $)) (-15 -1871 (|#1| |#1| $)) (-15 -2899 (|#1| $)) (-15 -2918 (|#1| |#1| $)) (-15 -1578 ($ $)) (-15 -1815 (|#1| $)) (IF (|has| $ (-6 -4520)) (-15 -3674 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-15 -4487 ((-1143) $)) (-15 -4022 ((-1108) $)) (-15 -2745 ((-850) $)) (-15 -1717 ((-121) $ $)) (-15 -2447 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4519)) (PROGN (-15 -1387 ((-121) (-1 (-121) |#1|) $)) (-15 -1319 ((-121) (-1 (-121) |#1|) $)) (-15 -4168 ((-763) (-1 (-121) |#1|) $)) (-15 -1697 ((-763) $)) (-15 -4360 ((-634 |#1|) $)) (-15 -1979 ((-634 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4519)) (IF (|has| |#1| (-1090)) (PROGN (-15 -3109 ((-121) |#1| $)) (-15 -4168 ((-763) |#1| $))) |noBranch|) |noBranch|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-4237 (($ (-310 |#1|)) 23)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-3374 (((-121) $) NIL)) (-3666 (((-3 (-310 |#1|) "failed") $) NIL)) (-2854 (((-310 |#1|) $) NIL)) (-2114 (($ $) 31)) (-2925 (((-3 $ "failed") $) NIL)) (-2735 (((-121) $) NIL)) (-2795 (($ (-1 (-310 |#1|) (-310 |#1|)) $) NIL)) (-2102 (((-310 |#1|) $) NIL)) (-3939 (($ $) 30)) (-4487 (((-1143) $) NIL)) (-4494 (((-121) $) NIL)) (-4022 (((-1108) $) NIL)) (-2704 (($ (-763)) NIL)) (-3075 (($ $) 32)) (-3206 (((-568) $) NIL)) (-2745 (((-850) $) 57) (($ (-568)) NIL) (($ (-310 |#1|)) NIL)) (-2604 (((-310 |#1|) $ $) NIL)) (-4078 (((-763)) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 25 T CONST)) (-1556 (($) 50 T CONST)) (-1717 (((-121) $ $) 28)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) 19)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 24) (($ (-310 |#1|) $) 18))) 
-(((-213 |#1| |#2|) (-13 (-612 (-310 |#1|)) (-1037 (-310 |#1|)) (-10 -8 (-15 -2102 ((-310 |#1|) $)) (-15 -3939 ($ $)) (-15 -2114 ($ $)) (-15 -2604 ((-310 |#1|) $ $)) (-15 -2704 ($ (-763))) (-15 -4494 ((-121) $)) (-15 -3374 ((-121) $)) (-15 -3206 ((-568) $)) (-15 -2795 ($ (-1 (-310 |#1|) (-310 |#1|)) $)) (-15 -4237 ($ (-310 |#1|))) (-15 -3075 ($ $)))) (-13 (-1047) (-842)) (-634 (-1161))) (T -213)) 
-((-2102 (*1 *2 *1) (-12 (-5 *2 (-310 *3)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161))))) (-3939 (*1 *1 *1) (-12 (-5 *1 (-213 *2 *3)) (-4 *2 (-13 (-1047) (-842))) (-14 *3 (-634 (-1161))))) (-2114 (*1 *1 *1) (-12 (-5 *1 (-213 *2 *3)) (-4 *2 (-13 (-1047) (-842))) (-14 *3 (-634 (-1161))))) (-2604 (*1 *2 *1 *1) (-12 (-5 *2 (-310 *3)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161))))) (-2704 (*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161))))) (-4494 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161))))) (-3374 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161))))) (-3206 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161))))) (-2795 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-310 *3) (-310 *3))) (-4 *3 (-13 (-1047) (-842))) (-5 *1 (-213 *3 *4)) (-14 *4 (-634 (-1161))))) (-4237 (*1 *1 *2) (-12 (-5 *2 (-310 *3)) (-4 *3 (-13 (-1047) (-842))) (-5 *1 (-213 *3 *4)) (-14 *4 (-634 (-1161))))) (-3075 (*1 *1 *1) (-12 (-5 *1 (-213 *2 *3)) (-4 *2 (-13 (-1047) (-842))) (-14 *3 (-634 (-1161)))))) 
-(-13 (-612 (-310 |#1|)) (-1037 (-310 |#1|)) (-10 -8 (-15 -2102 ((-310 |#1|) $)) (-15 -3939 ($ $)) (-15 -2114 ($ $)) (-15 -2604 ((-310 |#1|) $ $)) (-15 -2704 ($ (-763))) (-15 -4494 ((-121) $)) (-15 -3374 ((-121) $)) (-15 -3206 ((-568) $)) (-15 -2795 ($ (-1 (-310 |#1|) (-310 |#1|)) $)) (-15 -4237 ($ (-310 |#1|))) (-15 -3075 ($ $)))) 
-((-2042 (((-121) (-1143)) 22)) (-3793 (((-3 (-835 |#2|) "failed") (-607 |#2|) |#2| (-835 |#2|) (-835 |#2|) (-121)) 32)) (-3554 (((-3 (-121) "failed") (-1157 |#2|) (-835 |#2|) (-835 |#2|) (-121)) 73) (((-3 (-121) "failed") (-953 |#1|) (-1161) (-835 |#2|) (-835 |#2|) (-121)) 74))) 
-(((-214 |#1| |#2|) (-10 -7 (-15 -2042 ((-121) (-1143))) (-15 -3793 ((-3 (-835 |#2|) "failed") (-607 |#2|) |#2| (-835 |#2|) (-835 |#2|) (-121))) (-15 -3554 ((-3 (-121) "failed") (-953 |#1|) (-1161) (-835 |#2|) (-835 |#2|) (-121))) (-15 -3554 ((-3 (-121) "failed") (-1157 |#2|) (-835 |#2|) (-835 |#2|) (-121)))) (-13 (-453) (-842) (-1037 (-568)) (-630 (-568))) (-13 (-1181) (-29 |#1|))) (T -214)) 
-((-3554 (*1 *2 *3 *4 *4 *2) (|partial| -12 (-5 *2 (-121)) (-5 *3 (-1157 *6)) (-5 *4 (-835 *6)) (-4 *6 (-13 (-1181) (-29 *5))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-214 *5 *6)))) (-3554 (*1 *2 *3 *4 *5 *5 *2) (|partial| -12 (-5 *2 (-121)) (-5 *3 (-953 *6)) (-5 *4 (-1161)) (-5 *5 (-835 *7)) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-4 *7 (-13 (-1181) (-29 *6))) (-5 *1 (-214 *6 *7)))) (-3793 (*1 *2 *3 *4 *2 *2 *5) (|partial| -12 (-5 *2 (-835 *4)) (-5 *3 (-607 *4)) (-5 *5 (-121)) (-4 *4 (-13 (-1181) (-29 *6))) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-214 *6 *4)))) (-2042 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-121)) (-5 *1 (-214 *4 *5)) (-4 *5 (-13 (-1181) (-29 *4)))))) 
-(-10 -7 (-15 -2042 ((-121) (-1143))) (-15 -3793 ((-3 (-835 |#2|) "failed") (-607 |#2|) |#2| (-835 |#2|) (-835 |#2|) (-121))) (-15 -3554 ((-3 (-121) "failed") (-953 |#1|) (-1161) (-835 |#2|) (-835 |#2|) (-121))) (-15 -3554 ((-3 (-121) "failed") (-1157 |#2|) (-835 |#2|) (-835 |#2|) (-121)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 95)) (-1492 (((-568) $) 124)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-2617 (($ $) NIL)) (-1982 (($ $) 83)) (-1933 (($ $) 71)) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1902 (($ $) 62)) (-1497 (((-121) $ $) NIL)) (-1974 (($ $) 81)) (-2786 (($ $) 69)) (-3662 (((-568) $) 137)) (-1990 (($ $) 86)) (-1941 (($ $) 73)) (-2671 (($) NIL T CONST)) (-3047 (($ $) NIL)) (-3666 (((-3 (-568) "failed") $) 120) (((-3 (-409 (-568)) "failed") $) 135)) (-2854 (((-568) $) 136) (((-409 (-568)) $) 133)) (-2401 (($ $ $) NIL)) (-2925 (((-3 $ "failed") $) 98)) (-4036 (((-409 (-568)) $ (-763)) 131) (((-409 (-568)) $ (-763) (-763)) 130)) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-3359 (((-917)) 34) (((-917) (-917)) NIL (|has| $ (-6 -4510)))) (-2033 (((-121) $) NIL)) (-1303 (($ $ $) 123)) (-1897 (($) 44)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL)) (-4477 (((-568) $) 40)) (-2735 (((-121) $) NIL)) (-4044 (($ $ (-568)) NIL)) (-2657 (($ $) NIL)) (-2245 (((-121) $) 94)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2521 (($ $ $) 59) (($) 39 (-12 (-3044 (|has| $ (-6 -4502))) (-3044 (|has| $ (-6 -4510)))))) (-3268 (($ $ $) 58) (($) 38 (-12 (-3044 (|has| $ (-6 -4502))) (-3044 (|has| $ (-6 -4510)))))) (-3544 (((-568) $) 32)) (-2605 (((-409 (-568)) $) 27)) (-4299 (($ $) 35)) (-1907 (($ $) 63)) (-4416 (($ $) 68)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4225 (((-634 (-568)) $) 29)) (-2719 (((-917) (-568)) NIL (|has| $ (-6 -4510)))) (-4022 (((-1108) $) NIL) (((-568) $) 96)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3880 (($ $) NIL)) (-1519 (($ $) NIL)) (-3768 (($ (-568) (-568)) NIL) (($ (-568) (-568) (-917)) 125)) (-3848 (((-420 $) $) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3438 (((-568) $) 33)) (-2078 (($) 43)) (-1892 (($ $) 67)) (-2709 (((-763) $) NIL)) (-4440 (((-1143) (-1143)) 8)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3396 (((-917)) NIL) (((-917) (-917)) NIL (|has| $ (-6 -4510)))) (-1847 (($ $) 116)) (-4189 (($ $ (-763)) NIL) (($ $) 99)) (-2573 (((-917) (-568)) NIL (|has| $ (-6 -4510)))) (-1994 (($ $) 84)) (-1945 (($ $) 74)) (-1986 (($ $) 85)) (-1937 (($ $) 72)) (-1978 (($ $) 82)) (-2790 (($ $) 70)) (-4278 (((-381) $) 129) (((-215) $) 126) (((-887 (-381)) $) NIL) (((-541) $) 51)) (-2745 (((-850) $) 48) (($ (-568)) 66) (($ $) NIL) (($ (-409 (-568))) NIL) (($ (-568)) 66) (($ (-409 (-568))) NIL)) (-4078 (((-763)) NIL)) (-2285 (($ $) NIL)) (-4042 (((-917)) 37) (((-917) (-917)) NIL (|has| $ (-6 -4510)))) (-3657 (($ $ $) 112)) (-2375 (($ $ $) 110)) (-1369 (($ $ $) 108)) (-3737 (($ $ $) 106)) (-1461 (((-917)) 31)) (-2006 (($ $) 89)) (-1958 (($ $) 77) (($ $ $) 132)) (-1826 (((-121) $ $) NIL)) (-1998 (($ $) 87)) (-1949 (($ $) 75)) (-2014 (($ $) 92)) (-1966 (($ $) 80)) (-3828 (($ $) 104)) (-2357 (($ $) 102)) (-4023 (($ $) 90)) (-1970 (($ $) 78)) (-2010 (($ $) 91)) (-1962 (($ $) 79)) (-2002 (($ $) 88)) (-1953 (($ $) 76)) (-2897 (($ $) 138)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) 41 T CONST)) (-1556 (($) 42 T CONST)) (-3754 (((-1143) $) 19) (((-1143) $ (-121)) 21) (((-1249) (-817) $) 22) (((-1249) (-817) $ (-121)) 23)) (-3929 (($ $) 118) (($ $ $) NIL)) (-3190 (($ $ (-763)) NIL) (($ $) NIL)) (-3792 (($ $ $) 114)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 60)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 52)) (-1779 (($ $ $) 93) (($ $ (-568)) 61)) (-1773 (($ $) 53) (($ $ $) 55)) (-1767 (($ $ $) 54)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) 64) (($ $ (-409 (-568))) 148) (($ $ $) 65)) (* (($ (-917) $) 36) (($ (-763) $) NIL) (($ (-568) $) 57) (($ $ $) 56) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL))) 
-(((-215) (-13 (-406) (-225) (-823) (-1181) (-1124) (-609 (-541)) (-10 -8 (-15 -1779 ($ $ (-568))) (-15 ** ($ $ $)) (-15 -2078 ($)) (-15 -4022 ((-568) $)) (-15 -4299 ($ $)) (-15 -1907 ($ $)) (-15 -1958 ($ $ $)) (-15 -3929 ($ $)) (-15 -3792 ($ $ $)) (-15 -4440 ((-1143) (-1143))) (-15 -4036 ((-409 (-568)) $ (-763))) (-15 -4036 ((-409 (-568)) $ (-763) (-763))) (-15 -2605 ((-409 (-568)) $)) (-15 -4225 ((-634 (-568)) $))))) (T -215)) 
-((** (*1 *1 *1 *1) (-5 *1 (-215))) (-3929 (*1 *1 *1) (-5 *1 (-215))) (-3792 (*1 *1 *1 *1) (-5 *1 (-215))) (-1779 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-215)))) (-2078 (*1 *1) (-5 *1 (-215))) (-4022 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-215)))) (-4299 (*1 *1 *1) (-5 *1 (-215))) (-1907 (*1 *1 *1) (-5 *1 (-215))) (-1958 (*1 *1 *1 *1) (-5 *1 (-215))) (-4440 (*1 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-215)))) (-4036 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-409 (-568))) (-5 *1 (-215)))) (-4036 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-409 (-568))) (-5 *1 (-215)))) (-2605 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-215)))) (-4225 (*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-215))))) 
-(-13 (-406) (-225) (-823) (-1181) (-1124) (-609 (-541)) (-10 -8 (-15 -1779 ($ $ (-568))) (-15 ** ($ $ $)) (-15 -2078 ($)) (-15 -4022 ((-568) $)) (-15 -4299 ($ $)) (-15 -1907 ($ $)) (-15 -1958 ($ $ $)) (-15 -3929 ($ $)) (-15 -3792 ($ $ $)) (-15 -4440 ((-1143) (-1143))) (-15 -4036 ((-409 (-568)) $ (-763))) (-15 -4036 ((-409 (-568)) $ (-763) (-763))) (-15 -2605 ((-409 (-568)) $)) (-15 -4225 ((-634 (-568)) $)))) 
-((-2447 (((-121) $ $) NIL (|has| (-215) (-1090)))) (-3205 (($ (-763) (-763)) NIL)) (-3347 (($ $ $) NIL)) (-2870 (($ (-218)) NIL) (($ $) NIL)) (-1335 (((-121) $) NIL)) (-4343 (($ $ (-568) (-568)) NIL)) (-3622 (($ $ (-568) (-568)) NIL)) (-3676 (($ $ (-568) (-568) (-568) (-568)) NIL)) (-3976 (($ $) NIL)) (-2230 (((-121) $) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-1785 (($ $ (-568) (-568) $) NIL)) (-2436 (((-215) $ (-568) (-568) (-215)) NIL) (($ $ (-634 (-568)) (-634 (-568)) $) NIL)) (-4159 (($ $ (-568) (-218)) NIL)) (-2451 (($ $ (-568) (-218)) NIL)) (-3422 (($ (-763) (-215)) NIL)) (-2671 (($) NIL T CONST)) (-4167 (($ $) NIL (|has| (-215) (-301)))) (-1818 (((-218) $ (-568)) NIL)) (-3700 (((-763) $) NIL (|has| (-215) (-558)))) (-3989 (((-215) $ (-568) (-568) (-215)) 16)) (-3615 (($ (-568) (-568)) 18)) (-2602 (((-215) $ (-568) (-568)) 15)) (-2076 (((-215) $) NIL (|has| (-215) (-172)))) (-4360 (((-634 (-215)) $) NIL)) (-2121 (((-763) $) NIL (|has| (-215) (-558)))) (-4272 (((-634 (-218)) $) NIL (|has| (-215) (-558)))) (-3043 (((-763) $) 10)) (-1849 (($ (-763) (-763) (-215)) 19)) (-2555 (((-763) $) 11)) (-1737 (((-121) $ (-763)) NIL)) (-3082 (((-215) $) NIL (|has| (-215) (-6 (-4521 "*"))))) (-2087 (((-568) $) 7)) (-3364 (((-568) $) 8)) (-1979 (((-634 (-215)) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) (-215) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-215) (-1090))))) (-1663 (((-568) $) 12)) (-2893 (((-568) $) 13)) (-2269 (($ (-634 (-634 (-215)))) NIL)) (-3674 (($ (-1 (-215) (-215)) $) NIL)) (-2795 (($ (-1 (-215) (-215)) $) NIL) (($ (-1 (-215) (-215) (-215)) $ $) NIL) (($ (-1 (-215) (-215) (-215)) $ $ (-215)) NIL)) (-3208 (((-634 (-634 (-215))) $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (|has| (-215) (-1090)))) (-3140 (((-3 $ "failed") $) NIL (|has| (-215) (-365)))) (-2858 (($ $ $) NIL)) (-4022 (((-1108) $) NIL (|has| (-215) (-1090)))) (-3724 (($ $ (-215)) NIL)) (-2595 (((-3 $ "failed") $ (-215)) NIL (|has| (-215) (-558)))) (-1387 (((-121) (-1 (-121) (-215)) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-215)))) NIL (-12 (|has| (-215) (-303 (-215))) (|has| (-215) (-1090)))) (($ $ (-288 (-215))) NIL (-12 (|has| (-215) (-303 (-215))) (|has| (-215) (-1090)))) (($ $ (-215) (-215)) NIL (-12 (|has| (-215) (-303 (-215))) (|has| (-215) (-1090)))) (($ $ (-634 (-215)) (-634 (-215))) NIL (-12 (|has| (-215) (-303 (-215))) (|has| (-215) (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) 17)) (-2779 (((-215) $ (-568) (-568)) NIL) (((-215) $ (-568) (-568) (-215)) NIL) (($ $ (-634 (-568)) (-634 (-568))) NIL)) (-2282 (($ (-634 (-215))) NIL) (($ (-634 $)) NIL)) (-1960 (((-121) $) NIL)) (-2465 (((-215) $) NIL (|has| (-215) (-6 (-4521 "*"))))) (-4168 (((-763) (-1 (-121) (-215)) $) NIL (|has| $ (-6 -4519))) (((-763) (-215) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-215) (-1090))))) (-3863 (($ $) NIL)) (-2365 (((-634 (-218)) $) NIL (|has| (-215) (-301)))) (-3731 (((-218) $ (-568)) NIL)) (-2745 (((-850) $) NIL (|has| (-215) (-1090))) (($ (-218)) NIL)) (-1319 (((-121) (-1 (-121) (-215)) $) NIL (|has| $ (-6 -4519)))) (-1910 (((-121) $) NIL)) (-1717 (((-121) $ $) NIL (|has| (-215) (-1090)))) (-1779 (($ $ (-215)) NIL (|has| (-215) (-365)))) (-1773 (($ $ $) NIL) (($ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| (-215) (-365)))) (* (($ $ $) NIL) (($ (-215) $) NIL) (($ $ (-215)) NIL) (($ (-568) $) NIL) (((-218) $ (-218)) NIL) (((-218) (-218) $) NIL)) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-216) (-13 (-677 (-215) (-218) (-218)) (-10 -8 (-15 -3615 ($ (-568) (-568)))))) (T -216)) 
-((-3615 (*1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-216))))) 
-(-13 (-677 (-215) (-218) (-218)) (-10 -8 (-15 -3615 ($ (-568) (-568))))) 
-((-1303 (((-169 (-215)) (-763) (-169 (-215))) 40) (((-215) (-763) (-215)) 41)) (-3789 (((-169 (-215)) (-169 (-215))) 42) (((-215) (-215)) 43)) (-2165 (((-169 (-215)) (-169 (-215)) (-169 (-215))) 48) (((-215) (-215) (-215)) 51)) (-1847 (((-169 (-215)) (-169 (-215))) 53) (((-215) (-215)) 52)) (-3657 (((-169 (-215)) (-169 (-215)) (-169 (-215))) 70) (((-215) (-215) (-215)) 62)) (-2375 (((-169 (-215)) (-169 (-215)) (-169 (-215))) 73) (((-215) (-215) (-215)) 71)) (-1369 (((-169 (-215)) (-169 (-215)) (-169 (-215))) 44) (((-215) (-215) (-215)) 45)) (-3737 (((-169 (-215)) (-169 (-215)) (-169 (-215))) 46) (((-215) (-215) (-215)) 47)) (-3828 (((-169 (-215)) (-169 (-215))) 84) (((-215) (-215)) 83)) (-2357 (((-215) (-215)) 78) (((-169 (-215)) (-169 (-215))) 82)) (-3929 (((-169 (-215)) (-169 (-215))) 7) (((-215) (-215)) 9)) (-1622 (((-828 (-215)) (-568) (-215)) 23)) (-1812 (((-828 (-215)) (-828 (-215))) 36)) (-3153 (((-828 (-215)) (-828 (-215))) 35)) (-3435 (((-828 (-215)) (-828 (-215))) 34)) (-3716 (((-828 (-215)) (-828 (-215))) 33)) (-4005 (((-828 (-215)) (-828 (-215))) 32)) (-2241 (((-828 (-215)) (-828 (-215))) 31)) (-1969 (((-828 (-215)) (-828 (-215))) 37)) (-1993 (((-828 (-215)) (-215)) 22)) (-3792 (((-169 (-215)) (-169 (-215)) (-169 (-215))) 58) (((-215) (-215) (-215)) 54))) 
-(((-217) (-10 -7 (-15 -3929 ((-215) (-215))) (-15 -3929 ((-169 (-215)) (-169 (-215)))) (-15 -1993 ((-828 (-215)) (-215))) (-15 -1622 ((-828 (-215)) (-568) (-215))) (-15 -1969 ((-828 (-215)) (-828 (-215)))) (-15 -2241 ((-828 (-215)) (-828 (-215)))) (-15 -4005 ((-828 (-215)) (-828 (-215)))) (-15 -3716 ((-828 (-215)) (-828 (-215)))) (-15 -3435 ((-828 (-215)) (-828 (-215)))) (-15 -3153 ((-828 (-215)) (-828 (-215)))) (-15 -1812 ((-828 (-215)) (-828 (-215)))) (-15 -3792 ((-215) (-215) (-215))) (-15 -3792 ((-169 (-215)) (-169 (-215)) (-169 (-215)))) (-15 -3789 ((-215) (-215))) (-15 -3789 ((-169 (-215)) (-169 (-215)))) (-15 -1847 ((-215) (-215))) (-15 -1847 ((-169 (-215)) (-169 (-215)))) (-15 -1303 ((-215) (-763) (-215))) (-15 -1303 ((-169 (-215)) (-763) (-169 (-215)))) (-15 -1369 ((-215) (-215) (-215))) (-15 -1369 ((-169 (-215)) (-169 (-215)) (-169 (-215)))) (-15 -3657 ((-215) (-215) (-215))) (-15 -3657 ((-169 (-215)) (-169 (-215)) (-169 (-215)))) (-15 -3737 ((-215) (-215) (-215))) (-15 -3737 ((-169 (-215)) (-169 (-215)) (-169 (-215)))) (-15 -2375 ((-215) (-215) (-215))) (-15 -2375 ((-169 (-215)) (-169 (-215)) (-169 (-215)))) (-15 -2357 ((-169 (-215)) (-169 (-215)))) (-15 -2357 ((-215) (-215))) (-15 -3828 ((-215) (-215))) (-15 -3828 ((-169 (-215)) (-169 (-215)))) (-15 -2165 ((-215) (-215) (-215))) (-15 -2165 ((-169 (-215)) (-169 (-215)) (-169 (-215)))))) (T -217)) 
-((-2165 (*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) (-2165 (*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) (-3828 (*1 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) (-3828 (*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) (-2357 (*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) (-2357 (*1 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) (-2375 (*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) (-2375 (*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) (-3737 (*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) (-3737 (*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) (-3657 (*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) (-3657 (*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) (-1369 (*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) (-1369 (*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) (-1303 (*1 *2 *3 *2) (-12 (-5 *2 (-169 (-215))) (-5 *3 (-763)) (-5 *1 (-217)))) (-1303 (*1 *2 *3 *2) (-12 (-5 *2 (-215)) (-5 *3 (-763)) (-5 *1 (-217)))) (-1847 (*1 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) (-1847 (*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) (-3789 (*1 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) (-3789 (*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) (-3792 (*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) (-3792 (*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) (-1812 (*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217)))) (-3153 (*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217)))) (-3435 (*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217)))) (-3716 (*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217)))) (-4005 (*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217)))) (-2241 (*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217)))) (-1969 (*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217)))) (-1622 (*1 *2 *3 *4) (-12 (-5 *3 (-568)) (-5 *2 (-828 (-215))) (-5 *1 (-217)) (-5 *4 (-215)))) (-1993 (*1 *2 *3) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217)) (-5 *3 (-215)))) (-3929 (*1 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) (-3929 (*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217))))) 
-(-10 -7 (-15 -3929 ((-215) (-215))) (-15 -3929 ((-169 (-215)) (-169 (-215)))) (-15 -1993 ((-828 (-215)) (-215))) (-15 -1622 ((-828 (-215)) (-568) (-215))) (-15 -1969 ((-828 (-215)) (-828 (-215)))) (-15 -2241 ((-828 (-215)) (-828 (-215)))) (-15 -4005 ((-828 (-215)) (-828 (-215)))) (-15 -3716 ((-828 (-215)) (-828 (-215)))) (-15 -3435 ((-828 (-215)) (-828 (-215)))) (-15 -3153 ((-828 (-215)) (-828 (-215)))) (-15 -1812 ((-828 (-215)) (-828 (-215)))) (-15 -3792 ((-215) (-215) (-215))) (-15 -3792 ((-169 (-215)) (-169 (-215)) (-169 (-215)))) (-15 -3789 ((-215) (-215))) (-15 -3789 ((-169 (-215)) (-169 (-215)))) (-15 -1847 ((-215) (-215))) (-15 -1847 ((-169 (-215)) (-169 (-215)))) (-15 -1303 ((-215) (-763) (-215))) (-15 -1303 ((-169 (-215)) (-763) (-169 (-215)))) (-15 -1369 ((-215) (-215) (-215))) (-15 -1369 ((-169 (-215)) (-169 (-215)) (-169 (-215)))) (-15 -3657 ((-215) (-215) (-215))) (-15 -3657 ((-169 (-215)) (-169 (-215)) (-169 (-215)))) (-15 -3737 ((-215) (-215) (-215))) (-15 -3737 ((-169 (-215)) (-169 (-215)) (-169 (-215)))) (-15 -2375 ((-215) (-215) (-215))) (-15 -2375 ((-169 (-215)) (-169 (-215)) (-169 (-215)))) (-15 -2357 ((-169 (-215)) (-169 (-215)))) (-15 -2357 ((-215) (-215))) (-15 -3828 ((-215) (-215))) (-15 -3828 ((-169 (-215)) (-169 (-215)))) (-15 -2165 ((-215) (-215) (-215))) (-15 -2165 ((-169 (-215)) (-169 (-215)) (-169 (-215))))) 
-((-2447 (((-121) $ $) NIL (|has| (-215) (-1090)))) (-3205 (($ (-763)) NIL (|has| (-215) (-23)))) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-2016 (((-121) (-1 (-121) (-215) (-215)) $) NIL) (((-121) $) NIL (|has| (-215) (-842)))) (-3908 (($ (-1 (-121) (-215) (-215)) $) NIL (|has| $ (-6 -4520))) (($ $) NIL (-12 (|has| $ (-6 -4520)) (|has| (-215) (-842))))) (-3644 (($ (-1 (-121) (-215) (-215)) $) NIL) (($ $) NIL (|has| (-215) (-842)))) (-2510 (((-121) $ (-763)) NIL)) (-2436 (((-215) $ (-568) (-215)) 17 (|has| $ (-6 -4520))) (((-215) $ (-1210 (-568)) (-215)) NIL (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) (-215)) $) NIL (|has| $ (-6 -4519)))) (-2671 (($) NIL T CONST)) (-1578 (($ $) NIL (|has| $ (-6 -4520)))) (-3943 (($ $) NIL)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-215) (-1090))))) (-4328 (($ (-215) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-215) (-1090)))) (($ (-1 (-121) (-215)) $) NIL (|has| $ (-6 -4519)))) (-3092 (((-215) (-1 (-215) (-215) (-215)) $ (-215) (-215)) NIL (-12 (|has| $ (-6 -4519)) (|has| (-215) (-1090)))) (((-215) (-1 (-215) (-215) (-215)) $ (-215)) NIL (|has| $ (-6 -4519))) (((-215) (-1 (-215) (-215) (-215)) $) NIL (|has| $ (-6 -4519)))) (-3989 (((-215) $ (-568) (-215)) 9 (|has| $ (-6 -4520)))) (-3615 (($ (-568)) 14)) (-2602 (((-215) $ (-568)) 8)) (-2764 (((-568) (-1 (-121) (-215)) $) NIL) (((-568) (-215) $) NIL (|has| (-215) (-1090))) (((-568) (-215) $ (-568)) NIL (|has| (-215) (-1090)))) (-4360 (((-634 (-215)) $) NIL (|has| $ (-6 -4519)))) (-1802 (((-679 (-215)) $ $) NIL (|has| (-215) (-1047)))) (-1849 (($ (-763) (-215)) 15)) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) 12 (|has| (-568) (-842)))) (-2521 (($ $ $) NIL (|has| (-215) (-842)))) (-1347 (($ (-1 (-121) (-215) (-215)) $ $) NIL) (($ $ $) NIL (|has| (-215) (-842)))) (-1979 (((-634 (-215)) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) (-215) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-215) (-1090))))) (-2223 (((-568) $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (|has| (-215) (-842)))) (-3674 (($ (-1 (-215) (-215)) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-215) (-215)) $) NIL) (($ (-1 (-215) (-215) (-215)) $ $) NIL)) (-1550 (((-215) $) NIL (-12 (|has| (-215) (-1002)) (|has| (-215) (-1047))))) (-2166 (((-121) $ (-763)) NIL)) (-3678 (((-215) $) NIL (-12 (|has| (-215) (-1002)) (|has| (-215) (-1047))))) (-4487 (((-1143) $) NIL (|has| (-215) (-1090)))) (-4122 (($ (-215) $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4022 (((-1108) $) NIL (|has| (-215) (-1090)))) (-3876 (((-215) $) NIL (|has| (-568) (-842)))) (-3775 (((-3 (-215) "failed") (-1 (-121) (-215)) $) NIL)) (-3724 (($ $ (-215)) 18 (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) (-215)) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-215)))) NIL (-12 (|has| (-215) (-303 (-215))) (|has| (-215) (-1090)))) (($ $ (-288 (-215))) NIL (-12 (|has| (-215) (-303 (-215))) (|has| (-215) (-1090)))) (($ $ (-215) (-215)) NIL (-12 (|has| (-215) (-303 (-215))) (|has| (-215) (-1090)))) (($ $ (-634 (-215)) (-634 (-215))) NIL (-12 (|has| (-215) (-303 (-215))) (|has| (-215) (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) (-215) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-215) (-1090))))) (-2041 (((-634 (-215)) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) 13)) (-2779 (((-215) $ (-568) (-215)) NIL) (((-215) $ (-568)) 16) (($ $ (-1210 (-568))) NIL)) (-3682 (((-215) $ $) NIL (|has| (-215) (-1047)))) (-2826 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-2748 (($ $ $) NIL (|has| (-215) (-1047)))) (-4168 (((-763) (-1 (-121) (-215)) $) NIL (|has| $ (-6 -4519))) (((-763) (-215) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-215) (-1090))))) (-2256 (($ $ $ (-568)) NIL (|has| $ (-6 -4520)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| (-215) (-609 (-541))))) (-4287 (($ (-634 (-215))) NIL)) (-2768 (($ $ (-215)) NIL) (($ (-215) $) NIL) (($ $ $) NIL) (($ (-634 $)) NIL)) (-2745 (((-850) $) NIL (|has| (-215) (-1090)))) (-1319 (((-121) (-1 (-121) (-215)) $) NIL (|has| $ (-6 -4519)))) (-1751 (((-121) $ $) NIL (|has| (-215) (-842)))) (-1738 (((-121) $ $) NIL (|has| (-215) (-842)))) (-1717 (((-121) $ $) NIL (|has| (-215) (-1090)))) (-1745 (((-121) $ $) NIL (|has| (-215) (-842)))) (-1732 (((-121) $ $) NIL (|has| (-215) (-842)))) (-1773 (($ $) NIL (|has| (-215) (-21))) (($ $ $) NIL (|has| (-215) (-21)))) (-1767 (($ $ $) NIL (|has| (-215) (-25)))) (* (($ (-568) $) NIL (|has| (-215) (-21))) (($ (-215) $) NIL (|has| (-215) (-716))) (($ $ (-215)) NIL (|has| (-215) (-716)))) (-1697 (((-763) $) 11 (|has| $ (-6 -4519))))) 
-(((-218) (-13 (-1242 (-215)) (-10 -8 (-15 -3615 ($ (-568)))))) (T -218)) 
-((-3615 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-218))))) 
-(-13 (-1242 (-215)) (-10 -8 (-15 -3615 ($ (-568))))) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3205 (($ (-763) (-763)) NIL)) (-3347 (($ $ $) NIL)) (-2870 (($ (-1244 |#1|)) NIL) (($ $) NIL)) (-1859 (($ |#1| |#1| |#1|) 32)) (-1335 (((-121) $) NIL)) (-4343 (($ $ (-568) (-568)) NIL)) (-3622 (($ $ (-568) (-568)) NIL)) (-3676 (($ $ (-568) (-568) (-568) (-568)) NIL)) (-3976 (($ $) NIL)) (-2230 (((-121) $) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-1785 (($ $ (-568) (-568) $) NIL)) (-2436 ((|#1| $ (-568) (-568) |#1|) NIL) (($ $ (-634 (-568)) (-634 (-568)) $) NIL)) (-4159 (($ $ (-568) (-1244 |#1|)) NIL)) (-2451 (($ $ (-568) (-1244 |#1|)) NIL)) (-3646 (($ |#1| |#1| |#1|) 31)) (-3422 (($ (-763) |#1|) NIL)) (-2671 (($) NIL T CONST)) (-4167 (($ $) NIL (|has| |#1| (-301)))) (-1818 (((-1244 |#1|) $ (-568)) NIL)) (-2264 (($ |#1|) 30)) (-2531 (($ |#1|) 29)) (-3101 (($ |#1|) 28)) (-3700 (((-763) $) NIL (|has| |#1| (-558)))) (-3989 ((|#1| $ (-568) (-568) |#1|) NIL)) (-2602 ((|#1| $ (-568) (-568)) NIL)) (-2076 ((|#1| $) NIL (|has| |#1| (-172)))) (-4360 (((-634 |#1|) $) NIL)) (-2121 (((-763) $) NIL (|has| |#1| (-558)))) (-4272 (((-634 (-1244 |#1|)) $) NIL (|has| |#1| (-558)))) (-3043 (((-763) $) NIL)) (-1849 (($ (-763) (-763) |#1|) NIL)) (-2555 (((-763) $) NIL)) (-1737 (((-121) $ (-763)) NIL)) (-3082 ((|#1| $) NIL (|has| |#1| (-6 (-4521 "*"))))) (-2087 (((-568) $) NIL)) (-3364 (((-568) $) NIL)) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-1663 (((-568) $) NIL)) (-2893 (((-568) $) NIL)) (-2269 (($ (-634 (-634 |#1|))) 10)) (-3674 (($ (-1 |#1| |#1|) $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-3208 (((-634 (-634 |#1|)) $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-3140 (((-3 $ "failed") $) NIL (|has| |#1| (-365)))) (-3313 (($) 11)) (-2858 (($ $ $) NIL)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3724 (($ $ |#1|) NIL)) (-2595 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558)))) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#1| $ (-568) (-568)) NIL) ((|#1| $ (-568) (-568) |#1|) NIL) (($ $ (-634 (-568)) (-634 (-568))) NIL)) (-2282 (($ (-634 |#1|)) NIL) (($ (-634 $)) NIL)) (-1960 (((-121) $) NIL)) (-2465 ((|#1| $) NIL (|has| |#1| (-6 (-4521 "*"))))) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) NIL)) (-2365 (((-634 (-1244 |#1|)) $) NIL (|has| |#1| (-301)))) (-3731 (((-1244 |#1|) $ (-568)) NIL)) (-2745 (((-850) $) NIL (|has| |#1| (-1090))) (($ (-1244 |#1|)) NIL)) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1910 (((-121) $) NIL)) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1773 (($ $ $) NIL) (($ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (* (($ $ $) NIL) (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ (-568) $) NIL) (((-1244 |#1|) $ (-1244 |#1|)) 14) (((-1244 |#1|) (-1244 |#1|) $) NIL) (((-944 |#1|) $ (-944 |#1|)) 20)) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-219 |#1|) (-13 (-677 |#1| (-1244 |#1|) (-1244 |#1|)) (-10 -8 (-15 * ((-944 |#1|) $ (-944 |#1|))) (-15 -3313 ($)) (-15 -3101 ($ |#1|)) (-15 -2531 ($ |#1|)) (-15 -2264 ($ |#1|)) (-15 -3646 ($ |#1| |#1| |#1|)) (-15 -1859 ($ |#1| |#1| |#1|)))) (-13 (-365) (-1181))) (T -219)) 
-((* (*1 *2 *1 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181))) (-5 *1 (-219 *3)))) (-3313 (*1 *1) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181))))) (-3101 (*1 *1 *2) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181))))) (-2531 (*1 *1 *2) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181))))) (-2264 (*1 *1 *2) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181))))) (-3646 (*1 *1 *2 *2 *2) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181))))) (-1859 (*1 *1 *2 *2 *2) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181)))))) 
-(-13 (-677 |#1| (-1244 |#1|) (-1244 |#1|)) (-10 -8 (-15 * ((-944 |#1|) $ (-944 |#1|))) (-15 -3313 ($)) (-15 -3101 ($ |#1|)) (-15 -2531 ($ |#1|)) (-15 -2264 ($ |#1|)) (-15 -3646 ($ |#1| |#1| |#1|)) (-15 -1859 ($ |#1| |#1| |#1|)))) 
-((-3507 (($ (-1 (-121) |#2|) $) 17)) (-3405 (($ |#2| $) NIL) (($ (-1 (-121) |#2|) $) 25)) (-2085 (($) NIL) (($ (-634 |#2|)) 11)) (-1717 (((-121) $ $) 23))) 
-(((-220 |#1| |#2|) (-10 -8 (-15 -3507 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -3405 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -3405 (|#1| |#2| |#1|)) (-15 -2085 (|#1| (-634 |#2|))) (-15 -2085 (|#1|)) (-15 -1717 ((-121) |#1| |#1|))) (-221 |#2|) (-1090)) (T -220)) 
-NIL 
-(-10 -8 (-15 -3507 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -3405 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -3405 (|#1| |#2| |#1|)) (-15 -2085 (|#1| (-634 |#2|))) (-15 -2085 (|#1|)) (-15 -1717 ((-121) |#1| |#1|))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2510 (((-121) $ (-763)) 8)) (-3507 (($ (-1 (-121) |#1|) $) 42 (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) |#1|) $) 52 (|has| $ (-6 -4519)))) (-2671 (($) 7 T CONST)) (-3924 (($ $) 55 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3405 (($ |#1| $) 44 (|has| $ (-6 -4519))) (($ (-1 (-121) |#1|) $) 43 (|has| $ (-6 -4519)))) (-4328 (($ |#1| $) 54 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) |#1|) $) 51 (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4519)))) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) 9)) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35)) (-2166 (((-121) $ (-763)) 10)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-1890 ((|#1| $) 36)) (-4450 (($ |#1| $) 37)) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 48)) (-1315 ((|#1| $) 38)) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2085 (($) 46) (($ (-634 |#1|)) 45)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-4278 (((-541) $) 56 (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) 47)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-2367 (($ (-634 |#1|)) 39)) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-3687 (((-1249) $) 36) (((-1249) $ (-917) (-917)) 38)) (-2781 (($ $ (-990)) 19) (((-240 (-1143)) $ (-1161)) 15)) (-4127 (((-1249) $) 34)) (-2747 (((-850) $) 31) (($ (-634 |#1|)) 8)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $ $) 27)) (-1769 (($ $ $) 22))) 
+(((-205 |#1|) (-13 (-1090) (-10 -8 (-15 -2781 ($ $ (-990))) (-15 -2781 ((-240 (-1143)) $ (-1161))) (-15 -1769 ($ $ $)) (-15 -1775 ($ $ $)) (-15 -2747 ($ (-634 |#1|))) (-15 -4127 ((-1249) $)) (-15 -3687 ((-1249) $)) (-15 -3687 ((-1249) $ (-917) (-917))))) (-13 (-842) (-10 -8 (-15 -2781 ((-1143) $ (-1161))) (-15 -4127 ((-1249) $)) (-15 -3687 ((-1249) $))))) (T -205)) 
+((-2781 (*1 *1 *1 *2) (-12 (-5 *2 (-990)) (-5 *1 (-205 *3)) (-4 *3 (-13 (-842) (-10 -8 (-15 -2781 ((-1143) $ (-1161))) (-15 -4127 ((-1249) $)) (-15 -3687 ((-1249) $))))))) (-2781 (*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-240 (-1143))) (-5 *1 (-205 *4)) (-4 *4 (-13 (-842) (-10 -8 (-15 -2781 ((-1143) $ *3)) (-15 -4127 ((-1249) $)) (-15 -3687 ((-1249) $))))))) (-1769 (*1 *1 *1 *1) (-12 (-5 *1 (-205 *2)) (-4 *2 (-13 (-842) (-10 -8 (-15 -2781 ((-1143) $ (-1161))) (-15 -4127 ((-1249) $)) (-15 -3687 ((-1249) $))))))) (-1775 (*1 *1 *1 *1) (-12 (-5 *1 (-205 *2)) (-4 *2 (-13 (-842) (-10 -8 (-15 -2781 ((-1143) $ (-1161))) (-15 -4127 ((-1249) $)) (-15 -3687 ((-1249) $))))))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-13 (-842) (-10 -8 (-15 -2781 ((-1143) $ (-1161))) (-15 -4127 ((-1249) $)) (-15 -3687 ((-1249) $))))) (-5 *1 (-205 *3)))) (-4127 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-205 *3)) (-4 *3 (-13 (-842) (-10 -8 (-15 -2781 ((-1143) $ (-1161))) (-15 -4127 (*2 $)) (-15 -3687 (*2 $))))))) (-3687 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-205 *3)) (-4 *3 (-13 (-842) (-10 -8 (-15 -2781 ((-1143) $ (-1161))) (-15 -4127 (*2 $)) (-15 -3687 (*2 $))))))) (-3687 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1249)) (-5 *1 (-205 *4)) (-4 *4 (-13 (-842) (-10 -8 (-15 -2781 ((-1143) $ (-1161))) (-15 -4127 (*2 $)) (-15 -3687 (*2 $)))))))) 
+(-13 (-1090) (-10 -8 (-15 -2781 ($ $ (-990))) (-15 -2781 ((-240 (-1143)) $ (-1161))) (-15 -1769 ($ $ $)) (-15 -1775 ($ $ $)) (-15 -2747 ($ (-634 |#1|))) (-15 -4127 ((-1249) $)) (-15 -3687 ((-1249) $)) (-15 -3687 ((-1249) $ (-917) (-917))))) 
+((-3851 ((|#2| |#4| (-1 |#2| |#2|)) 46))) 
+(((-206 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3851 (|#2| |#4| (-1 |#2| |#2|)))) (-365) (-1219 |#1|) (-1219 (-409 |#2|)) (-340 |#1| |#2| |#3|)) (T -206)) 
+((-3851 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *2 *2)) (-4 *5 (-365)) (-4 *6 (-1219 (-409 *2))) (-4 *2 (-1219 *5)) (-5 *1 (-206 *5 *2 *6 *3)) (-4 *3 (-340 *5 *2 *6))))) 
+(-10 -7 (-15 -3851 (|#2| |#4| (-1 |#2| |#2|)))) 
+((-4471 ((|#2| |#2| (-763) |#2|) 41)) (-3750 ((|#2| |#2| (-763) |#2|) 37)) (-3316 (((-634 |#2|) (-634 (-2 (|:| |deg| (-763)) (|:| -1632 |#2|)))) 55)) (-2529 (((-634 (-2 (|:| |deg| (-763)) (|:| -1632 |#2|))) |#2|) 51)) (-1634 (((-121) |#2|) 48)) (-4254 (((-420 |#2|) |#2|) 74)) (-3850 (((-420 |#2|) |#2|) 73)) (-4413 ((|#2| |#2| (-763) |#2|) 35)) (-1725 (((-2 (|:| |cont| |#1|) (|:| -2075 (-634 (-2 (|:| |irr| |#2|) (|:| -4402 (-568)))))) |#2| (-121)) 66))) 
+(((-207 |#1| |#2|) (-10 -7 (-15 -3850 ((-420 |#2|) |#2|)) (-15 -4254 ((-420 |#2|) |#2|)) (-15 -1725 ((-2 (|:| |cont| |#1|) (|:| -2075 (-634 (-2 (|:| |irr| |#2|) (|:| -4402 (-568)))))) |#2| (-121))) (-15 -2529 ((-634 (-2 (|:| |deg| (-763)) (|:| -1632 |#2|))) |#2|)) (-15 -3316 ((-634 |#2|) (-634 (-2 (|:| |deg| (-763)) (|:| -1632 |#2|))))) (-15 -4413 (|#2| |#2| (-763) |#2|)) (-15 -3750 (|#2| |#2| (-763) |#2|)) (-15 -4471 (|#2| |#2| (-763) |#2|)) (-15 -1634 ((-121) |#2|))) (-350) (-1219 |#1|)) (T -207)) 
+((-1634 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-121)) (-5 *1 (-207 *4 *3)) (-4 *3 (-1219 *4)))) (-4471 (*1 *2 *2 *3 *2) (-12 (-5 *3 (-763)) (-4 *4 (-350)) (-5 *1 (-207 *4 *2)) (-4 *2 (-1219 *4)))) (-3750 (*1 *2 *2 *3 *2) (-12 (-5 *3 (-763)) (-4 *4 (-350)) (-5 *1 (-207 *4 *2)) (-4 *2 (-1219 *4)))) (-4413 (*1 *2 *2 *3 *2) (-12 (-5 *3 (-763)) (-4 *4 (-350)) (-5 *1 (-207 *4 *2)) (-4 *2 (-1219 *4)))) (-3316 (*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| |deg| (-763)) (|:| -1632 *5)))) (-4 *5 (-1219 *4)) (-4 *4 (-350)) (-5 *2 (-634 *5)) (-5 *1 (-207 *4 *5)))) (-2529 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-634 (-2 (|:| |deg| (-763)) (|:| -1632 *3)))) (-5 *1 (-207 *4 *3)) (-4 *3 (-1219 *4)))) (-1725 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-350)) (-5 *2 (-2 (|:| |cont| *5) (|:| -2075 (-634 (-2 (|:| |irr| *3) (|:| -4402 (-568))))))) (-5 *1 (-207 *5 *3)) (-4 *3 (-1219 *5)))) (-4254 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-207 *4 *3)) (-4 *3 (-1219 *4)))) (-3850 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-207 *4 *3)) (-4 *3 (-1219 *4))))) 
+(-10 -7 (-15 -3850 ((-420 |#2|) |#2|)) (-15 -4254 ((-420 |#2|) |#2|)) (-15 -1725 ((-2 (|:| |cont| |#1|) (|:| -2075 (-634 (-2 (|:| |irr| |#2|) (|:| -4402 (-568)))))) |#2| (-121))) (-15 -2529 ((-634 (-2 (|:| |deg| (-763)) (|:| -1632 |#2|))) |#2|)) (-15 -3316 ((-634 |#2|) (-634 (-2 (|:| |deg| (-763)) (|:| -1632 |#2|))))) (-15 -4413 (|#2| |#2| (-763) |#2|)) (-15 -3750 (|#2| |#2| (-763) |#2|)) (-15 -4471 (|#2| |#2| (-763) |#2|)) (-15 -1634 ((-121) |#2|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2563 (((-568) $) NIL (|has| (-568) (-301)))) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-2589 (((-121) $ $) NIL)) (-3337 (((-568) $) NIL (|has| (-568) (-815)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) NIL) (((-3 (-1161) "failed") $) NIL (|has| (-568) (-1037 (-1161)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| (-568) (-1037 (-568)))) (((-3 (-568) "failed") $) NIL (|has| (-568) (-1037 (-568))))) (-2857 (((-568) $) NIL) (((-1161) $) NIL (|has| (-568) (-1037 (-1161)))) (((-409 (-568)) $) NIL (|has| (-568) (-1037 (-568)))) (((-568) $) NIL (|has| (-568) (-1037 (-568))))) (-2403 (($ $ $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| (-568) (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| (-568) (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-679 (-568)) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1733 (($) NIL (|has| (-568) (-550)))) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-1436 (((-121) $) NIL (|has| (-568) (-815)))) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| (-568) (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| (-568) (-881 (-381))))) (-1598 (((-121) $) NIL)) (-3539 (($ $) NIL)) (-2319 (((-568) $) NIL)) (-2214 (((-3 $ "failed") $) NIL (|has| (-568) (-1136)))) (-2859 (((-121) $) NIL (|has| (-568) (-815)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1732 (($ $ $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (|has| (-568) (-842)))) (-2797 (($ (-1 (-568) (-568)) $) NIL)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4436 (($) NIL (|has| (-568) (-1136)) CONST)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1999 (($ $) NIL (|has| (-568) (-301))) (((-409 (-568)) $) NIL)) (-4115 (((-568) $) NIL (|has| (-568) (-550)))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-3850 (((-420 $) $) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1339 (($ $ (-634 (-568)) (-634 (-568))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-568) (-568)) NIL (|has| (-568) (-303 (-568)))) (($ $ (-288 (-568))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-634 (-288 (-568)))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-634 (-1161)) (-634 (-568))) NIL (|has| (-568) (-523 (-1161) (-568)))) (($ $ (-1161) (-568)) NIL (|has| (-568) (-523 (-1161) (-568))))) (-1466 (((-763) $) NIL)) (-2781 (($ $ (-568)) NIL (|has| (-568) (-281 (-568) (-568))))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-4191 (($ $) NIL (|has| (-568) (-225))) (($ $ (-763)) NIL (|has| (-568) (-225))) (($ $ (-1161)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1 (-568) (-568)) (-763)) NIL) (($ $ (-1 (-568) (-568))) NIL)) (-3210 (($ $) NIL)) (-2326 (((-568) $) NIL)) (-4012 (($ (-409 (-568))) 8)) (-4280 (((-887 (-568)) $) NIL (|has| (-568) (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| (-568) (-609 (-887 (-381))))) (((-541) $) NIL (|has| (-568) (-609 (-541)))) (((-381) $) NIL (|has| (-568) (-1021))) (((-215) $) NIL (|has| (-568) (-1021)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| (-568) (-904))))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) 7) (($ (-568)) NIL) (($ (-1161)) NIL (|has| (-568) (-1037 (-1161)))) (((-409 (-568)) $) NIL) (((-1004 10) $) 9)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| (-568) (-904))) (|has| (-568) (-148))))) (-3425 (((-763)) NIL)) (-3520 (((-568) $) NIL (|has| (-568) (-550)))) (-2273 (((-121) $ $) NIL)) (-2811 (($ $) NIL (|has| (-568) (-815)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $) NIL (|has| (-568) (-225))) (($ $ (-763)) NIL (|has| (-568) (-225))) (($ $ (-1161)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1 (-568) (-568)) (-763)) NIL) (($ $ (-1 (-568) (-568))) NIL)) (-1753 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1740 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1734 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1781 (($ $ $) NIL) (($ (-568) (-568)) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ (-568) $) NIL) (($ $ (-568)) NIL))) 
+(((-208) (-13 (-993 (-568)) (-10 -8 (-15 -2747 ((-409 (-568)) $)) (-15 -2747 ((-1004 10) $)) (-15 -1999 ((-409 (-568)) $)) (-15 -4012 ($ (-409 (-568))))))) (T -208)) 
+((-2747 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-208)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-1004 10)) (-5 *1 (-208)))) (-1999 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-208)))) (-4012 (*1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-208))))) 
+(-13 (-993 (-568)) (-10 -8 (-15 -2747 ((-409 (-568)) $)) (-15 -2747 ((-1004 10) $)) (-15 -1999 ((-409 (-568)) $)) (-15 -4012 ($ (-409 (-568)))))) 
+((-1845 (((-3 (|:| |f1| (-835 |#2|)) (|:| |f2| (-634 (-835 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1082 (-835 |#2|)) (-1143)) 27) (((-3 (|:| |f1| (-835 |#2|)) (|:| |f2| (-634 (-835 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1082 (-835 |#2|))) 23)) (-3537 (((-3 (|:| |f1| (-835 |#2|)) (|:| |f2| (-634 (-835 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1161) (-835 |#2|) (-835 |#2|) (-121)) 16))) 
+(((-209 |#1| |#2|) (-10 -7 (-15 -1845 ((-3 (|:| |f1| (-835 |#2|)) (|:| |f2| (-634 (-835 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1082 (-835 |#2|)))) (-15 -1845 ((-3 (|:| |f1| (-835 |#2|)) (|:| |f2| (-634 (-835 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1082 (-835 |#2|)) (-1143))) (-15 -3537 ((-3 (|:| |f1| (-835 |#2|)) (|:| |f2| (-634 (-835 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1161) (-835 |#2|) (-835 |#2|) (-121)))) (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568))) (-13 (-1181) (-959) (-29 |#1|))) (T -209)) 
+((-3537 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *4 (-1161)) (-5 *6 (-121)) (-4 *7 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-4 *3 (-13 (-1181) (-959) (-29 *7))) (-5 *2 (-3 (|:| |f1| (-835 *3)) (|:| |f2| (-634 (-835 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-209 *7 *3)) (-5 *5 (-835 *3)))) (-1845 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1082 (-835 *3))) (-5 *5 (-1143)) (-4 *3 (-13 (-1181) (-959) (-29 *6))) (-4 *6 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 *3)) (|:| |f2| (-634 (-835 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-209 *6 *3)))) (-1845 (*1 *2 *3 *4) (-12 (-5 *4 (-1082 (-835 *3))) (-4 *3 (-13 (-1181) (-959) (-29 *5))) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 *3)) (|:| |f2| (-634 (-835 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-209 *5 *3))))) 
+(-10 -7 (-15 -1845 ((-3 (|:| |f1| (-835 |#2|)) (|:| |f2| (-634 (-835 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1082 (-835 |#2|)))) (-15 -1845 ((-3 (|:| |f1| (-835 |#2|)) (|:| |f2| (-634 (-835 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1082 (-835 |#2|)) (-1143))) (-15 -3537 ((-3 (|:| |f1| (-835 |#2|)) (|:| |f2| (-634 (-835 |#2|))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) |#2| (-1161) (-835 |#2|) (-835 |#2|) (-121)))) 
+((-1845 (((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-409 (-953 |#1|)))) (-1143)) 44) (((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-409 (-953 |#1|))))) 41) (((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-310 |#1|))) (-1143)) 45) (((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-310 |#1|)))) 17))) 
+(((-210 |#1|) (-10 -7 (-15 -1845 ((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-310 |#1|))))) (-15 -1845 ((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-310 |#1|))) (-1143))) (-15 -1845 ((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-409 (-953 |#1|)))))) (-15 -1845 ((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-409 (-953 |#1|)))) (-1143)))) (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (T -210)) 
+((-1845 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1082 (-835 (-409 (-953 *6))))) (-5 *5 (-1143)) (-5 *3 (-409 (-953 *6))) (-4 *6 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 (-310 *6))) (|:| |f2| (-634 (-835 (-310 *6)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-210 *6)))) (-1845 (*1 *2 *3 *4) (-12 (-5 *4 (-1082 (-835 (-409 (-953 *5))))) (-5 *3 (-409 (-953 *5))) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 (-310 *5))) (|:| |f2| (-634 (-835 (-310 *5)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-210 *5)))) (-1845 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-409 (-953 *6))) (-5 *4 (-1082 (-835 (-310 *6)))) (-5 *5 (-1143)) (-4 *6 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 (-310 *6))) (|:| |f2| (-634 (-835 (-310 *6)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-210 *6)))) (-1845 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1082 (-835 (-310 *5)))) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 (-310 *5))) (|:| |f2| (-634 (-835 (-310 *5)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-210 *5))))) 
+(-10 -7 (-15 -1845 ((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-310 |#1|))))) (-15 -1845 ((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-310 |#1|))) (-1143))) (-15 -1845 ((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-409 (-953 |#1|)))))) (-15 -1845 ((-3 (|:| |f1| (-835 (-310 |#1|))) (|:| |f2| (-634 (-835 (-310 |#1|)))) (|:| |fail| "failed") (|:| |pole| "potentialPole")) (-409 (-953 |#1|)) (-1082 (-835 (-409 (-953 |#1|)))) (-1143)))) 
+((-3094 (((-2 (|:| -1416 (-1157 |#1|)) (|:| |deg| (-917))) (-1157 |#1|)) 20)) (-2791 (((-634 (-310 |#2|)) (-310 |#2|) (-917)) 42))) 
+(((-211 |#1| |#2|) (-10 -7 (-15 -3094 ((-2 (|:| -1416 (-1157 |#1|)) (|:| |deg| (-917))) (-1157 |#1|))) (-15 -2791 ((-634 (-310 |#2|)) (-310 |#2|) (-917)))) (-1047) (-13 (-558) (-842))) (T -211)) 
+((-2791 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *6 (-13 (-558) (-842))) (-5 *2 (-634 (-310 *6))) (-5 *1 (-211 *5 *6)) (-5 *3 (-310 *6)) (-4 *5 (-1047)))) (-3094 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-2 (|:| -1416 (-1157 *4)) (|:| |deg| (-917)))) (-5 *1 (-211 *4 *5)) (-5 *3 (-1157 *4)) (-4 *5 (-13 (-558) (-842)))))) 
+(-10 -7 (-15 -3094 ((-2 (|:| -1416 (-1157 |#1|)) (|:| |deg| (-917))) (-1157 |#1|))) (-15 -2791 ((-634 (-310 |#2|)) (-310 |#2|) (-917)))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2212 ((|#1| $) 25)) (-2618 ((|#1| $) 26)) (-1667 (((-121) $ (-763)) NIL)) (-4490 (($) NIL T CONST)) (-3743 (($ $) NIL)) (-4452 (($ $) 32)) (-2885 ((|#1| |#1| $) NIL)) (-2819 ((|#1| $) NIL)) (-3317 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) NIL)) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-2253 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-3680 (((-763) $) NIL)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-2580 ((|#1| $) NIL)) (-2487 ((|#1| |#1| $) 29)) (-3055 ((|#1| |#1| $) 31)) (-1708 (($ |#1| $) NIL)) (-2963 (((-763) $) 27)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-1929 ((|#1| $) NIL)) (-3430 ((|#1| $) 24)) (-2180 ((|#1| $) 8)) (-3403 ((|#1| $) NIL)) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-3920 ((|#1| |#1| $) NIL)) (-2436 (((-121) $) 15)) (-1990 (($) NIL)) (-4080 ((|#1| $) NIL)) (-1403 (($) NIL) (($ (-634 |#1|)) 13)) (-4156 (((-763) $) 28)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) NIL)) (-2747 (((-850) $) NIL (|has| |#1| (-1090)))) (-2120 ((|#1| $) 9)) (-4074 (($ (-634 |#1|)) NIL)) (-4035 ((|#1| $) NIL)) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-212 |#1|) (-13 (-247 |#1|) (-10 -8 (-15 -1403 ($ (-634 |#1|))) (-15 -4080 (|#1| $)) (-15 -3403 (|#1| $)) (-15 -3920 (|#1| |#1| $)) (-15 -1708 ($ |#1| $)) (-15 -2580 (|#1| $)) (-15 -1929 (|#1| $)) (-15 -4035 (|#1| $)) (-15 -3743 ($ $)) (-15 -3680 ((-763) $)) (-15 -3796 ((-121) $ (-763))) (-15 -3791 ((-121) $ (-763))) (-15 -1667 ((-121) $ (-763))) (-15 -4074 ($ (-634 |#1|))) (-15 -2436 ((-121) $)) (-15 -1990 ($)) (-15 -4490 ($)) (-15 -3865 ($ $)) (-15 -1702 ((-121) $ $)) (-15 -2797 ($ (-1 |#1| |#1|) $)) (-15 -4156 ((-763) $)) (-15 -1403 ($)) (-15 -2963 ((-763) $)) (-15 -2618 (|#1| $)) (-15 -2120 (|#1| $)) (-15 -2180 (|#1| $)) (-15 -3430 (|#1| $)) (-15 -3055 (|#1| |#1| $)) (-15 -2487 (|#1| |#1| $)) (-15 -2819 (|#1| $)) (-15 -2885 (|#1| |#1| $)) (-15 -4452 ($ $)) (-15 -2212 (|#1| $)) (IF (|has| $ (-6 -4522)) (-15 -2253 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-15 -1893 ((-1143) $)) (-15 -4025 ((-1108) $)) (-15 -2747 ((-850) $)) (-15 -1719 ((-121) $ $)) (-15 -2449 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4521)) (PROGN (-15 -3951 ((-121) (-1 (-121) |#1|) $)) (-15 -3437 ((-121) (-1 (-121) |#1|) $)) (-15 -4170 ((-763) (-1 (-121) |#1|) $)) (-15 -1699 ((-763) $)) (-15 -3317 ((-634 |#1|) $)) (-15 -4406 ((-634 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4521)) (IF (|has| |#1| (-1090)) (PROGN (-15 -2551 ((-121) |#1| $)) (-15 -4170 ((-763) |#1| $))) |noBranch|) |noBranch|))) (-1090)) (T -212)) 
+((-1702 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) (-3865 (*1 *1 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-1990 (*1 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-2436 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) (-3796 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-212 *4)) (-4 *4 (-1090)))) (-3791 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-212 *4)) (-4 *4 (-1090)))) (-1667 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-212 *4)) (-4 *4 (-1090)))) (-4490 (*1 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-1699 (*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-763)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) (-2797 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-212 *3)))) (-2253 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4522)) (-4 *3 (-1090)) (-5 *1 (-212 *3)))) (-3437 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-212 *4)))) (-3951 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-212 *4)))) (-4170 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-763)) (-5 *1 (-212 *4)))) (-3317 (*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-634 *3)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) (-4406 (*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-634 *3)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) (-4170 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-763)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2551 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-121)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-1893 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-4025 (*1 *2 *1) (-12 (-5 *2 (-1108)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-1719 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2449 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-4074 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-212 *3)))) (-3403 (*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-1708 (*1 *1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-2580 (*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-2885 (*1 *2 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-2819 (*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-2618 (*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-4156 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) (-4035 (*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-1929 (*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-3680 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) (-3743 (*1 *1 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-4080 (*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-3920 (*1 *2 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-1403 (*1 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-1403 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-212 *3)))) (-2963 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) (-2212 (*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-2120 (*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-2487 (*1 *2 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-3055 (*1 *2 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-3430 (*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-2180 (*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) (-4452 (*1 *1 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090))))) 
+(-13 (-247 |#1|) (-10 -8 (-15 -1403 ($ (-634 |#1|))) (-15 -4080 (|#1| $)) (-15 -3403 (|#1| $)) (-15 -3920 (|#1| |#1| $)) (-15 -1708 ($ |#1| $)) (-15 -2580 (|#1| $)) (-15 -1929 (|#1| $)) (-15 -4035 (|#1| $)) (-15 -3743 ($ $)) (-15 -3680 ((-763) $)) (-15 -3796 ((-121) $ (-763))) (-15 -3791 ((-121) $ (-763))) (-15 -1667 ((-121) $ (-763))) (-15 -4074 ($ (-634 |#1|))) (-15 -2436 ((-121) $)) (-15 -1990 ($)) (-15 -4490 ($)) (-15 -3865 ($ $)) (-15 -1702 ((-121) $ $)) (-15 -2797 ($ (-1 |#1| |#1|) $)) (-15 -4156 ((-763) $)) (-15 -1403 ($)) (-15 -2963 ((-763) $)) (-15 -2618 (|#1| $)) (-15 -2120 (|#1| $)) (-15 -2180 (|#1| $)) (-15 -3430 (|#1| $)) (-15 -3055 (|#1| |#1| $)) (-15 -2487 (|#1| |#1| $)) (-15 -2819 (|#1| $)) (-15 -2885 (|#1| |#1| $)) (-15 -4452 ($ $)) (-15 -2212 (|#1| $)) (IF (|has| $ (-6 -4522)) (-15 -2253 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-15 -1893 ((-1143) $)) (-15 -4025 ((-1108) $)) (-15 -2747 ((-850) $)) (-15 -1719 ((-121) $ $)) (-15 -2449 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4521)) (PROGN (-15 -3951 ((-121) (-1 (-121) |#1|) $)) (-15 -3437 ((-121) (-1 (-121) |#1|) $)) (-15 -4170 ((-763) (-1 (-121) |#1|) $)) (-15 -1699 ((-763) $)) (-15 -3317 ((-634 |#1|) $)) (-15 -4406 ((-634 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4521)) (IF (|has| |#1| (-1090)) (PROGN (-15 -2551 ((-121) |#1| $)) (-15 -4170 ((-763) |#1| $))) |noBranch|) |noBranch|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2829 (($ (-310 |#1|)) 23)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-1407 (((-121) $) NIL)) (-3668 (((-3 (-310 |#1|) "failed") $) NIL)) (-2857 (((-310 |#1|) $) NIL)) (-2116 (($ $) 31)) (-2902 (((-3 $ "failed") $) NIL)) (-1598 (((-121) $) NIL)) (-2797 (($ (-1 (-310 |#1|) (-310 |#1|)) $) NIL)) (-2104 (((-310 |#1|) $) NIL)) (-4313 (($ $) 30)) (-1893 (((-1143) $) NIL)) (-1923 (((-121) $) NIL)) (-4025 (((-1108) $) NIL)) (-2707 (($ (-763)) NIL)) (-2385 (($ $) 32)) (-1836 (((-568) $) NIL)) (-2747 (((-850) $) 57) (($ (-568)) NIL) (($ (-310 |#1|)) NIL)) (-2079 (((-310 |#1|) $ $) NIL)) (-3425 (((-763)) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 25 T CONST)) (-1557 (($) 50 T CONST)) (-1719 (((-121) $ $) 28)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) 19)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 24) (($ (-310 |#1|) $) 18))) 
+(((-213 |#1| |#2|) (-13 (-612 (-310 |#1|)) (-1037 (-310 |#1|)) (-10 -8 (-15 -2104 ((-310 |#1|) $)) (-15 -4313 ($ $)) (-15 -2116 ($ $)) (-15 -2079 ((-310 |#1|) $ $)) (-15 -2707 ($ (-763))) (-15 -1923 ((-121) $)) (-15 -1407 ((-121) $)) (-15 -1836 ((-568) $)) (-15 -2797 ($ (-1 (-310 |#1|) (-310 |#1|)) $)) (-15 -2829 ($ (-310 |#1|))) (-15 -2385 ($ $)))) (-13 (-1047) (-842)) (-634 (-1161))) (T -213)) 
+((-2104 (*1 *2 *1) (-12 (-5 *2 (-310 *3)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161))))) (-4313 (*1 *1 *1) (-12 (-5 *1 (-213 *2 *3)) (-4 *2 (-13 (-1047) (-842))) (-14 *3 (-634 (-1161))))) (-2116 (*1 *1 *1) (-12 (-5 *1 (-213 *2 *3)) (-4 *2 (-13 (-1047) (-842))) (-14 *3 (-634 (-1161))))) (-2079 (*1 *2 *1 *1) (-12 (-5 *2 (-310 *3)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161))))) (-2707 (*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161))))) (-1923 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161))))) (-1407 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161))))) (-1836 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161))))) (-2797 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-310 *3) (-310 *3))) (-4 *3 (-13 (-1047) (-842))) (-5 *1 (-213 *3 *4)) (-14 *4 (-634 (-1161))))) (-2829 (*1 *1 *2) (-12 (-5 *2 (-310 *3)) (-4 *3 (-13 (-1047) (-842))) (-5 *1 (-213 *3 *4)) (-14 *4 (-634 (-1161))))) (-2385 (*1 *1 *1) (-12 (-5 *1 (-213 *2 *3)) (-4 *2 (-13 (-1047) (-842))) (-14 *3 (-634 (-1161)))))) 
+(-13 (-612 (-310 |#1|)) (-1037 (-310 |#1|)) (-10 -8 (-15 -2104 ((-310 |#1|) $)) (-15 -4313 ($ $)) (-15 -2116 ($ $)) (-15 -2079 ((-310 |#1|) $ $)) (-15 -2707 ($ (-763))) (-15 -1923 ((-121) $)) (-15 -1407 ((-121) $)) (-15 -1836 ((-568) $)) (-15 -2797 ($ (-1 (-310 |#1|) (-310 |#1|)) $)) (-15 -2829 ($ (-310 |#1|))) (-15 -2385 ($ $)))) 
+((-1485 (((-121) (-1143)) 22)) (-2771 (((-3 (-835 |#2|) "failed") (-607 |#2|) |#2| (-835 |#2|) (-835 |#2|) (-121)) 32)) (-2826 (((-3 (-121) "failed") (-1157 |#2|) (-835 |#2|) (-835 |#2|) (-121)) 73) (((-3 (-121) "failed") (-953 |#1|) (-1161) (-835 |#2|) (-835 |#2|) (-121)) 74))) 
+(((-214 |#1| |#2|) (-10 -7 (-15 -1485 ((-121) (-1143))) (-15 -2771 ((-3 (-835 |#2|) "failed") (-607 |#2|) |#2| (-835 |#2|) (-835 |#2|) (-121))) (-15 -2826 ((-3 (-121) "failed") (-953 |#1|) (-1161) (-835 |#2|) (-835 |#2|) (-121))) (-15 -2826 ((-3 (-121) "failed") (-1157 |#2|) (-835 |#2|) (-835 |#2|) (-121)))) (-13 (-453) (-842) (-1037 (-568)) (-630 (-568))) (-13 (-1181) (-29 |#1|))) (T -214)) 
+((-2826 (*1 *2 *3 *4 *4 *2) (|partial| -12 (-5 *2 (-121)) (-5 *3 (-1157 *6)) (-5 *4 (-835 *6)) (-4 *6 (-13 (-1181) (-29 *5))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-214 *5 *6)))) (-2826 (*1 *2 *3 *4 *5 *5 *2) (|partial| -12 (-5 *2 (-121)) (-5 *3 (-953 *6)) (-5 *4 (-1161)) (-5 *5 (-835 *7)) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-4 *7 (-13 (-1181) (-29 *6))) (-5 *1 (-214 *6 *7)))) (-2771 (*1 *2 *3 *4 *2 *2 *5) (|partial| -12 (-5 *2 (-835 *4)) (-5 *3 (-607 *4)) (-5 *5 (-121)) (-4 *4 (-13 (-1181) (-29 *6))) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-214 *6 *4)))) (-1485 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-121)) (-5 *1 (-214 *4 *5)) (-4 *5 (-13 (-1181) (-29 *4)))))) 
+(-10 -7 (-15 -1485 ((-121) (-1143))) (-15 -2771 ((-3 (-835 |#2|) "failed") (-607 |#2|) |#2| (-835 |#2|) (-835 |#2|) (-121))) (-15 -2826 ((-3 (-121) "failed") (-953 |#1|) (-1161) (-835 |#2|) (-835 |#2|) (-121))) (-15 -2826 ((-3 (-121) "failed") (-1157 |#2|) (-835 |#2|) (-835 |#2|) (-121)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 95)) (-2563 (((-568) $) 124)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-4179 (($ $) NIL)) (-1984 (($ $) 83)) (-1935 (($ $) 71)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-1904 (($ $) 62)) (-2589 (((-121) $ $) NIL)) (-1976 (($ $) 81)) (-2788 (($ $) 69)) (-3337 (((-568) $) 137)) (-1992 (($ $) 86)) (-1943 (($ $) 73)) (-4490 (($) NIL T CONST)) (-2252 (($ $) NIL)) (-3668 (((-3 (-568) "failed") $) 120) (((-3 (-409 (-568)) "failed") $) 135)) (-2857 (((-568) $) 136) (((-409 (-568)) $) 133)) (-2403 (($ $ $) NIL)) (-2902 (((-3 $ "failed") $) 98)) (-1508 (((-409 (-568)) $ (-763)) 131) (((-409 (-568)) $ (-763) (-763)) 130)) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-3359 (((-917)) 34) (((-917) (-917)) NIL (|has| $ (-6 -4512)))) (-1436 (((-121) $) NIL)) (-3311 (($ $ $) 123)) (-1899 (($) 44)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL)) (-1844 (((-568) $) 40)) (-1598 (((-121) $) NIL)) (-1550 (($ $ (-568)) NIL)) (-4417 (($ $) NIL)) (-2859 (((-121) $) 94)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1732 (($ $ $) 59) (($) 39 (-12 (-3046 (|has| $ (-6 -4504))) (-3046 (|has| $ (-6 -4512)))))) (-2047 (($ $ $) 58) (($) 38 (-12 (-3046 (|has| $ (-6 -4504))) (-3046 (|has| $ (-6 -4512)))))) (-2790 (((-568) $) 32)) (-2085 (((-409 (-568)) $) 27)) (-3025 (($ $) 35)) (-2658 (($ $) 63)) (-4418 (($ $) 68)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4220 (((-634 (-568)) $) 29)) (-1529 (((-917) (-568)) NIL (|has| $ (-6 -4512)))) (-4025 (((-1108) $) NIL) (((-568) $) 96)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1999 (($ $) NIL)) (-4115 (($ $) NIL)) (-3770 (($ (-568) (-568)) NIL) (($ (-568) (-568) (-917)) 125)) (-3850 (((-420 $) $) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3483 (((-568) $) 33)) (-3111 (($) 43)) (-1894 (($ $) 67)) (-1466 (((-763) $) NIL)) (-1655 (((-1143) (-1143)) 8)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-1513 (((-917)) NIL) (((-917) (-917)) NIL (|has| $ (-6 -4512)))) (-2383 (($ $) 116)) (-4191 (($ $ (-763)) NIL) (($ $) 99)) (-1973 (((-917) (-568)) NIL (|has| $ (-6 -4512)))) (-1996 (($ $) 84)) (-1947 (($ $) 74)) (-1988 (($ $) 85)) (-1939 (($ $) 72)) (-1980 (($ $) 82)) (-2792 (($ $) 70)) (-4280 (((-381) $) 129) (((-215) $) 126) (((-887 (-381)) $) NIL) (((-541) $) 51)) (-2747 (((-850) $) 48) (($ (-568)) 66) (($ $) NIL) (($ (-409 (-568))) NIL) (($ (-568)) 66) (($ (-409 (-568))) NIL)) (-3425 (((-763)) NIL)) (-3520 (($ $) NIL)) (-1540 (((-917)) 37) (((-917) (-917)) NIL (|has| $ (-6 -4512)))) (-3301 (($ $ $) 112)) (-2149 (($ $ $) 110)) (-3826 (($ $ $) 108)) (-2547 (($ $ $) 106)) (-2404 (((-917)) 31)) (-2008 (($ $) 89)) (-1959 (($ $) 77) (($ $ $) 132)) (-2273 (((-121) $ $) NIL)) (-2000 (($ $) 87)) (-1951 (($ $) 75)) (-2016 (($ $) 92)) (-1968 (($ $) 80)) (-1813 (($ $) 104)) (-4009 (($ $) 102)) (-1439 (($ $) 90)) (-1972 (($ $) 78)) (-2012 (($ $) 91)) (-1964 (($ $) 79)) (-2004 (($ $) 88)) (-1955 (($ $) 76)) (-2811 (($ $) 138)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) 41 T CONST)) (-1557 (($) 42 T CONST)) (-2628 (((-1143) $) 19) (((-1143) $ (-121)) 21) (((-1249) (-817) $) 22) (((-1249) (-817) $ (-121)) 23)) (-2209 (($ $) 118) (($ $ $) NIL)) (-3192 (($ $ (-763)) NIL) (($ $) NIL)) (-2768 (($ $ $) 114)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 60)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 52)) (-1781 (($ $ $) 93) (($ $ (-568)) 61)) (-1775 (($ $) 53) (($ $ $) 55)) (-1769 (($ $ $) 54)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) 64) (($ $ (-409 (-568))) 148) (($ $ $) 65)) (* (($ (-917) $) 36) (($ (-763) $) NIL) (($ (-568) $) 57) (($ $ $) 56) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL))) 
+(((-215) (-13 (-406) (-225) (-823) (-1181) (-1124) (-609 (-541)) (-10 -8 (-15 -1781 ($ $ (-568))) (-15 ** ($ $ $)) (-15 -3111 ($)) (-15 -4025 ((-568) $)) (-15 -3025 ($ $)) (-15 -2658 ($ $)) (-15 -1959 ($ $ $)) (-15 -2209 ($ $)) (-15 -2768 ($ $ $)) (-15 -1655 ((-1143) (-1143))) (-15 -1508 ((-409 (-568)) $ (-763))) (-15 -1508 ((-409 (-568)) $ (-763) (-763))) (-15 -2085 ((-409 (-568)) $)) (-15 -4220 ((-634 (-568)) $))))) (T -215)) 
+((** (*1 *1 *1 *1) (-5 *1 (-215))) (-2209 (*1 *1 *1) (-5 *1 (-215))) (-2768 (*1 *1 *1 *1) (-5 *1 (-215))) (-1781 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-215)))) (-3111 (*1 *1) (-5 *1 (-215))) (-4025 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-215)))) (-3025 (*1 *1 *1) (-5 *1 (-215))) (-2658 (*1 *1 *1) (-5 *1 (-215))) (-1959 (*1 *1 *1 *1) (-5 *1 (-215))) (-1655 (*1 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-215)))) (-1508 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-409 (-568))) (-5 *1 (-215)))) (-1508 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-409 (-568))) (-5 *1 (-215)))) (-2085 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-215)))) (-4220 (*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-215))))) 
+(-13 (-406) (-225) (-823) (-1181) (-1124) (-609 (-541)) (-10 -8 (-15 -1781 ($ $ (-568))) (-15 ** ($ $ $)) (-15 -3111 ($)) (-15 -4025 ((-568) $)) (-15 -3025 ($ $)) (-15 -2658 ($ $)) (-15 -1959 ($ $ $)) (-15 -2209 ($ $)) (-15 -2768 ($ $ $)) (-15 -1655 ((-1143) (-1143))) (-15 -1508 ((-409 (-568)) $ (-763))) (-15 -1508 ((-409 (-568)) $ (-763) (-763))) (-15 -2085 ((-409 (-568)) $)) (-15 -4220 ((-634 (-568)) $)))) 
+((-2449 (((-121) $ $) NIL (|has| (-215) (-1090)))) (-3207 (($ (-763) (-763)) NIL)) (-4486 (($ $ $) NIL)) (-4089 (($ (-218)) NIL) (($ $) NIL)) (-3560 (((-121) $) NIL)) (-3211 (($ $ (-568) (-568)) NIL)) (-3096 (($ $ (-568) (-568)) NIL)) (-2265 (($ $ (-568) (-568) (-568) (-568)) NIL)) (-4467 (($ $) NIL)) (-3691 (((-121) $) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-4043 (($ $ (-568) (-568) $) NIL)) (-2438 (((-215) $ (-568) (-568) (-215)) NIL) (($ $ (-634 (-568)) (-634 (-568)) $) NIL)) (-3874 (($ $ (-568) (-218)) NIL)) (-2525 (($ $ (-568) (-218)) NIL)) (-1637 (($ (-763) (-215)) NIL)) (-4490 (($) NIL T CONST)) (-3912 (($ $) NIL (|has| (-215) (-301)))) (-2228 (((-218) $ (-568)) NIL)) (-2371 (((-763) $) NIL (|has| (-215) (-558)))) (-1292 (((-215) $ (-568) (-568) (-215)) 16)) (-3063 (($ (-568) (-568)) 18)) (-2069 (((-215) $ (-568) (-568)) 15)) (-3102 (((-215) $) NIL (|has| (-215) (-172)))) (-3317 (((-634 (-215)) $) NIL)) (-3344 (((-763) $) NIL (|has| (-215) (-558)))) (-2934 (((-634 (-218)) $) NIL (|has| (-215) (-558)))) (-2241 (((-763) $) 10)) (-1851 (($ (-763) (-763) (-215)) 19)) (-1901 (((-763) $) 11)) (-3791 (((-121) $ (-763)) NIL)) (-2424 (((-215) $) NIL (|has| (-215) (-6 (-4523 "*"))))) (-3139 (((-568) $) 7)) (-1343 (((-568) $) 8)) (-4406 (((-634 (-215)) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) (-215) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-215) (-1090))))) (-3405 (((-568) $) 12)) (-2801 (((-568) $) 13)) (-2271 (($ (-634 (-634 (-215)))) NIL)) (-2253 (($ (-1 (-215) (-215)) $) NIL)) (-2797 (($ (-1 (-215) (-215)) $) NIL) (($ (-1 (-215) (-215) (-215)) $ $) NIL) (($ (-1 (-215) (-215) (-215)) $ $ (-215)) NIL)) (-1843 (((-634 (-634 (-215))) $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (|has| (-215) (-1090)))) (-2715 (((-3 $ "failed") $) NIL (|has| (-215) (-365)))) (-4018 (($ $ $) NIL)) (-4025 (((-1108) $) NIL (|has| (-215) (-1090)))) (-2490 (($ $ (-215)) NIL)) (-2597 (((-3 $ "failed") $ (-215)) NIL (|has| (-215) (-558)))) (-3951 (((-121) (-1 (-121) (-215)) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-215)))) NIL (-12 (|has| (-215) (-303 (-215))) (|has| (-215) (-1090)))) (($ $ (-288 (-215))) NIL (-12 (|has| (-215) (-303 (-215))) (|has| (-215) (-1090)))) (($ $ (-215) (-215)) NIL (-12 (|has| (-215) (-303 (-215))) (|has| (-215) (-1090)))) (($ $ (-634 (-215)) (-634 (-215))) NIL (-12 (|has| (-215) (-303 (-215))) (|has| (-215) (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) 17)) (-2781 (((-215) $ (-568) (-568)) NIL) (((-215) $ (-568) (-568) (-215)) NIL) (($ $ (-634 (-568)) (-634 (-568))) NIL)) (-3499 (($ (-634 (-215))) NIL) (($ (-634 $)) NIL)) (-4322 (((-121) $) NIL)) (-2591 (((-215) $) NIL (|has| (-215) (-6 (-4523 "*"))))) (-4170 (((-763) (-1 (-121) (-215)) $) NIL (|has| $ (-6 -4521))) (((-763) (-215) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-215) (-1090))))) (-3865 (($ $) NIL)) (-4063 (((-634 (-218)) $) NIL (|has| (-215) (-301)))) (-2522 (((-218) $ (-568)) NIL)) (-2747 (((-850) $) NIL (|has| (-215) (-1090))) (($ (-218)) NIL)) (-3437 (((-121) (-1 (-121) (-215)) $) NIL (|has| $ (-6 -4521)))) (-2675 (((-121) $) NIL)) (-1719 (((-121) $ $) NIL (|has| (-215) (-1090)))) (-1781 (($ $ (-215)) NIL (|has| (-215) (-365)))) (-1775 (($ $ $) NIL) (($ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| (-215) (-365)))) (* (($ $ $) NIL) (($ (-215) $) NIL) (($ $ (-215)) NIL) (($ (-568) $) NIL) (((-218) $ (-218)) NIL) (((-218) (-218) $) NIL)) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-216) (-13 (-677 (-215) (-218) (-218)) (-10 -8 (-15 -3063 ($ (-568) (-568)))))) (T -216)) 
+((-3063 (*1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-216))))) 
+(-13 (-677 (-215) (-218) (-218)) (-10 -8 (-15 -3063 ($ (-568) (-568))))) 
+((-3311 (((-169 (-215)) (-763) (-169 (-215))) 40) (((-215) (-763) (-215)) 41)) (-2761 (((-169 (-215)) (-169 (-215))) 42) (((-215) (-215)) 43)) (-3787 (((-169 (-215)) (-169 (-215)) (-169 (-215))) 48) (((-215) (-215) (-215)) 51)) (-2383 (((-169 (-215)) (-169 (-215))) 53) (((-215) (-215)) 52)) (-3301 (((-169 (-215)) (-169 (-215)) (-169 (-215))) 70) (((-215) (-215) (-215)) 62)) (-2149 (((-169 (-215)) (-169 (-215)) (-169 (-215))) 73) (((-215) (-215) (-215)) 71)) (-3826 (((-169 (-215)) (-169 (-215)) (-169 (-215))) 44) (((-215) (-215) (-215)) 45)) (-2547 (((-169 (-215)) (-169 (-215)) (-169 (-215))) 46) (((-215) (-215) (-215)) 47)) (-1813 (((-169 (-215)) (-169 (-215))) 84) (((-215) (-215)) 83)) (-4009 (((-215) (-215)) 78) (((-169 (-215)) (-169 (-215))) 82)) (-2209 (((-169 (-215)) (-169 (-215))) 7) (((-215) (-215)) 9)) (-1465 (((-828 (-215)) (-568) (-215)) 23)) (-2192 (((-828 (-215)) (-828 (-215))) 36)) (-2758 (((-828 (-215)) (-828 (-215))) 35)) (-3458 (((-828 (-215)) (-828 (-215))) 34)) (-2448 (((-828 (-215)) (-828 (-215))) 33)) (-1358 (((-828 (-215)) (-828 (-215))) 32)) (-2745 (((-828 (-215)) (-828 (-215))) 31)) (-4366 (((-828 (-215)) (-828 (-215))) 37)) (-4464 (((-828 (-215)) (-215)) 22)) (-2768 (((-169 (-215)) (-169 (-215)) (-169 (-215))) 58) (((-215) (-215) (-215)) 54))) 
+(((-217) (-10 -7 (-15 -2209 ((-215) (-215))) (-15 -2209 ((-169 (-215)) (-169 (-215)))) (-15 -4464 ((-828 (-215)) (-215))) (-15 -1465 ((-828 (-215)) (-568) (-215))) (-15 -4366 ((-828 (-215)) (-828 (-215)))) (-15 -2745 ((-828 (-215)) (-828 (-215)))) (-15 -1358 ((-828 (-215)) (-828 (-215)))) (-15 -2448 ((-828 (-215)) (-828 (-215)))) (-15 -3458 ((-828 (-215)) (-828 (-215)))) (-15 -2758 ((-828 (-215)) (-828 (-215)))) (-15 -2192 ((-828 (-215)) (-828 (-215)))) (-15 -2768 ((-215) (-215) (-215))) (-15 -2768 ((-169 (-215)) (-169 (-215)) (-169 (-215)))) (-15 -2761 ((-215) (-215))) (-15 -2761 ((-169 (-215)) (-169 (-215)))) (-15 -2383 ((-215) (-215))) (-15 -2383 ((-169 (-215)) (-169 (-215)))) (-15 -3311 ((-215) (-763) (-215))) (-15 -3311 ((-169 (-215)) (-763) (-169 (-215)))) (-15 -3826 ((-215) (-215) (-215))) (-15 -3826 ((-169 (-215)) (-169 (-215)) (-169 (-215)))) (-15 -3301 ((-215) (-215) (-215))) (-15 -3301 ((-169 (-215)) (-169 (-215)) (-169 (-215)))) (-15 -2547 ((-215) (-215) (-215))) (-15 -2547 ((-169 (-215)) (-169 (-215)) (-169 (-215)))) (-15 -2149 ((-215) (-215) (-215))) (-15 -2149 ((-169 (-215)) (-169 (-215)) (-169 (-215)))) (-15 -4009 ((-169 (-215)) (-169 (-215)))) (-15 -4009 ((-215) (-215))) (-15 -1813 ((-215) (-215))) (-15 -1813 ((-169 (-215)) (-169 (-215)))) (-15 -3787 ((-215) (-215) (-215))) (-15 -3787 ((-169 (-215)) (-169 (-215)) (-169 (-215)))))) (T -217)) 
+((-3787 (*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) (-3787 (*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) (-1813 (*1 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) (-1813 (*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) (-4009 (*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) (-4009 (*1 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) (-2149 (*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) (-2149 (*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) (-2547 (*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) (-2547 (*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) (-3301 (*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) (-3301 (*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) (-3826 (*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) (-3826 (*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) (-3311 (*1 *2 *3 *2) (-12 (-5 *2 (-169 (-215))) (-5 *3 (-763)) (-5 *1 (-217)))) (-3311 (*1 *2 *3 *2) (-12 (-5 *2 (-215)) (-5 *3 (-763)) (-5 *1 (-217)))) (-2383 (*1 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) (-2383 (*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) (-2761 (*1 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) (-2761 (*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) (-2768 (*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) (-2768 (*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) (-2192 (*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217)))) (-2758 (*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217)))) (-3458 (*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217)))) (-2448 (*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217)))) (-1358 (*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217)))) (-2745 (*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217)))) (-4366 (*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217)))) (-1465 (*1 *2 *3 *4) (-12 (-5 *3 (-568)) (-5 *2 (-828 (-215))) (-5 *1 (-217)) (-5 *4 (-215)))) (-4464 (*1 *2 *3) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217)) (-5 *3 (-215)))) (-2209 (*1 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) (-2209 (*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217))))) 
+(-10 -7 (-15 -2209 ((-215) (-215))) (-15 -2209 ((-169 (-215)) (-169 (-215)))) (-15 -4464 ((-828 (-215)) (-215))) (-15 -1465 ((-828 (-215)) (-568) (-215))) (-15 -4366 ((-828 (-215)) (-828 (-215)))) (-15 -2745 ((-828 (-215)) (-828 (-215)))) (-15 -1358 ((-828 (-215)) (-828 (-215)))) (-15 -2448 ((-828 (-215)) (-828 (-215)))) (-15 -3458 ((-828 (-215)) (-828 (-215)))) (-15 -2758 ((-828 (-215)) (-828 (-215)))) (-15 -2192 ((-828 (-215)) (-828 (-215)))) (-15 -2768 ((-215) (-215) (-215))) (-15 -2768 ((-169 (-215)) (-169 (-215)) (-169 (-215)))) (-15 -2761 ((-215) (-215))) (-15 -2761 ((-169 (-215)) (-169 (-215)))) (-15 -2383 ((-215) (-215))) (-15 -2383 ((-169 (-215)) (-169 (-215)))) (-15 -3311 ((-215) (-763) (-215))) (-15 -3311 ((-169 (-215)) (-763) (-169 (-215)))) (-15 -3826 ((-215) (-215) (-215))) (-15 -3826 ((-169 (-215)) (-169 (-215)) (-169 (-215)))) (-15 -3301 ((-215) (-215) (-215))) (-15 -3301 ((-169 (-215)) (-169 (-215)) (-169 (-215)))) (-15 -2547 ((-215) (-215) (-215))) (-15 -2547 ((-169 (-215)) (-169 (-215)) (-169 (-215)))) (-15 -2149 ((-215) (-215) (-215))) (-15 -2149 ((-169 (-215)) (-169 (-215)) (-169 (-215)))) (-15 -4009 ((-169 (-215)) (-169 (-215)))) (-15 -4009 ((-215) (-215))) (-15 -1813 ((-215) (-215))) (-15 -1813 ((-169 (-215)) (-169 (-215)))) (-15 -3787 ((-215) (-215) (-215))) (-15 -3787 ((-169 (-215)) (-169 (-215)) (-169 (-215))))) 
+((-2449 (((-121) $ $) NIL (|has| (-215) (-1090)))) (-3207 (($ (-763)) NIL (|has| (-215) (-23)))) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-1324 (((-121) (-1 (-121) (-215) (-215)) $) NIL) (((-121) $) NIL (|has| (-215) (-842)))) (-2109 (($ (-1 (-121) (-215) (-215)) $) NIL (|has| $ (-6 -4522))) (($ $) NIL (-12 (|has| $ (-6 -4522)) (|has| (-215) (-842))))) (-3647 (($ (-1 (-121) (-215) (-215)) $) NIL) (($ $) NIL (|has| (-215) (-842)))) (-1667 (((-121) $ (-763)) NIL)) (-2438 (((-215) $ (-568) (-215)) 17 (|has| $ (-6 -4522))) (((-215) $ (-1210 (-568)) (-215)) NIL (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) (-215)) $) NIL (|has| $ (-6 -4521)))) (-4490 (($) NIL T CONST)) (-4452 (($ $) NIL (|has| $ (-6 -4522)))) (-3945 (($ $) NIL)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-215) (-1090))))) (-4330 (($ (-215) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-215) (-1090)))) (($ (-1 (-121) (-215)) $) NIL (|has| $ (-6 -4521)))) (-3094 (((-215) (-1 (-215) (-215) (-215)) $ (-215) (-215)) NIL (-12 (|has| $ (-6 -4521)) (|has| (-215) (-1090)))) (((-215) (-1 (-215) (-215) (-215)) $ (-215)) NIL (|has| $ (-6 -4521))) (((-215) (-1 (-215) (-215) (-215)) $) NIL (|has| $ (-6 -4521)))) (-1292 (((-215) $ (-568) (-215)) 9 (|has| $ (-6 -4522)))) (-3063 (($ (-568)) 14)) (-2069 (((-215) $ (-568)) 8)) (-2766 (((-568) (-1 (-121) (-215)) $) NIL) (((-568) (-215) $) NIL (|has| (-215) (-1090))) (((-568) (-215) $ (-568)) NIL (|has| (-215) (-1090)))) (-3317 (((-634 (-215)) $) NIL (|has| $ (-6 -4521)))) (-1804 (((-679 (-215)) $ $) NIL (|has| (-215) (-1047)))) (-1851 (($ (-763) (-215)) 15)) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) 12 (|has| (-568) (-842)))) (-1732 (($ $ $) NIL (|has| (-215) (-842)))) (-3645 (($ (-1 (-121) (-215) (-215)) $ $) NIL) (($ $ $) NIL (|has| (-215) (-842)))) (-4406 (((-634 (-215)) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) (-215) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-215) (-1090))))) (-3631 (((-568) $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (|has| (-215) (-842)))) (-2253 (($ (-1 (-215) (-215)) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-215) (-215)) $) NIL) (($ (-1 (-215) (-215) (-215)) $ $) NIL)) (-4303 (((-215) $) NIL (-12 (|has| (-215) (-1002)) (|has| (-215) (-1047))))) (-3796 (((-121) $ (-763)) NIL)) (-3680 (((-215) $) NIL (-12 (|has| (-215) (-1002)) (|has| (-215) (-1047))))) (-1893 (((-1143) $) NIL (|has| (-215) (-1090)))) (-4124 (($ (-215) $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4025 (((-1108) $) NIL (|has| (-215) (-1090)))) (-3877 (((-215) $) NIL (|has| (-568) (-842)))) (-2712 (((-3 (-215) "failed") (-1 (-121) (-215)) $) NIL)) (-2490 (($ $ (-215)) 18 (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) (-215)) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-215)))) NIL (-12 (|has| (-215) (-303 (-215))) (|has| (-215) (-1090)))) (($ $ (-288 (-215))) NIL (-12 (|has| (-215) (-303 (-215))) (|has| (-215) (-1090)))) (($ $ (-215) (-215)) NIL (-12 (|has| (-215) (-303 (-215))) (|has| (-215) (-1090)))) (($ $ (-634 (-215)) (-634 (-215))) NIL (-12 (|has| (-215) (-303 (-215))) (|has| (-215) (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) (-215) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-215) (-1090))))) (-1480 (((-634 (-215)) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) 13)) (-2781 (((-215) $ (-568) (-215)) NIL) (((-215) $ (-568)) 16) (($ $ (-1210 (-568))) NIL)) (-2286 (((-215) $ $) NIL (|has| (-215) (-1047)))) (-2828 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-3372 (($ $ $) NIL (|has| (-215) (-1047)))) (-4170 (((-763) (-1 (-121) (-215)) $) NIL (|has| $ (-6 -4521))) (((-763) (-215) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-215) (-1090))))) (-3306 (($ $ $ (-568)) NIL (|has| $ (-6 -4522)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| (-215) (-609 (-541))))) (-4289 (($ (-634 (-215))) NIL)) (-2770 (($ $ (-215)) NIL) (($ (-215) $) NIL) (($ $ $) NIL) (($ (-634 $)) NIL)) (-2747 (((-850) $) NIL (|has| (-215) (-1090)))) (-3437 (((-121) (-1 (-121) (-215)) $) NIL (|has| $ (-6 -4521)))) (-1753 (((-121) $ $) NIL (|has| (-215) (-842)))) (-1740 (((-121) $ $) NIL (|has| (-215) (-842)))) (-1719 (((-121) $ $) NIL (|has| (-215) (-1090)))) (-1747 (((-121) $ $) NIL (|has| (-215) (-842)))) (-1734 (((-121) $ $) NIL (|has| (-215) (-842)))) (-1775 (($ $) NIL (|has| (-215) (-21))) (($ $ $) NIL (|has| (-215) (-21)))) (-1769 (($ $ $) NIL (|has| (-215) (-25)))) (* (($ (-568) $) NIL (|has| (-215) (-21))) (($ (-215) $) NIL (|has| (-215) (-716))) (($ $ (-215)) NIL (|has| (-215) (-716)))) (-1699 (((-763) $) 11 (|has| $ (-6 -4521))))) 
+(((-218) (-13 (-1242 (-215)) (-10 -8 (-15 -3063 ($ (-568)))))) (T -218)) 
+((-3063 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-218))))) 
+(-13 (-1242 (-215)) (-10 -8 (-15 -3063 ($ (-568))))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3207 (($ (-763) (-763)) NIL)) (-4486 (($ $ $) NIL)) (-4089 (($ (-1244 |#1|)) NIL) (($ $) NIL)) (-1861 (($ |#1| |#1| |#1|) 32)) (-3560 (((-121) $) NIL)) (-3211 (($ $ (-568) (-568)) NIL)) (-3096 (($ $ (-568) (-568)) NIL)) (-2265 (($ $ (-568) (-568) (-568) (-568)) NIL)) (-4467 (($ $) NIL)) (-3691 (((-121) $) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-4043 (($ $ (-568) (-568) $) NIL)) (-2438 ((|#1| $ (-568) (-568) |#1|) NIL) (($ $ (-634 (-568)) (-634 (-568)) $) NIL)) (-3874 (($ $ (-568) (-1244 |#1|)) NIL)) (-2525 (($ $ (-568) (-1244 |#1|)) NIL)) (-3225 (($ |#1| |#1| |#1|) 31)) (-1637 (($ (-763) |#1|) NIL)) (-4490 (($) NIL T CONST)) (-3912 (($ $) NIL (|has| |#1| (-301)))) (-2228 (((-1244 |#1|) $ (-568)) NIL)) (-3353 (($ |#1|) 30)) (-1789 (($ |#1|) 29)) (-2516 (($ |#1|) 28)) (-2371 (((-763) $) NIL (|has| |#1| (-558)))) (-1292 ((|#1| $ (-568) (-568) |#1|) NIL)) (-2069 ((|#1| $ (-568) (-568)) NIL)) (-3102 ((|#1| $) NIL (|has| |#1| (-172)))) (-3317 (((-634 |#1|) $) NIL)) (-3344 (((-763) $) NIL (|has| |#1| (-558)))) (-2934 (((-634 (-1244 |#1|)) $) NIL (|has| |#1| (-558)))) (-2241 (((-763) $) NIL)) (-1851 (($ (-763) (-763) |#1|) NIL)) (-1901 (((-763) $) NIL)) (-3791 (((-121) $ (-763)) NIL)) (-2424 ((|#1| $) NIL (|has| |#1| (-6 (-4523 "*"))))) (-3139 (((-568) $) NIL)) (-1343 (((-568) $) NIL)) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3405 (((-568) $) NIL)) (-2801 (((-568) $) NIL)) (-2271 (($ (-634 (-634 |#1|))) 10)) (-2253 (($ (-1 |#1| |#1|) $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-1843 (((-634 (-634 |#1|)) $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-2715 (((-3 $ "failed") $) NIL (|has| |#1| (-365)))) (-4294 (($) 11)) (-4018 (($ $ $) NIL)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-2490 (($ $ |#1|) NIL)) (-2597 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558)))) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#1| $ (-568) (-568)) NIL) ((|#1| $ (-568) (-568) |#1|) NIL) (($ $ (-634 (-568)) (-634 (-568))) NIL)) (-3499 (($ (-634 |#1|)) NIL) (($ (-634 $)) NIL)) (-4322 (((-121) $) NIL)) (-2591 ((|#1| $) NIL (|has| |#1| (-6 (-4523 "*"))))) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) NIL)) (-4063 (((-634 (-1244 |#1|)) $) NIL (|has| |#1| (-301)))) (-2522 (((-1244 |#1|) $ (-568)) NIL)) (-2747 (((-850) $) NIL (|has| |#1| (-1090))) (($ (-1244 |#1|)) NIL)) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-2675 (((-121) $) NIL)) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1775 (($ $ $) NIL) (($ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (* (($ $ $) NIL) (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ (-568) $) NIL) (((-1244 |#1|) $ (-1244 |#1|)) 14) (((-1244 |#1|) (-1244 |#1|) $) NIL) (((-944 |#1|) $ (-944 |#1|)) 20)) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-219 |#1|) (-13 (-677 |#1| (-1244 |#1|) (-1244 |#1|)) (-10 -8 (-15 * ((-944 |#1|) $ (-944 |#1|))) (-15 -4294 ($)) (-15 -2516 ($ |#1|)) (-15 -1789 ($ |#1|)) (-15 -3353 ($ |#1|)) (-15 -3225 ($ |#1| |#1| |#1|)) (-15 -1861 ($ |#1| |#1| |#1|)))) (-13 (-365) (-1181))) (T -219)) 
+((* (*1 *2 *1 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181))) (-5 *1 (-219 *3)))) (-4294 (*1 *1) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181))))) (-2516 (*1 *1 *2) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181))))) (-1789 (*1 *1 *2) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181))))) (-3353 (*1 *1 *2) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181))))) (-3225 (*1 *1 *2 *2 *2) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181))))) (-1861 (*1 *1 *2 *2 *2) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181)))))) 
+(-13 (-677 |#1| (-1244 |#1|) (-1244 |#1|)) (-10 -8 (-15 * ((-944 |#1|) $ (-944 |#1|))) (-15 -4294 ($)) (-15 -2516 ($ |#1|)) (-15 -1789 ($ |#1|)) (-15 -3353 ($ |#1|)) (-15 -3225 ($ |#1| |#1| |#1|)) (-15 -1861 ($ |#1| |#1| |#1|)))) 
+((-3963 (($ (-1 (-121) |#2|) $) 17)) (-1568 (($ |#2| $) NIL) (($ (-1 (-121) |#2|) $) 25)) (-3132 (($) NIL) (($ (-634 |#2|)) 11)) (-1719 (((-121) $ $) 23))) 
+(((-220 |#1| |#2|) (-10 -8 (-15 -3963 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -1568 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -1568 (|#1| |#2| |#1|)) (-15 -3132 (|#1| (-634 |#2|))) (-15 -3132 (|#1|)) (-15 -1719 ((-121) |#1| |#1|))) (-221 |#2|) (-1090)) (T -220)) 
+NIL 
+(-10 -8 (-15 -3963 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -1568 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -1568 (|#1| |#2| |#1|)) (-15 -3132 (|#1| (-634 |#2|))) (-15 -3132 (|#1|)) (-15 -1719 ((-121) |#1| |#1|))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-1667 (((-121) $ (-763)) 8)) (-3963 (($ (-1 (-121) |#1|) $) 42 (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) |#1|) $) 52 (|has| $ (-6 -4521)))) (-4490 (($) 7 T CONST)) (-3926 (($ $) 55 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-1568 (($ |#1| $) 44 (|has| $ (-6 -4521))) (($ (-1 (-121) |#1|) $) 43 (|has| $ (-6 -4521)))) (-4330 (($ |#1| $) 54 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) |#1|) $) 51 (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4521)))) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) 9)) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35)) (-3796 (((-121) $ (-763)) 10)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-2580 ((|#1| $) 36)) (-1708 (($ |#1| $) 37)) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 48)) (-3403 ((|#1| $) 38)) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-3132 (($) 46) (($ (-634 |#1|)) 45)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-4280 (((-541) $) 56 (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) 47)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-4074 (($ (-634 |#1|)) 39)) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-221 |#1|) (-1275) (-1090)) (T -221)) 
 NIL 
 (-13 (-227 |t#1|)) 
 (((-39) . T) ((-111 |#1|) . T) ((-105) |has| |#1| (-1090)) ((-608 (-850)) |has| |#1| (-1090)) ((-154 |#1|) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-227 |#1|) . T) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-1090) |has| |#1| (-1090)) ((-1195) . T)) 
-((-4189 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-763)) 11) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) 19) (($ $ (-763)) NIL) (($ $) 16)) (-3190 (($ $ (-1 |#2| |#2|)) 12) (($ $ (-1 |#2| |#2|) (-763)) 14) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) NIL) (($ $ (-763)) NIL) (($ $) NIL))) 
-(((-222 |#1| |#2|) (-10 -8 (-15 -4189 (|#1| |#1|)) (-15 -3190 (|#1| |#1|)) (-15 -4189 (|#1| |#1| (-763))) (-15 -3190 (|#1| |#1| (-763))) (-15 -4189 (|#1| |#1| (-1161))) (-15 -4189 (|#1| |#1| (-634 (-1161)))) (-15 -4189 (|#1| |#1| (-1161) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -3190 (|#1| |#1| (-1161))) (-15 -3190 (|#1| |#1| (-634 (-1161)))) (-15 -3190 (|#1| |#1| (-1161) (-763))) (-15 -3190 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -3190 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -3190 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|)))) (-223 |#2|) (-1047)) (T -222)) 
+((-4191 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-763)) 11) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) 19) (($ $ (-763)) NIL) (($ $) 16)) (-3192 (($ $ (-1 |#2| |#2|)) 12) (($ $ (-1 |#2| |#2|) (-763)) 14) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) NIL) (($ $ (-763)) NIL) (($ $) NIL))) 
+(((-222 |#1| |#2|) (-10 -8 (-15 -4191 (|#1| |#1|)) (-15 -3192 (|#1| |#1|)) (-15 -4191 (|#1| |#1| (-763))) (-15 -3192 (|#1| |#1| (-763))) (-15 -4191 (|#1| |#1| (-1161))) (-15 -4191 (|#1| |#1| (-634 (-1161)))) (-15 -4191 (|#1| |#1| (-1161) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -3192 (|#1| |#1| (-1161))) (-15 -3192 (|#1| |#1| (-634 (-1161)))) (-15 -3192 (|#1| |#1| (-1161) (-763))) (-15 -3192 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -3192 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -3192 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|)))) (-223 |#2|) (-1047)) (T -222)) 
 NIL 
-(-10 -8 (-15 -4189 (|#1| |#1|)) (-15 -3190 (|#1| |#1|)) (-15 -4189 (|#1| |#1| (-763))) (-15 -3190 (|#1| |#1| (-763))) (-15 -4189 (|#1| |#1| (-1161))) (-15 -4189 (|#1| |#1| (-634 (-1161)))) (-15 -4189 (|#1| |#1| (-1161) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -3190 (|#1| |#1| (-1161))) (-15 -3190 (|#1| |#1| (-634 (-1161)))) (-15 -3190 (|#1| |#1| (-1161) (-763))) (-15 -3190 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -3190 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -3190 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-2925 (((-3 $ "failed") $) 33)) (-2735 (((-121) $) 30)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-4189 (($ $ (-1 |#1| |#1|)) 51) (($ $ (-1 |#1| |#1|) (-763)) 50) (($ $ (-634 (-1161)) (-634 (-763))) 43 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 42 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 41 (|has| |#1| (-895 (-1161)))) (($ $ (-1161)) 40 (|has| |#1| (-895 (-1161)))) (($ $ (-763)) 38 (|has| |#1| (-225))) (($ $) 36 (|has| |#1| (-225)))) (-2745 (((-850) $) 11) (($ (-568)) 27)) (-4078 (((-763)) 28)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $ (-1 |#1| |#1|)) 49) (($ $ (-1 |#1| |#1|) (-763)) 48) (($ $ (-634 (-1161)) (-634 (-763))) 47 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 46 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 45 (|has| |#1| (-895 (-1161)))) (($ $ (-1161)) 44 (|has| |#1| (-895 (-1161)))) (($ $ (-763)) 39 (|has| |#1| (-225))) (($ $) 37 (|has| |#1| (-225)))) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
+(-10 -8 (-15 -4191 (|#1| |#1|)) (-15 -3192 (|#1| |#1|)) (-15 -4191 (|#1| |#1| (-763))) (-15 -3192 (|#1| |#1| (-763))) (-15 -4191 (|#1| |#1| (-1161))) (-15 -4191 (|#1| |#1| (-634 (-1161)))) (-15 -4191 (|#1| |#1| (-1161) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -3192 (|#1| |#1| (-1161))) (-15 -3192 (|#1| |#1| (-634 (-1161)))) (-15 -3192 (|#1| |#1| (-1161) (-763))) (-15 -3192 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -3192 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -3192 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-2902 (((-3 $ "failed") $) 33)) (-1598 (((-121) $) 30)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-4191 (($ $ (-1 |#1| |#1|)) 51) (($ $ (-1 |#1| |#1|) (-763)) 50) (($ $ (-634 (-1161)) (-634 (-763))) 43 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 42 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 41 (|has| |#1| (-895 (-1161)))) (($ $ (-1161)) 40 (|has| |#1| (-895 (-1161)))) (($ $ (-763)) 38 (|has| |#1| (-225))) (($ $) 36 (|has| |#1| (-225)))) (-2747 (((-850) $) 11) (($ (-568)) 27)) (-3425 (((-763)) 28)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $ (-1 |#1| |#1|)) 49) (($ $ (-1 |#1| |#1|) (-763)) 48) (($ $ (-634 (-1161)) (-634 (-763))) 47 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 46 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 45 (|has| |#1| (-895 (-1161)))) (($ $ (-1161)) 44 (|has| |#1| (-895 (-1161)))) (($ $ (-763)) 39 (|has| |#1| (-225))) (($ $) 37 (|has| |#1| (-225)))) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
 (((-223 |#1|) (-1275) (-1047)) (T -223)) 
-((-4189 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-223 *3)) (-4 *3 (-1047)))) (-4189 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1 *4 *4)) (-5 *3 (-763)) (-4 *1 (-223 *4)) (-4 *4 (-1047)))) (-3190 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-223 *3)) (-4 *3 (-1047)))) (-3190 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1 *4 *4)) (-5 *3 (-763)) (-4 *1 (-223 *4)) (-4 *4 (-1047))))) 
-(-13 (-1047) (-10 -8 (-15 -4189 ($ $ (-1 |t#1| |t#1|))) (-15 -4189 ($ $ (-1 |t#1| |t#1|) (-763))) (-15 -3190 ($ $ (-1 |t#1| |t#1|))) (-15 -3190 ($ $ (-1 |t#1| |t#1|) (-763))) (IF (|has| |t#1| (-225)) (-6 (-225)) |noBranch|) (IF (|has| |t#1| (-895 (-1161))) (-6 (-895 (-1161))) |noBranch|))) 
+((-4191 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-223 *3)) (-4 *3 (-1047)))) (-4191 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1 *4 *4)) (-5 *3 (-763)) (-4 *1 (-223 *4)) (-4 *4 (-1047)))) (-3192 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-223 *3)) (-4 *3 (-1047)))) (-3192 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1 *4 *4)) (-5 *3 (-763)) (-4 *1 (-223 *4)) (-4 *4 (-1047))))) 
+(-13 (-1047) (-10 -8 (-15 -4191 ($ $ (-1 |t#1| |t#1|))) (-15 -4191 ($ $ (-1 |t#1| |t#1|) (-763))) (-15 -3192 ($ $ (-1 |t#1| |t#1|))) (-15 -3192 ($ $ (-1 |t#1| |t#1|) (-763))) (IF (|has| |t#1| (-225)) (-6 (-225)) |noBranch|) (IF (|has| |t#1| (-895 (-1161))) (-6 (-895 (-1161))) |noBranch|))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-137) . T) ((-608 (-850)) . T) ((-225) |has| |#1| (-225)) ((-637 $) . T) ((-716) . T) ((-895 (-1161)) |has| |#1| (-895 (-1161))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-4189 (($ $) NIL) (($ $ (-763)) 10)) (-3190 (($ $) 8) (($ $ (-763)) 12))) 
-(((-224 |#1|) (-10 -8 (-15 -3190 (|#1| |#1| (-763))) (-15 -4189 (|#1| |#1| (-763))) (-15 -3190 (|#1| |#1|)) (-15 -4189 (|#1| |#1|))) (-225)) (T -224)) 
+((-4191 (($ $) NIL) (($ $ (-763)) 10)) (-3192 (($ $) 8) (($ $ (-763)) 12))) 
+(((-224 |#1|) (-10 -8 (-15 -3192 (|#1| |#1| (-763))) (-15 -4191 (|#1| |#1| (-763))) (-15 -3192 (|#1| |#1|)) (-15 -4191 (|#1| |#1|))) (-225)) (T -224)) 
 NIL 
-(-10 -8 (-15 -3190 (|#1| |#1| (-763))) (-15 -4189 (|#1| |#1| (-763))) (-15 -3190 (|#1| |#1|)) (-15 -4189 (|#1| |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-2925 (((-3 $ "failed") $) 33)) (-2735 (((-121) $) 30)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-4189 (($ $) 37) (($ $ (-763)) 35)) (-2745 (((-850) $) 11) (($ (-568)) 27)) (-4078 (((-763)) 28)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $) 36) (($ $ (-763)) 34)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
+(-10 -8 (-15 -3192 (|#1| |#1| (-763))) (-15 -4191 (|#1| |#1| (-763))) (-15 -3192 (|#1| |#1|)) (-15 -4191 (|#1| |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-2902 (((-3 $ "failed") $) 33)) (-1598 (((-121) $) 30)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-4191 (($ $) 37) (($ $ (-763)) 35)) (-2747 (((-850) $) 11) (($ (-568)) 27)) (-3425 (((-763)) 28)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $) 36) (($ $ (-763)) 34)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
 (((-225) (-1275)) (T -225)) 
-((-4189 (*1 *1 *1) (-4 *1 (-225))) (-3190 (*1 *1 *1) (-4 *1 (-225))) (-4189 (*1 *1 *1 *2) (-12 (-4 *1 (-225)) (-5 *2 (-763)))) (-3190 (*1 *1 *1 *2) (-12 (-4 *1 (-225)) (-5 *2 (-763))))) 
-(-13 (-1047) (-10 -8 (-15 -4189 ($ $)) (-15 -3190 ($ $)) (-15 -4189 ($ $ (-763))) (-15 -3190 ($ $ (-763))))) 
+((-4191 (*1 *1 *1) (-4 *1 (-225))) (-3192 (*1 *1 *1) (-4 *1 (-225))) (-4191 (*1 *1 *1 *2) (-12 (-4 *1 (-225)) (-5 *2 (-763)))) (-3192 (*1 *1 *1 *2) (-12 (-4 *1 (-225)) (-5 *2 (-763))))) 
+(-13 (-1047) (-10 -8 (-15 -4191 ($ $)) (-15 -3192 ($ $)) (-15 -4191 ($ $ (-763))) (-15 -3192 ($ $ (-763))))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 $) . T) ((-716) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-2085 (($) 12) (($ (-634 |#2|)) NIL)) (-3863 (($ $) 14)) (-4287 (($ (-634 |#2|)) 10)) (-2745 (((-850) $) 21))) 
-(((-226 |#1| |#2|) (-10 -8 (-15 -2085 (|#1| (-634 |#2|))) (-15 -2085 (|#1|)) (-15 -4287 (|#1| (-634 |#2|))) (-15 -2745 ((-850) |#1|)) (-15 -3863 (|#1| |#1|))) (-227 |#2|) (-1090)) (T -226)) 
+((-3132 (($) 12) (($ (-634 |#2|)) NIL)) (-3865 (($ $) 14)) (-4289 (($ (-634 |#2|)) 10)) (-2747 (((-850) $) 21))) 
+(((-226 |#1| |#2|) (-10 -8 (-15 -3132 (|#1| (-634 |#2|))) (-15 -3132 (|#1|)) (-15 -4289 (|#1| (-634 |#2|))) (-15 -2747 ((-850) |#1|)) (-15 -3865 (|#1| |#1|))) (-227 |#2|) (-1090)) (T -226)) 
 NIL 
-(-10 -8 (-15 -2085 (|#1| (-634 |#2|))) (-15 -2085 (|#1|)) (-15 -4287 (|#1| (-634 |#2|))) (-15 -2745 ((-850) |#1|)) (-15 -3863 (|#1| |#1|))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2510 (((-121) $ (-763)) 8)) (-3507 (($ (-1 (-121) |#1|) $) 42 (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) |#1|) $) 52 (|has| $ (-6 -4519)))) (-2671 (($) 7 T CONST)) (-3924 (($ $) 55 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3405 (($ |#1| $) 44 (|has| $ (-6 -4519))) (($ (-1 (-121) |#1|) $) 43 (|has| $ (-6 -4519)))) (-4328 (($ |#1| $) 54 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) |#1|) $) 51 (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4519)))) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) 9)) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35)) (-2166 (((-121) $ (-763)) 10)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-1890 ((|#1| $) 36)) (-4450 (($ |#1| $) 37)) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 48)) (-1315 ((|#1| $) 38)) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2085 (($) 46) (($ (-634 |#1|)) 45)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-4278 (((-541) $) 56 (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) 47)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-2367 (($ (-634 |#1|)) 39)) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+(-10 -8 (-15 -3132 (|#1| (-634 |#2|))) (-15 -3132 (|#1|)) (-15 -4289 (|#1| (-634 |#2|))) (-15 -2747 ((-850) |#1|)) (-15 -3865 (|#1| |#1|))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-1667 (((-121) $ (-763)) 8)) (-3963 (($ (-1 (-121) |#1|) $) 42 (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) |#1|) $) 52 (|has| $ (-6 -4521)))) (-4490 (($) 7 T CONST)) (-3926 (($ $) 55 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-1568 (($ |#1| $) 44 (|has| $ (-6 -4521))) (($ (-1 (-121) |#1|) $) 43 (|has| $ (-6 -4521)))) (-4330 (($ |#1| $) 54 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) |#1|) $) 51 (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4521)))) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) 9)) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35)) (-3796 (((-121) $ (-763)) 10)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-2580 ((|#1| $) 36)) (-1708 (($ |#1| $) 37)) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 48)) (-3403 ((|#1| $) 38)) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-3132 (($) 46) (($ (-634 |#1|)) 45)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-4280 (((-541) $) 56 (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) 47)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-4074 (($ (-634 |#1|)) 39)) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-227 |#1|) (-1275) (-1090)) (T -227)) 
-((-2085 (*1 *1) (-12 (-4 *1 (-227 *2)) (-4 *2 (-1090)))) (-2085 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-4 *1 (-227 *3)))) (-3405 (*1 *1 *2 *1) (-12 (|has| *1 (-6 -4519)) (-4 *1 (-227 *2)) (-4 *2 (-1090)))) (-3405 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4519)) (-4 *1 (-227 *3)) (-4 *3 (-1090)))) (-3507 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4519)) (-4 *1 (-227 *3)) (-4 *3 (-1090))))) 
-(-13 (-111 |t#1|) (-154 |t#1|) (-10 -8 (-15 -2085 ($)) (-15 -2085 ($ (-634 |t#1|))) (IF (|has| $ (-6 -4519)) (PROGN (-15 -3405 ($ |t#1| $)) (-15 -3405 ($ (-1 (-121) |t#1|) $)) (-15 -3507 ($ (-1 (-121) |t#1|) $))) |noBranch|))) 
+((-3132 (*1 *1) (-12 (-4 *1 (-227 *2)) (-4 *2 (-1090)))) (-3132 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-4 *1 (-227 *3)))) (-1568 (*1 *1 *2 *1) (-12 (|has| *1 (-6 -4521)) (-4 *1 (-227 *2)) (-4 *2 (-1090)))) (-1568 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4521)) (-4 *1 (-227 *3)) (-4 *3 (-1090)))) (-3963 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4521)) (-4 *1 (-227 *3)) (-4 *3 (-1090))))) 
+(-13 (-111 |t#1|) (-154 |t#1|) (-10 -8 (-15 -3132 ($)) (-15 -3132 ($ (-634 |t#1|))) (IF (|has| $ (-6 -4521)) (PROGN (-15 -1568 ($ |t#1| $)) (-15 -1568 ($ (-1 (-121) |t#1|) $)) (-15 -3963 ($ (-1 (-121) |t#1|) $))) |noBranch|))) 
 (((-39) . T) ((-111 |#1|) . T) ((-105) |has| |#1| (-1090)) ((-608 (-850)) |has| |#1| (-1090)) ((-154 |#1|) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-1090) |has| |#1| (-1090)) ((-1195) . T)) 
-((-2829 (((-2 (|:| |varOrder| (-634 (-1161))) (|:| |inhom| (-3 (-634 (-1244 (-763))) "failed")) (|:| |hom| (-634 (-1244 (-763))))) (-288 (-953 (-568)))) 25))) 
-(((-228) (-10 -7 (-15 -2829 ((-2 (|:| |varOrder| (-634 (-1161))) (|:| |inhom| (-3 (-634 (-1244 (-763))) "failed")) (|:| |hom| (-634 (-1244 (-763))))) (-288 (-953 (-568))))))) (T -228)) 
-((-2829 (*1 *2 *3) (-12 (-5 *3 (-288 (-953 (-568)))) (-5 *2 (-2 (|:| |varOrder| (-634 (-1161))) (|:| |inhom| (-3 (-634 (-1244 (-763))) "failed")) (|:| |hom| (-634 (-1244 (-763)))))) (-5 *1 (-228))))) 
-(-10 -7 (-15 -2829 ((-2 (|:| |varOrder| (-634 (-1161))) (|:| |inhom| (-3 (-634 (-1244 (-763))) "failed")) (|:| |hom| (-634 (-1244 (-763))))) (-288 (-953 (-568)))))) 
-((-3983 (((-763)) 51)) (-3164 (((-2 (|:| -2928 (-679 |#3|)) (|:| |vec| (-1244 |#3|))) (-679 $) (-1244 $)) 49) (((-679 |#3|) (-679 $)) 41) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-679 (-568)) (-679 $)) NIL)) (-4321 (((-139)) 57)) (-4189 (($ $ (-1 |#3| |#3|) (-763)) NIL) (($ $ (-1 |#3| |#3|)) 18) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) NIL) (($ $ (-763)) NIL) (($ $) NIL)) (-2745 (((-1244 |#3|) $) NIL) (($ |#3|) NIL) (((-850) $) NIL) (($ (-568)) 12) (($ (-409 (-568))) NIL)) (-4078 (((-763)) 15)) (-1779 (($ $ |#3|) 54))) 
-(((-229 |#1| |#2| |#3|) (-10 -8 (-15 -2745 (|#1| (-409 (-568)))) (-15 -2745 (|#1| (-568))) (-15 -2745 ((-850) |#1|)) (-15 -4078 ((-763))) (-15 -4189 (|#1| |#1|)) (-15 -4189 (|#1| |#1| (-763))) (-15 -4189 (|#1| |#1| (-1161))) (-15 -4189 (|#1| |#1| (-634 (-1161)))) (-15 -4189 (|#1| |#1| (-1161) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -3164 ((-679 (-568)) (-679 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -2745 (|#1| |#3|)) (-15 -4189 (|#1| |#1| (-1 |#3| |#3|))) (-15 -4189 (|#1| |#1| (-1 |#3| |#3|) (-763))) (-15 -3164 ((-679 |#3|) (-679 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 |#3|)) (|:| |vec| (-1244 |#3|))) (-679 |#1|) (-1244 |#1|))) (-15 -3983 ((-763))) (-15 -1779 (|#1| |#1| |#3|)) (-15 -4321 ((-139))) (-15 -2745 ((-1244 |#3|) |#1|))) (-230 |#2| |#3|) (-763) (-1195)) (T -229)) 
-((-4321 (*1 *2) (-12 (-14 *4 (-763)) (-4 *5 (-1195)) (-5 *2 (-139)) (-5 *1 (-229 *3 *4 *5)) (-4 *3 (-230 *4 *5)))) (-3983 (*1 *2) (-12 (-14 *4 *2) (-4 *5 (-1195)) (-5 *2 (-763)) (-5 *1 (-229 *3 *4 *5)) (-4 *3 (-230 *4 *5)))) (-4078 (*1 *2) (-12 (-14 *4 *2) (-4 *5 (-1195)) (-5 *2 (-763)) (-5 *1 (-229 *3 *4 *5)) (-4 *3 (-230 *4 *5))))) 
-(-10 -8 (-15 -2745 (|#1| (-409 (-568)))) (-15 -2745 (|#1| (-568))) (-15 -2745 ((-850) |#1|)) (-15 -4078 ((-763))) (-15 -4189 (|#1| |#1|)) (-15 -4189 (|#1| |#1| (-763))) (-15 -4189 (|#1| |#1| (-1161))) (-15 -4189 (|#1| |#1| (-634 (-1161)))) (-15 -4189 (|#1| |#1| (-1161) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -3164 ((-679 (-568)) (-679 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -2745 (|#1| |#3|)) (-15 -4189 (|#1| |#1| (-1 |#3| |#3|))) (-15 -4189 (|#1| |#1| (-1 |#3| |#3|) (-763))) (-15 -3164 ((-679 |#3|) (-679 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 |#3|)) (|:| |vec| (-1244 |#3|))) (-679 |#1|) (-1244 |#1|))) (-15 -3983 ((-763))) (-15 -1779 (|#1| |#1| |#3|)) (-15 -4321 ((-139))) (-15 -2745 ((-1244 |#3|) |#1|))) 
-((-2447 (((-121) $ $) 18 (|has| |#2| (-1090)))) (-2537 (((-121) $) 67 (|has| |#2| (-137)))) (-1394 (($ (-917)) 122 (|has| |#2| (-1047)))) (-1868 (((-1249) $ (-568) (-568)) 37 (|has| $ (-6 -4520)))) (-1462 (($ $ $) 118 (|has| |#2| (-788)))) (-3134 (((-3 $ "failed") $ $) 69 (|has| |#2| (-137)))) (-2510 (((-121) $ (-763)) 8)) (-3983 (((-763)) 104 (|has| |#2| (-370)))) (-3662 (((-568) $) 116 (|has| |#2| (-840)))) (-2436 ((|#2| $ (-568) |#2|) 49 (|has| $ (-6 -4520)))) (-2671 (($) 7 T CONST)) (-3666 (((-3 (-568) "failed") $) 62 (-2139 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090)))) (((-3 (-409 (-568)) "failed") $) 59 (-2139 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) (((-3 |#2| "failed") $) 56 (|has| |#2| (-1090)))) (-2854 (((-568) $) 63 (-2139 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090)))) (((-409 (-568)) $) 60 (-2139 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) ((|#2| $) 55 (|has| |#2| (-1090)))) (-3164 (((-679 (-568)) (-679 $)) 103 (-2139 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 102 (-2139 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047)))) (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) 101 (|has| |#2| (-1047))) (((-679 |#2|) (-679 $)) 100 (|has| |#2| (-1047)))) (-2925 (((-3 $ "failed") $) 75 (|has| |#2| (-716)))) (-1731 (($) 107 (|has| |#2| (-370)))) (-3989 ((|#2| $ (-568) |#2|) 50 (|has| $ (-6 -4520)))) (-2602 ((|#2| $ (-568)) 48)) (-2033 (((-121) $) 114 (|has| |#2| (-840)))) (-4360 (((-634 |#2|) $) 30 (|has| $ (-6 -4519)))) (-2735 (((-121) $) 78 (|has| |#2| (-716)))) (-2245 (((-121) $) 115 (|has| |#2| (-840)))) (-1737 (((-121) $ (-763)) 9)) (-1881 (((-568) $) 40 (|has| (-568) (-842)))) (-2521 (($ $ $) 113 (-2198 (|has| |#2| (-840)) (|has| |#2| (-788))))) (-1979 (((-634 |#2|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#2| $) 27 (-12 (|has| |#2| (-1090)) (|has| $ (-6 -4519))))) (-2223 (((-568) $) 41 (|has| (-568) (-842)))) (-3268 (($ $ $) 112 (-2198 (|has| |#2| (-840)) (|has| |#2| (-788))))) (-3674 (($ (-1 |#2| |#2|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#2| |#2|) $) 35)) (-3683 (((-917) $) 106 (|has| |#2| (-370)))) (-2166 (((-121) $ (-763)) 10)) (-4487 (((-1143) $) 22 (|has| |#2| (-1090)))) (-4174 (((-634 (-568)) $) 43)) (-3578 (((-121) (-568) $) 44)) (-4355 (($ (-917)) 105 (|has| |#2| (-370)))) (-4022 (((-1108) $) 21 (|has| |#2| (-1090)))) (-3876 ((|#2| $) 39 (|has| (-568) (-842)))) (-3724 (($ $ |#2|) 38 (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) |#2|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#2|))) 26 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) 25 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) 24 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) 23 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-3171 (((-121) $ $) 14)) (-4467 (((-121) |#2| $) 42 (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-2041 (((-634 |#2|) $) 45)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 ((|#2| $ (-568) |#2|) 47) ((|#2| $ (-568)) 46)) (-3682 ((|#2| $ $) 121 (|has| |#2| (-1047)))) (-2039 (($ (-1244 |#2|)) 123)) (-4321 (((-139)) 120 (|has| |#2| (-365)))) (-4189 (($ $) 95 (-2139 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-763)) 93 (-2139 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-1161)) 91 (-2139 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161))) 90 (-2139 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1161) (-763)) 89 (-2139 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161)) (-634 (-763))) 88 (-2139 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1 |#2| |#2|) (-763)) 81 (|has| |#2| (-1047))) (($ $ (-1 |#2| |#2|)) 80 (|has| |#2| (-1047)))) (-4168 (((-763) (-1 (-121) |#2|) $) 31 (|has| $ (-6 -4519))) (((-763) |#2| $) 28 (-12 (|has| |#2| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-2745 (((-1244 |#2|) $) 124) (((-850) $) 20 (|has| |#2| (-1090))) (($ (-568)) 61 (-2198 (-2139 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090))) (|has| |#2| (-1047)))) (($ (-409 (-568))) 58 (-2139 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) (($ |#2|) 57 (|has| |#2| (-1090)))) (-4078 (((-763)) 99 (|has| |#2| (-1047)))) (-1319 (((-121) (-1 (-121) |#2|) $) 33 (|has| $ (-6 -4519)))) (-2897 (($ $) 117 (|has| |#2| (-840)))) (-1887 (($ $ (-763)) 76 (|has| |#2| (-716))) (($ $ (-917)) 72 (|has| |#2| (-716)))) (-3056 (($) 66 (|has| |#2| (-137)) CONST)) (-1556 (($) 79 (|has| |#2| (-716)) CONST)) (-3190 (($ $) 94 (-2139 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-763)) 92 (-2139 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-1161)) 87 (-2139 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161))) 86 (-2139 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1161) (-763)) 85 (-2139 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161)) (-634 (-763))) 84 (-2139 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1 |#2| |#2|) (-763)) 83 (|has| |#2| (-1047))) (($ $ (-1 |#2| |#2|)) 82 (|has| |#2| (-1047)))) (-1751 (((-121) $ $) 110 (-2198 (|has| |#2| (-840)) (|has| |#2| (-788))))) (-1738 (((-121) $ $) 109 (-2198 (|has| |#2| (-840)) (|has| |#2| (-788))))) (-1717 (((-121) $ $) 19 (|has| |#2| (-1090)))) (-1745 (((-121) $ $) 111 (-2198 (|has| |#2| (-840)) (|has| |#2| (-788))))) (-1732 (((-121) $ $) 108 (-2198 (|has| |#2| (-840)) (|has| |#2| (-788))))) (-1779 (($ $ |#2|) 119 (|has| |#2| (-365)))) (-1773 (($ $ $) 97 (|has| |#2| (-1047))) (($ $) 96 (|has| |#2| (-1047)))) (-1767 (($ $ $) 64 (|has| |#2| (-25)))) (** (($ $ (-763)) 77 (|has| |#2| (-716))) (($ $ (-917)) 73 (|has| |#2| (-716)))) (* (($ (-568) $) 98 (|has| |#2| (-1047))) (($ $ $) 74 (|has| |#2| (-716))) (($ $ |#2|) 71 (|has| |#2| (-1047))) (($ |#2| $) 70 (|has| |#2| (-1047))) (($ (-763) $) 68 (|has| |#2| (-137))) (($ (-917) $) 65 (|has| |#2| (-25)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-3807 (((-2 (|:| |varOrder| (-634 (-1161))) (|:| |inhom| (-3 (-634 (-1244 (-763))) "failed")) (|:| |hom| (-634 (-1244 (-763))))) (-288 (-953 (-568)))) 25))) 
+(((-228) (-10 -7 (-15 -3807 ((-2 (|:| |varOrder| (-634 (-1161))) (|:| |inhom| (-3 (-634 (-1244 (-763))) "failed")) (|:| |hom| (-634 (-1244 (-763))))) (-288 (-953 (-568))))))) (T -228)) 
+((-3807 (*1 *2 *3) (-12 (-5 *3 (-288 (-953 (-568)))) (-5 *2 (-2 (|:| |varOrder| (-634 (-1161))) (|:| |inhom| (-3 (-634 (-1244 (-763))) "failed")) (|:| |hom| (-634 (-1244 (-763)))))) (-5 *1 (-228))))) 
+(-10 -7 (-15 -3807 ((-2 (|:| |varOrder| (-634 (-1161))) (|:| |inhom| (-3 (-634 (-1244 (-763))) "failed")) (|:| |hom| (-634 (-1244 (-763))))) (-288 (-953 (-568)))))) 
+((-3986 (((-763)) 51)) (-1668 (((-2 (|:| -2908 (-679 |#3|)) (|:| |vec| (-1244 |#3|))) (-679 $) (-1244 $)) 49) (((-679 |#3|) (-679 $)) 41) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-679 (-568)) (-679 $)) NIL)) (-3108 (((-139)) 57)) (-4191 (($ $ (-1 |#3| |#3|) (-763)) NIL) (($ $ (-1 |#3| |#3|)) 18) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) NIL) (($ $ (-763)) NIL) (($ $) NIL)) (-2747 (((-1244 |#3|) $) NIL) (($ |#3|) NIL) (((-850) $) NIL) (($ (-568)) 12) (($ (-409 (-568))) NIL)) (-3425 (((-763)) 15)) (-1781 (($ $ |#3|) 54))) 
+(((-229 |#1| |#2| |#3|) (-10 -8 (-15 -2747 (|#1| (-409 (-568)))) (-15 -2747 (|#1| (-568))) (-15 -2747 ((-850) |#1|)) (-15 -3425 ((-763))) (-15 -4191 (|#1| |#1|)) (-15 -4191 (|#1| |#1| (-763))) (-15 -4191 (|#1| |#1| (-1161))) (-15 -4191 (|#1| |#1| (-634 (-1161)))) (-15 -4191 (|#1| |#1| (-1161) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -1668 ((-679 (-568)) (-679 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -2747 (|#1| |#3|)) (-15 -4191 (|#1| |#1| (-1 |#3| |#3|))) (-15 -4191 (|#1| |#1| (-1 |#3| |#3|) (-763))) (-15 -1668 ((-679 |#3|) (-679 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 |#3|)) (|:| |vec| (-1244 |#3|))) (-679 |#1|) (-1244 |#1|))) (-15 -3986 ((-763))) (-15 -1781 (|#1| |#1| |#3|)) (-15 -3108 ((-139))) (-15 -2747 ((-1244 |#3|) |#1|))) (-230 |#2| |#3|) (-763) (-1195)) (T -229)) 
+((-3108 (*1 *2) (-12 (-14 *4 (-763)) (-4 *5 (-1195)) (-5 *2 (-139)) (-5 *1 (-229 *3 *4 *5)) (-4 *3 (-230 *4 *5)))) (-3986 (*1 *2) (-12 (-14 *4 *2) (-4 *5 (-1195)) (-5 *2 (-763)) (-5 *1 (-229 *3 *4 *5)) (-4 *3 (-230 *4 *5)))) (-3425 (*1 *2) (-12 (-14 *4 *2) (-4 *5 (-1195)) (-5 *2 (-763)) (-5 *1 (-229 *3 *4 *5)) (-4 *3 (-230 *4 *5))))) 
+(-10 -8 (-15 -2747 (|#1| (-409 (-568)))) (-15 -2747 (|#1| (-568))) (-15 -2747 ((-850) |#1|)) (-15 -3425 ((-763))) (-15 -4191 (|#1| |#1|)) (-15 -4191 (|#1| |#1| (-763))) (-15 -4191 (|#1| |#1| (-1161))) (-15 -4191 (|#1| |#1| (-634 (-1161)))) (-15 -4191 (|#1| |#1| (-1161) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -1668 ((-679 (-568)) (-679 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -2747 (|#1| |#3|)) (-15 -4191 (|#1| |#1| (-1 |#3| |#3|))) (-15 -4191 (|#1| |#1| (-1 |#3| |#3|) (-763))) (-15 -1668 ((-679 |#3|) (-679 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 |#3|)) (|:| |vec| (-1244 |#3|))) (-679 |#1|) (-1244 |#1|))) (-15 -3986 ((-763))) (-15 -1781 (|#1| |#1| |#3|)) (-15 -3108 ((-139))) (-15 -2747 ((-1244 |#3|) |#1|))) 
+((-2449 (((-121) $ $) 18 (|has| |#2| (-1090)))) (-1819 (((-121) $) 67 (|has| |#2| (-137)))) (-4007 (($ (-917)) 122 (|has| |#2| (-1047)))) (-2481 (((-1249) $ (-568) (-568)) 37 (|has| $ (-6 -4522)))) (-2409 (($ $ $) 118 (|has| |#2| (-788)))) (-2689 (((-3 $ "failed") $ $) 69 (|has| |#2| (-137)))) (-1667 (((-121) $ (-763)) 8)) (-3986 (((-763)) 104 (|has| |#2| (-370)))) (-3337 (((-568) $) 116 (|has| |#2| (-840)))) (-2438 ((|#2| $ (-568) |#2|) 49 (|has| $ (-6 -4522)))) (-4490 (($) 7 T CONST)) (-3668 (((-3 (-568) "failed") $) 62 (-2141 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090)))) (((-3 (-409 (-568)) "failed") $) 59 (-2141 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) (((-3 |#2| "failed") $) 56 (|has| |#2| (-1090)))) (-2857 (((-568) $) 63 (-2141 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090)))) (((-409 (-568)) $) 60 (-2141 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) ((|#2| $) 55 (|has| |#2| (-1090)))) (-1668 (((-679 (-568)) (-679 $)) 103 (-2141 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 102 (-2141 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047)))) (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) 101 (|has| |#2| (-1047))) (((-679 |#2|) (-679 $)) 100 (|has| |#2| (-1047)))) (-2902 (((-3 $ "failed") $) 75 (|has| |#2| (-716)))) (-1733 (($) 107 (|has| |#2| (-370)))) (-1292 ((|#2| $ (-568) |#2|) 50 (|has| $ (-6 -4522)))) (-2069 ((|#2| $ (-568)) 48)) (-1436 (((-121) $) 114 (|has| |#2| (-840)))) (-3317 (((-634 |#2|) $) 30 (|has| $ (-6 -4521)))) (-1598 (((-121) $) 78 (|has| |#2| (-716)))) (-2859 (((-121) $) 115 (|has| |#2| (-840)))) (-3791 (((-121) $ (-763)) 9)) (-2539 (((-568) $) 40 (|has| (-568) (-842)))) (-1732 (($ $ $) 113 (-2199 (|has| |#2| (-840)) (|has| |#2| (-788))))) (-4406 (((-634 |#2|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#2| $) 27 (-12 (|has| |#2| (-1090)) (|has| $ (-6 -4521))))) (-3631 (((-568) $) 41 (|has| (-568) (-842)))) (-2047 (($ $ $) 112 (-2199 (|has| |#2| (-840)) (|has| |#2| (-788))))) (-2253 (($ (-1 |#2| |#2|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#2| |#2|) $) 35)) (-2291 (((-917) $) 106 (|has| |#2| (-370)))) (-3796 (((-121) $ (-763)) 10)) (-1893 (((-1143) $) 22 (|has| |#2| (-1090)))) (-3948 (((-634 (-568)) $) 43)) (-2916 (((-121) (-568) $) 44)) (-4357 (($ (-917)) 105 (|has| |#2| (-370)))) (-4025 (((-1108) $) 21 (|has| |#2| (-1090)))) (-3877 ((|#2| $) 39 (|has| (-568) (-842)))) (-2490 (($ $ |#2|) 38 (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) |#2|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#2|))) 26 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) 25 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) 24 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) 23 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-1702 (((-121) $ $) 14)) (-1801 (((-121) |#2| $) 42 (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-1480 (((-634 |#2|) $) 45)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 ((|#2| $ (-568) |#2|) 47) ((|#2| $ (-568)) 46)) (-2286 ((|#2| $ $) 121 (|has| |#2| (-1047)))) (-2041 (($ (-1244 |#2|)) 123)) (-3108 (((-139)) 120 (|has| |#2| (-365)))) (-4191 (($ $) 95 (-2141 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-763)) 93 (-2141 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-1161)) 91 (-2141 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161))) 90 (-2141 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1161) (-763)) 89 (-2141 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161)) (-634 (-763))) 88 (-2141 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1 |#2| |#2|) (-763)) 81 (|has| |#2| (-1047))) (($ $ (-1 |#2| |#2|)) 80 (|has| |#2| (-1047)))) (-4170 (((-763) (-1 (-121) |#2|) $) 31 (|has| $ (-6 -4521))) (((-763) |#2| $) 28 (-12 (|has| |#2| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-2747 (((-1244 |#2|) $) 124) (((-850) $) 20 (|has| |#2| (-1090))) (($ (-568)) 61 (-2199 (-2141 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090))) (|has| |#2| (-1047)))) (($ (-409 (-568))) 58 (-2141 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) (($ |#2|) 57 (|has| |#2| (-1090)))) (-3425 (((-763)) 99 (|has| |#2| (-1047)))) (-3437 (((-121) (-1 (-121) |#2|) $) 33 (|has| $ (-6 -4521)))) (-2811 (($ $) 117 (|has| |#2| (-840)))) (-1889 (($ $ (-763)) 76 (|has| |#2| (-716))) (($ $ (-917)) 72 (|has| |#2| (-716)))) (-3058 (($) 66 (|has| |#2| (-137)) CONST)) (-1557 (($) 79 (|has| |#2| (-716)) CONST)) (-3192 (($ $) 94 (-2141 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-763)) 92 (-2141 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-1161)) 87 (-2141 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161))) 86 (-2141 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1161) (-763)) 85 (-2141 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161)) (-634 (-763))) 84 (-2141 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1 |#2| |#2|) (-763)) 83 (|has| |#2| (-1047))) (($ $ (-1 |#2| |#2|)) 82 (|has| |#2| (-1047)))) (-1753 (((-121) $ $) 110 (-2199 (|has| |#2| (-840)) (|has| |#2| (-788))))) (-1740 (((-121) $ $) 109 (-2199 (|has| |#2| (-840)) (|has| |#2| (-788))))) (-1719 (((-121) $ $) 19 (|has| |#2| (-1090)))) (-1747 (((-121) $ $) 111 (-2199 (|has| |#2| (-840)) (|has| |#2| (-788))))) (-1734 (((-121) $ $) 108 (-2199 (|has| |#2| (-840)) (|has| |#2| (-788))))) (-1781 (($ $ |#2|) 119 (|has| |#2| (-365)))) (-1775 (($ $ $) 97 (|has| |#2| (-1047))) (($ $) 96 (|has| |#2| (-1047)))) (-1769 (($ $ $) 64 (|has| |#2| (-25)))) (** (($ $ (-763)) 77 (|has| |#2| (-716))) (($ $ (-917)) 73 (|has| |#2| (-716)))) (* (($ (-568) $) 98 (|has| |#2| (-1047))) (($ $ $) 74 (|has| |#2| (-716))) (($ $ |#2|) 71 (|has| |#2| (-1047))) (($ |#2| $) 70 (|has| |#2| (-1047))) (($ (-763) $) 68 (|has| |#2| (-137))) (($ (-917) $) 65 (|has| |#2| (-25)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-230 |#1| |#2|) (-1275) (-763) (-1195)) (T -230)) 
-((-2039 (*1 *1 *2) (-12 (-5 *2 (-1244 *4)) (-4 *4 (-1195)) (-4 *1 (-230 *3 *4)))) (-1394 (*1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-230 *3 *4)) (-4 *4 (-1047)) (-4 *4 (-1195)))) (-3682 (*1 *2 *1 *1) (-12 (-4 *1 (-230 *3 *2)) (-4 *2 (-1195)) (-4 *2 (-1047))))) 
-(-13 (-601 (-568) |t#2|) (-608 (-1244 |t#2|)) (-10 -8 (-6 -4519) (-15 -2039 ($ (-1244 |t#2|))) (IF (|has| |t#2| (-1090)) (-6 (-413 |t#2|)) |noBranch|) (IF (|has| |t#2| (-1047)) (PROGN (-6 (-120 |t#2| |t#2|)) (-6 (-223 |t#2|)) (-6 (-379 |t#2|)) (-15 -1394 ($ (-917))) (-15 -3682 (|t#2| $ $))) |noBranch|) (IF (|has| |t#2| (-25)) (-6 (-25)) |noBranch|) (IF (|has| |t#2| (-137)) (-6 (-137)) |noBranch|) (IF (|has| |t#2| (-716)) (-6 (-716 (SEQ (|:| * (-1 $ |t#2| $)) (|exit| 1 (|:| * (-1 $ $ |t#2|)))))) |noBranch|) (IF (|has| |t#2| (-370)) (-6 (-370)) |noBranch|) (IF (|has| |t#2| (-172)) (PROGN (-6 (-43 |t#2|)) (-6 (-172))) |noBranch|) (IF (|has| |t#2| (-6 -4516)) (-6 -4516) |noBranch|) (IF (|has| |t#2| (-840)) (-6 (-840)) |noBranch|) (IF (|has| |t#2| (-788)) (-6 (-788)) |noBranch|) (IF (|has| |t#2| (-365)) (-6 (-1251 |t#2|)) |noBranch|))) 
-(((-21) -2198 (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-365)) (|has| |#2| (-172))) ((-23) -2198 (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-788)) (|has| |#2| (-365)) (|has| |#2| (-172)) (|has| |#2| (-137))) ((-25) -2198 (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-788)) (|has| |#2| (-365)) (|has| |#2| (-172)) (|has| |#2| (-137)) (|has| |#2| (-25))) ((-39) . T) ((-43 |#2|) |has| |#2| (-172)) ((-105) -2198 (|has| |#2| (-1090)) (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-788)) (|has| |#2| (-716)) (|has| |#2| (-370)) (|has| |#2| (-365)) (|has| |#2| (-172)) (|has| |#2| (-137)) (|has| |#2| (-25))) ((-120 |#2| |#2|) -2198 (|has| |#2| (-1047)) (|has| |#2| (-365)) (|has| |#2| (-172))) ((-120 $ $) |has| |#2| (-172)) ((-137) -2198 (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-788)) (|has| |#2| (-365)) (|has| |#2| (-172)) (|has| |#2| (-137))) ((-608 (-850)) -2198 (|has| |#2| (-1090)) (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-788)) (|has| |#2| (-716)) (|has| |#2| (-370)) (|has| |#2| (-365)) (|has| |#2| (-172)) (|has| |#2| (-137)) (|has| |#2| (-25))) ((-608 (-1244 |#2|)) . T) ((-172) |has| |#2| (-172)) ((-223 |#2|) |has| |#2| (-1047)) ((-225) -12 (|has| |#2| (-225)) (|has| |#2| (-1047))) ((-281 (-568) |#2|) . T) ((-283 (-568) |#2|) . T) ((-303 |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) ((-370) |has| |#2| (-370)) ((-379 |#2|) |has| |#2| (-1047)) ((-413 |#2|) |has| |#2| (-1090)) ((-499 |#2|) . T) ((-601 (-568) |#2|) . T) ((-523 |#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) ((-637 |#2|) -2198 (|has| |#2| (-1047)) (|has| |#2| (-365)) (|has| |#2| (-172))) ((-637 $) -2198 (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-172))) ((-630 (-568)) -12 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047))) ((-630 |#2|) |has| |#2| (-1047)) ((-707 |#2|) -2198 (|has| |#2| (-365)) (|has| |#2| (-172))) ((-716 (SEQ (|:| * (-1 $ |#2| $)) (|exit| 1 (|:| * (-1 $ $ |#2|))))) |has| |#2| (-716)) ((-716) -2198 (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-172))) ((-786) |has| |#2| (-840)) ((-787) -2198 (|has| |#2| (-840)) (|has| |#2| (-788))) ((-788) |has| |#2| (-788)) ((-789) -2198 (|has| |#2| (-840)) (|has| |#2| (-788))) ((-790) -2198 (|has| |#2| (-840)) (|has| |#2| (-788))) ((-840) |has| |#2| (-840)) ((-842) -2198 (|has| |#2| (-840)) (|has| |#2| (-788))) ((-895 (-1161)) -12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047))) ((-1037 (-409 (-568))) -12 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090))) ((-1037 (-568)) -12 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090))) ((-1037 |#2|) |has| |#2| (-1090)) ((-1053 |#2|) -2198 (|has| |#2| (-1047)) (|has| |#2| (-365)) (|has| |#2| (-172))) ((-1053 $) |has| |#2| (-172)) ((-1047) -2198 (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-172))) ((-1054) -2198 (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-172))) ((-1102) -2198 (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-716)) (|has| |#2| (-172))) ((-1090) -2198 (|has| |#2| (-1090)) (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-788)) (|has| |#2| (-716)) (|has| |#2| (-370)) (|has| |#2| (-365)) (|has| |#2| (-172)) (|has| |#2| (-137)) (|has| |#2| (-25))) ((-1195) . T) ((-1251 |#2|) |has| |#2| (-365))) 
-((-2512 (((-232 |#1| |#3|) (-1 |#3| |#2| |#3|) (-232 |#1| |#2|) |#3|) 21)) (-3092 ((|#3| (-1 |#3| |#2| |#3|) (-232 |#1| |#2|) |#3|) 23)) (-2795 (((-232 |#1| |#3|) (-1 |#3| |#2|) (-232 |#1| |#2|)) 18))) 
-(((-231 |#1| |#2| |#3|) (-10 -7 (-15 -2512 ((-232 |#1| |#3|) (-1 |#3| |#2| |#3|) (-232 |#1| |#2|) |#3|)) (-15 -3092 (|#3| (-1 |#3| |#2| |#3|) (-232 |#1| |#2|) |#3|)) (-15 -2795 ((-232 |#1| |#3|) (-1 |#3| |#2|) (-232 |#1| |#2|)))) (-763) (-1195) (-1195)) (T -231)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-232 *5 *6)) (-14 *5 (-763)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-5 *2 (-232 *5 *7)) (-5 *1 (-231 *5 *6 *7)))) (-3092 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *6 *2)) (-5 *4 (-232 *5 *6)) (-14 *5 (-763)) (-4 *6 (-1195)) (-4 *2 (-1195)) (-5 *1 (-231 *5 *6 *2)))) (-2512 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *7 *5)) (-5 *4 (-232 *6 *7)) (-14 *6 (-763)) (-4 *7 (-1195)) (-4 *5 (-1195)) (-5 *2 (-232 *6 *5)) (-5 *1 (-231 *6 *7 *5))))) 
-(-10 -7 (-15 -2512 ((-232 |#1| |#3|) (-1 |#3| |#2| |#3|) (-232 |#1| |#2|) |#3|)) (-15 -3092 (|#3| (-1 |#3| |#2| |#3|) (-232 |#1| |#2|) |#3|)) (-15 -2795 ((-232 |#1| |#3|) (-1 |#3| |#2|) (-232 |#1| |#2|)))) 
-((-2447 (((-121) $ $) NIL (|has| |#2| (-1090)))) (-2537 (((-121) $) NIL (|has| |#2| (-137)))) (-1394 (($ (-917)) 56 (|has| |#2| (-1047)))) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-1462 (($ $ $) 60 (|has| |#2| (-788)))) (-3134 (((-3 $ "failed") $ $) 49 (|has| |#2| (-137)))) (-2510 (((-121) $ (-763)) 17)) (-3983 (((-763)) NIL (|has| |#2| (-370)))) (-3662 (((-568) $) NIL (|has| |#2| (-840)))) (-2436 ((|#2| $ (-568) |#2|) NIL (|has| $ (-6 -4520)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) NIL (-12 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090)))) (((-3 (-409 (-568)) "failed") $) NIL (-12 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) (((-3 |#2| "failed") $) 29 (|has| |#2| (-1090)))) (-2854 (((-568) $) NIL (-12 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090)))) (((-409 (-568)) $) NIL (-12 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) ((|#2| $) 27 (|has| |#2| (-1090)))) (-3164 (((-679 (-568)) (-679 $)) NIL (-12 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (-12 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047)))) (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL (|has| |#2| (-1047))) (((-679 |#2|) (-679 $)) NIL (|has| |#2| (-1047)))) (-2925 (((-3 $ "failed") $) 53 (|has| |#2| (-716)))) (-1731 (($) NIL (|has| |#2| (-370)))) (-3989 ((|#2| $ (-568) |#2|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#2| $ (-568)) 51)) (-2033 (((-121) $) NIL (|has| |#2| (-840)))) (-4360 (((-634 |#2|) $) 15 (|has| $ (-6 -4519)))) (-2735 (((-121) $) NIL (|has| |#2| (-716)))) (-2245 (((-121) $) NIL (|has| |#2| (-840)))) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) 20 (|has| (-568) (-842)))) (-2521 (($ $ $) NIL (-2198 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1979 (((-634 |#2|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-2223 (((-568) $) 50 (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (-2198 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-3674 (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#2| |#2|) $) 41)) (-3683 (((-917) $) NIL (|has| |#2| (-370)))) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (|has| |#2| (-1090)))) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4355 (($ (-917)) NIL (|has| |#2| (-370)))) (-4022 (((-1108) $) NIL (|has| |#2| (-1090)))) (-3876 ((|#2| $) NIL (|has| (-568) (-842)))) (-3724 (($ $ |#2|) NIL (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) |#2|) $) 24 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-2041 (((-634 |#2|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#2| $ (-568) |#2|) NIL) ((|#2| $ (-568)) 21)) (-3682 ((|#2| $ $) NIL (|has| |#2| (-1047)))) (-2039 (($ (-1244 |#2|)) 18)) (-4321 (((-139)) NIL (|has| |#2| (-365)))) (-4189 (($ $) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1 |#2| |#2|) (-763)) NIL (|has| |#2| (-1047))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1047)))) (-4168 (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-3863 (($ $) NIL)) (-2745 (((-1244 |#2|) $) 10) (((-850) $) NIL (|has| |#2| (-1090))) (($ (-568)) NIL (-2198 (-12 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090))) (|has| |#2| (-1047)))) (($ (-409 (-568))) NIL (-12 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) (($ |#2|) 13 (|has| |#2| (-1090)))) (-4078 (((-763)) NIL (|has| |#2| (-1047)))) (-1319 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-2897 (($ $) NIL (|has| |#2| (-840)))) (-1887 (($ $ (-763)) NIL (|has| |#2| (-716))) (($ $ (-917)) NIL (|has| |#2| (-716)))) (-3056 (($) 35 (|has| |#2| (-137)) CONST)) (-1556 (($) 38 (|has| |#2| (-716)) CONST)) (-3190 (($ $) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1 |#2| |#2|) (-763)) NIL (|has| |#2| (-1047))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1047)))) (-1751 (((-121) $ $) NIL (-2198 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1738 (((-121) $ $) NIL (-2198 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1717 (((-121) $ $) 26 (|has| |#2| (-1090)))) (-1745 (((-121) $ $) NIL (-2198 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1732 (((-121) $ $) 58 (-2198 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1779 (($ $ |#2|) NIL (|has| |#2| (-365)))) (-1773 (($ $ $) NIL (|has| |#2| (-1047))) (($ $) NIL (|has| |#2| (-1047)))) (-1767 (($ $ $) 33 (|has| |#2| (-25)))) (** (($ $ (-763)) NIL (|has| |#2| (-716))) (($ $ (-917)) NIL (|has| |#2| (-716)))) (* (($ (-568) $) NIL (|has| |#2| (-1047))) (($ $ $) 44 (|has| |#2| (-716))) (($ $ |#2|) 42 (|has| |#2| (-1047))) (($ |#2| $) 43 (|has| |#2| (-1047))) (($ (-763) $) NIL (|has| |#2| (-137))) (($ (-917) $) NIL (|has| |#2| (-25)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
+((-2041 (*1 *1 *2) (-12 (-5 *2 (-1244 *4)) (-4 *4 (-1195)) (-4 *1 (-230 *3 *4)))) (-4007 (*1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-230 *3 *4)) (-4 *4 (-1047)) (-4 *4 (-1195)))) (-2286 (*1 *2 *1 *1) (-12 (-4 *1 (-230 *3 *2)) (-4 *2 (-1195)) (-4 *2 (-1047))))) 
+(-13 (-601 (-568) |t#2|) (-608 (-1244 |t#2|)) (-10 -8 (-6 -4521) (-15 -2041 ($ (-1244 |t#2|))) (IF (|has| |t#2| (-1090)) (-6 (-413 |t#2|)) |noBranch|) (IF (|has| |t#2| (-1047)) (PROGN (-6 (-120 |t#2| |t#2|)) (-6 (-223 |t#2|)) (-6 (-379 |t#2|)) (-15 -4007 ($ (-917))) (-15 -2286 (|t#2| $ $))) |noBranch|) (IF (|has| |t#2| (-25)) (-6 (-25)) |noBranch|) (IF (|has| |t#2| (-137)) (-6 (-137)) |noBranch|) (IF (|has| |t#2| (-716)) (-6 (-716 (SEQ (|:| * (-1 $ |t#2| $)) (|exit| 1 (|:| * (-1 $ $ |t#2|)))))) |noBranch|) (IF (|has| |t#2| (-370)) (-6 (-370)) |noBranch|) (IF (|has| |t#2| (-172)) (PROGN (-6 (-43 |t#2|)) (-6 (-172))) |noBranch|) (IF (|has| |t#2| (-6 -4518)) (-6 -4518) |noBranch|) (IF (|has| |t#2| (-840)) (-6 (-840)) |noBranch|) (IF (|has| |t#2| (-788)) (-6 (-788)) |noBranch|) (IF (|has| |t#2| (-365)) (-6 (-1251 |t#2|)) |noBranch|))) 
+(((-21) -2199 (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-365)) (|has| |#2| (-172))) ((-23) -2199 (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-788)) (|has| |#2| (-365)) (|has| |#2| (-172)) (|has| |#2| (-137))) ((-25) -2199 (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-788)) (|has| |#2| (-365)) (|has| |#2| (-172)) (|has| |#2| (-137)) (|has| |#2| (-25))) ((-39) . T) ((-43 |#2|) |has| |#2| (-172)) ((-105) -2199 (|has| |#2| (-1090)) (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-788)) (|has| |#2| (-716)) (|has| |#2| (-370)) (|has| |#2| (-365)) (|has| |#2| (-172)) (|has| |#2| (-137)) (|has| |#2| (-25))) ((-120 |#2| |#2|) -2199 (|has| |#2| (-1047)) (|has| |#2| (-365)) (|has| |#2| (-172))) ((-120 $ $) |has| |#2| (-172)) ((-137) -2199 (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-788)) (|has| |#2| (-365)) (|has| |#2| (-172)) (|has| |#2| (-137))) ((-608 (-850)) -2199 (|has| |#2| (-1090)) (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-788)) (|has| |#2| (-716)) (|has| |#2| (-370)) (|has| |#2| (-365)) (|has| |#2| (-172)) (|has| |#2| (-137)) (|has| |#2| (-25))) ((-608 (-1244 |#2|)) . T) ((-172) |has| |#2| (-172)) ((-223 |#2|) |has| |#2| (-1047)) ((-225) -12 (|has| |#2| (-225)) (|has| |#2| (-1047))) ((-281 (-568) |#2|) . T) ((-283 (-568) |#2|) . T) ((-303 |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) ((-370) |has| |#2| (-370)) ((-379 |#2|) |has| |#2| (-1047)) ((-413 |#2|) |has| |#2| (-1090)) ((-499 |#2|) . T) ((-601 (-568) |#2|) . T) ((-523 |#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) ((-637 |#2|) -2199 (|has| |#2| (-1047)) (|has| |#2| (-365)) (|has| |#2| (-172))) ((-637 $) -2199 (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-172))) ((-630 (-568)) -12 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047))) ((-630 |#2|) |has| |#2| (-1047)) ((-707 |#2|) -2199 (|has| |#2| (-365)) (|has| |#2| (-172))) ((-716 (SEQ (|:| * (-1 $ |#2| $)) (|exit| 1 (|:| * (-1 $ $ |#2|))))) |has| |#2| (-716)) ((-716) -2199 (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-172))) ((-786) |has| |#2| (-840)) ((-787) -2199 (|has| |#2| (-840)) (|has| |#2| (-788))) ((-788) |has| |#2| (-788)) ((-789) -2199 (|has| |#2| (-840)) (|has| |#2| (-788))) ((-790) -2199 (|has| |#2| (-840)) (|has| |#2| (-788))) ((-840) |has| |#2| (-840)) ((-842) -2199 (|has| |#2| (-840)) (|has| |#2| (-788))) ((-895 (-1161)) -12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047))) ((-1037 (-409 (-568))) -12 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090))) ((-1037 (-568)) -12 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090))) ((-1037 |#2|) |has| |#2| (-1090)) ((-1053 |#2|) -2199 (|has| |#2| (-1047)) (|has| |#2| (-365)) (|has| |#2| (-172))) ((-1053 $) |has| |#2| (-172)) ((-1047) -2199 (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-172))) ((-1054) -2199 (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-172))) ((-1102) -2199 (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-716)) (|has| |#2| (-172))) ((-1090) -2199 (|has| |#2| (-1090)) (|has| |#2| (-1047)) (|has| |#2| (-840)) (|has| |#2| (-788)) (|has| |#2| (-716)) (|has| |#2| (-370)) (|has| |#2| (-365)) (|has| |#2| (-172)) (|has| |#2| (-137)) (|has| |#2| (-25))) ((-1195) . T) ((-1251 |#2|) |has| |#2| (-365))) 
+((-1678 (((-232 |#1| |#3|) (-1 |#3| |#2| |#3|) (-232 |#1| |#2|) |#3|) 21)) (-3094 ((|#3| (-1 |#3| |#2| |#3|) (-232 |#1| |#2|) |#3|) 23)) (-2797 (((-232 |#1| |#3|) (-1 |#3| |#2|) (-232 |#1| |#2|)) 18))) 
+(((-231 |#1| |#2| |#3|) (-10 -7 (-15 -1678 ((-232 |#1| |#3|) (-1 |#3| |#2| |#3|) (-232 |#1| |#2|) |#3|)) (-15 -3094 (|#3| (-1 |#3| |#2| |#3|) (-232 |#1| |#2|) |#3|)) (-15 -2797 ((-232 |#1| |#3|) (-1 |#3| |#2|) (-232 |#1| |#2|)))) (-763) (-1195) (-1195)) (T -231)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-232 *5 *6)) (-14 *5 (-763)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-5 *2 (-232 *5 *7)) (-5 *1 (-231 *5 *6 *7)))) (-3094 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *6 *2)) (-5 *4 (-232 *5 *6)) (-14 *5 (-763)) (-4 *6 (-1195)) (-4 *2 (-1195)) (-5 *1 (-231 *5 *6 *2)))) (-1678 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *7 *5)) (-5 *4 (-232 *6 *7)) (-14 *6 (-763)) (-4 *7 (-1195)) (-4 *5 (-1195)) (-5 *2 (-232 *6 *5)) (-5 *1 (-231 *6 *7 *5))))) 
+(-10 -7 (-15 -1678 ((-232 |#1| |#3|) (-1 |#3| |#2| |#3|) (-232 |#1| |#2|) |#3|)) (-15 -3094 (|#3| (-1 |#3| |#2| |#3|) (-232 |#1| |#2|) |#3|)) (-15 -2797 ((-232 |#1| |#3|) (-1 |#3| |#2|) (-232 |#1| |#2|)))) 
+((-2449 (((-121) $ $) NIL (|has| |#2| (-1090)))) (-1819 (((-121) $) NIL (|has| |#2| (-137)))) (-4007 (($ (-917)) 56 (|has| |#2| (-1047)))) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-2409 (($ $ $) 60 (|has| |#2| (-788)))) (-2689 (((-3 $ "failed") $ $) 49 (|has| |#2| (-137)))) (-1667 (((-121) $ (-763)) 17)) (-3986 (((-763)) NIL (|has| |#2| (-370)))) (-3337 (((-568) $) NIL (|has| |#2| (-840)))) (-2438 ((|#2| $ (-568) |#2|) NIL (|has| $ (-6 -4522)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) NIL (-12 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090)))) (((-3 (-409 (-568)) "failed") $) NIL (-12 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) (((-3 |#2| "failed") $) 29 (|has| |#2| (-1090)))) (-2857 (((-568) $) NIL (-12 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090)))) (((-409 (-568)) $) NIL (-12 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) ((|#2| $) 27 (|has| |#2| (-1090)))) (-1668 (((-679 (-568)) (-679 $)) NIL (-12 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (-12 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047)))) (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL (|has| |#2| (-1047))) (((-679 |#2|) (-679 $)) NIL (|has| |#2| (-1047)))) (-2902 (((-3 $ "failed") $) 53 (|has| |#2| (-716)))) (-1733 (($) NIL (|has| |#2| (-370)))) (-1292 ((|#2| $ (-568) |#2|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#2| $ (-568)) 51)) (-1436 (((-121) $) NIL (|has| |#2| (-840)))) (-3317 (((-634 |#2|) $) 15 (|has| $ (-6 -4521)))) (-1598 (((-121) $) NIL (|has| |#2| (-716)))) (-2859 (((-121) $) NIL (|has| |#2| (-840)))) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) 20 (|has| (-568) (-842)))) (-1732 (($ $ $) NIL (-2199 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-4406 (((-634 |#2|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-3631 (((-568) $) 50 (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (-2199 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-2253 (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#2| |#2|) $) 41)) (-2291 (((-917) $) NIL (|has| |#2| (-370)))) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (|has| |#2| (-1090)))) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4357 (($ (-917)) NIL (|has| |#2| (-370)))) (-4025 (((-1108) $) NIL (|has| |#2| (-1090)))) (-3877 ((|#2| $) NIL (|has| (-568) (-842)))) (-2490 (($ $ |#2|) NIL (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) |#2|) $) 24 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-1480 (((-634 |#2|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#2| $ (-568) |#2|) NIL) ((|#2| $ (-568)) 21)) (-2286 ((|#2| $ $) NIL (|has| |#2| (-1047)))) (-2041 (($ (-1244 |#2|)) 18)) (-3108 (((-139)) NIL (|has| |#2| (-365)))) (-4191 (($ $) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1 |#2| |#2|) (-763)) NIL (|has| |#2| (-1047))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1047)))) (-4170 (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-3865 (($ $) NIL)) (-2747 (((-1244 |#2|) $) 10) (((-850) $) NIL (|has| |#2| (-1090))) (($ (-568)) NIL (-2199 (-12 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090))) (|has| |#2| (-1047)))) (($ (-409 (-568))) NIL (-12 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) (($ |#2|) 13 (|has| |#2| (-1090)))) (-3425 (((-763)) NIL (|has| |#2| (-1047)))) (-3437 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-2811 (($ $) NIL (|has| |#2| (-840)))) (-1889 (($ $ (-763)) NIL (|has| |#2| (-716))) (($ $ (-917)) NIL (|has| |#2| (-716)))) (-3058 (($) 35 (|has| |#2| (-137)) CONST)) (-1557 (($) 38 (|has| |#2| (-716)) CONST)) (-3192 (($ $) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1 |#2| |#2|) (-763)) NIL (|has| |#2| (-1047))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1047)))) (-1753 (((-121) $ $) NIL (-2199 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1740 (((-121) $ $) NIL (-2199 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1719 (((-121) $ $) 26 (|has| |#2| (-1090)))) (-1747 (((-121) $ $) NIL (-2199 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1734 (((-121) $ $) 58 (-2199 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1781 (($ $ |#2|) NIL (|has| |#2| (-365)))) (-1775 (($ $ $) NIL (|has| |#2| (-1047))) (($ $) NIL (|has| |#2| (-1047)))) (-1769 (($ $ $) 33 (|has| |#2| (-25)))) (** (($ $ (-763)) NIL (|has| |#2| (-716))) (($ $ (-917)) NIL (|has| |#2| (-716)))) (* (($ (-568) $) NIL (|has| |#2| (-1047))) (($ $ $) 44 (|has| |#2| (-716))) (($ $ |#2|) 42 (|has| |#2| (-1047))) (($ |#2| $) 43 (|has| |#2| (-1047))) (($ (-763) $) NIL (|has| |#2| (-137))) (($ (-917) $) NIL (|has| |#2| (-25)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
 (((-232 |#1| |#2|) (-230 |#1| |#2|) (-763) (-1195)) (T -232)) 
 NIL 
 (-230 |#1| |#2|) 
-((-2447 (((-121) $ $) NIL)) (-2148 (($) 34 T CONST)) (-2537 (((-121) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-172)))) (-2227 (($ $) NIL (|has| |#1| (-172)))) (-1573 (((-121) $) 54 (|has| |#1| (-172)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-2925 (((-3 $ "failed") $) 55)) (-2735 (((-121) $) NIL)) (-4241 (((-121) $ (-917)) 71)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL (|has| |#1| (-172)))) (-2779 ((|#1| $ (-917)) 9)) (-2745 (((-850) $) 29) (($ (-568)) NIL) (($ (-1 |#1| (-917))) 12) (((-1 |#1| (-917)) $) 11) (($ (-1141 |#1|)) 26) (((-1141 |#1|) $) 24) (($ |#1|) NIL (|has| |#1| (-172))) (($ $) NIL (|has| |#1| (-172)))) (-4078 (((-763)) NIL)) (-1826 (((-121) $ $) NIL (|has| |#1| (-172)))) (-4292 (((-121) $ (-917)) 72)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 33 T CONST)) (-1556 (($) 13 T CONST)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) 38) (($ $ $) NIL)) (-1767 (($ $ $) 36)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 40) (($ $ $) 51) (($ |#1| $) 42 (|has| |#1| (-172))) (($ $ |#1|) NIL (|has| |#1| (-172))))) 
-(((-233 |#1|) (-13 (-1047) (-281 (-917) |#1|) (-10 -8 (IF (|has| |#1| (-172)) (-6 (-558)) |noBranch|) (IF (|has| |#1| (-172)) (-6 (-43 |#1|)) |noBranch|) (-15 -2745 ($ (-1 |#1| (-917)))) (-15 -2745 ((-1 |#1| (-917)) $)) (-15 -2745 ($ (-1141 |#1|))) (-15 -2745 ((-1141 |#1|) $)) (-15 -2148 ($) -3495) (-15 -4241 ((-121) $ (-917))) (-15 -4292 ((-121) $ (-917))))) (-1047)) (T -233)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1 *3 (-917))) (-4 *3 (-1047)) (-5 *1 (-233 *3)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-1 *3 (-917))) (-5 *1 (-233 *3)) (-4 *3 (-1047)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-233 *3)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-233 *3)) (-4 *3 (-1047)))) (-2148 (*1 *1) (-12 (-5 *1 (-233 *2)) (-4 *2 (-1047)))) (-4241 (*1 *2 *1 *3) (-12 (-5 *3 (-917)) (-5 *2 (-121)) (-5 *1 (-233 *4)) (-4 *4 (-1047)))) (-4292 (*1 *2 *1 *3) (-12 (-5 *3 (-917)) (-5 *2 (-121)) (-5 *1 (-233 *4)) (-4 *4 (-1047))))) 
-(-13 (-1047) (-281 (-917) |#1|) (-10 -8 (IF (|has| |#1| (-172)) (-6 (-558)) |noBranch|) (IF (|has| |#1| (-172)) (-6 (-43 |#1|)) |noBranch|) (-15 -2745 ($ (-1 |#1| (-917)))) (-15 -2745 ((-1 |#1| (-917)) $)) (-15 -2745 ($ (-1141 |#1|))) (-15 -2745 ((-1141 |#1|) $)) (-15 -2148 ($) -3495) (-15 -4241 ((-121) $ (-917))) (-15 -4292 ((-121) $ (-917))))) 
-((-4361 (((-568) (-634 (-1143))) 24) (((-568) (-1143)) 19)) (-4011 (((-1249) (-634 (-1143))) 29) (((-1249) (-1143)) 28)) (-1465 (((-1143)) 14)) (-2112 (((-1143) (-568) (-1143)) 16)) (-1374 (((-634 (-1143)) (-634 (-1143)) (-568) (-1143)) 25) (((-1143) (-1143) (-568) (-1143)) 23)) (-3474 (((-634 (-1143)) (-634 (-1143))) 13) (((-634 (-1143)) (-1143)) 11))) 
-(((-234) (-10 -7 (-15 -3474 ((-634 (-1143)) (-1143))) (-15 -3474 ((-634 (-1143)) (-634 (-1143)))) (-15 -1465 ((-1143))) (-15 -2112 ((-1143) (-568) (-1143))) (-15 -1374 ((-1143) (-1143) (-568) (-1143))) (-15 -1374 ((-634 (-1143)) (-634 (-1143)) (-568) (-1143))) (-15 -4011 ((-1249) (-1143))) (-15 -4011 ((-1249) (-634 (-1143)))) (-15 -4361 ((-568) (-1143))) (-15 -4361 ((-568) (-634 (-1143)))))) (T -234)) 
-((-4361 (*1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-568)) (-5 *1 (-234)))) (-4361 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-568)) (-5 *1 (-234)))) (-4011 (*1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-1249)) (-5 *1 (-234)))) (-4011 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-234)))) (-1374 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-634 (-1143))) (-5 *3 (-568)) (-5 *4 (-1143)) (-5 *1 (-234)))) (-1374 (*1 *2 *2 *3 *2) (-12 (-5 *2 (-1143)) (-5 *3 (-568)) (-5 *1 (-234)))) (-2112 (*1 *2 *3 *2) (-12 (-5 *2 (-1143)) (-5 *3 (-568)) (-5 *1 (-234)))) (-1465 (*1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-234)))) (-3474 (*1 *2 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-234)))) (-3474 (*1 *2 *3) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-234)) (-5 *3 (-1143))))) 
-(-10 -7 (-15 -3474 ((-634 (-1143)) (-1143))) (-15 -3474 ((-634 (-1143)) (-634 (-1143)))) (-15 -1465 ((-1143))) (-15 -2112 ((-1143) (-568) (-1143))) (-15 -1374 ((-1143) (-1143) (-568) (-1143))) (-15 -1374 ((-634 (-1143)) (-634 (-1143)) (-568) (-1143))) (-15 -4011 ((-1249) (-1143))) (-15 -4011 ((-1249) (-634 (-1143)))) (-15 -4361 ((-568) (-1143))) (-15 -4361 ((-568) (-634 (-1143))))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-2583 (((-634 (-2 (|:| |gen| |#1|) (|:| -1892 (-568)))) $) 44)) (-2533 (((-634 |#1|) $) 30)) (-2740 (((-634 |#1|) $) 29)) (-1917 (((-634 |#1|) $) 31)) (-3134 (((-3 $ "failed") $ $) 18)) (-3969 (((-634 $) $) 36)) (-3983 (((-763) $) 43)) (-2671 (($) 16 T CONST)) (-3666 (((-3 |#1| "failed") $) 39)) (-2854 ((|#1| $) 40)) (-2882 ((|#1| $ (-568)) 46)) (-1444 (((-568) $ (-568)) 45)) (-2096 (($ (-1 |#1| |#1|) $) 49)) (-2907 (($ (-1 (-568) (-568)) $) 48)) (-4487 (((-1143) $) 9)) (-2751 (($ $) 26)) (-1764 (($ $ $) 50 (|has| (-568) (-787)))) (-4022 (((-1108) $) 10)) (-2132 (((-121) $) 32)) (-4204 (($ $) 28)) (-1440 (($ $) 27)) (-3206 (((-568) $) 37)) (-2768 (($ $ $) 33)) (-3944 (($ $) 34)) (-2745 (((-850) $) 11) (($ |#1|) 38)) (-2604 (((-568) |#1| $) 47)) (-3056 (($) 17 T CONST)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 35)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13) (($ |#1| $) 41)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ (-568)) 52) (($ (-568) $) 51) (($ (-568) |#1|) 42))) 
+((-2449 (((-121) $ $) NIL)) (-3552 (($) 34 T CONST)) (-1819 (((-121) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-172)))) (-3661 (($ $) NIL (|has| |#1| (-172)))) (-4426 (((-121) $) 54 (|has| |#1| (-172)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-2902 (((-3 $ "failed") $) 55)) (-1598 (((-121) $) NIL)) (-2839 (((-121) $ (-917)) 71)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL (|has| |#1| (-172)))) (-2781 ((|#1| $ (-917)) 9)) (-2747 (((-850) $) 29) (($ (-568)) NIL) (($ (-1 |#1| (-917))) 12) (((-1 |#1| (-917)) $) 11) (($ (-1141 |#1|)) 26) (((-1141 |#1|) $) 24) (($ |#1|) NIL (|has| |#1| (-172))) (($ $) NIL (|has| |#1| (-172)))) (-3425 (((-763)) NIL)) (-2273 (((-121) $ $) NIL (|has| |#1| (-172)))) (-2998 (((-121) $ (-917)) 72)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 33 T CONST)) (-1557 (($) 13 T CONST)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) 38) (($ $ $) NIL)) (-1769 (($ $ $) 36)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 40) (($ $ $) 51) (($ |#1| $) 42 (|has| |#1| (-172))) (($ $ |#1|) NIL (|has| |#1| (-172))))) 
+(((-233 |#1|) (-13 (-1047) (-281 (-917) |#1|) (-10 -8 (IF (|has| |#1| (-172)) (-6 (-558)) |noBranch|) (IF (|has| |#1| (-172)) (-6 (-43 |#1|)) |noBranch|) (-15 -2747 ($ (-1 |#1| (-917)))) (-15 -2747 ((-1 |#1| (-917)) $)) (-15 -2747 ($ (-1141 |#1|))) (-15 -2747 ((-1141 |#1|) $)) (-15 -3552 ($) -3497) (-15 -2839 ((-121) $ (-917))) (-15 -2998 ((-121) $ (-917))))) (-1047)) (T -233)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1 *3 (-917))) (-4 *3 (-1047)) (-5 *1 (-233 *3)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-1 *3 (-917))) (-5 *1 (-233 *3)) (-4 *3 (-1047)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-233 *3)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-233 *3)) (-4 *3 (-1047)))) (-3552 (*1 *1) (-12 (-5 *1 (-233 *2)) (-4 *2 (-1047)))) (-2839 (*1 *2 *1 *3) (-12 (-5 *3 (-917)) (-5 *2 (-121)) (-5 *1 (-233 *4)) (-4 *4 (-1047)))) (-2998 (*1 *2 *1 *3) (-12 (-5 *3 (-917)) (-5 *2 (-121)) (-5 *1 (-233 *4)) (-4 *4 (-1047))))) 
+(-13 (-1047) (-281 (-917) |#1|) (-10 -8 (IF (|has| |#1| (-172)) (-6 (-558)) |noBranch|) (IF (|has| |#1| (-172)) (-6 (-43 |#1|)) |noBranch|) (-15 -2747 ($ (-1 |#1| (-917)))) (-15 -2747 ((-1 |#1| (-917)) $)) (-15 -2747 ($ (-1141 |#1|))) (-15 -2747 ((-1141 |#1|) $)) (-15 -3552 ($) -3497) (-15 -2839 ((-121) $ (-917))) (-15 -2998 ((-121) $ (-917))))) 
+((-3322 (((-568) (-634 (-1143))) 24) (((-568) (-1143)) 19)) (-4013 (((-1249) (-634 (-1143))) 29) (((-1249) (-1143)) 28)) (-2427 (((-1143)) 14)) (-3280 (((-1143) (-568) (-1143)) 16)) (-1374 (((-634 (-1143)) (-634 (-1143)) (-568) (-1143)) 25) (((-1143) (-1143) (-568) (-1143)) 23)) (-3476 (((-634 (-1143)) (-634 (-1143))) 13) (((-634 (-1143)) (-1143)) 11))) 
+(((-234) (-10 -7 (-15 -3476 ((-634 (-1143)) (-1143))) (-15 -3476 ((-634 (-1143)) (-634 (-1143)))) (-15 -2427 ((-1143))) (-15 -3280 ((-1143) (-568) (-1143))) (-15 -1374 ((-1143) (-1143) (-568) (-1143))) (-15 -1374 ((-634 (-1143)) (-634 (-1143)) (-568) (-1143))) (-15 -4013 ((-1249) (-1143))) (-15 -4013 ((-1249) (-634 (-1143)))) (-15 -3322 ((-568) (-1143))) (-15 -3322 ((-568) (-634 (-1143)))))) (T -234)) 
+((-3322 (*1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-568)) (-5 *1 (-234)))) (-3322 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-568)) (-5 *1 (-234)))) (-4013 (*1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-1249)) (-5 *1 (-234)))) (-4013 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-234)))) (-1374 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-634 (-1143))) (-5 *3 (-568)) (-5 *4 (-1143)) (-5 *1 (-234)))) (-1374 (*1 *2 *2 *3 *2) (-12 (-5 *2 (-1143)) (-5 *3 (-568)) (-5 *1 (-234)))) (-3280 (*1 *2 *3 *2) (-12 (-5 *2 (-1143)) (-5 *3 (-568)) (-5 *1 (-234)))) (-2427 (*1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-234)))) (-3476 (*1 *2 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-234)))) (-3476 (*1 *2 *3) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-234)) (-5 *3 (-1143))))) 
+(-10 -7 (-15 -3476 ((-634 (-1143)) (-1143))) (-15 -3476 ((-634 (-1143)) (-634 (-1143)))) (-15 -2427 ((-1143))) (-15 -3280 ((-1143) (-568) (-1143))) (-15 -1374 ((-1143) (-1143) (-568) (-1143))) (-15 -1374 ((-634 (-1143)) (-634 (-1143)) (-568) (-1143))) (-15 -4013 ((-1249) (-1143))) (-15 -4013 ((-1249) (-634 (-1143)))) (-15 -3322 ((-568) (-1143))) (-15 -3322 ((-568) (-634 (-1143))))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2013 (((-634 (-2 (|:| |gen| |#1|) (|:| -1894 (-568)))) $) 44)) (-1800 (((-634 |#1|) $) 30)) (-3328 (((-634 |#1|) $) 29)) (-2700 (((-634 |#1|) $) 31)) (-2689 (((-3 $ "failed") $ $) 18)) (-4446 (((-634 $) $) 36)) (-3986 (((-763) $) 43)) (-4490 (($) 16 T CONST)) (-3668 (((-3 |#1| "failed") $) 39)) (-2857 ((|#1| $) 40)) (-4167 ((|#1| $ (-568)) 46)) (-2313 (((-568) $ (-568)) 45)) (-3177 (($ (-1 |#1| |#1|) $) 49)) (-2847 (($ (-1 (-568) (-568)) $) 48)) (-1893 (((-1143) $) 9)) (-2753 (($ $) 26)) (-3933 (($ $ $) 50 (|has| (-568) (-787)))) (-4025 (((-1108) $) 10)) (-3435 (((-121) $) 32)) (-4105 (($ $) 28)) (-2292 (($ $) 27)) (-1836 (((-568) $) 37)) (-2770 (($ $ $) 33)) (-4332 (($ $) 34)) (-2747 (((-850) $) 11) (($ |#1|) 38)) (-2079 (((-568) |#1| $) 47)) (-3058 (($) 17 T CONST)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 35)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13) (($ |#1| $) 41)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ (-568)) 52) (($ (-568) $) 51) (($ (-568) |#1|) 42))) 
 (((-235 |#1|) (-1275) (-1090)) (T -235)) 
-((-3206 (*1 *2 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-568)))) (-3969 (*1 *2 *1) (-12 (-4 *3 (-1090)) (-5 *2 (-634 *1)) (-4 *1 (-235 *3)))) (-1745 (*1 *2 *1 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-121)))) (-3944 (*1 *1 *1) (-12 (-4 *1 (-235 *2)) (-4 *2 (-1090)))) (-2768 (*1 *1 *1 *1) (-12 (-4 *1 (-235 *2)) (-4 *2 (-1090)))) (-2132 (*1 *2 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-121)))) (-1917 (*1 *2 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-634 *3)))) (-2533 (*1 *2 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-634 *3)))) (-2740 (*1 *2 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-634 *3)))) (-4204 (*1 *1 *1) (-12 (-4 *1 (-235 *2)) (-4 *2 (-1090)))) (-1440 (*1 *1 *1) (-12 (-4 *1 (-235 *2)) (-4 *2 (-1090)))) (-2751 (*1 *1 *1) (-12 (-4 *1 (-235 *2)) (-4 *2 (-1090))))) 
-(-13 (-21) (-707 (-568)) (-320 |t#1| (-568)) (-10 -8 (-15 -3206 ((-568) $)) (-15 -3969 ((-634 $) $)) (-15 -1745 ((-121) $ $)) (-15 -3944 ($ $)) (-15 -2768 ($ $ $)) (-15 -2132 ((-121) $)) (-15 -1917 ((-634 |t#1|) $)) (-15 -2533 ((-634 |t#1|) $)) (-15 -2740 ((-634 |t#1|) $)) (-15 -4204 ($ $)) (-15 -1440 ($ $)) (-15 -2751 ($ $)))) 
+((-1836 (*1 *2 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-568)))) (-4446 (*1 *2 *1) (-12 (-4 *3 (-1090)) (-5 *2 (-634 *1)) (-4 *1 (-235 *3)))) (-1747 (*1 *2 *1 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-121)))) (-4332 (*1 *1 *1) (-12 (-4 *1 (-235 *2)) (-4 *2 (-1090)))) (-2770 (*1 *1 *1 *1) (-12 (-4 *1 (-235 *2)) (-4 *2 (-1090)))) (-3435 (*1 *2 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-121)))) (-2700 (*1 *2 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-634 *3)))) (-1800 (*1 *2 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-634 *3)))) (-3328 (*1 *2 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-634 *3)))) (-4105 (*1 *1 *1) (-12 (-4 *1 (-235 *2)) (-4 *2 (-1090)))) (-2292 (*1 *1 *1) (-12 (-4 *1 (-235 *2)) (-4 *2 (-1090)))) (-2753 (*1 *1 *1) (-12 (-4 *1 (-235 *2)) (-4 *2 (-1090))))) 
+(-13 (-21) (-707 (-568)) (-320 |t#1| (-568)) (-10 -8 (-15 -1836 ((-568) $)) (-15 -4446 ((-634 $) $)) (-15 -1747 ((-121) $ $)) (-15 -4332 ($ $)) (-15 -2770 ($ $ $)) (-15 -3435 ((-121) $)) (-15 -2700 ((-634 |t#1|) $)) (-15 -1800 ((-634 |t#1|) $)) (-15 -3328 ((-634 |t#1|) $)) (-15 -4105 ($ $)) (-15 -2292 ($ $)) (-15 -2753 ($ $)))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 (-568) (-568)) . T) ((-137) . T) ((-608 (-850)) . T) ((-320 |#1| (-568)) . T) ((-637 (-568)) . T) ((-707 (-568)) . T) ((-1037 |#1|) . T) ((-1053 (-568)) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 17)) (-2583 (((-634 (-2 (|:| |gen| |#1|) (|:| -1892 (-568)))) $) 30)) (-2533 (((-634 |#1|) $) 36)) (-2740 (((-634 |#1|) $) 37)) (-1917 (((-634 |#1|) $) 35)) (-3134 (((-3 $ "failed") $ $) NIL)) (-3969 (((-634 $) $) 29)) (-3983 (((-763) $) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) NIL)) (-2854 ((|#1| $) NIL)) (-2114 (($ $) 24)) (-2882 ((|#1| $ (-568)) NIL)) (-1444 (((-568) $ (-568)) NIL)) (-2096 (($ (-1 |#1| |#1|) $) NIL)) (-2907 (($ (-1 (-568) (-568)) $) NIL)) (-4487 (((-1143) $) NIL)) (-2751 (($ $) 8)) (-1764 (($ $ $) NIL (|has| (-568) (-787)))) (-1733 (((-2 (|:| |gen| |#1|) (|:| -1892 (-568))) $) 26)) (-4022 (((-1108) $) NIL)) (-2132 (((-121) $) 50)) (-4204 (($ $) 38)) (-1440 (($ $) 39)) (-3206 (((-568) $) 58)) (-2768 (($ $ $) 44)) (-3944 (($ $) 33)) (-2745 (((-850) $) 22) (($ |#1|) 27)) (-2604 (((-568) |#1| $) 32)) (-3056 (($) 23 T CONST)) (-1717 (((-121) $ $) 40)) (-1745 (((-121) $ $) 51)) (-1773 (($ $) 48) (($ $ $) 47)) (-1767 (($ $ $) 45) (($ |#1| $) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 49) (($ $ (-568)) NIL) (($ (-568) $) 49) (($ (-568) |#1|) NIL))) 
-(((-236 |#1|) (-13 (-235 |#1|) (-10 -8 (-15 -1733 ((-2 (|:| |gen| |#1|) (|:| -1892 (-568))) $)) (-15 -2114 ($ $)))) (-1088)) (T -236)) 
-((-1733 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |gen| *3) (|:| -1892 (-568)))) (-5 *1 (-236 *3)) (-4 *3 (-1088)))) (-2114 (*1 *1 *1) (-12 (-5 *1 (-236 *2)) (-4 *2 (-1088))))) 
-(-13 (-235 |#1|) (-10 -8 (-15 -1733 ((-2 (|:| |gen| |#1|) (|:| -1892 (-568))) $)) (-15 -2114 ($ $)))) 
-((-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) 9)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) 18)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ (-409 (-568)) $) 25) (($ $ (-409 (-568))) NIL))) 
-(((-237 |#1|) (-10 -8 (-15 -1887 (|#1| |#1| (-568))) (-15 ** (|#1| |#1| (-568))) (-15 * (|#1| |#1| (-409 (-568)))) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 ** (|#1| |#1| (-763))) (-15 -1887 (|#1| |#1| (-763))) (-15 * (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| (-917))) (-15 -1887 (|#1| |#1| (-917))) (-15 * (|#1| (-568) |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|))) (-238)) (T -237)) 
-NIL 
-(-10 -8 (-15 -1887 (|#1| |#1| (-568))) (-15 ** (|#1| |#1| (-568))) (-15 * (|#1| |#1| (-409 (-568)))) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 ** (|#1| |#1| (-763))) (-15 -1887 (|#1| |#1| (-763))) (-15 * (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| (-917))) (-15 -1887 (|#1| |#1| (-917))) (-15 * (|#1| (-568) |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-2925 (((-3 $ "failed") $) 33)) (-2735 (((-121) $) 30)) (-4487 (((-1143) $) 9)) (-2081 (($ $) 38)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ (-409 (-568))) 43)) (-4078 (((-763)) 28)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 39)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 40)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ (-409 (-568)) $) 42) (($ $ (-409 (-568))) 41))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 17)) (-2013 (((-634 (-2 (|:| |gen| |#1|) (|:| -1894 (-568)))) $) 30)) (-1800 (((-634 |#1|) $) 36)) (-3328 (((-634 |#1|) $) 37)) (-2700 (((-634 |#1|) $) 35)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4446 (((-634 $) $) 29)) (-3986 (((-763) $) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) NIL)) (-2857 ((|#1| $) NIL)) (-2116 (($ $) 24)) (-4167 ((|#1| $ (-568)) NIL)) (-2313 (((-568) $ (-568)) NIL)) (-3177 (($ (-1 |#1| |#1|) $) NIL)) (-2847 (($ (-1 (-568) (-568)) $) NIL)) (-1893 (((-1143) $) NIL)) (-2753 (($ $) 8)) (-3933 (($ $ $) NIL (|has| (-568) (-787)))) (-3763 (((-2 (|:| |gen| |#1|) (|:| -1894 (-568))) $) 26)) (-4025 (((-1108) $) NIL)) (-3435 (((-121) $) 50)) (-4105 (($ $) 38)) (-2292 (($ $) 39)) (-1836 (((-568) $) 58)) (-2770 (($ $ $) 44)) (-4332 (($ $) 33)) (-2747 (((-850) $) 22) (($ |#1|) 27)) (-2079 (((-568) |#1| $) 32)) (-3058 (($) 23 T CONST)) (-1719 (((-121) $ $) 40)) (-1747 (((-121) $ $) 51)) (-1775 (($ $) 48) (($ $ $) 47)) (-1769 (($ $ $) 45) (($ |#1| $) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 49) (($ $ (-568)) NIL) (($ (-568) $) 49) (($ (-568) |#1|) NIL))) 
+(((-236 |#1|) (-13 (-235 |#1|) (-10 -8 (-15 -3763 ((-2 (|:| |gen| |#1|) (|:| -1894 (-568))) $)) (-15 -2116 ($ $)))) (-1088)) (T -236)) 
+((-3763 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |gen| *3) (|:| -1894 (-568)))) (-5 *1 (-236 *3)) (-4 *3 (-1088)))) (-2116 (*1 *1 *1) (-12 (-5 *1 (-236 *2)) (-4 *2 (-1088))))) 
+(-13 (-235 |#1|) (-10 -8 (-15 -3763 ((-2 (|:| |gen| |#1|) (|:| -1894 (-568))) $)) (-15 -2116 ($ $)))) 
+((-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) 9)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) 18)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ (-409 (-568)) $) 25) (($ $ (-409 (-568))) NIL))) 
+(((-237 |#1|) (-10 -8 (-15 -1889 (|#1| |#1| (-568))) (-15 ** (|#1| |#1| (-568))) (-15 * (|#1| |#1| (-409 (-568)))) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 ** (|#1| |#1| (-763))) (-15 -1889 (|#1| |#1| (-763))) (-15 * (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| (-917))) (-15 -1889 (|#1| |#1| (-917))) (-15 * (|#1| (-568) |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|))) (-238)) (T -237)) 
+NIL 
+(-10 -8 (-15 -1889 (|#1| |#1| (-568))) (-15 ** (|#1| |#1| (-568))) (-15 * (|#1| |#1| (-409 (-568)))) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 ** (|#1| |#1| (-763))) (-15 -1889 (|#1| |#1| (-763))) (-15 * (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| (-917))) (-15 -1889 (|#1| |#1| (-917))) (-15 * (|#1| (-568) |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-2902 (((-3 $ "failed") $) 33)) (-1598 (((-121) $) 30)) (-1893 (((-1143) $) 9)) (-2083 (($ $) 38)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ (-409 (-568))) 43)) (-3425 (((-763)) 28)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 39)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 40)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ (-409 (-568)) $) 42) (($ $ (-409 (-568))) 41))) 
 (((-238) (-1275)) (T -238)) 
-((** (*1 *1 *1 *2) (-12 (-4 *1 (-238)) (-5 *2 (-568)))) (-1887 (*1 *1 *1 *2) (-12 (-4 *1 (-238)) (-5 *2 (-568)))) (-2081 (*1 *1 *1) (-4 *1 (-238)))) 
-(-13 (-285) (-43 (-409 (-568))) (-10 -8 (-15 ** ($ $ (-568))) (-15 -1887 ($ $ (-568))) (-15 -2081 ($ $)))) 
+((** (*1 *1 *1 *2) (-12 (-4 *1 (-238)) (-5 *2 (-568)))) (-1889 (*1 *1 *1 *2) (-12 (-4 *1 (-238)) (-5 *2 (-568)))) (-2083 (*1 *1 *1) (-4 *1 (-238)))) 
+(-13 (-285) (-43 (-409 (-568))) (-10 -8 (-15 ** ($ $ (-568))) (-15 -1889 ($ $ (-568))) (-15 -2083 ($ $)))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 $ $) . T) ((-137) . T) ((-608 (-850)) . T) ((-285) . T) ((-637 (-409 (-568))) . T) ((-637 $) . T) ((-707 (-409 (-568))) . T) ((-716) . T) ((-1053 (-409 (-568))) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2850 ((|#1| $) 45)) (-2796 (($ $) 54)) (-2510 (((-121) $ (-763)) 8)) (-1659 ((|#1| $ |#1|) 36 (|has| $ (-6 -4520)))) (-3139 (($ $ $) 50 (|has| $ (-6 -4520)))) (-3519 (($ $ $) 49 (|has| $ (-6 -4520)))) (-2436 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) 38 (|has| $ (-6 -4520)))) (-2671 (($) 7 T CONST)) (-3773 (($ $) 53)) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-2287 (((-634 $) $) 47)) (-1700 (((-121) $ $) 39 (|has| |#1| (-1090)))) (-3650 (($ $) 52)) (-1737 (((-121) $ (-763)) 9)) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35)) (-2166 (((-121) $ (-763)) 10)) (-2869 (((-634 |#1|) $) 42)) (-1651 (((-121) $) 46)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4162 ((|#1| $) 56)) (-1733 (($ $) 55)) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 ((|#1| $ "value") 44)) (-4075 (((-568) $ $) 41)) (-3790 (((-121) $) 43)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-3845 (($ $ $) 51 (|has| $ (-6 -4520)))) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-4339 (((-634 $) $) 48)) (-3491 (((-121) $ $) 40 (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2852 ((|#1| $) 45)) (-3623 (($ $) 54)) (-1667 (((-121) $ (-763)) 8)) (-3370 ((|#1| $ |#1|) 36 (|has| $ (-6 -4522)))) (-2711 (($ $ $) 50 (|has| $ (-6 -4522)))) (-4052 (($ $ $) 49 (|has| $ (-6 -4522)))) (-2438 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) 38 (|has| $ (-6 -4522)))) (-4490 (($) 7 T CONST)) (-2703 (($ $) 53)) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-3534 (((-634 $) $) 47)) (-3606 (((-121) $ $) 39 (|has| |#1| (-1090)))) (-3652 (($ $) 52)) (-3791 (((-121) $ (-763)) 9)) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35)) (-3796 (((-121) $ (-763)) 10)) (-4081 (((-634 |#1|) $) 42)) (-3319 (((-121) $) 46)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4164 ((|#1| $) 56)) (-3763 (($ $) 55)) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 ((|#1| $ "value") 44)) (-1665 (((-568) $ $) 41)) (-2763 (((-121) $) 43)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-1876 (($ $ $) 51 (|has| $ (-6 -4522)))) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-3180 (((-634 $) $) 48)) (-3873 (((-121) $ $) 40 (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-239 |#1|) (-1275) (-1195)) (T -239)) 
-((-4162 (*1 *2 *1) (-12 (-4 *1 (-239 *2)) (-4 *2 (-1195)))) (-1733 (*1 *1 *1) (-12 (-4 *1 (-239 *2)) (-4 *2 (-1195)))) (-2796 (*1 *1 *1) (-12 (-4 *1 (-239 *2)) (-4 *2 (-1195)))) (-3773 (*1 *1 *1) (-12 (-4 *1 (-239 *2)) (-4 *2 (-1195)))) (-3650 (*1 *1 *1) (-12 (-4 *1 (-239 *2)) (-4 *2 (-1195)))) (-3845 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-239 *2)) (-4 *2 (-1195)))) (-3139 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-239 *2)) (-4 *2 (-1195)))) (-3519 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-239 *2)) (-4 *2 (-1195))))) 
-(-13 (-1010 |t#1|) (-10 -8 (-15 -4162 (|t#1| $)) (-15 -1733 ($ $)) (-15 -2796 ($ $)) (-15 -3773 ($ $)) (-15 -3650 ($ $)) (IF (|has| $ (-6 -4520)) (PROGN (-15 -3845 ($ $ $)) (-15 -3139 ($ $ $)) (-15 -3519 ($ $ $))) |noBranch|))) 
+((-4164 (*1 *2 *1) (-12 (-4 *1 (-239 *2)) (-4 *2 (-1195)))) (-3763 (*1 *1 *1) (-12 (-4 *1 (-239 *2)) (-4 *2 (-1195)))) (-3623 (*1 *1 *1) (-12 (-4 *1 (-239 *2)) (-4 *2 (-1195)))) (-2703 (*1 *1 *1) (-12 (-4 *1 (-239 *2)) (-4 *2 (-1195)))) (-3652 (*1 *1 *1) (-12 (-4 *1 (-239 *2)) (-4 *2 (-1195)))) (-1876 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-239 *2)) (-4 *2 (-1195)))) (-2711 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-239 *2)) (-4 *2 (-1195)))) (-4052 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-239 *2)) (-4 *2 (-1195))))) 
+(-13 (-1010 |t#1|) (-10 -8 (-15 -4164 (|t#1| $)) (-15 -3763 ($ $)) (-15 -3623 ($ $)) (-15 -2703 ($ $)) (-15 -3652 ($ $)) (IF (|has| $ (-6 -4522)) (PROGN (-15 -1876 ($ $ $)) (-15 -2711 ($ $ $)) (-15 -4052 ($ $ $))) |noBranch|))) 
 (((-39) . T) ((-105) |has| |#1| (-1090)) ((-608 (-850)) |has| |#1| (-1090)) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-1010 |#1|) . T) ((-1090) |has| |#1| (-1090)) ((-1195) . T)) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2850 ((|#1| $) NIL)) (-2235 ((|#1| $) NIL)) (-2796 (($ $) NIL)) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-3910 (($ $ (-568)) NIL (|has| $ (-6 -4520)))) (-2016 (((-121) $) NIL (|has| |#1| (-842))) (((-121) (-1 (-121) |#1| |#1|) $) NIL)) (-3908 (($ $) NIL (-12 (|has| $ (-6 -4520)) (|has| |#1| (-842)))) (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-3644 (($ $) 10 (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-1659 ((|#1| $ |#1|) NIL (|has| $ (-6 -4520)))) (-3869 (($ $ $) NIL (|has| $ (-6 -4520)))) (-2395 ((|#1| $ |#1|) NIL (|has| $ (-6 -4520)))) (-2517 ((|#1| $ |#1|) NIL (|has| $ (-6 -4520)))) (-2436 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4520))) ((|#1| $ "first" |#1|) NIL (|has| $ (-6 -4520))) (($ $ "rest" $) NIL (|has| $ (-6 -4520))) ((|#1| $ "last" |#1|) NIL (|has| $ (-6 -4520))) ((|#1| $ (-1210 (-568)) |#1|) NIL (|has| $ (-6 -4520))) ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) NIL (|has| $ (-6 -4520)))) (-3507 (($ (-1 (-121) |#1|) $) NIL)) (-2801 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1679 ((|#1| $) NIL)) (-2671 (($) NIL T CONST)) (-1578 (($ $) NIL (|has| $ (-6 -4520)))) (-3943 (($ $) NIL)) (-3935 (($ $) NIL) (($ $ (-763)) NIL)) (-3369 (($ $) NIL (|has| |#1| (-1090)))) (-3924 (($ $) 7 (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3405 (($ |#1| $) NIL (|has| |#1| (-1090))) (($ (-1 (-121) |#1|) $) NIL)) (-4328 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (($ |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3989 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-568)) NIL)) (-1601 (((-121) $) NIL)) (-2764 (((-568) |#1| $ (-568)) NIL (|has| |#1| (-1090))) (((-568) |#1| $) NIL (|has| |#1| (-1090))) (((-568) (-1 (-121) |#1|) $) NIL)) (-4360 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-2287 (((-634 $) $) NIL)) (-1700 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1849 (($ (-763) |#1|) NIL)) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) NIL (|has| (-568) (-842)))) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-3349 (($ $ $) NIL (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $ $) NIL)) (-1347 (($ $ $) NIL (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $ $) NIL)) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2223 (((-568) $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-3674 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-3896 (($ |#1|) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-2869 (((-634 |#1|) $) NIL)) (-1651 (((-121) $) NIL)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4162 ((|#1| $) NIL) (($ $ (-763)) NIL)) (-4450 (($ $ $ (-568)) NIL) (($ |#1| $ (-568)) NIL)) (-4122 (($ $ $ (-568)) NIL) (($ |#1| $ (-568)) NIL)) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3876 ((|#1| $) NIL) (($ $ (-763)) NIL)) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3724 (($ $ |#1|) NIL (|has| $ (-6 -4520)))) (-1786 (((-121) $) NIL)) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#1| $ "value") NIL) ((|#1| $ "first") NIL) (($ $ "rest") NIL) ((|#1| $ "last") NIL) (($ $ (-1210 (-568))) NIL) ((|#1| $ (-568)) NIL) ((|#1| $ (-568) |#1|) NIL) (($ $ "unique") 9) (($ $ "sort") 12) (((-763) $ "count") 16)) (-4075 (((-568) $ $) NIL)) (-1783 (($ $ (-1210 (-568))) NIL) (($ $ (-568)) NIL)) (-2826 (($ $ (-1210 (-568))) NIL) (($ $ (-568)) NIL)) (-1403 (($ (-634 |#1|)) 22)) (-3790 (((-121) $) NIL)) (-2340 (($ $) NIL)) (-2714 (($ $) NIL (|has| $ (-6 -4520)))) (-2775 (((-763) $) NIL)) (-3335 (($ $) NIL)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2256 (($ $ $ (-568)) NIL (|has| $ (-6 -4520)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) NIL)) (-3845 (($ $ $) NIL) (($ $ |#1|) NIL)) (-2768 (($ $ $) NIL) (($ |#1| $) NIL) (($ (-634 $)) NIL) (($ $ |#1|) NIL)) (-2745 (($ (-634 |#1|)) 17) (((-634 |#1|) $) 18) (((-850) $) 21 (|has| |#1| (-1090)))) (-4339 (((-634 $) $) NIL)) (-3491 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1697 (((-763) $) 14 (|has| $ (-6 -4519))))) 
-(((-240 |#1|) (-13 (-658 |#1|) (-10 -8 (-15 -2745 ($ (-634 |#1|))) (-15 -2745 ((-634 |#1|) $)) (-15 -1403 ($ (-634 |#1|))) (-15 -2779 ($ $ "unique")) (-15 -2779 ($ $ "sort")) (-15 -2779 ((-763) $ "count")))) (-842)) (T -240)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-240 *3)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-240 *3)) (-4 *3 (-842)))) (-1403 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-240 *3)))) (-2779 (*1 *1 *1 *2) (-12 (-5 *2 "unique") (-5 *1 (-240 *3)) (-4 *3 (-842)))) (-2779 (*1 *1 *1 *2) (-12 (-5 *2 "sort") (-5 *1 (-240 *3)) (-4 *3 (-842)))) (-2779 (*1 *2 *1 *3) (-12 (-5 *3 "count") (-5 *2 (-763)) (-5 *1 (-240 *4)) (-4 *4 (-842))))) 
-(-13 (-658 |#1|) (-10 -8 (-15 -2745 ($ (-634 |#1|))) (-15 -2745 ((-634 |#1|) $)) (-15 -1403 ($ (-634 |#1|))) (-15 -2779 ($ $ "unique")) (-15 -2779 ($ $ "sort")) (-15 -2779 ((-763) $ "count")))) 
-((-2200 (((-3 (-763) "failed") |#1| |#1| (-763)) 26))) 
-(((-241 |#1|) (-10 -7 (-15 -2200 ((-3 (-763) "failed") |#1| |#1| (-763)))) (-13 (-716) (-370) (-10 -7 (-15 ** (|#1| |#1| (-568)))))) (T -241)) 
-((-2200 (*1 *2 *3 *3 *2) (|partial| -12 (-5 *2 (-763)) (-4 *3 (-13 (-716) (-370) (-10 -7 (-15 ** (*3 *3 (-568)))))) (-5 *1 (-241 *3))))) 
-(-10 -7 (-15 -2200 ((-3 (-763) "failed") |#1| |#1| (-763)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2055 (((-634 (-852 |#1|)) $) NIL)) (-3839 (((-1157 $) $ (-852 |#1|)) NIL) (((-1157 |#2|) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#2| (-558)))) (-2227 (($ $) NIL (|has| |#2| (-558)))) (-1573 (((-121) $) NIL (|has| |#2| (-558)))) (-2773 (((-763) $) NIL) (((-763) $ (-634 (-852 |#1|))) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-4305 (($ $) NIL (|has| |#2| (-453)))) (-1678 (((-420 $) $) NIL (|has| |#2| (-453)))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#2| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#2| (-1037 (-568)))) (((-3 (-852 |#1|) "failed") $) NIL)) (-2854 ((|#2| $) NIL) (((-409 (-568)) $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#2| (-1037 (-568)))) (((-852 |#1|) $) NIL)) (-4265 (($ $ $ (-852 |#1|)) NIL (|has| |#2| (-172)))) (-4425 (($ $ (-634 (-568))) NIL)) (-2114 (($ $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL) (((-679 |#2|) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3250 (($ $) NIL (|has| |#2| (-453))) (($ $ (-852 |#1|)) NIL (|has| |#2| (-453)))) (-2108 (((-634 $) $) NIL)) (-3927 (((-121) $) NIL (|has| |#2| (-904)))) (-3088 (($ $ |#2| (-232 (-1697 |#1|) (-763)) $) NIL)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-852 |#1|) (-881 (-381))) (|has| |#2| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-852 |#1|) (-881 (-568))) (|has| |#2| (-881 (-568)))))) (-2735 (((-121) $) NIL)) (-4178 (((-763) $) NIL)) (-2051 (($ (-1157 |#2|) (-852 |#1|)) NIL) (($ (-1157 $) (-852 |#1|)) NIL)) (-2976 (((-634 $) $) NIL)) (-3921 (((-121) $) NIL)) (-2047 (($ |#2| (-232 (-1697 |#1|) (-763))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-3379 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $ (-852 |#1|)) NIL)) (-2144 (((-232 (-1697 |#1|) (-763)) $) NIL) (((-763) $ (-852 |#1|)) NIL) (((-634 (-763)) $ (-634 (-852 |#1|))) NIL)) (-2521 (($ $ $) NIL (|has| |#2| (-842)))) (-3268 (($ $ $) NIL (|has| |#2| (-842)))) (-3842 (($ (-1 (-232 (-1697 |#1|) (-763)) (-232 (-1697 |#1|) (-763))) $) NIL)) (-2795 (($ (-1 |#2| |#2|) $) NIL)) (-2244 (((-3 (-852 |#1|) "failed") $) NIL)) (-2097 (($ $) NIL)) (-2102 ((|#2| $) NIL)) (-2495 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) NIL (|has| |#2| (-453)))) (-4487 (((-1143) $) NIL)) (-3324 (((-3 (-634 $) "failed") $) NIL)) (-1794 (((-3 (-634 $) "failed") $) NIL)) (-3751 (((-3 (-2 (|:| |var| (-852 |#1|)) (|:| -3438 (-763))) "failed") $) NIL)) (-4022 (((-1108) $) NIL)) (-2086 (((-121) $) NIL)) (-2091 ((|#2| $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#2| (-453)))) (-2721 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) NIL (|has| |#2| (-453)))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3848 (((-420 $) $) NIL (|has| |#2| (-904)))) (-2595 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-558)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-852 |#1|) |#2|) NIL) (($ $ (-634 (-852 |#1|)) (-634 |#2|)) NIL) (($ $ (-852 |#1|) $) NIL) (($ $ (-634 (-852 |#1|)) (-634 $)) NIL)) (-2217 (($ $ (-852 |#1|)) NIL (|has| |#2| (-172)))) (-4189 (($ $ (-852 |#1|)) NIL) (($ $ (-634 (-852 |#1|))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-3206 (((-232 (-1697 |#1|) (-763)) $) NIL) (((-763) $ (-852 |#1|)) NIL) (((-634 (-763)) $ (-634 (-852 |#1|))) NIL)) (-4278 (((-887 (-381)) $) NIL (-12 (|has| (-852 |#1|) (-609 (-887 (-381)))) (|has| |#2| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-852 |#1|) (-609 (-887 (-568)))) (|has| |#2| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-852 |#1|) (-609 (-541))) (|has| |#2| (-609 (-541)))))) (-3367 ((|#2| $) NIL (|has| |#2| (-453))) (($ $ (-852 |#1|)) NIL (|has| |#2| (-453)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#2| (-904))))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#2|) NIL) (($ (-852 |#1|)) NIL) (($ (-409 (-568))) NIL (-2198 (|has| |#2| (-43 (-409 (-568)))) (|has| |#2| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#2| (-558)))) (-1302 (((-634 |#2|) $) NIL)) (-2604 ((|#2| $ (-232 (-1697 |#1|) (-763))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| |#2| (-904))) (|has| |#2| (-148))))) (-4078 (((-763)) NIL)) (-4171 (($ $ $ (-763)) NIL (|has| |#2| (-172)))) (-1826 (((-121) $ $) NIL (|has| |#2| (-558)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $ (-852 |#1|)) NIL) (($ $ (-634 (-852 |#1|))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-1751 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1779 (($ $ |#2|) NIL (|has| |#2| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#2| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#2| (-43 (-409 (-568))))) (($ |#2| $) NIL) (($ $ |#2|) NIL))) 
-(((-242 |#1| |#2|) (-13 (-950 |#2| (-232 (-1697 |#1|) (-763)) (-852 |#1|)) (-10 -8 (-15 -4425 ($ $ (-634 (-568)))))) (-634 (-1161)) (-1047)) (T -242)) 
-((-4425 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-242 *3 *4)) (-14 *3 (-634 (-1161))) (-4 *4 (-1047))))) 
-(-13 (-950 |#2| (-232 (-1697 |#1|) (-763)) (-852 |#1|)) (-10 -8 (-15 -4425 ($ $ (-634 (-568)))))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-1394 (($ (-917)) NIL (|has| |#4| (-1047)))) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-1462 (($ $ $) NIL (|has| |#4| (-788)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-3983 (((-763)) NIL (|has| |#4| (-370)))) (-3662 (((-568) $) NIL (|has| |#4| (-840)))) (-2436 ((|#4| $ (-568) |#4|) NIL (|has| $ (-6 -4520)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#4| "failed") $) NIL (|has| |#4| (-1090))) (((-3 (-568) "failed") $) NIL (-12 (|has| |#4| (-1037 (-568))) (|has| |#4| (-1090)))) (((-3 (-409 (-568)) "failed") $) NIL (-12 (|has| |#4| (-1037 (-409 (-568)))) (|has| |#4| (-1090))))) (-2854 ((|#4| $) NIL (|has| |#4| (-1090))) (((-568) $) NIL (-12 (|has| |#4| (-1037 (-568))) (|has| |#4| (-1090)))) (((-409 (-568)) $) NIL (-12 (|has| |#4| (-1037 (-409 (-568)))) (|has| |#4| (-1090))))) (-3164 (((-2 (|:| -2928 (-679 |#4|)) (|:| |vec| (-1244 |#4|))) (-679 $) (-1244 $)) NIL (|has| |#4| (-1047))) (((-679 |#4|) (-679 $)) NIL (|has| |#4| (-1047))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (-12 (|has| |#4| (-630 (-568))) (|has| |#4| (-1047)))) (((-679 (-568)) (-679 $)) NIL (-12 (|has| |#4| (-630 (-568))) (|has| |#4| (-1047))))) (-2925 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| |#4| (-225)) (|has| |#4| (-1047))) (-12 (|has| |#4| (-630 (-568))) (|has| |#4| (-1047))) (|has| |#4| (-716)) (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))))) (-1731 (($) NIL (|has| |#4| (-370)))) (-3989 ((|#4| $ (-568) |#4|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#4| $ (-568)) NIL)) (-2033 (((-121) $) NIL (|has| |#4| (-840)))) (-4360 (((-634 |#4|) $) NIL (|has| $ (-6 -4519)))) (-2735 (((-121) $) NIL (-2198 (-12 (|has| |#4| (-225)) (|has| |#4| (-1047))) (-12 (|has| |#4| (-630 (-568))) (|has| |#4| (-1047))) (|has| |#4| (-716)) (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))))) (-2245 (((-121) $) NIL (|has| |#4| (-840)))) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) NIL (|has| (-568) (-842)))) (-2521 (($ $ $) NIL (-2198 (|has| |#4| (-788)) (|has| |#4| (-840))))) (-1979 (((-634 |#4|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#4| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090))))) (-2223 (((-568) $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (-2198 (|has| |#4| (-788)) (|has| |#4| (-840))))) (-3674 (($ (-1 |#4| |#4|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#4| |#4|) $) NIL)) (-3683 (((-917) $) NIL (|has| |#4| (-370)))) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL)) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4355 (($ (-917)) NIL (|has| |#4| (-370)))) (-4022 (((-1108) $) NIL)) (-3876 ((|#4| $) NIL (|has| (-568) (-842)))) (-3724 (($ $ |#4|) NIL (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#4|))) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 |#4|) (-634 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#4| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090))))) (-2041 (((-634 |#4|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#4| $ (-568) |#4|) NIL) ((|#4| $ (-568)) 12)) (-3682 ((|#4| $ $) NIL (|has| |#4| (-1047)))) (-2039 (($ (-1244 |#4|)) NIL)) (-4321 (((-139)) NIL (|has| |#4| (-365)))) (-4189 (($ $ (-1 |#4| |#4|) (-763)) NIL (|has| |#4| (-1047))) (($ $ (-1 |#4| |#4|)) NIL (|has| |#4| (-1047))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#4| (-225)) (|has| |#4| (-1047)))) (($ $) NIL (-12 (|has| |#4| (-225)) (|has| |#4| (-1047))))) (-4168 (((-763) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519))) (((-763) |#4| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090))))) (-3863 (($ $) NIL)) (-2745 (((-1244 |#4|) $) NIL) (((-850) $) NIL) (($ |#4|) NIL (|has| |#4| (-1090))) (($ (-568)) NIL (-2198 (-12 (|has| |#4| (-1037 (-568))) (|has| |#4| (-1090))) (|has| |#4| (-1047)))) (($ (-409 (-568))) NIL (-12 (|has| |#4| (-1037 (-409 (-568)))) (|has| |#4| (-1090))))) (-4078 (((-763)) NIL (|has| |#4| (-1047)))) (-1319 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-2897 (($ $) NIL (|has| |#4| (-840)))) (-1887 (($ $ (-763)) NIL (-2198 (-12 (|has| |#4| (-225)) (|has| |#4| (-1047))) (-12 (|has| |#4| (-630 (-568))) (|has| |#4| (-1047))) (|has| |#4| (-716)) (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047))))) (($ $ (-917)) NIL (-2198 (-12 (|has| |#4| (-225)) (|has| |#4| (-1047))) (-12 (|has| |#4| (-630 (-568))) (|has| |#4| (-1047))) (|has| |#4| (-716)) (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))))) (-3056 (($) NIL T CONST)) (-1556 (($) NIL (-2198 (-12 (|has| |#4| (-225)) (|has| |#4| (-1047))) (-12 (|has| |#4| (-630 (-568))) (|has| |#4| (-1047))) (|has| |#4| (-716)) (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))) CONST)) (-3190 (($ $ (-1 |#4| |#4|) (-763)) NIL (|has| |#4| (-1047))) (($ $ (-1 |#4| |#4|)) NIL (|has| |#4| (-1047))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#4| (-225)) (|has| |#4| (-1047)))) (($ $) NIL (-12 (|has| |#4| (-225)) (|has| |#4| (-1047))))) (-1751 (((-121) $ $) NIL (-2198 (|has| |#4| (-788)) (|has| |#4| (-840))))) (-1738 (((-121) $ $) NIL (-2198 (|has| |#4| (-788)) (|has| |#4| (-840))))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (-2198 (|has| |#4| (-788)) (|has| |#4| (-840))))) (-1732 (((-121) $ $) NIL (-2198 (|has| |#4| (-788)) (|has| |#4| (-840))))) (-1779 (($ $ |#4|) NIL (|has| |#4| (-365)))) (-1773 (($ $ $) NIL) (($ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-763)) NIL (-2198 (-12 (|has| |#4| (-225)) (|has| |#4| (-1047))) (-12 (|has| |#4| (-630 (-568))) (|has| |#4| (-1047))) (|has| |#4| (-716)) (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047))))) (($ $ (-917)) NIL (-2198 (-12 (|has| |#4| (-225)) (|has| |#4| (-1047))) (-12 (|has| |#4| (-630 (-568))) (|has| |#4| (-1047))) (|has| |#4| (-716)) (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))))) (* (($ |#2| $) 14) (($ (-568) $) NIL) (($ (-763) $) NIL) (($ (-917) $) NIL) (($ |#3| $) 18) (($ $ |#4|) NIL (|has| |#4| (-1047))) (($ |#4| $) NIL (|has| |#4| (-1047))) (($ $ $) NIL (-2198 (-12 (|has| |#4| (-225)) (|has| |#4| (-1047))) (-12 (|has| |#4| (-630 (-568))) (|has| |#4| (-1047))) (|has| |#4| (-716)) (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2852 ((|#1| $) NIL)) (-2237 ((|#1| $) NIL)) (-3623 (($ $) NIL)) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-2121 (($ $ (-568)) NIL (|has| $ (-6 -4522)))) (-1324 (((-121) $) NIL (|has| |#1| (-842))) (((-121) (-1 (-121) |#1| |#1|) $) NIL)) (-2109 (($ $) NIL (-12 (|has| $ (-6 -4522)) (|has| |#1| (-842)))) (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-3647 (($ $) 10 (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-3370 ((|#1| $ |#1|) NIL (|has| $ (-6 -4522)))) (-1958 (($ $ $) NIL (|has| $ (-6 -4522)))) (-2257 ((|#1| $ |#1|) NIL (|has| $ (-6 -4522)))) (-1706 ((|#1| $ |#1|) NIL (|has| $ (-6 -4522)))) (-2438 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4522))) ((|#1| $ "first" |#1|) NIL (|has| $ (-6 -4522))) (($ $ "rest" $) NIL (|has| $ (-6 -4522))) ((|#1| $ "last" |#1|) NIL (|has| $ (-6 -4522))) ((|#1| $ (-1210 (-568)) |#1|) NIL (|has| $ (-6 -4522))) ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) NIL (|has| $ (-6 -4522)))) (-3963 (($ (-1 (-121) |#1|) $) NIL)) (-2803 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1681 ((|#1| $) NIL)) (-4490 (($) NIL T CONST)) (-4452 (($ $) NIL (|has| $ (-6 -4522)))) (-3945 (($ $) NIL)) (-3936 (($ $) NIL) (($ $ (-763)) NIL)) (-1377 (($ $) NIL (|has| |#1| (-1090)))) (-3926 (($ $) 7 (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1568 (($ |#1| $) NIL (|has| |#1| (-1090))) (($ (-1 (-121) |#1|) $) NIL)) (-4330 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (($ |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1292 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-568)) NIL)) (-1340 (((-121) $) NIL)) (-2766 (((-568) |#1| $ (-568)) NIL (|has| |#1| (-1090))) (((-568) |#1| $) NIL (|has| |#1| (-1090))) (((-568) (-1 (-121) |#1|) $) NIL)) (-3317 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-3534 (((-634 $) $) NIL)) (-3606 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1851 (($ (-763) |#1|) NIL)) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) NIL (|has| (-568) (-842)))) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-4496 (($ $ $) NIL (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $ $) NIL)) (-3645 (($ $ $) NIL (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $ $) NIL)) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3631 (((-568) $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-2253 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-3897 (($ |#1|) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-4081 (((-634 |#1|) $) NIL)) (-3319 (((-121) $) NIL)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4164 ((|#1| $) NIL) (($ $ (-763)) NIL)) (-1708 (($ $ $ (-568)) NIL) (($ |#1| $ (-568)) NIL)) (-4124 (($ $ $ (-568)) NIL) (($ |#1| $ (-568)) NIL)) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3877 ((|#1| $) NIL) (($ $ (-763)) NIL)) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-2490 (($ $ |#1|) NIL (|has| $ (-6 -4522)))) (-4049 (((-121) $) NIL)) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#1| $ "value") NIL) ((|#1| $ "first") NIL) (($ $ "rest") NIL) ((|#1| $ "last") NIL) (($ $ (-1210 (-568))) NIL) ((|#1| $ (-568)) NIL) ((|#1| $ (-568) |#1|) NIL) (($ $ "unique") 9) (($ $ "sort") 12) (((-763) $ "count") 16)) (-1665 (((-568) $ $) NIL)) (-4031 (($ $ (-1210 (-568))) NIL) (($ $ (-568)) NIL)) (-2828 (($ $ (-1210 (-568))) NIL) (($ $ (-568)) NIL)) (-2100 (($ (-634 |#1|)) 22)) (-2763 (((-121) $) NIL)) (-3903 (($ $) NIL)) (-1499 (($ $) NIL (|has| $ (-6 -4522)))) (-3535 (((-763) $) NIL)) (-4424 (($ $) NIL)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3306 (($ $ $ (-568)) NIL (|has| $ (-6 -4522)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) NIL)) (-1876 (($ $ $) NIL) (($ $ |#1|) NIL)) (-2770 (($ $ $) NIL) (($ |#1| $) NIL) (($ (-634 $)) NIL) (($ $ |#1|) NIL)) (-2747 (($ (-634 |#1|)) 17) (((-634 |#1|) $) 18) (((-850) $) 21 (|has| |#1| (-1090)))) (-3180 (((-634 $) $) NIL)) (-3873 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1699 (((-763) $) 14 (|has| $ (-6 -4521))))) 
+(((-240 |#1|) (-13 (-658 |#1|) (-10 -8 (-15 -2747 ($ (-634 |#1|))) (-15 -2747 ((-634 |#1|) $)) (-15 -2100 ($ (-634 |#1|))) (-15 -2781 ($ $ "unique")) (-15 -2781 ($ $ "sort")) (-15 -2781 ((-763) $ "count")))) (-842)) (T -240)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-240 *3)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-240 *3)) (-4 *3 (-842)))) (-2100 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-240 *3)))) (-2781 (*1 *1 *1 *2) (-12 (-5 *2 "unique") (-5 *1 (-240 *3)) (-4 *3 (-842)))) (-2781 (*1 *1 *1 *2) (-12 (-5 *2 "sort") (-5 *1 (-240 *3)) (-4 *3 (-842)))) (-2781 (*1 *2 *1 *3) (-12 (-5 *3 "count") (-5 *2 (-763)) (-5 *1 (-240 *4)) (-4 *4 (-842))))) 
+(-13 (-658 |#1|) (-10 -8 (-15 -2747 ($ (-634 |#1|))) (-15 -2747 ((-634 |#1|) $)) (-15 -2100 ($ (-634 |#1|))) (-15 -2781 ($ $ "unique")) (-15 -2781 ($ $ "sort")) (-15 -2781 ((-763) $ "count")))) 
+((-3104 (((-3 (-763) "failed") |#1| |#1| (-763)) 26))) 
+(((-241 |#1|) (-10 -7 (-15 -3104 ((-3 (-763) "failed") |#1| |#1| (-763)))) (-13 (-716) (-370) (-10 -7 (-15 ** (|#1| |#1| (-568)))))) (T -241)) 
+((-3104 (*1 *2 *3 *3 *2) (|partial| -12 (-5 *2 (-763)) (-4 *3 (-13 (-716) (-370) (-10 -7 (-15 ** (*3 *3 (-568)))))) (-5 *1 (-241 *3))))) 
+(-10 -7 (-15 -3104 ((-3 (-763) "failed") |#1| |#1| (-763)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2057 (((-634 (-852 |#1|)) $) NIL)) (-3840 (((-1157 $) $ (-852 |#1|)) NIL) (((-1157 |#2|) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#2| (-558)))) (-3661 (($ $) NIL (|has| |#2| (-558)))) (-4426 (((-121) $) NIL (|has| |#2| (-558)))) (-3528 (((-763) $) NIL) (((-763) $ (-634 (-852 |#1|))) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3045 (($ $) NIL (|has| |#2| (-453)))) (-3498 (((-420 $) $) NIL (|has| |#2| (-453)))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#2| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#2| (-1037 (-568)))) (((-3 (-852 |#1|) "failed") $) NIL)) (-2857 ((|#2| $) NIL) (((-409 (-568)) $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#2| (-1037 (-568)))) (((-852 |#1|) $) NIL)) (-2910 (($ $ $ (-852 |#1|)) NIL (|has| |#2| (-172)))) (-1594 (($ $ (-634 (-568))) NIL)) (-2116 (($ $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL) (((-679 |#2|) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1998 (($ $) NIL (|has| |#2| (-453))) (($ $ (-852 |#1|)) NIL (|has| |#2| (-453)))) (-2110 (((-634 $) $) NIL)) (-2197 (((-121) $) NIL (|has| |#2| (-904)))) (-2453 (($ $ |#2| (-232 (-1699 |#1|) (-763)) $) NIL)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-852 |#1|) (-881 (-381))) (|has| |#2| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-852 |#1|) (-881 (-568))) (|has| |#2| (-881 (-568)))))) (-1598 (((-121) $) NIL)) (-3971 (((-763) $) NIL)) (-2053 (($ (-1157 |#2|) (-852 |#1|)) NIL) (($ (-1157 $) (-852 |#1|)) NIL)) (-3062 (((-634 $) $) NIL)) (-2171 (((-121) $) NIL)) (-2049 (($ |#2| (-232 (-1699 |#1|) (-763))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-1438 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $ (-852 |#1|)) NIL)) (-3524 (((-232 (-1699 |#1|) (-763)) $) NIL) (((-763) $ (-852 |#1|)) NIL) (((-634 (-763)) $ (-634 (-852 |#1|))) NIL)) (-1732 (($ $ $) NIL (|has| |#2| (-842)))) (-2047 (($ $ $) NIL (|has| |#2| (-842)))) (-1865 (($ (-1 (-232 (-1699 |#1|) (-763)) (-232 (-1699 |#1|) (-763))) $) NIL)) (-2797 (($ (-1 |#2| |#2|) $) NIL)) (-2817 (((-3 (-852 |#1|) "failed") $) NIL)) (-2099 (($ $) NIL)) (-2104 ((|#2| $) NIL)) (-2498 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) NIL (|has| |#2| (-453)))) (-1893 (((-1143) $) NIL)) (-4362 (((-3 (-634 $) "failed") $) NIL)) (-2112 (((-3 (-634 $) "failed") $) NIL)) (-2617 (((-3 (-2 (|:| |var| (-852 |#1|)) (|:| -3483 (-763))) "failed") $) NIL)) (-4025 (((-1108) $) NIL)) (-2088 (((-121) $) NIL)) (-2093 ((|#2| $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#2| (-453)))) (-2723 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) NIL (|has| |#2| (-453)))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3850 (((-420 $) $) NIL (|has| |#2| (-904)))) (-2597 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-558)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-852 |#1|) |#2|) NIL) (($ $ (-634 (-852 |#1|)) (-634 |#2|)) NIL) (($ $ (-852 |#1|) $) NIL) (($ $ (-634 (-852 |#1|)) (-634 $)) NIL)) (-3440 (($ $ (-852 |#1|)) NIL (|has| |#2| (-172)))) (-4191 (($ $ (-852 |#1|)) NIL) (($ $ (-634 (-852 |#1|))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-1836 (((-232 (-1699 |#1|) (-763)) $) NIL) (((-763) $ (-852 |#1|)) NIL) (((-634 (-763)) $ (-634 (-852 |#1|))) NIL)) (-4280 (((-887 (-381)) $) NIL (-12 (|has| (-852 |#1|) (-609 (-887 (-381)))) (|has| |#2| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-852 |#1|) (-609 (-887 (-568)))) (|has| |#2| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-852 |#1|) (-609 (-541))) (|has| |#2| (-609 (-541)))))) (-1364 ((|#2| $) NIL (|has| |#2| (-453))) (($ $ (-852 |#1|)) NIL (|has| |#2| (-453)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#2| (-904))))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#2|) NIL) (($ (-852 |#1|)) NIL) (($ (-409 (-568))) NIL (-2199 (|has| |#2| (-43 (-409 (-568)))) (|has| |#2| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#2| (-558)))) (-3304 (((-634 |#2|) $) NIL)) (-2079 ((|#2| $ (-232 (-1699 |#1|) (-763))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| |#2| (-904))) (|has| |#2| (-148))))) (-3425 (((-763)) NIL)) (-3925 (($ $ $ (-763)) NIL (|has| |#2| (-172)))) (-2273 (((-121) $ $) NIL (|has| |#2| (-558)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $ (-852 |#1|)) NIL) (($ $ (-634 (-852 |#1|))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-1753 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1781 (($ $ |#2|) NIL (|has| |#2| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#2| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#2| (-43 (-409 (-568))))) (($ |#2| $) NIL) (($ $ |#2|) NIL))) 
+(((-242 |#1| |#2|) (-13 (-950 |#2| (-232 (-1699 |#1|) (-763)) (-852 |#1|)) (-10 -8 (-15 -1594 ($ $ (-634 (-568)))))) (-634 (-1161)) (-1047)) (T -242)) 
+((-1594 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-242 *3 *4)) (-14 *3 (-634 (-1161))) (-4 *4 (-1047))))) 
+(-13 (-950 |#2| (-232 (-1699 |#1|) (-763)) (-852 |#1|)) (-10 -8 (-15 -1594 ($ $ (-634 (-568)))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-4007 (($ (-917)) NIL (|has| |#4| (-1047)))) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-2409 (($ $ $) NIL (|has| |#4| (-788)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-3986 (((-763)) NIL (|has| |#4| (-370)))) (-3337 (((-568) $) NIL (|has| |#4| (-840)))) (-2438 ((|#4| $ (-568) |#4|) NIL (|has| $ (-6 -4522)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#4| "failed") $) NIL (|has| |#4| (-1090))) (((-3 (-568) "failed") $) NIL (-12 (|has| |#4| (-1037 (-568))) (|has| |#4| (-1090)))) (((-3 (-409 (-568)) "failed") $) NIL (-12 (|has| |#4| (-1037 (-409 (-568)))) (|has| |#4| (-1090))))) (-2857 ((|#4| $) NIL (|has| |#4| (-1090))) (((-568) $) NIL (-12 (|has| |#4| (-1037 (-568))) (|has| |#4| (-1090)))) (((-409 (-568)) $) NIL (-12 (|has| |#4| (-1037 (-409 (-568)))) (|has| |#4| (-1090))))) (-1668 (((-2 (|:| -2908 (-679 |#4|)) (|:| |vec| (-1244 |#4|))) (-679 $) (-1244 $)) NIL (|has| |#4| (-1047))) (((-679 |#4|) (-679 $)) NIL (|has| |#4| (-1047))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (-12 (|has| |#4| (-630 (-568))) (|has| |#4| (-1047)))) (((-679 (-568)) (-679 $)) NIL (-12 (|has| |#4| (-630 (-568))) (|has| |#4| (-1047))))) (-2902 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| |#4| (-225)) (|has| |#4| (-1047))) (-12 (|has| |#4| (-630 (-568))) (|has| |#4| (-1047))) (|has| |#4| (-716)) (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))))) (-1733 (($) NIL (|has| |#4| (-370)))) (-1292 ((|#4| $ (-568) |#4|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#4| $ (-568)) NIL)) (-1436 (((-121) $) NIL (|has| |#4| (-840)))) (-3317 (((-634 |#4|) $) NIL (|has| $ (-6 -4521)))) (-1598 (((-121) $) NIL (-2199 (-12 (|has| |#4| (-225)) (|has| |#4| (-1047))) (-12 (|has| |#4| (-630 (-568))) (|has| |#4| (-1047))) (|has| |#4| (-716)) (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))))) (-2859 (((-121) $) NIL (|has| |#4| (-840)))) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) NIL (|has| (-568) (-842)))) (-1732 (($ $ $) NIL (-2199 (|has| |#4| (-788)) (|has| |#4| (-840))))) (-4406 (((-634 |#4|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#4| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090))))) (-3631 (((-568) $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (-2199 (|has| |#4| (-788)) (|has| |#4| (-840))))) (-2253 (($ (-1 |#4| |#4|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#4| |#4|) $) NIL)) (-2291 (((-917) $) NIL (|has| |#4| (-370)))) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL)) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4357 (($ (-917)) NIL (|has| |#4| (-370)))) (-4025 (((-1108) $) NIL)) (-3877 ((|#4| $) NIL (|has| (-568) (-842)))) (-2490 (($ $ |#4|) NIL (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#4|))) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 |#4|) (-634 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#4| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090))))) (-1480 (((-634 |#4|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#4| $ (-568) |#4|) NIL) ((|#4| $ (-568)) 12)) (-2286 ((|#4| $ $) NIL (|has| |#4| (-1047)))) (-2041 (($ (-1244 |#4|)) NIL)) (-3108 (((-139)) NIL (|has| |#4| (-365)))) (-4191 (($ $ (-1 |#4| |#4|) (-763)) NIL (|has| |#4| (-1047))) (($ $ (-1 |#4| |#4|)) NIL (|has| |#4| (-1047))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#4| (-225)) (|has| |#4| (-1047)))) (($ $) NIL (-12 (|has| |#4| (-225)) (|has| |#4| (-1047))))) (-4170 (((-763) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521))) (((-763) |#4| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090))))) (-3865 (($ $) NIL)) (-2747 (((-1244 |#4|) $) NIL) (((-850) $) NIL) (($ |#4|) NIL (|has| |#4| (-1090))) (($ (-568)) NIL (-2199 (-12 (|has| |#4| (-1037 (-568))) (|has| |#4| (-1090))) (|has| |#4| (-1047)))) (($ (-409 (-568))) NIL (-12 (|has| |#4| (-1037 (-409 (-568)))) (|has| |#4| (-1090))))) (-3425 (((-763)) NIL (|has| |#4| (-1047)))) (-3437 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-2811 (($ $) NIL (|has| |#4| (-840)))) (-1889 (($ $ (-763)) NIL (-2199 (-12 (|has| |#4| (-225)) (|has| |#4| (-1047))) (-12 (|has| |#4| (-630 (-568))) (|has| |#4| (-1047))) (|has| |#4| (-716)) (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047))))) (($ $ (-917)) NIL (-2199 (-12 (|has| |#4| (-225)) (|has| |#4| (-1047))) (-12 (|has| |#4| (-630 (-568))) (|has| |#4| (-1047))) (|has| |#4| (-716)) (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))))) (-3058 (($) NIL T CONST)) (-1557 (($) NIL (-2199 (-12 (|has| |#4| (-225)) (|has| |#4| (-1047))) (-12 (|has| |#4| (-630 (-568))) (|has| |#4| (-1047))) (|has| |#4| (-716)) (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))) CONST)) (-3192 (($ $ (-1 |#4| |#4|) (-763)) NIL (|has| |#4| (-1047))) (($ $ (-1 |#4| |#4|)) NIL (|has| |#4| (-1047))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#4| (-225)) (|has| |#4| (-1047)))) (($ $) NIL (-12 (|has| |#4| (-225)) (|has| |#4| (-1047))))) (-1753 (((-121) $ $) NIL (-2199 (|has| |#4| (-788)) (|has| |#4| (-840))))) (-1740 (((-121) $ $) NIL (-2199 (|has| |#4| (-788)) (|has| |#4| (-840))))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (-2199 (|has| |#4| (-788)) (|has| |#4| (-840))))) (-1734 (((-121) $ $) NIL (-2199 (|has| |#4| (-788)) (|has| |#4| (-840))))) (-1781 (($ $ |#4|) NIL (|has| |#4| (-365)))) (-1775 (($ $ $) NIL) (($ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-763)) NIL (-2199 (-12 (|has| |#4| (-225)) (|has| |#4| (-1047))) (-12 (|has| |#4| (-630 (-568))) (|has| |#4| (-1047))) (|has| |#4| (-716)) (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047))))) (($ $ (-917)) NIL (-2199 (-12 (|has| |#4| (-225)) (|has| |#4| (-1047))) (-12 (|has| |#4| (-630 (-568))) (|has| |#4| (-1047))) (|has| |#4| (-716)) (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))))) (* (($ |#2| $) 14) (($ (-568) $) NIL) (($ (-763) $) NIL) (($ (-917) $) NIL) (($ |#3| $) 18) (($ $ |#4|) NIL (|has| |#4| (-1047))) (($ |#4| $) NIL (|has| |#4| (-1047))) (($ $ $) NIL (-2199 (-12 (|has| |#4| (-225)) (|has| |#4| (-1047))) (-12 (|has| |#4| (-630 (-568))) (|has| |#4| (-1047))) (|has| |#4| (-716)) (-12 (|has| |#4| (-895 (-1161))) (|has| |#4| (-1047)))))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
 (((-243 |#1| |#2| |#3| |#4|) (-13 (-230 |#1| |#4|) (-637 |#2|) (-637 |#3|)) (-917) (-1047) (-1111 |#1| |#2| (-232 |#1| |#2|) (-232 |#1| |#2|)) (-637 |#2|)) (T -243)) 
 NIL 
 (-13 (-230 |#1| |#4|) (-637 |#2|) (-637 |#3|)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-1394 (($ (-917)) NIL (|has| |#3| (-1047)))) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-1462 (($ $ $) NIL (|has| |#3| (-788)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-3983 (((-763)) NIL (|has| |#3| (-370)))) (-3662 (((-568) $) NIL (|has| |#3| (-840)))) (-2436 ((|#3| $ (-568) |#3|) NIL (|has| $ (-6 -4520)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#3| "failed") $) NIL (|has| |#3| (-1090))) (((-3 (-568) "failed") $) NIL (-12 (|has| |#3| (-1037 (-568))) (|has| |#3| (-1090)))) (((-3 (-409 (-568)) "failed") $) NIL (-12 (|has| |#3| (-1037 (-409 (-568)))) (|has| |#3| (-1090))))) (-2854 ((|#3| $) NIL (|has| |#3| (-1090))) (((-568) $) NIL (-12 (|has| |#3| (-1037 (-568))) (|has| |#3| (-1090)))) (((-409 (-568)) $) NIL (-12 (|has| |#3| (-1037 (-409 (-568)))) (|has| |#3| (-1090))))) (-3164 (((-2 (|:| -2928 (-679 |#3|)) (|:| |vec| (-1244 |#3|))) (-679 $) (-1244 $)) NIL (|has| |#3| (-1047))) (((-679 |#3|) (-679 $)) NIL (|has| |#3| (-1047))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047)))) (((-679 (-568)) (-679 $)) NIL (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047))))) (-2925 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| |#3| (-225)) (|has| |#3| (-1047))) (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047))) (|has| |#3| (-716)) (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))))) (-1731 (($) NIL (|has| |#3| (-370)))) (-3989 ((|#3| $ (-568) |#3|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#3| $ (-568)) NIL)) (-2033 (((-121) $) NIL (|has| |#3| (-840)))) (-4360 (((-634 |#3|) $) NIL (|has| $ (-6 -4519)))) (-2735 (((-121) $) NIL (-2198 (-12 (|has| |#3| (-225)) (|has| |#3| (-1047))) (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047))) (|has| |#3| (-716)) (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))))) (-2245 (((-121) $) NIL (|has| |#3| (-840)))) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) NIL (|has| (-568) (-842)))) (-2521 (($ $ $) NIL (-2198 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-1979 (((-634 |#3|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#3| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#3| (-1090))))) (-2223 (((-568) $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (-2198 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-3674 (($ (-1 |#3| |#3|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#3| |#3|) $) NIL)) (-3683 (((-917) $) NIL (|has| |#3| (-370)))) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL)) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4355 (($ (-917)) NIL (|has| |#3| (-370)))) (-4022 (((-1108) $) NIL)) (-3876 ((|#3| $) NIL (|has| (-568) (-842)))) (-3724 (($ $ |#3|) NIL (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#3|))) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ (-288 |#3|)) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ |#3| |#3|) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ (-634 |#3|) (-634 |#3|)) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#3| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#3| (-1090))))) (-2041 (((-634 |#3|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#3| $ (-568) |#3|) NIL) ((|#3| $ (-568)) 11)) (-3682 ((|#3| $ $) NIL (|has| |#3| (-1047)))) (-2039 (($ (-1244 |#3|)) NIL)) (-4321 (((-139)) NIL (|has| |#3| (-365)))) (-4189 (($ $ (-1 |#3| |#3|) (-763)) NIL (|has| |#3| (-1047))) (($ $ (-1 |#3| |#3|)) NIL (|has| |#3| (-1047))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#3| (-225)) (|has| |#3| (-1047)))) (($ $) NIL (-12 (|has| |#3| (-225)) (|has| |#3| (-1047))))) (-4168 (((-763) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4519))) (((-763) |#3| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#3| (-1090))))) (-3863 (($ $) NIL)) (-2745 (((-1244 |#3|) $) NIL) (((-850) $) NIL) (($ |#3|) NIL (|has| |#3| (-1090))) (($ (-568)) NIL (-2198 (-12 (|has| |#3| (-1037 (-568))) (|has| |#3| (-1090))) (|has| |#3| (-1047)))) (($ (-409 (-568))) NIL (-12 (|has| |#3| (-1037 (-409 (-568)))) (|has| |#3| (-1090))))) (-4078 (((-763)) NIL (|has| |#3| (-1047)))) (-1319 (((-121) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4519)))) (-2897 (($ $) NIL (|has| |#3| (-840)))) (-1887 (($ $ (-763)) NIL (-2198 (-12 (|has| |#3| (-225)) (|has| |#3| (-1047))) (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047))) (|has| |#3| (-716)) (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047))))) (($ $ (-917)) NIL (-2198 (-12 (|has| |#3| (-225)) (|has| |#3| (-1047))) (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047))) (|has| |#3| (-716)) (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))))) (-3056 (($) NIL T CONST)) (-1556 (($) NIL (-2198 (-12 (|has| |#3| (-225)) (|has| |#3| (-1047))) (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047))) (|has| |#3| (-716)) (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) CONST)) (-3190 (($ $ (-1 |#3| |#3|) (-763)) NIL (|has| |#3| (-1047))) (($ $ (-1 |#3| |#3|)) NIL (|has| |#3| (-1047))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#3| (-225)) (|has| |#3| (-1047)))) (($ $) NIL (-12 (|has| |#3| (-225)) (|has| |#3| (-1047))))) (-1751 (((-121) $ $) NIL (-2198 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-1738 (((-121) $ $) NIL (-2198 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (-2198 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-1732 (((-121) $ $) NIL (-2198 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-1779 (($ $ |#3|) NIL (|has| |#3| (-365)))) (-1773 (($ $ $) NIL) (($ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-763)) NIL (-2198 (-12 (|has| |#3| (-225)) (|has| |#3| (-1047))) (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047))) (|has| |#3| (-716)) (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047))))) (($ $ (-917)) NIL (-2198 (-12 (|has| |#3| (-225)) (|has| |#3| (-1047))) (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047))) (|has| |#3| (-716)) (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))))) (* (($ |#2| $) 13) (($ (-568) $) NIL) (($ (-763) $) NIL) (($ (-917) $) NIL) (($ $ |#3|) NIL (|has| |#3| (-1047))) (($ |#3| $) NIL (|has| |#3| (-1047))) (($ $ $) NIL (-2198 (-12 (|has| |#3| (-225)) (|has| |#3| (-1047))) (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047))) (|has| |#3| (-716)) (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-4007 (($ (-917)) NIL (|has| |#3| (-1047)))) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-2409 (($ $ $) NIL (|has| |#3| (-788)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-3986 (((-763)) NIL (|has| |#3| (-370)))) (-3337 (((-568) $) NIL (|has| |#3| (-840)))) (-2438 ((|#3| $ (-568) |#3|) NIL (|has| $ (-6 -4522)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#3| "failed") $) NIL (|has| |#3| (-1090))) (((-3 (-568) "failed") $) NIL (-12 (|has| |#3| (-1037 (-568))) (|has| |#3| (-1090)))) (((-3 (-409 (-568)) "failed") $) NIL (-12 (|has| |#3| (-1037 (-409 (-568)))) (|has| |#3| (-1090))))) (-2857 ((|#3| $) NIL (|has| |#3| (-1090))) (((-568) $) NIL (-12 (|has| |#3| (-1037 (-568))) (|has| |#3| (-1090)))) (((-409 (-568)) $) NIL (-12 (|has| |#3| (-1037 (-409 (-568)))) (|has| |#3| (-1090))))) (-1668 (((-2 (|:| -2908 (-679 |#3|)) (|:| |vec| (-1244 |#3|))) (-679 $) (-1244 $)) NIL (|has| |#3| (-1047))) (((-679 |#3|) (-679 $)) NIL (|has| |#3| (-1047))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047)))) (((-679 (-568)) (-679 $)) NIL (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047))))) (-2902 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| |#3| (-225)) (|has| |#3| (-1047))) (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047))) (|has| |#3| (-716)) (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))))) (-1733 (($) NIL (|has| |#3| (-370)))) (-1292 ((|#3| $ (-568) |#3|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#3| $ (-568)) NIL)) (-1436 (((-121) $) NIL (|has| |#3| (-840)))) (-3317 (((-634 |#3|) $) NIL (|has| $ (-6 -4521)))) (-1598 (((-121) $) NIL (-2199 (-12 (|has| |#3| (-225)) (|has| |#3| (-1047))) (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047))) (|has| |#3| (-716)) (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))))) (-2859 (((-121) $) NIL (|has| |#3| (-840)))) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) NIL (|has| (-568) (-842)))) (-1732 (($ $ $) NIL (-2199 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-4406 (((-634 |#3|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#3| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#3| (-1090))))) (-3631 (((-568) $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (-2199 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-2253 (($ (-1 |#3| |#3|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#3| |#3|) $) NIL)) (-2291 (((-917) $) NIL (|has| |#3| (-370)))) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL)) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4357 (($ (-917)) NIL (|has| |#3| (-370)))) (-4025 (((-1108) $) NIL)) (-3877 ((|#3| $) NIL (|has| (-568) (-842)))) (-2490 (($ $ |#3|) NIL (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#3|))) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ (-288 |#3|)) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ |#3| |#3|) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ (-634 |#3|) (-634 |#3|)) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#3| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#3| (-1090))))) (-1480 (((-634 |#3|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#3| $ (-568) |#3|) NIL) ((|#3| $ (-568)) 11)) (-2286 ((|#3| $ $) NIL (|has| |#3| (-1047)))) (-2041 (($ (-1244 |#3|)) NIL)) (-3108 (((-139)) NIL (|has| |#3| (-365)))) (-4191 (($ $ (-1 |#3| |#3|) (-763)) NIL (|has| |#3| (-1047))) (($ $ (-1 |#3| |#3|)) NIL (|has| |#3| (-1047))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#3| (-225)) (|has| |#3| (-1047)))) (($ $) NIL (-12 (|has| |#3| (-225)) (|has| |#3| (-1047))))) (-4170 (((-763) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4521))) (((-763) |#3| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#3| (-1090))))) (-3865 (($ $) NIL)) (-2747 (((-1244 |#3|) $) NIL) (((-850) $) NIL) (($ |#3|) NIL (|has| |#3| (-1090))) (($ (-568)) NIL (-2199 (-12 (|has| |#3| (-1037 (-568))) (|has| |#3| (-1090))) (|has| |#3| (-1047)))) (($ (-409 (-568))) NIL (-12 (|has| |#3| (-1037 (-409 (-568)))) (|has| |#3| (-1090))))) (-3425 (((-763)) NIL (|has| |#3| (-1047)))) (-3437 (((-121) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4521)))) (-2811 (($ $) NIL (|has| |#3| (-840)))) (-1889 (($ $ (-763)) NIL (-2199 (-12 (|has| |#3| (-225)) (|has| |#3| (-1047))) (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047))) (|has| |#3| (-716)) (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047))))) (($ $ (-917)) NIL (-2199 (-12 (|has| |#3| (-225)) (|has| |#3| (-1047))) (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047))) (|has| |#3| (-716)) (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))))) (-3058 (($) NIL T CONST)) (-1557 (($) NIL (-2199 (-12 (|has| |#3| (-225)) (|has| |#3| (-1047))) (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047))) (|has| |#3| (-716)) (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) CONST)) (-3192 (($ $ (-1 |#3| |#3|) (-763)) NIL (|has| |#3| (-1047))) (($ $ (-1 |#3| |#3|)) NIL (|has| |#3| (-1047))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#3| (-225)) (|has| |#3| (-1047)))) (($ $) NIL (-12 (|has| |#3| (-225)) (|has| |#3| (-1047))))) (-1753 (((-121) $ $) NIL (-2199 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-1740 (((-121) $ $) NIL (-2199 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (-2199 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-1734 (((-121) $ $) NIL (-2199 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-1781 (($ $ |#3|) NIL (|has| |#3| (-365)))) (-1775 (($ $ $) NIL) (($ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-763)) NIL (-2199 (-12 (|has| |#3| (-225)) (|has| |#3| (-1047))) (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047))) (|has| |#3| (-716)) (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047))))) (($ $ (-917)) NIL (-2199 (-12 (|has| |#3| (-225)) (|has| |#3| (-1047))) (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047))) (|has| |#3| (-716)) (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))))) (* (($ |#2| $) 13) (($ (-568) $) NIL) (($ (-763) $) NIL) (($ (-917) $) NIL) (($ $ |#3|) NIL (|has| |#3| (-1047))) (($ |#3| $) NIL (|has| |#3| (-1047))) (($ $ $) NIL (-2199 (-12 (|has| |#3| (-225)) (|has| |#3| (-1047))) (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047))) (|has| |#3| (-716)) (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
 (((-244 |#1| |#2| |#3|) (-13 (-230 |#1| |#3|) (-637 |#2|)) (-763) (-1047) (-637 |#2|)) (T -244)) 
 NIL 
 (-13 (-230 |#1| |#3|) (-637 |#2|)) 
-((-3902 (((-634 (-763)) $) 47) (((-634 (-763)) $ |#3|) 50)) (-1551 (((-763) $) 49) (((-763) $ |#3|) 52)) (-4180 (($ $) 65)) (-3666 (((-3 |#2| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 (-568) "failed") $) NIL) (((-3 |#4| "failed") $) NIL) (((-3 |#3| "failed") $) 72)) (-4477 (((-763) $ |#3|) 39) (((-763) $) 36)) (-4300 (((-1 $ (-763)) |#3|) 15) (((-1 $ (-763)) $) 77)) (-1690 ((|#4| $) 58)) (-1989 (((-121) $) 56)) (-1484 (($ $) 64)) (-1339 (($ $ (-634 (-288 $))) 96) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ |#4| |#2|) NIL) (($ $ (-634 |#4|) (-634 |#2|)) NIL) (($ $ |#4| $) NIL) (($ $ (-634 |#4|) (-634 $)) NIL) (($ $ |#3| $) NIL) (($ $ (-634 |#3|) (-634 $)) 89) (($ $ |#3| |#2|) NIL) (($ $ (-634 |#3|) (-634 |#2|)) 84)) (-4189 (($ $ |#4|) NIL) (($ $ (-634 |#4|)) NIL) (($ $ |#4| (-763)) NIL) (($ $ (-634 |#4|) (-634 (-763))) NIL) (($ $) NIL) (($ $ (-763)) NIL) (($ $ (-1161)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) 32)) (-3795 (((-634 |#3|) $) 75)) (-3206 ((|#5| $) NIL) (((-763) $ |#4|) NIL) (((-634 (-763)) $ (-634 |#4|)) NIL) (((-763) $ |#3|) 44)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#2|) NIL) (($ |#4|) NIL) (($ |#3|) 67) (($ (-409 (-568))) NIL) (($ $) NIL))) 
-(((-245 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 -2745 (|#1| |#1|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -1339 (|#1| |#1| (-634 |#3|) (-634 |#2|))) (-15 -1339 (|#1| |#1| |#3| |#2|)) (-15 -1339 (|#1| |#1| (-634 |#3|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#3| |#1|)) (-15 -4300 ((-1 |#1| (-763)) |#1|)) (-15 -4180 (|#1| |#1|)) (-15 -1484 (|#1| |#1|)) (-15 -1690 (|#4| |#1|)) (-15 -1989 ((-121) |#1|)) (-15 -1551 ((-763) |#1| |#3|)) (-15 -3902 ((-634 (-763)) |#1| |#3|)) (-15 -1551 ((-763) |#1|)) (-15 -3902 ((-634 (-763)) |#1|)) (-15 -3206 ((-763) |#1| |#3|)) (-15 -4477 ((-763) |#1|)) (-15 -4477 ((-763) |#1| |#3|)) (-15 -3795 ((-634 |#3|) |#1|)) (-15 -4300 ((-1 |#1| (-763)) |#3|)) (-15 -3666 ((-3 |#3| "failed") |#1|)) (-15 -2745 (|#1| |#3|)) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -4189 (|#1| |#1| (-1161) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)))) (-15 -4189 (|#1| |#1| (-1161))) (-15 -4189 (|#1| |#1| (-763))) (-15 -4189 (|#1| |#1|)) (-15 -3206 ((-634 (-763)) |#1| (-634 |#4|))) (-15 -3206 ((-763) |#1| |#4|)) (-15 -3666 ((-3 |#4| "failed") |#1|)) (-15 -2745 (|#1| |#4|)) (-15 -1339 (|#1| |#1| (-634 |#4|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#4| |#1|)) (-15 -1339 (|#1| |#1| (-634 |#4|) (-634 |#2|))) (-15 -1339 (|#1| |#1| |#4| |#2|)) (-15 -1339 (|#1| |#1| (-634 |#1|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#1| |#1|)) (-15 -1339 (|#1| |#1| (-288 |#1|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -3206 (|#5| |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2745 (|#1| |#2|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -4189 (|#1| |#1| (-634 |#4|) (-634 (-763)))) (-15 -4189 (|#1| |#1| |#4| (-763))) (-15 -4189 (|#1| |#1| (-634 |#4|))) (-15 -4189 (|#1| |#1| |#4|)) (-15 -2745 (|#1| (-568))) (-15 -2745 ((-850) |#1|))) (-246 |#2| |#3| |#4| |#5|) (-1047) (-842) (-262 |#3|) (-788)) (T -245)) 
+((-2076 (((-634 (-763)) $) 47) (((-634 (-763)) $ |#3|) 50)) (-4308 (((-763) $) 49) (((-763) $ |#3|) 52)) (-3988 (($ $) 65)) (-3668 (((-3 |#2| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 (-568) "failed") $) NIL) (((-3 |#4| "failed") $) NIL) (((-3 |#3| "failed") $) 72)) (-1844 (((-763) $ |#3|) 39) (((-763) $) 36)) (-3029 (((-1 $ (-763)) |#3|) 15) (((-1 $ (-763)) $) 77)) (-1692 ((|#4| $) 58)) (-4448 (((-121) $) 56)) (-1484 (($ $) 64)) (-1339 (($ $ (-634 (-288 $))) 96) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ |#4| |#2|) NIL) (($ $ (-634 |#4|) (-634 |#2|)) NIL) (($ $ |#4| $) NIL) (($ $ (-634 |#4|) (-634 $)) NIL) (($ $ |#3| $) NIL) (($ $ (-634 |#3|) (-634 $)) 89) (($ $ |#3| |#2|) NIL) (($ $ (-634 |#3|) (-634 |#2|)) 84)) (-4191 (($ $ |#4|) NIL) (($ $ (-634 |#4|)) NIL) (($ $ |#4| (-763)) NIL) (($ $ (-634 |#4|) (-634 (-763))) NIL) (($ $) NIL) (($ $ (-763)) NIL) (($ $ (-1161)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) 32)) (-2775 (((-634 |#3|) $) 75)) (-1836 ((|#5| $) NIL) (((-763) $ |#4|) NIL) (((-634 (-763)) $ (-634 |#4|)) NIL) (((-763) $ |#3|) 44)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#2|) NIL) (($ |#4|) NIL) (($ |#3|) 67) (($ (-409 (-568))) NIL) (($ $) NIL))) 
+(((-245 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 -2747 (|#1| |#1|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -1339 (|#1| |#1| (-634 |#3|) (-634 |#2|))) (-15 -1339 (|#1| |#1| |#3| |#2|)) (-15 -1339 (|#1| |#1| (-634 |#3|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#3| |#1|)) (-15 -3029 ((-1 |#1| (-763)) |#1|)) (-15 -3988 (|#1| |#1|)) (-15 -1484 (|#1| |#1|)) (-15 -1692 (|#4| |#1|)) (-15 -4448 ((-121) |#1|)) (-15 -4308 ((-763) |#1| |#3|)) (-15 -2076 ((-634 (-763)) |#1| |#3|)) (-15 -4308 ((-763) |#1|)) (-15 -2076 ((-634 (-763)) |#1|)) (-15 -1836 ((-763) |#1| |#3|)) (-15 -1844 ((-763) |#1|)) (-15 -1844 ((-763) |#1| |#3|)) (-15 -2775 ((-634 |#3|) |#1|)) (-15 -3029 ((-1 |#1| (-763)) |#3|)) (-15 -3668 ((-3 |#3| "failed") |#1|)) (-15 -2747 (|#1| |#3|)) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -4191 (|#1| |#1| (-1161) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)))) (-15 -4191 (|#1| |#1| (-1161))) (-15 -4191 (|#1| |#1| (-763))) (-15 -4191 (|#1| |#1|)) (-15 -1836 ((-634 (-763)) |#1| (-634 |#4|))) (-15 -1836 ((-763) |#1| |#4|)) (-15 -3668 ((-3 |#4| "failed") |#1|)) (-15 -2747 (|#1| |#4|)) (-15 -1339 (|#1| |#1| (-634 |#4|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#4| |#1|)) (-15 -1339 (|#1| |#1| (-634 |#4|) (-634 |#2|))) (-15 -1339 (|#1| |#1| |#4| |#2|)) (-15 -1339 (|#1| |#1| (-634 |#1|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#1| |#1|)) (-15 -1339 (|#1| |#1| (-288 |#1|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -1836 (|#5| |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2747 (|#1| |#2|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -4191 (|#1| |#1| (-634 |#4|) (-634 (-763)))) (-15 -4191 (|#1| |#1| |#4| (-763))) (-15 -4191 (|#1| |#1| (-634 |#4|))) (-15 -4191 (|#1| |#1| |#4|)) (-15 -2747 (|#1| (-568))) (-15 -2747 ((-850) |#1|))) (-246 |#2| |#3| |#4| |#5|) (-1047) (-842) (-262 |#3|) (-788)) (T -245)) 
 NIL 
-(-10 -8 (-15 -2745 (|#1| |#1|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -1339 (|#1| |#1| (-634 |#3|) (-634 |#2|))) (-15 -1339 (|#1| |#1| |#3| |#2|)) (-15 -1339 (|#1| |#1| (-634 |#3|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#3| |#1|)) (-15 -4300 ((-1 |#1| (-763)) |#1|)) (-15 -4180 (|#1| |#1|)) (-15 -1484 (|#1| |#1|)) (-15 -1690 (|#4| |#1|)) (-15 -1989 ((-121) |#1|)) (-15 -1551 ((-763) |#1| |#3|)) (-15 -3902 ((-634 (-763)) |#1| |#3|)) (-15 -1551 ((-763) |#1|)) (-15 -3902 ((-634 (-763)) |#1|)) (-15 -3206 ((-763) |#1| |#3|)) (-15 -4477 ((-763) |#1|)) (-15 -4477 ((-763) |#1| |#3|)) (-15 -3795 ((-634 |#3|) |#1|)) (-15 -4300 ((-1 |#1| (-763)) |#3|)) (-15 -3666 ((-3 |#3| "failed") |#1|)) (-15 -2745 (|#1| |#3|)) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -4189 (|#1| |#1| (-1161) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)))) (-15 -4189 (|#1| |#1| (-1161))) (-15 -4189 (|#1| |#1| (-763))) (-15 -4189 (|#1| |#1|)) (-15 -3206 ((-634 (-763)) |#1| (-634 |#4|))) (-15 -3206 ((-763) |#1| |#4|)) (-15 -3666 ((-3 |#4| "failed") |#1|)) (-15 -2745 (|#1| |#4|)) (-15 -1339 (|#1| |#1| (-634 |#4|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#4| |#1|)) (-15 -1339 (|#1| |#1| (-634 |#4|) (-634 |#2|))) (-15 -1339 (|#1| |#1| |#4| |#2|)) (-15 -1339 (|#1| |#1| (-634 |#1|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#1| |#1|)) (-15 -1339 (|#1| |#1| (-288 |#1|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -3206 (|#5| |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2745 (|#1| |#2|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -4189 (|#1| |#1| (-634 |#4|) (-634 (-763)))) (-15 -4189 (|#1| |#1| |#4| (-763))) (-15 -4189 (|#1| |#1| (-634 |#4|))) (-15 -4189 (|#1| |#1| |#4|)) (-15 -2745 (|#1| (-568))) (-15 -2745 ((-850) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3902 (((-634 (-763)) $) 193) (((-634 (-763)) $ |#2|) 191)) (-1551 (((-763) $) 192) (((-763) $ |#2|) 190)) (-2055 (((-634 |#3|) $) 108)) (-3839 (((-1157 $) $ |#3|) 123) (((-1157 |#1|) $) 122)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 85 (|has| |#1| (-558)))) (-2227 (($ $) 86 (|has| |#1| (-558)))) (-1573 (((-121) $) 88 (|has| |#1| (-558)))) (-2773 (((-763) $) 110) (((-763) $ (-634 |#3|)) 109)) (-3134 (((-3 $ "failed") $ $) 18)) (-1750 (((-420 (-1157 $)) (-1157 $)) 98 (|has| |#1| (-904)))) (-4305 (($ $) 96 (|has| |#1| (-453)))) (-1678 (((-420 $) $) 95 (|has| |#1| (-453)))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 101 (|has| |#1| (-904)))) (-4180 (($ $) 186)) (-2671 (($) 16 T CONST)) (-3666 (((-3 |#1| "failed") $) 162) (((-3 (-409 (-568)) "failed") $) 160 (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) 158 (|has| |#1| (-1037 (-568)))) (((-3 |#3| "failed") $) 134) (((-3 |#2| "failed") $) 200)) (-2854 ((|#1| $) 163) (((-409 (-568)) $) 159 (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) 157 (|has| |#1| (-1037 (-568)))) ((|#3| $) 133) ((|#2| $) 199)) (-4265 (($ $ $ |#3|) 106 (|has| |#1| (-172)))) (-2114 (($ $) 152)) (-3164 (((-679 (-568)) (-679 $)) 132 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 131 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 130) (((-679 |#1|) (-679 $)) 129)) (-2925 (((-3 $ "failed") $) 33)) (-3250 (($ $) 174 (|has| |#1| (-453))) (($ $ |#3|) 103 (|has| |#1| (-453)))) (-2108 (((-634 $) $) 107)) (-3927 (((-121) $) 94 (|has| |#1| (-904)))) (-3088 (($ $ |#1| |#4| $) 170)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 82 (-12 (|has| |#3| (-881 (-381))) (|has| |#1| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 81 (-12 (|has| |#3| (-881 (-568))) (|has| |#1| (-881 (-568)))))) (-4477 (((-763) $ |#2|) 196) (((-763) $) 195)) (-2735 (((-121) $) 30)) (-4178 (((-763) $) 167)) (-2051 (($ (-1157 |#1|) |#3|) 115) (($ (-1157 $) |#3|) 114)) (-2976 (((-634 $) $) 124)) (-3921 (((-121) $) 150)) (-2047 (($ |#1| |#4|) 151) (($ $ |#3| (-763)) 117) (($ $ (-634 |#3|) (-634 (-763))) 116)) (-3379 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $ |#3|) 118)) (-2144 ((|#4| $) 168) (((-763) $ |#3|) 120) (((-634 (-763)) $ (-634 |#3|)) 119)) (-2521 (($ $ $) 77 (|has| |#1| (-842)))) (-3268 (($ $ $) 76 (|has| |#1| (-842)))) (-3842 (($ (-1 |#4| |#4|) $) 169)) (-2795 (($ (-1 |#1| |#1|) $) 149)) (-4300 (((-1 $ (-763)) |#2|) 198) (((-1 $ (-763)) $) 185 (|has| |#1| (-225)))) (-2244 (((-3 |#3| "failed") $) 121)) (-2097 (($ $) 147)) (-2102 ((|#1| $) 146)) (-1690 ((|#3| $) 188)) (-2495 (($ (-634 $)) 92 (|has| |#1| (-453))) (($ $ $) 91 (|has| |#1| (-453)))) (-4487 (((-1143) $) 9)) (-1989 (((-121) $) 189)) (-3324 (((-3 (-634 $) "failed") $) 112)) (-1794 (((-3 (-634 $) "failed") $) 113)) (-3751 (((-3 (-2 (|:| |var| |#3|) (|:| -3438 (-763))) "failed") $) 111)) (-1484 (($ $) 187)) (-4022 (((-1108) $) 10)) (-2086 (((-121) $) 164)) (-2091 ((|#1| $) 165)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 93 (|has| |#1| (-453)))) (-2721 (($ (-634 $)) 90 (|has| |#1| (-453))) (($ $ $) 89 (|has| |#1| (-453)))) (-2905 (((-420 (-1157 $)) (-1157 $)) 100 (|has| |#1| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) 99 (|has| |#1| (-904)))) (-3848 (((-420 $) $) 97 (|has| |#1| (-904)))) (-2595 (((-3 $ "failed") $ |#1|) 172 (|has| |#1| (-558))) (((-3 $ "failed") $ $) 84 (|has| |#1| (-558)))) (-1339 (($ $ (-634 (-288 $))) 143) (($ $ (-288 $)) 142) (($ $ $ $) 141) (($ $ (-634 $) (-634 $)) 140) (($ $ |#3| |#1|) 139) (($ $ (-634 |#3|) (-634 |#1|)) 138) (($ $ |#3| $) 137) (($ $ (-634 |#3|) (-634 $)) 136) (($ $ |#2| $) 184 (|has| |#1| (-225))) (($ $ (-634 |#2|) (-634 $)) 183 (|has| |#1| (-225))) (($ $ |#2| |#1|) 182 (|has| |#1| (-225))) (($ $ (-634 |#2|) (-634 |#1|)) 181 (|has| |#1| (-225)))) (-2217 (($ $ |#3|) 105 (|has| |#1| (-172)))) (-4189 (($ $ |#3|) 41) (($ $ (-634 |#3|)) 40) (($ $ |#3| (-763)) 39) (($ $ (-634 |#3|) (-634 (-763))) 38) (($ $) 217 (|has| |#1| (-225))) (($ $ (-763)) 215 (|has| |#1| (-225))) (($ $ (-1161)) 213 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 212 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 211 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) 210 (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) 203) (($ $ (-1 |#1| |#1|)) 202)) (-3795 (((-634 |#2|) $) 197)) (-3206 ((|#4| $) 148) (((-763) $ |#3|) 128) (((-634 (-763)) $ (-634 |#3|)) 127) (((-763) $ |#2|) 194)) (-4278 (((-887 (-381)) $) 80 (-12 (|has| |#3| (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381)))))) (((-887 (-568)) $) 79 (-12 (|has| |#3| (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568)))))) (((-541) $) 78 (-12 (|has| |#3| (-609 (-541))) (|has| |#1| (-609 (-541)))))) (-3367 ((|#1| $) 173 (|has| |#1| (-453))) (($ $ |#3|) 104 (|has| |#1| (-453)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) 102 (-2139 (|has| $ (-148)) (|has| |#1| (-904))))) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 161) (($ |#3|) 135) (($ |#2|) 201) (($ (-409 (-568))) 70 (-2198 (|has| |#1| (-1037 (-409 (-568)))) (|has| |#1| (-43 (-409 (-568)))))) (($ $) 83 (|has| |#1| (-558)))) (-1302 (((-634 |#1|) $) 166)) (-2604 ((|#1| $ |#4|) 153) (($ $ |#3| (-763)) 126) (($ $ (-634 |#3|) (-634 (-763))) 125)) (-4371 (((-3 $ "failed") $) 71 (-2198 (-2139 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-4078 (((-763)) 28)) (-4171 (($ $ $ (-763)) 171 (|has| |#1| (-172)))) (-1826 (((-121) $ $) 87 (|has| |#1| (-558)))) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $ |#3|) 37) (($ $ (-634 |#3|)) 36) (($ $ |#3| (-763)) 35) (($ $ (-634 |#3|) (-634 (-763))) 34) (($ $) 216 (|has| |#1| (-225))) (($ $ (-763)) 214 (|has| |#1| (-225))) (($ $ (-1161)) 209 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 208 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 207 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) 206 (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) 205) (($ $ (-1 |#1| |#1|)) 204)) (-1751 (((-121) $ $) 74 (|has| |#1| (-842)))) (-1738 (((-121) $ $) 73 (|has| |#1| (-842)))) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 75 (|has| |#1| (-842)))) (-1732 (((-121) $ $) 72 (|has| |#1| (-842)))) (-1779 (($ $ |#1|) 154 (|has| |#1| (-365)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 156 (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) 155 (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) 145) (($ $ |#1|) 144))) 
+(-10 -8 (-15 -2747 (|#1| |#1|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -1339 (|#1| |#1| (-634 |#3|) (-634 |#2|))) (-15 -1339 (|#1| |#1| |#3| |#2|)) (-15 -1339 (|#1| |#1| (-634 |#3|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#3| |#1|)) (-15 -3029 ((-1 |#1| (-763)) |#1|)) (-15 -3988 (|#1| |#1|)) (-15 -1484 (|#1| |#1|)) (-15 -1692 (|#4| |#1|)) (-15 -4448 ((-121) |#1|)) (-15 -4308 ((-763) |#1| |#3|)) (-15 -2076 ((-634 (-763)) |#1| |#3|)) (-15 -4308 ((-763) |#1|)) (-15 -2076 ((-634 (-763)) |#1|)) (-15 -1836 ((-763) |#1| |#3|)) (-15 -1844 ((-763) |#1|)) (-15 -1844 ((-763) |#1| |#3|)) (-15 -2775 ((-634 |#3|) |#1|)) (-15 -3029 ((-1 |#1| (-763)) |#3|)) (-15 -3668 ((-3 |#3| "failed") |#1|)) (-15 -2747 (|#1| |#3|)) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -4191 (|#1| |#1| (-1161) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)))) (-15 -4191 (|#1| |#1| (-1161))) (-15 -4191 (|#1| |#1| (-763))) (-15 -4191 (|#1| |#1|)) (-15 -1836 ((-634 (-763)) |#1| (-634 |#4|))) (-15 -1836 ((-763) |#1| |#4|)) (-15 -3668 ((-3 |#4| "failed") |#1|)) (-15 -2747 (|#1| |#4|)) (-15 -1339 (|#1| |#1| (-634 |#4|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#4| |#1|)) (-15 -1339 (|#1| |#1| (-634 |#4|) (-634 |#2|))) (-15 -1339 (|#1| |#1| |#4| |#2|)) (-15 -1339 (|#1| |#1| (-634 |#1|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#1| |#1|)) (-15 -1339 (|#1| |#1| (-288 |#1|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -1836 (|#5| |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2747 (|#1| |#2|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -4191 (|#1| |#1| (-634 |#4|) (-634 (-763)))) (-15 -4191 (|#1| |#1| |#4| (-763))) (-15 -4191 (|#1| |#1| (-634 |#4|))) (-15 -4191 (|#1| |#1| |#4|)) (-15 -2747 (|#1| (-568))) (-15 -2747 ((-850) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2076 (((-634 (-763)) $) 193) (((-634 (-763)) $ |#2|) 191)) (-4308 (((-763) $) 192) (((-763) $ |#2|) 190)) (-2057 (((-634 |#3|) $) 108)) (-3840 (((-1157 $) $ |#3|) 123) (((-1157 |#1|) $) 122)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 85 (|has| |#1| (-558)))) (-3661 (($ $) 86 (|has| |#1| (-558)))) (-4426 (((-121) $) 88 (|has| |#1| (-558)))) (-3528 (((-763) $) 110) (((-763) $ (-634 |#3|)) 109)) (-2689 (((-3 $ "failed") $ $) 18)) (-3863 (((-420 (-1157 $)) (-1157 $)) 98 (|has| |#1| (-904)))) (-3045 (($ $) 96 (|has| |#1| (-453)))) (-3498 (((-420 $) $) 95 (|has| |#1| (-453)))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 101 (|has| |#1| (-904)))) (-3988 (($ $) 186)) (-4490 (($) 16 T CONST)) (-3668 (((-3 |#1| "failed") $) 162) (((-3 (-409 (-568)) "failed") $) 160 (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) 158 (|has| |#1| (-1037 (-568)))) (((-3 |#3| "failed") $) 134) (((-3 |#2| "failed") $) 200)) (-2857 ((|#1| $) 163) (((-409 (-568)) $) 159 (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) 157 (|has| |#1| (-1037 (-568)))) ((|#3| $) 133) ((|#2| $) 199)) (-2910 (($ $ $ |#3|) 106 (|has| |#1| (-172)))) (-2116 (($ $) 152)) (-1668 (((-679 (-568)) (-679 $)) 132 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 131 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 130) (((-679 |#1|) (-679 $)) 129)) (-2902 (((-3 $ "failed") $) 33)) (-1998 (($ $) 174 (|has| |#1| (-453))) (($ $ |#3|) 103 (|has| |#1| (-453)))) (-2110 (((-634 $) $) 107)) (-2197 (((-121) $) 94 (|has| |#1| (-904)))) (-2453 (($ $ |#1| |#4| $) 170)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 82 (-12 (|has| |#3| (-881 (-381))) (|has| |#1| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 81 (-12 (|has| |#3| (-881 (-568))) (|has| |#1| (-881 (-568)))))) (-1844 (((-763) $ |#2|) 196) (((-763) $) 195)) (-1598 (((-121) $) 30)) (-3971 (((-763) $) 167)) (-2053 (($ (-1157 |#1|) |#3|) 115) (($ (-1157 $) |#3|) 114)) (-3062 (((-634 $) $) 124)) (-2171 (((-121) $) 150)) (-2049 (($ |#1| |#4|) 151) (($ $ |#3| (-763)) 117) (($ $ (-634 |#3|) (-634 (-763))) 116)) (-1438 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $ |#3|) 118)) (-3524 ((|#4| $) 168) (((-763) $ |#3|) 120) (((-634 (-763)) $ (-634 |#3|)) 119)) (-1732 (($ $ $) 77 (|has| |#1| (-842)))) (-2047 (($ $ $) 76 (|has| |#1| (-842)))) (-1865 (($ (-1 |#4| |#4|) $) 169)) (-2797 (($ (-1 |#1| |#1|) $) 149)) (-3029 (((-1 $ (-763)) |#2|) 198) (((-1 $ (-763)) $) 185 (|has| |#1| (-225)))) (-2817 (((-3 |#3| "failed") $) 121)) (-2099 (($ $) 147)) (-2104 ((|#1| $) 146)) (-1692 ((|#3| $) 188)) (-2498 (($ (-634 $)) 92 (|has| |#1| (-453))) (($ $ $) 91 (|has| |#1| (-453)))) (-1893 (((-1143) $) 9)) (-4448 (((-121) $) 189)) (-4362 (((-3 (-634 $) "failed") $) 112)) (-2112 (((-3 (-634 $) "failed") $) 113)) (-2617 (((-3 (-2 (|:| |var| |#3|) (|:| -3483 (-763))) "failed") $) 111)) (-1484 (($ $) 187)) (-4025 (((-1108) $) 10)) (-2088 (((-121) $) 164)) (-2093 ((|#1| $) 165)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 93 (|has| |#1| (-453)))) (-2723 (($ (-634 $)) 90 (|has| |#1| (-453))) (($ $ $) 89 (|has| |#1| (-453)))) (-2841 (((-420 (-1157 $)) (-1157 $)) 100 (|has| |#1| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) 99 (|has| |#1| (-904)))) (-3850 (((-420 $) $) 97 (|has| |#1| (-904)))) (-2597 (((-3 $ "failed") $ |#1|) 172 (|has| |#1| (-558))) (((-3 $ "failed") $ $) 84 (|has| |#1| (-558)))) (-1339 (($ $ (-634 (-288 $))) 143) (($ $ (-288 $)) 142) (($ $ $ $) 141) (($ $ (-634 $) (-634 $)) 140) (($ $ |#3| |#1|) 139) (($ $ (-634 |#3|) (-634 |#1|)) 138) (($ $ |#3| $) 137) (($ $ (-634 |#3|) (-634 $)) 136) (($ $ |#2| $) 184 (|has| |#1| (-225))) (($ $ (-634 |#2|) (-634 $)) 183 (|has| |#1| (-225))) (($ $ |#2| |#1|) 182 (|has| |#1| (-225))) (($ $ (-634 |#2|) (-634 |#1|)) 181 (|has| |#1| (-225)))) (-3440 (($ $ |#3|) 105 (|has| |#1| (-172)))) (-4191 (($ $ |#3|) 41) (($ $ (-634 |#3|)) 40) (($ $ |#3| (-763)) 39) (($ $ (-634 |#3|) (-634 (-763))) 38) (($ $) 217 (|has| |#1| (-225))) (($ $ (-763)) 215 (|has| |#1| (-225))) (($ $ (-1161)) 213 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 212 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 211 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) 210 (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) 203) (($ $ (-1 |#1| |#1|)) 202)) (-2775 (((-634 |#2|) $) 197)) (-1836 ((|#4| $) 148) (((-763) $ |#3|) 128) (((-634 (-763)) $ (-634 |#3|)) 127) (((-763) $ |#2|) 194)) (-4280 (((-887 (-381)) $) 80 (-12 (|has| |#3| (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381)))))) (((-887 (-568)) $) 79 (-12 (|has| |#3| (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568)))))) (((-541) $) 78 (-12 (|has| |#3| (-609 (-541))) (|has| |#1| (-609 (-541)))))) (-1364 ((|#1| $) 173 (|has| |#1| (-453))) (($ $ |#3|) 104 (|has| |#1| (-453)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) 102 (-2141 (|has| $ (-148)) (|has| |#1| (-904))))) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 161) (($ |#3|) 135) (($ |#2|) 201) (($ (-409 (-568))) 70 (-2199 (|has| |#1| (-1037 (-409 (-568)))) (|has| |#1| (-43 (-409 (-568)))))) (($ $) 83 (|has| |#1| (-558)))) (-3304 (((-634 |#1|) $) 166)) (-2079 ((|#1| $ |#4|) 153) (($ $ |#3| (-763)) 126) (($ $ (-634 |#3|) (-634 (-763))) 125)) (-3385 (((-3 $ "failed") $) 71 (-2199 (-2141 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-3425 (((-763)) 28)) (-3925 (($ $ $ (-763)) 171 (|has| |#1| (-172)))) (-2273 (((-121) $ $) 87 (|has| |#1| (-558)))) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $ |#3|) 37) (($ $ (-634 |#3|)) 36) (($ $ |#3| (-763)) 35) (($ $ (-634 |#3|) (-634 (-763))) 34) (($ $) 216 (|has| |#1| (-225))) (($ $ (-763)) 214 (|has| |#1| (-225))) (($ $ (-1161)) 209 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 208 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 207 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) 206 (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) 205) (($ $ (-1 |#1| |#1|)) 204)) (-1753 (((-121) $ $) 74 (|has| |#1| (-842)))) (-1740 (((-121) $ $) 73 (|has| |#1| (-842)))) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 75 (|has| |#1| (-842)))) (-1734 (((-121) $ $) 72 (|has| |#1| (-842)))) (-1781 (($ $ |#1|) 154 (|has| |#1| (-365)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 156 (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) 155 (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) 145) (($ $ |#1|) 144))) 
 (((-246 |#1| |#2| |#3| |#4|) (-1275) (-1047) (-842) (-262 |t#2|) (-788)) (T -246)) 
-((-4300 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *3 (-842)) (-4 *5 (-262 *3)) (-4 *6 (-788)) (-5 *2 (-1 *1 (-763))) (-4 *1 (-246 *4 *3 *5 *6)))) (-3795 (*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-634 *4)))) (-4477 (*1 *2 *1 *3) (-12 (-4 *1 (-246 *4 *3 *5 *6)) (-4 *4 (-1047)) (-4 *3 (-842)) (-4 *5 (-262 *3)) (-4 *6 (-788)) (-5 *2 (-763)))) (-4477 (*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-763)))) (-3206 (*1 *2 *1 *3) (-12 (-4 *1 (-246 *4 *3 *5 *6)) (-4 *4 (-1047)) (-4 *3 (-842)) (-4 *5 (-262 *3)) (-4 *6 (-788)) (-5 *2 (-763)))) (-3902 (*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-634 (-763))))) (-1551 (*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-763)))) (-3902 (*1 *2 *1 *3) (-12 (-4 *1 (-246 *4 *3 *5 *6)) (-4 *4 (-1047)) (-4 *3 (-842)) (-4 *5 (-262 *3)) (-4 *6 (-788)) (-5 *2 (-634 (-763))))) (-1551 (*1 *2 *1 *3) (-12 (-4 *1 (-246 *4 *3 *5 *6)) (-4 *4 (-1047)) (-4 *3 (-842)) (-4 *5 (-262 *3)) (-4 *6 (-788)) (-5 *2 (-763)))) (-1989 (*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-121)))) (-1690 (*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *2 *5)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-788)) (-4 *2 (-262 *4)))) (-1484 (*1 *1 *1) (-12 (-4 *1 (-246 *2 *3 *4 *5)) (-4 *2 (-1047)) (-4 *3 (-842)) (-4 *4 (-262 *3)) (-4 *5 (-788)))) (-4180 (*1 *1 *1) (-12 (-4 *1 (-246 *2 *3 *4 *5)) (-4 *2 (-1047)) (-4 *3 (-842)) (-4 *4 (-262 *3)) (-4 *5 (-788)))) (-4300 (*1 *2 *1) (-12 (-4 *3 (-225)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-1 *1 (-763))) (-4 *1 (-246 *3 *4 *5 *6))))) 
-(-13 (-950 |t#1| |t#4| |t#3|) (-223 |t#1|) (-1037 |t#2|) (-10 -8 (-15 -4300 ((-1 $ (-763)) |t#2|)) (-15 -3795 ((-634 |t#2|) $)) (-15 -4477 ((-763) $ |t#2|)) (-15 -4477 ((-763) $)) (-15 -3206 ((-763) $ |t#2|)) (-15 -3902 ((-634 (-763)) $)) (-15 -1551 ((-763) $)) (-15 -3902 ((-634 (-763)) $ |t#2|)) (-15 -1551 ((-763) $ |t#2|)) (-15 -1989 ((-121) $)) (-15 -1690 (|t#3| $)) (-15 -1484 ($ $)) (-15 -4180 ($ $)) (IF (|has| |t#1| (-225)) (PROGN (-6 (-523 |t#2| |t#1|)) (-6 (-523 |t#2| $)) (-6 (-303 $)) (-15 -4300 ((-1 $ (-763)) $))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| |#4|) . T) ((-25) . T) ((-43 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-172))) ((-609 (-541)) -12 (|has| |#1| (-609 (-541))) (|has| |#3| (-609 (-541)))) ((-609 (-887 (-381))) -12 (|has| |#1| (-609 (-887 (-381)))) (|has| |#3| (-609 (-887 (-381))))) ((-609 (-887 (-568))) -12 (|has| |#1| (-609 (-887 (-568)))) (|has| |#3| (-609 (-887 (-568))))) ((-223 |#1|) . T) ((-225) |has| |#1| (-225)) ((-285) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-303 $) . T) ((-324 |#1| |#4|) . T) ((-379 |#1|) . T) ((-413 |#1|) . T) ((-453) -2198 (|has| |#1| (-904)) (|has| |#1| (-453))) ((-523 |#2| |#1|) |has| |#1| (-225)) ((-523 |#2| $) |has| |#1| (-225)) ((-523 |#3| |#1|) . T) ((-523 |#3| $) . T) ((-523 $ $) . T) ((-558) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-637 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-637 |#1|) . T) ((-637 $) . T) ((-630 (-568)) |has| |#1| (-630 (-568))) ((-630 |#1|) . T) ((-707 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-716) . T) ((-842) |has| |#1| (-842)) ((-895 (-1161)) |has| |#1| (-895 (-1161))) ((-895 |#3|) . T) ((-881 (-381)) -12 (|has| |#1| (-881 (-381))) (|has| |#3| (-881 (-381)))) ((-881 (-568)) -12 (|has| |#1| (-881 (-568))) (|has| |#3| (-881 (-568)))) ((-950 |#1| |#4| |#3|) . T) ((-904) |has| |#1| (-904)) ((-1037 (-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 |#1|) . T) ((-1037 |#2|) . T) ((-1037 |#3|) . T) ((-1053 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-1053 |#1|) . T) ((-1053 $) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1199) |has| |#1| (-904))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-1815 ((|#1| $) 51)) (-2616 ((|#1| $) 41)) (-2510 (((-121) $ (-763)) 8)) (-2671 (($) 7 T CONST)) (-3475 (($ $) 57)) (-1578 (($ $) 45)) (-2918 ((|#1| |#1| $) 43)) (-2899 ((|#1| $) 42)) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) 9)) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35)) (-2166 (((-121) $ (-763)) 10)) (-3678 (((-763) $) 58)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-1890 ((|#1| $) 36)) (-1871 ((|#1| |#1| $) 49)) (-4308 ((|#1| |#1| $) 48)) (-4450 (($ |#1| $) 37)) (-2961 (((-763) $) 52)) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3860 ((|#1| $) 59)) (-2216 ((|#1| $) 47)) (-3923 ((|#1| $) 46)) (-1315 ((|#1| $) 38)) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-1383 ((|#1| |#1| $) 55)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2368 ((|#1| $) 56)) (-1612 (($) 54) (($ (-634 |#1|)) 53)) (-4154 (((-763) $) 40)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-3286 ((|#1| $) 50)) (-2367 (($ (-634 |#1|)) 39)) (-4190 ((|#1| $) 60)) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-3029 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *3 (-842)) (-4 *5 (-262 *3)) (-4 *6 (-788)) (-5 *2 (-1 *1 (-763))) (-4 *1 (-246 *4 *3 *5 *6)))) (-2775 (*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-634 *4)))) (-1844 (*1 *2 *1 *3) (-12 (-4 *1 (-246 *4 *3 *5 *6)) (-4 *4 (-1047)) (-4 *3 (-842)) (-4 *5 (-262 *3)) (-4 *6 (-788)) (-5 *2 (-763)))) (-1844 (*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-763)))) (-1836 (*1 *2 *1 *3) (-12 (-4 *1 (-246 *4 *3 *5 *6)) (-4 *4 (-1047)) (-4 *3 (-842)) (-4 *5 (-262 *3)) (-4 *6 (-788)) (-5 *2 (-763)))) (-2076 (*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-634 (-763))))) (-4308 (*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-763)))) (-2076 (*1 *2 *1 *3) (-12 (-4 *1 (-246 *4 *3 *5 *6)) (-4 *4 (-1047)) (-4 *3 (-842)) (-4 *5 (-262 *3)) (-4 *6 (-788)) (-5 *2 (-634 (-763))))) (-4308 (*1 *2 *1 *3) (-12 (-4 *1 (-246 *4 *3 *5 *6)) (-4 *4 (-1047)) (-4 *3 (-842)) (-4 *5 (-262 *3)) (-4 *6 (-788)) (-5 *2 (-763)))) (-4448 (*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-121)))) (-1692 (*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *2 *5)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-788)) (-4 *2 (-262 *4)))) (-1484 (*1 *1 *1) (-12 (-4 *1 (-246 *2 *3 *4 *5)) (-4 *2 (-1047)) (-4 *3 (-842)) (-4 *4 (-262 *3)) (-4 *5 (-788)))) (-3988 (*1 *1 *1) (-12 (-4 *1 (-246 *2 *3 *4 *5)) (-4 *2 (-1047)) (-4 *3 (-842)) (-4 *4 (-262 *3)) (-4 *5 (-788)))) (-3029 (*1 *2 *1) (-12 (-4 *3 (-225)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-1 *1 (-763))) (-4 *1 (-246 *3 *4 *5 *6))))) 
+(-13 (-950 |t#1| |t#4| |t#3|) (-223 |t#1|) (-1037 |t#2|) (-10 -8 (-15 -3029 ((-1 $ (-763)) |t#2|)) (-15 -2775 ((-634 |t#2|) $)) (-15 -1844 ((-763) $ |t#2|)) (-15 -1844 ((-763) $)) (-15 -1836 ((-763) $ |t#2|)) (-15 -2076 ((-634 (-763)) $)) (-15 -4308 ((-763) $)) (-15 -2076 ((-634 (-763)) $ |t#2|)) (-15 -4308 ((-763) $ |t#2|)) (-15 -4448 ((-121) $)) (-15 -1692 (|t#3| $)) (-15 -1484 ($ $)) (-15 -3988 ($ $)) (IF (|has| |t#1| (-225)) (PROGN (-6 (-523 |t#2| |t#1|)) (-6 (-523 |t#2| $)) (-6 (-303 $)) (-15 -3029 ((-1 $ (-763)) $))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| |#4|) . T) ((-25) . T) ((-43 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-172))) ((-609 (-541)) -12 (|has| |#1| (-609 (-541))) (|has| |#3| (-609 (-541)))) ((-609 (-887 (-381))) -12 (|has| |#1| (-609 (-887 (-381)))) (|has| |#3| (-609 (-887 (-381))))) ((-609 (-887 (-568))) -12 (|has| |#1| (-609 (-887 (-568)))) (|has| |#3| (-609 (-887 (-568))))) ((-223 |#1|) . T) ((-225) |has| |#1| (-225)) ((-285) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-303 $) . T) ((-324 |#1| |#4|) . T) ((-379 |#1|) . T) ((-413 |#1|) . T) ((-453) -2199 (|has| |#1| (-904)) (|has| |#1| (-453))) ((-523 |#2| |#1|) |has| |#1| (-225)) ((-523 |#2| $) |has| |#1| (-225)) ((-523 |#3| |#1|) . T) ((-523 |#3| $) . T) ((-523 $ $) . T) ((-558) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-637 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-637 |#1|) . T) ((-637 $) . T) ((-630 (-568)) |has| |#1| (-630 (-568))) ((-630 |#1|) . T) ((-707 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-716) . T) ((-842) |has| |#1| (-842)) ((-895 (-1161)) |has| |#1| (-895 (-1161))) ((-895 |#3|) . T) ((-881 (-381)) -12 (|has| |#1| (-881 (-381))) (|has| |#3| (-881 (-381)))) ((-881 (-568)) -12 (|has| |#1| (-881 (-568))) (|has| |#3| (-881 (-568)))) ((-950 |#1| |#4| |#3|) . T) ((-904) |has| |#1| (-904)) ((-1037 (-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 |#1|) . T) ((-1037 |#2|) . T) ((-1037 |#3|) . T) ((-1053 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-1053 |#1|) . T) ((-1053 $) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1199) |has| |#1| (-904))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2212 ((|#1| $) 51)) (-2618 ((|#1| $) 41)) (-1667 (((-121) $ (-763)) 8)) (-4490 (($) 7 T CONST)) (-3743 (($ $) 57)) (-4452 (($ $) 45)) (-2885 ((|#1| |#1| $) 43)) (-2819 ((|#1| $) 42)) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) 9)) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35)) (-3796 (((-121) $ (-763)) 10)) (-3680 (((-763) $) 58)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-2580 ((|#1| $) 36)) (-2487 ((|#1| |#1| $) 49)) (-3055 ((|#1| |#1| $) 48)) (-1708 (($ |#1| $) 37)) (-2963 (((-763) $) 52)) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-1929 ((|#1| $) 59)) (-3430 ((|#1| $) 47)) (-2180 ((|#1| $) 46)) (-3403 ((|#1| $) 38)) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-3920 ((|#1| |#1| $) 55)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-4080 ((|#1| $) 56)) (-1403 (($) 54) (($ (-634 |#1|)) 53)) (-4156 (((-763) $) 40)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-2120 ((|#1| $) 50)) (-4074 (($ (-634 |#1|)) 39)) (-4035 ((|#1| $) 60)) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-247 |#1|) (-1275) (-1195)) (T -247)) 
-((-1612 (*1 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195)))) (-1612 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-4 *1 (-247 *3)))) (-2961 (*1 *2 *1) (-12 (-4 *1 (-247 *3)) (-4 *3 (-1195)) (-5 *2 (-763)))) (-1815 (*1 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195)))) (-3286 (*1 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195)))) (-1871 (*1 *2 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195)))) (-4308 (*1 *2 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195)))) (-2216 (*1 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195)))) (-3923 (*1 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195)))) (-1578 (*1 *1 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195))))) 
-(-13 (-1109 |t#1|) (-995 |t#1|) (-10 -8 (-15 -1612 ($)) (-15 -1612 ($ (-634 |t#1|))) (-15 -2961 ((-763) $)) (-15 -1815 (|t#1| $)) (-15 -3286 (|t#1| $)) (-15 -1871 (|t#1| |t#1| $)) (-15 -4308 (|t#1| |t#1| $)) (-15 -2216 (|t#1| $)) (-15 -3923 (|t#1| $)) (-15 -1578 ($ $)))) 
+((-1403 (*1 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195)))) (-1403 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-4 *1 (-247 *3)))) (-2963 (*1 *2 *1) (-12 (-4 *1 (-247 *3)) (-4 *3 (-1195)) (-5 *2 (-763)))) (-2212 (*1 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195)))) (-2120 (*1 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195)))) (-2487 (*1 *2 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195)))) (-3055 (*1 *2 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195)))) (-3430 (*1 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195)))) (-2180 (*1 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195)))) (-4452 (*1 *1 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195))))) 
+(-13 (-1109 |t#1|) (-995 |t#1|) (-10 -8 (-15 -1403 ($)) (-15 -1403 ($ (-634 |t#1|))) (-15 -2963 ((-763) $)) (-15 -2212 (|t#1| $)) (-15 -2120 (|t#1| $)) (-15 -2487 (|t#1| |t#1| $)) (-15 -3055 (|t#1| |t#1| $)) (-15 -3430 (|t#1| $)) (-15 -2180 (|t#1| $)) (-15 -4452 ($ $)))) 
 (((-39) . T) ((-111 |#1|) . T) ((-105) |has| |#1| (-1090)) ((-608 (-850)) |has| |#1| (-1090)) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-995 |#1|) . T) ((-1090) |has| |#1| (-1090)) ((-1109 |#1|) . T) ((-1195) . T)) 
-((-2339 (((-1 (-944 (-215)) (-215) (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1 (-215) (-215) (-215) (-215))) 139)) (-2342 (((-1121 (-215)) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381))) 160) (((-1121 (-215)) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381)) (-634 (-256))) 158) (((-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381))) 163) (((-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256))) 159) (((-1121 (-215)) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381))) 150) (((-1121 (-215)) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256))) 149) (((-1121 (-215)) (-1 (-944 (-215)) (-215)) (-1084 (-381))) 129) (((-1121 (-215)) (-1 (-944 (-215)) (-215)) (-1084 (-381)) (-634 (-256))) 127) (((-1121 (-215)) (-875 (-1 (-215) (-215))) (-1084 (-381))) 128) (((-1121 (-215)) (-875 (-1 (-215) (-215))) (-1084 (-381)) (-634 (-256))) 125)) (-2336 (((-1246) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381))) 162) (((-1246) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381)) (-634 (-256))) 161) (((-1246) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381))) 165) (((-1246) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256))) 164) (((-1246) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381))) 152) (((-1246) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256))) 151) (((-1246) (-1 (-944 (-215)) (-215)) (-1084 (-381))) 135) (((-1246) (-1 (-944 (-215)) (-215)) (-1084 (-381)) (-634 (-256))) 134) (((-1246) (-875 (-1 (-215) (-215))) (-1084 (-381))) 133) (((-1246) (-875 (-1 (-215) (-215))) (-1084 (-381)) (-634 (-256))) 132) (((-1245) (-873 (-1 (-215) (-215))) (-1084 (-381))) 99) (((-1245) (-873 (-1 (-215) (-215))) (-1084 (-381)) (-634 (-256))) 98) (((-1245) (-1 (-215) (-215)) (-1084 (-381))) 95) (((-1245) (-1 (-215) (-215)) (-1084 (-381)) (-634 (-256))) 94))) 
-(((-248) (-10 -7 (-15 -2336 ((-1245) (-1 (-215) (-215)) (-1084 (-381)) (-634 (-256)))) (-15 -2336 ((-1245) (-1 (-215) (-215)) (-1084 (-381)))) (-15 -2336 ((-1245) (-873 (-1 (-215) (-215))) (-1084 (-381)) (-634 (-256)))) (-15 -2336 ((-1245) (-873 (-1 (-215) (-215))) (-1084 (-381)))) (-15 -2336 ((-1246) (-875 (-1 (-215) (-215))) (-1084 (-381)) (-634 (-256)))) (-15 -2336 ((-1246) (-875 (-1 (-215) (-215))) (-1084 (-381)))) (-15 -2336 ((-1246) (-1 (-944 (-215)) (-215)) (-1084 (-381)) (-634 (-256)))) (-15 -2336 ((-1246) (-1 (-944 (-215)) (-215)) (-1084 (-381)))) (-15 -2342 ((-1121 (-215)) (-875 (-1 (-215) (-215))) (-1084 (-381)) (-634 (-256)))) (-15 -2342 ((-1121 (-215)) (-875 (-1 (-215) (-215))) (-1084 (-381)))) (-15 -2342 ((-1121 (-215)) (-1 (-944 (-215)) (-215)) (-1084 (-381)) (-634 (-256)))) (-15 -2342 ((-1121 (-215)) (-1 (-944 (-215)) (-215)) (-1084 (-381)))) (-15 -2336 ((-1246) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2336 ((-1246) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381)))) (-15 -2342 ((-1121 (-215)) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2342 ((-1121 (-215)) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381)))) (-15 -2336 ((-1246) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2336 ((-1246) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381)))) (-15 -2342 ((-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2342 ((-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381)))) (-15 -2336 ((-1246) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2336 ((-1246) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381)))) (-15 -2342 ((-1121 (-215)) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2342 ((-1121 (-215)) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381)))) (-15 -2339 ((-1 (-944 (-215)) (-215) (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1 (-215) (-215) (-215) (-215)))))) (T -248)) 
-((-2339 (*1 *2 *2 *3) (-12 (-5 *2 (-1 (-944 (-215)) (-215) (-215))) (-5 *3 (-1 (-215) (-215) (-215) (-215))) (-5 *1 (-248)))) (-2342 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-877 (-1 (-215) (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) (-2342 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-877 (-1 (-215) (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) (-2336 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-877 (-1 (-215) (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *2 (-1246)) (-5 *1 (-248)))) (-2336 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-877 (-1 (-215) (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-248)))) (-2342 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) (-2342 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) (-2336 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1246)) (-5 *1 (-248)))) (-2336 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-248)))) (-2342 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) (-2342 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) (-2336 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1246)) (-5 *1 (-248)))) (-2336 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-248)))) (-2342 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-944 (-215)) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) (-2342 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-944 (-215)) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) (-2342 (*1 *2 *3 *4) (-12 (-5 *3 (-875 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) (-2342 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-875 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) (-2336 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-944 (-215)) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1246)) (-5 *1 (-248)))) (-2336 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-944 (-215)) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-248)))) (-2336 (*1 *2 *3 *4) (-12 (-5 *3 (-875 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *2 (-1246)) (-5 *1 (-248)))) (-2336 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-875 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-248)))) (-2336 (*1 *2 *3 *4) (-12 (-5 *3 (-873 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *2 (-1245)) (-5 *1 (-248)))) (-2336 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-873 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-248)))) (-2336 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1245)) (-5 *1 (-248)))) (-2336 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-248))))) 
-(-10 -7 (-15 -2336 ((-1245) (-1 (-215) (-215)) (-1084 (-381)) (-634 (-256)))) (-15 -2336 ((-1245) (-1 (-215) (-215)) (-1084 (-381)))) (-15 -2336 ((-1245) (-873 (-1 (-215) (-215))) (-1084 (-381)) (-634 (-256)))) (-15 -2336 ((-1245) (-873 (-1 (-215) (-215))) (-1084 (-381)))) (-15 -2336 ((-1246) (-875 (-1 (-215) (-215))) (-1084 (-381)) (-634 (-256)))) (-15 -2336 ((-1246) (-875 (-1 (-215) (-215))) (-1084 (-381)))) (-15 -2336 ((-1246) (-1 (-944 (-215)) (-215)) (-1084 (-381)) (-634 (-256)))) (-15 -2336 ((-1246) (-1 (-944 (-215)) (-215)) (-1084 (-381)))) (-15 -2342 ((-1121 (-215)) (-875 (-1 (-215) (-215))) (-1084 (-381)) (-634 (-256)))) (-15 -2342 ((-1121 (-215)) (-875 (-1 (-215) (-215))) (-1084 (-381)))) (-15 -2342 ((-1121 (-215)) (-1 (-944 (-215)) (-215)) (-1084 (-381)) (-634 (-256)))) (-15 -2342 ((-1121 (-215)) (-1 (-944 (-215)) (-215)) (-1084 (-381)))) (-15 -2336 ((-1246) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2336 ((-1246) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381)))) (-15 -2342 ((-1121 (-215)) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2342 ((-1121 (-215)) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381)))) (-15 -2336 ((-1246) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2336 ((-1246) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381)))) (-15 -2342 ((-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2342 ((-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381)))) (-15 -2336 ((-1246) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2336 ((-1246) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381)))) (-15 -2342 ((-1121 (-215)) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2342 ((-1121 (-215)) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381)))) (-15 -2339 ((-1 (-944 (-215)) (-215) (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1 (-215) (-215) (-215) (-215))))) 
-((-2336 (((-1245) (-288 |#2|) (-1161) (-1161) (-634 (-256))) 93))) 
-(((-249 |#1| |#2|) (-10 -7 (-15 -2336 ((-1245) (-288 |#2|) (-1161) (-1161) (-634 (-256))))) (-13 (-558) (-842) (-1037 (-568))) (-432 |#1|)) (T -249)) 
-((-2336 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-288 *7)) (-5 *4 (-1161)) (-5 *5 (-634 (-256))) (-4 *7 (-432 *6)) (-4 *6 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-1245)) (-5 *1 (-249 *6 *7))))) 
-(-10 -7 (-15 -2336 ((-1245) (-288 |#2|) (-1161) (-1161) (-634 (-256))))) 
-((-3126 (((-568) (-568)) 50)) (-1865 (((-568) (-568)) 51)) (-1546 (((-215) (-215)) 52)) (-2290 (((-1246) (-1 (-169 (-215)) (-169 (-215))) (-1084 (-215)) (-1084 (-215))) 49)) (-4009 (((-1246) (-1 (-169 (-215)) (-169 (-215))) (-1084 (-215)) (-1084 (-215)) (-121)) 47))) 
-(((-250) (-10 -7 (-15 -4009 ((-1246) (-1 (-169 (-215)) (-169 (-215))) (-1084 (-215)) (-1084 (-215)) (-121))) (-15 -2290 ((-1246) (-1 (-169 (-215)) (-169 (-215))) (-1084 (-215)) (-1084 (-215)))) (-15 -3126 ((-568) (-568))) (-15 -1865 ((-568) (-568))) (-15 -1546 ((-215) (-215))))) (T -250)) 
-((-1546 (*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-250)))) (-1865 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-250)))) (-3126 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-250)))) (-2290 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-169 (-215)) (-169 (-215)))) (-5 *4 (-1084 (-215))) (-5 *2 (-1246)) (-5 *1 (-250)))) (-4009 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-169 (-215)) (-169 (-215)))) (-5 *4 (-1084 (-215))) (-5 *5 (-121)) (-5 *2 (-1246)) (-5 *1 (-250))))) 
-(-10 -7 (-15 -4009 ((-1246) (-1 (-169 (-215)) (-169 (-215))) (-1084 (-215)) (-1084 (-215)) (-121))) (-15 -2290 ((-1246) (-1 (-169 (-215)) (-169 (-215))) (-1084 (-215)) (-1084 (-215)))) (-15 -3126 ((-568) (-568))) (-15 -1865 ((-568) (-568))) (-15 -1546 ((-215) (-215)))) 
-((-2745 (((-1082 (-381)) (-1082 (-310 |#1|))) 16))) 
-(((-251 |#1|) (-10 -7 (-15 -2745 ((-1082 (-381)) (-1082 (-310 |#1|))))) (-13 (-842) (-558) (-609 (-381)))) (T -251)) 
-((-2745 (*1 *2 *3) (-12 (-5 *3 (-1082 (-310 *4))) (-4 *4 (-13 (-842) (-558) (-609 (-381)))) (-5 *2 (-1082 (-381))) (-5 *1 (-251 *4))))) 
-(-10 -7 (-15 -2745 ((-1082 (-381)) (-1082 (-310 |#1|))))) 
-((-2342 (((-1121 (-215)) (-877 |#1|) (-1082 (-381)) (-1082 (-381))) 69) (((-1121 (-215)) (-877 |#1|) (-1082 (-381)) (-1082 (-381)) (-634 (-256))) 68) (((-1121 (-215)) |#1| (-1082 (-381)) (-1082 (-381))) 59) (((-1121 (-215)) |#1| (-1082 (-381)) (-1082 (-381)) (-634 (-256))) 58) (((-1121 (-215)) (-875 |#1|) (-1082 (-381))) 50) (((-1121 (-215)) (-875 |#1|) (-1082 (-381)) (-634 (-256))) 49)) (-2336 (((-1246) (-877 |#1|) (-1082 (-381)) (-1082 (-381))) 72) (((-1246) (-877 |#1|) (-1082 (-381)) (-1082 (-381)) (-634 (-256))) 71) (((-1246) |#1| (-1082 (-381)) (-1082 (-381))) 62) (((-1246) |#1| (-1082 (-381)) (-1082 (-381)) (-634 (-256))) 61) (((-1246) (-875 |#1|) (-1082 (-381))) 54) (((-1246) (-875 |#1|) (-1082 (-381)) (-634 (-256))) 53) (((-1245) (-873 |#1|) (-1082 (-381))) 41) (((-1245) (-873 |#1|) (-1082 (-381)) (-634 (-256))) 40) (((-1245) |#1| (-1082 (-381))) 33) (((-1245) |#1| (-1082 (-381)) (-634 (-256))) 32))) 
-(((-252 |#1|) (-10 -7 (-15 -2336 ((-1245) |#1| (-1082 (-381)) (-634 (-256)))) (-15 -2336 ((-1245) |#1| (-1082 (-381)))) (-15 -2336 ((-1245) (-873 |#1|) (-1082 (-381)) (-634 (-256)))) (-15 -2336 ((-1245) (-873 |#1|) (-1082 (-381)))) (-15 -2336 ((-1246) (-875 |#1|) (-1082 (-381)) (-634 (-256)))) (-15 -2336 ((-1246) (-875 |#1|) (-1082 (-381)))) (-15 -2342 ((-1121 (-215)) (-875 |#1|) (-1082 (-381)) (-634 (-256)))) (-15 -2342 ((-1121 (-215)) (-875 |#1|) (-1082 (-381)))) (-15 -2336 ((-1246) |#1| (-1082 (-381)) (-1082 (-381)) (-634 (-256)))) (-15 -2336 ((-1246) |#1| (-1082 (-381)) (-1082 (-381)))) (-15 -2342 ((-1121 (-215)) |#1| (-1082 (-381)) (-1082 (-381)) (-634 (-256)))) (-15 -2342 ((-1121 (-215)) |#1| (-1082 (-381)) (-1082 (-381)))) (-15 -2336 ((-1246) (-877 |#1|) (-1082 (-381)) (-1082 (-381)) (-634 (-256)))) (-15 -2336 ((-1246) (-877 |#1|) (-1082 (-381)) (-1082 (-381)))) (-15 -2342 ((-1121 (-215)) (-877 |#1|) (-1082 (-381)) (-1082 (-381)) (-634 (-256)))) (-15 -2342 ((-1121 (-215)) (-877 |#1|) (-1082 (-381)) (-1082 (-381))))) (-13 (-609 (-541)) (-1090))) (T -252)) 
-((-2342 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-877 *5)) (-5 *4 (-1082 (-381))) (-4 *5 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *5)))) (-2342 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-877 *6)) (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-4 *6 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *6)))) (-2336 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-877 *5)) (-5 *4 (-1082 (-381))) (-4 *5 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1246)) (-5 *1 (-252 *5)))) (-2336 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-877 *6)) (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-4 *6 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1246)) (-5 *1 (-252 *6)))) (-2342 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-1082 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090))))) (-2342 (*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090))))) (-2336 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-1082 (-381))) (-5 *2 (-1246)) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090))))) (-2336 (*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090))))) (-2342 (*1 *2 *3 *4) (-12 (-5 *3 (-875 *5)) (-5 *4 (-1082 (-381))) (-4 *5 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *5)))) (-2342 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-875 *6)) (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-4 *6 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *6)))) (-2336 (*1 *2 *3 *4) (-12 (-5 *3 (-875 *5)) (-5 *4 (-1082 (-381))) (-4 *5 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1246)) (-5 *1 (-252 *5)))) (-2336 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-875 *6)) (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-4 *6 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1246)) (-5 *1 (-252 *6)))) (-2336 (*1 *2 *3 *4) (-12 (-5 *3 (-873 *5)) (-5 *4 (-1082 (-381))) (-4 *5 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1245)) (-5 *1 (-252 *5)))) (-2336 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-873 *6)) (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-4 *6 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1245)) (-5 *1 (-252 *6)))) (-2336 (*1 *2 *3 *4) (-12 (-5 *4 (-1082 (-381))) (-5 *2 (-1245)) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090))))) (-2336 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090)))))) 
-(-10 -7 (-15 -2336 ((-1245) |#1| (-1082 (-381)) (-634 (-256)))) (-15 -2336 ((-1245) |#1| (-1082 (-381)))) (-15 -2336 ((-1245) (-873 |#1|) (-1082 (-381)) (-634 (-256)))) (-15 -2336 ((-1245) (-873 |#1|) (-1082 (-381)))) (-15 -2336 ((-1246) (-875 |#1|) (-1082 (-381)) (-634 (-256)))) (-15 -2336 ((-1246) (-875 |#1|) (-1082 (-381)))) (-15 -2342 ((-1121 (-215)) (-875 |#1|) (-1082 (-381)) (-634 (-256)))) (-15 -2342 ((-1121 (-215)) (-875 |#1|) (-1082 (-381)))) (-15 -2336 ((-1246) |#1| (-1082 (-381)) (-1082 (-381)) (-634 (-256)))) (-15 -2336 ((-1246) |#1| (-1082 (-381)) (-1082 (-381)))) (-15 -2342 ((-1121 (-215)) |#1| (-1082 (-381)) (-1082 (-381)) (-634 (-256)))) (-15 -2342 ((-1121 (-215)) |#1| (-1082 (-381)) (-1082 (-381)))) (-15 -2336 ((-1246) (-877 |#1|) (-1082 (-381)) (-1082 (-381)) (-634 (-256)))) (-15 -2336 ((-1246) (-877 |#1|) (-1082 (-381)) (-1082 (-381)))) (-15 -2342 ((-1121 (-215)) (-877 |#1|) (-1082 (-381)) (-1082 (-381)) (-634 (-256)))) (-15 -2342 ((-1121 (-215)) (-877 |#1|) (-1082 (-381)) (-1082 (-381))))) 
-((-2336 (((-1246) (-634 (-215)) (-634 (-215)) (-634 (-215)) (-634 (-256))) 21) (((-1246) (-634 (-215)) (-634 (-215)) (-634 (-215))) 22) (((-1245) (-634 (-944 (-215))) (-634 (-256))) 13) (((-1245) (-634 (-944 (-215)))) 14) (((-1245) (-634 (-215)) (-634 (-215)) (-634 (-256))) 18) (((-1245) (-634 (-215)) (-634 (-215))) 19))) 
-(((-253) (-10 -7 (-15 -2336 ((-1245) (-634 (-215)) (-634 (-215)))) (-15 -2336 ((-1245) (-634 (-215)) (-634 (-215)) (-634 (-256)))) (-15 -2336 ((-1245) (-634 (-944 (-215))))) (-15 -2336 ((-1245) (-634 (-944 (-215))) (-634 (-256)))) (-15 -2336 ((-1246) (-634 (-215)) (-634 (-215)) (-634 (-215)))) (-15 -2336 ((-1246) (-634 (-215)) (-634 (-215)) (-634 (-215)) (-634 (-256)))))) (T -253)) 
-((-2336 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-634 (-215))) (-5 *4 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-253)))) (-2336 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-1246)) (-5 *1 (-253)))) (-2336 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-944 (-215)))) (-5 *4 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-253)))) (-2336 (*1 *2 *3) (-12 (-5 *3 (-634 (-944 (-215)))) (-5 *2 (-1245)) (-5 *1 (-253)))) (-2336 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-634 (-215))) (-5 *4 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-253)))) (-2336 (*1 *2 *3 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-1245)) (-5 *1 (-253))))) 
-(-10 -7 (-15 -2336 ((-1245) (-634 (-215)) (-634 (-215)))) (-15 -2336 ((-1245) (-634 (-215)) (-634 (-215)) (-634 (-256)))) (-15 -2336 ((-1245) (-634 (-944 (-215))))) (-15 -2336 ((-1245) (-634 (-944 (-215))) (-634 (-256)))) (-15 -2336 ((-1246) (-634 (-215)) (-634 (-215)) (-634 (-215)))) (-15 -2336 ((-1246) (-634 (-215)) (-634 (-215)) (-634 (-215)) (-634 (-256))))) 
-((-2501 (((-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))) (-634 (-256)) (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)))) 24)) (-2115 (((-917) (-634 (-256)) (-917)) 49)) (-3571 (((-917) (-634 (-256)) (-917)) 48)) (-2832 (((-634 (-381)) (-634 (-256)) (-634 (-381))) 65)) (-3485 (((-381) (-634 (-256)) (-381)) 55)) (-1787 (((-917) (-634 (-256)) (-917)) 50)) (-3254 (((-121) (-634 (-256)) (-121)) 26)) (-1784 (((-1143) (-634 (-256)) (-1143)) 19)) (-2529 (((-1143) (-634 (-256)) (-1143)) 25)) (-4194 (((-1121 (-215)) (-634 (-256))) 43)) (-3437 (((-634 (-1084 (-381))) (-634 (-256)) (-634 (-1084 (-381)))) 37)) (-3577 (((-869) (-634 (-256)) (-869)) 31)) (-2984 (((-869) (-634 (-256)) (-869)) 32)) (-4061 (((-1 (-944 (-215)) (-944 (-215))) (-634 (-256)) (-1 (-944 (-215)) (-944 (-215)))) 60)) (-1482 (((-121) (-634 (-256)) (-121)) 15)) (-3831 (((-121) (-634 (-256)) (-121)) 14))) 
-(((-254) (-10 -7 (-15 -3831 ((-121) (-634 (-256)) (-121))) (-15 -1482 ((-121) (-634 (-256)) (-121))) (-15 -2501 ((-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))) (-634 (-256)) (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))))) (-15 -1784 ((-1143) (-634 (-256)) (-1143))) (-15 -2529 ((-1143) (-634 (-256)) (-1143))) (-15 -3254 ((-121) (-634 (-256)) (-121))) (-15 -3577 ((-869) (-634 (-256)) (-869))) (-15 -2984 ((-869) (-634 (-256)) (-869))) (-15 -3437 ((-634 (-1084 (-381))) (-634 (-256)) (-634 (-1084 (-381))))) (-15 -3571 ((-917) (-634 (-256)) (-917))) (-15 -2115 ((-917) (-634 (-256)) (-917))) (-15 -4194 ((-1121 (-215)) (-634 (-256)))) (-15 -1787 ((-917) (-634 (-256)) (-917))) (-15 -3485 ((-381) (-634 (-256)) (-381))) (-15 -4061 ((-1 (-944 (-215)) (-944 (-215))) (-634 (-256)) (-1 (-944 (-215)) (-944 (-215))))) (-15 -2832 ((-634 (-381)) (-634 (-256)) (-634 (-381)))))) (T -254)) 
-((-2832 (*1 *2 *3 *2) (-12 (-5 *2 (-634 (-381))) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-4061 (*1 *2 *3 *2) (-12 (-5 *2 (-1 (-944 (-215)) (-944 (-215)))) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-3485 (*1 *2 *3 *2) (-12 (-5 *2 (-381)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-1787 (*1 *2 *3 *2) (-12 (-5 *2 (-917)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-4194 (*1 *2 *3) (-12 (-5 *3 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-254)))) (-2115 (*1 *2 *3 *2) (-12 (-5 *2 (-917)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-3571 (*1 *2 *3 *2) (-12 (-5 *2 (-917)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-3437 (*1 *2 *3 *2) (-12 (-5 *2 (-634 (-1084 (-381)))) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-2984 (*1 *2 *3 *2) (-12 (-5 *2 (-869)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-3577 (*1 *2 *3 *2) (-12 (-5 *2 (-869)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-3254 (*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-2529 (*1 *2 *3 *2) (-12 (-5 *2 (-1143)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-1784 (*1 *2 *3 *2) (-12 (-5 *2 (-1143)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-2501 (*1 *2 *3 *2) (-12 (-5 *2 (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)))) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-1482 (*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-3831 (*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *3 (-634 (-256))) (-5 *1 (-254))))) 
-(-10 -7 (-15 -3831 ((-121) (-634 (-256)) (-121))) (-15 -1482 ((-121) (-634 (-256)) (-121))) (-15 -2501 ((-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))) (-634 (-256)) (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))))) (-15 -1784 ((-1143) (-634 (-256)) (-1143))) (-15 -2529 ((-1143) (-634 (-256)) (-1143))) (-15 -3254 ((-121) (-634 (-256)) (-121))) (-15 -3577 ((-869) (-634 (-256)) (-869))) (-15 -2984 ((-869) (-634 (-256)) (-869))) (-15 -3437 ((-634 (-1084 (-381))) (-634 (-256)) (-634 (-1084 (-381))))) (-15 -3571 ((-917) (-634 (-256)) (-917))) (-15 -2115 ((-917) (-634 (-256)) (-917))) (-15 -4194 ((-1121 (-215)) (-634 (-256)))) (-15 -1787 ((-917) (-634 (-256)) (-917))) (-15 -3485 ((-381) (-634 (-256)) (-381))) (-15 -4061 ((-1 (-944 (-215)) (-944 (-215))) (-634 (-256)) (-1 (-944 (-215)) (-944 (-215))))) (-15 -2832 ((-634 (-381)) (-634 (-256)) (-634 (-381))))) 
-((-2960 (((-3 |#1| "failed") (-634 (-256)) (-1161)) 17))) 
-(((-255 |#1|) (-10 -7 (-15 -2960 ((-3 |#1| "failed") (-634 (-256)) (-1161)))) (-1195)) (T -255)) 
-((-2960 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-634 (-256))) (-5 *4 (-1161)) (-5 *1 (-255 *2)) (-4 *2 (-1195))))) 
-(-10 -7 (-15 -2960 ((-3 |#1| "failed") (-634 (-256)) (-1161)))) 
-((-2447 (((-121) $ $) NIL)) (-2501 (($ (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)))) 14)) (-2115 (($ (-917)) 70)) (-3571 (($ (-917)) 69)) (-2295 (($ (-634 (-381))) 76)) (-3485 (($ (-381)) 55)) (-1787 (($ (-917)) 71)) (-3254 (($ (-121)) 22)) (-1784 (($ (-1143)) 17)) (-2529 (($ (-1143)) 18)) (-4194 (($ (-1121 (-215))) 65)) (-3437 (($ (-634 (-1084 (-381)))) 61)) (-1338 (($ (-634 (-1084 (-381)))) 56) (($ (-634 (-1084 (-409 (-568))))) 60)) (-3574 (($ (-381)) 28) (($ (-869)) 32)) (-1507 (((-121) (-634 $) (-1161)) 85)) (-2960 (((-3 (-57) "failed") (-634 $) (-1161)) 87)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-3083 (($ (-381)) 33) (($ (-869)) 34)) (-4073 (($ (-1 (-944 (-215)) (-944 (-215)))) 54)) (-4061 (($ (-1 (-944 (-215)) (-944 (-215)))) 72)) (-3858 (($ (-1 (-215) (-215))) 38) (($ (-1 (-215) (-215) (-215))) 42) (($ (-1 (-215) (-215) (-215) (-215))) 46)) (-2745 (((-850) $) 81)) (-3182 (($ (-121)) 23) (($ (-634 (-1084 (-381)))) 50)) (-3831 (($ (-121)) 24)) (-1717 (((-121) $ $) 83))) 
-(((-256) (-13 (-1090) (-10 -8 (-15 -3831 ($ (-121))) (-15 -3182 ($ (-121))) (-15 -2501 ($ (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))))) (-15 -1784 ($ (-1143))) (-15 -2529 ($ (-1143))) (-15 -3254 ($ (-121))) (-15 -3182 ($ (-634 (-1084 (-381))))) (-15 -4073 ($ (-1 (-944 (-215)) (-944 (-215))))) (-15 -3574 ($ (-381))) (-15 -3574 ($ (-869))) (-15 -3083 ($ (-381))) (-15 -3083 ($ (-869))) (-15 -3858 ($ (-1 (-215) (-215)))) (-15 -3858 ($ (-1 (-215) (-215) (-215)))) (-15 -3858 ($ (-1 (-215) (-215) (-215) (-215)))) (-15 -3485 ($ (-381))) (-15 -1338 ($ (-634 (-1084 (-381))))) (-15 -1338 ($ (-634 (-1084 (-409 (-568)))))) (-15 -3437 ($ (-634 (-1084 (-381))))) (-15 -4194 ($ (-1121 (-215)))) (-15 -3571 ($ (-917))) (-15 -2115 ($ (-917))) (-15 -1787 ($ (-917))) (-15 -4061 ($ (-1 (-944 (-215)) (-944 (-215))))) (-15 -2295 ($ (-634 (-381)))) (-15 -2960 ((-3 (-57) "failed") (-634 $) (-1161))) (-15 -1507 ((-121) (-634 $) (-1161)))))) (T -256)) 
-((-3831 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-256)))) (-3182 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-256)))) (-2501 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)))) (-5 *1 (-256)))) (-1784 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-256)))) (-2529 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-256)))) (-3254 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-256)))) (-3182 (*1 *1 *2) (-12 (-5 *2 (-634 (-1084 (-381)))) (-5 *1 (-256)))) (-4073 (*1 *1 *2) (-12 (-5 *2 (-1 (-944 (-215)) (-944 (-215)))) (-5 *1 (-256)))) (-3574 (*1 *1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-256)))) (-3574 (*1 *1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-256)))) (-3083 (*1 *1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-256)))) (-3083 (*1 *1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-256)))) (-3858 (*1 *1 *2) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *1 (-256)))) (-3858 (*1 *1 *2) (-12 (-5 *2 (-1 (-215) (-215) (-215))) (-5 *1 (-256)))) (-3858 (*1 *1 *2) (-12 (-5 *2 (-1 (-215) (-215) (-215) (-215))) (-5 *1 (-256)))) (-3485 (*1 *1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-256)))) (-1338 (*1 *1 *2) (-12 (-5 *2 (-634 (-1084 (-381)))) (-5 *1 (-256)))) (-1338 (*1 *1 *2) (-12 (-5 *2 (-634 (-1084 (-409 (-568))))) (-5 *1 (-256)))) (-3437 (*1 *1 *2) (-12 (-5 *2 (-634 (-1084 (-381)))) (-5 *1 (-256)))) (-4194 (*1 *1 *2) (-12 (-5 *2 (-1121 (-215))) (-5 *1 (-256)))) (-3571 (*1 *1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-256)))) (-2115 (*1 *1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-256)))) (-1787 (*1 *1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-256)))) (-4061 (*1 *1 *2) (-12 (-5 *2 (-1 (-944 (-215)) (-944 (-215)))) (-5 *1 (-256)))) (-2295 (*1 *1 *2) (-12 (-5 *2 (-634 (-381))) (-5 *1 (-256)))) (-2960 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-634 (-256))) (-5 *4 (-1161)) (-5 *2 (-57)) (-5 *1 (-256)))) (-1507 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-256))) (-5 *4 (-1161)) (-5 *2 (-121)) (-5 *1 (-256))))) 
-(-13 (-1090) (-10 -8 (-15 -3831 ($ (-121))) (-15 -3182 ($ (-121))) (-15 -2501 ($ (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))))) (-15 -1784 ($ (-1143))) (-15 -2529 ($ (-1143))) (-15 -3254 ($ (-121))) (-15 -3182 ($ (-634 (-1084 (-381))))) (-15 -4073 ($ (-1 (-944 (-215)) (-944 (-215))))) (-15 -3574 ($ (-381))) (-15 -3574 ($ (-869))) (-15 -3083 ($ (-381))) (-15 -3083 ($ (-869))) (-15 -3858 ($ (-1 (-215) (-215)))) (-15 -3858 ($ (-1 (-215) (-215) (-215)))) (-15 -3858 ($ (-1 (-215) (-215) (-215) (-215)))) (-15 -3485 ($ (-381))) (-15 -1338 ($ (-634 (-1084 (-381))))) (-15 -1338 ($ (-634 (-1084 (-409 (-568)))))) (-15 -3437 ($ (-634 (-1084 (-381))))) (-15 -4194 ($ (-1121 (-215)))) (-15 -3571 ($ (-917))) (-15 -2115 ($ (-917))) (-15 -1787 ($ (-917))) (-15 -4061 ($ (-1 (-944 (-215)) (-944 (-215))))) (-15 -2295 ($ (-634 (-381)))) (-15 -2960 ((-3 (-57) "failed") (-634 $) (-1161))) (-15 -1507 ((-121) (-634 $) (-1161))))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3902 (((-634 (-763)) $) NIL) (((-634 (-763)) $ |#2|) NIL)) (-1551 (((-763) $) NIL) (((-763) $ |#2|) NIL)) (-2055 (((-634 |#3|) $) NIL)) (-3839 (((-1157 $) $ |#3|) NIL) (((-1157 |#1|) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-2773 (((-763) $) NIL) (((-763) $ (-634 |#3|)) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-4305 (($ $) NIL (|has| |#1| (-453)))) (-1678 (((-420 $) $) NIL (|has| |#1| (-453)))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-4180 (($ $) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 |#3| "failed") $) NIL) (((-3 |#2| "failed") $) NIL) (((-3 (-1113 |#1| |#2|) "failed") $) 20)) (-2854 ((|#1| $) NIL) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#1| (-1037 (-568)))) ((|#3| $) NIL) ((|#2| $) NIL) (((-1113 |#1| |#2|) $) NIL)) (-4265 (($ $ $ |#3|) NIL (|has| |#1| (-172)))) (-2114 (($ $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3250 (($ $) NIL (|has| |#1| (-453))) (($ $ |#3|) NIL (|has| |#1| (-453)))) (-2108 (((-634 $) $) NIL)) (-3927 (((-121) $) NIL (|has| |#1| (-904)))) (-3088 (($ $ |#1| (-534 |#3|) $) NIL)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| |#1| (-881 (-381))) (|has| |#3| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| |#1| (-881 (-568))) (|has| |#3| (-881 (-568)))))) (-4477 (((-763) $ |#2|) NIL) (((-763) $) 10)) (-2735 (((-121) $) NIL)) (-4178 (((-763) $) NIL)) (-2051 (($ (-1157 |#1|) |#3|) NIL) (($ (-1157 $) |#3|) NIL)) (-2976 (((-634 $) $) NIL)) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| (-534 |#3|)) NIL) (($ $ |#3| (-763)) NIL) (($ $ (-634 |#3|) (-634 (-763))) NIL)) (-3379 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $ |#3|) NIL)) (-2144 (((-534 |#3|) $) NIL) (((-763) $ |#3|) NIL) (((-634 (-763)) $ (-634 |#3|)) NIL)) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-3842 (($ (-1 (-534 |#3|) (-534 |#3|)) $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-4300 (((-1 $ (-763)) |#2|) NIL) (((-1 $ (-763)) $) NIL (|has| |#1| (-225)))) (-2244 (((-3 |#3| "failed") $) NIL)) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-1690 ((|#3| $) NIL)) (-2495 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-4487 (((-1143) $) NIL)) (-1989 (((-121) $) NIL)) (-3324 (((-3 (-634 $) "failed") $) NIL)) (-1794 (((-3 (-634 $) "failed") $) NIL)) (-3751 (((-3 (-2 (|:| |var| |#3|) (|:| -3438 (-763))) "failed") $) NIL)) (-1484 (($ $) NIL)) (-4022 (((-1108) $) NIL)) (-2086 (((-121) $) NIL)) (-2091 ((|#1| $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-453)))) (-2721 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3848 (((-420 $) $) NIL (|has| |#1| (-904)))) (-2595 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ |#3| |#1|) NIL) (($ $ (-634 |#3|) (-634 |#1|)) NIL) (($ $ |#3| $) NIL) (($ $ (-634 |#3|) (-634 $)) NIL) (($ $ |#2| $) NIL (|has| |#1| (-225))) (($ $ (-634 |#2|) (-634 $)) NIL (|has| |#1| (-225))) (($ $ |#2| |#1|) NIL (|has| |#1| (-225))) (($ $ (-634 |#2|) (-634 |#1|)) NIL (|has| |#1| (-225)))) (-2217 (($ $ |#3|) NIL (|has| |#1| (-172)))) (-4189 (($ $ |#3|) NIL) (($ $ (-634 |#3|)) NIL) (($ $ |#3| (-763)) NIL) (($ $ (-634 |#3|) (-634 (-763))) NIL) (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-3795 (((-634 |#2|) $) NIL)) (-3206 (((-534 |#3|) $) NIL) (((-763) $ |#3|) NIL) (((-634 (-763)) $ (-634 |#3|)) NIL) (((-763) $ |#2|) NIL)) (-4278 (((-887 (-381)) $) NIL (-12 (|has| |#1| (-609 (-887 (-381)))) (|has| |#3| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| |#1| (-609 (-887 (-568)))) (|has| |#3| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| |#1| (-609 (-541))) (|has| |#3| (-609 (-541)))))) (-3367 ((|#1| $) NIL (|has| |#1| (-453))) (($ $ |#3|) NIL (|has| |#1| (-453)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#1| (-904))))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) 23) (($ |#3|) 22) (($ |#2|) NIL) (($ (-1113 |#1| |#2|)) 28) (($ (-409 (-568))) NIL (-2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#1| (-558)))) (-1302 (((-634 |#1|) $) NIL)) (-2604 ((|#1| $ (-534 |#3|)) NIL) (($ $ |#3| (-763)) NIL) (($ $ (-634 |#3|) (-634 (-763))) NIL)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-4078 (((-763)) NIL)) (-4171 (($ $ $ (-763)) NIL (|has| |#1| (-172)))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $ |#3|) NIL) (($ $ (-634 |#3|)) NIL) (($ $ |#3| (-763)) NIL) (($ $ (-634 |#3|) (-634 (-763))) NIL) (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
+((-3895 (((-1 (-944 (-215)) (-215) (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1 (-215) (-215) (-215) (-215))) 139)) (-2344 (((-1121 (-215)) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381))) 160) (((-1121 (-215)) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381)) (-634 (-256))) 158) (((-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381))) 163) (((-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256))) 159) (((-1121 (-215)) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381))) 150) (((-1121 (-215)) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256))) 149) (((-1121 (-215)) (-1 (-944 (-215)) (-215)) (-1084 (-381))) 129) (((-1121 (-215)) (-1 (-944 (-215)) (-215)) (-1084 (-381)) (-634 (-256))) 127) (((-1121 (-215)) (-875 (-1 (-215) (-215))) (-1084 (-381))) 128) (((-1121 (-215)) (-875 (-1 (-215) (-215))) (-1084 (-381)) (-634 (-256))) 125)) (-2338 (((-1246) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381))) 162) (((-1246) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381)) (-634 (-256))) 161) (((-1246) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381))) 165) (((-1246) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256))) 164) (((-1246) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381))) 152) (((-1246) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256))) 151) (((-1246) (-1 (-944 (-215)) (-215)) (-1084 (-381))) 135) (((-1246) (-1 (-944 (-215)) (-215)) (-1084 (-381)) (-634 (-256))) 134) (((-1246) (-875 (-1 (-215) (-215))) (-1084 (-381))) 133) (((-1246) (-875 (-1 (-215) (-215))) (-1084 (-381)) (-634 (-256))) 132) (((-1245) (-873 (-1 (-215) (-215))) (-1084 (-381))) 99) (((-1245) (-873 (-1 (-215) (-215))) (-1084 (-381)) (-634 (-256))) 98) (((-1245) (-1 (-215) (-215)) (-1084 (-381))) 95) (((-1245) (-1 (-215) (-215)) (-1084 (-381)) (-634 (-256))) 94))) 
+(((-248) (-10 -7 (-15 -2338 ((-1245) (-1 (-215) (-215)) (-1084 (-381)) (-634 (-256)))) (-15 -2338 ((-1245) (-1 (-215) (-215)) (-1084 (-381)))) (-15 -2338 ((-1245) (-873 (-1 (-215) (-215))) (-1084 (-381)) (-634 (-256)))) (-15 -2338 ((-1245) (-873 (-1 (-215) (-215))) (-1084 (-381)))) (-15 -2338 ((-1246) (-875 (-1 (-215) (-215))) (-1084 (-381)) (-634 (-256)))) (-15 -2338 ((-1246) (-875 (-1 (-215) (-215))) (-1084 (-381)))) (-15 -2338 ((-1246) (-1 (-944 (-215)) (-215)) (-1084 (-381)) (-634 (-256)))) (-15 -2338 ((-1246) (-1 (-944 (-215)) (-215)) (-1084 (-381)))) (-15 -2344 ((-1121 (-215)) (-875 (-1 (-215) (-215))) (-1084 (-381)) (-634 (-256)))) (-15 -2344 ((-1121 (-215)) (-875 (-1 (-215) (-215))) (-1084 (-381)))) (-15 -2344 ((-1121 (-215)) (-1 (-944 (-215)) (-215)) (-1084 (-381)) (-634 (-256)))) (-15 -2344 ((-1121 (-215)) (-1 (-944 (-215)) (-215)) (-1084 (-381)))) (-15 -2338 ((-1246) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2338 ((-1246) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381)))) (-15 -2344 ((-1121 (-215)) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2344 ((-1121 (-215)) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381)))) (-15 -2338 ((-1246) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2338 ((-1246) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381)))) (-15 -2344 ((-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2344 ((-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381)))) (-15 -2338 ((-1246) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2338 ((-1246) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381)))) (-15 -2344 ((-1121 (-215)) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2344 ((-1121 (-215)) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381)))) (-15 -3895 ((-1 (-944 (-215)) (-215) (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1 (-215) (-215) (-215) (-215)))))) (T -248)) 
+((-3895 (*1 *2 *2 *3) (-12 (-5 *2 (-1 (-944 (-215)) (-215) (-215))) (-5 *3 (-1 (-215) (-215) (-215) (-215))) (-5 *1 (-248)))) (-2344 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-877 (-1 (-215) (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) (-2344 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-877 (-1 (-215) (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) (-2338 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-877 (-1 (-215) (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *2 (-1246)) (-5 *1 (-248)))) (-2338 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-877 (-1 (-215) (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-248)))) (-2344 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) (-2344 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) (-2338 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1246)) (-5 *1 (-248)))) (-2338 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-248)))) (-2344 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) (-2344 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) (-2338 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1246)) (-5 *1 (-248)))) (-2338 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-248)))) (-2344 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-944 (-215)) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) (-2344 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-944 (-215)) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) (-2344 (*1 *2 *3 *4) (-12 (-5 *3 (-875 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) (-2344 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-875 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) (-2338 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-944 (-215)) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1246)) (-5 *1 (-248)))) (-2338 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-944 (-215)) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-248)))) (-2338 (*1 *2 *3 *4) (-12 (-5 *3 (-875 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *2 (-1246)) (-5 *1 (-248)))) (-2338 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-875 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-248)))) (-2338 (*1 *2 *3 *4) (-12 (-5 *3 (-873 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *2 (-1245)) (-5 *1 (-248)))) (-2338 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-873 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-248)))) (-2338 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1245)) (-5 *1 (-248)))) (-2338 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-248))))) 
+(-10 -7 (-15 -2338 ((-1245) (-1 (-215) (-215)) (-1084 (-381)) (-634 (-256)))) (-15 -2338 ((-1245) (-1 (-215) (-215)) (-1084 (-381)))) (-15 -2338 ((-1245) (-873 (-1 (-215) (-215))) (-1084 (-381)) (-634 (-256)))) (-15 -2338 ((-1245) (-873 (-1 (-215) (-215))) (-1084 (-381)))) (-15 -2338 ((-1246) (-875 (-1 (-215) (-215))) (-1084 (-381)) (-634 (-256)))) (-15 -2338 ((-1246) (-875 (-1 (-215) (-215))) (-1084 (-381)))) (-15 -2338 ((-1246) (-1 (-944 (-215)) (-215)) (-1084 (-381)) (-634 (-256)))) (-15 -2338 ((-1246) (-1 (-944 (-215)) (-215)) (-1084 (-381)))) (-15 -2344 ((-1121 (-215)) (-875 (-1 (-215) (-215))) (-1084 (-381)) (-634 (-256)))) (-15 -2344 ((-1121 (-215)) (-875 (-1 (-215) (-215))) (-1084 (-381)))) (-15 -2344 ((-1121 (-215)) (-1 (-944 (-215)) (-215)) (-1084 (-381)) (-634 (-256)))) (-15 -2344 ((-1121 (-215)) (-1 (-944 (-215)) (-215)) (-1084 (-381)))) (-15 -2338 ((-1246) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2338 ((-1246) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381)))) (-15 -2344 ((-1121 (-215)) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2344 ((-1121 (-215)) (-1 (-215) (-215) (-215)) (-1084 (-381)) (-1084 (-381)))) (-15 -2338 ((-1246) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2338 ((-1246) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381)))) (-15 -2344 ((-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2344 ((-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-381)) (-1084 (-381)))) (-15 -2338 ((-1246) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2338 ((-1246) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381)))) (-15 -2344 ((-1121 (-215)) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381)) (-634 (-256)))) (-15 -2344 ((-1121 (-215)) (-877 (-1 (-215) (-215) (-215))) (-1084 (-381)) (-1084 (-381)))) (-15 -3895 ((-1 (-944 (-215)) (-215) (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1 (-215) (-215) (-215) (-215))))) 
+((-2338 (((-1245) (-288 |#2|) (-1161) (-1161) (-634 (-256))) 93))) 
+(((-249 |#1| |#2|) (-10 -7 (-15 -2338 ((-1245) (-288 |#2|) (-1161) (-1161) (-634 (-256))))) (-13 (-558) (-842) (-1037 (-568))) (-432 |#1|)) (T -249)) 
+((-2338 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-288 *7)) (-5 *4 (-1161)) (-5 *5 (-634 (-256))) (-4 *7 (-432 *6)) (-4 *6 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-1245)) (-5 *1 (-249 *6 *7))))) 
+(-10 -7 (-15 -2338 ((-1245) (-288 |#2|) (-1161) (-1161) (-634 (-256))))) 
+((-2644 (((-568) (-568)) 50)) (-2461 (((-568) (-568)) 51)) (-4275 (((-215) (-215)) 52)) (-3555 (((-1246) (-1 (-169 (-215)) (-169 (-215))) (-1084 (-215)) (-1084 (-215))) 49)) (-1384 (((-1246) (-1 (-169 (-215)) (-169 (-215))) (-1084 (-215)) (-1084 (-215)) (-121)) 47))) 
+(((-250) (-10 -7 (-15 -1384 ((-1246) (-1 (-169 (-215)) (-169 (-215))) (-1084 (-215)) (-1084 (-215)) (-121))) (-15 -3555 ((-1246) (-1 (-169 (-215)) (-169 (-215))) (-1084 (-215)) (-1084 (-215)))) (-15 -2644 ((-568) (-568))) (-15 -2461 ((-568) (-568))) (-15 -4275 ((-215) (-215))))) (T -250)) 
+((-4275 (*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-250)))) (-2461 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-250)))) (-2644 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-250)))) (-3555 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-169 (-215)) (-169 (-215)))) (-5 *4 (-1084 (-215))) (-5 *2 (-1246)) (-5 *1 (-250)))) (-1384 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-169 (-215)) (-169 (-215)))) (-5 *4 (-1084 (-215))) (-5 *5 (-121)) (-5 *2 (-1246)) (-5 *1 (-250))))) 
+(-10 -7 (-15 -1384 ((-1246) (-1 (-169 (-215)) (-169 (-215))) (-1084 (-215)) (-1084 (-215)) (-121))) (-15 -3555 ((-1246) (-1 (-169 (-215)) (-169 (-215))) (-1084 (-215)) (-1084 (-215)))) (-15 -2644 ((-568) (-568))) (-15 -2461 ((-568) (-568))) (-15 -4275 ((-215) (-215)))) 
+((-2747 (((-1082 (-381)) (-1082 (-310 |#1|))) 16))) 
+(((-251 |#1|) (-10 -7 (-15 -2747 ((-1082 (-381)) (-1082 (-310 |#1|))))) (-13 (-842) (-558) (-609 (-381)))) (T -251)) 
+((-2747 (*1 *2 *3) (-12 (-5 *3 (-1082 (-310 *4))) (-4 *4 (-13 (-842) (-558) (-609 (-381)))) (-5 *2 (-1082 (-381))) (-5 *1 (-251 *4))))) 
+(-10 -7 (-15 -2747 ((-1082 (-381)) (-1082 (-310 |#1|))))) 
+((-2344 (((-1121 (-215)) (-877 |#1|) (-1082 (-381)) (-1082 (-381))) 69) (((-1121 (-215)) (-877 |#1|) (-1082 (-381)) (-1082 (-381)) (-634 (-256))) 68) (((-1121 (-215)) |#1| (-1082 (-381)) (-1082 (-381))) 59) (((-1121 (-215)) |#1| (-1082 (-381)) (-1082 (-381)) (-634 (-256))) 58) (((-1121 (-215)) (-875 |#1|) (-1082 (-381))) 50) (((-1121 (-215)) (-875 |#1|) (-1082 (-381)) (-634 (-256))) 49)) (-2338 (((-1246) (-877 |#1|) (-1082 (-381)) (-1082 (-381))) 72) (((-1246) (-877 |#1|) (-1082 (-381)) (-1082 (-381)) (-634 (-256))) 71) (((-1246) |#1| (-1082 (-381)) (-1082 (-381))) 62) (((-1246) |#1| (-1082 (-381)) (-1082 (-381)) (-634 (-256))) 61) (((-1246) (-875 |#1|) (-1082 (-381))) 54) (((-1246) (-875 |#1|) (-1082 (-381)) (-634 (-256))) 53) (((-1245) (-873 |#1|) (-1082 (-381))) 41) (((-1245) (-873 |#1|) (-1082 (-381)) (-634 (-256))) 40) (((-1245) |#1| (-1082 (-381))) 33) (((-1245) |#1| (-1082 (-381)) (-634 (-256))) 32))) 
+(((-252 |#1|) (-10 -7 (-15 -2338 ((-1245) |#1| (-1082 (-381)) (-634 (-256)))) (-15 -2338 ((-1245) |#1| (-1082 (-381)))) (-15 -2338 ((-1245) (-873 |#1|) (-1082 (-381)) (-634 (-256)))) (-15 -2338 ((-1245) (-873 |#1|) (-1082 (-381)))) (-15 -2338 ((-1246) (-875 |#1|) (-1082 (-381)) (-634 (-256)))) (-15 -2338 ((-1246) (-875 |#1|) (-1082 (-381)))) (-15 -2344 ((-1121 (-215)) (-875 |#1|) (-1082 (-381)) (-634 (-256)))) (-15 -2344 ((-1121 (-215)) (-875 |#1|) (-1082 (-381)))) (-15 -2338 ((-1246) |#1| (-1082 (-381)) (-1082 (-381)) (-634 (-256)))) (-15 -2338 ((-1246) |#1| (-1082 (-381)) (-1082 (-381)))) (-15 -2344 ((-1121 (-215)) |#1| (-1082 (-381)) (-1082 (-381)) (-634 (-256)))) (-15 -2344 ((-1121 (-215)) |#1| (-1082 (-381)) (-1082 (-381)))) (-15 -2338 ((-1246) (-877 |#1|) (-1082 (-381)) (-1082 (-381)) (-634 (-256)))) (-15 -2338 ((-1246) (-877 |#1|) (-1082 (-381)) (-1082 (-381)))) (-15 -2344 ((-1121 (-215)) (-877 |#1|) (-1082 (-381)) (-1082 (-381)) (-634 (-256)))) (-15 -2344 ((-1121 (-215)) (-877 |#1|) (-1082 (-381)) (-1082 (-381))))) (-13 (-609 (-541)) (-1090))) (T -252)) 
+((-2344 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-877 *5)) (-5 *4 (-1082 (-381))) (-4 *5 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *5)))) (-2344 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-877 *6)) (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-4 *6 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *6)))) (-2338 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-877 *5)) (-5 *4 (-1082 (-381))) (-4 *5 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1246)) (-5 *1 (-252 *5)))) (-2338 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-877 *6)) (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-4 *6 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1246)) (-5 *1 (-252 *6)))) (-2344 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-1082 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090))))) (-2344 (*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090))))) (-2338 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-1082 (-381))) (-5 *2 (-1246)) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090))))) (-2338 (*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090))))) (-2344 (*1 *2 *3 *4) (-12 (-5 *3 (-875 *5)) (-5 *4 (-1082 (-381))) (-4 *5 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *5)))) (-2344 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-875 *6)) (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-4 *6 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *6)))) (-2338 (*1 *2 *3 *4) (-12 (-5 *3 (-875 *5)) (-5 *4 (-1082 (-381))) (-4 *5 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1246)) (-5 *1 (-252 *5)))) (-2338 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-875 *6)) (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-4 *6 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1246)) (-5 *1 (-252 *6)))) (-2338 (*1 *2 *3 *4) (-12 (-5 *3 (-873 *5)) (-5 *4 (-1082 (-381))) (-4 *5 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1245)) (-5 *1 (-252 *5)))) (-2338 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-873 *6)) (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-4 *6 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1245)) (-5 *1 (-252 *6)))) (-2338 (*1 *2 *3 *4) (-12 (-5 *4 (-1082 (-381))) (-5 *2 (-1245)) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090))))) (-2338 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090)))))) 
+(-10 -7 (-15 -2338 ((-1245) |#1| (-1082 (-381)) (-634 (-256)))) (-15 -2338 ((-1245) |#1| (-1082 (-381)))) (-15 -2338 ((-1245) (-873 |#1|) (-1082 (-381)) (-634 (-256)))) (-15 -2338 ((-1245) (-873 |#1|) (-1082 (-381)))) (-15 -2338 ((-1246) (-875 |#1|) (-1082 (-381)) (-634 (-256)))) (-15 -2338 ((-1246) (-875 |#1|) (-1082 (-381)))) (-15 -2344 ((-1121 (-215)) (-875 |#1|) (-1082 (-381)) (-634 (-256)))) (-15 -2344 ((-1121 (-215)) (-875 |#1|) (-1082 (-381)))) (-15 -2338 ((-1246) |#1| (-1082 (-381)) (-1082 (-381)) (-634 (-256)))) (-15 -2338 ((-1246) |#1| (-1082 (-381)) (-1082 (-381)))) (-15 -2344 ((-1121 (-215)) |#1| (-1082 (-381)) (-1082 (-381)) (-634 (-256)))) (-15 -2344 ((-1121 (-215)) |#1| (-1082 (-381)) (-1082 (-381)))) (-15 -2338 ((-1246) (-877 |#1|) (-1082 (-381)) (-1082 (-381)) (-634 (-256)))) (-15 -2338 ((-1246) (-877 |#1|) (-1082 (-381)) (-1082 (-381)))) (-15 -2344 ((-1121 (-215)) (-877 |#1|) (-1082 (-381)) (-1082 (-381)) (-634 (-256)))) (-15 -2344 ((-1121 (-215)) (-877 |#1|) (-1082 (-381)) (-1082 (-381))))) 
+((-2338 (((-1246) (-634 (-215)) (-634 (-215)) (-634 (-215)) (-634 (-256))) 21) (((-1246) (-634 (-215)) (-634 (-215)) (-634 (-215))) 22) (((-1245) (-634 (-944 (-215))) (-634 (-256))) 13) (((-1245) (-634 (-944 (-215)))) 14) (((-1245) (-634 (-215)) (-634 (-215)) (-634 (-256))) 18) (((-1245) (-634 (-215)) (-634 (-215))) 19))) 
+(((-253) (-10 -7 (-15 -2338 ((-1245) (-634 (-215)) (-634 (-215)))) (-15 -2338 ((-1245) (-634 (-215)) (-634 (-215)) (-634 (-256)))) (-15 -2338 ((-1245) (-634 (-944 (-215))))) (-15 -2338 ((-1245) (-634 (-944 (-215))) (-634 (-256)))) (-15 -2338 ((-1246) (-634 (-215)) (-634 (-215)) (-634 (-215)))) (-15 -2338 ((-1246) (-634 (-215)) (-634 (-215)) (-634 (-215)) (-634 (-256)))))) (T -253)) 
+((-2338 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-634 (-215))) (-5 *4 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-253)))) (-2338 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-1246)) (-5 *1 (-253)))) (-2338 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-944 (-215)))) (-5 *4 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-253)))) (-2338 (*1 *2 *3) (-12 (-5 *3 (-634 (-944 (-215)))) (-5 *2 (-1245)) (-5 *1 (-253)))) (-2338 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-634 (-215))) (-5 *4 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-253)))) (-2338 (*1 *2 *3 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-1245)) (-5 *1 (-253))))) 
+(-10 -7 (-15 -2338 ((-1245) (-634 (-215)) (-634 (-215)))) (-15 -2338 ((-1245) (-634 (-215)) (-634 (-215)) (-634 (-256)))) (-15 -2338 ((-1245) (-634 (-944 (-215))))) (-15 -2338 ((-1245) (-634 (-944 (-215))) (-634 (-256)))) (-15 -2338 ((-1246) (-634 (-215)) (-634 (-215)) (-634 (-215)))) (-15 -2338 ((-1246) (-634 (-215)) (-634 (-215)) (-634 (-215)) (-634 (-256))))) 
+((-1627 (((-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))) (-634 (-256)) (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)))) 24)) (-3299 (((-917) (-634 (-256)) (-917)) 49)) (-2893 (((-917) (-634 (-256)) (-917)) 48)) (-2833 (((-634 (-381)) (-634 (-256)) (-634 (-381))) 65)) (-3810 (((-381) (-634 (-256)) (-381)) 55)) (-4055 (((-917) (-634 (-256)) (-917)) 50)) (-2006 (((-121) (-634 (-256)) (-121)) 26)) (-4037 (((-1143) (-634 (-256)) (-1143)) 19)) (-1778 (((-1143) (-634 (-256)) (-1143)) 25)) (-4053 (((-1121 (-215)) (-634 (-256))) 43)) (-3474 (((-634 (-1084 (-381))) (-634 (-256)) (-634 (-1084 (-381)))) 37)) (-2913 (((-869) (-634 (-256)) (-869)) 31)) (-3088 (((-869) (-634 (-256)) (-869)) 32)) (-1617 (((-1 (-944 (-215)) (-944 (-215))) (-634 (-256)) (-1 (-944 (-215)) (-944 (-215)))) 60)) (-2518 (((-121) (-634 (-256)) (-121)) 15)) (-1825 (((-121) (-634 (-256)) (-121)) 14))) 
+(((-254) (-10 -7 (-15 -1825 ((-121) (-634 (-256)) (-121))) (-15 -2518 ((-121) (-634 (-256)) (-121))) (-15 -1627 ((-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))) (-634 (-256)) (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))))) (-15 -4037 ((-1143) (-634 (-256)) (-1143))) (-15 -1778 ((-1143) (-634 (-256)) (-1143))) (-15 -2006 ((-121) (-634 (-256)) (-121))) (-15 -2913 ((-869) (-634 (-256)) (-869))) (-15 -3088 ((-869) (-634 (-256)) (-869))) (-15 -3474 ((-634 (-1084 (-381))) (-634 (-256)) (-634 (-1084 (-381))))) (-15 -2893 ((-917) (-634 (-256)) (-917))) (-15 -3299 ((-917) (-634 (-256)) (-917))) (-15 -4053 ((-1121 (-215)) (-634 (-256)))) (-15 -4055 ((-917) (-634 (-256)) (-917))) (-15 -3810 ((-381) (-634 (-256)) (-381))) (-15 -1617 ((-1 (-944 (-215)) (-944 (-215))) (-634 (-256)) (-1 (-944 (-215)) (-944 (-215))))) (-15 -2833 ((-634 (-381)) (-634 (-256)) (-634 (-381)))))) (T -254)) 
+((-2833 (*1 *2 *3 *2) (-12 (-5 *2 (-634 (-381))) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-1617 (*1 *2 *3 *2) (-12 (-5 *2 (-1 (-944 (-215)) (-944 (-215)))) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-3810 (*1 *2 *3 *2) (-12 (-5 *2 (-381)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-4055 (*1 *2 *3 *2) (-12 (-5 *2 (-917)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-4053 (*1 *2 *3) (-12 (-5 *3 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-254)))) (-3299 (*1 *2 *3 *2) (-12 (-5 *2 (-917)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-2893 (*1 *2 *3 *2) (-12 (-5 *2 (-917)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-3474 (*1 *2 *3 *2) (-12 (-5 *2 (-634 (-1084 (-381)))) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-3088 (*1 *2 *3 *2) (-12 (-5 *2 (-869)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-2913 (*1 *2 *3 *2) (-12 (-5 *2 (-869)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-2006 (*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-1778 (*1 *2 *3 *2) (-12 (-5 *2 (-1143)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-4037 (*1 *2 *3 *2) (-12 (-5 *2 (-1143)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-1627 (*1 *2 *3 *2) (-12 (-5 *2 (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)))) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-2518 (*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) (-1825 (*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *3 (-634 (-256))) (-5 *1 (-254))))) 
+(-10 -7 (-15 -1825 ((-121) (-634 (-256)) (-121))) (-15 -2518 ((-121) (-634 (-256)) (-121))) (-15 -1627 ((-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))) (-634 (-256)) (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))))) (-15 -4037 ((-1143) (-634 (-256)) (-1143))) (-15 -1778 ((-1143) (-634 (-256)) (-1143))) (-15 -2006 ((-121) (-634 (-256)) (-121))) (-15 -2913 ((-869) (-634 (-256)) (-869))) (-15 -3088 ((-869) (-634 (-256)) (-869))) (-15 -3474 ((-634 (-1084 (-381))) (-634 (-256)) (-634 (-1084 (-381))))) (-15 -2893 ((-917) (-634 (-256)) (-917))) (-15 -3299 ((-917) (-634 (-256)) (-917))) (-15 -4053 ((-1121 (-215)) (-634 (-256)))) (-15 -4055 ((-917) (-634 (-256)) (-917))) (-15 -3810 ((-381) (-634 (-256)) (-381))) (-15 -1617 ((-1 (-944 (-215)) (-944 (-215))) (-634 (-256)) (-1 (-944 (-215)) (-944 (-215))))) (-15 -2833 ((-634 (-381)) (-634 (-256)) (-634 (-381))))) 
+((-2962 (((-3 |#1| "failed") (-634 (-256)) (-1161)) 17))) 
+(((-255 |#1|) (-10 -7 (-15 -2962 ((-3 |#1| "failed") (-634 (-256)) (-1161)))) (-1195)) (T -255)) 
+((-2962 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-634 (-256))) (-5 *4 (-1161)) (-5 *1 (-255 *2)) (-4 *2 (-1195))))) 
+(-10 -7 (-15 -2962 ((-3 |#1| "failed") (-634 (-256)) (-1161)))) 
+((-2449 (((-121) $ $) NIL)) (-1627 (($ (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)))) 14)) (-3299 (($ (-917)) 70)) (-2893 (($ (-917)) 69)) (-3591 (($ (-634 (-381))) 76)) (-3810 (($ (-381)) 55)) (-4055 (($ (-917)) 71)) (-2006 (($ (-121)) 22)) (-4037 (($ (-1143)) 17)) (-1778 (($ (-1143)) 18)) (-4053 (($ (-1121 (-215))) 65)) (-3474 (($ (-634 (-1084 (-381)))) 61)) (-3581 (($ (-634 (-1084 (-381)))) 56) (($ (-634 (-1084 (-409 (-568))))) 60)) (-2903 (($ (-381)) 28) (($ (-869)) 32)) (-2647 (((-121) (-634 $) (-1161)) 85)) (-2962 (((-3 (-57) "failed") (-634 $) (-1161)) 87)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2430 (($ (-381)) 33) (($ (-869)) 34)) (-1656 (($ (-1 (-944 (-215)) (-944 (-215)))) 54)) (-1617 (($ (-1 (-944 (-215)) (-944 (-215)))) 72)) (-1919 (($ (-1 (-215) (-215))) 38) (($ (-1 (-215) (-215) (-215))) 42) (($ (-1 (-215) (-215) (-215) (-215))) 46)) (-2747 (((-850) $) 81)) (-1743 (($ (-121)) 23) (($ (-634 (-1084 (-381)))) 50)) (-1825 (($ (-121)) 24)) (-1719 (((-121) $ $) 83))) 
+(((-256) (-13 (-1090) (-10 -8 (-15 -1825 ($ (-121))) (-15 -1743 ($ (-121))) (-15 -1627 ($ (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))))) (-15 -4037 ($ (-1143))) (-15 -1778 ($ (-1143))) (-15 -2006 ($ (-121))) (-15 -1743 ($ (-634 (-1084 (-381))))) (-15 -1656 ($ (-1 (-944 (-215)) (-944 (-215))))) (-15 -2903 ($ (-381))) (-15 -2903 ($ (-869))) (-15 -2430 ($ (-381))) (-15 -2430 ($ (-869))) (-15 -1919 ($ (-1 (-215) (-215)))) (-15 -1919 ($ (-1 (-215) (-215) (-215)))) (-15 -1919 ($ (-1 (-215) (-215) (-215) (-215)))) (-15 -3810 ($ (-381))) (-15 -3581 ($ (-634 (-1084 (-381))))) (-15 -3581 ($ (-634 (-1084 (-409 (-568)))))) (-15 -3474 ($ (-634 (-1084 (-381))))) (-15 -4053 ($ (-1121 (-215)))) (-15 -2893 ($ (-917))) (-15 -3299 ($ (-917))) (-15 -4055 ($ (-917))) (-15 -1617 ($ (-1 (-944 (-215)) (-944 (-215))))) (-15 -3591 ($ (-634 (-381)))) (-15 -2962 ((-3 (-57) "failed") (-634 $) (-1161))) (-15 -2647 ((-121) (-634 $) (-1161)))))) (T -256)) 
+((-1825 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-256)))) (-1743 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-256)))) (-1627 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)))) (-5 *1 (-256)))) (-4037 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-256)))) (-1778 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-256)))) (-2006 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-256)))) (-1743 (*1 *1 *2) (-12 (-5 *2 (-634 (-1084 (-381)))) (-5 *1 (-256)))) (-1656 (*1 *1 *2) (-12 (-5 *2 (-1 (-944 (-215)) (-944 (-215)))) (-5 *1 (-256)))) (-2903 (*1 *1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-256)))) (-2903 (*1 *1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-256)))) (-2430 (*1 *1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-256)))) (-2430 (*1 *1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-256)))) (-1919 (*1 *1 *2) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *1 (-256)))) (-1919 (*1 *1 *2) (-12 (-5 *2 (-1 (-215) (-215) (-215))) (-5 *1 (-256)))) (-1919 (*1 *1 *2) (-12 (-5 *2 (-1 (-215) (-215) (-215) (-215))) (-5 *1 (-256)))) (-3810 (*1 *1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-256)))) (-3581 (*1 *1 *2) (-12 (-5 *2 (-634 (-1084 (-381)))) (-5 *1 (-256)))) (-3581 (*1 *1 *2) (-12 (-5 *2 (-634 (-1084 (-409 (-568))))) (-5 *1 (-256)))) (-3474 (*1 *1 *2) (-12 (-5 *2 (-634 (-1084 (-381)))) (-5 *1 (-256)))) (-4053 (*1 *1 *2) (-12 (-5 *2 (-1121 (-215))) (-5 *1 (-256)))) (-2893 (*1 *1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-256)))) (-3299 (*1 *1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-256)))) (-4055 (*1 *1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-256)))) (-1617 (*1 *1 *2) (-12 (-5 *2 (-1 (-944 (-215)) (-944 (-215)))) (-5 *1 (-256)))) (-3591 (*1 *1 *2) (-12 (-5 *2 (-634 (-381))) (-5 *1 (-256)))) (-2962 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-634 (-256))) (-5 *4 (-1161)) (-5 *2 (-57)) (-5 *1 (-256)))) (-2647 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-256))) (-5 *4 (-1161)) (-5 *2 (-121)) (-5 *1 (-256))))) 
+(-13 (-1090) (-10 -8 (-15 -1825 ($ (-121))) (-15 -1743 ($ (-121))) (-15 -1627 ($ (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))))) (-15 -4037 ($ (-1143))) (-15 -1778 ($ (-1143))) (-15 -2006 ($ (-121))) (-15 -1743 ($ (-634 (-1084 (-381))))) (-15 -1656 ($ (-1 (-944 (-215)) (-944 (-215))))) (-15 -2903 ($ (-381))) (-15 -2903 ($ (-869))) (-15 -2430 ($ (-381))) (-15 -2430 ($ (-869))) (-15 -1919 ($ (-1 (-215) (-215)))) (-15 -1919 ($ (-1 (-215) (-215) (-215)))) (-15 -1919 ($ (-1 (-215) (-215) (-215) (-215)))) (-15 -3810 ($ (-381))) (-15 -3581 ($ (-634 (-1084 (-381))))) (-15 -3581 ($ (-634 (-1084 (-409 (-568)))))) (-15 -3474 ($ (-634 (-1084 (-381))))) (-15 -4053 ($ (-1121 (-215)))) (-15 -2893 ($ (-917))) (-15 -3299 ($ (-917))) (-15 -4055 ($ (-917))) (-15 -1617 ($ (-1 (-944 (-215)) (-944 (-215))))) (-15 -3591 ($ (-634 (-381)))) (-15 -2962 ((-3 (-57) "failed") (-634 $) (-1161))) (-15 -2647 ((-121) (-634 $) (-1161))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2076 (((-634 (-763)) $) NIL) (((-634 (-763)) $ |#2|) NIL)) (-4308 (((-763) $) NIL) (((-763) $ |#2|) NIL)) (-2057 (((-634 |#3|) $) NIL)) (-3840 (((-1157 $) $ |#3|) NIL) (((-1157 |#1|) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-3528 (((-763) $) NIL) (((-763) $ (-634 |#3|)) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3045 (($ $) NIL (|has| |#1| (-453)))) (-3498 (((-420 $) $) NIL (|has| |#1| (-453)))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3988 (($ $) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 |#3| "failed") $) NIL) (((-3 |#2| "failed") $) NIL) (((-3 (-1113 |#1| |#2|) "failed") $) 20)) (-2857 ((|#1| $) NIL) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#1| (-1037 (-568)))) ((|#3| $) NIL) ((|#2| $) NIL) (((-1113 |#1| |#2|) $) NIL)) (-2910 (($ $ $ |#3|) NIL (|has| |#1| (-172)))) (-2116 (($ $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1998 (($ $) NIL (|has| |#1| (-453))) (($ $ |#3|) NIL (|has| |#1| (-453)))) (-2110 (((-634 $) $) NIL)) (-2197 (((-121) $) NIL (|has| |#1| (-904)))) (-2453 (($ $ |#1| (-534 |#3|) $) NIL)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| |#1| (-881 (-381))) (|has| |#3| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| |#1| (-881 (-568))) (|has| |#3| (-881 (-568)))))) (-1844 (((-763) $ |#2|) NIL) (((-763) $) 10)) (-1598 (((-121) $) NIL)) (-3971 (((-763) $) NIL)) (-2053 (($ (-1157 |#1|) |#3|) NIL) (($ (-1157 $) |#3|) NIL)) (-3062 (((-634 $) $) NIL)) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| (-534 |#3|)) NIL) (($ $ |#3| (-763)) NIL) (($ $ (-634 |#3|) (-634 (-763))) NIL)) (-1438 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $ |#3|) NIL)) (-3524 (((-534 |#3|) $) NIL) (((-763) $ |#3|) NIL) (((-634 (-763)) $ (-634 |#3|)) NIL)) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-1865 (($ (-1 (-534 |#3|) (-534 |#3|)) $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-3029 (((-1 $ (-763)) |#2|) NIL) (((-1 $ (-763)) $) NIL (|has| |#1| (-225)))) (-2817 (((-3 |#3| "failed") $) NIL)) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-1692 ((|#3| $) NIL)) (-2498 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-1893 (((-1143) $) NIL)) (-4448 (((-121) $) NIL)) (-4362 (((-3 (-634 $) "failed") $) NIL)) (-2112 (((-3 (-634 $) "failed") $) NIL)) (-2617 (((-3 (-2 (|:| |var| |#3|) (|:| -3483 (-763))) "failed") $) NIL)) (-1484 (($ $) NIL)) (-4025 (((-1108) $) NIL)) (-2088 (((-121) $) NIL)) (-2093 ((|#1| $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-453)))) (-2723 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3850 (((-420 $) $) NIL (|has| |#1| (-904)))) (-2597 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ |#3| |#1|) NIL) (($ $ (-634 |#3|) (-634 |#1|)) NIL) (($ $ |#3| $) NIL) (($ $ (-634 |#3|) (-634 $)) NIL) (($ $ |#2| $) NIL (|has| |#1| (-225))) (($ $ (-634 |#2|) (-634 $)) NIL (|has| |#1| (-225))) (($ $ |#2| |#1|) NIL (|has| |#1| (-225))) (($ $ (-634 |#2|) (-634 |#1|)) NIL (|has| |#1| (-225)))) (-3440 (($ $ |#3|) NIL (|has| |#1| (-172)))) (-4191 (($ $ |#3|) NIL) (($ $ (-634 |#3|)) NIL) (($ $ |#3| (-763)) NIL) (($ $ (-634 |#3|) (-634 (-763))) NIL) (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-2775 (((-634 |#2|) $) NIL)) (-1836 (((-534 |#3|) $) NIL) (((-763) $ |#3|) NIL) (((-634 (-763)) $ (-634 |#3|)) NIL) (((-763) $ |#2|) NIL)) (-4280 (((-887 (-381)) $) NIL (-12 (|has| |#1| (-609 (-887 (-381)))) (|has| |#3| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| |#1| (-609 (-887 (-568)))) (|has| |#3| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| |#1| (-609 (-541))) (|has| |#3| (-609 (-541)))))) (-1364 ((|#1| $) NIL (|has| |#1| (-453))) (($ $ |#3|) NIL (|has| |#1| (-453)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#1| (-904))))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) 23) (($ |#3|) 22) (($ |#2|) NIL) (($ (-1113 |#1| |#2|)) 28) (($ (-409 (-568))) NIL (-2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#1| (-558)))) (-3304 (((-634 |#1|) $) NIL)) (-2079 ((|#1| $ (-534 |#3|)) NIL) (($ $ |#3| (-763)) NIL) (($ $ (-634 |#3|) (-634 (-763))) NIL)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-3425 (((-763)) NIL)) (-3925 (($ $ $ (-763)) NIL (|has| |#1| (-172)))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $ |#3|) NIL) (($ $ (-634 |#3|)) NIL) (($ $ |#3| (-763)) NIL) (($ $ (-634 |#3|) (-634 (-763))) NIL) (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
 (((-257 |#1| |#2| |#3|) (-13 (-246 |#1| |#2| |#3| (-534 |#3|)) (-1037 (-1113 |#1| |#2|))) (-1047) (-842) (-262 |#2|)) (T -257)) 
 NIL 
 (-13 (-246 |#1| |#2| |#3| (-534 |#3|)) (-1037 (-1113 |#1| |#2|))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2850 ((|#1| $) 45)) (-3399 (($ |#1| (-634 $)) 51) (($ |#1|) 50) (($ (-634 |#1|)) 49)) (-2510 (((-121) $ (-763)) 8)) (-1659 ((|#1| $ |#1|) 36 (|has| $ (-6 -4520)))) (-2436 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) 38 (|has| $ (-6 -4520)))) (-2671 (($) 7 T CONST)) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-2287 (((-634 $) $) 47)) (-1700 (((-121) $ $) 39 (|has| |#1| (-1090)))) (-1737 (((-121) $ (-763)) 9)) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35)) (-2166 (((-121) $ (-763)) 10)) (-2869 (((-634 |#1|) $) 42)) (-1651 (((-121) $) 46)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 ((|#1| $ "value") 44)) (-4075 (((-568) $ $) 41)) (-3790 (((-121) $) 43)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-4339 (((-634 $) $) 48)) (-3491 (((-121) $ $) 40 (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2852 ((|#1| $) 45)) (-1533 (($ |#1| (-634 $)) 51) (($ |#1|) 50) (($ (-634 |#1|)) 49)) (-1667 (((-121) $ (-763)) 8)) (-3370 ((|#1| $ |#1|) 36 (|has| $ (-6 -4522)))) (-2438 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) 38 (|has| $ (-6 -4522)))) (-4490 (($) 7 T CONST)) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-3534 (((-634 $) $) 47)) (-3606 (((-121) $ $) 39 (|has| |#1| (-1090)))) (-3791 (((-121) $ (-763)) 9)) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35)) (-3796 (((-121) $ (-763)) 10)) (-4081 (((-634 |#1|) $) 42)) (-3319 (((-121) $) 46)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 ((|#1| $ "value") 44)) (-1665 (((-568) $ $) 41)) (-2763 (((-121) $) 43)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-3180 (((-634 $) $) 48)) (-3873 (((-121) $ $) 40 (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-258 |#1|) (-1275) (-1090)) (T -258)) 
-((-3399 (*1 *1 *2 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-258 *2)) (-4 *2 (-1090)))) (-3399 (*1 *1 *2) (-12 (-4 *1 (-258 *2)) (-4 *2 (-1090)))) (-3399 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-4 *1 (-258 *3))))) 
-(-13 (-1010 |t#1|) (-10 -8 (-6 -4520) (-6 -4519) (-15 -3399 ($ |t#1| (-634 $))) (-15 -3399 ($ |t#1|)) (-15 -3399 ($ (-634 |t#1|))))) 
+((-1533 (*1 *1 *2 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-258 *2)) (-4 *2 (-1090)))) (-1533 (*1 *1 *2) (-12 (-4 *1 (-258 *2)) (-4 *2 (-1090)))) (-1533 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-4 *1 (-258 *3))))) 
+(-13 (-1010 |t#1|) (-10 -8 (-6 -4522) (-6 -4521) (-15 -1533 ($ |t#1| (-634 $))) (-15 -1533 ($ |t#1|)) (-15 -1533 ($ (-634 |t#1|))))) 
 (((-39) . T) ((-105) |has| |#1| (-1090)) ((-608 (-850)) |has| |#1| (-1090)) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-1010 |#1|) . T) ((-1090) |has| |#1| (-1090)) ((-1195) . T)) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2850 ((|#1| $) 12)) (-3399 (($ |#1| (-634 $)) 31) (($ |#1|) 32) (($ (-634 |#1|)) 33)) (-2510 (((-121) $ (-763)) NIL)) (-1659 ((|#1| $ |#1|) 35 (|has| $ (-6 -4520)))) (-2436 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) 34 (|has| $ (-6 -4520)))) (-2671 (($) NIL T CONST)) (-4360 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-2287 (((-634 $) $) NIL)) (-1700 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1737 (((-121) $ (-763)) NIL)) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3674 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-2869 (((-634 |#1|) $) 22)) (-1651 (((-121) $) NIL)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3936 (((-121) (-121)) 18) (((-121)) 19)) (-2184 (((-850) $) 15)) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-2153 (((-1143) $) 28)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#1| $ "value") NIL)) (-4075 (((-568) $ $) NIL)) (-3790 (((-121) $) NIL)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) NIL)) (-2745 (((-850) $) 30 (|has| |#1| (-1090)))) (-4339 (((-634 $) $) 8)) (-3491 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 26 (|has| |#1| (-1090)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-259 |#1|) (-13 (-258 |#1|) (-10 -8 (-15 -2153 ((-1143) $)) (-15 -2184 ((-850) $)) (-15 -3936 ((-121) (-121))) (-15 -3936 ((-121))))) (-1090)) (T -259)) 
-((-2153 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-259 *3)) (-4 *3 (-1090)))) (-2184 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-259 *3)) (-4 *3 (-1090)))) (-3936 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-259 *3)) (-4 *3 (-1090)))) (-3936 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-259 *3)) (-4 *3 (-1090))))) 
-(-13 (-258 |#1|) (-10 -8 (-15 -2153 ((-1143) $)) (-15 -2184 ((-850) $)) (-15 -3936 ((-121) (-121))) (-15 -3936 ((-121))))) 
-((-2190 (((-1249) |#10| (-634 |#3|)) 133) (((-1249) |#10|) 135)) (-2390 (((-1249) |#10|) NIL)) (-2587 ((|#8| |#10|) 28)) (-4207 (((-568) (-763) (-634 |#10|)) 147)) (-4424 (((-763) (-763) (-634 |#10|)) 145)) (-1801 (((-568) |#3|) 148)) (-2126 (((-763) |#3|) 146)) (-1410 (((-1249) |#10|) 136)) (-2388 ((|#8| |#3| |#10|) 111)) (-2625 ((|#10| |#5| |#3|) 138)) (-2176 (((-634 |#10|) |#3|) 144)) (-1703 (((-1249) |#10|) 134)) (-1883 (((-634 |#9|) |#9|) 87)) (-2480 ((|#8| |#10|) 110))) 
-(((-260 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9| |#10| |#11|) (-10 -7 (-15 -1883 ((-634 |#9|) |#9|)) (-15 -2388 (|#8| |#3| |#10|)) (-15 -2480 (|#8| |#10|)) (-15 -1703 ((-1249) |#10|)) (-15 -2625 (|#10| |#5| |#3|)) (-15 -2176 ((-634 |#10|) |#3|)) (-15 -1410 ((-1249) |#10|)) (-15 -2390 ((-1249) |#10|)) (-15 -2190 ((-1249) |#10|)) (-15 -2190 ((-1249) |#10| (-634 |#3|))) (-15 -2126 ((-763) |#3|)) (-15 -1801 ((-568) |#3|)) (-15 -4424 ((-763) (-763) (-634 |#10|))) (-15 -2587 (|#8| |#10|)) (-15 -4207 ((-568) (-763) (-634 |#10|)))) (-365) (-634 (-1161)) (-950 |#1| |#4| (-852 |#2|)) (-230 (-1697 |#2|) (-763)) (-971 |#1|) (-641 |#1|) (-920 |#1| |#6|) (-235 |#7|) (-536 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#11|) (-258 |#9|) (-117)) (T -260)) 
-((-4207 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *14)) (-4 *14 (-258 *13)) (-4 *13 (-536 *5 *6 *7 *8 *9 *10 *11 *12 *15)) (-4 *15 (-117)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1697 *6) *3)) (-4 *9 (-971 *5)) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-4 *12 (-235 *11)) (-5 *3 (-763)) (-5 *2 (-568)) (-5 *1 (-260 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14 *15)))) (-2587 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-536 *4 *5 *6 *7 *8 *9 *10 *2 *12)) (-4 *12 (-117)) (-4 *2 (-235 *10)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *2 *11 *3 *12)) (-4 *3 (-258 *11)))) (-4424 (*1 *2 *2 *3) (-12 (-5 *3 (-634 *13)) (-4 *13 (-258 *12)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) *2)) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-5 *2 (-763)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)))) (-1801 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *6 (-230 (-1697 *5) (-763))) (-4 *7 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-568)) (-5 *1 (-260 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-2126 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *6 (-230 (-1697 *5) *2)) (-4 *7 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-763)) (-5 *1 (-260 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-2190 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *7)) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1697 *6) (-763))) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *9 (-971 *5)) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-4 *12 (-235 *11)) (-4 *13 (-536 *5 *6 *7 *8 *9 *10 *11 *12 *14)) (-4 *14 (-117)) (-5 *2 (-1249)) (-5 *1 (-260 *5 *6 *7 *8 *9 *10 *11 *12 *13 *3 *14)) (-4 *3 (-258 *13)))) (-2190 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1249)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-258 *12)))) (-2390 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1249)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-258 *12)))) (-1410 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1249)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-258 *12)))) (-2176 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *6 (-230 (-1697 *5) (-763))) (-4 *7 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *12)) (-5 *1 (-260 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-2625 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *4 (-950 *5 *7 (-852 *6))) (-4 *7 (-230 (-1697 *6) (-763))) (-4 *3 (-971 *5)) (-4 *8 (-641 *5)) (-4 *9 (-920 *5 *8)) (-4 *10 (-235 *9)) (-4 *12 (-117)) (-4 *2 (-258 *11)) (-5 *1 (-260 *5 *6 *4 *7 *3 *8 *9 *10 *11 *2 *12)) (-4 *11 (-536 *5 *6 *4 *7 *3 *8 *9 *10 *12)))) (-1703 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1249)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-258 *12)))) (-2480 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-536 *4 *5 *6 *7 *8 *9 *10 *2 *12)) (-4 *12 (-117)) (-4 *2 (-235 *10)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *2 *11 *3 *12)) (-4 *3 (-258 *11)))) (-2388 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *7 (-230 (-1697 *6) (-763))) (-4 *8 (-971 *5)) (-4 *9 (-641 *5)) (-4 *10 (-920 *5 *9)) (-4 *11 (-536 *5 *6 *3 *7 *8 *9 *10 *2 *12)) (-4 *12 (-117)) (-4 *2 (-235 *10)) (-5 *1 (-260 *5 *6 *3 *7 *8 *9 *10 *2 *11 *4 *12)) (-4 *4 (-258 *11)))) (-1883 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *3 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-634 *3)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13)) (-4 *12 (-258 *3))))) 
-(-10 -7 (-15 -1883 ((-634 |#9|) |#9|)) (-15 -2388 (|#8| |#3| |#10|)) (-15 -2480 (|#8| |#10|)) (-15 -1703 ((-1249) |#10|)) (-15 -2625 (|#10| |#5| |#3|)) (-15 -2176 ((-634 |#10|) |#3|)) (-15 -1410 ((-1249) |#10|)) (-15 -2390 ((-1249) |#10|)) (-15 -2190 ((-1249) |#10|)) (-15 -2190 ((-1249) |#10| (-634 |#3|))) (-15 -2126 ((-763) |#3|)) (-15 -1801 ((-568) |#3|)) (-15 -4424 ((-763) (-763) (-634 |#10|))) (-15 -2587 (|#8| |#10|)) (-15 -4207 ((-568) (-763) (-634 |#10|)))) 
-((-1551 (((-763) $) 30)) (-3666 (((-3 |#2| "failed") $) 17)) (-2854 ((|#2| $) 27)) (-4189 (($ $) 12) (($ $ (-763)) 15)) (-2745 (((-850) $) 26) (($ |#2|) 10)) (-1717 (((-121) $ $) 20)) (-1732 (((-121) $ $) 29))) 
-(((-261 |#1| |#2|) (-10 -8 (-15 -4189 (|#1| |#1| (-763))) (-15 -4189 (|#1| |#1|)) (-15 -1551 ((-763) |#1|)) (-15 -2854 (|#2| |#1|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -2745 (|#1| |#2|)) (-15 -1732 ((-121) |#1| |#1|)) (-15 -2745 ((-850) |#1|)) (-15 -1717 ((-121) |#1| |#1|))) (-262 |#2|) (-842)) (T -261)) 
-NIL 
-(-10 -8 (-15 -4189 (|#1| |#1| (-763))) (-15 -4189 (|#1| |#1|)) (-15 -1551 ((-763) |#1|)) (-15 -2854 (|#2| |#1|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -2745 (|#1| |#2|)) (-15 -1732 ((-121) |#1| |#1|)) (-15 -2745 ((-850) |#1|)) (-15 -1717 ((-121) |#1| |#1|))) 
-((-2447 (((-121) $ $) 7)) (-1551 (((-763) $) 21)) (-1305 ((|#1| $) 22)) (-3666 (((-3 |#1| "failed") $) 26)) (-2854 ((|#1| $) 25)) (-4477 (((-763) $) 23)) (-2521 (($ $ $) 12)) (-3268 (($ $ $) 13)) (-4300 (($ |#1| (-763)) 24)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-4189 (($ $) 20) (($ $ (-763)) 19)) (-2745 (((-850) $) 11) (($ |#1|) 27)) (-1751 (((-121) $ $) 15)) (-1738 (((-121) $ $) 16)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 14)) (-1732 (((-121) $ $) 17))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2852 ((|#1| $) 12)) (-1533 (($ |#1| (-634 $)) 31) (($ |#1|) 32) (($ (-634 |#1|)) 33)) (-1667 (((-121) $ (-763)) NIL)) (-3370 ((|#1| $ |#1|) 35 (|has| $ (-6 -4522)))) (-2438 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) 34 (|has| $ (-6 -4522)))) (-4490 (($) NIL T CONST)) (-3317 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-3534 (((-634 $) $) NIL)) (-3606 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3791 (((-121) $ (-763)) NIL)) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-2253 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-4081 (((-634 |#1|) $) 22)) (-3319 (((-121) $) NIL)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-4295 (((-121) (-121)) 18) (((-121)) 19)) (-2860 (((-850) $) 15)) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-3587 (((-1143) $) 28)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#1| $ "value") NIL)) (-1665 (((-568) $ $) NIL)) (-2763 (((-121) $) NIL)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) NIL)) (-2747 (((-850) $) 30 (|has| |#1| (-1090)))) (-3180 (((-634 $) $) 8)) (-3873 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 26 (|has| |#1| (-1090)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-259 |#1|) (-13 (-258 |#1|) (-10 -8 (-15 -3587 ((-1143) $)) (-15 -2860 ((-850) $)) (-15 -4295 ((-121) (-121))) (-15 -4295 ((-121))))) (-1090)) (T -259)) 
+((-3587 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-259 *3)) (-4 *3 (-1090)))) (-2860 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-259 *3)) (-4 *3 (-1090)))) (-4295 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-259 *3)) (-4 *3 (-1090)))) (-4295 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-259 *3)) (-4 *3 (-1090))))) 
+(-13 (-258 |#1|) (-10 -8 (-15 -3587 ((-1143) $)) (-15 -2860 ((-850) $)) (-15 -4295 ((-121) (-121))) (-15 -4295 ((-121))))) 
+((-2990 (((-1249) |#10| (-634 |#3|)) 133) (((-1249) |#10|) 135)) (-2229 (((-1249) |#10|) NIL)) (-2026 ((|#8| |#10|) 28)) (-4123 (((-568) (-763) (-634 |#10|)) 147)) (-1591 (((-763) (-763) (-634 |#10|)) 145)) (-2148 (((-568) |#3|) 148)) (-3383 (((-763) |#3|) 146)) (-2132 (((-1249) |#10|) 136)) (-2218 ((|#8| |#3| |#10|) 111)) (-4230 ((|#10| |#5| |#3|) 138)) (-3012 (((-634 |#10|) |#3|) 144)) (-3621 (((-1249) |#10|) 134)) (-2549 (((-634 |#9|) |#9|) 87)) (-2669 ((|#8| |#10|) 110))) 
+(((-260 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9| |#10| |#11|) (-10 -7 (-15 -2549 ((-634 |#9|) |#9|)) (-15 -2218 (|#8| |#3| |#10|)) (-15 -2669 (|#8| |#10|)) (-15 -3621 ((-1249) |#10|)) (-15 -4230 (|#10| |#5| |#3|)) (-15 -3012 ((-634 |#10|) |#3|)) (-15 -2132 ((-1249) |#10|)) (-15 -2229 ((-1249) |#10|)) (-15 -2990 ((-1249) |#10|)) (-15 -2990 ((-1249) |#10| (-634 |#3|))) (-15 -3383 ((-763) |#3|)) (-15 -2148 ((-568) |#3|)) (-15 -1591 ((-763) (-763) (-634 |#10|))) (-15 -2026 (|#8| |#10|)) (-15 -4123 ((-568) (-763) (-634 |#10|)))) (-365) (-634 (-1161)) (-950 |#1| |#4| (-852 |#2|)) (-230 (-1699 |#2|) (-763)) (-971 |#1|) (-641 |#1|) (-920 |#1| |#6|) (-235 |#7|) (-536 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#11|) (-258 |#9|) (-117)) (T -260)) 
+((-4123 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *14)) (-4 *14 (-258 *13)) (-4 *13 (-536 *5 *6 *7 *8 *9 *10 *11 *12 *15)) (-4 *15 (-117)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1699 *6) *3)) (-4 *9 (-971 *5)) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-4 *12 (-235 *11)) (-5 *3 (-763)) (-5 *2 (-568)) (-5 *1 (-260 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14 *15)))) (-2026 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-536 *4 *5 *6 *7 *8 *9 *10 *2 *12)) (-4 *12 (-117)) (-4 *2 (-235 *10)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *2 *11 *3 *12)) (-4 *3 (-258 *11)))) (-1591 (*1 *2 *2 *3) (-12 (-5 *3 (-634 *13)) (-4 *13 (-258 *12)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) *2)) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-5 *2 (-763)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)))) (-2148 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *6 (-230 (-1699 *5) (-763))) (-4 *7 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-568)) (-5 *1 (-260 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-3383 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *6 (-230 (-1699 *5) *2)) (-4 *7 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-763)) (-5 *1 (-260 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-2990 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *7)) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1699 *6) (-763))) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *9 (-971 *5)) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-4 *12 (-235 *11)) (-4 *13 (-536 *5 *6 *7 *8 *9 *10 *11 *12 *14)) (-4 *14 (-117)) (-5 *2 (-1249)) (-5 *1 (-260 *5 *6 *7 *8 *9 *10 *11 *12 *13 *3 *14)) (-4 *3 (-258 *13)))) (-2990 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1249)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-258 *12)))) (-2229 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1249)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-258 *12)))) (-2132 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1249)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-258 *12)))) (-3012 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *6 (-230 (-1699 *5) (-763))) (-4 *7 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *12)) (-5 *1 (-260 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-4230 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *4 (-950 *5 *7 (-852 *6))) (-4 *7 (-230 (-1699 *6) (-763))) (-4 *3 (-971 *5)) (-4 *8 (-641 *5)) (-4 *9 (-920 *5 *8)) (-4 *10 (-235 *9)) (-4 *12 (-117)) (-4 *2 (-258 *11)) (-5 *1 (-260 *5 *6 *4 *7 *3 *8 *9 *10 *11 *2 *12)) (-4 *11 (-536 *5 *6 *4 *7 *3 *8 *9 *10 *12)))) (-3621 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1249)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-258 *12)))) (-2669 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-536 *4 *5 *6 *7 *8 *9 *10 *2 *12)) (-4 *12 (-117)) (-4 *2 (-235 *10)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *2 *11 *3 *12)) (-4 *3 (-258 *11)))) (-2218 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *7 (-230 (-1699 *6) (-763))) (-4 *8 (-971 *5)) (-4 *9 (-641 *5)) (-4 *10 (-920 *5 *9)) (-4 *11 (-536 *5 *6 *3 *7 *8 *9 *10 *2 *12)) (-4 *12 (-117)) (-4 *2 (-235 *10)) (-5 *1 (-260 *5 *6 *3 *7 *8 *9 *10 *2 *11 *4 *12)) (-4 *4 (-258 *11)))) (-2549 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *3 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-634 *3)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13)) (-4 *12 (-258 *3))))) 
+(-10 -7 (-15 -2549 ((-634 |#9|) |#9|)) (-15 -2218 (|#8| |#3| |#10|)) (-15 -2669 (|#8| |#10|)) (-15 -3621 ((-1249) |#10|)) (-15 -4230 (|#10| |#5| |#3|)) (-15 -3012 ((-634 |#10|) |#3|)) (-15 -2132 ((-1249) |#10|)) (-15 -2229 ((-1249) |#10|)) (-15 -2990 ((-1249) |#10|)) (-15 -2990 ((-1249) |#10| (-634 |#3|))) (-15 -3383 ((-763) |#3|)) (-15 -2148 ((-568) |#3|)) (-15 -1591 ((-763) (-763) (-634 |#10|))) (-15 -2026 (|#8| |#10|)) (-15 -4123 ((-568) (-763) (-634 |#10|)))) 
+((-4308 (((-763) $) 30)) (-3668 (((-3 |#2| "failed") $) 17)) (-2857 ((|#2| $) 27)) (-4191 (($ $) 12) (($ $ (-763)) 15)) (-2747 (((-850) $) 26) (($ |#2|) 10)) (-1719 (((-121) $ $) 20)) (-1734 (((-121) $ $) 29))) 
+(((-261 |#1| |#2|) (-10 -8 (-15 -4191 (|#1| |#1| (-763))) (-15 -4191 (|#1| |#1|)) (-15 -4308 ((-763) |#1|)) (-15 -2857 (|#2| |#1|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -2747 (|#1| |#2|)) (-15 -1734 ((-121) |#1| |#1|)) (-15 -2747 ((-850) |#1|)) (-15 -1719 ((-121) |#1| |#1|))) (-262 |#2|) (-842)) (T -261)) 
+NIL 
+(-10 -8 (-15 -4191 (|#1| |#1| (-763))) (-15 -4191 (|#1| |#1|)) (-15 -4308 ((-763) |#1|)) (-15 -2857 (|#2| |#1|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -2747 (|#1| |#2|)) (-15 -1734 ((-121) |#1| |#1|)) (-15 -2747 ((-850) |#1|)) (-15 -1719 ((-121) |#1| |#1|))) 
+((-2449 (((-121) $ $) 7)) (-4308 (((-763) $) 21)) (-3325 ((|#1| $) 22)) (-3668 (((-3 |#1| "failed") $) 26)) (-2857 ((|#1| $) 25)) (-1844 (((-763) $) 23)) (-1732 (($ $ $) 12)) (-2047 (($ $ $) 13)) (-3029 (($ |#1| (-763)) 24)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-4191 (($ $) 20) (($ $ (-763)) 19)) (-2747 (((-850) $) 11) (($ |#1|) 27)) (-1753 (((-121) $ $) 15)) (-1740 (((-121) $ $) 16)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 14)) (-1734 (((-121) $ $) 17))) 
 (((-262 |#1|) (-1275) (-842)) (T -262)) 
-((-2745 (*1 *1 *2) (-12 (-4 *1 (-262 *2)) (-4 *2 (-842)))) (-4300 (*1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-262 *2)) (-4 *2 (-842)))) (-4477 (*1 *2 *1) (-12 (-4 *1 (-262 *3)) (-4 *3 (-842)) (-5 *2 (-763)))) (-1305 (*1 *2 *1) (-12 (-4 *1 (-262 *2)) (-4 *2 (-842)))) (-1551 (*1 *2 *1) (-12 (-4 *1 (-262 *3)) (-4 *3 (-842)) (-5 *2 (-763)))) (-4189 (*1 *1 *1) (-12 (-4 *1 (-262 *2)) (-4 *2 (-842)))) (-4189 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-262 *3)) (-4 *3 (-842))))) 
-(-13 (-842) (-1037 |t#1|) (-10 -8 (-15 -4300 ($ |t#1| (-763))) (-15 -4477 ((-763) $)) (-15 -1305 (|t#1| $)) (-15 -1551 ((-763) $)) (-15 -4189 ($ $)) (-15 -4189 ($ $ (-763))) (-15 -2745 ($ |t#1|)))) 
+((-2747 (*1 *1 *2) (-12 (-4 *1 (-262 *2)) (-4 *2 (-842)))) (-3029 (*1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-262 *2)) (-4 *2 (-842)))) (-1844 (*1 *2 *1) (-12 (-4 *1 (-262 *3)) (-4 *3 (-842)) (-5 *2 (-763)))) (-3325 (*1 *2 *1) (-12 (-4 *1 (-262 *2)) (-4 *2 (-842)))) (-4308 (*1 *2 *1) (-12 (-4 *1 (-262 *3)) (-4 *3 (-842)) (-5 *2 (-763)))) (-4191 (*1 *1 *1) (-12 (-4 *1 (-262 *2)) (-4 *2 (-842)))) (-4191 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-262 *3)) (-4 *3 (-842))))) 
+(-13 (-842) (-1037 |t#1|) (-10 -8 (-15 -3029 ($ |t#1| (-763))) (-15 -1844 ((-763) $)) (-15 -3325 (|t#1| $)) (-15 -4308 ((-763) $)) (-15 -4191 ($ $)) (-15 -4191 ($ $ (-763))) (-15 -2747 ($ |t#1|)))) 
 (((-105) . T) ((-608 (-850)) . T) ((-842) . T) ((-1037 |#1|) . T) ((-1090) . T)) 
-((-2055 (((-634 (-1161)) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) 40)) (-3595 (((-634 (-1161)) (-310 (-215)) (-763)) 79)) (-2423 (((-3 (-310 (-215)) "failed") (-310 (-215))) 50)) (-3159 (((-310 (-215)) (-310 (-215))) 65)) (-3021 (((-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215))))) (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 26)) (-1888 (((-121) (-634 (-310 (-215)))) 83)) (-4087 (((-121) (-310 (-215))) 24)) (-1885 (((-634 (-1143)) (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))))) 104)) (-1912 (((-634 (-310 (-215))) (-634 (-310 (-215)))) 86)) (-3110 (((-634 (-310 (-215))) (-634 (-310 (-215)))) 85)) (-1935 (((-679 (-215)) (-634 (-310 (-215))) (-763)) 93)) (-4364 (((-121) (-310 (-215))) 20) (((-121) (-634 (-310 (-215)))) 84)) (-3559 (((-634 (-215)) (-634 (-835 (-215))) (-215)) 14)) (-4014 (((-381) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) 99)) (-4165 (((-1035) (-1161) (-1035)) 33))) 
-(((-263) (-10 -7 (-15 -3559 ((-634 (-215)) (-634 (-835 (-215))) (-215))) (-15 -3021 ((-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215))))) (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215))))))) (-15 -2423 ((-3 (-310 (-215)) "failed") (-310 (-215)))) (-15 -3159 ((-310 (-215)) (-310 (-215)))) (-15 -1888 ((-121) (-634 (-310 (-215))))) (-15 -4364 ((-121) (-634 (-310 (-215))))) (-15 -4364 ((-121) (-310 (-215)))) (-15 -1935 ((-679 (-215)) (-634 (-310 (-215))) (-763))) (-15 -3110 ((-634 (-310 (-215))) (-634 (-310 (-215))))) (-15 -1912 ((-634 (-310 (-215))) (-634 (-310 (-215))))) (-15 -4087 ((-121) (-310 (-215)))) (-15 -2055 ((-634 (-1161)) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215)))))) (-15 -3595 ((-634 (-1161)) (-310 (-215)) (-763))) (-15 -4165 ((-1035) (-1161) (-1035))) (-15 -4014 ((-381) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215)))))) (-15 -1885 ((-634 (-1143)) (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215)))))))))) (T -263)) 
-((-1885 (*1 *2 *3) (-12 (-5 *3 (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))))) (-5 *2 (-634 (-1143))) (-5 *1 (-263)))) (-4014 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) (-5 *2 (-381)) (-5 *1 (-263)))) (-4165 (*1 *2 *3 *2) (-12 (-5 *2 (-1035)) (-5 *3 (-1161)) (-5 *1 (-263)))) (-3595 (*1 *2 *3 *4) (-12 (-5 *3 (-310 (-215))) (-5 *4 (-763)) (-5 *2 (-634 (-1161))) (-5 *1 (-263)))) (-2055 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) (-5 *2 (-634 (-1161))) (-5 *1 (-263)))) (-4087 (*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-121)) (-5 *1 (-263)))) (-1912 (*1 *2 *2) (-12 (-5 *2 (-634 (-310 (-215)))) (-5 *1 (-263)))) (-3110 (*1 *2 *2) (-12 (-5 *2 (-634 (-310 (-215)))) (-5 *1 (-263)))) (-1935 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-310 (-215)))) (-5 *4 (-763)) (-5 *2 (-679 (-215))) (-5 *1 (-263)))) (-4364 (*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-121)) (-5 *1 (-263)))) (-4364 (*1 *2 *3) (-12 (-5 *3 (-634 (-310 (-215)))) (-5 *2 (-121)) (-5 *1 (-263)))) (-1888 (*1 *2 *3) (-12 (-5 *3 (-634 (-310 (-215)))) (-5 *2 (-121)) (-5 *1 (-263)))) (-3159 (*1 *2 *2) (-12 (-5 *2 (-310 (-215))) (-5 *1 (-263)))) (-2423 (*1 *2 *2) (|partial| -12 (-5 *2 (-310 (-215))) (-5 *1 (-263)))) (-3021 (*1 *2 *2) (-12 (-5 *2 (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (-5 *1 (-263)))) (-3559 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-835 (-215)))) (-5 *4 (-215)) (-5 *2 (-634 *4)) (-5 *1 (-263))))) 
-(-10 -7 (-15 -3559 ((-634 (-215)) (-634 (-835 (-215))) (-215))) (-15 -3021 ((-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215))))) (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215))))))) (-15 -2423 ((-3 (-310 (-215)) "failed") (-310 (-215)))) (-15 -3159 ((-310 (-215)) (-310 (-215)))) (-15 -1888 ((-121) (-634 (-310 (-215))))) (-15 -4364 ((-121) (-634 (-310 (-215))))) (-15 -4364 ((-121) (-310 (-215)))) (-15 -1935 ((-679 (-215)) (-634 (-310 (-215))) (-763))) (-15 -3110 ((-634 (-310 (-215))) (-634 (-310 (-215))))) (-15 -1912 ((-634 (-310 (-215))) (-634 (-310 (-215))))) (-15 -4087 ((-121) (-310 (-215)))) (-15 -2055 ((-634 (-1161)) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215)))))) (-15 -3595 ((-634 (-1161)) (-310 (-215)) (-763))) (-15 -4165 ((-1035) (-1161) (-1035))) (-15 -4014 ((-381) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215)))))) (-15 -1885 ((-634 (-1143)) (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))))))) 
-((-2447 (((-121) $ $) NIL)) (-2855 (((-1035) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) NIL) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 39)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 20) (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2057 (((-634 (-1161)) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) 40)) (-2981 (((-634 (-1161)) (-310 (-215)) (-763)) 79)) (-2389 (((-3 (-310 (-215)) "failed") (-310 (-215))) 50)) (-1650 (((-310 (-215)) (-310 (-215))) 65)) (-3256 (((-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215))))) (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 26)) (-2569 (((-121) (-634 (-310 (-215)))) 83)) (-3469 (((-121) (-310 (-215))) 24)) (-2559 (((-634 (-1143)) (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))))) 104)) (-2681 (((-634 (-310 (-215))) (-634 (-310 (-215)))) 86)) (-2556 (((-634 (-310 (-215))) (-634 (-310 (-215)))) 85)) (-4205 (((-679 (-215)) (-634 (-310 (-215))) (-763)) 93)) (-3338 (((-121) (-310 (-215))) 20) (((-121) (-634 (-310 (-215)))) 84)) (-2845 (((-634 (-215)) (-634 (-835 (-215))) (-215)) 14)) (-1402 (((-381) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) 99)) (-3900 (((-1035) (-1161) (-1035)) 33))) 
+(((-263) (-10 -7 (-15 -2845 ((-634 (-215)) (-634 (-835 (-215))) (-215))) (-15 -3256 ((-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215))))) (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215))))))) (-15 -2389 ((-3 (-310 (-215)) "failed") (-310 (-215)))) (-15 -1650 ((-310 (-215)) (-310 (-215)))) (-15 -2569 ((-121) (-634 (-310 (-215))))) (-15 -3338 ((-121) (-634 (-310 (-215))))) (-15 -3338 ((-121) (-310 (-215)))) (-15 -4205 ((-679 (-215)) (-634 (-310 (-215))) (-763))) (-15 -2556 ((-634 (-310 (-215))) (-634 (-310 (-215))))) (-15 -2681 ((-634 (-310 (-215))) (-634 (-310 (-215))))) (-15 -3469 ((-121) (-310 (-215)))) (-15 -2057 ((-634 (-1161)) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215)))))) (-15 -2981 ((-634 (-1161)) (-310 (-215)) (-763))) (-15 -3900 ((-1035) (-1161) (-1035))) (-15 -1402 ((-381) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215)))))) (-15 -2559 ((-634 (-1143)) (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215)))))))))) (T -263)) 
+((-2559 (*1 *2 *3) (-12 (-5 *3 (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))))) (-5 *2 (-634 (-1143))) (-5 *1 (-263)))) (-1402 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) (-5 *2 (-381)) (-5 *1 (-263)))) (-3900 (*1 *2 *3 *2) (-12 (-5 *2 (-1035)) (-5 *3 (-1161)) (-5 *1 (-263)))) (-2981 (*1 *2 *3 *4) (-12 (-5 *3 (-310 (-215))) (-5 *4 (-763)) (-5 *2 (-634 (-1161))) (-5 *1 (-263)))) (-2057 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) (-5 *2 (-634 (-1161))) (-5 *1 (-263)))) (-3469 (*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-121)) (-5 *1 (-263)))) (-2681 (*1 *2 *2) (-12 (-5 *2 (-634 (-310 (-215)))) (-5 *1 (-263)))) (-2556 (*1 *2 *2) (-12 (-5 *2 (-634 (-310 (-215)))) (-5 *1 (-263)))) (-4205 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-310 (-215)))) (-5 *4 (-763)) (-5 *2 (-679 (-215))) (-5 *1 (-263)))) (-3338 (*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-121)) (-5 *1 (-263)))) (-3338 (*1 *2 *3) (-12 (-5 *3 (-634 (-310 (-215)))) (-5 *2 (-121)) (-5 *1 (-263)))) (-2569 (*1 *2 *3) (-12 (-5 *3 (-634 (-310 (-215)))) (-5 *2 (-121)) (-5 *1 (-263)))) (-1650 (*1 *2 *2) (-12 (-5 *2 (-310 (-215))) (-5 *1 (-263)))) (-2389 (*1 *2 *2) (|partial| -12 (-5 *2 (-310 (-215))) (-5 *1 (-263)))) (-3256 (*1 *2 *2) (-12 (-5 *2 (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (-5 *1 (-263)))) (-2845 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-835 (-215)))) (-5 *4 (-215)) (-5 *2 (-634 *4)) (-5 *1 (-263))))) 
+(-10 -7 (-15 -2845 ((-634 (-215)) (-634 (-835 (-215))) (-215))) (-15 -3256 ((-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215))))) (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215))))))) (-15 -2389 ((-3 (-310 (-215)) "failed") (-310 (-215)))) (-15 -1650 ((-310 (-215)) (-310 (-215)))) (-15 -2569 ((-121) (-634 (-310 (-215))))) (-15 -3338 ((-121) (-634 (-310 (-215))))) (-15 -3338 ((-121) (-310 (-215)))) (-15 -4205 ((-679 (-215)) (-634 (-310 (-215))) (-763))) (-15 -2556 ((-634 (-310 (-215))) (-634 (-310 (-215))))) (-15 -2681 ((-634 (-310 (-215))) (-634 (-310 (-215))))) (-15 -3469 ((-121) (-310 (-215)))) (-15 -2057 ((-634 (-1161)) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215)))))) (-15 -2981 ((-634 (-1161)) (-310 (-215)) (-763))) (-15 -3900 ((-1035) (-1161) (-1035))) (-15 -1402 ((-381) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215)))))) (-15 -2559 ((-634 (-1143)) (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))))))) 
+((-2449 (((-121) $ $) NIL)) (-3994 (((-1035) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) NIL) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 39)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 20) (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-264) (-831)) (T -264)) 
 NIL 
 (-831) 
-((-2447 (((-121) $ $) NIL)) (-2855 (((-1035) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) 54) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 49)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 29) (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) 31)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-3994 (((-1035) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) 54) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 49)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 29) (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) 31)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-265) (-831)) (T -265)) 
 NIL 
 (-831) 
-((-2447 (((-121) $ $) NIL)) (-2855 (((-1035) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) 73) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 69)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 40) (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) 51)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-3994 (((-1035) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) 73) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 69)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 40) (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) 51)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-266) (-831)) (T -266)) 
 NIL 
 (-831) 
-((-2447 (((-121) $ $) NIL)) (-2855 (((-1035) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) NIL) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 48)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 27) (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-3994 (((-1035) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) NIL) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 48)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 27) (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-267) (-831)) (T -267)) 
 NIL 
 (-831) 
-((-2447 (((-121) $ $) NIL)) (-2855 (((-1035) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) NIL) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 48)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 23) (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-3994 (((-1035) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) NIL) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 48)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 23) (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-268) (-831)) (T -268)) 
 NIL 
 (-831) 
-((-2447 (((-121) $ $) NIL)) (-2855 (((-1035) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) NIL) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 69)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 23) (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-3994 (((-1035) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) NIL) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 69)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 23) (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-269) (-831)) (T -269)) 
 NIL 
 (-831) 
-((-2447 (((-121) $ $) NIL)) (-2855 (((-1035) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) NIL) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 73)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 19) (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-3994 (((-1035) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) NIL) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 73)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 19) (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-270) (-831)) (T -270)) 
 NIL 
 (-831) 
-((-2447 (((-121) $ $) NIL)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-1889 (((-634 (-568)) $) 16)) (-3206 (((-763) $) 14)) (-2745 (((-850) $) 20) (($ (-634 (-568))) 12)) (-4134 (($ (-763)) 17)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 9)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 10))) 
-(((-271) (-13 (-842) (-10 -8 (-15 -2745 ($ (-634 (-568)))) (-15 -3206 ((-763) $)) (-15 -1889 ((-634 (-568)) $)) (-15 -4134 ($ (-763)))))) (T -271)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-271)))) (-3206 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-271)))) (-1889 (*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-271)))) (-4134 (*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-271))))) 
-(-13 (-842) (-10 -8 (-15 -2745 ($ (-634 (-568)))) (-15 -3206 ((-763) $)) (-15 -1889 ((-634 (-568)) $)) (-15 -4134 ($ (-763))))) 
-((-1982 ((|#2| |#2|) 77)) (-1933 ((|#2| |#2|) 65)) (-2124 (((-3 |#2| "failed") |#2| (-634 (-2 (|:| |func| |#2|) (|:| |pole| (-121))))) 116)) (-1974 ((|#2| |#2|) 75)) (-2786 ((|#2| |#2|) 63)) (-1990 ((|#2| |#2|) 79)) (-1941 ((|#2| |#2|) 67)) (-1897 ((|#2|) 46)) (-3488 (((-123) (-123)) 95)) (-4416 ((|#2| |#2|) 61)) (-1926 (((-121) |#2|) 134)) (-2610 ((|#2| |#2|) 180)) (-3445 ((|#2| |#2|) 156)) (-2158 ((|#2|) 59)) (-1735 ((|#2|) 58)) (-3796 ((|#2| |#2|) 176)) (-2138 ((|#2| |#2|) 152)) (-3331 ((|#2| |#2|) 184)) (-1728 ((|#2| |#2|) 160)) (-3486 ((|#2| |#2|) 148)) (-2777 ((|#2| |#2|) 150)) (-2867 ((|#2| |#2|) 186)) (-1439 ((|#2| |#2|) 162)) (-3513 ((|#2| |#2|) 182)) (-2996 ((|#2| |#2|) 158)) (-4306 ((|#2| |#2|) 178)) (-2261 ((|#2| |#2|) 154)) (-4270 ((|#2| |#2|) 192)) (-3351 ((|#2| |#2|) 168)) (-3667 ((|#2| |#2|) 188)) (-2585 ((|#2| |#2|) 164)) (-2073 ((|#2| |#2|) 196)) (-1404 ((|#2| |#2|) 172)) (-1701 ((|#2| |#2|) 198)) (-3215 ((|#2| |#2|) 174)) (-1504 ((|#2| |#2|) 194)) (-1563 ((|#2| |#2|) 170)) (-2731 ((|#2| |#2|) 190)) (-4247 ((|#2| |#2|) 166)) (-1892 ((|#2| |#2|) 62)) (-1994 ((|#2| |#2|) 80)) (-1945 ((|#2| |#2|) 68)) (-1986 ((|#2| |#2|) 78)) (-1937 ((|#2| |#2|) 66)) (-1978 ((|#2| |#2|) 76)) (-2790 ((|#2| |#2|) 64)) (-2887 (((-121) (-123)) 93)) (-2006 ((|#2| |#2|) 83)) (-1958 ((|#2| |#2|) 71)) (-1998 ((|#2| |#2|) 81)) (-1949 ((|#2| |#2|) 69)) (-2014 ((|#2| |#2|) 85)) (-1966 ((|#2| |#2|) 73)) (-4023 ((|#2| |#2|) 86)) (-1970 ((|#2| |#2|) 74)) (-2010 ((|#2| |#2|) 84)) (-1962 ((|#2| |#2|) 72)) (-2002 ((|#2| |#2|) 82)) (-1953 ((|#2| |#2|) 70))) 
-(((-272 |#1| |#2|) (-10 -7 (-15 -1892 (|#2| |#2|)) (-15 -4416 (|#2| |#2|)) (-15 -2786 (|#2| |#2|)) (-15 -2790 (|#2| |#2|)) (-15 -1933 (|#2| |#2|)) (-15 -1937 (|#2| |#2|)) (-15 -1941 (|#2| |#2|)) (-15 -1945 (|#2| |#2|)) (-15 -1949 (|#2| |#2|)) (-15 -1953 (|#2| |#2|)) (-15 -1958 (|#2| |#2|)) (-15 -1962 (|#2| |#2|)) (-15 -1966 (|#2| |#2|)) (-15 -1970 (|#2| |#2|)) (-15 -1974 (|#2| |#2|)) (-15 -1978 (|#2| |#2|)) (-15 -1982 (|#2| |#2|)) (-15 -1986 (|#2| |#2|)) (-15 -1990 (|#2| |#2|)) (-15 -1994 (|#2| |#2|)) (-15 -1998 (|#2| |#2|)) (-15 -2002 (|#2| |#2|)) (-15 -2006 (|#2| |#2|)) (-15 -2010 (|#2| |#2|)) (-15 -2014 (|#2| |#2|)) (-15 -4023 (|#2| |#2|)) (-15 -1897 (|#2|)) (-15 -2887 ((-121) (-123))) (-15 -3488 ((-123) (-123))) (-15 -1735 (|#2|)) (-15 -2158 (|#2|)) (-15 -2777 (|#2| |#2|)) (-15 -3486 (|#2| |#2|)) (-15 -2138 (|#2| |#2|)) (-15 -2261 (|#2| |#2|)) (-15 -3445 (|#2| |#2|)) (-15 -2996 (|#2| |#2|)) (-15 -1728 (|#2| |#2|)) (-15 -1439 (|#2| |#2|)) (-15 -2585 (|#2| |#2|)) (-15 -4247 (|#2| |#2|)) (-15 -3351 (|#2| |#2|)) (-15 -1563 (|#2| |#2|)) (-15 -1404 (|#2| |#2|)) (-15 -3215 (|#2| |#2|)) (-15 -3796 (|#2| |#2|)) (-15 -4306 (|#2| |#2|)) (-15 -2610 (|#2| |#2|)) (-15 -3513 (|#2| |#2|)) (-15 -3331 (|#2| |#2|)) (-15 -2867 (|#2| |#2|)) (-15 -3667 (|#2| |#2|)) (-15 -2731 (|#2| |#2|)) (-15 -4270 (|#2| |#2|)) (-15 -1504 (|#2| |#2|)) (-15 -2073 (|#2| |#2|)) (-15 -1701 (|#2| |#2|)) (-15 -2124 ((-3 |#2| "failed") |#2| (-634 (-2 (|:| |func| |#2|) (|:| |pole| (-121)))))) (-15 -1926 ((-121) |#2|))) (-13 (-842) (-558)) (-13 (-432 |#1|) (-1002))) (T -272)) 
-((-1926 (*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-272 *4 *3)) (-4 *3 (-13 (-432 *4) (-1002))))) (-2124 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-634 (-2 (|:| |func| *2) (|:| |pole| (-121))))) (-4 *2 (-13 (-432 *4) (-1002))) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-272 *4 *2)))) (-1701 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2073 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1504 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-4270 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2731 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-3667 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2867 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-3331 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-3513 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2610 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-4306 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-3796 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-3215 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1404 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1563 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-3351 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-4247 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2585 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1439 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1728 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2996 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-3445 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2261 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2138 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-3486 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2777 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2158 (*1 *2) (-12 (-4 *2 (-13 (-432 *3) (-1002))) (-5 *1 (-272 *3 *2)) (-4 *3 (-13 (-842) (-558))))) (-1735 (*1 *2) (-12 (-4 *2 (-13 (-432 *3) (-1002))) (-5 *1 (-272 *3 *2)) (-4 *3 (-13 (-842) (-558))))) (-3488 (*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *4)) (-4 *4 (-13 (-432 *3) (-1002))))) (-2887 (*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-272 *4 *5)) (-4 *5 (-13 (-432 *4) (-1002))))) (-1897 (*1 *2) (-12 (-4 *2 (-13 (-432 *3) (-1002))) (-5 *1 (-272 *3 *2)) (-4 *3 (-13 (-842) (-558))))) (-4023 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2014 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2010 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2006 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2002 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1998 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1994 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1990 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1986 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1982 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1978 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1974 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1970 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1966 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1962 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1958 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1953 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1949 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1945 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1941 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1937 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1933 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2790 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2786 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-4416 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1892 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(-10 -7 (-15 -1892 (|#2| |#2|)) (-15 -4416 (|#2| |#2|)) (-15 -2786 (|#2| |#2|)) (-15 -2790 (|#2| |#2|)) (-15 -1933 (|#2| |#2|)) (-15 -1937 (|#2| |#2|)) (-15 -1941 (|#2| |#2|)) (-15 -1945 (|#2| |#2|)) (-15 -1949 (|#2| |#2|)) (-15 -1953 (|#2| |#2|)) (-15 -1958 (|#2| |#2|)) (-15 -1962 (|#2| |#2|)) (-15 -1966 (|#2| |#2|)) (-15 -1970 (|#2| |#2|)) (-15 -1974 (|#2| |#2|)) (-15 -1978 (|#2| |#2|)) (-15 -1982 (|#2| |#2|)) (-15 -1986 (|#2| |#2|)) (-15 -1990 (|#2| |#2|)) (-15 -1994 (|#2| |#2|)) (-15 -1998 (|#2| |#2|)) (-15 -2002 (|#2| |#2|)) (-15 -2006 (|#2| |#2|)) (-15 -2010 (|#2| |#2|)) (-15 -2014 (|#2| |#2|)) (-15 -4023 (|#2| |#2|)) (-15 -1897 (|#2|)) (-15 -2887 ((-121) (-123))) (-15 -3488 ((-123) (-123))) (-15 -1735 (|#2|)) (-15 -2158 (|#2|)) (-15 -2777 (|#2| |#2|)) (-15 -3486 (|#2| |#2|)) (-15 -2138 (|#2| |#2|)) (-15 -2261 (|#2| |#2|)) (-15 -3445 (|#2| |#2|)) (-15 -2996 (|#2| |#2|)) (-15 -1728 (|#2| |#2|)) (-15 -1439 (|#2| |#2|)) (-15 -2585 (|#2| |#2|)) (-15 -4247 (|#2| |#2|)) (-15 -3351 (|#2| |#2|)) (-15 -1563 (|#2| |#2|)) (-15 -1404 (|#2| |#2|)) (-15 -3215 (|#2| |#2|)) (-15 -3796 (|#2| |#2|)) (-15 -4306 (|#2| |#2|)) (-15 -2610 (|#2| |#2|)) (-15 -3513 (|#2| |#2|)) (-15 -3331 (|#2| |#2|)) (-15 -2867 (|#2| |#2|)) (-15 -3667 (|#2| |#2|)) (-15 -2731 (|#2| |#2|)) (-15 -4270 (|#2| |#2|)) (-15 -1504 (|#2| |#2|)) (-15 -2073 (|#2| |#2|)) (-15 -1701 (|#2| |#2|)) (-15 -2124 ((-3 |#2| "failed") |#2| (-634 (-2 (|:| |func| |#2|) (|:| |pole| (-121)))))) (-15 -1926 ((-121) |#2|))) 
-((-3987 (((-3 |#2| "failed") (-634 (-607 |#2|)) |#2| (-1161)) 133)) (-4455 ((|#2| (-409 (-568)) |#2|) 50)) (-2711 ((|#2| |#2| (-607 |#2|)) 126)) (-1542 (((-2 (|:| |func| |#2|) (|:| |kers| (-634 (-607 |#2|))) (|:| |vals| (-634 |#2|))) |#2| (-1161)) 125)) (-3031 ((|#2| |#2| (-1161)) 19) ((|#2| |#2|) 22)) (-3628 ((|#2| |#2| (-1161)) 139) ((|#2| |#2|) 137))) 
-(((-273 |#1| |#2|) (-10 -7 (-15 -3628 (|#2| |#2|)) (-15 -3628 (|#2| |#2| (-1161))) (-15 -1542 ((-2 (|:| |func| |#2|) (|:| |kers| (-634 (-607 |#2|))) (|:| |vals| (-634 |#2|))) |#2| (-1161))) (-15 -3031 (|#2| |#2|)) (-15 -3031 (|#2| |#2| (-1161))) (-15 -3987 ((-3 |#2| "failed") (-634 (-607 |#2|)) |#2| (-1161))) (-15 -2711 (|#2| |#2| (-607 |#2|))) (-15 -4455 (|#2| (-409 (-568)) |#2|))) (-13 (-558) (-842) (-1037 (-568)) (-630 (-568))) (-13 (-27) (-1181) (-432 |#1|))) (T -273)) 
-((-4455 (*1 *2 *3 *2) (-12 (-5 *3 (-409 (-568))) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4))))) (-2711 (*1 *2 *2 *3) (-12 (-5 *3 (-607 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4))) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *4 *2)))) (-3987 (*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-634 (-607 *2))) (-5 *4 (-1161)) (-4 *2 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *5 *2)))) (-3031 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4))))) (-3031 (*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3))))) (-1542 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-2 (|:| |func| *3) (|:| |kers| (-634 (-607 *3))) (|:| |vals| (-634 *3)))) (-5 *1 (-273 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) (-3628 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4))))) (-3628 (*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3)))))) 
-(-10 -7 (-15 -3628 (|#2| |#2|)) (-15 -3628 (|#2| |#2| (-1161))) (-15 -1542 ((-2 (|:| |func| |#2|) (|:| |kers| (-634 (-607 |#2|))) (|:| |vals| (-634 |#2|))) |#2| (-1161))) (-15 -3031 (|#2| |#2|)) (-15 -3031 (|#2| |#2| (-1161))) (-15 -3987 ((-3 |#2| "failed") (-634 (-607 |#2|)) |#2| (-1161))) (-15 -2711 (|#2| |#2| (-607 |#2|))) (-15 -4455 (|#2| (-409 (-568)) |#2|))) 
-((-2588 (((-3 |#3| "failed") |#3|) 110)) (-1982 ((|#3| |#3|) 131)) (-4444 (((-3 |#3| "failed") |#3|) 82)) (-1933 ((|#3| |#3|) 121)) (-3458 (((-3 |#3| "failed") |#3|) 58)) (-1974 ((|#3| |#3|) 129)) (-1856 (((-3 |#3| "failed") |#3|) 46)) (-2786 ((|#3| |#3|) 119)) (-2369 (((-3 |#3| "failed") |#3|) 112)) (-1990 ((|#3| |#3|) 133)) (-3864 (((-3 |#3| "failed") |#3|) 84)) (-1941 ((|#3| |#3|) 123)) (-1623 (((-3 |#3| "failed") |#3| (-763)) 36)) (-3269 (((-3 |#3| "failed") |#3|) 74)) (-4416 ((|#3| |#3|) 118)) (-1648 (((-3 |#3| "failed") |#3|) 44)) (-1892 ((|#3| |#3|) 117)) (-3511 (((-3 |#3| "failed") |#3|) 113)) (-1994 ((|#3| |#3|) 134)) (-4206 (((-3 |#3| "failed") |#3|) 85)) (-1945 ((|#3| |#3|) 124)) (-2581 (((-3 |#3| "failed") |#3|) 111)) (-1986 ((|#3| |#3|) 132)) (-3509 (((-3 |#3| "failed") |#3|) 83)) (-1937 ((|#3| |#3|) 122)) (-1390 (((-3 |#3| "failed") |#3|) 60)) (-1978 ((|#3| |#3|) 130)) (-3322 (((-3 |#3| "failed") |#3|) 48)) (-2790 ((|#3| |#3|) 120)) (-1778 (((-3 |#3| "failed") |#3|) 66)) (-2006 ((|#3| |#3|) 137)) (-1981 (((-3 |#3| "failed") |#3|) 104)) (-1958 ((|#3| |#3|) 142)) (-2037 (((-3 |#3| "failed") |#3|) 62)) (-1998 ((|#3| |#3|) 135)) (-3984 (((-3 |#3| "failed") |#3|) 50)) (-1949 ((|#3| |#3|) 125)) (-1780 (((-3 |#3| "failed") |#3|) 70)) (-2014 ((|#3| |#3|) 139)) (-3517 (((-3 |#3| "failed") |#3|) 54)) (-1966 ((|#3| |#3|) 127)) (-2136 (((-3 |#3| "failed") |#3|) 72)) (-4023 ((|#3| |#3|) 140)) (-4316 (((-3 |#3| "failed") |#3|) 56)) (-1970 ((|#3| |#3|) 128)) (-2236 (((-3 |#3| "failed") |#3|) 68)) (-2010 ((|#3| |#3|) 138)) (-3053 (((-3 |#3| "failed") |#3|) 107)) (-1962 ((|#3| |#3|) 143)) (-3525 (((-3 |#3| "failed") |#3|) 64)) (-2002 ((|#3| |#3|) 136)) (-3928 (((-3 |#3| "failed") |#3|) 52)) (-1953 ((|#3| |#3|) 126)) (** ((|#3| |#3| (-409 (-568))) 40 (|has| |#1| (-365))))) 
-(((-274 |#1| |#2| |#3|) (-13 (-984 |#3|) (-10 -7 (IF (|has| |#1| (-365)) (-15 ** (|#3| |#3| (-409 (-568)))) |noBranch|) (-15 -1892 (|#3| |#3|)) (-15 -4416 (|#3| |#3|)) (-15 -2786 (|#3| |#3|)) (-15 -2790 (|#3| |#3|)) (-15 -1933 (|#3| |#3|)) (-15 -1937 (|#3| |#3|)) (-15 -1941 (|#3| |#3|)) (-15 -1945 (|#3| |#3|)) (-15 -1949 (|#3| |#3|)) (-15 -1953 (|#3| |#3|)) (-15 -1958 (|#3| |#3|)) (-15 -1962 (|#3| |#3|)) (-15 -1966 (|#3| |#3|)) (-15 -1970 (|#3| |#3|)) (-15 -1974 (|#3| |#3|)) (-15 -1978 (|#3| |#3|)) (-15 -1982 (|#3| |#3|)) (-15 -1986 (|#3| |#3|)) (-15 -1990 (|#3| |#3|)) (-15 -1994 (|#3| |#3|)) (-15 -1998 (|#3| |#3|)) (-15 -2002 (|#3| |#3|)) (-15 -2006 (|#3| |#3|)) (-15 -2010 (|#3| |#3|)) (-15 -2014 (|#3| |#3|)) (-15 -4023 (|#3| |#3|)))) (-43 (-409 (-568))) (-1234 |#1|) (-1205 |#1| |#2|)) (T -274)) 
-((** (*1 *2 *2 *3) (-12 (-5 *3 (-409 (-568))) (-4 *4 (-365)) (-4 *4 (-43 *3)) (-4 *5 (-1234 *4)) (-5 *1 (-274 *4 *5 *2)) (-4 *2 (-1205 *4 *5)))) (-1892 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-4416 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-2786 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-2790 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1933 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1937 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1941 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1945 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1949 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1953 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1958 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1962 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1966 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1970 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1974 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1978 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1982 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1986 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1990 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1994 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1998 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-2002 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-2006 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-2010 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-2014 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-4023 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4))))) 
-(-13 (-984 |#3|) (-10 -7 (IF (|has| |#1| (-365)) (-15 ** (|#3| |#3| (-409 (-568)))) |noBranch|) (-15 -1892 (|#3| |#3|)) (-15 -4416 (|#3| |#3|)) (-15 -2786 (|#3| |#3|)) (-15 -2790 (|#3| |#3|)) (-15 -1933 (|#3| |#3|)) (-15 -1937 (|#3| |#3|)) (-15 -1941 (|#3| |#3|)) (-15 -1945 (|#3| |#3|)) (-15 -1949 (|#3| |#3|)) (-15 -1953 (|#3| |#3|)) (-15 -1958 (|#3| |#3|)) (-15 -1962 (|#3| |#3|)) (-15 -1966 (|#3| |#3|)) (-15 -1970 (|#3| |#3|)) (-15 -1974 (|#3| |#3|)) (-15 -1978 (|#3| |#3|)) (-15 -1982 (|#3| |#3|)) (-15 -1986 (|#3| |#3|)) (-15 -1990 (|#3| |#3|)) (-15 -1994 (|#3| |#3|)) (-15 -1998 (|#3| |#3|)) (-15 -2002 (|#3| |#3|)) (-15 -2006 (|#3| |#3|)) (-15 -2010 (|#3| |#3|)) (-15 -2014 (|#3| |#3|)) (-15 -4023 (|#3| |#3|)))) 
-((-2588 (((-3 |#3| "failed") |#3|) 66)) (-1982 ((|#3| |#3|) 133)) (-4444 (((-3 |#3| "failed") |#3|) 50)) (-1933 ((|#3| |#3|) 121)) (-3458 (((-3 |#3| "failed") |#3|) 62)) (-1974 ((|#3| |#3|) 131)) (-1856 (((-3 |#3| "failed") |#3|) 46)) (-2786 ((|#3| |#3|) 119)) (-2369 (((-3 |#3| "failed") |#3|) 70)) (-1990 ((|#3| |#3|) 135)) (-3864 (((-3 |#3| "failed") |#3|) 54)) (-1941 ((|#3| |#3|) 123)) (-1623 (((-3 |#3| "failed") |#3| (-763)) 35)) (-3269 (((-3 |#3| "failed") |#3|) 44)) (-4416 ((|#3| |#3|) 112)) (-1648 (((-3 |#3| "failed") |#3|) 42)) (-1892 ((|#3| |#3|) 118)) (-3511 (((-3 |#3| "failed") |#3|) 72)) (-1994 ((|#3| |#3|) 136)) (-4206 (((-3 |#3| "failed") |#3|) 56)) (-1945 ((|#3| |#3|) 124)) (-2581 (((-3 |#3| "failed") |#3|) 68)) (-1986 ((|#3| |#3|) 134)) (-3509 (((-3 |#3| "failed") |#3|) 52)) (-1937 ((|#3| |#3|) 122)) (-1390 (((-3 |#3| "failed") |#3|) 64)) (-1978 ((|#3| |#3|) 132)) (-3322 (((-3 |#3| "failed") |#3|) 48)) (-2790 ((|#3| |#3|) 120)) (-1778 (((-3 |#3| "failed") |#3|) 78)) (-2006 ((|#3| |#3|) 139)) (-1981 (((-3 |#3| "failed") |#3|) 58)) (-1958 ((|#3| |#3|) 127)) (-2037 (((-3 |#3| "failed") |#3|) 74)) (-1998 ((|#3| |#3|) 137)) (-3984 (((-3 |#3| "failed") |#3|) 102)) (-1949 ((|#3| |#3|) 125)) (-1780 (((-3 |#3| "failed") |#3|) 82)) (-2014 ((|#3| |#3|) 141)) (-3517 (((-3 |#3| "failed") |#3|) 109)) (-1966 ((|#3| |#3|) 129)) (-2136 (((-3 |#3| "failed") |#3|) 84)) (-4023 ((|#3| |#3|) 142)) (-4316 (((-3 |#3| "failed") |#3|) 111)) (-1970 ((|#3| |#3|) 130)) (-2236 (((-3 |#3| "failed") |#3|) 80)) (-2010 ((|#3| |#3|) 140)) (-3053 (((-3 |#3| "failed") |#3|) 60)) (-1962 ((|#3| |#3|) 128)) (-3525 (((-3 |#3| "failed") |#3|) 76)) (-2002 ((|#3| |#3|) 138)) (-3928 (((-3 |#3| "failed") |#3|) 105)) (-1953 ((|#3| |#3|) 126)) (** ((|#3| |#3| (-409 (-568))) 40 (|has| |#1| (-365))))) 
-(((-275 |#1| |#2| |#3| |#4|) (-13 (-984 |#3|) (-10 -7 (IF (|has| |#1| (-365)) (-15 ** (|#3| |#3| (-409 (-568)))) |noBranch|) (-15 -1892 (|#3| |#3|)) (-15 -4416 (|#3| |#3|)) (-15 -2786 (|#3| |#3|)) (-15 -2790 (|#3| |#3|)) (-15 -1933 (|#3| |#3|)) (-15 -1937 (|#3| |#3|)) (-15 -1941 (|#3| |#3|)) (-15 -1945 (|#3| |#3|)) (-15 -1949 (|#3| |#3|)) (-15 -1953 (|#3| |#3|)) (-15 -1958 (|#3| |#3|)) (-15 -1962 (|#3| |#3|)) (-15 -1966 (|#3| |#3|)) (-15 -1970 (|#3| |#3|)) (-15 -1974 (|#3| |#3|)) (-15 -1978 (|#3| |#3|)) (-15 -1982 (|#3| |#3|)) (-15 -1986 (|#3| |#3|)) (-15 -1990 (|#3| |#3|)) (-15 -1994 (|#3| |#3|)) (-15 -1998 (|#3| |#3|)) (-15 -2002 (|#3| |#3|)) (-15 -2006 (|#3| |#3|)) (-15 -2010 (|#3| |#3|)) (-15 -2014 (|#3| |#3|)) (-15 -4023 (|#3| |#3|)))) (-43 (-409 (-568))) (-1203 |#1|) (-1226 |#1| |#2|) (-984 |#2|)) (T -275)) 
-((** (*1 *2 *2 *3) (-12 (-5 *3 (-409 (-568))) (-4 *4 (-365)) (-4 *4 (-43 *3)) (-4 *5 (-1203 *4)) (-5 *1 (-275 *4 *5 *2 *6)) (-4 *2 (-1226 *4 *5)) (-4 *6 (-984 *5)))) (-1892 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-4416 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-2786 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-2790 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1933 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1937 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1941 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1945 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1949 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1953 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1958 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1962 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1966 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1970 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1974 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1978 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1982 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1986 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1990 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1994 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1998 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-2002 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-2006 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-2010 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-2014 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-4023 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4))))) 
-(-13 (-984 |#3|) (-10 -7 (IF (|has| |#1| (-365)) (-15 ** (|#3| |#3| (-409 (-568)))) |noBranch|) (-15 -1892 (|#3| |#3|)) (-15 -4416 (|#3| |#3|)) (-15 -2786 (|#3| |#3|)) (-15 -2790 (|#3| |#3|)) (-15 -1933 (|#3| |#3|)) (-15 -1937 (|#3| |#3|)) (-15 -1941 (|#3| |#3|)) (-15 -1945 (|#3| |#3|)) (-15 -1949 (|#3| |#3|)) (-15 -1953 (|#3| |#3|)) (-15 -1958 (|#3| |#3|)) (-15 -1962 (|#3| |#3|)) (-15 -1966 (|#3| |#3|)) (-15 -1970 (|#3| |#3|)) (-15 -1974 (|#3| |#3|)) (-15 -1978 (|#3| |#3|)) (-15 -1982 (|#3| |#3|)) (-15 -1986 (|#3| |#3|)) (-15 -1990 (|#3| |#3|)) (-15 -1994 (|#3| |#3|)) (-15 -1998 (|#3| |#3|)) (-15 -2002 (|#3| |#3|)) (-15 -2006 (|#3| |#3|)) (-15 -2010 (|#3| |#3|)) (-15 -2014 (|#3| |#3|)) (-15 -4023 (|#3| |#3|)))) 
-((-2801 (($ (-1 (-121) |#2|) $) 23)) (-3924 (($ $) 36)) (-3405 (($ (-1 (-121) |#2|) $) NIL) (($ |#2| $) 34)) (-4328 (($ |#2| $) 31) (($ (-1 (-121) |#2|) $) 17)) (-3349 (($ (-1 (-121) |#2| |#2|) $ $) NIL) (($ $ $) 40)) (-4122 (($ |#2| $ (-568)) 19) (($ $ $ (-568)) 21)) (-2826 (($ $ (-568)) 11) (($ $ (-1210 (-568))) 14)) (-3845 (($ $ |#2|) 29) (($ $ $) NIL)) (-2768 (($ $ |#2|) 28) (($ |#2| $) NIL) (($ $ $) 25) (($ (-634 $)) NIL))) 
-(((-276 |#1| |#2|) (-10 -8 (-15 -3349 (|#1| |#1| |#1|)) (-15 -3405 (|#1| |#2| |#1|)) (-15 -3349 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -3405 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -3845 (|#1| |#1| |#1|)) (-15 -3845 (|#1| |#1| |#2|)) (-15 -4122 (|#1| |#1| |#1| (-568))) (-15 -4122 (|#1| |#2| |#1| (-568))) (-15 -2826 (|#1| |#1| (-1210 (-568)))) (-15 -2826 (|#1| |#1| (-568))) (-15 -2768 (|#1| (-634 |#1|))) (-15 -2768 (|#1| |#1| |#1|)) (-15 -2768 (|#1| |#2| |#1|)) (-15 -2768 (|#1| |#1| |#2|)) (-15 -4328 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -2801 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -4328 (|#1| |#2| |#1|)) (-15 -3924 (|#1| |#1|))) (-277 |#2|) (-1195)) (T -276)) 
-NIL 
-(-10 -8 (-15 -3349 (|#1| |#1| |#1|)) (-15 -3405 (|#1| |#2| |#1|)) (-15 -3349 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -3405 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -3845 (|#1| |#1| |#1|)) (-15 -3845 (|#1| |#1| |#2|)) (-15 -4122 (|#1| |#1| |#1| (-568))) (-15 -4122 (|#1| |#2| |#1| (-568))) (-15 -2826 (|#1| |#1| (-1210 (-568)))) (-15 -2826 (|#1| |#1| (-568))) (-15 -2768 (|#1| (-634 |#1|))) (-15 -2768 (|#1| |#1| |#1|)) (-15 -2768 (|#1| |#2| |#1|)) (-15 -2768 (|#1| |#1| |#2|)) (-15 -4328 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -2801 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -4328 (|#1| |#2| |#1|)) (-15 -3924 (|#1| |#1|))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-1868 (((-1249) $ (-568) (-568)) 37 (|has| $ (-6 -4520)))) (-2510 (((-121) $ (-763)) 8)) (-2436 ((|#1| $ (-568) |#1|) 49 (|has| $ (-6 -4520))) ((|#1| $ (-1210 (-568)) |#1|) 53 (|has| $ (-6 -4520)))) (-3507 (($ (-1 (-121) |#1|) $) 78)) (-2801 (($ (-1 (-121) |#1|) $) 70 (|has| $ (-6 -4519)))) (-2671 (($) 7 T CONST)) (-3369 (($ $) 76 (|has| |#1| (-1090)))) (-3924 (($ $) 73 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3405 (($ (-1 (-121) |#1|) $) 82) (($ |#1| $) 77 (|has| |#1| (-1090)))) (-4328 (($ |#1| $) 72 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) |#1|) $) 69 (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4519)))) (-3989 ((|#1| $ (-568) |#1|) 50 (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-568)) 48)) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-1849 (($ (-763) |#1|) 64)) (-1737 (((-121) $ (-763)) 9)) (-1881 (((-568) $) 40 (|has| (-568) (-842)))) (-3349 (($ (-1 (-121) |#1| |#1|) $ $) 79) (($ $ $) 75 (|has| |#1| (-842)))) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-2223 (((-568) $) 41 (|has| (-568) (-842)))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-2166 (((-121) $ (-763)) 10)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4450 (($ |#1| $ (-568)) 81) (($ $ $ (-568)) 80)) (-4122 (($ |#1| $ (-568)) 55) (($ $ $ (-568)) 54)) (-4174 (((-634 (-568)) $) 43)) (-3578 (((-121) (-568) $) 44)) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3876 ((|#1| $) 39 (|has| (-568) (-842)))) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 66)) (-3724 (($ $ |#1|) 38 (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-4467 (((-121) |#1| $) 42 (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) 45)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 ((|#1| $ (-568) |#1|) 47) ((|#1| $ (-568)) 46) (($ $ (-1210 (-568))) 58)) (-1783 (($ $ (-568)) 84) (($ $ (-1210 (-568))) 83)) (-2826 (($ $ (-568)) 57) (($ $ (-1210 (-568))) 56)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-4278 (((-541) $) 74 (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) 65)) (-3845 (($ $ |#1|) 86) (($ $ $) 85)) (-2768 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-634 $)) 60)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2575 (((-634 (-568)) $) 16)) (-1836 (((-763) $) 14)) (-2747 (((-850) $) 20) (($ (-634 (-568))) 12)) (-3723 (($ (-763)) 17)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 9)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 10))) 
+(((-271) (-13 (-842) (-10 -8 (-15 -2747 ($ (-634 (-568)))) (-15 -1836 ((-763) $)) (-15 -2575 ((-634 (-568)) $)) (-15 -3723 ($ (-763)))))) (T -271)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-271)))) (-1836 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-271)))) (-2575 (*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-271)))) (-3723 (*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-271))))) 
+(-13 (-842) (-10 -8 (-15 -2747 ($ (-634 (-568)))) (-15 -1836 ((-763) $)) (-15 -2575 ((-634 (-568)) $)) (-15 -3723 ($ (-763))))) 
+((-1984 ((|#2| |#2|) 77)) (-1935 ((|#2| |#2|) 65)) (-3367 (((-3 |#2| "failed") |#2| (-634 (-2 (|:| |func| |#2|) (|:| |pole| (-121))))) 116)) (-1976 ((|#2| |#2|) 75)) (-2788 ((|#2| |#2|) 63)) (-1992 ((|#2| |#2|) 79)) (-1943 ((|#2| |#2|) 67)) (-1899 ((|#2|) 46)) (-3842 (((-123) (-123)) 95)) (-4418 ((|#2| |#2|) 61)) (-4166 (((-121) |#2|) 134)) (-2113 ((|#2| |#2|) 180)) (-3529 ((|#2| |#2|) 156)) (-3626 ((|#2|) 59)) (-3782 ((|#2|) 58)) (-2778 ((|#2| |#2|) 176)) (-3475 ((|#2| |#2|) 152)) (-4401 ((|#2| |#2|) 184)) (-3748 ((|#2| |#2|) 160)) (-3821 ((|#2| |#2|) 148)) (-3549 ((|#2| |#2|) 150)) (-4070 ((|#2| |#2|) 186)) (-2287 ((|#2| |#2|) 162)) (-4011 ((|#2| |#2|) 182)) (-3128 ((|#2| |#2|) 158)) (-3051 ((|#2| |#2|) 178)) (-3334 ((|#2| |#2|) 154)) (-2925 ((|#2| |#2|) 192)) (-1281 ((|#2| |#2|) 168)) (-2226 ((|#2| |#2|) 188)) (-2020 ((|#2| |#2|) 164)) (-3089 ((|#2| |#2|) 196)) (-2105 ((|#2| |#2|) 172)) (-3614 ((|#2| |#2|) 198)) (-1873 ((|#2| |#2|) 174)) (-2629 ((|#2| |#2|) 194)) (-4370 ((|#2| |#2|) 170)) (-1585 ((|#2| |#2|) 190)) (-2858 ((|#2| |#2|) 166)) (-1894 ((|#2| |#2|) 62)) (-1996 ((|#2| |#2|) 80)) (-1947 ((|#2| |#2|) 68)) (-1988 ((|#2| |#2|) 78)) (-1939 ((|#2| |#2|) 66)) (-1980 ((|#2| |#2|) 76)) (-2792 ((|#2| |#2|) 64)) (-2779 (((-121) (-123)) 93)) (-2008 ((|#2| |#2|) 83)) (-1959 ((|#2| |#2|) 71)) (-2000 ((|#2| |#2|) 81)) (-1951 ((|#2| |#2|) 69)) (-2016 ((|#2| |#2|) 85)) (-1968 ((|#2| |#2|) 73)) (-1439 ((|#2| |#2|) 86)) (-1972 ((|#2| |#2|) 74)) (-2012 ((|#2| |#2|) 84)) (-1964 ((|#2| |#2|) 72)) (-2004 ((|#2| |#2|) 82)) (-1955 ((|#2| |#2|) 70))) 
+(((-272 |#1| |#2|) (-10 -7 (-15 -1894 (|#2| |#2|)) (-15 -4418 (|#2| |#2|)) (-15 -2788 (|#2| |#2|)) (-15 -2792 (|#2| |#2|)) (-15 -1935 (|#2| |#2|)) (-15 -1939 (|#2| |#2|)) (-15 -1943 (|#2| |#2|)) (-15 -1947 (|#2| |#2|)) (-15 -1951 (|#2| |#2|)) (-15 -1955 (|#2| |#2|)) (-15 -1959 (|#2| |#2|)) (-15 -1964 (|#2| |#2|)) (-15 -1968 (|#2| |#2|)) (-15 -1972 (|#2| |#2|)) (-15 -1976 (|#2| |#2|)) (-15 -1980 (|#2| |#2|)) (-15 -1984 (|#2| |#2|)) (-15 -1988 (|#2| |#2|)) (-15 -1992 (|#2| |#2|)) (-15 -1996 (|#2| |#2|)) (-15 -2000 (|#2| |#2|)) (-15 -2004 (|#2| |#2|)) (-15 -2008 (|#2| |#2|)) (-15 -2012 (|#2| |#2|)) (-15 -2016 (|#2| |#2|)) (-15 -1439 (|#2| |#2|)) (-15 -1899 (|#2|)) (-15 -2779 ((-121) (-123))) (-15 -3842 ((-123) (-123))) (-15 -3782 (|#2|)) (-15 -3626 (|#2|)) (-15 -3549 (|#2| |#2|)) (-15 -3821 (|#2| |#2|)) (-15 -3475 (|#2| |#2|)) (-15 -3334 (|#2| |#2|)) (-15 -3529 (|#2| |#2|)) (-15 -3128 (|#2| |#2|)) (-15 -3748 (|#2| |#2|)) (-15 -2287 (|#2| |#2|)) (-15 -2020 (|#2| |#2|)) (-15 -2858 (|#2| |#2|)) (-15 -1281 (|#2| |#2|)) (-15 -4370 (|#2| |#2|)) (-15 -2105 (|#2| |#2|)) (-15 -1873 (|#2| |#2|)) (-15 -2778 (|#2| |#2|)) (-15 -3051 (|#2| |#2|)) (-15 -2113 (|#2| |#2|)) (-15 -4011 (|#2| |#2|)) (-15 -4401 (|#2| |#2|)) (-15 -4070 (|#2| |#2|)) (-15 -2226 (|#2| |#2|)) (-15 -1585 (|#2| |#2|)) (-15 -2925 (|#2| |#2|)) (-15 -2629 (|#2| |#2|)) (-15 -3089 (|#2| |#2|)) (-15 -3614 (|#2| |#2|)) (-15 -3367 ((-3 |#2| "failed") |#2| (-634 (-2 (|:| |func| |#2|) (|:| |pole| (-121)))))) (-15 -4166 ((-121) |#2|))) (-13 (-842) (-558)) (-13 (-432 |#1|) (-1002))) (T -272)) 
+((-4166 (*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-272 *4 *3)) (-4 *3 (-13 (-432 *4) (-1002))))) (-3367 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-634 (-2 (|:| |func| *2) (|:| |pole| (-121))))) (-4 *2 (-13 (-432 *4) (-1002))) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-272 *4 *2)))) (-3614 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-3089 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2629 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2925 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1585 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2226 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-4070 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-4401 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-4011 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2113 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-3051 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2778 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1873 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2105 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-4370 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1281 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2858 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2020 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2287 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-3748 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-3128 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-3529 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-3334 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-3475 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-3821 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-3549 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-3626 (*1 *2) (-12 (-4 *2 (-13 (-432 *3) (-1002))) (-5 *1 (-272 *3 *2)) (-4 *3 (-13 (-842) (-558))))) (-3782 (*1 *2) (-12 (-4 *2 (-13 (-432 *3) (-1002))) (-5 *1 (-272 *3 *2)) (-4 *3 (-13 (-842) (-558))))) (-3842 (*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *4)) (-4 *4 (-13 (-432 *3) (-1002))))) (-2779 (*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-272 *4 *5)) (-4 *5 (-13 (-432 *4) (-1002))))) (-1899 (*1 *2) (-12 (-4 *2 (-13 (-432 *3) (-1002))) (-5 *1 (-272 *3 *2)) (-4 *3 (-13 (-842) (-558))))) (-1439 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2016 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2012 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2008 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2004 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2000 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1996 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1992 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1988 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1984 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1980 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1976 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1972 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1968 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1964 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1959 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1955 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1951 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1947 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1943 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1939 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1935 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2792 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-2788 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-4418 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) (-1894 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
+(-10 -7 (-15 -1894 (|#2| |#2|)) (-15 -4418 (|#2| |#2|)) (-15 -2788 (|#2| |#2|)) (-15 -2792 (|#2| |#2|)) (-15 -1935 (|#2| |#2|)) (-15 -1939 (|#2| |#2|)) (-15 -1943 (|#2| |#2|)) (-15 -1947 (|#2| |#2|)) (-15 -1951 (|#2| |#2|)) (-15 -1955 (|#2| |#2|)) (-15 -1959 (|#2| |#2|)) (-15 -1964 (|#2| |#2|)) (-15 -1968 (|#2| |#2|)) (-15 -1972 (|#2| |#2|)) (-15 -1976 (|#2| |#2|)) (-15 -1980 (|#2| |#2|)) (-15 -1984 (|#2| |#2|)) (-15 -1988 (|#2| |#2|)) (-15 -1992 (|#2| |#2|)) (-15 -1996 (|#2| |#2|)) (-15 -2000 (|#2| |#2|)) (-15 -2004 (|#2| |#2|)) (-15 -2008 (|#2| |#2|)) (-15 -2012 (|#2| |#2|)) (-15 -2016 (|#2| |#2|)) (-15 -1439 (|#2| |#2|)) (-15 -1899 (|#2|)) (-15 -2779 ((-121) (-123))) (-15 -3842 ((-123) (-123))) (-15 -3782 (|#2|)) (-15 -3626 (|#2|)) (-15 -3549 (|#2| |#2|)) (-15 -3821 (|#2| |#2|)) (-15 -3475 (|#2| |#2|)) (-15 -3334 (|#2| |#2|)) (-15 -3529 (|#2| |#2|)) (-15 -3128 (|#2| |#2|)) (-15 -3748 (|#2| |#2|)) (-15 -2287 (|#2| |#2|)) (-15 -2020 (|#2| |#2|)) (-15 -2858 (|#2| |#2|)) (-15 -1281 (|#2| |#2|)) (-15 -4370 (|#2| |#2|)) (-15 -2105 (|#2| |#2|)) (-15 -1873 (|#2| |#2|)) (-15 -2778 (|#2| |#2|)) (-15 -3051 (|#2| |#2|)) (-15 -2113 (|#2| |#2|)) (-15 -4011 (|#2| |#2|)) (-15 -4401 (|#2| |#2|)) (-15 -4070 (|#2| |#2|)) (-15 -2226 (|#2| |#2|)) (-15 -1585 (|#2| |#2|)) (-15 -2925 (|#2| |#2|)) (-15 -2629 (|#2| |#2|)) (-15 -3089 (|#2| |#2|)) (-15 -3614 (|#2| |#2|)) (-15 -3367 ((-3 |#2| "failed") |#2| (-634 (-2 (|:| |func| |#2|) (|:| |pole| (-121)))))) (-15 -4166 ((-121) |#2|))) 
+((-1287 (((-3 |#2| "failed") (-634 (-607 |#2|)) |#2| (-1161)) 133)) (-1737 ((|#2| (-409 (-568)) |#2|) 50)) (-1477 ((|#2| |#2| (-607 |#2|)) 126)) (-4251 (((-2 (|:| |func| |#2|) (|:| |kers| (-634 (-607 |#2|))) (|:| |vals| (-634 |#2|))) |#2| (-1161)) 125)) (-2184 ((|#2| |#2| (-1161)) 19) ((|#2| |#2|) 22)) (-3126 ((|#2| |#2| (-1161)) 139) ((|#2| |#2|) 137))) 
+(((-273 |#1| |#2|) (-10 -7 (-15 -3126 (|#2| |#2|)) (-15 -3126 (|#2| |#2| (-1161))) (-15 -4251 ((-2 (|:| |func| |#2|) (|:| |kers| (-634 (-607 |#2|))) (|:| |vals| (-634 |#2|))) |#2| (-1161))) (-15 -2184 (|#2| |#2|)) (-15 -2184 (|#2| |#2| (-1161))) (-15 -1287 ((-3 |#2| "failed") (-634 (-607 |#2|)) |#2| (-1161))) (-15 -1477 (|#2| |#2| (-607 |#2|))) (-15 -1737 (|#2| (-409 (-568)) |#2|))) (-13 (-558) (-842) (-1037 (-568)) (-630 (-568))) (-13 (-27) (-1181) (-432 |#1|))) (T -273)) 
+((-1737 (*1 *2 *3 *2) (-12 (-5 *3 (-409 (-568))) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4))))) (-1477 (*1 *2 *2 *3) (-12 (-5 *3 (-607 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4))) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *4 *2)))) (-1287 (*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-634 (-607 *2))) (-5 *4 (-1161)) (-4 *2 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *5 *2)))) (-2184 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4))))) (-2184 (*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3))))) (-4251 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-2 (|:| |func| *3) (|:| |kers| (-634 (-607 *3))) (|:| |vals| (-634 *3)))) (-5 *1 (-273 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) (-3126 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4))))) (-3126 (*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3)))))) 
+(-10 -7 (-15 -3126 (|#2| |#2|)) (-15 -3126 (|#2| |#2| (-1161))) (-15 -4251 ((-2 (|:| |func| |#2|) (|:| |kers| (-634 (-607 |#2|))) (|:| |vals| (-634 |#2|))) |#2| (-1161))) (-15 -2184 (|#2| |#2|)) (-15 -2184 (|#2| |#2| (-1161))) (-15 -1287 ((-3 |#2| "failed") (-634 (-607 |#2|)) |#2| (-1161))) (-15 -1477 (|#2| |#2| (-607 |#2|))) (-15 -1737 (|#2| (-409 (-568)) |#2|))) 
+((-2029 (((-3 |#3| "failed") |#3|) 110)) (-1984 ((|#3| |#3|) 131)) (-1674 (((-3 |#3| "failed") |#3|) 82)) (-1935 ((|#3| |#3|) 121)) (-3624 (((-3 |#3| "failed") |#3|) 58)) (-1976 ((|#3| |#3|) 129)) (-2422 (((-3 |#3| "failed") |#3|) 46)) (-2788 ((|#3| |#3|) 119)) (-4087 (((-3 |#3| "failed") |#3|) 112)) (-1992 ((|#3| |#3|) 133)) (-1942 (((-3 |#3| "failed") |#3|) 84)) (-1943 ((|#3| |#3|) 123)) (-1472 (((-3 |#3| "failed") |#3| (-763)) 36)) (-2051 (((-3 |#3| "failed") |#3|) 74)) (-4418 ((|#3| |#3|) 118)) (-3296 (((-3 |#3| "failed") |#3|) 44)) (-1894 ((|#3| |#3|) 117)) (-3995 (((-3 |#3| "failed") |#3|) 113)) (-1996 ((|#3| |#3|) 134)) (-4119 (((-3 |#3| "failed") |#3|) 85)) (-1947 ((|#3| |#3|) 124)) (-2005 (((-3 |#3| "failed") |#3|) 111)) (-1988 ((|#3| |#3|) 132)) (-3979 (((-3 |#3| "failed") |#3|) 83)) (-1939 ((|#3| |#3|) 122)) (-3975 (((-3 |#3| "failed") |#3|) 60)) (-1980 ((|#3| |#3|) 130)) (-4349 (((-3 |#3| "failed") |#3|) 48)) (-2792 ((|#3| |#3|) 120)) (-4008 (((-3 |#3| "failed") |#3|) 66)) (-2008 ((|#3| |#3|) 137)) (-4415 (((-3 |#3| "failed") |#3|) 104)) (-1959 ((|#3| |#3|) 142)) (-1461 (((-3 |#3| "failed") |#3|) 62)) (-2000 ((|#3| |#3|) 135)) (-4497 (((-3 |#3| "failed") |#3|) 50)) (-1951 ((|#3| |#3|) 125)) (-4016 (((-3 |#3| "failed") |#3|) 70)) (-2016 ((|#3| |#3|) 139)) (-4040 (((-3 |#3| "failed") |#3|) 54)) (-1968 ((|#3| |#3|) 127)) (-3468 (((-3 |#3| "failed") |#3|) 72)) (-1439 ((|#3| |#3|) 140)) (-3084 (((-3 |#3| "failed") |#3|) 56)) (-1972 ((|#3| |#3|) 128)) (-2695 (((-3 |#3| "failed") |#3|) 68)) (-2012 ((|#3| |#3|) 138)) (-2285 (((-3 |#3| "failed") |#3|) 107)) (-1964 ((|#3| |#3|) 143)) (-4090 (((-3 |#3| "failed") |#3|) 64)) (-2004 ((|#3| |#3|) 136)) (-2203 (((-3 |#3| "failed") |#3|) 52)) (-1955 ((|#3| |#3|) 126)) (** ((|#3| |#3| (-409 (-568))) 40 (|has| |#1| (-365))))) 
+(((-274 |#1| |#2| |#3|) (-13 (-984 |#3|) (-10 -7 (IF (|has| |#1| (-365)) (-15 ** (|#3| |#3| (-409 (-568)))) |noBranch|) (-15 -1894 (|#3| |#3|)) (-15 -4418 (|#3| |#3|)) (-15 -2788 (|#3| |#3|)) (-15 -2792 (|#3| |#3|)) (-15 -1935 (|#3| |#3|)) (-15 -1939 (|#3| |#3|)) (-15 -1943 (|#3| |#3|)) (-15 -1947 (|#3| |#3|)) (-15 -1951 (|#3| |#3|)) (-15 -1955 (|#3| |#3|)) (-15 -1959 (|#3| |#3|)) (-15 -1964 (|#3| |#3|)) (-15 -1968 (|#3| |#3|)) (-15 -1972 (|#3| |#3|)) (-15 -1976 (|#3| |#3|)) (-15 -1980 (|#3| |#3|)) (-15 -1984 (|#3| |#3|)) (-15 -1988 (|#3| |#3|)) (-15 -1992 (|#3| |#3|)) (-15 -1996 (|#3| |#3|)) (-15 -2000 (|#3| |#3|)) (-15 -2004 (|#3| |#3|)) (-15 -2008 (|#3| |#3|)) (-15 -2012 (|#3| |#3|)) (-15 -2016 (|#3| |#3|)) (-15 -1439 (|#3| |#3|)))) (-43 (-409 (-568))) (-1234 |#1|) (-1205 |#1| |#2|)) (T -274)) 
+((** (*1 *2 *2 *3) (-12 (-5 *3 (-409 (-568))) (-4 *4 (-365)) (-4 *4 (-43 *3)) (-4 *5 (-1234 *4)) (-5 *1 (-274 *4 *5 *2)) (-4 *2 (-1205 *4 *5)))) (-1894 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-4418 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-2788 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-2792 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1935 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1939 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1943 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1947 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1951 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1955 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1959 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1964 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1968 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1972 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1976 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1980 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1984 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1988 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1992 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1996 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-2000 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-2004 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-2008 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-2012 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-2016 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) (-1439 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4))))) 
+(-13 (-984 |#3|) (-10 -7 (IF (|has| |#1| (-365)) (-15 ** (|#3| |#3| (-409 (-568)))) |noBranch|) (-15 -1894 (|#3| |#3|)) (-15 -4418 (|#3| |#3|)) (-15 -2788 (|#3| |#3|)) (-15 -2792 (|#3| |#3|)) (-15 -1935 (|#3| |#3|)) (-15 -1939 (|#3| |#3|)) (-15 -1943 (|#3| |#3|)) (-15 -1947 (|#3| |#3|)) (-15 -1951 (|#3| |#3|)) (-15 -1955 (|#3| |#3|)) (-15 -1959 (|#3| |#3|)) (-15 -1964 (|#3| |#3|)) (-15 -1968 (|#3| |#3|)) (-15 -1972 (|#3| |#3|)) (-15 -1976 (|#3| |#3|)) (-15 -1980 (|#3| |#3|)) (-15 -1984 (|#3| |#3|)) (-15 -1988 (|#3| |#3|)) (-15 -1992 (|#3| |#3|)) (-15 -1996 (|#3| |#3|)) (-15 -2000 (|#3| |#3|)) (-15 -2004 (|#3| |#3|)) (-15 -2008 (|#3| |#3|)) (-15 -2012 (|#3| |#3|)) (-15 -2016 (|#3| |#3|)) (-15 -1439 (|#3| |#3|)))) 
+((-2029 (((-3 |#3| "failed") |#3|) 66)) (-1984 ((|#3| |#3|) 133)) (-1674 (((-3 |#3| "failed") |#3|) 50)) (-1935 ((|#3| |#3|) 121)) (-3624 (((-3 |#3| "failed") |#3|) 62)) (-1976 ((|#3| |#3|) 131)) (-2422 (((-3 |#3| "failed") |#3|) 46)) (-2788 ((|#3| |#3|) 119)) (-4087 (((-3 |#3| "failed") |#3|) 70)) (-1992 ((|#3| |#3|) 135)) (-1942 (((-3 |#3| "failed") |#3|) 54)) (-1943 ((|#3| |#3|) 123)) (-1472 (((-3 |#3| "failed") |#3| (-763)) 35)) (-2051 (((-3 |#3| "failed") |#3|) 44)) (-4418 ((|#3| |#3|) 112)) (-3296 (((-3 |#3| "failed") |#3|) 42)) (-1894 ((|#3| |#3|) 118)) (-3995 (((-3 |#3| "failed") |#3|) 72)) (-1996 ((|#3| |#3|) 136)) (-4119 (((-3 |#3| "failed") |#3|) 56)) (-1947 ((|#3| |#3|) 124)) (-2005 (((-3 |#3| "failed") |#3|) 68)) (-1988 ((|#3| |#3|) 134)) (-3979 (((-3 |#3| "failed") |#3|) 52)) (-1939 ((|#3| |#3|) 122)) (-3975 (((-3 |#3| "failed") |#3|) 64)) (-1980 ((|#3| |#3|) 132)) (-4349 (((-3 |#3| "failed") |#3|) 48)) (-2792 ((|#3| |#3|) 120)) (-4008 (((-3 |#3| "failed") |#3|) 78)) (-2008 ((|#3| |#3|) 139)) (-4415 (((-3 |#3| "failed") |#3|) 58)) (-1959 ((|#3| |#3|) 127)) (-1461 (((-3 |#3| "failed") |#3|) 74)) (-2000 ((|#3| |#3|) 137)) (-4497 (((-3 |#3| "failed") |#3|) 102)) (-1951 ((|#3| |#3|) 125)) (-4016 (((-3 |#3| "failed") |#3|) 82)) (-2016 ((|#3| |#3|) 141)) (-4040 (((-3 |#3| "failed") |#3|) 109)) (-1968 ((|#3| |#3|) 129)) (-3468 (((-3 |#3| "failed") |#3|) 84)) (-1439 ((|#3| |#3|) 142)) (-3084 (((-3 |#3| "failed") |#3|) 111)) (-1972 ((|#3| |#3|) 130)) (-2695 (((-3 |#3| "failed") |#3|) 80)) (-2012 ((|#3| |#3|) 140)) (-2285 (((-3 |#3| "failed") |#3|) 60)) (-1964 ((|#3| |#3|) 128)) (-4090 (((-3 |#3| "failed") |#3|) 76)) (-2004 ((|#3| |#3|) 138)) (-2203 (((-3 |#3| "failed") |#3|) 105)) (-1955 ((|#3| |#3|) 126)) (** ((|#3| |#3| (-409 (-568))) 40 (|has| |#1| (-365))))) 
+(((-275 |#1| |#2| |#3| |#4|) (-13 (-984 |#3|) (-10 -7 (IF (|has| |#1| (-365)) (-15 ** (|#3| |#3| (-409 (-568)))) |noBranch|) (-15 -1894 (|#3| |#3|)) (-15 -4418 (|#3| |#3|)) (-15 -2788 (|#3| |#3|)) (-15 -2792 (|#3| |#3|)) (-15 -1935 (|#3| |#3|)) (-15 -1939 (|#3| |#3|)) (-15 -1943 (|#3| |#3|)) (-15 -1947 (|#3| |#3|)) (-15 -1951 (|#3| |#3|)) (-15 -1955 (|#3| |#3|)) (-15 -1959 (|#3| |#3|)) (-15 -1964 (|#3| |#3|)) (-15 -1968 (|#3| |#3|)) (-15 -1972 (|#3| |#3|)) (-15 -1976 (|#3| |#3|)) (-15 -1980 (|#3| |#3|)) (-15 -1984 (|#3| |#3|)) (-15 -1988 (|#3| |#3|)) (-15 -1992 (|#3| |#3|)) (-15 -1996 (|#3| |#3|)) (-15 -2000 (|#3| |#3|)) (-15 -2004 (|#3| |#3|)) (-15 -2008 (|#3| |#3|)) (-15 -2012 (|#3| |#3|)) (-15 -2016 (|#3| |#3|)) (-15 -1439 (|#3| |#3|)))) (-43 (-409 (-568))) (-1203 |#1|) (-1226 |#1| |#2|) (-984 |#2|)) (T -275)) 
+((** (*1 *2 *2 *3) (-12 (-5 *3 (-409 (-568))) (-4 *4 (-365)) (-4 *4 (-43 *3)) (-4 *5 (-1203 *4)) (-5 *1 (-275 *4 *5 *2 *6)) (-4 *2 (-1226 *4 *5)) (-4 *6 (-984 *5)))) (-1894 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-4418 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-2788 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-2792 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1935 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1939 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1943 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1947 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1951 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1955 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1959 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1964 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1968 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1972 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1976 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1980 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1984 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1988 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1992 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1996 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-2000 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-2004 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-2008 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-2012 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-2016 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) (-1439 (*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4))))) 
+(-13 (-984 |#3|) (-10 -7 (IF (|has| |#1| (-365)) (-15 ** (|#3| |#3| (-409 (-568)))) |noBranch|) (-15 -1894 (|#3| |#3|)) (-15 -4418 (|#3| |#3|)) (-15 -2788 (|#3| |#3|)) (-15 -2792 (|#3| |#3|)) (-15 -1935 (|#3| |#3|)) (-15 -1939 (|#3| |#3|)) (-15 -1943 (|#3| |#3|)) (-15 -1947 (|#3| |#3|)) (-15 -1951 (|#3| |#3|)) (-15 -1955 (|#3| |#3|)) (-15 -1959 (|#3| |#3|)) (-15 -1964 (|#3| |#3|)) (-15 -1968 (|#3| |#3|)) (-15 -1972 (|#3| |#3|)) (-15 -1976 (|#3| |#3|)) (-15 -1980 (|#3| |#3|)) (-15 -1984 (|#3| |#3|)) (-15 -1988 (|#3| |#3|)) (-15 -1992 (|#3| |#3|)) (-15 -1996 (|#3| |#3|)) (-15 -2000 (|#3| |#3|)) (-15 -2004 (|#3| |#3|)) (-15 -2008 (|#3| |#3|)) (-15 -2012 (|#3| |#3|)) (-15 -2016 (|#3| |#3|)) (-15 -1439 (|#3| |#3|)))) 
+((-2803 (($ (-1 (-121) |#2|) $) 23)) (-3926 (($ $) 36)) (-1568 (($ (-1 (-121) |#2|) $) NIL) (($ |#2| $) 34)) (-4330 (($ |#2| $) 31) (($ (-1 (-121) |#2|) $) 17)) (-4496 (($ (-1 (-121) |#2| |#2|) $ $) NIL) (($ $ $) 40)) (-4124 (($ |#2| $ (-568)) 19) (($ $ $ (-568)) 21)) (-2828 (($ $ (-568)) 11) (($ $ (-1210 (-568))) 14)) (-1876 (($ $ |#2|) 29) (($ $ $) NIL)) (-2770 (($ $ |#2|) 28) (($ |#2| $) NIL) (($ $ $) 25) (($ (-634 $)) NIL))) 
+(((-276 |#1| |#2|) (-10 -8 (-15 -4496 (|#1| |#1| |#1|)) (-15 -1568 (|#1| |#2| |#1|)) (-15 -4496 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -1568 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -1876 (|#1| |#1| |#1|)) (-15 -1876 (|#1| |#1| |#2|)) (-15 -4124 (|#1| |#1| |#1| (-568))) (-15 -4124 (|#1| |#2| |#1| (-568))) (-15 -2828 (|#1| |#1| (-1210 (-568)))) (-15 -2828 (|#1| |#1| (-568))) (-15 -2770 (|#1| (-634 |#1|))) (-15 -2770 (|#1| |#1| |#1|)) (-15 -2770 (|#1| |#2| |#1|)) (-15 -2770 (|#1| |#1| |#2|)) (-15 -4330 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -2803 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -4330 (|#1| |#2| |#1|)) (-15 -3926 (|#1| |#1|))) (-277 |#2|) (-1195)) (T -276)) 
+NIL 
+(-10 -8 (-15 -4496 (|#1| |#1| |#1|)) (-15 -1568 (|#1| |#2| |#1|)) (-15 -4496 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -1568 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -1876 (|#1| |#1| |#1|)) (-15 -1876 (|#1| |#1| |#2|)) (-15 -4124 (|#1| |#1| |#1| (-568))) (-15 -4124 (|#1| |#2| |#1| (-568))) (-15 -2828 (|#1| |#1| (-1210 (-568)))) (-15 -2828 (|#1| |#1| (-568))) (-15 -2770 (|#1| (-634 |#1|))) (-15 -2770 (|#1| |#1| |#1|)) (-15 -2770 (|#1| |#2| |#1|)) (-15 -2770 (|#1| |#1| |#2|)) (-15 -4330 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -2803 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -4330 (|#1| |#2| |#1|)) (-15 -3926 (|#1| |#1|))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2481 (((-1249) $ (-568) (-568)) 37 (|has| $ (-6 -4522)))) (-1667 (((-121) $ (-763)) 8)) (-2438 ((|#1| $ (-568) |#1|) 49 (|has| $ (-6 -4522))) ((|#1| $ (-1210 (-568)) |#1|) 53 (|has| $ (-6 -4522)))) (-3963 (($ (-1 (-121) |#1|) $) 78)) (-2803 (($ (-1 (-121) |#1|) $) 70 (|has| $ (-6 -4521)))) (-4490 (($) 7 T CONST)) (-1377 (($ $) 76 (|has| |#1| (-1090)))) (-3926 (($ $) 73 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-1568 (($ (-1 (-121) |#1|) $) 82) (($ |#1| $) 77 (|has| |#1| (-1090)))) (-4330 (($ |#1| $) 72 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) |#1|) $) 69 (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4521)))) (-1292 ((|#1| $ (-568) |#1|) 50 (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-568)) 48)) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-1851 (($ (-763) |#1|) 64)) (-3791 (((-121) $ (-763)) 9)) (-2539 (((-568) $) 40 (|has| (-568) (-842)))) (-4496 (($ (-1 (-121) |#1| |#1|) $ $) 79) (($ $ $) 75 (|has| |#1| (-842)))) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3631 (((-568) $) 41 (|has| (-568) (-842)))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-3796 (((-121) $ (-763)) 10)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-1708 (($ |#1| $ (-568)) 81) (($ $ $ (-568)) 80)) (-4124 (($ |#1| $ (-568)) 55) (($ $ $ (-568)) 54)) (-3948 (((-634 (-568)) $) 43)) (-2916 (((-121) (-568) $) 44)) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3877 ((|#1| $) 39 (|has| (-568) (-842)))) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 66)) (-2490 (($ $ |#1|) 38 (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-1801 (((-121) |#1| $) 42 (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) 45)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 ((|#1| $ (-568) |#1|) 47) ((|#1| $ (-568)) 46) (($ $ (-1210 (-568))) 58)) (-4031 (($ $ (-568)) 84) (($ $ (-1210 (-568))) 83)) (-2828 (($ $ (-568)) 57) (($ $ (-1210 (-568))) 56)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-4280 (((-541) $) 74 (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) 65)) (-1876 (($ $ |#1|) 86) (($ $ $) 85)) (-2770 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-634 $)) 60)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-277 |#1|) (-1275) (-1195)) (T -277)) 
-((-3845 (*1 *1 *1 *2) (-12 (-4 *1 (-277 *2)) (-4 *2 (-1195)))) (-3845 (*1 *1 *1 *1) (-12 (-4 *1 (-277 *2)) (-4 *2 (-1195)))) (-1783 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-277 *3)) (-4 *3 (-1195)))) (-1783 (*1 *1 *1 *2) (-12 (-5 *2 (-1210 (-568))) (-4 *1 (-277 *3)) (-4 *3 (-1195)))) (-3405 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-277 *3)) (-4 *3 (-1195)))) (-4450 (*1 *1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-277 *2)) (-4 *2 (-1195)))) (-4450 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-277 *3)) (-4 *3 (-1195)))) (-3349 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (-4 *1 (-277 *3)) (-4 *3 (-1195)))) (-3507 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-277 *3)) (-4 *3 (-1195)))) (-3405 (*1 *1 *2 *1) (-12 (-4 *1 (-277 *2)) (-4 *2 (-1195)) (-4 *2 (-1090)))) (-3369 (*1 *1 *1) (-12 (-4 *1 (-277 *2)) (-4 *2 (-1195)) (-4 *2 (-1090)))) (-3349 (*1 *1 *1 *1) (-12 (-4 *1 (-277 *2)) (-4 *2 (-1195)) (-4 *2 (-842))))) 
-(-13 (-640 |t#1|) (-10 -8 (-6 -4520) (-15 -3845 ($ $ |t#1|)) (-15 -3845 ($ $ $)) (-15 -1783 ($ $ (-568))) (-15 -1783 ($ $ (-1210 (-568)))) (-15 -3405 ($ (-1 (-121) |t#1|) $)) (-15 -4450 ($ |t#1| $ (-568))) (-15 -4450 ($ $ $ (-568))) (-15 -3349 ($ (-1 (-121) |t#1| |t#1|) $ $)) (-15 -3507 ($ (-1 (-121) |t#1|) $)) (IF (|has| |t#1| (-1090)) (PROGN (-15 -3405 ($ |t#1| $)) (-15 -3369 ($ $))) |noBranch|) (IF (|has| |t#1| (-842)) (-15 -3349 ($ $ $)) |noBranch|))) 
+((-1876 (*1 *1 *1 *2) (-12 (-4 *1 (-277 *2)) (-4 *2 (-1195)))) (-1876 (*1 *1 *1 *1) (-12 (-4 *1 (-277 *2)) (-4 *2 (-1195)))) (-4031 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-277 *3)) (-4 *3 (-1195)))) (-4031 (*1 *1 *1 *2) (-12 (-5 *2 (-1210 (-568))) (-4 *1 (-277 *3)) (-4 *3 (-1195)))) (-1568 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-277 *3)) (-4 *3 (-1195)))) (-1708 (*1 *1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-277 *2)) (-4 *2 (-1195)))) (-1708 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-277 *3)) (-4 *3 (-1195)))) (-4496 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (-4 *1 (-277 *3)) (-4 *3 (-1195)))) (-3963 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-277 *3)) (-4 *3 (-1195)))) (-1568 (*1 *1 *2 *1) (-12 (-4 *1 (-277 *2)) (-4 *2 (-1195)) (-4 *2 (-1090)))) (-1377 (*1 *1 *1) (-12 (-4 *1 (-277 *2)) (-4 *2 (-1195)) (-4 *2 (-1090)))) (-4496 (*1 *1 *1 *1) (-12 (-4 *1 (-277 *2)) (-4 *2 (-1195)) (-4 *2 (-842))))) 
+(-13 (-640 |t#1|) (-10 -8 (-6 -4522) (-15 -1876 ($ $ |t#1|)) (-15 -1876 ($ $ $)) (-15 -4031 ($ $ (-568))) (-15 -4031 ($ $ (-1210 (-568)))) (-15 -1568 ($ (-1 (-121) |t#1|) $)) (-15 -1708 ($ |t#1| $ (-568))) (-15 -1708 ($ $ $ (-568))) (-15 -4496 ($ (-1 (-121) |t#1| |t#1|) $ $)) (-15 -3963 ($ (-1 (-121) |t#1|) $)) (IF (|has| |t#1| (-1090)) (PROGN (-15 -1568 ($ |t#1| $)) (-15 -1377 ($ $))) |noBranch|) (IF (|has| |t#1| (-842)) (-15 -4496 ($ $ $)) |noBranch|))) 
 (((-39) . T) ((-105) |has| |#1| (-1090)) ((-608 (-850)) |has| |#1| (-1090)) ((-154 |#1|) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-281 (-568) |#1|) . T) ((-283 (-568) |#1|) . T) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-601 (-568) |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-640 |#1|) . T) ((-1090) |has| |#1| (-1090)) ((-1195) . T)) 
 ((** (($ $ $) 10))) 
 (((-278 |#1|) (-10 -8 (-15 ** (|#1| |#1| |#1|))) (-279)) (T -278)) 
 NIL 
 (-10 -8 (-15 ** (|#1| |#1| |#1|))) 
-((-4416 (($ $) 6)) (-1892 (($ $) 7)) (** (($ $ $) 8))) 
+((-4418 (($ $) 6)) (-1894 (($ $) 7)) (** (($ $ $) 8))) 
 (((-279) (-1275)) (T -279)) 
-((** (*1 *1 *1 *1) (-4 *1 (-279))) (-1892 (*1 *1 *1) (-4 *1 (-279))) (-4416 (*1 *1 *1) (-4 *1 (-279)))) 
-(-13 (-10 -8 (-15 -4416 ($ $)) (-15 -1892 ($ $)) (-15 ** ($ $ $)))) 
-((-2833 (((-634 (-1141 |#1|)) (-1141 |#1|) |#1|) 35)) (-1513 ((|#2| |#2| |#1|) 38)) (-4191 ((|#2| |#2| |#1|) 40)) (-3762 ((|#2| |#2| |#1|) 39))) 
-(((-280 |#1| |#2|) (-10 -7 (-15 -1513 (|#2| |#2| |#1|)) (-15 -3762 (|#2| |#2| |#1|)) (-15 -4191 (|#2| |#2| |#1|)) (-15 -2833 ((-634 (-1141 |#1|)) (-1141 |#1|) |#1|))) (-365) (-1234 |#1|)) (T -280)) 
-((-2833 (*1 *2 *3 *4) (-12 (-4 *4 (-365)) (-5 *2 (-634 (-1141 *4))) (-5 *1 (-280 *4 *5)) (-5 *3 (-1141 *4)) (-4 *5 (-1234 *4)))) (-4191 (*1 *2 *2 *3) (-12 (-4 *3 (-365)) (-5 *1 (-280 *3 *2)) (-4 *2 (-1234 *3)))) (-3762 (*1 *2 *2 *3) (-12 (-4 *3 (-365)) (-5 *1 (-280 *3 *2)) (-4 *2 (-1234 *3)))) (-1513 (*1 *2 *2 *3) (-12 (-4 *3 (-365)) (-5 *1 (-280 *3 *2)) (-4 *2 (-1234 *3))))) 
-(-10 -7 (-15 -1513 (|#2| |#2| |#1|)) (-15 -3762 (|#2| |#2| |#1|)) (-15 -4191 (|#2| |#2| |#1|)) (-15 -2833 ((-634 (-1141 |#1|)) (-1141 |#1|) |#1|))) 
-((-2779 ((|#2| $ |#1|) 6))) 
+((** (*1 *1 *1 *1) (-4 *1 (-279))) (-1894 (*1 *1 *1) (-4 *1 (-279))) (-4418 (*1 *1 *1) (-4 *1 (-279)))) 
+(-13 (-10 -8 (-15 -4418 ($ $)) (-15 -1894 ($ $)) (-15 ** ($ $ $)))) 
+((-3860 (((-634 (-1141 |#1|)) (-1141 |#1|) |#1|) 35)) (-2680 ((|#2| |#2| |#1|) 38)) (-4041 ((|#2| |#2| |#1|) 40)) (-2661 ((|#2| |#2| |#1|) 39))) 
+(((-280 |#1| |#2|) (-10 -7 (-15 -2680 (|#2| |#2| |#1|)) (-15 -2661 (|#2| |#2| |#1|)) (-15 -4041 (|#2| |#2| |#1|)) (-15 -3860 ((-634 (-1141 |#1|)) (-1141 |#1|) |#1|))) (-365) (-1234 |#1|)) (T -280)) 
+((-3860 (*1 *2 *3 *4) (-12 (-4 *4 (-365)) (-5 *2 (-634 (-1141 *4))) (-5 *1 (-280 *4 *5)) (-5 *3 (-1141 *4)) (-4 *5 (-1234 *4)))) (-4041 (*1 *2 *2 *3) (-12 (-4 *3 (-365)) (-5 *1 (-280 *3 *2)) (-4 *2 (-1234 *3)))) (-2661 (*1 *2 *2 *3) (-12 (-4 *3 (-365)) (-5 *1 (-280 *3 *2)) (-4 *2 (-1234 *3)))) (-2680 (*1 *2 *2 *3) (-12 (-4 *3 (-365)) (-5 *1 (-280 *3 *2)) (-4 *2 (-1234 *3))))) 
+(-10 -7 (-15 -2680 (|#2| |#2| |#1|)) (-15 -2661 (|#2| |#2| |#1|)) (-15 -4041 (|#2| |#2| |#1|)) (-15 -3860 ((-634 (-1141 |#1|)) (-1141 |#1|) |#1|))) 
+((-2781 ((|#2| $ |#1|) 6))) 
 (((-281 |#1| |#2|) (-1275) (-1090) (-1195)) (T -281)) 
-((-2779 (*1 *2 *1 *3) (-12 (-4 *1 (-281 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195))))) 
-(-13 (-10 -8 (-15 -2779 (|t#2| $ |t#1|)))) 
-((-3989 ((|#3| $ |#2| |#3|) 12)) (-2602 ((|#3| $ |#2|) 10))) 
-(((-282 |#1| |#2| |#3|) (-10 -8 (-15 -3989 (|#3| |#1| |#2| |#3|)) (-15 -2602 (|#3| |#1| |#2|))) (-283 |#2| |#3|) (-1090) (-1195)) (T -282)) 
+((-2781 (*1 *2 *1 *3) (-12 (-4 *1 (-281 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195))))) 
+(-13 (-10 -8 (-15 -2781 (|t#2| $ |t#1|)))) 
+((-1292 ((|#3| $ |#2| |#3|) 12)) (-2069 ((|#3| $ |#2|) 10))) 
+(((-282 |#1| |#2| |#3|) (-10 -8 (-15 -1292 (|#3| |#1| |#2| |#3|)) (-15 -2069 (|#3| |#1| |#2|))) (-283 |#2| |#3|) (-1090) (-1195)) (T -282)) 
 NIL 
-(-10 -8 (-15 -3989 (|#3| |#1| |#2| |#3|)) (-15 -2602 (|#3| |#1| |#2|))) 
-((-2436 ((|#2| $ |#1| |#2|) 8 (|has| $ (-6 -4520)))) (-3989 ((|#2| $ |#1| |#2|) 7 (|has| $ (-6 -4520)))) (-2602 ((|#2| $ |#1|) 9)) (-2779 ((|#2| $ |#1|) 6) ((|#2| $ |#1| |#2|) 10))) 
+(-10 -8 (-15 -1292 (|#3| |#1| |#2| |#3|)) (-15 -2069 (|#3| |#1| |#2|))) 
+((-2438 ((|#2| $ |#1| |#2|) 8 (|has| $ (-6 -4522)))) (-1292 ((|#2| $ |#1| |#2|) 7 (|has| $ (-6 -4522)))) (-2069 ((|#2| $ |#1|) 9)) (-2781 ((|#2| $ |#1|) 6) ((|#2| $ |#1| |#2|) 10))) 
 (((-283 |#1| |#2|) (-1275) (-1090) (-1195)) (T -283)) 
-((-2779 (*1 *2 *1 *3 *2) (-12 (-4 *1 (-283 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195)))) (-2602 (*1 *2 *1 *3) (-12 (-4 *1 (-283 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195)))) (-2436 (*1 *2 *1 *3 *2) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-283 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195)))) (-3989 (*1 *2 *1 *3 *2) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-283 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195))))) 
-(-13 (-281 |t#1| |t#2|) (-10 -8 (-15 -2779 (|t#2| $ |t#1| |t#2|)) (-15 -2602 (|t#2| $ |t#1|)) (IF (|has| $ (-6 -4520)) (PROGN (-15 -2436 (|t#2| $ |t#1| |t#2|)) (-15 -3989 (|t#2| $ |t#1| |t#2|))) |noBranch|))) 
+((-2781 (*1 *2 *1 *3 *2) (-12 (-4 *1 (-283 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195)))) (-2069 (*1 *2 *1 *3) (-12 (-4 *1 (-283 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195)))) (-2438 (*1 *2 *1 *3 *2) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-283 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195)))) (-1292 (*1 *2 *1 *3 *2) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-283 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195))))) 
+(-13 (-281 |t#1| |t#2|) (-10 -8 (-15 -2781 (|t#2| $ |t#1| |t#2|)) (-15 -2069 (|t#2| $ |t#1|)) (IF (|has| $ (-6 -4522)) (PROGN (-15 -2438 (|t#2| $ |t#1| |t#2|)) (-15 -1292 (|t#2| $ |t#1| |t#2|))) |noBranch|))) 
 (((-281 |#1| |#2|) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 34)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 39)) (-2227 (($ $) 37)) (-1573 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1497 (((-121) $ $) NIL)) (-2671 (($) NIL T CONST)) (-2401 (($ $ $) 32)) (-3092 (($ |#2| |#3|) 19)) (-2925 (((-3 $ "failed") $) NIL)) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-2735 (((-121) $) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3094 ((|#3| $) NIL)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) 20)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3697 (((-3 $ "failed") $ $) NIL)) (-2709 (((-763) $) 33)) (-2779 ((|#2| $ |#2|) 41)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 24)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) ((|#2| $) NIL)) (-4078 (((-763)) NIL)) (-1826 (((-121) $ $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 27 T CONST)) (-1556 (($) 35 T CONST)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 36))) 
-(((-284 |#1| |#2| |#3| |#4| |#5| |#6|) (-13 (-301) (-10 -8 (-15 -3094 (|#3| $)) (-15 -2745 (|#2| $)) (-15 -3092 ($ |#2| |#3|)) (-15 -3697 ((-3 $ "failed") $ $)) (-15 -2925 ((-3 $ "failed") $)) (-15 -2081 ($ $)) (-15 -2779 (|#2| $ |#2|)))) (-172) (-1219 |#1|) (-23) (-1 |#2| |#2| |#3|) (-1 (-3 |#3| "failed") |#3| |#3|) (-1 (-3 |#2| "failed") |#2| |#2| |#3|)) (T -284)) 
-((-2925 (*1 *1 *1) (|partial| -12 (-4 *2 (-172)) (-5 *1 (-284 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1219 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) (-3094 (*1 *2 *1) (-12 (-4 *3 (-172)) (-4 *2 (-23)) (-5 *1 (-284 *3 *4 *2 *5 *6 *7)) (-4 *4 (-1219 *3)) (-14 *5 (-1 *4 *4 *2)) (-14 *6 (-1 (-3 *2 "failed") *2 *2)) (-14 *7 (-1 (-3 *4 "failed") *4 *4 *2)))) (-2745 (*1 *2 *1) (-12 (-4 *2 (-1219 *3)) (-5 *1 (-284 *3 *2 *4 *5 *6 *7)) (-4 *3 (-172)) (-4 *4 (-23)) (-14 *5 (-1 *2 *2 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *4)))) (-3092 (*1 *1 *2 *3) (-12 (-4 *4 (-172)) (-5 *1 (-284 *4 *2 *3 *5 *6 *7)) (-4 *2 (-1219 *4)) (-4 *3 (-23)) (-14 *5 (-1 *2 *2 *3)) (-14 *6 (-1 (-3 *3 "failed") *3 *3)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *3)))) (-3697 (*1 *1 *1 *1) (|partial| -12 (-4 *2 (-172)) (-5 *1 (-284 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1219 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) (-2081 (*1 *1 *1) (-12 (-4 *2 (-172)) (-5 *1 (-284 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1219 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) (-2779 (*1 *2 *1 *2) (-12 (-4 *3 (-172)) (-5 *1 (-284 *3 *2 *4 *5 *6 *7)) (-4 *2 (-1219 *3)) (-4 *4 (-23)) (-14 *5 (-1 *2 *2 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *4))))) 
-(-13 (-301) (-10 -8 (-15 -3094 (|#3| $)) (-15 -2745 (|#2| $)) (-15 -3092 ($ |#2| |#3|)) (-15 -3697 ((-3 $ "failed") $ $)) (-15 -2925 ((-3 $ "failed") $)) (-15 -2081 ($ $)) (-15 -2779 (|#2| $ |#2|)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-2925 (((-3 $ "failed") $) 33)) (-2735 (((-121) $) 30)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11) (($ (-568)) 27)) (-4078 (((-763)) 28)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 34)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 39)) (-3661 (($ $) 37)) (-4426 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-2589 (((-121) $ $) NIL)) (-4490 (($) NIL T CONST)) (-2403 (($ $ $) 32)) (-3094 (($ |#2| |#3|) 19)) (-2902 (((-3 $ "failed") $) NIL)) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-1598 (((-121) $) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2477 ((|#3| $) NIL)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) 20)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2355 (((-3 $ "failed") $ $) NIL)) (-1466 (((-763) $) 33)) (-2781 ((|#2| $ |#2|) 41)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 24)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) ((|#2| $) NIL)) (-3425 (((-763)) NIL)) (-2273 (((-121) $ $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 27 T CONST)) (-1557 (($) 35 T CONST)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 36))) 
+(((-284 |#1| |#2| |#3| |#4| |#5| |#6|) (-13 (-301) (-10 -8 (-15 -2477 (|#3| $)) (-15 -2747 (|#2| $)) (-15 -3094 ($ |#2| |#3|)) (-15 -2355 ((-3 $ "failed") $ $)) (-15 -2902 ((-3 $ "failed") $)) (-15 -2083 ($ $)) (-15 -2781 (|#2| $ |#2|)))) (-172) (-1219 |#1|) (-23) (-1 |#2| |#2| |#3|) (-1 (-3 |#3| "failed") |#3| |#3|) (-1 (-3 |#2| "failed") |#2| |#2| |#3|)) (T -284)) 
+((-2902 (*1 *1 *1) (|partial| -12 (-4 *2 (-172)) (-5 *1 (-284 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1219 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) (-2477 (*1 *2 *1) (-12 (-4 *3 (-172)) (-4 *2 (-23)) (-5 *1 (-284 *3 *4 *2 *5 *6 *7)) (-4 *4 (-1219 *3)) (-14 *5 (-1 *4 *4 *2)) (-14 *6 (-1 (-3 *2 "failed") *2 *2)) (-14 *7 (-1 (-3 *4 "failed") *4 *4 *2)))) (-2747 (*1 *2 *1) (-12 (-4 *2 (-1219 *3)) (-5 *1 (-284 *3 *2 *4 *5 *6 *7)) (-4 *3 (-172)) (-4 *4 (-23)) (-14 *5 (-1 *2 *2 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *4)))) (-3094 (*1 *1 *2 *3) (-12 (-4 *4 (-172)) (-5 *1 (-284 *4 *2 *3 *5 *6 *7)) (-4 *2 (-1219 *4)) (-4 *3 (-23)) (-14 *5 (-1 *2 *2 *3)) (-14 *6 (-1 (-3 *3 "failed") *3 *3)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *3)))) (-2355 (*1 *1 *1 *1) (|partial| -12 (-4 *2 (-172)) (-5 *1 (-284 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1219 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) (-2083 (*1 *1 *1) (-12 (-4 *2 (-172)) (-5 *1 (-284 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1219 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) (-2781 (*1 *2 *1 *2) (-12 (-4 *3 (-172)) (-5 *1 (-284 *3 *2 *4 *5 *6 *7)) (-4 *2 (-1219 *3)) (-4 *4 (-23)) (-14 *5 (-1 *2 *2 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *4))))) 
+(-13 (-301) (-10 -8 (-15 -2477 (|#3| $)) (-15 -2747 (|#2| $)) (-15 -3094 ($ |#2| |#3|)) (-15 -2355 ((-3 $ "failed") $ $)) (-15 -2902 ((-3 $ "failed") $)) (-15 -2083 ($ $)) (-15 -2781 (|#2| $ |#2|)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-2902 (((-3 $ "failed") $) 33)) (-1598 (((-121) $) 30)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11) (($ (-568)) 27)) (-3425 (((-763)) 28)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
 (((-285) (-1275)) (T -285)) 
 NIL 
-(-13 (-1047) (-120 $ $) (-10 -7 (-6 -4512))) 
+(-13 (-1047) (-120 $ $) (-10 -7 (-6 -4514))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 $ $) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 $) . T) ((-716) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-1955 (((-634 (-2 (|:| |eigval| (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (|:| |geneigvec| (-634 (-679 (-409 (-953 |#1|))))))) (-679 (-409 (-953 |#1|)))) 83)) (-3122 (((-634 (-679 (-409 (-953 |#1|)))) (-2 (|:| |eigval| (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (|:| |eigmult| (-763)) (|:| |eigvec| (-634 (-679 (-409 (-953 |#1|)))))) (-679 (-409 (-953 |#1|)))) 78) (((-634 (-679 (-409 (-953 |#1|)))) (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|))) (-679 (-409 (-953 |#1|))) (-763) (-763)) 36)) (-3925 (((-634 (-2 (|:| |eigval| (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (|:| |eigmult| (-763)) (|:| |eigvec| (-634 (-679 (-409 (-953 |#1|))))))) (-679 (-409 (-953 |#1|)))) 80)) (-3708 (((-634 (-679 (-409 (-953 |#1|)))) (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|))) (-679 (-409 (-953 |#1|)))) 60)) (-1760 (((-634 (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (-679 (-409 (-953 |#1|)))) 59)) (-2678 (((-953 |#1|) (-679 (-409 (-953 |#1|)))) 47) (((-953 |#1|) (-679 (-409 (-953 |#1|))) (-1161)) 48))) 
-(((-286 |#1|) (-10 -7 (-15 -2678 ((-953 |#1|) (-679 (-409 (-953 |#1|))) (-1161))) (-15 -2678 ((-953 |#1|) (-679 (-409 (-953 |#1|))))) (-15 -1760 ((-634 (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (-679 (-409 (-953 |#1|))))) (-15 -3708 ((-634 (-679 (-409 (-953 |#1|)))) (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|))) (-679 (-409 (-953 |#1|))))) (-15 -3122 ((-634 (-679 (-409 (-953 |#1|)))) (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|))) (-679 (-409 (-953 |#1|))) (-763) (-763))) (-15 -3122 ((-634 (-679 (-409 (-953 |#1|)))) (-2 (|:| |eigval| (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (|:| |eigmult| (-763)) (|:| |eigvec| (-634 (-679 (-409 (-953 |#1|)))))) (-679 (-409 (-953 |#1|))))) (-15 -1955 ((-634 (-2 (|:| |eigval| (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (|:| |geneigvec| (-634 (-679 (-409 (-953 |#1|))))))) (-679 (-409 (-953 |#1|))))) (-15 -3925 ((-634 (-2 (|:| |eigval| (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (|:| |eigmult| (-763)) (|:| |eigvec| (-634 (-679 (-409 (-953 |#1|))))))) (-679 (-409 (-953 |#1|)))))) (-453)) (T -286)) 
-((-3925 (*1 *2 *3) (-12 (-4 *4 (-453)) (-5 *2 (-634 (-2 (|:| |eigval| (-3 (-409 (-953 *4)) (-1150 (-1161) (-953 *4)))) (|:| |eigmult| (-763)) (|:| |eigvec| (-634 (-679 (-409 (-953 *4)))))))) (-5 *1 (-286 *4)) (-5 *3 (-679 (-409 (-953 *4)))))) (-1955 (*1 *2 *3) (-12 (-4 *4 (-453)) (-5 *2 (-634 (-2 (|:| |eigval| (-3 (-409 (-953 *4)) (-1150 (-1161) (-953 *4)))) (|:| |geneigvec| (-634 (-679 (-409 (-953 *4)))))))) (-5 *1 (-286 *4)) (-5 *3 (-679 (-409 (-953 *4)))))) (-3122 (*1 *2 *3 *4) (-12 (-5 *3 (-2 (|:| |eigval| (-3 (-409 (-953 *5)) (-1150 (-1161) (-953 *5)))) (|:| |eigmult| (-763)) (|:| |eigvec| (-634 *4)))) (-4 *5 (-453)) (-5 *2 (-634 (-679 (-409 (-953 *5))))) (-5 *1 (-286 *5)) (-5 *4 (-679 (-409 (-953 *5)))))) (-3122 (*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-3 (-409 (-953 *6)) (-1150 (-1161) (-953 *6)))) (-5 *5 (-763)) (-4 *6 (-453)) (-5 *2 (-634 (-679 (-409 (-953 *6))))) (-5 *1 (-286 *6)) (-5 *4 (-679 (-409 (-953 *6)))))) (-3708 (*1 *2 *3 *4) (-12 (-5 *3 (-3 (-409 (-953 *5)) (-1150 (-1161) (-953 *5)))) (-4 *5 (-453)) (-5 *2 (-634 (-679 (-409 (-953 *5))))) (-5 *1 (-286 *5)) (-5 *4 (-679 (-409 (-953 *5)))))) (-1760 (*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-953 *4)))) (-4 *4 (-453)) (-5 *2 (-634 (-3 (-409 (-953 *4)) (-1150 (-1161) (-953 *4))))) (-5 *1 (-286 *4)))) (-2678 (*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-953 *4)))) (-5 *2 (-953 *4)) (-5 *1 (-286 *4)) (-4 *4 (-453)))) (-2678 (*1 *2 *3 *4) (-12 (-5 *3 (-679 (-409 (-953 *5)))) (-5 *4 (-1161)) (-5 *2 (-953 *5)) (-5 *1 (-286 *5)) (-4 *5 (-453))))) 
-(-10 -7 (-15 -2678 ((-953 |#1|) (-679 (-409 (-953 |#1|))) (-1161))) (-15 -2678 ((-953 |#1|) (-679 (-409 (-953 |#1|))))) (-15 -1760 ((-634 (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (-679 (-409 (-953 |#1|))))) (-15 -3708 ((-634 (-679 (-409 (-953 |#1|)))) (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|))) (-679 (-409 (-953 |#1|))))) (-15 -3122 ((-634 (-679 (-409 (-953 |#1|)))) (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|))) (-679 (-409 (-953 |#1|))) (-763) (-763))) (-15 -3122 ((-634 (-679 (-409 (-953 |#1|)))) (-2 (|:| |eigval| (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (|:| |eigmult| (-763)) (|:| |eigvec| (-634 (-679 (-409 (-953 |#1|)))))) (-679 (-409 (-953 |#1|))))) (-15 -1955 ((-634 (-2 (|:| |eigval| (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (|:| |geneigvec| (-634 (-679 (-409 (-953 |#1|))))))) (-679 (-409 (-953 |#1|))))) (-15 -3925 ((-634 (-2 (|:| |eigval| (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (|:| |eigmult| (-763)) (|:| |eigvec| (-634 (-679 (-409 (-953 |#1|))))))) (-679 (-409 (-953 |#1|)))))) 
-((-2795 (((-288 |#2|) (-1 |#2| |#1|) (-288 |#1|)) 14))) 
-(((-287 |#1| |#2|) (-10 -7 (-15 -2795 ((-288 |#2|) (-1 |#2| |#1|) (-288 |#1|)))) (-1195) (-1195)) (T -287)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-288 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-288 *6)) (-5 *1 (-287 *5 *6))))) 
-(-10 -7 (-15 -2795 ((-288 |#2|) (-1 |#2| |#1|) (-288 |#1|)))) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2537 (((-121) $) NIL (|has| |#1| (-21)))) (-2589 (($ $) 22)) (-3134 (((-3 $ "failed") $ $) NIL (|has| |#1| (-21)))) (-2366 (($ $ $) 93 (|has| |#1| (-296)))) (-2671 (($) NIL (-2198 (|has| |#1| (-21)) (|has| |#1| (-716))) CONST)) (-4153 (($ $) 8 (|has| |#1| (-21)))) (-2363 (((-3 $ "failed") $) 68 (|has| |#1| (-716)))) (-2107 ((|#1| $) 21)) (-2925 (((-3 $ "failed") $) 66 (|has| |#1| (-716)))) (-2735 (((-121) $) NIL (|has| |#1| (-716)))) (-2795 (($ (-1 |#1| |#1|) $) 24)) (-1466 ((|#1| $) 9)) (-3183 (($ $) 57 (|has| |#1| (-21)))) (-2307 (((-3 $ "failed") $) 67 (|has| |#1| (-716)))) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-2081 (($ $) 70 (-2198 (|has| |#1| (-365)) (|has| |#1| (-478))))) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-2503 (((-634 $) $) 19 (|has| |#1| (-558)))) (-1339 (($ $ $) 34 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 $)) 37 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-1161) |#1|) 27 (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-634 (-1161)) (-634 |#1|)) 31 (|has| |#1| (-523 (-1161) |#1|)))) (-2783 (($ |#1| |#1|) 17)) (-4321 (((-139)) 88 (|has| |#1| (-365)))) (-4189 (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161)) 85 (|has| |#1| (-895 (-1161))))) (-1458 (($ $ $) NIL (|has| |#1| (-478)))) (-2353 (($ $ $) NIL (|has| |#1| (-478)))) (-2745 (($ (-568)) NIL (|has| |#1| (-1047))) (((-121) $) 45 (|has| |#1| (-1090))) (((-850) $) 44 (|has| |#1| (-1090)))) (-4078 (((-763)) 73 (|has| |#1| (-1047)))) (-1887 (($ $ (-568)) NIL (|has| |#1| (-478))) (($ $ (-763)) NIL (|has| |#1| (-716))) (($ $ (-917)) NIL (|has| |#1| (-1102)))) (-3056 (($) 55 (|has| |#1| (-21)) CONST)) (-1556 (($) 63 (|has| |#1| (-716)) CONST)) (-3190 (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161))))) (-1717 (($ |#1| |#1|) 20) (((-121) $ $) 40 (|has| |#1| (-1090)))) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365))) (($ $ $) 90 (-2198 (|has| |#1| (-365)) (|has| |#1| (-478))))) (-1773 (($ |#1| $) 53 (|has| |#1| (-21))) (($ $ |#1|) 54 (|has| |#1| (-21))) (($ $ $) 52 (|has| |#1| (-21))) (($ $) 51 (|has| |#1| (-21)))) (-1767 (($ |#1| $) 48 (|has| |#1| (-25))) (($ $ |#1|) 49 (|has| |#1| (-25))) (($ $ $) 47 (|has| |#1| (-25)))) (** (($ $ (-568)) NIL (|has| |#1| (-478))) (($ $ (-763)) NIL (|has| |#1| (-716))) (($ $ (-917)) NIL (|has| |#1| (-1102)))) (* (($ $ |#1|) 61 (|has| |#1| (-1102))) (($ |#1| $) 60 (|has| |#1| (-1102))) (($ $ $) 59 (|has| |#1| (-1102))) (($ (-568) $) 76 (|has| |#1| (-21))) (($ (-763) $) NIL (|has| |#1| (-21))) (($ (-917) $) NIL (|has| |#1| (-25))))) 
-(((-288 |#1|) (-13 (-1195) (-10 -8 (-15 -1717 ($ |#1| |#1|)) (-15 -2783 ($ |#1| |#1|)) (-15 -2589 ($ $)) (-15 -1466 (|#1| $)) (-15 -2107 (|#1| $)) (-15 -2795 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-523 (-1161) |#1|)) (-6 (-523 (-1161) |#1|)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-6 (-1090)) (-6 (-608 (-121))) (IF (|has| |#1| (-303 |#1|)) (PROGN (-15 -1339 ($ $ $)) (-15 -1339 ($ $ (-634 $)))) |noBranch|)) |noBranch|) (IF (|has| |#1| (-25)) (PROGN (-6 (-25)) (-15 -1767 ($ |#1| $)) (-15 -1767 ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-21)) (PROGN (-6 (-21)) (-15 -3183 ($ $)) (-15 -4153 ($ $)) (-15 -1773 ($ |#1| $)) (-15 -1773 ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-1102)) (PROGN (-6 (-1102)) (-15 * ($ |#1| $)) (-15 * ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-716)) (PROGN (-6 (-716)) (-15 -2307 ((-3 $ "failed") $)) (-15 -2363 ((-3 $ "failed") $))) |noBranch|) (IF (|has| |#1| (-478)) (PROGN (-6 (-478)) (-15 -2307 ((-3 $ "failed") $)) (-15 -2363 ((-3 $ "failed") $))) |noBranch|) (IF (|has| |#1| (-1047)) (PROGN (-6 (-1047)) (-6 (-120 |#1| |#1|))) |noBranch|) (IF (|has| |#1| (-172)) (-6 (-707 |#1|)) |noBranch|) (IF (|has| |#1| (-558)) (-15 -2503 ((-634 $) $)) |noBranch|) (IF (|has| |#1| (-895 (-1161))) (-6 (-895 (-1161))) |noBranch|) (IF (|has| |#1| (-365)) (PROGN (-6 (-1251 |#1|)) (-15 -1779 ($ $ $)) (-15 -2081 ($ $))) |noBranch|) (IF (|has| |#1| (-296)) (-15 -2366 ($ $ $)) |noBranch|))) (-1195)) (T -288)) 
-((-1717 (*1 *1 *2 *2) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1195)))) (-2783 (*1 *1 *2 *2) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1195)))) (-2589 (*1 *1 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1195)))) (-1466 (*1 *2 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1195)))) (-2107 (*1 *2 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1195)))) (-2795 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1195)) (-5 *1 (-288 *3)))) (-1339 (*1 *1 *1 *1) (-12 (-4 *2 (-303 *2)) (-4 *2 (-1090)) (-4 *2 (-1195)) (-5 *1 (-288 *2)))) (-1339 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-288 *3))) (-4 *3 (-303 *3)) (-4 *3 (-1090)) (-4 *3 (-1195)) (-5 *1 (-288 *3)))) (-1767 (*1 *1 *2 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-25)) (-4 *2 (-1195)))) (-1767 (*1 *1 *1 *2) (-12 (-5 *1 (-288 *2)) (-4 *2 (-25)) (-4 *2 (-1195)))) (-3183 (*1 *1 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-21)) (-4 *2 (-1195)))) (-4153 (*1 *1 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-21)) (-4 *2 (-1195)))) (-1773 (*1 *1 *2 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-21)) (-4 *2 (-1195)))) (-1773 (*1 *1 *1 *2) (-12 (-5 *1 (-288 *2)) (-4 *2 (-21)) (-4 *2 (-1195)))) (-2307 (*1 *1 *1) (|partial| -12 (-5 *1 (-288 *2)) (-4 *2 (-716)) (-4 *2 (-1195)))) (-2363 (*1 *1 *1) (|partial| -12 (-5 *1 (-288 *2)) (-4 *2 (-716)) (-4 *2 (-1195)))) (-2503 (*1 *2 *1) (-12 (-5 *2 (-634 (-288 *3))) (-5 *1 (-288 *3)) (-4 *3 (-558)) (-4 *3 (-1195)))) (-2366 (*1 *1 *1 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-296)) (-4 *2 (-1195)))) (* (*1 *1 *1 *2) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1102)) (-4 *2 (-1195)))) (* (*1 *1 *2 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1102)) (-4 *2 (-1195)))) (-1779 (*1 *1 *1 *1) (-2198 (-12 (-5 *1 (-288 *2)) (-4 *2 (-365)) (-4 *2 (-1195))) (-12 (-5 *1 (-288 *2)) (-4 *2 (-478)) (-4 *2 (-1195))))) (-2081 (*1 *1 *1) (-2198 (-12 (-5 *1 (-288 *2)) (-4 *2 (-365)) (-4 *2 (-1195))) (-12 (-5 *1 (-288 *2)) (-4 *2 (-478)) (-4 *2 (-1195)))))) 
-(-13 (-1195) (-10 -8 (-15 -1717 ($ |#1| |#1|)) (-15 -2783 ($ |#1| |#1|)) (-15 -2589 ($ $)) (-15 -1466 (|#1| $)) (-15 -2107 (|#1| $)) (-15 -2795 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-523 (-1161) |#1|)) (-6 (-523 (-1161) |#1|)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-6 (-1090)) (-6 (-608 (-121))) (IF (|has| |#1| (-303 |#1|)) (PROGN (-15 -1339 ($ $ $)) (-15 -1339 ($ $ (-634 $)))) |noBranch|)) |noBranch|) (IF (|has| |#1| (-25)) (PROGN (-6 (-25)) (-15 -1767 ($ |#1| $)) (-15 -1767 ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-21)) (PROGN (-6 (-21)) (-15 -3183 ($ $)) (-15 -4153 ($ $)) (-15 -1773 ($ |#1| $)) (-15 -1773 ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-1102)) (PROGN (-6 (-1102)) (-15 * ($ |#1| $)) (-15 * ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-716)) (PROGN (-6 (-716)) (-15 -2307 ((-3 $ "failed") $)) (-15 -2363 ((-3 $ "failed") $))) |noBranch|) (IF (|has| |#1| (-478)) (PROGN (-6 (-478)) (-15 -2307 ((-3 $ "failed") $)) (-15 -2363 ((-3 $ "failed") $))) |noBranch|) (IF (|has| |#1| (-1047)) (PROGN (-6 (-1047)) (-6 (-120 |#1| |#1|))) |noBranch|) (IF (|has| |#1| (-172)) (-6 (-707 |#1|)) |noBranch|) (IF (|has| |#1| (-558)) (-15 -2503 ((-634 $) $)) |noBranch|) (IF (|has| |#1| (-895 (-1161))) (-6 (-895 (-1161))) |noBranch|) (IF (|has| |#1| (-365)) (PROGN (-6 (-1251 |#1|)) (-15 -1779 ($ $ $)) (-15 -2081 ($ $))) |noBranch|) (IF (|has| |#1| (-296)) (-15 -2366 ($ $ $)) |noBranch|))) 
-((-2447 (((-121) $ $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-2986 (($) NIL) (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-1868 (((-1249) $ |#1| |#1|) NIL (|has| $ (-6 -4520)))) (-2510 (((-121) $ (-763)) NIL)) (-2436 ((|#2| $ |#1| |#2|) NIL)) (-3507 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-2674 (((-3 |#2| "failed") |#1| $) NIL)) (-2671 (($) NIL T CONST)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-3405 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (|has| $ (-6 -4519))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-3 |#2| "failed") |#1| $) NIL)) (-4328 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-3092 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (|has| $ (-6 -4519))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-3989 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#2| $ |#1|) NIL)) (-4360 (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-634 |#2|) $) NIL (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) NIL)) (-1881 ((|#1| $) NIL (|has| |#1| (-842)))) (-1979 (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-634 |#2|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-2223 ((|#1| $) NIL (|has| |#1| (-842)))) (-3674 (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4520))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-1946 (((-634 |#1|) $) NIL)) (-3548 (((-121) |#1| $) NIL)) (-1890 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-4450 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-4174 (((-634 |#1|) $) NIL)) (-3578 (((-121) |#1| $) NIL)) (-4022 (((-1108) $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-3876 ((|#2| $) NIL (|has| |#1| (-842)))) (-3775 (((-3 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) "failed") (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL)) (-3724 (($ $ |#2|) NIL (|has| $ (-6 -4520)))) (-1315 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-1387 (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-2041 (((-634 |#2|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL)) (-2085 (($) NIL) (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-4168 (((-763) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-763) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090)))) (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-609 (-541))))) (-4287 (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-2745 (((-850) $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-2367 (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-1319 (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-289 |#1| |#2|) (-13 (-1172 |#1| |#2|) (-10 -7 (-6 -4519))) (-1090) (-1090)) (T -289)) 
-NIL 
-(-13 (-1172 |#1| |#2|) (-10 -7 (-6 -4519))) 
-((-2183 (((-305) (-1143) (-634 (-1143))) 16) (((-305) (-1143) (-1143)) 15) (((-305) (-634 (-1143))) 14) (((-305) (-1143)) 12))) 
-(((-290) (-10 -7 (-15 -2183 ((-305) (-1143))) (-15 -2183 ((-305) (-634 (-1143)))) (-15 -2183 ((-305) (-1143) (-1143))) (-15 -2183 ((-305) (-1143) (-634 (-1143)))))) (T -290)) 
-((-2183 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-1143))) (-5 *3 (-1143)) (-5 *2 (-305)) (-5 *1 (-290)))) (-2183 (*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-305)) (-5 *1 (-290)))) (-2183 (*1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-305)) (-5 *1 (-290)))) (-2183 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-305)) (-5 *1 (-290))))) 
-(-10 -7 (-15 -2183 ((-305) (-1143))) (-15 -2183 ((-305) (-634 (-1143)))) (-15 -2183 ((-305) (-1143) (-1143))) (-15 -2183 ((-305) (-1143) (-634 (-1143))))) 
-((-2795 ((|#2| (-1 |#2| |#1|) (-1143) (-607 |#1|)) 17))) 
-(((-291 |#1| |#2|) (-10 -7 (-15 -2795 (|#2| (-1 |#2| |#1|) (-1143) (-607 |#1|)))) (-296) (-1195)) (T -291)) 
-((-2795 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *6)) (-5 *4 (-1143)) (-5 *5 (-607 *6)) (-4 *6 (-296)) (-4 *2 (-1195)) (-5 *1 (-291 *6 *2))))) 
-(-10 -7 (-15 -2795 (|#2| (-1 |#2| |#1|) (-1143) (-607 |#1|)))) 
-((-2795 ((|#2| (-1 |#2| |#1|) (-607 |#1|)) 17))) 
-(((-292 |#1| |#2|) (-10 -7 (-15 -2795 (|#2| (-1 |#2| |#1|) (-607 |#1|)))) (-296) (-296)) (T -292)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 *5)) (-5 *4 (-607 *5)) (-4 *5 (-296)) (-4 *2 (-296)) (-5 *1 (-292 *5 *2))))) 
-(-10 -7 (-15 -2795 (|#2| (-1 |#2| |#1|) (-607 |#1|)))) 
-((-1816 (((-121) (-215)) 10))) 
-(((-293 |#1| |#2|) (-10 -7 (-15 -1816 ((-121) (-215)))) (-215) (-215)) (T -293)) 
-((-1816 (*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-121)) (-5 *1 (-293 *4 *5)) (-14 *4 *3) (-14 *5 *3)))) 
-(-10 -7 (-15 -1816 ((-121) (-215)))) 
-((-2394 (((-1141 (-215)) (-310 (-215)) (-634 (-1161)) (-1084 (-835 (-215)))) 88)) (-1539 (((-1141 (-215)) (-1244 (-310 (-215))) (-634 (-1161)) (-1084 (-835 (-215)))) 103) (((-1141 (-215)) (-310 (-215)) (-634 (-1161)) (-1084 (-835 (-215)))) 58)) (-1903 (((-634 (-1143)) (-1141 (-215))) NIL)) (-1685 (((-634 (-215)) (-310 (-215)) (-1161) (-1084 (-835 (-215)))) 55)) (-2922 (((-634 (-215)) (-953 (-409 (-568))) (-1161) (-1084 (-835 (-215)))) 47)) (-2309 (((-634 (-1143)) (-634 (-215))) NIL)) (-2066 (((-215) (-1084 (-835 (-215)))) 23)) (-3632 (((-215) (-1084 (-835 (-215)))) 24)) (-3931 (((-121) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 51)) (-2281 (((-1143) (-215)) NIL))) 
-(((-294) (-10 -7 (-15 -2066 ((-215) (-1084 (-835 (-215))))) (-15 -3632 ((-215) (-1084 (-835 (-215))))) (-15 -3931 ((-121) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -1685 ((-634 (-215)) (-310 (-215)) (-1161) (-1084 (-835 (-215))))) (-15 -2394 ((-1141 (-215)) (-310 (-215)) (-634 (-1161)) (-1084 (-835 (-215))))) (-15 -1539 ((-1141 (-215)) (-310 (-215)) (-634 (-1161)) (-1084 (-835 (-215))))) (-15 -1539 ((-1141 (-215)) (-1244 (-310 (-215))) (-634 (-1161)) (-1084 (-835 (-215))))) (-15 -2922 ((-634 (-215)) (-953 (-409 (-568))) (-1161) (-1084 (-835 (-215))))) (-15 -2281 ((-1143) (-215))) (-15 -2309 ((-634 (-1143)) (-634 (-215)))) (-15 -1903 ((-634 (-1143)) (-1141 (-215)))))) (T -294)) 
-((-1903 (*1 *2 *3) (-12 (-5 *3 (-1141 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-294)))) (-2309 (*1 *2 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-294)))) (-2281 (*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-1143)) (-5 *1 (-294)))) (-2922 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-953 (-409 (-568)))) (-5 *4 (-1161)) (-5 *5 (-1084 (-835 (-215)))) (-5 *2 (-634 (-215))) (-5 *1 (-294)))) (-1539 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1244 (-310 (-215)))) (-5 *4 (-634 (-1161))) (-5 *5 (-1084 (-835 (-215)))) (-5 *2 (-1141 (-215))) (-5 *1 (-294)))) (-1539 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-215))) (-5 *4 (-634 (-1161))) (-5 *5 (-1084 (-835 (-215)))) (-5 *2 (-1141 (-215))) (-5 *1 (-294)))) (-2394 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-215))) (-5 *4 (-634 (-1161))) (-5 *5 (-1084 (-835 (-215)))) (-5 *2 (-1141 (-215))) (-5 *1 (-294)))) (-1685 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-215))) (-5 *4 (-1161)) (-5 *5 (-1084 (-835 (-215)))) (-5 *2 (-634 (-215))) (-5 *1 (-294)))) (-3931 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-121)) (-5 *1 (-294)))) (-3632 (*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-294)))) (-2066 (*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-294))))) 
-(-10 -7 (-15 -2066 ((-215) (-1084 (-835 (-215))))) (-15 -3632 ((-215) (-1084 (-835 (-215))))) (-15 -3931 ((-121) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -1685 ((-634 (-215)) (-310 (-215)) (-1161) (-1084 (-835 (-215))))) (-15 -2394 ((-1141 (-215)) (-310 (-215)) (-634 (-1161)) (-1084 (-835 (-215))))) (-15 -1539 ((-1141 (-215)) (-310 (-215)) (-634 (-1161)) (-1084 (-835 (-215))))) (-15 -1539 ((-1141 (-215)) (-1244 (-310 (-215))) (-634 (-1161)) (-1084 (-835 (-215))))) (-15 -2922 ((-634 (-215)) (-953 (-409 (-568))) (-1161) (-1084 (-835 (-215))))) (-15 -2281 ((-1143) (-215))) (-15 -2309 ((-634 (-1143)) (-634 (-215)))) (-15 -1903 ((-634 (-1143)) (-1141 (-215))))) 
-((-3001 (((-634 (-607 $)) $) 28)) (-2366 (($ $ (-288 $)) 80) (($ $ (-634 (-288 $))) 120) (($ $ (-634 (-607 $)) (-634 $)) NIL)) (-3666 (((-3 (-607 $) "failed") $) 110)) (-2854 (((-607 $) $) 109)) (-4499 (($ $) 19) (($ (-634 $)) 54)) (-3296 (((-634 (-123)) $) 37)) (-3488 (((-123) (-123)) 90)) (-1825 (((-121) $) 128)) (-2795 (($ (-1 $ $) (-607 $)) 88)) (-3693 (((-3 (-607 $) "failed") $) 92)) (-3443 (($ (-123) $) 60) (($ (-123) (-634 $)) 98)) (-2841 (((-121) $ (-123)) 114) (((-121) $ (-1161)) 113)) (-2961 (((-763) $) 45)) (-4059 (((-121) $ $) 58) (((-121) $ (-1161)) 49)) (-3277 (((-121) $) 126)) (-1339 (($ $ (-607 $) $) NIL) (($ $ (-634 (-607 $)) (-634 $)) NIL) (($ $ (-634 (-288 $))) 118) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ $))) 83) (($ $ (-634 (-1161)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-1161) (-1 $ (-634 $))) 68) (($ $ (-1161) (-1 $ $)) 74) (($ $ (-634 (-123)) (-634 (-1 $ $))) 82) (($ $ (-634 (-123)) (-634 (-1 $ (-634 $)))) 84) (($ $ (-123) (-1 $ (-634 $))) 70) (($ $ (-123) (-1 $ $)) 76)) (-2779 (($ (-123) $) 61) (($ (-123) $ $) 62) (($ (-123) $ $ $) 63) (($ (-123) $ $ $ $) 64) (($ (-123) (-634 $)) 106)) (-3502 (($ $) 51) (($ $ $) 116)) (-2092 (($ $) 17) (($ (-634 $)) 53)) (-2887 (((-121) (-123)) 22))) 
-(((-295 |#1|) (-10 -8 (-15 -1825 ((-121) |#1|)) (-15 -3277 ((-121) |#1|)) (-15 -1339 (|#1| |#1| (-123) (-1 |#1| |#1|))) (-15 -1339 (|#1| |#1| (-123) (-1 |#1| (-634 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-123)) (-634 (-1 |#1| (-634 |#1|))))) (-15 -1339 (|#1| |#1| (-634 (-123)) (-634 (-1 |#1| |#1|)))) (-15 -1339 (|#1| |#1| (-1161) (-1 |#1| |#1|))) (-15 -1339 (|#1| |#1| (-1161) (-1 |#1| (-634 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-1 |#1| (-634 |#1|))))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-1 |#1| |#1|)))) (-15 -4059 ((-121) |#1| (-1161))) (-15 -4059 ((-121) |#1| |#1|)) (-15 -2795 (|#1| (-1 |#1| |#1|) (-607 |#1|))) (-15 -3443 (|#1| (-123) (-634 |#1|))) (-15 -3443 (|#1| (-123) |#1|)) (-15 -2841 ((-121) |#1| (-1161))) (-15 -2841 ((-121) |#1| (-123))) (-15 -2887 ((-121) (-123))) (-15 -3488 ((-123) (-123))) (-15 -3296 ((-634 (-123)) |#1|)) (-15 -3001 ((-634 (-607 |#1|)) |#1|)) (-15 -3693 ((-3 (-607 |#1|) "failed") |#1|)) (-15 -2961 ((-763) |#1|)) (-15 -3502 (|#1| |#1| |#1|)) (-15 -3502 (|#1| |#1|)) (-15 -4499 (|#1| (-634 |#1|))) (-15 -4499 (|#1| |#1|)) (-15 -2092 (|#1| (-634 |#1|))) (-15 -2092 (|#1| |#1|)) (-15 -2366 (|#1| |#1| (-634 (-607 |#1|)) (-634 |#1|))) (-15 -2366 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -2366 (|#1| |#1| (-288 |#1|))) (-15 -2779 (|#1| (-123) (-634 |#1|))) (-15 -2779 (|#1| (-123) |#1| |#1| |#1| |#1|)) (-15 -2779 (|#1| (-123) |#1| |#1| |#1|)) (-15 -2779 (|#1| (-123) |#1| |#1|)) (-15 -2779 (|#1| (-123) |#1|)) (-15 -1339 (|#1| |#1| (-634 |#1|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#1| |#1|)) (-15 -1339 (|#1| |#1| (-288 |#1|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-607 |#1|)) (-634 |#1|))) (-15 -1339 (|#1| |#1| (-607 |#1|) |#1|)) (-15 -2854 ((-607 |#1|) |#1|)) (-15 -3666 ((-3 (-607 |#1|) "failed") |#1|))) (-296)) (T -295)) 
-((-3488 (*1 *2 *2) (-12 (-5 *2 (-123)) (-5 *1 (-295 *3)) (-4 *3 (-296)))) (-2887 (*1 *2 *3) (-12 (-5 *3 (-123)) (-5 *2 (-121)) (-5 *1 (-295 *4)) (-4 *4 (-296))))) 
-(-10 -8 (-15 -1825 ((-121) |#1|)) (-15 -3277 ((-121) |#1|)) (-15 -1339 (|#1| |#1| (-123) (-1 |#1| |#1|))) (-15 -1339 (|#1| |#1| (-123) (-1 |#1| (-634 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-123)) (-634 (-1 |#1| (-634 |#1|))))) (-15 -1339 (|#1| |#1| (-634 (-123)) (-634 (-1 |#1| |#1|)))) (-15 -1339 (|#1| |#1| (-1161) (-1 |#1| |#1|))) (-15 -1339 (|#1| |#1| (-1161) (-1 |#1| (-634 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-1 |#1| (-634 |#1|))))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-1 |#1| |#1|)))) (-15 -4059 ((-121) |#1| (-1161))) (-15 -4059 ((-121) |#1| |#1|)) (-15 -2795 (|#1| (-1 |#1| |#1|) (-607 |#1|))) (-15 -3443 (|#1| (-123) (-634 |#1|))) (-15 -3443 (|#1| (-123) |#1|)) (-15 -2841 ((-121) |#1| (-1161))) (-15 -2841 ((-121) |#1| (-123))) (-15 -2887 ((-121) (-123))) (-15 -3488 ((-123) (-123))) (-15 -3296 ((-634 (-123)) |#1|)) (-15 -3001 ((-634 (-607 |#1|)) |#1|)) (-15 -3693 ((-3 (-607 |#1|) "failed") |#1|)) (-15 -2961 ((-763) |#1|)) (-15 -3502 (|#1| |#1| |#1|)) (-15 -3502 (|#1| |#1|)) (-15 -4499 (|#1| (-634 |#1|))) (-15 -4499 (|#1| |#1|)) (-15 -2092 (|#1| (-634 |#1|))) (-15 -2092 (|#1| |#1|)) (-15 -2366 (|#1| |#1| (-634 (-607 |#1|)) (-634 |#1|))) (-15 -2366 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -2366 (|#1| |#1| (-288 |#1|))) (-15 -2779 (|#1| (-123) (-634 |#1|))) (-15 -2779 (|#1| (-123) |#1| |#1| |#1| |#1|)) (-15 -2779 (|#1| (-123) |#1| |#1| |#1|)) (-15 -2779 (|#1| (-123) |#1| |#1|)) (-15 -2779 (|#1| (-123) |#1|)) (-15 -1339 (|#1| |#1| (-634 |#1|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#1| |#1|)) (-15 -1339 (|#1| |#1| (-288 |#1|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-607 |#1|)) (-634 |#1|))) (-15 -1339 (|#1| |#1| (-607 |#1|) |#1|)) (-15 -2854 ((-607 |#1|) |#1|)) (-15 -3666 ((-3 (-607 |#1|) "failed") |#1|))) 
-((-2447 (((-121) $ $) 7)) (-3001 (((-634 (-607 $)) $) 43)) (-2366 (($ $ (-288 $)) 55) (($ $ (-634 (-288 $))) 54) (($ $ (-634 (-607 $)) (-634 $)) 53)) (-3666 (((-3 (-607 $) "failed") $) 68)) (-2854 (((-607 $) $) 67)) (-4499 (($ $) 50) (($ (-634 $)) 49)) (-3296 (((-634 (-123)) $) 42)) (-3488 (((-123) (-123)) 41)) (-1825 (((-121) $) 21 (|has| $ (-1037 (-568))))) (-3007 (((-1157 $) (-607 $)) 24 (|has| $ (-1047)))) (-2521 (($ $ $) 12)) (-3268 (($ $ $) 13)) (-2795 (($ (-1 $ $) (-607 $)) 35)) (-3693 (((-3 (-607 $) "failed") $) 45)) (-4487 (((-1143) $) 9)) (-3804 (((-634 (-607 $)) $) 44)) (-3443 (($ (-123) $) 37) (($ (-123) (-634 $)) 36)) (-2841 (((-121) $ (-123)) 39) (((-121) $ (-1161)) 38)) (-2961 (((-763) $) 46)) (-4022 (((-1108) $) 10)) (-4059 (((-121) $ $) 34) (((-121) $ (-1161)) 33)) (-3277 (((-121) $) 22 (|has| $ (-1037 (-568))))) (-1339 (($ $ (-607 $) $) 66) (($ $ (-634 (-607 $)) (-634 $)) 65) (($ $ (-634 (-288 $))) 64) (($ $ (-288 $)) 63) (($ $ $ $) 62) (($ $ (-634 $) (-634 $)) 61) (($ $ (-634 (-1161)) (-634 (-1 $ $))) 32) (($ $ (-634 (-1161)) (-634 (-1 $ (-634 $)))) 31) (($ $ (-1161) (-1 $ (-634 $))) 30) (($ $ (-1161) (-1 $ $)) 29) (($ $ (-634 (-123)) (-634 (-1 $ $))) 28) (($ $ (-634 (-123)) (-634 (-1 $ (-634 $)))) 27) (($ $ (-123) (-1 $ (-634 $))) 26) (($ $ (-123) (-1 $ $)) 25)) (-2779 (($ (-123) $) 60) (($ (-123) $ $) 59) (($ (-123) $ $ $) 58) (($ (-123) $ $ $ $) 57) (($ (-123) (-634 $)) 56)) (-3502 (($ $) 48) (($ $ $) 47)) (-1626 (($ $) 23 (|has| $ (-1047)))) (-2745 (((-850) $) 11) (($ (-607 $)) 69)) (-2092 (($ $) 52) (($ (-634 $)) 51)) (-2887 (((-121) (-123)) 40)) (-1751 (((-121) $ $) 15)) (-1738 (((-121) $ $) 16)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 14)) (-1732 (((-121) $ $) 17))) 
+((-4298 (((-634 (-2 (|:| |eigval| (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (|:| |geneigvec| (-634 (-679 (-409 (-953 |#1|))))))) (-679 (-409 (-953 |#1|)))) 83)) (-2622 (((-634 (-679 (-409 (-953 |#1|)))) (-2 (|:| |eigval| (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (|:| |eigmult| (-763)) (|:| |eigvec| (-634 (-679 (-409 (-953 |#1|)))))) (-679 (-409 (-953 |#1|)))) 78) (((-634 (-679 (-409 (-953 |#1|)))) (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|))) (-679 (-409 (-953 |#1|))) (-763) (-763)) 36)) (-2186 (((-634 (-2 (|:| |eigval| (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (|:| |eigmult| (-763)) (|:| |eigvec| (-634 (-679 (-409 (-953 |#1|))))))) (-679 (-409 (-953 |#1|)))) 80)) (-2408 (((-634 (-679 (-409 (-953 |#1|)))) (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|))) (-679 (-409 (-953 |#1|)))) 60)) (-3908 (((-634 (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (-679 (-409 (-953 |#1|)))) 59)) (-1295 (((-953 |#1|) (-679 (-409 (-953 |#1|)))) 47) (((-953 |#1|) (-679 (-409 (-953 |#1|))) (-1161)) 48))) 
+(((-286 |#1|) (-10 -7 (-15 -1295 ((-953 |#1|) (-679 (-409 (-953 |#1|))) (-1161))) (-15 -1295 ((-953 |#1|) (-679 (-409 (-953 |#1|))))) (-15 -3908 ((-634 (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (-679 (-409 (-953 |#1|))))) (-15 -2408 ((-634 (-679 (-409 (-953 |#1|)))) (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|))) (-679 (-409 (-953 |#1|))))) (-15 -2622 ((-634 (-679 (-409 (-953 |#1|)))) (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|))) (-679 (-409 (-953 |#1|))) (-763) (-763))) (-15 -2622 ((-634 (-679 (-409 (-953 |#1|)))) (-2 (|:| |eigval| (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (|:| |eigmult| (-763)) (|:| |eigvec| (-634 (-679 (-409 (-953 |#1|)))))) (-679 (-409 (-953 |#1|))))) (-15 -4298 ((-634 (-2 (|:| |eigval| (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (|:| |geneigvec| (-634 (-679 (-409 (-953 |#1|))))))) (-679 (-409 (-953 |#1|))))) (-15 -2186 ((-634 (-2 (|:| |eigval| (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (|:| |eigmult| (-763)) (|:| |eigvec| (-634 (-679 (-409 (-953 |#1|))))))) (-679 (-409 (-953 |#1|)))))) (-453)) (T -286)) 
+((-2186 (*1 *2 *3) (-12 (-4 *4 (-453)) (-5 *2 (-634 (-2 (|:| |eigval| (-3 (-409 (-953 *4)) (-1150 (-1161) (-953 *4)))) (|:| |eigmult| (-763)) (|:| |eigvec| (-634 (-679 (-409 (-953 *4)))))))) (-5 *1 (-286 *4)) (-5 *3 (-679 (-409 (-953 *4)))))) (-4298 (*1 *2 *3) (-12 (-4 *4 (-453)) (-5 *2 (-634 (-2 (|:| |eigval| (-3 (-409 (-953 *4)) (-1150 (-1161) (-953 *4)))) (|:| |geneigvec| (-634 (-679 (-409 (-953 *4)))))))) (-5 *1 (-286 *4)) (-5 *3 (-679 (-409 (-953 *4)))))) (-2622 (*1 *2 *3 *4) (-12 (-5 *3 (-2 (|:| |eigval| (-3 (-409 (-953 *5)) (-1150 (-1161) (-953 *5)))) (|:| |eigmult| (-763)) (|:| |eigvec| (-634 *4)))) (-4 *5 (-453)) (-5 *2 (-634 (-679 (-409 (-953 *5))))) (-5 *1 (-286 *5)) (-5 *4 (-679 (-409 (-953 *5)))))) (-2622 (*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-3 (-409 (-953 *6)) (-1150 (-1161) (-953 *6)))) (-5 *5 (-763)) (-4 *6 (-453)) (-5 *2 (-634 (-679 (-409 (-953 *6))))) (-5 *1 (-286 *6)) (-5 *4 (-679 (-409 (-953 *6)))))) (-2408 (*1 *2 *3 *4) (-12 (-5 *3 (-3 (-409 (-953 *5)) (-1150 (-1161) (-953 *5)))) (-4 *5 (-453)) (-5 *2 (-634 (-679 (-409 (-953 *5))))) (-5 *1 (-286 *5)) (-5 *4 (-679 (-409 (-953 *5)))))) (-3908 (*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-953 *4)))) (-4 *4 (-453)) (-5 *2 (-634 (-3 (-409 (-953 *4)) (-1150 (-1161) (-953 *4))))) (-5 *1 (-286 *4)))) (-1295 (*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-953 *4)))) (-5 *2 (-953 *4)) (-5 *1 (-286 *4)) (-4 *4 (-453)))) (-1295 (*1 *2 *3 *4) (-12 (-5 *3 (-679 (-409 (-953 *5)))) (-5 *4 (-1161)) (-5 *2 (-953 *5)) (-5 *1 (-286 *5)) (-4 *5 (-453))))) 
+(-10 -7 (-15 -1295 ((-953 |#1|) (-679 (-409 (-953 |#1|))) (-1161))) (-15 -1295 ((-953 |#1|) (-679 (-409 (-953 |#1|))))) (-15 -3908 ((-634 (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (-679 (-409 (-953 |#1|))))) (-15 -2408 ((-634 (-679 (-409 (-953 |#1|)))) (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|))) (-679 (-409 (-953 |#1|))))) (-15 -2622 ((-634 (-679 (-409 (-953 |#1|)))) (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|))) (-679 (-409 (-953 |#1|))) (-763) (-763))) (-15 -2622 ((-634 (-679 (-409 (-953 |#1|)))) (-2 (|:| |eigval| (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (|:| |eigmult| (-763)) (|:| |eigvec| (-634 (-679 (-409 (-953 |#1|)))))) (-679 (-409 (-953 |#1|))))) (-15 -4298 ((-634 (-2 (|:| |eigval| (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (|:| |geneigvec| (-634 (-679 (-409 (-953 |#1|))))))) (-679 (-409 (-953 |#1|))))) (-15 -2186 ((-634 (-2 (|:| |eigval| (-3 (-409 (-953 |#1|)) (-1150 (-1161) (-953 |#1|)))) (|:| |eigmult| (-763)) (|:| |eigvec| (-634 (-679 (-409 (-953 |#1|))))))) (-679 (-409 (-953 |#1|)))))) 
+((-2797 (((-288 |#2|) (-1 |#2| |#1|) (-288 |#1|)) 14))) 
+(((-287 |#1| |#2|) (-10 -7 (-15 -2797 ((-288 |#2|) (-1 |#2| |#1|) (-288 |#1|)))) (-1195) (-1195)) (T -287)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-288 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-288 *6)) (-5 *1 (-287 *5 *6))))) 
+(-10 -7 (-15 -2797 ((-288 |#2|) (-1 |#2| |#1|) (-288 |#1|)))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1819 (((-121) $) NIL (|has| |#1| (-21)))) (-2032 (($ $) 22)) (-2689 (((-3 $ "failed") $ $) NIL (|has| |#1| (-21)))) (-4069 (($ $ $) 93 (|has| |#1| (-296)))) (-4490 (($) NIL (-2199 (|has| |#1| (-21)) (|has| |#1| (-716))) CONST)) (-3830 (($ $) 8 (|has| |#1| (-21)))) (-4050 (((-3 $ "failed") $) 68 (|has| |#1| (-716)))) (-3250 ((|#1| $) 21)) (-2902 (((-3 $ "failed") $) 66 (|has| |#1| (-716)))) (-1598 (((-121) $) NIL (|has| |#1| (-716)))) (-2797 (($ (-1 |#1| |#1|) $) 24)) (-2433 ((|#1| $) 9)) (-1750 (($ $) 57 (|has| |#1| (-21)))) (-3686 (((-3 $ "failed") $) 67 (|has| |#1| (-716)))) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-2083 (($ $) 70 (-2199 (|has| |#1| (-365)) (|has| |#1| (-478))))) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-1635 (((-634 $) $) 19 (|has| |#1| (-558)))) (-1339 (($ $ $) 34 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 $)) 37 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-1161) |#1|) 27 (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-634 (-1161)) (-634 |#1|)) 31 (|has| |#1| (-523 (-1161) |#1|)))) (-2785 (($ |#1| |#1|) 17)) (-3108 (((-139)) 88 (|has| |#1| (-365)))) (-4191 (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161)) 85 (|has| |#1| (-895 (-1161))))) (-2387 (($ $ $) NIL (|has| |#1| (-478)))) (-3985 (($ $ $) NIL (|has| |#1| (-478)))) (-2747 (($ (-568)) NIL (|has| |#1| (-1047))) (((-121) $) 45 (|has| |#1| (-1090))) (((-850) $) 44 (|has| |#1| (-1090)))) (-3425 (((-763)) 73 (|has| |#1| (-1047)))) (-1889 (($ $ (-568)) NIL (|has| |#1| (-478))) (($ $ (-763)) NIL (|has| |#1| (-716))) (($ $ (-917)) NIL (|has| |#1| (-1102)))) (-3058 (($) 55 (|has| |#1| (-21)) CONST)) (-1557 (($) 63 (|has| |#1| (-716)) CONST)) (-3192 (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161))))) (-1719 (($ |#1| |#1|) 20) (((-121) $ $) 40 (|has| |#1| (-1090)))) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365))) (($ $ $) 90 (-2199 (|has| |#1| (-365)) (|has| |#1| (-478))))) (-1775 (($ |#1| $) 53 (|has| |#1| (-21))) (($ $ |#1|) 54 (|has| |#1| (-21))) (($ $ $) 52 (|has| |#1| (-21))) (($ $) 51 (|has| |#1| (-21)))) (-1769 (($ |#1| $) 48 (|has| |#1| (-25))) (($ $ |#1|) 49 (|has| |#1| (-25))) (($ $ $) 47 (|has| |#1| (-25)))) (** (($ $ (-568)) NIL (|has| |#1| (-478))) (($ $ (-763)) NIL (|has| |#1| (-716))) (($ $ (-917)) NIL (|has| |#1| (-1102)))) (* (($ $ |#1|) 61 (|has| |#1| (-1102))) (($ |#1| $) 60 (|has| |#1| (-1102))) (($ $ $) 59 (|has| |#1| (-1102))) (($ (-568) $) 76 (|has| |#1| (-21))) (($ (-763) $) NIL (|has| |#1| (-21))) (($ (-917) $) NIL (|has| |#1| (-25))))) 
+(((-288 |#1|) (-13 (-1195) (-10 -8 (-15 -1719 ($ |#1| |#1|)) (-15 -2785 ($ |#1| |#1|)) (-15 -2032 ($ $)) (-15 -2433 (|#1| $)) (-15 -3250 (|#1| $)) (-15 -2797 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-523 (-1161) |#1|)) (-6 (-523 (-1161) |#1|)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-6 (-1090)) (-6 (-608 (-121))) (IF (|has| |#1| (-303 |#1|)) (PROGN (-15 -1339 ($ $ $)) (-15 -1339 ($ $ (-634 $)))) |noBranch|)) |noBranch|) (IF (|has| |#1| (-25)) (PROGN (-6 (-25)) (-15 -1769 ($ |#1| $)) (-15 -1769 ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-21)) (PROGN (-6 (-21)) (-15 -1750 ($ $)) (-15 -3830 ($ $)) (-15 -1775 ($ |#1| $)) (-15 -1775 ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-1102)) (PROGN (-6 (-1102)) (-15 * ($ |#1| $)) (-15 * ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-716)) (PROGN (-6 (-716)) (-15 -3686 ((-3 $ "failed") $)) (-15 -4050 ((-3 $ "failed") $))) |noBranch|) (IF (|has| |#1| (-478)) (PROGN (-6 (-478)) (-15 -3686 ((-3 $ "failed") $)) (-15 -4050 ((-3 $ "failed") $))) |noBranch|) (IF (|has| |#1| (-1047)) (PROGN (-6 (-1047)) (-6 (-120 |#1| |#1|))) |noBranch|) (IF (|has| |#1| (-172)) (-6 (-707 |#1|)) |noBranch|) (IF (|has| |#1| (-558)) (-15 -1635 ((-634 $) $)) |noBranch|) (IF (|has| |#1| (-895 (-1161))) (-6 (-895 (-1161))) |noBranch|) (IF (|has| |#1| (-365)) (PROGN (-6 (-1251 |#1|)) (-15 -1781 ($ $ $)) (-15 -2083 ($ $))) |noBranch|) (IF (|has| |#1| (-296)) (-15 -4069 ($ $ $)) |noBranch|))) (-1195)) (T -288)) 
+((-1719 (*1 *1 *2 *2) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1195)))) (-2785 (*1 *1 *2 *2) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1195)))) (-2032 (*1 *1 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1195)))) (-2433 (*1 *2 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1195)))) (-3250 (*1 *2 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1195)))) (-2797 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1195)) (-5 *1 (-288 *3)))) (-1339 (*1 *1 *1 *1) (-12 (-4 *2 (-303 *2)) (-4 *2 (-1090)) (-4 *2 (-1195)) (-5 *1 (-288 *2)))) (-1339 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-288 *3))) (-4 *3 (-303 *3)) (-4 *3 (-1090)) (-4 *3 (-1195)) (-5 *1 (-288 *3)))) (-1769 (*1 *1 *2 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-25)) (-4 *2 (-1195)))) (-1769 (*1 *1 *1 *2) (-12 (-5 *1 (-288 *2)) (-4 *2 (-25)) (-4 *2 (-1195)))) (-1750 (*1 *1 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-21)) (-4 *2 (-1195)))) (-3830 (*1 *1 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-21)) (-4 *2 (-1195)))) (-1775 (*1 *1 *2 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-21)) (-4 *2 (-1195)))) (-1775 (*1 *1 *1 *2) (-12 (-5 *1 (-288 *2)) (-4 *2 (-21)) (-4 *2 (-1195)))) (-3686 (*1 *1 *1) (|partial| -12 (-5 *1 (-288 *2)) (-4 *2 (-716)) (-4 *2 (-1195)))) (-4050 (*1 *1 *1) (|partial| -12 (-5 *1 (-288 *2)) (-4 *2 (-716)) (-4 *2 (-1195)))) (-1635 (*1 *2 *1) (-12 (-5 *2 (-634 (-288 *3))) (-5 *1 (-288 *3)) (-4 *3 (-558)) (-4 *3 (-1195)))) (-4069 (*1 *1 *1 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-296)) (-4 *2 (-1195)))) (* (*1 *1 *1 *2) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1102)) (-4 *2 (-1195)))) (* (*1 *1 *2 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1102)) (-4 *2 (-1195)))) (-1781 (*1 *1 *1 *1) (-2199 (-12 (-5 *1 (-288 *2)) (-4 *2 (-365)) (-4 *2 (-1195))) (-12 (-5 *1 (-288 *2)) (-4 *2 (-478)) (-4 *2 (-1195))))) (-2083 (*1 *1 *1) (-2199 (-12 (-5 *1 (-288 *2)) (-4 *2 (-365)) (-4 *2 (-1195))) (-12 (-5 *1 (-288 *2)) (-4 *2 (-478)) (-4 *2 (-1195)))))) 
+(-13 (-1195) (-10 -8 (-15 -1719 ($ |#1| |#1|)) (-15 -2785 ($ |#1| |#1|)) (-15 -2032 ($ $)) (-15 -2433 (|#1| $)) (-15 -3250 (|#1| $)) (-15 -2797 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-523 (-1161) |#1|)) (-6 (-523 (-1161) |#1|)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-6 (-1090)) (-6 (-608 (-121))) (IF (|has| |#1| (-303 |#1|)) (PROGN (-15 -1339 ($ $ $)) (-15 -1339 ($ $ (-634 $)))) |noBranch|)) |noBranch|) (IF (|has| |#1| (-25)) (PROGN (-6 (-25)) (-15 -1769 ($ |#1| $)) (-15 -1769 ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-21)) (PROGN (-6 (-21)) (-15 -1750 ($ $)) (-15 -3830 ($ $)) (-15 -1775 ($ |#1| $)) (-15 -1775 ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-1102)) (PROGN (-6 (-1102)) (-15 * ($ |#1| $)) (-15 * ($ $ |#1|))) |noBranch|) (IF (|has| |#1| (-716)) (PROGN (-6 (-716)) (-15 -3686 ((-3 $ "failed") $)) (-15 -4050 ((-3 $ "failed") $))) |noBranch|) (IF (|has| |#1| (-478)) (PROGN (-6 (-478)) (-15 -3686 ((-3 $ "failed") $)) (-15 -4050 ((-3 $ "failed") $))) |noBranch|) (IF (|has| |#1| (-1047)) (PROGN (-6 (-1047)) (-6 (-120 |#1| |#1|))) |noBranch|) (IF (|has| |#1| (-172)) (-6 (-707 |#1|)) |noBranch|) (IF (|has| |#1| (-558)) (-15 -1635 ((-634 $) $)) |noBranch|) (IF (|has| |#1| (-895 (-1161))) (-6 (-895 (-1161))) |noBranch|) (IF (|has| |#1| (-365)) (PROGN (-6 (-1251 |#1|)) (-15 -1781 ($ $ $)) (-15 -2083 ($ $))) |noBranch|) (IF (|has| |#1| (-296)) (-15 -4069 ($ $ $)) |noBranch|))) 
+((-2449 (((-121) $ $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-2988 (($) NIL) (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-2481 (((-1249) $ |#1| |#1|) NIL (|has| $ (-6 -4522)))) (-1667 (((-121) $ (-763)) NIL)) (-2438 ((|#2| $ |#1| |#2|) NIL)) (-3963 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-2678 (((-3 |#2| "failed") |#1| $) NIL)) (-4490 (($) NIL T CONST)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-1568 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (|has| $ (-6 -4521))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-3 |#2| "failed") |#1| $) NIL)) (-4330 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-3094 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (|has| $ (-6 -4521))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-1292 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#2| $ |#1|) NIL)) (-3317 (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-634 |#2|) $) NIL (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) NIL)) (-2539 ((|#1| $) NIL (|has| |#1| (-842)))) (-4406 (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-634 |#2|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-3631 ((|#1| $) NIL (|has| |#1| (-842)))) (-2253 (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4522))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-4253 (((-634 |#1|) $) NIL)) (-2807 (((-121) |#1| $) NIL)) (-2580 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-1708 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-3948 (((-634 |#1|) $) NIL)) (-2916 (((-121) |#1| $) NIL)) (-4025 (((-1108) $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-3877 ((|#2| $) NIL (|has| |#1| (-842)))) (-2712 (((-3 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) "failed") (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL)) (-2490 (($ $ |#2|) NIL (|has| $ (-6 -4522)))) (-3403 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-3951 (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-1480 (((-634 |#2|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL)) (-3132 (($) NIL) (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-4170 (((-763) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-763) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090)))) (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-609 (-541))))) (-4289 (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-2747 (((-850) $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-4074 (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-3437 (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-289 |#1| |#2|) (-13 (-1172 |#1| |#2|) (-10 -7 (-6 -4521))) (-1090) (-1090)) (T -289)) 
+NIL 
+(-13 (-1172 |#1| |#2|) (-10 -7 (-6 -4521))) 
+((-2185 (((-305) (-1143) (-634 (-1143))) 16) (((-305) (-1143) (-1143)) 15) (((-305) (-634 (-1143))) 14) (((-305) (-1143)) 12))) 
+(((-290) (-10 -7 (-15 -2185 ((-305) (-1143))) (-15 -2185 ((-305) (-634 (-1143)))) (-15 -2185 ((-305) (-1143) (-1143))) (-15 -2185 ((-305) (-1143) (-634 (-1143)))))) (T -290)) 
+((-2185 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-1143))) (-5 *3 (-1143)) (-5 *2 (-305)) (-5 *1 (-290)))) (-2185 (*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-305)) (-5 *1 (-290)))) (-2185 (*1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-305)) (-5 *1 (-290)))) (-2185 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-305)) (-5 *1 (-290))))) 
+(-10 -7 (-15 -2185 ((-305) (-1143))) (-15 -2185 ((-305) (-634 (-1143)))) (-15 -2185 ((-305) (-1143) (-1143))) (-15 -2185 ((-305) (-1143) (-634 (-1143))))) 
+((-2797 ((|#2| (-1 |#2| |#1|) (-1143) (-607 |#1|)) 17))) 
+(((-291 |#1| |#2|) (-10 -7 (-15 -2797 (|#2| (-1 |#2| |#1|) (-1143) (-607 |#1|)))) (-296) (-1195)) (T -291)) 
+((-2797 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *6)) (-5 *4 (-1143)) (-5 *5 (-607 *6)) (-4 *6 (-296)) (-4 *2 (-1195)) (-5 *1 (-291 *6 *2))))) 
+(-10 -7 (-15 -2797 (|#2| (-1 |#2| |#1|) (-1143) (-607 |#1|)))) 
+((-2797 ((|#2| (-1 |#2| |#1|) (-607 |#1|)) 17))) 
+(((-292 |#1| |#2|) (-10 -7 (-15 -2797 (|#2| (-1 |#2| |#1|) (-607 |#1|)))) (-296) (-296)) (T -292)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 *5)) (-5 *4 (-607 *5)) (-4 *5 (-296)) (-4 *2 (-296)) (-5 *1 (-292 *5 *2))))) 
+(-10 -7 (-15 -2797 (|#2| (-1 |#2| |#1|) (-607 |#1|)))) 
+((-2217 (((-121) (-215)) 10))) 
+(((-293 |#1| |#2|) (-10 -7 (-15 -2217 ((-121) (-215)))) (-215) (-215)) (T -293)) 
+((-2217 (*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-121)) (-5 *1 (-293 *4 *5)) (-14 *4 *3) (-14 *5 *3)))) 
+(-10 -7 (-15 -2217 ((-121) (-215)))) 
+((-2251 (((-1141 (-215)) (-310 (-215)) (-634 (-1161)) (-1084 (-835 (-215)))) 88)) (-4233 (((-1141 (-215)) (-1244 (-310 (-215))) (-634 (-1161)) (-1084 (-835 (-215)))) 103) (((-1141 (-215)) (-310 (-215)) (-634 (-1161)) (-1084 (-835 (-215)))) 58)) (-2636 (((-634 (-1143)) (-1141 (-215))) NIL)) (-3533 (((-634 (-215)) (-310 (-215)) (-1161) (-1084 (-835 (-215)))) 55)) (-2895 (((-634 (-215)) (-953 (-409 (-568))) (-1161) (-1084 (-835 (-215)))) 47)) (-3706 (((-634 (-1143)) (-634 (-215))) NIL)) (-2793 (((-215) (-1084 (-835 (-215)))) 23)) (-3141 (((-215) (-1084 (-835 (-215)))) 24)) (-4274 (((-121) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 51)) (-3486 (((-1143) (-215)) NIL))) 
+(((-294) (-10 -7 (-15 -2793 ((-215) (-1084 (-835 (-215))))) (-15 -3141 ((-215) (-1084 (-835 (-215))))) (-15 -4274 ((-121) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -3533 ((-634 (-215)) (-310 (-215)) (-1161) (-1084 (-835 (-215))))) (-15 -2251 ((-1141 (-215)) (-310 (-215)) (-634 (-1161)) (-1084 (-835 (-215))))) (-15 -4233 ((-1141 (-215)) (-310 (-215)) (-634 (-1161)) (-1084 (-835 (-215))))) (-15 -4233 ((-1141 (-215)) (-1244 (-310 (-215))) (-634 (-1161)) (-1084 (-835 (-215))))) (-15 -2895 ((-634 (-215)) (-953 (-409 (-568))) (-1161) (-1084 (-835 (-215))))) (-15 -3486 ((-1143) (-215))) (-15 -3706 ((-634 (-1143)) (-634 (-215)))) (-15 -2636 ((-634 (-1143)) (-1141 (-215)))))) (T -294)) 
+((-2636 (*1 *2 *3) (-12 (-5 *3 (-1141 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-294)))) (-3706 (*1 *2 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-294)))) (-3486 (*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-1143)) (-5 *1 (-294)))) (-2895 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-953 (-409 (-568)))) (-5 *4 (-1161)) (-5 *5 (-1084 (-835 (-215)))) (-5 *2 (-634 (-215))) (-5 *1 (-294)))) (-4233 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1244 (-310 (-215)))) (-5 *4 (-634 (-1161))) (-5 *5 (-1084 (-835 (-215)))) (-5 *2 (-1141 (-215))) (-5 *1 (-294)))) (-4233 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-215))) (-5 *4 (-634 (-1161))) (-5 *5 (-1084 (-835 (-215)))) (-5 *2 (-1141 (-215))) (-5 *1 (-294)))) (-2251 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-215))) (-5 *4 (-634 (-1161))) (-5 *5 (-1084 (-835 (-215)))) (-5 *2 (-1141 (-215))) (-5 *1 (-294)))) (-3533 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-215))) (-5 *4 (-1161)) (-5 *5 (-1084 (-835 (-215)))) (-5 *2 (-634 (-215))) (-5 *1 (-294)))) (-4274 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-121)) (-5 *1 (-294)))) (-3141 (*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-294)))) (-2793 (*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-294))))) 
+(-10 -7 (-15 -2793 ((-215) (-1084 (-835 (-215))))) (-15 -3141 ((-215) (-1084 (-835 (-215))))) (-15 -4274 ((-121) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -3533 ((-634 (-215)) (-310 (-215)) (-1161) (-1084 (-835 (-215))))) (-15 -2251 ((-1141 (-215)) (-310 (-215)) (-634 (-1161)) (-1084 (-835 (-215))))) (-15 -4233 ((-1141 (-215)) (-310 (-215)) (-634 (-1161)) (-1084 (-835 (-215))))) (-15 -4233 ((-1141 (-215)) (-1244 (-310 (-215))) (-634 (-1161)) (-1084 (-835 (-215))))) (-15 -2895 ((-634 (-215)) (-953 (-409 (-568))) (-1161) (-1084 (-835 (-215))))) (-15 -3486 ((-1143) (-215))) (-15 -3706 ((-634 (-1143)) (-634 (-215)))) (-15 -2636 ((-634 (-1143)) (-1141 (-215))))) 
+((-3145 (((-634 (-607 $)) $) 28)) (-4069 (($ $ (-288 $)) 80) (($ $ (-634 (-288 $))) 120) (($ $ (-634 (-607 $)) (-634 $)) NIL)) (-3668 (((-3 (-607 $) "failed") $) 110)) (-2857 (((-607 $) $) 109)) (-3855 (($ $) 19) (($ (-634 $)) 54)) (-2160 (((-634 (-123)) $) 37)) (-3842 (((-123) (-123)) 90)) (-2268 (((-121) $) 128)) (-2797 (($ (-1 $ $) (-607 $)) 88)) (-2337 (((-3 (-607 $) "failed") $) 92)) (-3446 (($ (-123) $) 60) (($ (-123) (-634 $)) 98)) (-3910 (((-121) $ (-123)) 114) (((-121) $ (-1161)) 113)) (-2963 (((-763) $) 45)) (-1609 (((-121) $ $) 58) (((-121) $ (-1161)) 49)) (-2080 (((-121) $) 126)) (-1339 (($ $ (-607 $) $) NIL) (($ $ (-634 (-607 $)) (-634 $)) NIL) (($ $ (-634 (-288 $))) 118) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ $))) 83) (($ $ (-634 (-1161)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-1161) (-1 $ (-634 $))) 68) (($ $ (-1161) (-1 $ $)) 74) (($ $ (-634 (-123)) (-634 (-1 $ $))) 82) (($ $ (-634 (-123)) (-634 (-1 $ (-634 $)))) 84) (($ $ (-123) (-1 $ (-634 $))) 70) (($ $ (-123) (-1 $ $)) 76)) (-2781 (($ (-123) $) 61) (($ (-123) $ $) 62) (($ (-123) $ $ $) 63) (($ (-123) $ $ $ $) 64) (($ (-123) (-634 $)) 106)) (-3924 (($ $) 51) (($ $ $) 116)) (-3159 (($ $) 17) (($ (-634 $)) 53)) (-2779 (((-121) (-123)) 22))) 
+(((-295 |#1|) (-10 -8 (-15 -2268 ((-121) |#1|)) (-15 -2080 ((-121) |#1|)) (-15 -1339 (|#1| |#1| (-123) (-1 |#1| |#1|))) (-15 -1339 (|#1| |#1| (-123) (-1 |#1| (-634 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-123)) (-634 (-1 |#1| (-634 |#1|))))) (-15 -1339 (|#1| |#1| (-634 (-123)) (-634 (-1 |#1| |#1|)))) (-15 -1339 (|#1| |#1| (-1161) (-1 |#1| |#1|))) (-15 -1339 (|#1| |#1| (-1161) (-1 |#1| (-634 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-1 |#1| (-634 |#1|))))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-1 |#1| |#1|)))) (-15 -1609 ((-121) |#1| (-1161))) (-15 -1609 ((-121) |#1| |#1|)) (-15 -2797 (|#1| (-1 |#1| |#1|) (-607 |#1|))) (-15 -3446 (|#1| (-123) (-634 |#1|))) (-15 -3446 (|#1| (-123) |#1|)) (-15 -3910 ((-121) |#1| (-1161))) (-15 -3910 ((-121) |#1| (-123))) (-15 -2779 ((-121) (-123))) (-15 -3842 ((-123) (-123))) (-15 -2160 ((-634 (-123)) |#1|)) (-15 -3145 ((-634 (-607 |#1|)) |#1|)) (-15 -2337 ((-3 (-607 |#1|) "failed") |#1|)) (-15 -2963 ((-763) |#1|)) (-15 -3924 (|#1| |#1| |#1|)) (-15 -3924 (|#1| |#1|)) (-15 -3855 (|#1| (-634 |#1|))) (-15 -3855 (|#1| |#1|)) (-15 -3159 (|#1| (-634 |#1|))) (-15 -3159 (|#1| |#1|)) (-15 -4069 (|#1| |#1| (-634 (-607 |#1|)) (-634 |#1|))) (-15 -4069 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -4069 (|#1| |#1| (-288 |#1|))) (-15 -2781 (|#1| (-123) (-634 |#1|))) (-15 -2781 (|#1| (-123) |#1| |#1| |#1| |#1|)) (-15 -2781 (|#1| (-123) |#1| |#1| |#1|)) (-15 -2781 (|#1| (-123) |#1| |#1|)) (-15 -2781 (|#1| (-123) |#1|)) (-15 -1339 (|#1| |#1| (-634 |#1|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#1| |#1|)) (-15 -1339 (|#1| |#1| (-288 |#1|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-607 |#1|)) (-634 |#1|))) (-15 -1339 (|#1| |#1| (-607 |#1|) |#1|)) (-15 -2857 ((-607 |#1|) |#1|)) (-15 -3668 ((-3 (-607 |#1|) "failed") |#1|))) (-296)) (T -295)) 
+((-3842 (*1 *2 *2) (-12 (-5 *2 (-123)) (-5 *1 (-295 *3)) (-4 *3 (-296)))) (-2779 (*1 *2 *3) (-12 (-5 *3 (-123)) (-5 *2 (-121)) (-5 *1 (-295 *4)) (-4 *4 (-296))))) 
+(-10 -8 (-15 -2268 ((-121) |#1|)) (-15 -2080 ((-121) |#1|)) (-15 -1339 (|#1| |#1| (-123) (-1 |#1| |#1|))) (-15 -1339 (|#1| |#1| (-123) (-1 |#1| (-634 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-123)) (-634 (-1 |#1| (-634 |#1|))))) (-15 -1339 (|#1| |#1| (-634 (-123)) (-634 (-1 |#1| |#1|)))) (-15 -1339 (|#1| |#1| (-1161) (-1 |#1| |#1|))) (-15 -1339 (|#1| |#1| (-1161) (-1 |#1| (-634 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-1 |#1| (-634 |#1|))))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-1 |#1| |#1|)))) (-15 -1609 ((-121) |#1| (-1161))) (-15 -1609 ((-121) |#1| |#1|)) (-15 -2797 (|#1| (-1 |#1| |#1|) (-607 |#1|))) (-15 -3446 (|#1| (-123) (-634 |#1|))) (-15 -3446 (|#1| (-123) |#1|)) (-15 -3910 ((-121) |#1| (-1161))) (-15 -3910 ((-121) |#1| (-123))) (-15 -2779 ((-121) (-123))) (-15 -3842 ((-123) (-123))) (-15 -2160 ((-634 (-123)) |#1|)) (-15 -3145 ((-634 (-607 |#1|)) |#1|)) (-15 -2337 ((-3 (-607 |#1|) "failed") |#1|)) (-15 -2963 ((-763) |#1|)) (-15 -3924 (|#1| |#1| |#1|)) (-15 -3924 (|#1| |#1|)) (-15 -3855 (|#1| (-634 |#1|))) (-15 -3855 (|#1| |#1|)) (-15 -3159 (|#1| (-634 |#1|))) (-15 -3159 (|#1| |#1|)) (-15 -4069 (|#1| |#1| (-634 (-607 |#1|)) (-634 |#1|))) (-15 -4069 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -4069 (|#1| |#1| (-288 |#1|))) (-15 -2781 (|#1| (-123) (-634 |#1|))) (-15 -2781 (|#1| (-123) |#1| |#1| |#1| |#1|)) (-15 -2781 (|#1| (-123) |#1| |#1| |#1|)) (-15 -2781 (|#1| (-123) |#1| |#1|)) (-15 -2781 (|#1| (-123) |#1|)) (-15 -1339 (|#1| |#1| (-634 |#1|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#1| |#1|)) (-15 -1339 (|#1| |#1| (-288 |#1|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-607 |#1|)) (-634 |#1|))) (-15 -1339 (|#1| |#1| (-607 |#1|) |#1|)) (-15 -2857 ((-607 |#1|) |#1|)) (-15 -3668 ((-3 (-607 |#1|) "failed") |#1|))) 
+((-2449 (((-121) $ $) 7)) (-3145 (((-634 (-607 $)) $) 43)) (-4069 (($ $ (-288 $)) 55) (($ $ (-634 (-288 $))) 54) (($ $ (-634 (-607 $)) (-634 $)) 53)) (-3668 (((-3 (-607 $) "failed") $) 68)) (-2857 (((-607 $) $) 67)) (-3855 (($ $) 50) (($ (-634 $)) 49)) (-2160 (((-634 (-123)) $) 42)) (-3842 (((-123) (-123)) 41)) (-2268 (((-121) $) 21 (|has| $ (-1037 (-568))))) (-3170 (((-1157 $) (-607 $)) 24 (|has| $ (-1047)))) (-1732 (($ $ $) 12)) (-2047 (($ $ $) 13)) (-2797 (($ (-1 $ $) (-607 $)) 35)) (-2337 (((-3 (-607 $) "failed") $) 45)) (-1893 (((-1143) $) 9)) (-3832 (((-634 (-607 $)) $) 44)) (-3446 (($ (-123) $) 37) (($ (-123) (-634 $)) 36)) (-3910 (((-121) $ (-123)) 39) (((-121) $ (-1161)) 38)) (-2963 (((-763) $) 46)) (-4025 (((-1108) $) 10)) (-1609 (((-121) $ $) 34) (((-121) $ (-1161)) 33)) (-2080 (((-121) $) 22 (|has| $ (-1037 (-568))))) (-1339 (($ $ (-607 $) $) 66) (($ $ (-634 (-607 $)) (-634 $)) 65) (($ $ (-634 (-288 $))) 64) (($ $ (-288 $)) 63) (($ $ $ $) 62) (($ $ (-634 $) (-634 $)) 61) (($ $ (-634 (-1161)) (-634 (-1 $ $))) 32) (($ $ (-634 (-1161)) (-634 (-1 $ (-634 $)))) 31) (($ $ (-1161) (-1 $ (-634 $))) 30) (($ $ (-1161) (-1 $ $)) 29) (($ $ (-634 (-123)) (-634 (-1 $ $))) 28) (($ $ (-634 (-123)) (-634 (-1 $ (-634 $)))) 27) (($ $ (-123) (-1 $ (-634 $))) 26) (($ $ (-123) (-1 $ $)) 25)) (-2781 (($ (-123) $) 60) (($ (-123) $ $) 59) (($ (-123) $ $ $) 58) (($ (-123) $ $ $ $) 57) (($ (-123) (-634 $)) 56)) (-3924 (($ $) 48) (($ $ $) 47)) (-1492 (($ $) 23 (|has| $ (-1047)))) (-2747 (((-850) $) 11) (($ (-607 $)) 69)) (-3159 (($ $) 52) (($ (-634 $)) 51)) (-2779 (((-121) (-123)) 40)) (-1753 (((-121) $ $) 15)) (-1740 (((-121) $ $) 16)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 14)) (-1734 (((-121) $ $) 17))) 
 (((-296) (-1275)) (T -296)) 
-((-2779 (*1 *1 *2 *1) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) (-2779 (*1 *1 *2 *1 *1) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) (-2779 (*1 *1 *2 *1 *1 *1) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) (-2779 (*1 *1 *2 *1 *1 *1 *1) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) (-2779 (*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-634 *1)) (-4 *1 (-296)))) (-2366 (*1 *1 *1 *2) (-12 (-5 *2 (-288 *1)) (-4 *1 (-296)))) (-2366 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-288 *1))) (-4 *1 (-296)))) (-2366 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-607 *1))) (-5 *3 (-634 *1)) (-4 *1 (-296)))) (-2092 (*1 *1 *1) (-4 *1 (-296))) (-2092 (*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-296)))) (-4499 (*1 *1 *1) (-4 *1 (-296))) (-4499 (*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-296)))) (-3502 (*1 *1 *1) (-4 *1 (-296))) (-3502 (*1 *1 *1 *1) (-4 *1 (-296))) (-2961 (*1 *2 *1) (-12 (-4 *1 (-296)) (-5 *2 (-763)))) (-3693 (*1 *2 *1) (|partial| -12 (-5 *2 (-607 *1)) (-4 *1 (-296)))) (-3804 (*1 *2 *1) (-12 (-5 *2 (-634 (-607 *1))) (-4 *1 (-296)))) (-3001 (*1 *2 *1) (-12 (-5 *2 (-634 (-607 *1))) (-4 *1 (-296)))) (-3296 (*1 *2 *1) (-12 (-4 *1 (-296)) (-5 *2 (-634 (-123))))) (-3488 (*1 *2 *2) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) (-2887 (*1 *2 *3) (-12 (-4 *1 (-296)) (-5 *3 (-123)) (-5 *2 (-121)))) (-2841 (*1 *2 *1 *3) (-12 (-4 *1 (-296)) (-5 *3 (-123)) (-5 *2 (-121)))) (-2841 (*1 *2 *1 *3) (-12 (-4 *1 (-296)) (-5 *3 (-1161)) (-5 *2 (-121)))) (-3443 (*1 *1 *2 *1) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) (-3443 (*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-634 *1)) (-4 *1 (-296)))) (-2795 (*1 *1 *2 *3) (-12 (-5 *2 (-1 *1 *1)) (-5 *3 (-607 *1)) (-4 *1 (-296)))) (-4059 (*1 *2 *1 *1) (-12 (-4 *1 (-296)) (-5 *2 (-121)))) (-4059 (*1 *2 *1 *3) (-12 (-4 *1 (-296)) (-5 *3 (-1161)) (-5 *2 (-121)))) (-1339 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-634 (-1 *1 *1))) (-4 *1 (-296)))) (-1339 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-634 (-1 *1 (-634 *1)))) (-4 *1 (-296)))) (-1339 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1 *1 (-634 *1))) (-4 *1 (-296)))) (-1339 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1 *1 *1)) (-4 *1 (-296)))) (-1339 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-123))) (-5 *3 (-634 (-1 *1 *1))) (-4 *1 (-296)))) (-1339 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-123))) (-5 *3 (-634 (-1 *1 (-634 *1)))) (-4 *1 (-296)))) (-1339 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *1 (-634 *1))) (-4 *1 (-296)))) (-1339 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *1 *1)) (-4 *1 (-296)))) (-3007 (*1 *2 *3) (-12 (-5 *3 (-607 *1)) (-4 *1 (-1047)) (-4 *1 (-296)) (-5 *2 (-1157 *1)))) (-1626 (*1 *1 *1) (-12 (-4 *1 (-1047)) (-4 *1 (-296)))) (-3277 (*1 *2 *1) (-12 (-4 *1 (-1037 (-568))) (-4 *1 (-296)) (-5 *2 (-121)))) (-1825 (*1 *2 *1) (-12 (-4 *1 (-1037 (-568))) (-4 *1 (-296)) (-5 *2 (-121))))) 
-(-13 (-842) (-1037 (-607 $)) (-523 (-607 $) $) (-303 $) (-10 -8 (-15 -2779 ($ (-123) $)) (-15 -2779 ($ (-123) $ $)) (-15 -2779 ($ (-123) $ $ $)) (-15 -2779 ($ (-123) $ $ $ $)) (-15 -2779 ($ (-123) (-634 $))) (-15 -2366 ($ $ (-288 $))) (-15 -2366 ($ $ (-634 (-288 $)))) (-15 -2366 ($ $ (-634 (-607 $)) (-634 $))) (-15 -2092 ($ $)) (-15 -2092 ($ (-634 $))) (-15 -4499 ($ $)) (-15 -4499 ($ (-634 $))) (-15 -3502 ($ $)) (-15 -3502 ($ $ $)) (-15 -2961 ((-763) $)) (-15 -3693 ((-3 (-607 $) "failed") $)) (-15 -3804 ((-634 (-607 $)) $)) (-15 -3001 ((-634 (-607 $)) $)) (-15 -3296 ((-634 (-123)) $)) (-15 -3488 ((-123) (-123))) (-15 -2887 ((-121) (-123))) (-15 -2841 ((-121) $ (-123))) (-15 -2841 ((-121) $ (-1161))) (-15 -3443 ($ (-123) $)) (-15 -3443 ($ (-123) (-634 $))) (-15 -2795 ($ (-1 $ $) (-607 $))) (-15 -4059 ((-121) $ $)) (-15 -4059 ((-121) $ (-1161))) (-15 -1339 ($ $ (-634 (-1161)) (-634 (-1 $ $)))) (-15 -1339 ($ $ (-634 (-1161)) (-634 (-1 $ (-634 $))))) (-15 -1339 ($ $ (-1161) (-1 $ (-634 $)))) (-15 -1339 ($ $ (-1161) (-1 $ $))) (-15 -1339 ($ $ (-634 (-123)) (-634 (-1 $ $)))) (-15 -1339 ($ $ (-634 (-123)) (-634 (-1 $ (-634 $))))) (-15 -1339 ($ $ (-123) (-1 $ (-634 $)))) (-15 -1339 ($ $ (-123) (-1 $ $))) (IF (|has| $ (-1047)) (PROGN (-15 -3007 ((-1157 $) (-607 $))) (-15 -1626 ($ $))) |noBranch|) (IF (|has| $ (-1037 (-568))) (PROGN (-15 -3277 ((-121) $)) (-15 -1825 ((-121) $))) |noBranch|))) 
+((-2781 (*1 *1 *2 *1) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) (-2781 (*1 *1 *2 *1 *1) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) (-2781 (*1 *1 *2 *1 *1 *1) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) (-2781 (*1 *1 *2 *1 *1 *1 *1) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) (-2781 (*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-634 *1)) (-4 *1 (-296)))) (-4069 (*1 *1 *1 *2) (-12 (-5 *2 (-288 *1)) (-4 *1 (-296)))) (-4069 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-288 *1))) (-4 *1 (-296)))) (-4069 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-607 *1))) (-5 *3 (-634 *1)) (-4 *1 (-296)))) (-3159 (*1 *1 *1) (-4 *1 (-296))) (-3159 (*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-296)))) (-3855 (*1 *1 *1) (-4 *1 (-296))) (-3855 (*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-296)))) (-3924 (*1 *1 *1) (-4 *1 (-296))) (-3924 (*1 *1 *1 *1) (-4 *1 (-296))) (-2963 (*1 *2 *1) (-12 (-4 *1 (-296)) (-5 *2 (-763)))) (-2337 (*1 *2 *1) (|partial| -12 (-5 *2 (-607 *1)) (-4 *1 (-296)))) (-3832 (*1 *2 *1) (-12 (-5 *2 (-634 (-607 *1))) (-4 *1 (-296)))) (-3145 (*1 *2 *1) (-12 (-5 *2 (-634 (-607 *1))) (-4 *1 (-296)))) (-2160 (*1 *2 *1) (-12 (-4 *1 (-296)) (-5 *2 (-634 (-123))))) (-3842 (*1 *2 *2) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) (-2779 (*1 *2 *3) (-12 (-4 *1 (-296)) (-5 *3 (-123)) (-5 *2 (-121)))) (-3910 (*1 *2 *1 *3) (-12 (-4 *1 (-296)) (-5 *3 (-123)) (-5 *2 (-121)))) (-3910 (*1 *2 *1 *3) (-12 (-4 *1 (-296)) (-5 *3 (-1161)) (-5 *2 (-121)))) (-3446 (*1 *1 *2 *1) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) (-3446 (*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-634 *1)) (-4 *1 (-296)))) (-2797 (*1 *1 *2 *3) (-12 (-5 *2 (-1 *1 *1)) (-5 *3 (-607 *1)) (-4 *1 (-296)))) (-1609 (*1 *2 *1 *1) (-12 (-4 *1 (-296)) (-5 *2 (-121)))) (-1609 (*1 *2 *1 *3) (-12 (-4 *1 (-296)) (-5 *3 (-1161)) (-5 *2 (-121)))) (-1339 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-634 (-1 *1 *1))) (-4 *1 (-296)))) (-1339 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-634 (-1 *1 (-634 *1)))) (-4 *1 (-296)))) (-1339 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1 *1 (-634 *1))) (-4 *1 (-296)))) (-1339 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1 *1 *1)) (-4 *1 (-296)))) (-1339 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-123))) (-5 *3 (-634 (-1 *1 *1))) (-4 *1 (-296)))) (-1339 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-123))) (-5 *3 (-634 (-1 *1 (-634 *1)))) (-4 *1 (-296)))) (-1339 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *1 (-634 *1))) (-4 *1 (-296)))) (-1339 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *1 *1)) (-4 *1 (-296)))) (-3170 (*1 *2 *3) (-12 (-5 *3 (-607 *1)) (-4 *1 (-1047)) (-4 *1 (-296)) (-5 *2 (-1157 *1)))) (-1492 (*1 *1 *1) (-12 (-4 *1 (-1047)) (-4 *1 (-296)))) (-2080 (*1 *2 *1) (-12 (-4 *1 (-1037 (-568))) (-4 *1 (-296)) (-5 *2 (-121)))) (-2268 (*1 *2 *1) (-12 (-4 *1 (-1037 (-568))) (-4 *1 (-296)) (-5 *2 (-121))))) 
+(-13 (-842) (-1037 (-607 $)) (-523 (-607 $) $) (-303 $) (-10 -8 (-15 -2781 ($ (-123) $)) (-15 -2781 ($ (-123) $ $)) (-15 -2781 ($ (-123) $ $ $)) (-15 -2781 ($ (-123) $ $ $ $)) (-15 -2781 ($ (-123) (-634 $))) (-15 -4069 ($ $ (-288 $))) (-15 -4069 ($ $ (-634 (-288 $)))) (-15 -4069 ($ $ (-634 (-607 $)) (-634 $))) (-15 -3159 ($ $)) (-15 -3159 ($ (-634 $))) (-15 -3855 ($ $)) (-15 -3855 ($ (-634 $))) (-15 -3924 ($ $)) (-15 -3924 ($ $ $)) (-15 -2963 ((-763) $)) (-15 -2337 ((-3 (-607 $) "failed") $)) (-15 -3832 ((-634 (-607 $)) $)) (-15 -3145 ((-634 (-607 $)) $)) (-15 -2160 ((-634 (-123)) $)) (-15 -3842 ((-123) (-123))) (-15 -2779 ((-121) (-123))) (-15 -3910 ((-121) $ (-123))) (-15 -3910 ((-121) $ (-1161))) (-15 -3446 ($ (-123) $)) (-15 -3446 ($ (-123) (-634 $))) (-15 -2797 ($ (-1 $ $) (-607 $))) (-15 -1609 ((-121) $ $)) (-15 -1609 ((-121) $ (-1161))) (-15 -1339 ($ $ (-634 (-1161)) (-634 (-1 $ $)))) (-15 -1339 ($ $ (-634 (-1161)) (-634 (-1 $ (-634 $))))) (-15 -1339 ($ $ (-1161) (-1 $ (-634 $)))) (-15 -1339 ($ $ (-1161) (-1 $ $))) (-15 -1339 ($ $ (-634 (-123)) (-634 (-1 $ $)))) (-15 -1339 ($ $ (-634 (-123)) (-634 (-1 $ (-634 $))))) (-15 -1339 ($ $ (-123) (-1 $ (-634 $)))) (-15 -1339 ($ $ (-123) (-1 $ $))) (IF (|has| $ (-1047)) (PROGN (-15 -3170 ((-1157 $) (-607 $))) (-15 -1492 ($ $))) |noBranch|) (IF (|has| $ (-1037 (-568))) (PROGN (-15 -2080 ((-121) $)) (-15 -2268 ((-121) $))) |noBranch|))) 
 (((-105) . T) ((-608 (-850)) . T) ((-303 $) . T) ((-523 (-607 $) $) . T) ((-523 $ $) . T) ((-842) . T) ((-1037 (-607 $)) . T) ((-1090) . T)) 
-((-4266 (((-634 |#1|) (-634 |#1|)) 10))) 
-(((-297 |#1|) (-10 -7 (-15 -4266 ((-634 |#1|) (-634 |#1|)))) (-840)) (T -297)) 
-((-4266 (*1 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-840)) (-5 *1 (-297 *3))))) 
-(-10 -7 (-15 -4266 ((-634 |#1|) (-634 |#1|)))) 
-((-2795 (((-679 |#2|) (-1 |#2| |#1|) (-679 |#1|)) 15))) 
-(((-298 |#1| |#2|) (-10 -7 (-15 -2795 ((-679 |#2|) (-1 |#2| |#1|) (-679 |#1|)))) (-1047) (-1047)) (T -298)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-679 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-5 *2 (-679 *6)) (-5 *1 (-298 *5 *6))))) 
-(-10 -7 (-15 -2795 ((-679 |#2|) (-1 |#2| |#1|) (-679 |#1|)))) 
-((-2811 (((-1244 (-310 (-381))) (-1244 (-310 (-215)))) 105)) (-3026 (((-1084 (-835 (-215))) (-1084 (-835 (-381)))) 39)) (-1903 (((-634 (-1143)) (-1141 (-215))) 87)) (-3246 (((-310 (-381)) (-953 (-215))) 49)) (-2985 (((-215) (-953 (-215))) 45)) (-4037 (((-1143) (-381)) 167)) (-3079 (((-835 (-215)) (-835 (-381))) 33)) (-4281 (((-2 (|:| |additions| (-568)) (|:| |multiplications| (-568)) (|:| |exponentiations| (-568)) (|:| |functionCalls| (-568))) (-1244 (-310 (-215)))) 142)) (-1407 (((-1035) (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035)))) 180) (((-1035) (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))))) 178)) (-2928 (((-679 (-215)) (-634 (-215)) (-763)) 13)) (-2656 (((-1244 (-688)) (-634 (-215))) 94)) (-2309 (((-634 (-1143)) (-634 (-215))) 74)) (-2258 (((-3 (-310 (-215)) "failed") (-310 (-215))) 120)) (-1816 (((-121) (-215) (-1084 (-835 (-215)))) 109)) (-3132 (((-1035) (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381)))) 198)) (-2066 (((-215) (-1084 (-835 (-215)))) 107)) (-3632 (((-215) (-1084 (-835 (-215)))) 108)) (-3453 (((-215) (-409 (-568))) 26)) (-4198 (((-1143) (-381)) 72)) (-3370 (((-215) (-381)) 17)) (-4014 (((-381) (-1244 (-310 (-215)))) 153)) (-4050 (((-310 (-215)) (-310 (-381))) 23)) (-2489 (((-409 (-568)) (-310 (-215))) 52)) (-1809 (((-310 (-409 (-568))) (-310 (-215))) 68)) (-3061 (((-310 (-381)) (-310 (-215))) 98)) (-4348 (((-215) (-310 (-215))) 53)) (-4290 (((-634 (-215)) (-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) 63)) (-3014 (((-1084 (-835 (-215))) (-1084 (-835 (-215)))) 60)) (-2281 (((-1143) (-215)) 71)) (-3035 (((-688) (-215)) 90)) (-3149 (((-409 (-568)) (-215)) 54)) (-1650 (((-310 (-381)) (-215)) 48)) (-4278 (((-634 (-1084 (-835 (-215)))) (-634 (-1084 (-835 (-381))))) 42)) (-2768 (((-1035) (-634 (-1035))) 163) (((-1035) (-1035) (-1035)) 160)) (-2345 (((-1035) (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) 194))) 
-(((-299) (-10 -7 (-15 -3370 ((-215) (-381))) (-15 -4050 ((-310 (-215)) (-310 (-381)))) (-15 -3079 ((-835 (-215)) (-835 (-381)))) (-15 -3026 ((-1084 (-835 (-215))) (-1084 (-835 (-381))))) (-15 -4278 ((-634 (-1084 (-835 (-215)))) (-634 (-1084 (-835 (-381)))))) (-15 -3149 ((-409 (-568)) (-215))) (-15 -2489 ((-409 (-568)) (-310 (-215)))) (-15 -4348 ((-215) (-310 (-215)))) (-15 -2258 ((-3 (-310 (-215)) "failed") (-310 (-215)))) (-15 -4014 ((-381) (-1244 (-310 (-215))))) (-15 -4281 ((-2 (|:| |additions| (-568)) (|:| |multiplications| (-568)) (|:| |exponentiations| (-568)) (|:| |functionCalls| (-568))) (-1244 (-310 (-215))))) (-15 -1809 ((-310 (-409 (-568))) (-310 (-215)))) (-15 -3014 ((-1084 (-835 (-215))) (-1084 (-835 (-215))))) (-15 -4290 ((-634 (-215)) (-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))))) (-15 -3035 ((-688) (-215))) (-15 -2656 ((-1244 (-688)) (-634 (-215)))) (-15 -3061 ((-310 (-381)) (-310 (-215)))) (-15 -2811 ((-1244 (-310 (-381))) (-1244 (-310 (-215))))) (-15 -1816 ((-121) (-215) (-1084 (-835 (-215))))) (-15 -2281 ((-1143) (-215))) (-15 -4198 ((-1143) (-381))) (-15 -2309 ((-634 (-1143)) (-634 (-215)))) (-15 -1903 ((-634 (-1143)) (-1141 (-215)))) (-15 -2066 ((-215) (-1084 (-835 (-215))))) (-15 -3632 ((-215) (-1084 (-835 (-215))))) (-15 -2768 ((-1035) (-1035) (-1035))) (-15 -2768 ((-1035) (-634 (-1035)))) (-15 -4037 ((-1143) (-381))) (-15 -1407 ((-1035) (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143)))))) (-15 -1407 ((-1035) (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035))))) (-15 -2345 ((-1035) (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))) (-15 -3132 ((-1035) (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381))))) (-15 -3246 ((-310 (-381)) (-953 (-215)))) (-15 -2985 ((-215) (-953 (-215)))) (-15 -1650 ((-310 (-381)) (-215))) (-15 -3453 ((-215) (-409 (-568)))) (-15 -2928 ((-679 (-215)) (-634 (-215)) (-763))))) (T -299)) 
-((-2928 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-215))) (-5 *4 (-763)) (-5 *2 (-679 (-215))) (-5 *1 (-299)))) (-3453 (*1 *2 *3) (-12 (-5 *3 (-409 (-568))) (-5 *2 (-215)) (-5 *1 (-299)))) (-1650 (*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-310 (-381))) (-5 *1 (-299)))) (-2985 (*1 *2 *3) (-12 (-5 *3 (-953 (-215))) (-5 *2 (-215)) (-5 *1 (-299)))) (-3246 (*1 *2 *3) (-12 (-5 *3 (-953 (-215))) (-5 *2 (-310 (-381))) (-5 *1 (-299)))) (-3132 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381)))) (-5 *2 (-1035)) (-5 *1 (-299)))) (-2345 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *2 (-1035)) (-5 *1 (-299)))) (-1407 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035)))) (-5 *2 (-1035)) (-5 *1 (-299)))) (-1407 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *2 (-1035)) (-5 *1 (-299)))) (-4037 (*1 *2 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1143)) (-5 *1 (-299)))) (-2768 (*1 *2 *3) (-12 (-5 *3 (-634 (-1035))) (-5 *2 (-1035)) (-5 *1 (-299)))) (-2768 (*1 *2 *2 *2) (-12 (-5 *2 (-1035)) (-5 *1 (-299)))) (-3632 (*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-299)))) (-2066 (*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-299)))) (-1903 (*1 *2 *3) (-12 (-5 *3 (-1141 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-299)))) (-2309 (*1 *2 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-299)))) (-4198 (*1 *2 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1143)) (-5 *1 (-299)))) (-2281 (*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-1143)) (-5 *1 (-299)))) (-1816 (*1 *2 *3 *4) (-12 (-5 *4 (-1084 (-835 (-215)))) (-5 *3 (-215)) (-5 *2 (-121)) (-5 *1 (-299)))) (-2811 (*1 *2 *3) (-12 (-5 *3 (-1244 (-310 (-215)))) (-5 *2 (-1244 (-310 (-381)))) (-5 *1 (-299)))) (-3061 (*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-310 (-381))) (-5 *1 (-299)))) (-2656 (*1 *2 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-1244 (-688))) (-5 *1 (-299)))) (-3035 (*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-688)) (-5 *1 (-299)))) (-4290 (*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) (-5 *2 (-634 (-215))) (-5 *1 (-299)))) (-3014 (*1 *2 *2) (-12 (-5 *2 (-1084 (-835 (-215)))) (-5 *1 (-299)))) (-1809 (*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-310 (-409 (-568)))) (-5 *1 (-299)))) (-4281 (*1 *2 *3) (-12 (-5 *3 (-1244 (-310 (-215)))) (-5 *2 (-2 (|:| |additions| (-568)) (|:| |multiplications| (-568)) (|:| |exponentiations| (-568)) (|:| |functionCalls| (-568)))) (-5 *1 (-299)))) (-4014 (*1 *2 *3) (-12 (-5 *3 (-1244 (-310 (-215)))) (-5 *2 (-381)) (-5 *1 (-299)))) (-2258 (*1 *2 *2) (|partial| -12 (-5 *2 (-310 (-215))) (-5 *1 (-299)))) (-4348 (*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-215)) (-5 *1 (-299)))) (-2489 (*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-409 (-568))) (-5 *1 (-299)))) (-3149 (*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-409 (-568))) (-5 *1 (-299)))) (-4278 (*1 *2 *3) (-12 (-5 *3 (-634 (-1084 (-835 (-381))))) (-5 *2 (-634 (-1084 (-835 (-215))))) (-5 *1 (-299)))) (-3026 (*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-381)))) (-5 *2 (-1084 (-835 (-215)))) (-5 *1 (-299)))) (-3079 (*1 *2 *3) (-12 (-5 *3 (-835 (-381))) (-5 *2 (-835 (-215))) (-5 *1 (-299)))) (-4050 (*1 *2 *3) (-12 (-5 *3 (-310 (-381))) (-5 *2 (-310 (-215))) (-5 *1 (-299)))) (-3370 (*1 *2 *3) (-12 (-5 *3 (-381)) (-5 *2 (-215)) (-5 *1 (-299))))) 
-(-10 -7 (-15 -3370 ((-215) (-381))) (-15 -4050 ((-310 (-215)) (-310 (-381)))) (-15 -3079 ((-835 (-215)) (-835 (-381)))) (-15 -3026 ((-1084 (-835 (-215))) (-1084 (-835 (-381))))) (-15 -4278 ((-634 (-1084 (-835 (-215)))) (-634 (-1084 (-835 (-381)))))) (-15 -3149 ((-409 (-568)) (-215))) (-15 -2489 ((-409 (-568)) (-310 (-215)))) (-15 -4348 ((-215) (-310 (-215)))) (-15 -2258 ((-3 (-310 (-215)) "failed") (-310 (-215)))) (-15 -4014 ((-381) (-1244 (-310 (-215))))) (-15 -4281 ((-2 (|:| |additions| (-568)) (|:| |multiplications| (-568)) (|:| |exponentiations| (-568)) (|:| |functionCalls| (-568))) (-1244 (-310 (-215))))) (-15 -1809 ((-310 (-409 (-568))) (-310 (-215)))) (-15 -3014 ((-1084 (-835 (-215))) (-1084 (-835 (-215))))) (-15 -4290 ((-634 (-215)) (-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))))) (-15 -3035 ((-688) (-215))) (-15 -2656 ((-1244 (-688)) (-634 (-215)))) (-15 -3061 ((-310 (-381)) (-310 (-215)))) (-15 -2811 ((-1244 (-310 (-381))) (-1244 (-310 (-215))))) (-15 -1816 ((-121) (-215) (-1084 (-835 (-215))))) (-15 -2281 ((-1143) (-215))) (-15 -4198 ((-1143) (-381))) (-15 -2309 ((-634 (-1143)) (-634 (-215)))) (-15 -1903 ((-634 (-1143)) (-1141 (-215)))) (-15 -2066 ((-215) (-1084 (-835 (-215))))) (-15 -3632 ((-215) (-1084 (-835 (-215))))) (-15 -2768 ((-1035) (-1035) (-1035))) (-15 -2768 ((-1035) (-634 (-1035)))) (-15 -4037 ((-1143) (-381))) (-15 -1407 ((-1035) (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143)))))) (-15 -1407 ((-1035) (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035))))) (-15 -2345 ((-1035) (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))) (-15 -3132 ((-1035) (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381))))) (-15 -3246 ((-310 (-381)) (-953 (-215)))) (-15 -2985 ((-215) (-953 (-215)))) (-15 -1650 ((-310 (-381)) (-215))) (-15 -3453 ((-215) (-409 (-568)))) (-15 -2928 ((-679 (-215)) (-634 (-215)) (-763)))) 
-((-1497 (((-121) $ $) 11)) (-2401 (($ $ $) 15)) (-2412 (($ $ $) 14)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 43)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 52)) (-2721 (($ $ $) 21) (($ (-634 $)) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 31) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 36)) (-2595 (((-3 $ "failed") $ $) 18)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 45))) 
-(((-300 |#1|) (-10 -8 (-15 -3562 ((-3 (-634 |#1|) "failed") (-634 |#1|) |#1|)) (-15 -4497 ((-3 (-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|)) "failed") |#1| |#1| |#1|)) (-15 -4497 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2704 |#1|)) |#1| |#1|)) (-15 -2401 (|#1| |#1| |#1|)) (-15 -2412 (|#1| |#1| |#1|)) (-15 -1497 ((-121) |#1| |#1|)) (-15 -2344 ((-3 (-634 |#1|) "failed") (-634 |#1|) |#1|)) (-15 -1983 ((-2 (|:| -2348 (-634 |#1|)) (|:| -2704 |#1|)) (-634 |#1|))) (-15 -2721 (|#1| (-634 |#1|))) (-15 -2721 (|#1| |#1| |#1|)) (-15 -2595 ((-3 |#1| "failed") |#1| |#1|))) (-301)) (T -300)) 
-NIL 
-(-10 -8 (-15 -3562 ((-3 (-634 |#1|) "failed") (-634 |#1|) |#1|)) (-15 -4497 ((-3 (-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|)) "failed") |#1| |#1| |#1|)) (-15 -4497 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2704 |#1|)) |#1| |#1|)) (-15 -2401 (|#1| |#1| |#1|)) (-15 -2412 (|#1| |#1| |#1|)) (-15 -1497 ((-121) |#1| |#1|)) (-15 -2344 ((-3 (-634 |#1|) "failed") (-634 |#1|) |#1|)) (-15 -1983 ((-2 (|:| -2348 (-634 |#1|)) (|:| -2704 |#1|)) (-634 |#1|))) (-15 -2721 (|#1| (-634 |#1|))) (-15 -2721 (|#1| |#1| |#1|)) (-15 -2595 ((-3 |#1| "failed") |#1| |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-3134 (((-3 $ "failed") $ $) 18)) (-1497 (((-121) $ $) 57)) (-2671 (($) 16 T CONST)) (-2401 (($ $ $) 53)) (-2925 (((-3 $ "failed") $) 33)) (-2412 (($ $ $) 54)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 49)) (-2735 (((-121) $) 30)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2595 (((-3 $ "failed") $ $) 41)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-2709 (((-763) $) 56)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 55)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42)) (-4078 (((-763)) 28)) (-1826 (((-121) $ $) 38)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
+((-2914 (((-634 |#1|) (-634 |#1|)) 10))) 
+(((-297 |#1|) (-10 -7 (-15 -2914 ((-634 |#1|) (-634 |#1|)))) (-840)) (T -297)) 
+((-2914 (*1 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-840)) (-5 *1 (-297 *3))))) 
+(-10 -7 (-15 -2914 ((-634 |#1|) (-634 |#1|)))) 
+((-2797 (((-679 |#2|) (-1 |#2| |#1|) (-679 |#1|)) 15))) 
+(((-298 |#1| |#2|) (-10 -7 (-15 -2797 ((-679 |#2|) (-1 |#2| |#1|) (-679 |#1|)))) (-1047) (-1047)) (T -298)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-679 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-5 *2 (-679 *6)) (-5 *1 (-298 *5 *6))))) 
+(-10 -7 (-15 -2797 ((-679 |#2|) (-1 |#2| |#1|) (-679 |#1|)))) 
+((-3721 (((-1244 (-310 (-381))) (-1244 (-310 (-215)))) 105)) (-3289 (((-1084 (-835 (-215))) (-1084 (-835 (-381)))) 39)) (-2636 (((-634 (-1143)) (-1141 (-215))) 87)) (-1982 (((-310 (-381)) (-953 (-215))) 49)) (-3091 (((-215) (-953 (-215))) 45)) (-1514 (((-1143) (-381)) 167)) (-2407 (((-835 (-215)) (-835 (-381))) 33)) (-2961 (((-2 (|:| |additions| (-568)) (|:| |multiplications| (-568)) (|:| |exponentiations| (-568)) (|:| |functionCalls| (-568))) (-1244 (-310 (-215)))) 142)) (-2122 (((-1035) (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035)))) 180) (((-1035) (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))))) 178)) (-2908 (((-679 (-215)) (-634 (-215)) (-763)) 13)) (-4412 (((-1244 (-688)) (-634 (-215))) 94)) (-3706 (((-634 (-1143)) (-634 (-215))) 74)) (-2260 (((-3 (-310 (-215)) "failed") (-310 (-215))) 120)) (-2217 (((-121) (-215) (-1084 (-835 (-215)))) 109)) (-2672 (((-1035) (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381)))) 198)) (-2793 (((-215) (-1084 (-835 (-215)))) 107)) (-3141 (((-215) (-1084 (-835 (-215)))) 108)) (-3585 (((-215) (-409 (-568))) 26)) (-4072 (((-1143) (-381)) 72)) (-1383 (((-215) (-381)) 17)) (-1402 (((-381) (-1244 (-310 (-215)))) 153)) (-1579 (((-310 (-215)) (-310 (-381))) 23)) (-2714 (((-409 (-568)) (-310 (-215))) 52)) (-2177 (((-310 (-409 (-568))) (-310 (-215))) 68)) (-2311 (((-310 (-381)) (-310 (-215))) 98)) (-3242 (((-215) (-310 (-215))) 53)) (-2985 (((-634 (-215)) (-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) 63)) (-3216 (((-1084 (-835 (-215))) (-1084 (-835 (-215)))) 60)) (-3486 (((-1143) (-215)) 71)) (-2202 (((-688) (-215)) 90)) (-2743 (((-409 (-568)) (-215)) 54)) (-3310 (((-310 (-381)) (-215)) 48)) (-4280 (((-634 (-1084 (-835 (-215)))) (-634 (-1084 (-835 (-381))))) 42)) (-2770 (((-1035) (-634 (-1035))) 163) (((-1035) (-1035) (-1035)) 160)) (-3929 (((-1035) (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) 194))) 
+(((-299) (-10 -7 (-15 -1383 ((-215) (-381))) (-15 -1579 ((-310 (-215)) (-310 (-381)))) (-15 -2407 ((-835 (-215)) (-835 (-381)))) (-15 -3289 ((-1084 (-835 (-215))) (-1084 (-835 (-381))))) (-15 -4280 ((-634 (-1084 (-835 (-215)))) (-634 (-1084 (-835 (-381)))))) (-15 -2743 ((-409 (-568)) (-215))) (-15 -2714 ((-409 (-568)) (-310 (-215)))) (-15 -3242 ((-215) (-310 (-215)))) (-15 -2260 ((-3 (-310 (-215)) "failed") (-310 (-215)))) (-15 -1402 ((-381) (-1244 (-310 (-215))))) (-15 -2961 ((-2 (|:| |additions| (-568)) (|:| |multiplications| (-568)) (|:| |exponentiations| (-568)) (|:| |functionCalls| (-568))) (-1244 (-310 (-215))))) (-15 -2177 ((-310 (-409 (-568))) (-310 (-215)))) (-15 -3216 ((-1084 (-835 (-215))) (-1084 (-835 (-215))))) (-15 -2985 ((-634 (-215)) (-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))))) (-15 -2202 ((-688) (-215))) (-15 -4412 ((-1244 (-688)) (-634 (-215)))) (-15 -2311 ((-310 (-381)) (-310 (-215)))) (-15 -3721 ((-1244 (-310 (-381))) (-1244 (-310 (-215))))) (-15 -2217 ((-121) (-215) (-1084 (-835 (-215))))) (-15 -3486 ((-1143) (-215))) (-15 -4072 ((-1143) (-381))) (-15 -3706 ((-634 (-1143)) (-634 (-215)))) (-15 -2636 ((-634 (-1143)) (-1141 (-215)))) (-15 -2793 ((-215) (-1084 (-835 (-215))))) (-15 -3141 ((-215) (-1084 (-835 (-215))))) (-15 -2770 ((-1035) (-1035) (-1035))) (-15 -2770 ((-1035) (-634 (-1035)))) (-15 -1514 ((-1143) (-381))) (-15 -2122 ((-1035) (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143)))))) (-15 -2122 ((-1035) (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035))))) (-15 -3929 ((-1035) (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))) (-15 -2672 ((-1035) (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381))))) (-15 -1982 ((-310 (-381)) (-953 (-215)))) (-15 -3091 ((-215) (-953 (-215)))) (-15 -3310 ((-310 (-381)) (-215))) (-15 -3585 ((-215) (-409 (-568)))) (-15 -2908 ((-679 (-215)) (-634 (-215)) (-763))))) (T -299)) 
+((-2908 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-215))) (-5 *4 (-763)) (-5 *2 (-679 (-215))) (-5 *1 (-299)))) (-3585 (*1 *2 *3) (-12 (-5 *3 (-409 (-568))) (-5 *2 (-215)) (-5 *1 (-299)))) (-3310 (*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-310 (-381))) (-5 *1 (-299)))) (-3091 (*1 *2 *3) (-12 (-5 *3 (-953 (-215))) (-5 *2 (-215)) (-5 *1 (-299)))) (-1982 (*1 *2 *3) (-12 (-5 *3 (-953 (-215))) (-5 *2 (-310 (-381))) (-5 *1 (-299)))) (-2672 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381)))) (-5 *2 (-1035)) (-5 *1 (-299)))) (-3929 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *2 (-1035)) (-5 *1 (-299)))) (-2122 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035)))) (-5 *2 (-1035)) (-5 *1 (-299)))) (-2122 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *2 (-1035)) (-5 *1 (-299)))) (-1514 (*1 *2 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1143)) (-5 *1 (-299)))) (-2770 (*1 *2 *3) (-12 (-5 *3 (-634 (-1035))) (-5 *2 (-1035)) (-5 *1 (-299)))) (-2770 (*1 *2 *2 *2) (-12 (-5 *2 (-1035)) (-5 *1 (-299)))) (-3141 (*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-299)))) (-2793 (*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-299)))) (-2636 (*1 *2 *3) (-12 (-5 *3 (-1141 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-299)))) (-3706 (*1 *2 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-299)))) (-4072 (*1 *2 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1143)) (-5 *1 (-299)))) (-3486 (*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-1143)) (-5 *1 (-299)))) (-2217 (*1 *2 *3 *4) (-12 (-5 *4 (-1084 (-835 (-215)))) (-5 *3 (-215)) (-5 *2 (-121)) (-5 *1 (-299)))) (-3721 (*1 *2 *3) (-12 (-5 *3 (-1244 (-310 (-215)))) (-5 *2 (-1244 (-310 (-381)))) (-5 *1 (-299)))) (-2311 (*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-310 (-381))) (-5 *1 (-299)))) (-4412 (*1 *2 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-1244 (-688))) (-5 *1 (-299)))) (-2202 (*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-688)) (-5 *1 (-299)))) (-2985 (*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) (-5 *2 (-634 (-215))) (-5 *1 (-299)))) (-3216 (*1 *2 *2) (-12 (-5 *2 (-1084 (-835 (-215)))) (-5 *1 (-299)))) (-2177 (*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-310 (-409 (-568)))) (-5 *1 (-299)))) (-2961 (*1 *2 *3) (-12 (-5 *3 (-1244 (-310 (-215)))) (-5 *2 (-2 (|:| |additions| (-568)) (|:| |multiplications| (-568)) (|:| |exponentiations| (-568)) (|:| |functionCalls| (-568)))) (-5 *1 (-299)))) (-1402 (*1 *2 *3) (-12 (-5 *3 (-1244 (-310 (-215)))) (-5 *2 (-381)) (-5 *1 (-299)))) (-2260 (*1 *2 *2) (|partial| -12 (-5 *2 (-310 (-215))) (-5 *1 (-299)))) (-3242 (*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-215)) (-5 *1 (-299)))) (-2714 (*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-409 (-568))) (-5 *1 (-299)))) (-2743 (*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-409 (-568))) (-5 *1 (-299)))) (-4280 (*1 *2 *3) (-12 (-5 *3 (-634 (-1084 (-835 (-381))))) (-5 *2 (-634 (-1084 (-835 (-215))))) (-5 *1 (-299)))) (-3289 (*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-381)))) (-5 *2 (-1084 (-835 (-215)))) (-5 *1 (-299)))) (-2407 (*1 *2 *3) (-12 (-5 *3 (-835 (-381))) (-5 *2 (-835 (-215))) (-5 *1 (-299)))) (-1579 (*1 *2 *3) (-12 (-5 *3 (-310 (-381))) (-5 *2 (-310 (-215))) (-5 *1 (-299)))) (-1383 (*1 *2 *3) (-12 (-5 *3 (-381)) (-5 *2 (-215)) (-5 *1 (-299))))) 
+(-10 -7 (-15 -1383 ((-215) (-381))) (-15 -1579 ((-310 (-215)) (-310 (-381)))) (-15 -2407 ((-835 (-215)) (-835 (-381)))) (-15 -3289 ((-1084 (-835 (-215))) (-1084 (-835 (-381))))) (-15 -4280 ((-634 (-1084 (-835 (-215)))) (-634 (-1084 (-835 (-381)))))) (-15 -2743 ((-409 (-568)) (-215))) (-15 -2714 ((-409 (-568)) (-310 (-215)))) (-15 -3242 ((-215) (-310 (-215)))) (-15 -2260 ((-3 (-310 (-215)) "failed") (-310 (-215)))) (-15 -1402 ((-381) (-1244 (-310 (-215))))) (-15 -2961 ((-2 (|:| |additions| (-568)) (|:| |multiplications| (-568)) (|:| |exponentiations| (-568)) (|:| |functionCalls| (-568))) (-1244 (-310 (-215))))) (-15 -2177 ((-310 (-409 (-568))) (-310 (-215)))) (-15 -3216 ((-1084 (-835 (-215))) (-1084 (-835 (-215))))) (-15 -2985 ((-634 (-215)) (-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))))) (-15 -2202 ((-688) (-215))) (-15 -4412 ((-1244 (-688)) (-634 (-215)))) (-15 -2311 ((-310 (-381)) (-310 (-215)))) (-15 -3721 ((-1244 (-310 (-381))) (-1244 (-310 (-215))))) (-15 -2217 ((-121) (-215) (-1084 (-835 (-215))))) (-15 -3486 ((-1143) (-215))) (-15 -4072 ((-1143) (-381))) (-15 -3706 ((-634 (-1143)) (-634 (-215)))) (-15 -2636 ((-634 (-1143)) (-1141 (-215)))) (-15 -2793 ((-215) (-1084 (-835 (-215))))) (-15 -3141 ((-215) (-1084 (-835 (-215))))) (-15 -2770 ((-1035) (-1035) (-1035))) (-15 -2770 ((-1035) (-634 (-1035)))) (-15 -1514 ((-1143) (-381))) (-15 -2122 ((-1035) (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143)))))) (-15 -2122 ((-1035) (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035))))) (-15 -3929 ((-1035) (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))) (-15 -2672 ((-1035) (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381))))) (-15 -1982 ((-310 (-381)) (-953 (-215)))) (-15 -3091 ((-215) (-953 (-215)))) (-15 -3310 ((-310 (-381)) (-215))) (-15 -3585 ((-215) (-409 (-568)))) (-15 -2908 ((-679 (-215)) (-634 (-215)) (-763)))) 
+((-2589 (((-121) $ $) 11)) (-2403 (($ $ $) 15)) (-2414 (($ $ $) 14)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 43)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 52)) (-2723 (($ $ $) 21) (($ (-634 $)) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 31) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 36)) (-2597 (((-3 $ "failed") $ $) 18)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 45))) 
+(((-300 |#1|) (-10 -8 (-15 -2855 ((-3 (-634 |#1|) "failed") (-634 |#1|) |#1|)) (-15 -3833 ((-3 (-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|)) "failed") |#1| |#1| |#1|)) (-15 -3833 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2707 |#1|)) |#1| |#1|)) (-15 -2403 (|#1| |#1| |#1|)) (-15 -2414 (|#1| |#1| |#1|)) (-15 -2589 ((-121) |#1| |#1|)) (-15 -3922 ((-3 (-634 |#1|) "failed") (-634 |#1|) |#1|)) (-15 -4422 ((-2 (|:| -2350 (-634 |#1|)) (|:| -2707 |#1|)) (-634 |#1|))) (-15 -2723 (|#1| (-634 |#1|))) (-15 -2723 (|#1| |#1| |#1|)) (-15 -2597 ((-3 |#1| "failed") |#1| |#1|))) (-301)) (T -300)) 
+NIL 
+(-10 -8 (-15 -2855 ((-3 (-634 |#1|) "failed") (-634 |#1|) |#1|)) (-15 -3833 ((-3 (-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|)) "failed") |#1| |#1| |#1|)) (-15 -3833 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2707 |#1|)) |#1| |#1|)) (-15 -2403 (|#1| |#1| |#1|)) (-15 -2414 (|#1| |#1| |#1|)) (-15 -2589 ((-121) |#1| |#1|)) (-15 -3922 ((-3 (-634 |#1|) "failed") (-634 |#1|) |#1|)) (-15 -4422 ((-2 (|:| -2350 (-634 |#1|)) (|:| -2707 |#1|)) (-634 |#1|))) (-15 -2723 (|#1| (-634 |#1|))) (-15 -2723 (|#1| |#1| |#1|)) (-15 -2597 ((-3 |#1| "failed") |#1| |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-2689 (((-3 $ "failed") $ $) 18)) (-2589 (((-121) $ $) 57)) (-4490 (($) 16 T CONST)) (-2403 (($ $ $) 53)) (-2902 (((-3 $ "failed") $) 33)) (-2414 (($ $ $) 54)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 49)) (-1598 (((-121) $) 30)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2597 (((-3 $ "failed") $ $) 41)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-1466 (((-763) $) 56)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 55)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42)) (-3425 (((-763)) 28)) (-2273 (((-121) $ $) 38)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
 (((-301) (-1275)) (T -301)) 
-((-1497 (*1 *2 *1 *1) (-12 (-4 *1 (-301)) (-5 *2 (-121)))) (-2709 (*1 *2 *1) (-12 (-4 *1 (-301)) (-5 *2 (-763)))) (-3210 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-301)))) (-2412 (*1 *1 *1 *1) (-4 *1 (-301))) (-2401 (*1 *1 *1 *1) (-4 *1 (-301))) (-4497 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2704 *1))) (-4 *1 (-301)))) (-4497 (*1 *2 *1 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1))) (-4 *1 (-301)))) (-3562 (*1 *2 *2 *1) (|partial| -12 (-5 *2 (-634 *1)) (-4 *1 (-301))))) 
-(-13 (-916) (-10 -8 (-15 -1497 ((-121) $ $)) (-15 -2709 ((-763) $)) (-15 -3210 ((-2 (|:| -3961 $) (|:| -1500 $)) $ $)) (-15 -2412 ($ $ $)) (-15 -2401 ($ $ $)) (-15 -4497 ((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $)) (-15 -4497 ((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $)) (-15 -3562 ((-3 (-634 $) "failed") (-634 $) $)))) 
+((-2589 (*1 *2 *1 *1) (-12 (-4 *1 (-301)) (-5 *2 (-121)))) (-1466 (*1 *2 *1) (-12 (-4 *1 (-301)) (-5 *2 (-763)))) (-1854 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-301)))) (-2414 (*1 *1 *1 *1) (-4 *1 (-301))) (-2403 (*1 *1 *1 *1) (-4 *1 (-301))) (-3833 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2707 *1))) (-4 *1 (-301)))) (-3833 (*1 *2 *1 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1))) (-4 *1 (-301)))) (-2855 (*1 *2 *2 *1) (|partial| -12 (-5 *2 (-634 *1)) (-4 *1 (-301))))) 
+(-13 (-916) (-10 -8 (-15 -2589 ((-121) $ $)) (-15 -1466 ((-763) $)) (-15 -1854 ((-2 (|:| -4409 $) (|:| -2607 $)) $ $)) (-15 -2414 ($ $ $)) (-15 -2403 ($ $ $)) (-15 -3833 ((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $)) (-15 -3833 ((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $)) (-15 -2855 ((-3 (-634 $) "failed") (-634 $) $)))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-105) . T) ((-120 $ $) . T) ((-137) . T) ((-608 (-850)) . T) ((-172) . T) ((-285) . T) ((-453) . T) ((-558) . T) ((-637 $) . T) ((-707 $) . T) ((-716) . T) ((-916) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
 ((-1339 (($ $ (-634 |#2|) (-634 |#2|)) 14) (($ $ |#2| |#2|) NIL) (($ $ (-288 |#2|)) 11) (($ $ (-634 (-288 |#2|))) NIL))) 
 (((-302 |#1| |#2|) (-10 -8 (-15 -1339 (|#1| |#1| (-634 (-288 |#2|)))) (-15 -1339 (|#1| |#1| (-288 |#2|))) (-15 -1339 (|#1| |#1| |#2| |#2|)) (-15 -1339 (|#1| |#1| (-634 |#2|) (-634 |#2|)))) (-303 |#2|) (-1090)) (T -302)) 
@@ -1192,909 +1192,909 @@ NIL
 (((-304 |#1|) (-10 -7 (-15 -1339 (|#1| (-1 |#1| (-568)) (-1163 (-409 (-568)))))) (-43 (-409 (-568)))) (T -304)) 
 ((-1339 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 (-568))) (-5 *4 (-1163 (-409 (-568)))) (-5 *1 (-304 *2)) (-4 *2 (-43 (-409 (-568))))))) 
 (-10 -7 (-15 -1339 (|#1| (-1 |#1| (-568)) (-1163 (-409 (-568)))))) 
-((-2447 (((-121) $ $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 7)) (-1717 (((-121) $ $) 9))) 
+((-2449 (((-121) $ $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 7)) (-1719 (((-121) $ $) 9))) 
 (((-305) (-1090)) (T -305)) 
 NIL 
 (-1090) 
-((-2741 (((-1249) (-1149 3 (-215)) (-1143)) 38))) 
-(((-306) (-10 -7 (-15 -2741 ((-1249) (-1149 3 (-215)) (-1143))))) (T -306)) 
-((-2741 (*1 *2 *3 *4) (-12 (-5 *3 (-1149 3 (-215))) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-306))))) 
-(-10 -7 (-15 -2741 ((-1249) (-1149 3 (-215)) (-1143)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 62)) (-1492 (((-1229 |#1| |#2| |#3| |#4|) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-301)))) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-904)))) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-904)))) (-1497 (((-121) $ $) NIL)) (-3662 (((-568) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-815)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-1229 |#1| |#2| |#3| |#4|) "failed") $) NIL) (((-3 (-1161) "failed") $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-1037 (-1161)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-1037 (-568)))) (((-3 (-568) "failed") $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-1037 (-568)))) (((-3 (-1228 |#2| |#3| |#4|) "failed") $) 24)) (-2854 (((-1229 |#1| |#2| |#3| |#4|) $) NIL) (((-1161) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-1037 (-1161)))) (((-409 (-568)) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-1037 (-568)))) (((-568) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-1037 (-568)))) (((-1228 |#2| |#3| |#4|) $) NIL)) (-2401 (($ $ $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-630 (-568)))) (((-2 (|:| -2928 (-679 (-1229 |#1| |#2| |#3| |#4|))) (|:| |vec| (-1244 (-1229 |#1| |#2| |#3| |#4|)))) (-679 $) (-1244 $)) NIL) (((-679 (-1229 |#1| |#2| |#3| |#4|)) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1731 (($) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-550)))) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-2033 (((-121) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-815)))) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-881 (-381))))) (-2735 (((-121) $) NIL)) (-1332 (($ $) NIL)) (-2317 (((-1229 |#1| |#2| |#3| |#4|) $) 21)) (-3038 (((-3 $ "failed") $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-1136)))) (-2245 (((-121) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-815)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2521 (($ $ $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-842)))) (-3268 (($ $ $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-842)))) (-2795 (($ (-1 (-1229 |#1| |#2| |#3| |#4|) (-1229 |#1| |#2| |#3| |#4|)) $) NIL)) (-2620 (((-3 (-835 |#2|) "failed") $) 76)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4434 (($) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-1136)) CONST)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3880 (($ $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-301)))) (-1519 (((-1229 |#1| |#2| |#3| |#4|) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-550)))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-904)))) (-3848 (((-420 $) $) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1339 (($ $ (-634 (-1229 |#1| |#2| |#3| |#4|)) (-634 (-1229 |#1| |#2| |#3| |#4|))) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-303 (-1229 |#1| |#2| |#3| |#4|)))) (($ $ (-1229 |#1| |#2| |#3| |#4|) (-1229 |#1| |#2| |#3| |#4|)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-303 (-1229 |#1| |#2| |#3| |#4|)))) (($ $ (-288 (-1229 |#1| |#2| |#3| |#4|))) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-303 (-1229 |#1| |#2| |#3| |#4|)))) (($ $ (-634 (-288 (-1229 |#1| |#2| |#3| |#4|)))) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-303 (-1229 |#1| |#2| |#3| |#4|)))) (($ $ (-634 (-1161)) (-634 (-1229 |#1| |#2| |#3| |#4|))) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-523 (-1161) (-1229 |#1| |#2| |#3| |#4|)))) (($ $ (-1161) (-1229 |#1| |#2| |#3| |#4|)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-523 (-1161) (-1229 |#1| |#2| |#3| |#4|))))) (-2709 (((-763) $) NIL)) (-2779 (($ $ (-1229 |#1| |#2| |#3| |#4|)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-281 (-1229 |#1| |#2| |#3| |#4|) (-1229 |#1| |#2| |#3| |#4|))))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-4189 (($ $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-225))) (($ $ (-763)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-225))) (($ $ (-1161)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-895 (-1161)))) (($ $ (-1 (-1229 |#1| |#2| |#3| |#4|) (-1229 |#1| |#2| |#3| |#4|)) (-763)) NIL) (($ $ (-1 (-1229 |#1| |#2| |#3| |#4|) (-1229 |#1| |#2| |#3| |#4|))) NIL)) (-3013 (($ $) NIL)) (-2324 (((-1229 |#1| |#2| |#3| |#4|) $) 17)) (-4278 (((-887 (-568)) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-609 (-887 (-381))))) (((-541) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-609 (-541)))) (((-381) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-1021))) (((-215) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-1021)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| (-1229 |#1| |#2| |#3| |#4|) (-904))))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ (-1229 |#1| |#2| |#3| |#4|)) 28) (($ (-1161)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-1037 (-1161)))) (($ (-1228 |#2| |#3| |#4|)) 36)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| (-1229 |#1| |#2| |#3| |#4|) (-904))) (|has| (-1229 |#1| |#2| |#3| |#4|) (-148))))) (-4078 (((-763)) NIL)) (-2285 (((-1229 |#1| |#2| |#3| |#4|) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-550)))) (-1826 (((-121) $ $) NIL)) (-2897 (($ $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-815)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) 41 T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-225))) (($ $ (-763)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-225))) (($ $ (-1161)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-895 (-1161)))) (($ $ (-1 (-1229 |#1| |#2| |#3| |#4|) (-1229 |#1| |#2| |#3| |#4|)) (-763)) NIL) (($ $ (-1 (-1229 |#1| |#2| |#3| |#4|) (-1229 |#1| |#2| |#3| |#4|))) NIL)) (-1751 (((-121) $ $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-842)))) (-1738 (((-121) $ $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-842)))) (-1732 (((-121) $ $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-842)))) (-1779 (($ $ $) 33) (($ (-1229 |#1| |#2| |#3| |#4|) (-1229 |#1| |#2| |#3| |#4|)) 30)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ (-1229 |#1| |#2| |#3| |#4|) $) 29) (($ $ (-1229 |#1| |#2| |#3| |#4|)) NIL))) 
-(((-307 |#1| |#2| |#3| |#4|) (-13 (-993 (-1229 |#1| |#2| |#3| |#4|)) (-1037 (-1228 |#2| |#3| |#4|)) (-10 -8 (-15 -2620 ((-3 (-835 |#2|) "failed") $)) (-15 -2745 ($ (-1228 |#2| |#3| |#4|))))) (-13 (-842) (-1037 (-568)) (-630 (-568)) (-453)) (-13 (-27) (-1181) (-432 |#1|)) (-1161) |#2|) (T -307)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1228 *4 *5 *6)) (-4 *4 (-13 (-27) (-1181) (-432 *3))) (-14 *5 (-1161)) (-14 *6 *4) (-4 *3 (-13 (-842) (-1037 (-568)) (-630 (-568)) (-453))) (-5 *1 (-307 *3 *4 *5 *6)))) (-2620 (*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-842) (-1037 (-568)) (-630 (-568)) (-453))) (-5 *2 (-835 *4)) (-5 *1 (-307 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1181) (-432 *3))) (-14 *5 (-1161)) (-14 *6 *4)))) 
-(-13 (-993 (-1229 |#1| |#2| |#3| |#4|)) (-1037 (-1228 |#2| |#3| |#4|)) (-10 -8 (-15 -2620 ((-3 (-835 |#2|) "failed") $)) (-15 -2745 ($ (-1228 |#2| |#3| |#4|))))) 
-((-2795 (((-310 |#2|) (-1 |#2| |#1|) (-310 |#1|)) 13))) 
-(((-308 |#1| |#2|) (-10 -7 (-15 -2795 ((-310 |#2|) (-1 |#2| |#1|) (-310 |#1|)))) (-842) (-842)) (T -308)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-310 *5)) (-4 *5 (-842)) (-4 *6 (-842)) (-5 *2 (-310 *6)) (-5 *1 (-308 *5 *6))))) 
-(-10 -7 (-15 -2795 ((-310 |#2|) (-1 |#2| |#1|) (-310 |#1|)))) 
-((-2065 (((-57) |#2| (-288 |#2|) (-763)) 33) (((-57) |#2| (-288 |#2|)) 24) (((-57) |#2| (-763)) 28) (((-57) |#2|) 25) (((-57) (-1161)) 21)) (-3728 (((-57) |#2| (-288 |#2|) (-409 (-568))) 51) (((-57) |#2| (-288 |#2|)) 48) (((-57) |#2| (-409 (-568))) 50) (((-57) |#2|) 49) (((-57) (-1161)) 47)) (-2075 (((-57) |#2| (-288 |#2|) (-409 (-568))) 46) (((-57) |#2| (-288 |#2|)) 43) (((-57) |#2| (-409 (-568))) 45) (((-57) |#2|) 44) (((-57) (-1161)) 42)) (-2070 (((-57) |#2| (-288 |#2|) (-568)) 39) (((-57) |#2| (-288 |#2|)) 35) (((-57) |#2| (-568)) 38) (((-57) |#2|) 36) (((-57) (-1161)) 34))) 
-(((-309 |#1| |#2|) (-10 -7 (-15 -2065 ((-57) (-1161))) (-15 -2065 ((-57) |#2|)) (-15 -2065 ((-57) |#2| (-763))) (-15 -2065 ((-57) |#2| (-288 |#2|))) (-15 -2065 ((-57) |#2| (-288 |#2|) (-763))) (-15 -2070 ((-57) (-1161))) (-15 -2070 ((-57) |#2|)) (-15 -2070 ((-57) |#2| (-568))) (-15 -2070 ((-57) |#2| (-288 |#2|))) (-15 -2070 ((-57) |#2| (-288 |#2|) (-568))) (-15 -2075 ((-57) (-1161))) (-15 -2075 ((-57) |#2|)) (-15 -2075 ((-57) |#2| (-409 (-568)))) (-15 -2075 ((-57) |#2| (-288 |#2|))) (-15 -2075 ((-57) |#2| (-288 |#2|) (-409 (-568)))) (-15 -3728 ((-57) (-1161))) (-15 -3728 ((-57) |#2|)) (-15 -3728 ((-57) |#2| (-409 (-568)))) (-15 -3728 ((-57) |#2| (-288 |#2|))) (-15 -3728 ((-57) |#2| (-288 |#2|) (-409 (-568))))) (-13 (-453) (-842) (-1037 (-568)) (-630 (-568))) (-13 (-27) (-1181) (-432 |#1|))) (T -309)) 
-((-3728 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-288 *3)) (-5 *5 (-409 (-568))) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *6 *3)))) (-3728 (*1 *2 *3 *4) (-12 (-5 *4 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)))) (-3728 (*1 *2 *3 *4) (-12 (-5 *4 (-409 (-568))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) (-3728 (*1 *2 *3) (-12 (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4))))) (-3728 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *5)) (-4 *5 (-13 (-27) (-1181) (-432 *4))))) (-2075 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-288 *3)) (-5 *5 (-409 (-568))) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *6 *3)))) (-2075 (*1 *2 *3 *4) (-12 (-5 *4 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)))) (-2075 (*1 *2 *3 *4) (-12 (-5 *4 (-409 (-568))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) (-2075 (*1 *2 *3) (-12 (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4))))) (-2075 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *5)) (-4 *5 (-13 (-27) (-1181) (-432 *4))))) (-2070 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-453) (-842) (-1037 *5) (-630 *5))) (-5 *5 (-568)) (-5 *2 (-57)) (-5 *1 (-309 *6 *3)))) (-2070 (*1 *2 *3 *4) (-12 (-5 *4 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)))) (-2070 (*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-13 (-453) (-842) (-1037 *4) (-630 *4))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) (-2070 (*1 *2 *3) (-12 (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4))))) (-2070 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *5)) (-4 *5 (-13 (-27) (-1181) (-432 *4))))) (-2065 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-288 *3)) (-5 *5 (-763)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *6 *3)))) (-2065 (*1 *2 *3 *4) (-12 (-5 *4 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)))) (-2065 (*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) (-2065 (*1 *2 *3) (-12 (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4))))) (-2065 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *5)) (-4 *5 (-13 (-27) (-1181) (-432 *4)))))) 
-(-10 -7 (-15 -2065 ((-57) (-1161))) (-15 -2065 ((-57) |#2|)) (-15 -2065 ((-57) |#2| (-763))) (-15 -2065 ((-57) |#2| (-288 |#2|))) (-15 -2065 ((-57) |#2| (-288 |#2|) (-763))) (-15 -2070 ((-57) (-1161))) (-15 -2070 ((-57) |#2|)) (-15 -2070 ((-57) |#2| (-568))) (-15 -2070 ((-57) |#2| (-288 |#2|))) (-15 -2070 ((-57) |#2| (-288 |#2|) (-568))) (-15 -2075 ((-57) (-1161))) (-15 -2075 ((-57) |#2|)) (-15 -2075 ((-57) |#2| (-409 (-568)))) (-15 -2075 ((-57) |#2| (-288 |#2|))) (-15 -2075 ((-57) |#2| (-288 |#2|) (-409 (-568)))) (-15 -3728 ((-57) (-1161))) (-15 -3728 ((-57) |#2|)) (-15 -3728 ((-57) |#2| (-409 (-568)))) (-15 -3728 ((-57) |#2| (-288 |#2|))) (-15 -3728 ((-57) |#2| (-288 |#2|) (-409 (-568))))) 
-((-2447 (((-121) $ $) NIL)) (-2394 (((-634 $) $ (-1161)) NIL (|has| |#1| (-558))) (((-634 $) $) NIL (|has| |#1| (-558))) (((-634 $) (-1157 $) (-1161)) NIL (|has| |#1| (-558))) (((-634 $) (-1157 $)) NIL (|has| |#1| (-558))) (((-634 $) (-953 $)) NIL (|has| |#1| (-558)))) (-1681 (($ $ (-1161)) NIL (|has| |#1| (-558))) (($ $) NIL (|has| |#1| (-558))) (($ (-1157 $) (-1161)) NIL (|has| |#1| (-558))) (($ (-1157 $)) NIL (|has| |#1| (-558))) (($ (-953 $)) NIL (|has| |#1| (-558)))) (-2537 (((-121) $) 27 (-2198 (|has| |#1| (-25)) (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047)))))) (-2055 (((-634 (-1161)) $) 344)) (-3839 (((-409 (-1157 $)) $ (-607 $)) NIL (|has| |#1| (-558)))) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-3001 (((-634 (-607 $)) $) NIL)) (-1982 (($ $) 154 (|has| |#1| (-558)))) (-1933 (($ $) 130 (|has| |#1| (-558)))) (-4452 (($ $ (-1082 $)) 215 (|has| |#1| (-558))) (($ $ (-1161)) 211 (|has| |#1| (-558)))) (-3134 (((-3 $ "failed") $ $) NIL (-2198 (|has| |#1| (-21)) (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047)))))) (-2366 (($ $ (-288 $)) NIL) (($ $ (-634 (-288 $))) 360) (($ $ (-634 (-607 $)) (-634 $)) 403)) (-1750 (((-420 (-1157 $)) (-1157 $)) 288 (-12 (|has| |#1| (-453)) (|has| |#1| (-558))))) (-4305 (($ $) NIL (|has| |#1| (-558)))) (-1678 (((-420 $) $) NIL (|has| |#1| (-558)))) (-1902 (($ $) NIL (|has| |#1| (-558)))) (-1497 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1974 (($ $) 150 (|has| |#1| (-558)))) (-2786 (($ $) 126 (|has| |#1| (-558)))) (-2352 (($ $ (-568)) 64 (|has| |#1| (-558)))) (-1990 (($ $) 158 (|has| |#1| (-558)))) (-1941 (($ $) 134 (|has| |#1| (-558)))) (-2671 (($) NIL (-2198 (|has| |#1| (-25)) (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))) (|has| |#1| (-1102))) CONST)) (-3214 (((-634 $) $ (-1161)) NIL (|has| |#1| (-558))) (((-634 $) $) NIL (|has| |#1| (-558))) (((-634 $) (-1157 $) (-1161)) NIL (|has| |#1| (-558))) (((-634 $) (-1157 $)) NIL (|has| |#1| (-558))) (((-634 $) (-953 $)) NIL (|has| |#1| (-558)))) (-2932 (($ $ (-1161)) NIL (|has| |#1| (-558))) (($ $) NIL (|has| |#1| (-558))) (($ (-1157 $) (-1161)) 117 (|has| |#1| (-558))) (($ (-1157 $)) NIL (|has| |#1| (-558))) (($ (-953 $)) NIL (|has| |#1| (-558)))) (-3666 (((-3 (-607 $) "failed") $) 17) (((-3 (-1161) "failed") $) NIL) (((-3 |#1| "failed") $) 412) (((-3 (-53) "failed") $) 317 (-12 (|has| |#1| (-558)) (|has| |#1| (-1037 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-953 |#1|)) "failed") $) NIL (|has| |#1| (-558))) (((-3 (-953 |#1|) "failed") $) NIL (|has| |#1| (-1047))) (((-3 (-409 (-568)) "failed") $) 45 (-2198 (-12 (|has| |#1| (-558)) (|has| |#1| (-1037 (-568)))) (|has| |#1| (-1037 (-409 (-568))))))) (-2854 (((-607 $) $) 11) (((-1161) $) NIL) ((|#1| $) 394) (((-53) $) NIL (-12 (|has| |#1| (-558)) (|has| |#1| (-1037 (-568))))) (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-953 |#1|)) $) NIL (|has| |#1| (-558))) (((-953 |#1|) $) NIL (|has| |#1| (-1047))) (((-409 (-568)) $) 301 (-2198 (-12 (|has| |#1| (-558)) (|has| |#1| (-1037 (-568)))) (|has| |#1| (-1037 (-409 (-568))))))) (-2401 (($ $ $) NIL (|has| |#1| (-558)))) (-3164 (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 110 (|has| |#1| (-1047))) (((-679 |#1|) (-679 $)) 102 (|has| |#1| (-1047))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047)))) (((-679 (-568)) (-679 $)) NIL (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))))) (-3092 (($ $) 84 (|has| |#1| (-558)))) (-2925 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))) (|has| |#1| (-1102))))) (-2412 (($ $ $) NIL (|has| |#1| (-558)))) (-3272 (($ $ (-1082 $)) 219 (|has| |#1| (-558))) (($ $ (-1161)) 217 (|has| |#1| (-558)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| |#1| (-558)))) (-3927 (((-121) $) NIL (|has| |#1| (-558)))) (-1303 (($ $ $) 185 (|has| |#1| (-558)))) (-1897 (($) 120 (|has| |#1| (-558)))) (-2413 (($ $ $) 205 (|has| |#1| (-558)))) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 366 (|has| |#1| (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 372 (|has| |#1| (-881 (-381))))) (-4499 (($ $) NIL) (($ (-634 $)) NIL)) (-3296 (((-634 (-123)) $) NIL)) (-3488 (((-123) (-123)) 260)) (-2735 (((-121) $) 25 (-2198 (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))) (|has| |#1| (-1102))))) (-1825 (((-121) $) NIL (|has| $ (-1037 (-568))))) (-1332 (($ $) 66 (|has| |#1| (-1047)))) (-2317 (((-1113 |#1| (-607 $)) $) 79 (|has| |#1| (-1047)))) (-3185 (((-121) $) 46 (|has| |#1| (-558)))) (-4044 (($ $ (-568)) NIL (|has| |#1| (-558)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-558)))) (-3007 (((-1157 $) (-607 $)) 261 (|has| $ (-1047)))) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-2795 (($ (-1 $ $) (-607 $)) 399)) (-3693 (((-3 (-607 $) "failed") $) NIL)) (-4416 (($ $) 124 (|has| |#1| (-558)))) (-1911 (($ $) 230 (|has| |#1| (-558)))) (-2495 (($ (-634 $)) NIL (|has| |#1| (-558))) (($ $ $) NIL (|has| |#1| (-558)))) (-4487 (((-1143) $) NIL)) (-3804 (((-634 (-607 $)) $) 48)) (-3443 (($ (-123) $) NIL) (($ (-123) (-634 $)) 404)) (-3324 (((-3 (-634 $) "failed") $) NIL (|has| |#1| (-1102)))) (-2672 (((-3 (-2 (|:| |val| $) (|:| -3438 (-568))) "failed") $) NIL (|has| |#1| (-1047)))) (-1794 (((-3 (-634 $) "failed") $) 407 (|has| |#1| (-25)))) (-2392 (((-3 (-2 (|:| -2348 (-568)) (|:| |var| (-607 $))) "failed") $) 411 (|has| |#1| (-25)))) (-3751 (((-3 (-2 (|:| |var| (-607 $)) (|:| -3438 (-568))) "failed") $) NIL (|has| |#1| (-1102))) (((-3 (-2 (|:| |var| (-607 $)) (|:| -3438 (-568))) "failed") $ (-123)) NIL (|has| |#1| (-1047))) (((-3 (-2 (|:| |var| (-607 $)) (|:| -3438 (-568))) "failed") $ (-1161)) NIL (|has| |#1| (-1047)))) (-2841 (((-121) $ (-123)) NIL) (((-121) $ (-1161)) 52)) (-2081 (($ $) NIL (-2198 (|has| |#1| (-478)) (|has| |#1| (-558))))) (-3690 (($ $ (-1161)) 234 (|has| |#1| (-558))) (($ $ (-1082 $)) 236 (|has| |#1| (-558)))) (-2961 (((-763) $) NIL)) (-4022 (((-1108) $) NIL)) (-2086 (((-121) $) 43)) (-2091 ((|#1| $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 281 (|has| |#1| (-558)))) (-2721 (($ (-634 $)) NIL (|has| |#1| (-558))) (($ $ $) NIL (|has| |#1| (-558)))) (-4059 (((-121) $ $) NIL) (((-121) $ (-1161)) NIL)) (-2784 (($ $ (-1161)) 209 (|has| |#1| (-558))) (($ $) 207 (|has| |#1| (-558)))) (-2427 (($ $) 201 (|has| |#1| (-558)))) (-3545 (((-420 (-1157 $)) (-1157 $)) 286 (-12 (|has| |#1| (-453)) (|has| |#1| (-558))))) (-3848 (((-420 $) $) NIL (|has| |#1| (-558)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-558))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-558)))) (-2595 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-558)))) (-1892 (($ $) 122 (|has| |#1| (-558)))) (-3277 (((-121) $) NIL (|has| $ (-1037 (-568))))) (-1339 (($ $ (-607 $) $) NIL) (($ $ (-634 (-607 $)) (-634 $)) 398) (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ $))) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-1161) (-1 $ (-634 $))) NIL) (($ $ (-1161) (-1 $ $)) NIL) (($ $ (-634 (-123)) (-634 (-1 $ $))) 354) (($ $ (-634 (-123)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-123) (-1 $ (-634 $))) NIL) (($ $ (-123) (-1 $ $)) NIL) (($ $ (-1161)) NIL (|has| |#1| (-609 (-541)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-609 (-541)))) (($ $) NIL (|has| |#1| (-609 (-541)))) (($ $ (-123) $ (-1161)) 342 (|has| |#1| (-609 (-541)))) (($ $ (-634 (-123)) (-634 $) (-1161)) 341 (|has| |#1| (-609 (-541)))) (($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ $))) NIL (|has| |#1| (-1047))) (($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ (-634 $)))) NIL (|has| |#1| (-1047))) (($ $ (-1161) (-763) (-1 $ (-634 $))) NIL (|has| |#1| (-1047))) (($ $ (-1161) (-763) (-1 $ $)) NIL (|has| |#1| (-1047)))) (-2709 (((-763) $) NIL (|has| |#1| (-558)))) (-1916 (($ $) 222 (|has| |#1| (-558)))) (-2779 (($ (-123) $) NIL) (($ (-123) $ $) NIL) (($ (-123) $ $ $) NIL) (($ (-123) $ $ $ $) NIL) (($ (-123) (-634 $)) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-558)))) (-3502 (($ $) NIL) (($ $ $) NIL)) (-1928 (($ $) 232 (|has| |#1| (-558)))) (-1847 (($ $) 183 (|has| |#1| (-558)))) (-4189 (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-1047))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-1047))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-1047))) (($ $ (-1161)) NIL (|has| |#1| (-1047)))) (-3013 (($ $) 67 (|has| |#1| (-558)))) (-2324 (((-1113 |#1| (-607 $)) $) 81 (|has| |#1| (-558)))) (-1626 (($ $) 299 (|has| $ (-1047)))) (-1994 (($ $) 160 (|has| |#1| (-558)))) (-1945 (($ $) 136 (|has| |#1| (-558)))) (-1986 (($ $) 156 (|has| |#1| (-558)))) (-1937 (($ $) 132 (|has| |#1| (-558)))) (-1978 (($ $) 152 (|has| |#1| (-558)))) (-2790 (($ $) 128 (|has| |#1| (-558)))) (-4278 (((-887 (-568)) $) NIL (|has| |#1| (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| |#1| (-609 (-887 (-381))))) (($ (-420 $)) NIL (|has| |#1| (-558))) (((-541) $) 339 (|has| |#1| (-609 (-541))))) (-1458 (($ $ $) NIL (|has| |#1| (-478)))) (-2353 (($ $ $) NIL (|has| |#1| (-478)))) (-2745 (((-850) $) 397) (($ (-607 $)) 388) (($ (-1161)) 356) (($ |#1|) 318) (($ $) NIL (|has| |#1| (-558))) (($ (-53)) 293 (-12 (|has| |#1| (-558)) (|has| |#1| (-1037 (-568))))) (($ (-1113 |#1| (-607 $))) 83 (|has| |#1| (-1047))) (($ (-409 |#1|)) NIL (|has| |#1| (-558))) (($ (-953 (-409 |#1|))) NIL (|has| |#1| (-558))) (($ (-409 (-953 (-409 |#1|)))) NIL (|has| |#1| (-558))) (($ (-409 (-953 |#1|))) NIL (|has| |#1| (-558))) (($ (-953 |#1|)) NIL (|has| |#1| (-1047))) (($ (-409 (-568))) NIL (-2198 (|has| |#1| (-558)) (|has| |#1| (-1037 (-409 (-568)))))) (($ (-568)) 34 (-2198 (|has| |#1| (-1037 (-568))) (|has| |#1| (-1047))))) (-4371 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-4078 (((-763)) NIL (|has| |#1| (-1047)))) (-2092 (($ $) NIL) (($ (-634 $)) NIL)) (-2787 (($ $ $) 203 (|has| |#1| (-558)))) (-3657 (($ $ $) 189 (|has| |#1| (-558)))) (-2375 (($ $ $) 193 (|has| |#1| (-558)))) (-1369 (($ $ $) 187 (|has| |#1| (-558)))) (-3737 (($ $ $) 191 (|has| |#1| (-558)))) (-2887 (((-121) (-123)) 9)) (-2006 (($ $) 166 (|has| |#1| (-558)))) (-1958 (($ $) 142 (|has| |#1| (-558)))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1998 (($ $) 162 (|has| |#1| (-558)))) (-1949 (($ $) 138 (|has| |#1| (-558)))) (-2014 (($ $) 170 (|has| |#1| (-558)))) (-1966 (($ $) 146 (|has| |#1| (-558)))) (-3058 (($ (-1161) $) NIL) (($ (-1161) $ $) NIL) (($ (-1161) $ $ $) NIL) (($ (-1161) $ $ $ $) NIL) (($ (-1161) (-634 $)) NIL)) (-3828 (($ $) 197 (|has| |#1| (-558)))) (-2357 (($ $) 195 (|has| |#1| (-558)))) (-4023 (($ $) 172 (|has| |#1| (-558)))) (-1970 (($ $) 148 (|has| |#1| (-558)))) (-2010 (($ $) 168 (|has| |#1| (-558)))) (-1962 (($ $) 144 (|has| |#1| (-558)))) (-2002 (($ $) 164 (|has| |#1| (-558)))) (-1953 (($ $) 140 (|has| |#1| (-558)))) (-2897 (($ $) 175 (|has| |#1| (-558)))) (-1887 (($ $ (-568)) NIL (-2198 (|has| |#1| (-478)) (|has| |#1| (-558)))) (($ $ (-763)) NIL (-2198 (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))) (|has| |#1| (-1102)))) (($ $ (-917)) NIL (-2198 (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))) (|has| |#1| (-1102))))) (-3056 (($) 20 (-2198 (|has| |#1| (-25)) (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047)))) CONST)) (-3833 (($ $) 226 (|has| |#1| (-558)))) (-1556 (($) 22 (-2198 (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))) (|has| |#1| (-1102))) CONST)) (-3929 (($ $) 177 (|has| |#1| (-558))) (($ $ $) 179 (|has| |#1| (-558)))) (-1969 (($ $) 224 (|has| |#1| (-558)))) (-3190 (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-1047))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-1047))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-1047))) (($ $ (-1161)) NIL (|has| |#1| (-1047)))) (-2902 (($ $) 228 (|has| |#1| (-558)))) (-3792 (($ $ $) 181 (|has| |#1| (-558)))) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 76)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 75)) (-1779 (($ (-1113 |#1| (-607 $)) (-1113 |#1| (-607 $))) 93 (|has| |#1| (-558))) (($ $ $) 42 (-2198 (|has| |#1| (-478)) (|has| |#1| (-558))))) (-1773 (($ $ $) 40 (-2198 (|has| |#1| (-21)) (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))))) (($ $) 29 (-2198 (|has| |#1| (-21)) (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047)))))) (-1767 (($ $ $) 38 (-2198 (|has| |#1| (-25)) (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047)))))) (** (($ $ $) 61 (|has| |#1| (-558))) (($ $ (-409 (-568))) 296 (|has| |#1| (-558))) (($ $ (-568)) 71 (-2198 (|has| |#1| (-478)) (|has| |#1| (-558)))) (($ $ (-763)) 68 (-2198 (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))) (|has| |#1| (-1102)))) (($ $ (-917)) 73 (-2198 (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))) (|has| |#1| (-1102))))) (* (($ (-409 (-568)) $) NIL (|has| |#1| (-558))) (($ $ (-409 (-568))) NIL (|has| |#1| (-558))) (($ |#1| $) NIL (|has| |#1| (-172))) (($ $ |#1|) NIL (|has| |#1| (-172))) (($ $ $) 36 (-2198 (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))) (|has| |#1| (-1102)))) (($ (-568) $) 32 (-2198 (|has| |#1| (-21)) (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))))) (($ (-763) $) NIL (-2198 (|has| |#1| (-25)) (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))))) (($ (-917) $) NIL (-2198 (|has| |#1| (-25)) (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))))))) 
-(((-310 |#1|) (-13 (-432 |#1|) (-10 -8 (IF (|has| |#1| (-558)) (PROGN (-6 (-29 |#1|)) (-6 (-1181)) (-6 (-161)) (-6 (-620)) (-6 (-1124)) (-15 -3092 ($ $)) (-15 -3185 ((-121) $)) (-15 -2352 ($ $ (-568))) (IF (|has| |#1| (-453)) (PROGN (-15 -3545 ((-420 (-1157 $)) (-1157 $))) (-15 -1750 ((-420 (-1157 $)) (-1157 $)))) |noBranch|) (IF (|has| |#1| (-1037 (-568))) (-6 (-1037 (-53))) |noBranch|)) |noBranch|))) (-842)) (T -310)) 
-((-3092 (*1 *1 *1) (-12 (-5 *1 (-310 *2)) (-4 *2 (-558)) (-4 *2 (-842)))) (-3185 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-310 *3)) (-4 *3 (-558)) (-4 *3 (-842)))) (-2352 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-310 *3)) (-4 *3 (-558)) (-4 *3 (-842)))) (-3545 (*1 *2 *3) (-12 (-5 *2 (-420 (-1157 *1))) (-5 *1 (-310 *4)) (-5 *3 (-1157 *1)) (-4 *4 (-453)) (-4 *4 (-558)) (-4 *4 (-842)))) (-1750 (*1 *2 *3) (-12 (-5 *2 (-420 (-1157 *1))) (-5 *1 (-310 *4)) (-5 *3 (-1157 *1)) (-4 *4 (-453)) (-4 *4 (-558)) (-4 *4 (-842))))) 
-(-13 (-432 |#1|) (-10 -8 (IF (|has| |#1| (-558)) (PROGN (-6 (-29 |#1|)) (-6 (-1181)) (-6 (-161)) (-6 (-620)) (-6 (-1124)) (-15 -3092 ($ $)) (-15 -3185 ((-121) $)) (-15 -2352 ($ $ (-568))) (IF (|has| |#1| (-453)) (PROGN (-15 -3545 ((-420 (-1157 $)) (-1157 $))) (-15 -1750 ((-420 (-1157 $)) (-1157 $)))) |noBranch|) (IF (|has| |#1| (-1037 (-568))) (-6 (-1037 (-53))) |noBranch|)) |noBranch|))) 
-((-4251 (((-57) |#2| (-123) (-288 |#2|) (-634 |#2|)) 86) (((-57) |#2| (-123) (-288 |#2|) (-288 |#2|)) 82) (((-57) |#2| (-123) (-288 |#2|) |#2|) 84) (((-57) (-288 |#2|) (-123) (-288 |#2|) |#2|) 85) (((-57) (-634 |#2|) (-634 (-123)) (-288 |#2|) (-634 (-288 |#2|))) 78) (((-57) (-634 |#2|) (-634 (-123)) (-288 |#2|) (-634 |#2|)) 80) (((-57) (-634 (-288 |#2|)) (-634 (-123)) (-288 |#2|) (-634 |#2|)) 81) (((-57) (-634 (-288 |#2|)) (-634 (-123)) (-288 |#2|) (-634 (-288 |#2|))) 79) (((-57) (-288 |#2|) (-123) (-288 |#2|) (-634 |#2|)) 87) (((-57) (-288 |#2|) (-123) (-288 |#2|) (-288 |#2|)) 83))) 
-(((-311 |#1| |#2|) (-10 -7 (-15 -4251 ((-57) (-288 |#2|) (-123) (-288 |#2|) (-288 |#2|))) (-15 -4251 ((-57) (-288 |#2|) (-123) (-288 |#2|) (-634 |#2|))) (-15 -4251 ((-57) (-634 (-288 |#2|)) (-634 (-123)) (-288 |#2|) (-634 (-288 |#2|)))) (-15 -4251 ((-57) (-634 (-288 |#2|)) (-634 (-123)) (-288 |#2|) (-634 |#2|))) (-15 -4251 ((-57) (-634 |#2|) (-634 (-123)) (-288 |#2|) (-634 |#2|))) (-15 -4251 ((-57) (-634 |#2|) (-634 (-123)) (-288 |#2|) (-634 (-288 |#2|)))) (-15 -4251 ((-57) (-288 |#2|) (-123) (-288 |#2|) |#2|)) (-15 -4251 ((-57) |#2| (-123) (-288 |#2|) |#2|)) (-15 -4251 ((-57) |#2| (-123) (-288 |#2|) (-288 |#2|))) (-15 -4251 ((-57) |#2| (-123) (-288 |#2|) (-634 |#2|)))) (-13 (-842) (-558) (-609 (-541))) (-432 |#1|)) (T -311)) 
-((-4251 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-123)) (-5 *5 (-288 *3)) (-5 *6 (-634 *3)) (-4 *3 (-432 *7)) (-4 *7 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *7 *3)))) (-4251 (*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-123)) (-5 *5 (-288 *3)) (-4 *3 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *3)))) (-4251 (*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-123)) (-5 *5 (-288 *3)) (-4 *3 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *3)))) (-4251 (*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-288 *5)) (-5 *4 (-123)) (-4 *5 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *5)))) (-4251 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 (-123))) (-5 *6 (-634 (-288 *8))) (-4 *8 (-432 *7)) (-5 *5 (-288 *8)) (-4 *7 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *7 *8)))) (-4251 (*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-634 *7)) (-5 *4 (-634 (-123))) (-5 *5 (-288 *7)) (-4 *7 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *7)))) (-4251 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-634 (-288 *8))) (-5 *4 (-634 (-123))) (-5 *5 (-288 *8)) (-5 *6 (-634 *8)) (-4 *8 (-432 *7)) (-4 *7 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *7 *8)))) (-4251 (*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-634 (-288 *7))) (-5 *4 (-634 (-123))) (-5 *5 (-288 *7)) (-4 *7 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *7)))) (-4251 (*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-288 *7)) (-5 *4 (-123)) (-5 *5 (-634 *7)) (-4 *7 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *7)))) (-4251 (*1 *2 *3 *4 *3 *3) (-12 (-5 *3 (-288 *6)) (-5 *4 (-123)) (-4 *6 (-432 *5)) (-4 *5 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *5 *6))))) 
-(-10 -7 (-15 -4251 ((-57) (-288 |#2|) (-123) (-288 |#2|) (-288 |#2|))) (-15 -4251 ((-57) (-288 |#2|) (-123) (-288 |#2|) (-634 |#2|))) (-15 -4251 ((-57) (-634 (-288 |#2|)) (-634 (-123)) (-288 |#2|) (-634 (-288 |#2|)))) (-15 -4251 ((-57) (-634 (-288 |#2|)) (-634 (-123)) (-288 |#2|) (-634 |#2|))) (-15 -4251 ((-57) (-634 |#2|) (-634 (-123)) (-288 |#2|) (-634 |#2|))) (-15 -4251 ((-57) (-634 |#2|) (-634 (-123)) (-288 |#2|) (-634 (-288 |#2|)))) (-15 -4251 ((-57) (-288 |#2|) (-123) (-288 |#2|) |#2|)) (-15 -4251 ((-57) |#2| (-123) (-288 |#2|) |#2|)) (-15 -4251 ((-57) |#2| (-123) (-288 |#2|) (-288 |#2|))) (-15 -4251 ((-57) |#2| (-123) (-288 |#2|) (-634 |#2|)))) 
-((-4251 ((|#3| |#2| (-123) (-1161) (-634 |#2|)) 53)) (-1952 ((|#2| |#2| (-123) (-1161)) 30))) 
-(((-312 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4251 (|#3| |#2| (-123) (-1161) (-634 |#2|))) (-15 -1952 (|#2| |#2| (-123) (-1161)))) (-13 (-842) (-558) (-609 (-541))) (-432 |#1|) (-1234 |#2|) (-1234 (-1155 |#2|))) (T -312)) 
-((-1952 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-123)) (-5 *4 (-1161)) (-4 *5 (-13 (-842) (-558) (-609 (-541)))) (-4 *2 (-432 *5)) (-5 *1 (-312 *5 *2 *6 *7)) (-4 *6 (-1234 *2)) (-4 *7 (-1234 (-1155 *2))))) (-4251 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-123)) (-5 *5 (-1161)) (-5 *6 (-634 *3)) (-4 *3 (-432 *7)) (-4 *7 (-13 (-842) (-558) (-609 (-541)))) (-4 *2 (-1234 *3)) (-5 *1 (-312 *7 *3 *2 *8)) (-4 *8 (-1234 (-1155 *3)))))) 
-(-10 -7 (-15 -4251 (|#3| |#2| (-123) (-1161) (-634 |#2|))) (-15 -1952 (|#2| |#2| (-123) (-1161)))) 
-((-1673 (((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-215) (-568) (-1143)) 45) (((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-215) (-568)) 46) (((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-1 (-215) (-215)) (-568) (-1143)) 42) (((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-1 (-215) (-215)) (-568)) 43)) (-3967 (((-1 (-215) (-215)) (-215)) 44))) 
-(((-313) (-10 -7 (-15 -3967 ((-1 (-215) (-215)) (-215))) (-15 -1673 ((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-1 (-215) (-215)) (-568))) (-15 -1673 ((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-1 (-215) (-215)) (-568) (-1143))) (-15 -1673 ((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-215) (-568))) (-15 -1673 ((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-215) (-568) (-1143))))) (T -313)) 
-((-1673 (*1 *2 *3 *3 *3 *4 *5 *6 *7 *8) (-12 (-5 *3 (-310 (-568))) (-5 *4 (-1 (-215) (-215))) (-5 *5 (-1084 (-215))) (-5 *6 (-215)) (-5 *7 (-568)) (-5 *8 (-1143)) (-5 *2 (-1191 (-926))) (-5 *1 (-313)))) (-1673 (*1 *2 *3 *3 *3 *4 *5 *6 *7) (-12 (-5 *3 (-310 (-568))) (-5 *4 (-1 (-215) (-215))) (-5 *5 (-1084 (-215))) (-5 *6 (-215)) (-5 *7 (-568)) (-5 *2 (-1191 (-926))) (-5 *1 (-313)))) (-1673 (*1 *2 *3 *3 *3 *4 *5 *4 *6 *7) (-12 (-5 *3 (-310 (-568))) (-5 *4 (-1 (-215) (-215))) (-5 *5 (-1084 (-215))) (-5 *6 (-568)) (-5 *7 (-1143)) (-5 *2 (-1191 (-926))) (-5 *1 (-313)))) (-1673 (*1 *2 *3 *3 *3 *4 *5 *4 *6) (-12 (-5 *3 (-310 (-568))) (-5 *4 (-1 (-215) (-215))) (-5 *5 (-1084 (-215))) (-5 *6 (-568)) (-5 *2 (-1191 (-926))) (-5 *1 (-313)))) (-3967 (*1 *2 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *1 (-313)) (-5 *3 (-215))))) 
-(-10 -7 (-15 -3967 ((-1 (-215) (-215)) (-215))) (-15 -1673 ((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-1 (-215) (-215)) (-568))) (-15 -1673 ((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-1 (-215) (-215)) (-568) (-1143))) (-15 -1673 ((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-215) (-568))) (-15 -1673 ((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-215) (-568) (-1143)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 24)) (-2055 (((-634 (-1075)) $) NIL)) (-1305 (((-1161) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-2617 (($ $ (-409 (-568))) NIL) (($ $ (-409 (-568)) (-409 (-568))) NIL)) (-2583 (((-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|))) $) 19)) (-1982 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1933 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL (|has| |#1| (-365)))) (-1678 (((-420 $) $) NIL (|has| |#1| (-365)))) (-1902 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1497 (((-121) $ $) NIL (|has| |#1| (-365)))) (-1974 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2786 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3728 (($ (-763) (-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|)))) NIL)) (-1990 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1941 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2671 (($) NIL T CONST)) (-2401 (($ $ $) NIL (|has| |#1| (-365)))) (-2114 (($ $) 30)) (-2925 (((-3 $ "failed") $) NIL)) (-2412 (($ $ $) NIL (|has| |#1| (-365)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-3927 (((-121) $) NIL (|has| |#1| (-365)))) (-3992 (((-121) $) NIL)) (-1897 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4477 (((-409 (-568)) $) NIL) (((-409 (-568)) $ (-409 (-568))) 15)) (-2735 (((-121) $) NIL)) (-4044 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3536 (($ $ (-917)) NIL) (($ $ (-409 (-568))) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| (-409 (-568))) NIL) (($ $ (-1075) (-409 (-568))) NIL) (($ $ (-634 (-1075)) (-634 (-409 (-568)))) NIL)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-4416 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-2495 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL (|has| |#1| (-365)))) (-3837 (($ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) NIL (-2198 (-12 (|has| |#1| (-15 -3837 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2055 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181)))))) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-365)))) (-2721 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-3848 (((-420 $) $) NIL (|has| |#1| (-365)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-365)))) (-1807 (($ $ (-409 (-568))) NIL)) (-2595 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-2301 (((-409 (-568)) $) 16)) (-4327 (($ (-1228 |#1| |#2| |#3|)) 11)) (-3438 (((-1228 |#1| |#2| |#3|) $) 12)) (-1892 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))))) (-2709 (((-763) $) NIL (|has| |#1| (-365)))) (-2779 ((|#1| $ (-409 (-568))) NIL) (($ $ $) NIL (|has| (-409 (-568)) (-1102)))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-365)))) (-4189 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (-3206 (((-409 (-568)) $) NIL)) (-1994 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1945 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1986 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1937 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1978 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2790 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1811 (($ $) 10)) (-2745 (((-850) $) 36) (($ (-568)) NIL) (($ |#1|) NIL (|has| |#1| (-172))) (($ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $) NIL (|has| |#1| (-558)))) (-2604 ((|#1| $ (-409 (-568))) 28)) (-4371 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-4078 (((-763)) NIL)) (-1374 ((|#1| $) NIL)) (-2006 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1958 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1998 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1949 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2014 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1966 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3996 ((|#1| $ (-409 (-568))) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))) (|has| |#1| (-15 -2745 (|#1| (-1161))))))) (-4023 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1970 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2010 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1962 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2002 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1953 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 26)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 31)) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
-(((-314 |#1| |#2| |#3|) (-13 (-1224 |#1|) (-787) (-10 -8 (-15 -4327 ($ (-1228 |#1| |#2| |#3|))) (-15 -3438 ((-1228 |#1| |#2| |#3|) $)) (-15 -2301 ((-409 (-568)) $)))) (-13 (-365) (-842)) (-1161) |#1|) (T -314)) 
-((-4327 (*1 *1 *2) (-12 (-5 *2 (-1228 *3 *4 *5)) (-4 *3 (-13 (-365) (-842))) (-14 *4 (-1161)) (-14 *5 *3) (-5 *1 (-314 *3 *4 *5)))) (-3438 (*1 *2 *1) (-12 (-5 *2 (-1228 *3 *4 *5)) (-5 *1 (-314 *3 *4 *5)) (-4 *3 (-13 (-365) (-842))) (-14 *4 (-1161)) (-14 *5 *3))) (-2301 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-314 *3 *4 *5)) (-4 *3 (-13 (-365) (-842))) (-14 *4 (-1161)) (-14 *5 *3)))) 
-(-13 (-1224 |#1|) (-787) (-10 -8 (-15 -4327 ($ (-1228 |#1| |#2| |#3|))) (-15 -3438 ((-1228 |#1| |#2| |#3|) $)) (-15 -2301 ((-409 (-568)) $)))) 
-((-2643 (((-420 (-1157 |#1|)) (-1157 |#1|) |#1|) 15)) (-3848 (((-420 (-1157 |#1|)) (-1157 |#1|) |#1|) 24))) 
-(((-315 |#1|) (-10 -7 (-15 -3848 ((-420 (-1157 |#1|)) (-1157 |#1|) |#1|)) (-15 -2643 ((-420 (-1157 |#1|)) (-1157 |#1|) |#1|))) (-854)) (T -315)) 
-((-2643 (*1 *2 *3 *4) (-12 (-4 *4 (-854)) (-5 *2 (-420 (-1157 *4))) (-5 *1 (-315 *4)) (-5 *3 (-1157 *4)))) (-3848 (*1 *2 *3 *4) (-12 (-4 *4 (-854)) (-5 *2 (-420 (-1157 *4))) (-5 *1 (-315 *4)) (-5 *3 (-1157 *4))))) 
-(-10 -7 (-15 -3848 ((-420 (-1157 |#1|)) (-1157 |#1|) |#1|)) (-15 -2643 ((-420 (-1157 |#1|)) (-1157 |#1|) |#1|))) 
-((-4044 (((-2 (|:| -3438 (-763)) (|:| -2348 |#1|) (|:| |radicand| (-634 |#1|))) (-420 |#1|) (-763)) 24)) (-4416 (((-634 (-2 (|:| -2348 (-763)) (|:| |logand| |#1|))) (-420 |#1|)) 28))) 
-(((-316 |#1|) (-10 -7 (-15 -4044 ((-2 (|:| -3438 (-763)) (|:| -2348 |#1|) (|:| |radicand| (-634 |#1|))) (-420 |#1|) (-763))) (-15 -4416 ((-634 (-2 (|:| -2348 (-763)) (|:| |logand| |#1|))) (-420 |#1|)))) (-558)) (T -316)) 
-((-4416 (*1 *2 *3) (-12 (-5 *3 (-420 *4)) (-4 *4 (-558)) (-5 *2 (-634 (-2 (|:| -2348 (-763)) (|:| |logand| *4)))) (-5 *1 (-316 *4)))) (-4044 (*1 *2 *3 *4) (-12 (-5 *3 (-420 *5)) (-4 *5 (-558)) (-5 *2 (-2 (|:| -3438 (-763)) (|:| -2348 *5) (|:| |radicand| (-634 *5)))) (-5 *1 (-316 *5)) (-5 *4 (-763))))) 
-(-10 -7 (-15 -4044 ((-2 (|:| -3438 (-763)) (|:| -2348 |#1|) (|:| |radicand| (-634 |#1|))) (-420 |#1|) (-763))) (-15 -4416 ((-634 (-2 (|:| -2348 (-763)) (|:| |logand| |#1|))) (-420 |#1|)))) 
-((-2643 (((-420 (-1157 |#1|)) (-1157 |#1|) |#1|) 15)) (-3848 (((-420 (-1157 |#1|)) (-1157 |#1|) |#1|) 24))) 
-(((-317 |#1|) (-10 -7 (-15 -3848 ((-420 (-1157 |#1|)) (-1157 |#1|) |#1|)) (-15 -2643 ((-420 (-1157 |#1|)) (-1157 |#1|) |#1|))) (-859)) (T -317)) 
-((-2643 (*1 *2 *3 *4) (-12 (-4 *4 (-859)) (-5 *2 (-420 (-1157 *4))) (-5 *1 (-317 *4)) (-5 *3 (-1157 *4)))) (-3848 (*1 *2 *3 *4) (-12 (-4 *4 (-859)) (-5 *2 (-420 (-1157 *4))) (-5 *1 (-317 *4)) (-5 *3 (-1157 *4))))) 
-(-10 -7 (-15 -3848 ((-420 (-1157 |#1|)) (-1157 |#1|) |#1|)) (-15 -2643 ((-420 (-1157 |#1|)) (-1157 |#1|) |#1|))) 
-((-2055 (((-634 |#2|) (-1157 |#4|)) 43)) (-4414 ((|#3| (-568)) 46)) (-3669 (((-1157 |#4|) (-1157 |#3|)) 30)) (-2708 (((-1157 |#4|) (-1157 |#4|) (-568)) 55)) (-1517 (((-1157 |#3|) (-1157 |#4|)) 21)) (-3206 (((-634 (-763)) (-1157 |#4|) (-634 |#2|)) 40)) (-2810 (((-1157 |#3|) (-1157 |#4|) (-634 |#2|) (-634 |#3|)) 35))) 
-(((-318 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2810 ((-1157 |#3|) (-1157 |#4|) (-634 |#2|) (-634 |#3|))) (-15 -3206 ((-634 (-763)) (-1157 |#4|) (-634 |#2|))) (-15 -2055 ((-634 |#2|) (-1157 |#4|))) (-15 -1517 ((-1157 |#3|) (-1157 |#4|))) (-15 -3669 ((-1157 |#4|) (-1157 |#3|))) (-15 -2708 ((-1157 |#4|) (-1157 |#4|) (-568))) (-15 -4414 (|#3| (-568)))) (-788) (-842) (-1047) (-950 |#3| |#1| |#2|)) (T -318)) 
-((-4414 (*1 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1047)) (-5 *1 (-318 *4 *5 *2 *6)) (-4 *6 (-950 *2 *4 *5)))) (-2708 (*1 *2 *2 *3) (-12 (-5 *2 (-1157 *7)) (-5 *3 (-568)) (-4 *7 (-950 *6 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-5 *1 (-318 *4 *5 *6 *7)))) (-3669 (*1 *2 *3) (-12 (-5 *3 (-1157 *6)) (-4 *6 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-1157 *7)) (-5 *1 (-318 *4 *5 *6 *7)) (-4 *7 (-950 *6 *4 *5)))) (-1517 (*1 *2 *3) (-12 (-5 *3 (-1157 *7)) (-4 *7 (-950 *6 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-5 *2 (-1157 *6)) (-5 *1 (-318 *4 *5 *6 *7)))) (-2055 (*1 *2 *3) (-12 (-5 *3 (-1157 *7)) (-4 *7 (-950 *6 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-5 *2 (-634 *5)) (-5 *1 (-318 *4 *5 *6 *7)))) (-3206 (*1 *2 *3 *4) (-12 (-5 *3 (-1157 *8)) (-5 *4 (-634 *6)) (-4 *6 (-842)) (-4 *8 (-950 *7 *5 *6)) (-4 *5 (-788)) (-4 *7 (-1047)) (-5 *2 (-634 (-763))) (-5 *1 (-318 *5 *6 *7 *8)))) (-2810 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1157 *9)) (-5 *4 (-634 *7)) (-5 *5 (-634 *8)) (-4 *7 (-842)) (-4 *8 (-1047)) (-4 *9 (-950 *8 *6 *7)) (-4 *6 (-788)) (-5 *2 (-1157 *8)) (-5 *1 (-318 *6 *7 *8 *9))))) 
-(-10 -7 (-15 -2810 ((-1157 |#3|) (-1157 |#4|) (-634 |#2|) (-634 |#3|))) (-15 -3206 ((-634 (-763)) (-1157 |#4|) (-634 |#2|))) (-15 -2055 ((-634 |#2|) (-1157 |#4|))) (-15 -1517 ((-1157 |#3|) (-1157 |#4|))) (-15 -3669 ((-1157 |#4|) (-1157 |#3|))) (-15 -2708 ((-1157 |#4|) (-1157 |#4|) (-568))) (-15 -4414 (|#3| (-568)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 14)) (-2583 (((-634 (-2 (|:| |gen| |#1|) (|:| -1892 (-568)))) $) 18)) (-3134 (((-3 $ "failed") $ $) NIL)) (-3983 (((-763) $) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) NIL)) (-2854 ((|#1| $) NIL)) (-2882 ((|#1| $ (-568)) NIL)) (-1444 (((-568) $ (-568)) NIL)) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-2096 (($ (-1 |#1| |#1|) $) NIL)) (-2907 (($ (-1 (-568) (-568)) $) 10)) (-4487 (((-1143) $) NIL)) (-1764 (($ $ $) NIL (|has| (-568) (-787)))) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL) (($ |#1|) NIL)) (-2604 (((-568) |#1| $) NIL)) (-3056 (($) 15 T CONST)) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) 21 (|has| |#1| (-842)))) (-1773 (($ $) 11) (($ $ $) 20)) (-1767 (($ $ $) NIL) (($ |#1| $) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ (-568)) NIL) (($ (-568) |#1|) 19))) 
+((-3335 (((-1249) (-1149 3 (-215)) (-1143)) 38))) 
+(((-306) (-10 -7 (-15 -3335 ((-1249) (-1149 3 (-215)) (-1143))))) (T -306)) 
+((-3335 (*1 *2 *3 *4) (-12 (-5 *3 (-1149 3 (-215))) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-306))))) 
+(-10 -7 (-15 -3335 ((-1249) (-1149 3 (-215)) (-1143)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 62)) (-2563 (((-1229 |#1| |#2| |#3| |#4|) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-301)))) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-904)))) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-904)))) (-2589 (((-121) $ $) NIL)) (-3337 (((-568) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-815)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-1229 |#1| |#2| |#3| |#4|) "failed") $) NIL) (((-3 (-1161) "failed") $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-1037 (-1161)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-1037 (-568)))) (((-3 (-568) "failed") $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-1037 (-568)))) (((-3 (-1228 |#2| |#3| |#4|) "failed") $) 24)) (-2857 (((-1229 |#1| |#2| |#3| |#4|) $) NIL) (((-1161) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-1037 (-1161)))) (((-409 (-568)) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-1037 (-568)))) (((-568) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-1037 (-568)))) (((-1228 |#2| |#3| |#4|) $) NIL)) (-2403 (($ $ $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-630 (-568)))) (((-2 (|:| -2908 (-679 (-1229 |#1| |#2| |#3| |#4|))) (|:| |vec| (-1244 (-1229 |#1| |#2| |#3| |#4|)))) (-679 $) (-1244 $)) NIL) (((-679 (-1229 |#1| |#2| |#3| |#4|)) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1733 (($) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-550)))) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-1436 (((-121) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-815)))) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-881 (-381))))) (-1598 (((-121) $) NIL)) (-3539 (($ $) NIL)) (-2319 (((-1229 |#1| |#2| |#3| |#4|) $) 21)) (-2214 (((-3 $ "failed") $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-1136)))) (-2859 (((-121) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-815)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1732 (($ $ $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-842)))) (-2047 (($ $ $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-842)))) (-2797 (($ (-1 (-1229 |#1| |#2| |#3| |#4|) (-1229 |#1| |#2| |#3| |#4|)) $) NIL)) (-4200 (((-3 (-835 |#2|) "failed") $) 76)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4436 (($) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-1136)) CONST)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1999 (($ $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-301)))) (-4115 (((-1229 |#1| |#2| |#3| |#4|) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-550)))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-904)))) (-3850 (((-420 $) $) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1339 (($ $ (-634 (-1229 |#1| |#2| |#3| |#4|)) (-634 (-1229 |#1| |#2| |#3| |#4|))) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-303 (-1229 |#1| |#2| |#3| |#4|)))) (($ $ (-1229 |#1| |#2| |#3| |#4|) (-1229 |#1| |#2| |#3| |#4|)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-303 (-1229 |#1| |#2| |#3| |#4|)))) (($ $ (-288 (-1229 |#1| |#2| |#3| |#4|))) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-303 (-1229 |#1| |#2| |#3| |#4|)))) (($ $ (-634 (-288 (-1229 |#1| |#2| |#3| |#4|)))) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-303 (-1229 |#1| |#2| |#3| |#4|)))) (($ $ (-634 (-1161)) (-634 (-1229 |#1| |#2| |#3| |#4|))) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-523 (-1161) (-1229 |#1| |#2| |#3| |#4|)))) (($ $ (-1161) (-1229 |#1| |#2| |#3| |#4|)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-523 (-1161) (-1229 |#1| |#2| |#3| |#4|))))) (-1466 (((-763) $) NIL)) (-2781 (($ $ (-1229 |#1| |#2| |#3| |#4|)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-281 (-1229 |#1| |#2| |#3| |#4|) (-1229 |#1| |#2| |#3| |#4|))))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-4191 (($ $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-225))) (($ $ (-763)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-225))) (($ $ (-1161)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-895 (-1161)))) (($ $ (-1 (-1229 |#1| |#2| |#3| |#4|) (-1229 |#1| |#2| |#3| |#4|)) (-763)) NIL) (($ $ (-1 (-1229 |#1| |#2| |#3| |#4|) (-1229 |#1| |#2| |#3| |#4|))) NIL)) (-3210 (($ $) NIL)) (-2326 (((-1229 |#1| |#2| |#3| |#4|) $) 17)) (-4280 (((-887 (-568)) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-609 (-887 (-381))))) (((-541) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-609 (-541)))) (((-381) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-1021))) (((-215) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-1021)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| (-1229 |#1| |#2| |#3| |#4|) (-904))))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ (-1229 |#1| |#2| |#3| |#4|)) 28) (($ (-1161)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-1037 (-1161)))) (($ (-1228 |#2| |#3| |#4|)) 36)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| (-1229 |#1| |#2| |#3| |#4|) (-904))) (|has| (-1229 |#1| |#2| |#3| |#4|) (-148))))) (-3425 (((-763)) NIL)) (-3520 (((-1229 |#1| |#2| |#3| |#4|) $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-550)))) (-2273 (((-121) $ $) NIL)) (-2811 (($ $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-815)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) 41 T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-225))) (($ $ (-763)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-225))) (($ $ (-1161)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-895 (-1161)))) (($ $ (-1 (-1229 |#1| |#2| |#3| |#4|) (-1229 |#1| |#2| |#3| |#4|)) (-763)) NIL) (($ $ (-1 (-1229 |#1| |#2| |#3| |#4|) (-1229 |#1| |#2| |#3| |#4|))) NIL)) (-1753 (((-121) $ $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-842)))) (-1740 (((-121) $ $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-842)))) (-1734 (((-121) $ $) NIL (|has| (-1229 |#1| |#2| |#3| |#4|) (-842)))) (-1781 (($ $ $) 33) (($ (-1229 |#1| |#2| |#3| |#4|) (-1229 |#1| |#2| |#3| |#4|)) 30)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ (-1229 |#1| |#2| |#3| |#4|) $) 29) (($ $ (-1229 |#1| |#2| |#3| |#4|)) NIL))) 
+(((-307 |#1| |#2| |#3| |#4|) (-13 (-993 (-1229 |#1| |#2| |#3| |#4|)) (-1037 (-1228 |#2| |#3| |#4|)) (-10 -8 (-15 -4200 ((-3 (-835 |#2|) "failed") $)) (-15 -2747 ($ (-1228 |#2| |#3| |#4|))))) (-13 (-842) (-1037 (-568)) (-630 (-568)) (-453)) (-13 (-27) (-1181) (-432 |#1|)) (-1161) |#2|) (T -307)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1228 *4 *5 *6)) (-4 *4 (-13 (-27) (-1181) (-432 *3))) (-14 *5 (-1161)) (-14 *6 *4) (-4 *3 (-13 (-842) (-1037 (-568)) (-630 (-568)) (-453))) (-5 *1 (-307 *3 *4 *5 *6)))) (-4200 (*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-842) (-1037 (-568)) (-630 (-568)) (-453))) (-5 *2 (-835 *4)) (-5 *1 (-307 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1181) (-432 *3))) (-14 *5 (-1161)) (-14 *6 *4)))) 
+(-13 (-993 (-1229 |#1| |#2| |#3| |#4|)) (-1037 (-1228 |#2| |#3| |#4|)) (-10 -8 (-15 -4200 ((-3 (-835 |#2|) "failed") $)) (-15 -2747 ($ (-1228 |#2| |#3| |#4|))))) 
+((-2797 (((-310 |#2|) (-1 |#2| |#1|) (-310 |#1|)) 13))) 
+(((-308 |#1| |#2|) (-10 -7 (-15 -2797 ((-310 |#2|) (-1 |#2| |#1|) (-310 |#1|)))) (-842) (-842)) (T -308)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-310 *5)) (-4 *5 (-842)) (-4 *6 (-842)) (-5 *2 (-310 *6)) (-5 *1 (-308 *5 *6))))) 
+(-10 -7 (-15 -2797 ((-310 |#2|) (-1 |#2| |#1|) (-310 |#1|)))) 
+((-2067 (((-57) |#2| (-288 |#2|) (-763)) 33) (((-57) |#2| (-288 |#2|)) 24) (((-57) |#2| (-763)) 28) (((-57) |#2|) 25) (((-57) (-1161)) 21)) (-2512 (((-57) |#2| (-288 |#2|) (-409 (-568))) 51) (((-57) |#2| (-288 |#2|)) 48) (((-57) |#2| (-409 (-568))) 50) (((-57) |#2|) 49) (((-57) (-1161)) 47)) (-2077 (((-57) |#2| (-288 |#2|) (-409 (-568))) 46) (((-57) |#2| (-288 |#2|)) 43) (((-57) |#2| (-409 (-568))) 45) (((-57) |#2|) 44) (((-57) (-1161)) 42)) (-2072 (((-57) |#2| (-288 |#2|) (-568)) 39) (((-57) |#2| (-288 |#2|)) 35) (((-57) |#2| (-568)) 38) (((-57) |#2|) 36) (((-57) (-1161)) 34))) 
+(((-309 |#1| |#2|) (-10 -7 (-15 -2067 ((-57) (-1161))) (-15 -2067 ((-57) |#2|)) (-15 -2067 ((-57) |#2| (-763))) (-15 -2067 ((-57) |#2| (-288 |#2|))) (-15 -2067 ((-57) |#2| (-288 |#2|) (-763))) (-15 -2072 ((-57) (-1161))) (-15 -2072 ((-57) |#2|)) (-15 -2072 ((-57) |#2| (-568))) (-15 -2072 ((-57) |#2| (-288 |#2|))) (-15 -2072 ((-57) |#2| (-288 |#2|) (-568))) (-15 -2077 ((-57) (-1161))) (-15 -2077 ((-57) |#2|)) (-15 -2077 ((-57) |#2| (-409 (-568)))) (-15 -2077 ((-57) |#2| (-288 |#2|))) (-15 -2077 ((-57) |#2| (-288 |#2|) (-409 (-568)))) (-15 -2512 ((-57) (-1161))) (-15 -2512 ((-57) |#2|)) (-15 -2512 ((-57) |#2| (-409 (-568)))) (-15 -2512 ((-57) |#2| (-288 |#2|))) (-15 -2512 ((-57) |#2| (-288 |#2|) (-409 (-568))))) (-13 (-453) (-842) (-1037 (-568)) (-630 (-568))) (-13 (-27) (-1181) (-432 |#1|))) (T -309)) 
+((-2512 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-288 *3)) (-5 *5 (-409 (-568))) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *6 *3)))) (-2512 (*1 *2 *3 *4) (-12 (-5 *4 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)))) (-2512 (*1 *2 *3 *4) (-12 (-5 *4 (-409 (-568))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) (-2512 (*1 *2 *3) (-12 (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4))))) (-2512 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *5)) (-4 *5 (-13 (-27) (-1181) (-432 *4))))) (-2077 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-288 *3)) (-5 *5 (-409 (-568))) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *6 *3)))) (-2077 (*1 *2 *3 *4) (-12 (-5 *4 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)))) (-2077 (*1 *2 *3 *4) (-12 (-5 *4 (-409 (-568))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) (-2077 (*1 *2 *3) (-12 (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4))))) (-2077 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *5)) (-4 *5 (-13 (-27) (-1181) (-432 *4))))) (-2072 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-453) (-842) (-1037 *5) (-630 *5))) (-5 *5 (-568)) (-5 *2 (-57)) (-5 *1 (-309 *6 *3)))) (-2072 (*1 *2 *3 *4) (-12 (-5 *4 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)))) (-2072 (*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-13 (-453) (-842) (-1037 *4) (-630 *4))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) (-2072 (*1 *2 *3) (-12 (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4))))) (-2072 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *5)) (-4 *5 (-13 (-27) (-1181) (-432 *4))))) (-2067 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-288 *3)) (-5 *5 (-763)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *6 *3)))) (-2067 (*1 *2 *3 *4) (-12 (-5 *4 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)))) (-2067 (*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) (-2067 (*1 *2 *3) (-12 (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4))))) (-2067 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *5)) (-4 *5 (-13 (-27) (-1181) (-432 *4)))))) 
+(-10 -7 (-15 -2067 ((-57) (-1161))) (-15 -2067 ((-57) |#2|)) (-15 -2067 ((-57) |#2| (-763))) (-15 -2067 ((-57) |#2| (-288 |#2|))) (-15 -2067 ((-57) |#2| (-288 |#2|) (-763))) (-15 -2072 ((-57) (-1161))) (-15 -2072 ((-57) |#2|)) (-15 -2072 ((-57) |#2| (-568))) (-15 -2072 ((-57) |#2| (-288 |#2|))) (-15 -2072 ((-57) |#2| (-288 |#2|) (-568))) (-15 -2077 ((-57) (-1161))) (-15 -2077 ((-57) |#2|)) (-15 -2077 ((-57) |#2| (-409 (-568)))) (-15 -2077 ((-57) |#2| (-288 |#2|))) (-15 -2077 ((-57) |#2| (-288 |#2|) (-409 (-568)))) (-15 -2512 ((-57) (-1161))) (-15 -2512 ((-57) |#2|)) (-15 -2512 ((-57) |#2| (-409 (-568)))) (-15 -2512 ((-57) |#2| (-288 |#2|))) (-15 -2512 ((-57) |#2| (-288 |#2|) (-409 (-568))))) 
+((-2449 (((-121) $ $) NIL)) (-2251 (((-634 $) $ (-1161)) NIL (|has| |#1| (-558))) (((-634 $) $) NIL (|has| |#1| (-558))) (((-634 $) (-1157 $) (-1161)) NIL (|has| |#1| (-558))) (((-634 $) (-1157 $)) NIL (|has| |#1| (-558))) (((-634 $) (-953 $)) NIL (|has| |#1| (-558)))) (-3505 (($ $ (-1161)) NIL (|has| |#1| (-558))) (($ $) NIL (|has| |#1| (-558))) (($ (-1157 $) (-1161)) NIL (|has| |#1| (-558))) (($ (-1157 $)) NIL (|has| |#1| (-558))) (($ (-953 $)) NIL (|has| |#1| (-558)))) (-1819 (((-121) $) 27 (-2199 (|has| |#1| (-25)) (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047)))))) (-2057 (((-634 (-1161)) $) 348)) (-3840 (((-409 (-1157 $)) $ (-607 $)) NIL (|has| |#1| (-558)))) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-3145 (((-634 (-607 $)) $) NIL)) (-1984 (($ $) 154 (|has| |#1| (-558)))) (-1935 (($ $) 130 (|has| |#1| (-558)))) (-1715 (($ $ (-1082 $)) 215 (|has| |#1| (-558))) (($ $ (-1161)) 211 (|has| |#1| (-558)))) (-2689 (((-3 $ "failed") $ $) NIL (-2199 (|has| |#1| (-21)) (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047)))))) (-4069 (($ $ (-288 $)) NIL) (($ $ (-634 (-288 $))) 364) (($ $ (-634 (-607 $)) (-634 $)) 407)) (-3863 (((-420 (-1157 $)) (-1157 $)) 292 (-12 (|has| |#1| (-453)) (|has| |#1| (-558))))) (-3045 (($ $) NIL (|has| |#1| (-558)))) (-3498 (((-420 $) $) NIL (|has| |#1| (-558)))) (-1904 (($ $) NIL (|has| |#1| (-558)))) (-2589 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1976 (($ $) 150 (|has| |#1| (-558)))) (-2788 (($ $) 126 (|has| |#1| (-558)))) (-3972 (($ $ (-568)) 64 (|has| |#1| (-558)))) (-1992 (($ $) 158 (|has| |#1| (-558)))) (-1943 (($ $) 134 (|has| |#1| (-558)))) (-4490 (($) NIL (-2199 (|has| |#1| (-25)) (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))) (|has| |#1| (-1102))) CONST)) (-1867 (((-634 $) $ (-1161)) NIL (|has| |#1| (-558))) (((-634 $) $) NIL (|has| |#1| (-558))) (((-634 $) (-1157 $) (-1161)) NIL (|has| |#1| (-558))) (((-634 $) (-1157 $)) NIL (|has| |#1| (-558))) (((-634 $) (-953 $)) NIL (|has| |#1| (-558)))) (-2919 (($ $ (-1161)) NIL (|has| |#1| (-558))) (($ $) NIL (|has| |#1| (-558))) (($ (-1157 $) (-1161)) 117 (|has| |#1| (-558))) (($ (-1157 $)) NIL (|has| |#1| (-558))) (($ (-953 $)) NIL (|has| |#1| (-558)))) (-3668 (((-3 (-607 $) "failed") $) 17) (((-3 (-1161) "failed") $) NIL) (((-3 |#1| "failed") $) 416) (((-3 (-53) "failed") $) 321 (-12 (|has| |#1| (-558)) (|has| |#1| (-1037 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-953 |#1|)) "failed") $) NIL (|has| |#1| (-558))) (((-3 (-953 |#1|) "failed") $) NIL (|has| |#1| (-1047))) (((-3 (-409 (-568)) "failed") $) 45 (-2199 (-12 (|has| |#1| (-558)) (|has| |#1| (-1037 (-568)))) (|has| |#1| (-1037 (-409 (-568))))))) (-2857 (((-607 $) $) 11) (((-1161) $) NIL) ((|#1| $) 398) (((-53) $) NIL (-12 (|has| |#1| (-558)) (|has| |#1| (-1037 (-568))))) (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-953 |#1|)) $) NIL (|has| |#1| (-558))) (((-953 |#1|) $) NIL (|has| |#1| (-1047))) (((-409 (-568)) $) 305 (-2199 (-12 (|has| |#1| (-558)) (|has| |#1| (-1037 (-568)))) (|has| |#1| (-1037 (-409 (-568))))))) (-2403 (($ $ $) NIL (|has| |#1| (-558)))) (-1668 (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 110 (|has| |#1| (-1047))) (((-679 |#1|) (-679 $)) 102 (|has| |#1| (-1047))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047)))) (((-679 (-568)) (-679 $)) NIL (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))))) (-3094 (($ $) 84 (|has| |#1| (-558)))) (-2902 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))) (|has| |#1| (-1102))))) (-2414 (($ $ $) NIL (|has| |#1| (-558)))) (-2062 (($ $ (-1082 $)) 219 (|has| |#1| (-558))) (($ $ (-1161)) 217 (|has| |#1| (-558)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| |#1| (-558)))) (-2197 (((-121) $) NIL (|has| |#1| (-558)))) (-3311 (($ $ $) 185 (|has| |#1| (-558)))) (-1899 (($) 120 (|has| |#1| (-558)))) (-2341 (($ $ $) 205 (|has| |#1| (-558)))) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 370 (|has| |#1| (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 376 (|has| |#1| (-881 (-381))))) (-3855 (($ $) NIL) (($ (-634 $)) NIL)) (-2160 (((-634 (-123)) $) NIL)) (-3842 (((-123) (-123)) 264)) (-1598 (((-121) $) 25 (-2199 (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))) (|has| |#1| (-1102))))) (-2268 (((-121) $) NIL (|has| $ (-1037 (-568))))) (-3539 (($ $) 66 (|has| |#1| (-1047)))) (-2319 (((-1113 |#1| (-607 $)) $) 79 (|has| |#1| (-1047)))) (-1762 (((-121) $) 46 (|has| |#1| (-558)))) (-1550 (($ $ (-568)) NIL (|has| |#1| (-558)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-558)))) (-3170 (((-1157 $) (-607 $)) 265 (|has| $ (-1047)))) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-2797 (($ (-1 $ $) (-607 $)) 403)) (-2337 (((-3 (-607 $) "failed") $) NIL)) (-4418 (($ $) 124 (|has| |#1| (-558)))) (-1913 (($ $) 230 (|has| |#1| (-558)))) (-2498 (($ (-634 $)) NIL (|has| |#1| (-558))) (($ $ $) NIL (|has| |#1| (-558)))) (-1893 (((-1143) $) NIL)) (-3832 (((-634 (-607 $)) $) 48)) (-3446 (($ (-123) $) NIL) (($ (-123) (-634 $)) 408)) (-4362 (((-3 (-634 $) "failed") $) NIL (|has| |#1| (-1102)))) (-4495 (((-3 (-2 (|:| |val| $) (|:| -3483 (-568))) "failed") $) NIL (|has| |#1| (-1047)))) (-2112 (((-3 (-634 $) "failed") $) 411 (|has| |#1| (-25)))) (-2240 (((-3 (-2 (|:| -2350 (-568)) (|:| |var| (-607 $))) "failed") $) 415 (|has| |#1| (-25)))) (-2617 (((-3 (-2 (|:| |var| (-607 $)) (|:| -3483 (-568))) "failed") $) NIL (|has| |#1| (-1102))) (((-3 (-2 (|:| |var| (-607 $)) (|:| -3483 (-568))) "failed") $ (-123)) NIL (|has| |#1| (-1047))) (((-3 (-2 (|:| |var| (-607 $)) (|:| -3483 (-568))) "failed") $ (-1161)) NIL (|has| |#1| (-1047)))) (-3910 (((-121) $ (-123)) NIL) (((-121) $ (-1161)) 52)) (-2083 (($ $) NIL (-2199 (|has| |#1| (-478)) (|has| |#1| (-558))))) (-2317 (($ $ (-1161)) 238 (|has| |#1| (-558))) (($ $ (-1082 $)) 240 (|has| |#1| (-558)))) (-2963 (((-763) $) NIL)) (-4025 (((-1108) $) NIL)) (-2088 (((-121) $) 43)) (-2093 ((|#1| $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 285 (|has| |#1| (-558)))) (-2723 (($ (-634 $)) NIL (|has| |#1| (-558))) (($ $ $) NIL (|has| |#1| (-558)))) (-1558 (($ $) 234 (|has| |#1| (-558)))) (-1565 (($ $) 236 (|has| |#1| (-558)))) (-1609 (((-121) $ $) NIL) (((-121) $ (-1161)) NIL)) (-3577 (($ $ (-1161)) 209 (|has| |#1| (-558))) (($ $) 207 (|has| |#1| (-558)))) (-2406 (($ $) 201 (|has| |#1| (-558)))) (-2795 (((-420 (-1157 $)) (-1157 $)) 290 (-12 (|has| |#1| (-453)) (|has| |#1| (-558))))) (-3850 (((-420 $) $) NIL (|has| |#1| (-558)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-558))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-558)))) (-2597 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-558)))) (-1894 (($ $) 122 (|has| |#1| (-558)))) (-2080 (((-121) $) NIL (|has| $ (-1037 (-568))))) (-1339 (($ $ (-607 $) $) NIL) (($ $ (-634 (-607 $)) (-634 $)) 402) (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ $))) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-1161) (-1 $ (-634 $))) NIL) (($ $ (-1161) (-1 $ $)) NIL) (($ $ (-634 (-123)) (-634 (-1 $ $))) 358) (($ $ (-634 (-123)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-123) (-1 $ (-634 $))) NIL) (($ $ (-123) (-1 $ $)) NIL) (($ $ (-1161)) NIL (|has| |#1| (-609 (-541)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-609 (-541)))) (($ $) NIL (|has| |#1| (-609 (-541)))) (($ $ (-123) $ (-1161)) 346 (|has| |#1| (-609 (-541)))) (($ $ (-634 (-123)) (-634 $) (-1161)) 345 (|has| |#1| (-609 (-541)))) (($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ $))) NIL (|has| |#1| (-1047))) (($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ (-634 $)))) NIL (|has| |#1| (-1047))) (($ $ (-1161) (-763) (-1 $ (-634 $))) NIL (|has| |#1| (-1047))) (($ $ (-1161) (-763) (-1 $ $)) NIL (|has| |#1| (-1047)))) (-1466 (((-763) $) NIL (|has| |#1| (-558)))) (-1918 (($ $) 222 (|has| |#1| (-558)))) (-2781 (($ (-123) $) NIL) (($ (-123) $ $) NIL) (($ (-123) $ $ $) NIL) (($ (-123) $ $ $ $) NIL) (($ (-123) (-634 $)) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-558)))) (-3924 (($ $) NIL) (($ $ $) NIL)) (-1930 (($ $) 232 (|has| |#1| (-558)))) (-2383 (($ $) 183 (|has| |#1| (-558)))) (-4191 (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-1047))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-1047))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-1047))) (($ $ (-1161)) NIL (|has| |#1| (-1047)))) (-3210 (($ $) 67 (|has| |#1| (-558)))) (-2326 (((-1113 |#1| (-607 $)) $) 81 (|has| |#1| (-558)))) (-1492 (($ $) 303 (|has| $ (-1047)))) (-1996 (($ $) 160 (|has| |#1| (-558)))) (-1947 (($ $) 136 (|has| |#1| (-558)))) (-1988 (($ $) 156 (|has| |#1| (-558)))) (-1939 (($ $) 132 (|has| |#1| (-558)))) (-1980 (($ $) 152 (|has| |#1| (-558)))) (-2792 (($ $) 128 (|has| |#1| (-558)))) (-4280 (((-887 (-568)) $) NIL (|has| |#1| (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| |#1| (-609 (-887 (-381))))) (($ (-420 $)) NIL (|has| |#1| (-558))) (((-541) $) 343 (|has| |#1| (-609 (-541))))) (-2387 (($ $ $) NIL (|has| |#1| (-478)))) (-3985 (($ $ $) NIL (|has| |#1| (-478)))) (-2747 (((-850) $) 401) (($ (-607 $)) 392) (($ (-1161)) 360) (($ |#1|) 322) (($ $) NIL (|has| |#1| (-558))) (($ (-53)) 297 (-12 (|has| |#1| (-558)) (|has| |#1| (-1037 (-568))))) (($ (-1113 |#1| (-607 $))) 83 (|has| |#1| (-1047))) (($ (-409 |#1|)) NIL (|has| |#1| (-558))) (($ (-953 (-409 |#1|))) NIL (|has| |#1| (-558))) (($ (-409 (-953 (-409 |#1|)))) NIL (|has| |#1| (-558))) (($ (-409 (-953 |#1|))) NIL (|has| |#1| (-558))) (($ (-953 |#1|)) NIL (|has| |#1| (-1047))) (($ (-409 (-568))) NIL (-2199 (|has| |#1| (-558)) (|has| |#1| (-1037 (-409 (-568)))))) (($ (-568)) 34 (-2199 (|has| |#1| (-1037 (-568))) (|has| |#1| (-1047))))) (-3385 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-3425 (((-763)) NIL (|has| |#1| (-1047)))) (-3159 (($ $) NIL) (($ (-634 $)) NIL)) (-3584 (($ $ $) 203 (|has| |#1| (-558)))) (-3301 (($ $ $) 189 (|has| |#1| (-558)))) (-2149 (($ $ $) 193 (|has| |#1| (-558)))) (-3826 (($ $ $) 187 (|has| |#1| (-558)))) (-2547 (($ $ $) 191 (|has| |#1| (-558)))) (-2779 (((-121) (-123)) 9)) (-2008 (($ $) 166 (|has| |#1| (-558)))) (-1959 (($ $) 142 (|has| |#1| (-558)))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2000 (($ $) 162 (|has| |#1| (-558)))) (-1951 (($ $) 138 (|has| |#1| (-558)))) (-2016 (($ $) 170 (|has| |#1| (-558)))) (-1968 (($ $) 146 (|has| |#1| (-558)))) (-3060 (($ (-1161) $) NIL) (($ (-1161) $ $) NIL) (($ (-1161) $ $ $) NIL) (($ (-1161) $ $ $ $) NIL) (($ (-1161) (-634 $)) NIL)) (-1813 (($ $) 197 (|has| |#1| (-558)))) (-4009 (($ $) 195 (|has| |#1| (-558)))) (-1439 (($ $) 172 (|has| |#1| (-558)))) (-1972 (($ $) 148 (|has| |#1| (-558)))) (-2012 (($ $) 168 (|has| |#1| (-558)))) (-1964 (($ $) 144 (|has| |#1| (-558)))) (-2004 (($ $) 164 (|has| |#1| (-558)))) (-1955 (($ $) 140 (|has| |#1| (-558)))) (-2811 (($ $) 175 (|has| |#1| (-558)))) (-1889 (($ $ (-568)) NIL (-2199 (|has| |#1| (-478)) (|has| |#1| (-558)))) (($ $ (-763)) NIL (-2199 (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))) (|has| |#1| (-1102)))) (($ $ (-917)) NIL (-2199 (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))) (|has| |#1| (-1102))))) (-3058 (($) 20 (-2199 (|has| |#1| (-25)) (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047)))) CONST)) (-1826 (($ $) 226 (|has| |#1| (-558)))) (-1557 (($) 22 (-2199 (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))) (|has| |#1| (-1102))) CONST)) (-2209 (($ $) 177 (|has| |#1| (-558))) (($ $ $) 179 (|has| |#1| (-558)))) (-4366 (($ $) 224 (|has| |#1| (-558)))) (-3192 (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-1047))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-1047))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-1047))) (($ $ (-1161)) NIL (|has| |#1| (-1047)))) (-2830 (($ $) 228 (|has| |#1| (-558)))) (-2768 (($ $ $) 181 (|has| |#1| (-558)))) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 76)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 75)) (-1781 (($ (-1113 |#1| (-607 $)) (-1113 |#1| (-607 $))) 93 (|has| |#1| (-558))) (($ $ $) 42 (-2199 (|has| |#1| (-478)) (|has| |#1| (-558))))) (-1775 (($ $ $) 40 (-2199 (|has| |#1| (-21)) (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))))) (($ $) 29 (-2199 (|has| |#1| (-21)) (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047)))))) (-1769 (($ $ $) 38 (-2199 (|has| |#1| (-25)) (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047)))))) (** (($ $ $) 61 (|has| |#1| (-558))) (($ $ (-409 (-568))) 300 (|has| |#1| (-558))) (($ $ (-568)) 71 (-2199 (|has| |#1| (-478)) (|has| |#1| (-558)))) (($ $ (-763)) 68 (-2199 (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))) (|has| |#1| (-1102)))) (($ $ (-917)) 73 (-2199 (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))) (|has| |#1| (-1102))))) (* (($ (-409 (-568)) $) NIL (|has| |#1| (-558))) (($ $ (-409 (-568))) NIL (|has| |#1| (-558))) (($ |#1| $) NIL (|has| |#1| (-172))) (($ $ |#1|) NIL (|has| |#1| (-172))) (($ $ $) 36 (-2199 (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))) (|has| |#1| (-1102)))) (($ (-568) $) 32 (-2199 (|has| |#1| (-21)) (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))))) (($ (-763) $) NIL (-2199 (|has| |#1| (-25)) (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))))) (($ (-917) $) NIL (-2199 (|has| |#1| (-25)) (-12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))))))) 
+(((-310 |#1|) (-13 (-432 |#1|) (-10 -8 (IF (|has| |#1| (-558)) (PROGN (-6 (-29 |#1|)) (-6 (-1181)) (-6 (-161)) (-6 (-620)) (-6 (-1124)) (-15 -3094 ($ $)) (-15 -1762 ((-121) $)) (-15 -3972 ($ $ (-568))) (IF (|has| |#1| (-453)) (PROGN (-15 -2795 ((-420 (-1157 $)) (-1157 $))) (-15 -3863 ((-420 (-1157 $)) (-1157 $)))) |noBranch|) (IF (|has| |#1| (-1037 (-568))) (-6 (-1037 (-53))) |noBranch|)) |noBranch|))) (-842)) (T -310)) 
+((-3094 (*1 *1 *1) (-12 (-5 *1 (-310 *2)) (-4 *2 (-558)) (-4 *2 (-842)))) (-1762 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-310 *3)) (-4 *3 (-558)) (-4 *3 (-842)))) (-3972 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-310 *3)) (-4 *3 (-558)) (-4 *3 (-842)))) (-2795 (*1 *2 *3) (-12 (-5 *2 (-420 (-1157 *1))) (-5 *1 (-310 *4)) (-5 *3 (-1157 *1)) (-4 *4 (-453)) (-4 *4 (-558)) (-4 *4 (-842)))) (-3863 (*1 *2 *3) (-12 (-5 *2 (-420 (-1157 *1))) (-5 *1 (-310 *4)) (-5 *3 (-1157 *1)) (-4 *4 (-453)) (-4 *4 (-558)) (-4 *4 (-842))))) 
+(-13 (-432 |#1|) (-10 -8 (IF (|has| |#1| (-558)) (PROGN (-6 (-29 |#1|)) (-6 (-1181)) (-6 (-161)) (-6 (-620)) (-6 (-1124)) (-15 -3094 ($ $)) (-15 -1762 ((-121) $)) (-15 -3972 ($ $ (-568))) (IF (|has| |#1| (-453)) (PROGN (-15 -2795 ((-420 (-1157 $)) (-1157 $))) (-15 -3863 ((-420 (-1157 $)) (-1157 $)))) |noBranch|) (IF (|has| |#1| (-1037 (-568))) (-6 (-1037 (-53))) |noBranch|)) |noBranch|))) 
+((-2873 (((-57) |#2| (-123) (-288 |#2|) (-634 |#2|)) 86) (((-57) |#2| (-123) (-288 |#2|) (-288 |#2|)) 82) (((-57) |#2| (-123) (-288 |#2|) |#2|) 84) (((-57) (-288 |#2|) (-123) (-288 |#2|) |#2|) 85) (((-57) (-634 |#2|) (-634 (-123)) (-288 |#2|) (-634 (-288 |#2|))) 78) (((-57) (-634 |#2|) (-634 (-123)) (-288 |#2|) (-634 |#2|)) 80) (((-57) (-634 (-288 |#2|)) (-634 (-123)) (-288 |#2|) (-634 |#2|)) 81) (((-57) (-634 (-288 |#2|)) (-634 (-123)) (-288 |#2|) (-634 (-288 |#2|))) 79) (((-57) (-288 |#2|) (-123) (-288 |#2|) (-634 |#2|)) 87) (((-57) (-288 |#2|) (-123) (-288 |#2|) (-288 |#2|)) 83))) 
+(((-311 |#1| |#2|) (-10 -7 (-15 -2873 ((-57) (-288 |#2|) (-123) (-288 |#2|) (-288 |#2|))) (-15 -2873 ((-57) (-288 |#2|) (-123) (-288 |#2|) (-634 |#2|))) (-15 -2873 ((-57) (-634 (-288 |#2|)) (-634 (-123)) (-288 |#2|) (-634 (-288 |#2|)))) (-15 -2873 ((-57) (-634 (-288 |#2|)) (-634 (-123)) (-288 |#2|) (-634 |#2|))) (-15 -2873 ((-57) (-634 |#2|) (-634 (-123)) (-288 |#2|) (-634 |#2|))) (-15 -2873 ((-57) (-634 |#2|) (-634 (-123)) (-288 |#2|) (-634 (-288 |#2|)))) (-15 -2873 ((-57) (-288 |#2|) (-123) (-288 |#2|) |#2|)) (-15 -2873 ((-57) |#2| (-123) (-288 |#2|) |#2|)) (-15 -2873 ((-57) |#2| (-123) (-288 |#2|) (-288 |#2|))) (-15 -2873 ((-57) |#2| (-123) (-288 |#2|) (-634 |#2|)))) (-13 (-842) (-558) (-609 (-541))) (-432 |#1|)) (T -311)) 
+((-2873 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-123)) (-5 *5 (-288 *3)) (-5 *6 (-634 *3)) (-4 *3 (-432 *7)) (-4 *7 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *7 *3)))) (-2873 (*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-123)) (-5 *5 (-288 *3)) (-4 *3 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *3)))) (-2873 (*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-123)) (-5 *5 (-288 *3)) (-4 *3 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *3)))) (-2873 (*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-288 *5)) (-5 *4 (-123)) (-4 *5 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *5)))) (-2873 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 (-123))) (-5 *6 (-634 (-288 *8))) (-4 *8 (-432 *7)) (-5 *5 (-288 *8)) (-4 *7 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *7 *8)))) (-2873 (*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-634 *7)) (-5 *4 (-634 (-123))) (-5 *5 (-288 *7)) (-4 *7 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *7)))) (-2873 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-634 (-288 *8))) (-5 *4 (-634 (-123))) (-5 *5 (-288 *8)) (-5 *6 (-634 *8)) (-4 *8 (-432 *7)) (-4 *7 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *7 *8)))) (-2873 (*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-634 (-288 *7))) (-5 *4 (-634 (-123))) (-5 *5 (-288 *7)) (-4 *7 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *7)))) (-2873 (*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-288 *7)) (-5 *4 (-123)) (-5 *5 (-634 *7)) (-4 *7 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *7)))) (-2873 (*1 *2 *3 *4 *3 *3) (-12 (-5 *3 (-288 *6)) (-5 *4 (-123)) (-4 *6 (-432 *5)) (-4 *5 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *5 *6))))) 
+(-10 -7 (-15 -2873 ((-57) (-288 |#2|) (-123) (-288 |#2|) (-288 |#2|))) (-15 -2873 ((-57) (-288 |#2|) (-123) (-288 |#2|) (-634 |#2|))) (-15 -2873 ((-57) (-634 (-288 |#2|)) (-634 (-123)) (-288 |#2|) (-634 (-288 |#2|)))) (-15 -2873 ((-57) (-634 (-288 |#2|)) (-634 (-123)) (-288 |#2|) (-634 |#2|))) (-15 -2873 ((-57) (-634 |#2|) (-634 (-123)) (-288 |#2|) (-634 |#2|))) (-15 -2873 ((-57) (-634 |#2|) (-634 (-123)) (-288 |#2|) (-634 (-288 |#2|)))) (-15 -2873 ((-57) (-288 |#2|) (-123) (-288 |#2|) |#2|)) (-15 -2873 ((-57) |#2| (-123) (-288 |#2|) |#2|)) (-15 -2873 ((-57) |#2| (-123) (-288 |#2|) (-288 |#2|))) (-15 -2873 ((-57) |#2| (-123) (-288 |#2|) (-634 |#2|)))) 
+((-2873 ((|#3| |#2| (-123) (-1161) (-634 |#2|)) 53)) (-4282 ((|#2| |#2| (-123) (-1161)) 30))) 
+(((-312 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2873 (|#3| |#2| (-123) (-1161) (-634 |#2|))) (-15 -4282 (|#2| |#2| (-123) (-1161)))) (-13 (-842) (-558) (-609 (-541))) (-432 |#1|) (-1234 |#2|) (-1234 (-1155 |#2|))) (T -312)) 
+((-4282 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-123)) (-5 *4 (-1161)) (-4 *5 (-13 (-842) (-558) (-609 (-541)))) (-4 *2 (-432 *5)) (-5 *1 (-312 *5 *2 *6 *7)) (-4 *6 (-1234 *2)) (-4 *7 (-1234 (-1155 *2))))) (-2873 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-123)) (-5 *5 (-1161)) (-5 *6 (-634 *3)) (-4 *3 (-432 *7)) (-4 *7 (-13 (-842) (-558) (-609 (-541)))) (-4 *2 (-1234 *3)) (-5 *1 (-312 *7 *3 *2 *8)) (-4 *8 (-1234 (-1155 *3)))))) 
+(-10 -7 (-15 -2873 (|#3| |#2| (-123) (-1161) (-634 |#2|))) (-15 -4282 (|#2| |#2| (-123) (-1161)))) 
+((-3471 (((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-215) (-568) (-1143)) 45) (((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-215) (-568)) 46) (((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-1 (-215) (-215)) (-568) (-1143)) 42) (((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-1 (-215) (-215)) (-568)) 43)) (-4435 (((-1 (-215) (-215)) (-215)) 44))) 
+(((-313) (-10 -7 (-15 -4435 ((-1 (-215) (-215)) (-215))) (-15 -3471 ((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-1 (-215) (-215)) (-568))) (-15 -3471 ((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-1 (-215) (-215)) (-568) (-1143))) (-15 -3471 ((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-215) (-568))) (-15 -3471 ((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-215) (-568) (-1143))))) (T -313)) 
+((-3471 (*1 *2 *3 *3 *3 *4 *5 *6 *7 *8) (-12 (-5 *3 (-310 (-568))) (-5 *4 (-1 (-215) (-215))) (-5 *5 (-1084 (-215))) (-5 *6 (-215)) (-5 *7 (-568)) (-5 *8 (-1143)) (-5 *2 (-1191 (-926))) (-5 *1 (-313)))) (-3471 (*1 *2 *3 *3 *3 *4 *5 *6 *7) (-12 (-5 *3 (-310 (-568))) (-5 *4 (-1 (-215) (-215))) (-5 *5 (-1084 (-215))) (-5 *6 (-215)) (-5 *7 (-568)) (-5 *2 (-1191 (-926))) (-5 *1 (-313)))) (-3471 (*1 *2 *3 *3 *3 *4 *5 *4 *6 *7) (-12 (-5 *3 (-310 (-568))) (-5 *4 (-1 (-215) (-215))) (-5 *5 (-1084 (-215))) (-5 *6 (-568)) (-5 *7 (-1143)) (-5 *2 (-1191 (-926))) (-5 *1 (-313)))) (-3471 (*1 *2 *3 *3 *3 *4 *5 *4 *6) (-12 (-5 *3 (-310 (-568))) (-5 *4 (-1 (-215) (-215))) (-5 *5 (-1084 (-215))) (-5 *6 (-568)) (-5 *2 (-1191 (-926))) (-5 *1 (-313)))) (-4435 (*1 *2 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *1 (-313)) (-5 *3 (-215))))) 
+(-10 -7 (-15 -4435 ((-1 (-215) (-215)) (-215))) (-15 -3471 ((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-1 (-215) (-215)) (-568))) (-15 -3471 ((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-1 (-215) (-215)) (-568) (-1143))) (-15 -3471 ((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-215) (-568))) (-15 -3471 ((-1191 (-926)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-215) (-568) (-1143)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 24)) (-2057 (((-634 (-1075)) $) NIL)) (-3325 (((-1161) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-4179 (($ $ (-409 (-568))) NIL) (($ $ (-409 (-568)) (-409 (-568))) NIL)) (-2013 (((-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|))) $) 19)) (-1984 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1935 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL (|has| |#1| (-365)))) (-3498 (((-420 $) $) NIL (|has| |#1| (-365)))) (-1904 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2589 (((-121) $ $) NIL (|has| |#1| (-365)))) (-1976 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2788 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2512 (($ (-763) (-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|)))) NIL)) (-1992 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1943 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4490 (($) NIL T CONST)) (-2403 (($ $ $) NIL (|has| |#1| (-365)))) (-2116 (($ $) 30)) (-2902 (((-3 $ "failed") $) NIL)) (-2414 (($ $ $) NIL (|has| |#1| (-365)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-2197 (((-121) $) NIL (|has| |#1| (-365)))) (-1302 (((-121) $) NIL)) (-1899 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1844 (((-409 (-568)) $) NIL) (((-409 (-568)) $ (-409 (-568))) 15)) (-1598 (((-121) $) NIL)) (-1550 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4168 (($ $ (-917)) NIL) (($ $ (-409 (-568))) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| (-409 (-568))) NIL) (($ $ (-1075) (-409 (-568))) NIL) (($ $ (-634 (-1075)) (-634 (-409 (-568)))) NIL)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-4418 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-2498 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL (|has| |#1| (-365)))) (-1845 (($ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) NIL (-2199 (-12 (|has| |#1| (-15 -1845 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2057 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181)))))) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-365)))) (-2723 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-3850 (((-420 $) $) NIL (|has| |#1| (-365)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-365)))) (-2168 (($ $ (-409 (-568))) NIL)) (-2597 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-3635 (((-409 (-568)) $) 16)) (-3129 (($ (-1228 |#1| |#2| |#3|)) 11)) (-3483 (((-1228 |#1| |#2| |#3|) $) 12)) (-1894 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))))) (-1466 (((-763) $) NIL (|has| |#1| (-365)))) (-2781 ((|#1| $ (-409 (-568))) NIL) (($ $ $) NIL (|has| (-409 (-568)) (-1102)))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-365)))) (-4191 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (-1836 (((-409 (-568)) $) NIL)) (-1996 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1947 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1988 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1939 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1980 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2792 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2188 (($ $) 10)) (-2747 (((-850) $) 36) (($ (-568)) NIL) (($ |#1|) NIL (|has| |#1| (-172))) (($ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $) NIL (|has| |#1| (-558)))) (-2079 ((|#1| $ (-409 (-568))) 28)) (-3385 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-3425 (((-763)) NIL)) (-1374 ((|#1| $) NIL)) (-2008 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1959 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2000 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1951 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2016 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1968 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3999 ((|#1| $ (-409 (-568))) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))) (|has| |#1| (-15 -2747 (|#1| (-1161))))))) (-1439 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1972 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2012 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1964 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2004 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1955 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 26)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 31)) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
+(((-314 |#1| |#2| |#3|) (-13 (-1224 |#1|) (-787) (-10 -8 (-15 -3129 ($ (-1228 |#1| |#2| |#3|))) (-15 -3483 ((-1228 |#1| |#2| |#3|) $)) (-15 -3635 ((-409 (-568)) $)))) (-13 (-365) (-842)) (-1161) |#1|) (T -314)) 
+((-3129 (*1 *1 *2) (-12 (-5 *2 (-1228 *3 *4 *5)) (-4 *3 (-13 (-365) (-842))) (-14 *4 (-1161)) (-14 *5 *3) (-5 *1 (-314 *3 *4 *5)))) (-3483 (*1 *2 *1) (-12 (-5 *2 (-1228 *3 *4 *5)) (-5 *1 (-314 *3 *4 *5)) (-4 *3 (-13 (-365) (-842))) (-14 *4 (-1161)) (-14 *5 *3))) (-3635 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-314 *3 *4 *5)) (-4 *3 (-13 (-365) (-842))) (-14 *4 (-1161)) (-14 *5 *3)))) 
+(-13 (-1224 |#1|) (-787) (-10 -8 (-15 -3129 ($ (-1228 |#1| |#2| |#3|))) (-15 -3483 ((-1228 |#1| |#2| |#3|) $)) (-15 -3635 ((-409 (-568)) $)))) 
+((-4336 (((-420 (-1157 |#1|)) (-1157 |#1|) |#1|) 15)) (-3850 (((-420 (-1157 |#1|)) (-1157 |#1|) |#1|) 24))) 
+(((-315 |#1|) (-10 -7 (-15 -3850 ((-420 (-1157 |#1|)) (-1157 |#1|) |#1|)) (-15 -4336 ((-420 (-1157 |#1|)) (-1157 |#1|) |#1|))) (-854)) (T -315)) 
+((-4336 (*1 *2 *3 *4) (-12 (-4 *4 (-854)) (-5 *2 (-420 (-1157 *4))) (-5 *1 (-315 *4)) (-5 *3 (-1157 *4)))) (-3850 (*1 *2 *3 *4) (-12 (-4 *4 (-854)) (-5 *2 (-420 (-1157 *4))) (-5 *1 (-315 *4)) (-5 *3 (-1157 *4))))) 
+(-10 -7 (-15 -3850 ((-420 (-1157 |#1|)) (-1157 |#1|) |#1|)) (-15 -4336 ((-420 (-1157 |#1|)) (-1157 |#1|) |#1|))) 
+((-1550 (((-2 (|:| -3483 (-763)) (|:| -2350 |#1|) (|:| |radicand| (-634 |#1|))) (-420 |#1|) (-763)) 24)) (-4418 (((-634 (-2 (|:| -2350 (-763)) (|:| |logand| |#1|))) (-420 |#1|)) 28))) 
+(((-316 |#1|) (-10 -7 (-15 -1550 ((-2 (|:| -3483 (-763)) (|:| -2350 |#1|) (|:| |radicand| (-634 |#1|))) (-420 |#1|) (-763))) (-15 -4418 ((-634 (-2 (|:| -2350 (-763)) (|:| |logand| |#1|))) (-420 |#1|)))) (-558)) (T -316)) 
+((-4418 (*1 *2 *3) (-12 (-5 *3 (-420 *4)) (-4 *4 (-558)) (-5 *2 (-634 (-2 (|:| -2350 (-763)) (|:| |logand| *4)))) (-5 *1 (-316 *4)))) (-1550 (*1 *2 *3 *4) (-12 (-5 *3 (-420 *5)) (-4 *5 (-558)) (-5 *2 (-2 (|:| -3483 (-763)) (|:| -2350 *5) (|:| |radicand| (-634 *5)))) (-5 *1 (-316 *5)) (-5 *4 (-763))))) 
+(-10 -7 (-15 -1550 ((-2 (|:| -3483 (-763)) (|:| -2350 |#1|) (|:| |radicand| (-634 |#1|))) (-420 |#1|) (-763))) (-15 -4418 ((-634 (-2 (|:| -2350 (-763)) (|:| |logand| |#1|))) (-420 |#1|)))) 
+((-4336 (((-420 (-1157 |#1|)) (-1157 |#1|) |#1|) 15)) (-3850 (((-420 (-1157 |#1|)) (-1157 |#1|) |#1|) 24))) 
+(((-317 |#1|) (-10 -7 (-15 -3850 ((-420 (-1157 |#1|)) (-1157 |#1|) |#1|)) (-15 -4336 ((-420 (-1157 |#1|)) (-1157 |#1|) |#1|))) (-859)) (T -317)) 
+((-4336 (*1 *2 *3 *4) (-12 (-4 *4 (-859)) (-5 *2 (-420 (-1157 *4))) (-5 *1 (-317 *4)) (-5 *3 (-1157 *4)))) (-3850 (*1 *2 *3 *4) (-12 (-4 *4 (-859)) (-5 *2 (-420 (-1157 *4))) (-5 *1 (-317 *4)) (-5 *3 (-1157 *4))))) 
+(-10 -7 (-15 -3850 ((-420 (-1157 |#1|)) (-1157 |#1|) |#1|)) (-15 -4336 ((-420 (-1157 |#1|)) (-1157 |#1|) |#1|))) 
+((-2057 (((-634 |#2|) (-1157 |#4|)) 43)) (-1541 ((|#3| (-568)) 46)) (-2231 (((-1157 |#4|) (-1157 |#3|)) 30)) (-1459 (((-1157 |#4|) (-1157 |#4|) (-568)) 55)) (-4099 (((-1157 |#3|) (-1157 |#4|)) 21)) (-1836 (((-634 (-763)) (-1157 |#4|) (-634 |#2|)) 40)) (-3714 (((-1157 |#3|) (-1157 |#4|) (-634 |#2|) (-634 |#3|)) 35))) 
+(((-318 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3714 ((-1157 |#3|) (-1157 |#4|) (-634 |#2|) (-634 |#3|))) (-15 -1836 ((-634 (-763)) (-1157 |#4|) (-634 |#2|))) (-15 -2057 ((-634 |#2|) (-1157 |#4|))) (-15 -4099 ((-1157 |#3|) (-1157 |#4|))) (-15 -2231 ((-1157 |#4|) (-1157 |#3|))) (-15 -1459 ((-1157 |#4|) (-1157 |#4|) (-568))) (-15 -1541 (|#3| (-568)))) (-788) (-842) (-1047) (-950 |#3| |#1| |#2|)) (T -318)) 
+((-1541 (*1 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1047)) (-5 *1 (-318 *4 *5 *2 *6)) (-4 *6 (-950 *2 *4 *5)))) (-1459 (*1 *2 *2 *3) (-12 (-5 *2 (-1157 *7)) (-5 *3 (-568)) (-4 *7 (-950 *6 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-5 *1 (-318 *4 *5 *6 *7)))) (-2231 (*1 *2 *3) (-12 (-5 *3 (-1157 *6)) (-4 *6 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-1157 *7)) (-5 *1 (-318 *4 *5 *6 *7)) (-4 *7 (-950 *6 *4 *5)))) (-4099 (*1 *2 *3) (-12 (-5 *3 (-1157 *7)) (-4 *7 (-950 *6 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-5 *2 (-1157 *6)) (-5 *1 (-318 *4 *5 *6 *7)))) (-2057 (*1 *2 *3) (-12 (-5 *3 (-1157 *7)) (-4 *7 (-950 *6 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-5 *2 (-634 *5)) (-5 *1 (-318 *4 *5 *6 *7)))) (-1836 (*1 *2 *3 *4) (-12 (-5 *3 (-1157 *8)) (-5 *4 (-634 *6)) (-4 *6 (-842)) (-4 *8 (-950 *7 *5 *6)) (-4 *5 (-788)) (-4 *7 (-1047)) (-5 *2 (-634 (-763))) (-5 *1 (-318 *5 *6 *7 *8)))) (-3714 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1157 *9)) (-5 *4 (-634 *7)) (-5 *5 (-634 *8)) (-4 *7 (-842)) (-4 *8 (-1047)) (-4 *9 (-950 *8 *6 *7)) (-4 *6 (-788)) (-5 *2 (-1157 *8)) (-5 *1 (-318 *6 *7 *8 *9))))) 
+(-10 -7 (-15 -3714 ((-1157 |#3|) (-1157 |#4|) (-634 |#2|) (-634 |#3|))) (-15 -1836 ((-634 (-763)) (-1157 |#4|) (-634 |#2|))) (-15 -2057 ((-634 |#2|) (-1157 |#4|))) (-15 -4099 ((-1157 |#3|) (-1157 |#4|))) (-15 -2231 ((-1157 |#4|) (-1157 |#3|))) (-15 -1459 ((-1157 |#4|) (-1157 |#4|) (-568))) (-15 -1541 (|#3| (-568)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 14)) (-2013 (((-634 (-2 (|:| |gen| |#1|) (|:| -1894 (-568)))) $) 18)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3986 (((-763) $) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) NIL)) (-2857 ((|#1| $) NIL)) (-4167 ((|#1| $ (-568)) NIL)) (-2313 (((-568) $ (-568)) NIL)) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-3177 (($ (-1 |#1| |#1|) $) NIL)) (-2847 (($ (-1 (-568) (-568)) $) 10)) (-1893 (((-1143) $) NIL)) (-3933 (($ $ $) NIL (|has| (-568) (-787)))) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL) (($ |#1|) NIL)) (-2079 (((-568) |#1| $) NIL)) (-3058 (($) 15 T CONST)) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) 21 (|has| |#1| (-842)))) (-1775 (($ $) 11) (($ $ $) 20)) (-1769 (($ $ $) NIL) (($ |#1| $) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ (-568)) NIL) (($ (-568) |#1|) 19))) 
 (((-319 |#1|) (-13 (-21) (-707 (-568)) (-320 |#1| (-568)) (-10 -7 (IF (|has| |#1| (-842)) (-6 (-842)) |noBranch|))) (-1090)) (T -319)) 
 NIL 
 (-13 (-21) (-707 (-568)) (-320 |#1| (-568)) (-10 -7 (IF (|has| |#1| (-842)) (-6 (-842)) |noBranch|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-2583 (((-634 (-2 (|:| |gen| |#1|) (|:| -1892 |#2|))) $) 26)) (-3134 (((-3 $ "failed") $ $) 18)) (-3983 (((-763) $) 27)) (-2671 (($) 16 T CONST)) (-3666 (((-3 |#1| "failed") $) 31)) (-2854 ((|#1| $) 30)) (-2882 ((|#1| $ (-568)) 24)) (-1444 ((|#2| $ (-568)) 25)) (-2096 (($ (-1 |#1| |#1|) $) 21)) (-2907 (($ (-1 |#2| |#2|) $) 22)) (-4487 (((-1143) $) 9)) (-1764 (($ $ $) 20 (|has| |#2| (-787)))) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11) (($ |#1|) 32)) (-2604 ((|#2| |#1| $) 23)) (-3056 (($) 17 T CONST)) (-1717 (((-121) $ $) 6)) (-1767 (($ $ $) 13) (($ |#1| $) 29)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ |#2| |#1|) 28))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2013 (((-634 (-2 (|:| |gen| |#1|) (|:| -1894 |#2|))) $) 26)) (-2689 (((-3 $ "failed") $ $) 18)) (-3986 (((-763) $) 27)) (-4490 (($) 16 T CONST)) (-3668 (((-3 |#1| "failed") $) 31)) (-2857 ((|#1| $) 30)) (-4167 ((|#1| $ (-568)) 24)) (-2313 ((|#2| $ (-568)) 25)) (-3177 (($ (-1 |#1| |#1|) $) 21)) (-2847 (($ (-1 |#2| |#2|) $) 22)) (-1893 (((-1143) $) 9)) (-3933 (($ $ $) 20 (|has| |#2| (-787)))) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11) (($ |#1|) 32)) (-2079 ((|#2| |#1| $) 23)) (-3058 (($) 17 T CONST)) (-1719 (((-121) $ $) 6)) (-1769 (($ $ $) 13) (($ |#1| $) 29)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ |#2| |#1|) 28))) 
 (((-320 |#1| |#2|) (-1275) (-1090) (-137)) (T -320)) 
-((-1767 (*1 *1 *2 *1) (-12 (-4 *1 (-320 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-137)))) (* (*1 *1 *2 *3) (-12 (-4 *1 (-320 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-137)))) (-3983 (*1 *2 *1) (-12 (-4 *1 (-320 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-137)) (-5 *2 (-763)))) (-2583 (*1 *2 *1) (-12 (-4 *1 (-320 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-137)) (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1892 *4)))))) (-1444 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-320 *4 *2)) (-4 *4 (-1090)) (-4 *2 (-137)))) (-2882 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-320 *2 *4)) (-4 *4 (-137)) (-4 *2 (-1090)))) (-2604 (*1 *2 *3 *1) (-12 (-4 *1 (-320 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-137)))) (-2907 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-320 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-137)))) (-2096 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-320 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-137)))) (-1764 (*1 *1 *1 *1) (-12 (-4 *1 (-320 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-137)) (-4 *3 (-787))))) 
-(-13 (-137) (-1037 |t#1|) (-10 -8 (-15 -1767 ($ |t#1| $)) (-15 * ($ |t#2| |t#1|)) (-15 -3983 ((-763) $)) (-15 -2583 ((-634 (-2 (|:| |gen| |t#1|) (|:| -1892 |t#2|))) $)) (-15 -1444 (|t#2| $ (-568))) (-15 -2882 (|t#1| $ (-568))) (-15 -2604 (|t#2| |t#1| $)) (-15 -2907 ($ (-1 |t#2| |t#2|) $)) (-15 -2096 ($ (-1 |t#1| |t#1|) $)) (IF (|has| |t#2| (-787)) (-15 -1764 ($ $ $)) |noBranch|))) 
+((-1769 (*1 *1 *2 *1) (-12 (-4 *1 (-320 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-137)))) (* (*1 *1 *2 *3) (-12 (-4 *1 (-320 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-137)))) (-3986 (*1 *2 *1) (-12 (-4 *1 (-320 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-137)) (-5 *2 (-763)))) (-2013 (*1 *2 *1) (-12 (-4 *1 (-320 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-137)) (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1894 *4)))))) (-2313 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-320 *4 *2)) (-4 *4 (-1090)) (-4 *2 (-137)))) (-4167 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-320 *2 *4)) (-4 *4 (-137)) (-4 *2 (-1090)))) (-2079 (*1 *2 *3 *1) (-12 (-4 *1 (-320 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-137)))) (-2847 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-320 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-137)))) (-3177 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-320 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-137)))) (-3933 (*1 *1 *1 *1) (-12 (-4 *1 (-320 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-137)) (-4 *3 (-787))))) 
+(-13 (-137) (-1037 |t#1|) (-10 -8 (-15 -1769 ($ |t#1| $)) (-15 * ($ |t#2| |t#1|)) (-15 -3986 ((-763) $)) (-15 -2013 ((-634 (-2 (|:| |gen| |t#1|) (|:| -1894 |t#2|))) $)) (-15 -2313 (|t#2| $ (-568))) (-15 -4167 (|t#1| $ (-568))) (-15 -2079 (|t#2| |t#1| $)) (-15 -2847 ($ (-1 |t#2| |t#2|) $)) (-15 -3177 ($ (-1 |t#1| |t#1|) $)) (IF (|has| |t#2| (-787)) (-15 -3933 ($ $ $)) |noBranch|))) 
 (((-23) . T) ((-25) . T) ((-105) . T) ((-137) . T) ((-608 (-850)) . T) ((-1037 |#1|) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2583 (((-634 (-2 (|:| |gen| |#1|) (|:| -1892 (-763)))) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-3983 (((-763) $) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) NIL)) (-2854 ((|#1| $) NIL)) (-2882 ((|#1| $ (-568)) NIL)) (-1444 (((-763) $ (-568)) NIL)) (-2096 (($ (-1 |#1| |#1|) $) NIL)) (-2907 (($ (-1 (-763) (-763)) $) NIL)) (-4487 (((-1143) $) NIL)) (-1764 (($ $ $) NIL (|has| (-763) (-787)))) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL) (($ |#1|) NIL)) (-2604 (((-763) |#1| $) NIL)) (-3056 (($) NIL T CONST)) (-1717 (((-121) $ $) NIL)) (-1767 (($ $ $) NIL) (($ |#1| $) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-763) |#1|) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2013 (((-634 (-2 (|:| |gen| |#1|) (|:| -1894 (-763)))) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3986 (((-763) $) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) NIL)) (-2857 ((|#1| $) NIL)) (-4167 ((|#1| $ (-568)) NIL)) (-2313 (((-763) $ (-568)) NIL)) (-3177 (($ (-1 |#1| |#1|) $) NIL)) (-2847 (($ (-1 (-763) (-763)) $) NIL)) (-1893 (((-1143) $) NIL)) (-3933 (($ $ $) NIL (|has| (-763) (-787)))) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL) (($ |#1|) NIL)) (-2079 (((-763) |#1| $) NIL)) (-3058 (($) NIL T CONST)) (-1719 (((-121) $ $) NIL)) (-1769 (($ $ $) NIL) (($ |#1| $) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-763) |#1|) NIL))) 
 (((-321 |#1|) (-320 |#1| (-763)) (-1090)) (T -321)) 
 NIL 
 (-320 |#1| (-763)) 
-((-2795 ((|#5| (-1 |#4| |#2|) |#3|) 19))) 
-(((-322 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2795 (|#5| (-1 |#4| |#2|) |#3|))) (-787) (-1047) (-324 |#2| |#1|) (-1047) (-324 |#4| |#1|)) (T -322)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-4 *6 (-1047)) (-4 *7 (-1047)) (-4 *5 (-787)) (-4 *2 (-324 *7 *5)) (-5 *1 (-322 *5 *6 *4 *7 *2)) (-4 *4 (-324 *6 *5))))) 
-(-10 -7 (-15 -2795 (|#5| (-1 |#4| |#2|) |#3|))) 
-((-3250 (($ $) 52)) (-3088 (($ $ |#2| |#3| $) 14)) (-3842 (($ (-1 |#3| |#3|) $) 35)) (-2086 (((-121) $) 27)) (-2091 ((|#2| $) 29)) (-2595 (((-3 $ "failed") $ $) NIL) (((-3 $ "failed") $ |#2|) 45)) (-3367 ((|#2| $) 48)) (-1302 (((-634 |#2|) $) 38)) (-4171 (($ $ $ (-763)) 23)) (-1779 (($ $ |#2|) 42))) 
-(((-323 |#1| |#2| |#3|) (-10 -8 (-15 -3250 (|#1| |#1|)) (-15 -3367 (|#2| |#1|)) (-15 -2595 ((-3 |#1| "failed") |#1| |#2|)) (-15 -4171 (|#1| |#1| |#1| (-763))) (-15 -3088 (|#1| |#1| |#2| |#3| |#1|)) (-15 -3842 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -1302 ((-634 |#2|) |#1|)) (-15 -2091 (|#2| |#1|)) (-15 -2086 ((-121) |#1|)) (-15 -2595 ((-3 |#1| "failed") |#1| |#1|)) (-15 -1779 (|#1| |#1| |#2|))) (-324 |#2| |#3|) (-1047) (-787)) (T -323)) 
-NIL 
-(-10 -8 (-15 -3250 (|#1| |#1|)) (-15 -3367 (|#2| |#1|)) (-15 -2595 ((-3 |#1| "failed") |#1| |#2|)) (-15 -4171 (|#1| |#1| |#1| (-763))) (-15 -3088 (|#1| |#1| |#2| |#3| |#1|)) (-15 -3842 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -1302 ((-634 |#2|) |#1|)) (-15 -2091 (|#2| |#1|)) (-15 -2086 ((-121) |#1|)) (-15 -2595 ((-3 |#1| "failed") |#1| |#1|)) (-15 -1779 (|#1| |#1| |#2|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 50 (|has| |#1| (-558)))) (-2227 (($ $) 51 (|has| |#1| (-558)))) (-1573 (((-121) $) 53 (|has| |#1| (-558)))) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-3666 (((-3 (-568) "failed") $) 86 (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) 84 (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 83)) (-2854 (((-568) $) 87 (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) 85 (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) 82)) (-2114 (($ $) 59)) (-2925 (((-3 $ "failed") $) 33)) (-3250 (($ $) 71 (|has| |#1| (-453)))) (-3088 (($ $ |#1| |#2| $) 75)) (-2735 (((-121) $) 30)) (-4178 (((-763) $) 78)) (-3921 (((-121) $) 61)) (-2047 (($ |#1| |#2|) 60)) (-2144 ((|#2| $) 77)) (-3842 (($ (-1 |#2| |#2|) $) 76)) (-2795 (($ (-1 |#1| |#1|) $) 62)) (-2097 (($ $) 64)) (-2102 ((|#1| $) 65)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2086 (((-121) $) 81)) (-2091 ((|#1| $) 80)) (-2595 (((-3 $ "failed") $ $) 49 (|has| |#1| (-558))) (((-3 $ "failed") $ |#1|) 73 (|has| |#1| (-558)))) (-3206 ((|#2| $) 63)) (-3367 ((|#1| $) 72 (|has| |#1| (-453)))) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 48 (|has| |#1| (-558))) (($ |#1|) 46) (($ (-409 (-568))) 56 (-2198 (|has| |#1| (-1037 (-409 (-568)))) (|has| |#1| (-43 (-409 (-568))))))) (-1302 (((-634 |#1|) $) 79)) (-2604 ((|#1| $ |#2|) 58)) (-4371 (((-3 $ "failed") $) 47 (|has| |#1| (-148)))) (-4078 (((-763)) 28)) (-4171 (($ $ $ (-763)) 74 (|has| |#1| (-172)))) (-1826 (((-121) $ $) 52 (|has| |#1| (-558)))) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1779 (($ $ |#1|) 57 (|has| |#1| (-365)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-409 (-568)) $) 55 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 54 (|has| |#1| (-43 (-409 (-568))))))) 
+((-2797 ((|#5| (-1 |#4| |#2|) |#3|) 19))) 
+(((-322 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2797 (|#5| (-1 |#4| |#2|) |#3|))) (-787) (-1047) (-324 |#2| |#1|) (-1047) (-324 |#4| |#1|)) (T -322)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-4 *6 (-1047)) (-4 *7 (-1047)) (-4 *5 (-787)) (-4 *2 (-324 *7 *5)) (-5 *1 (-322 *5 *6 *4 *7 *2)) (-4 *4 (-324 *6 *5))))) 
+(-10 -7 (-15 -2797 (|#5| (-1 |#4| |#2|) |#3|))) 
+((-1998 (($ $) 52)) (-2453 (($ $ |#2| |#3| $) 14)) (-1865 (($ (-1 |#3| |#3|) $) 35)) (-2088 (((-121) $) 27)) (-2093 ((|#2| $) 29)) (-2597 (((-3 $ "failed") $ $) NIL) (((-3 $ "failed") $ |#2|) 45)) (-1364 ((|#2| $) 48)) (-3304 (((-634 |#2|) $) 38)) (-3925 (($ $ $ (-763)) 23)) (-1781 (($ $ |#2|) 42))) 
+(((-323 |#1| |#2| |#3|) (-10 -8 (-15 -1998 (|#1| |#1|)) (-15 -1364 (|#2| |#1|)) (-15 -2597 ((-3 |#1| "failed") |#1| |#2|)) (-15 -3925 (|#1| |#1| |#1| (-763))) (-15 -2453 (|#1| |#1| |#2| |#3| |#1|)) (-15 -1865 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -3304 ((-634 |#2|) |#1|)) (-15 -2093 (|#2| |#1|)) (-15 -2088 ((-121) |#1|)) (-15 -2597 ((-3 |#1| "failed") |#1| |#1|)) (-15 -1781 (|#1| |#1| |#2|))) (-324 |#2| |#3|) (-1047) (-787)) (T -323)) 
+NIL 
+(-10 -8 (-15 -1998 (|#1| |#1|)) (-15 -1364 (|#2| |#1|)) (-15 -2597 ((-3 |#1| "failed") |#1| |#2|)) (-15 -3925 (|#1| |#1| |#1| (-763))) (-15 -2453 (|#1| |#1| |#2| |#3| |#1|)) (-15 -1865 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -3304 ((-634 |#2|) |#1|)) (-15 -2093 (|#2| |#1|)) (-15 -2088 ((-121) |#1|)) (-15 -2597 ((-3 |#1| "failed") |#1| |#1|)) (-15 -1781 (|#1| |#1| |#2|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 50 (|has| |#1| (-558)))) (-3661 (($ $) 51 (|has| |#1| (-558)))) (-4426 (((-121) $) 53 (|has| |#1| (-558)))) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-3668 (((-3 (-568) "failed") $) 86 (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) 84 (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 83)) (-2857 (((-568) $) 87 (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) 85 (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) 82)) (-2116 (($ $) 59)) (-2902 (((-3 $ "failed") $) 33)) (-1998 (($ $) 71 (|has| |#1| (-453)))) (-2453 (($ $ |#1| |#2| $) 75)) (-1598 (((-121) $) 30)) (-3971 (((-763) $) 78)) (-2171 (((-121) $) 61)) (-2049 (($ |#1| |#2|) 60)) (-3524 ((|#2| $) 77)) (-1865 (($ (-1 |#2| |#2|) $) 76)) (-2797 (($ (-1 |#1| |#1|) $) 62)) (-2099 (($ $) 64)) (-2104 ((|#1| $) 65)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2088 (((-121) $) 81)) (-2093 ((|#1| $) 80)) (-2597 (((-3 $ "failed") $ $) 49 (|has| |#1| (-558))) (((-3 $ "failed") $ |#1|) 73 (|has| |#1| (-558)))) (-1836 ((|#2| $) 63)) (-1364 ((|#1| $) 72 (|has| |#1| (-453)))) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 48 (|has| |#1| (-558))) (($ |#1|) 46) (($ (-409 (-568))) 56 (-2199 (|has| |#1| (-1037 (-409 (-568)))) (|has| |#1| (-43 (-409 (-568))))))) (-3304 (((-634 |#1|) $) 79)) (-2079 ((|#1| $ |#2|) 58)) (-3385 (((-3 $ "failed") $) 47 (|has| |#1| (-148)))) (-3425 (((-763)) 28)) (-3925 (($ $ $ (-763)) 74 (|has| |#1| (-172)))) (-2273 (((-121) $ $) 52 (|has| |#1| (-558)))) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1781 (($ $ |#1|) 57 (|has| |#1| (-365)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-409 (-568)) $) 55 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 54 (|has| |#1| (-43 (-409 (-568))))))) 
 (((-324 |#1| |#2|) (-1275) (-1047) (-787)) (T -324)) 
-((-2086 (*1 *2 *1) (-12 (-4 *1 (-324 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-121)))) (-2091 (*1 *2 *1) (-12 (-4 *1 (-324 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047)))) (-1302 (*1 *2 *1) (-12 (-4 *1 (-324 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-634 *3)))) (-4178 (*1 *2 *1) (-12 (-4 *1 (-324 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-763)))) (-2144 (*1 *2 *1) (-12 (-4 *1 (-324 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787)))) (-3842 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-324 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)))) (-3088 (*1 *1 *1 *2 *3 *1) (-12 (-4 *1 (-324 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)))) (-4171 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-324 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-4 *3 (-172)))) (-2595 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-324 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)) (-4 *2 (-558)))) (-3367 (*1 *2 *1) (-12 (-4 *1 (-324 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047)) (-4 *2 (-453)))) (-3250 (*1 *1 *1) (-12 (-4 *1 (-324 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)) (-4 *2 (-453))))) 
-(-13 (-52 |t#1| |t#2|) (-413 |t#1|) (-10 -8 (-15 -2086 ((-121) $)) (-15 -2091 (|t#1| $)) (-15 -1302 ((-634 |t#1|) $)) (-15 -4178 ((-763) $)) (-15 -2144 (|t#2| $)) (-15 -3842 ($ (-1 |t#2| |t#2|) $)) (-15 -3088 ($ $ |t#1| |t#2| $)) (IF (|has| |t#1| (-172)) (-15 -4171 ($ $ $ (-763))) |noBranch|) (IF (|has| |t#1| (-558)) (-15 -2595 ((-3 $ "failed") $ |t#1|)) |noBranch|) (IF (|has| |t#1| (-453)) (PROGN (-15 -3367 (|t#1| $)) (-15 -3250 ($ $))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| |#2|) . T) ((-25) . T) ((-43 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) |has| |#1| (-558)) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2198 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2198 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-285) |has| |#1| (-558)) ((-413 |#1|) . T) ((-558) |has| |#1| (-558)) ((-637 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) |has| |#1| (-558)) ((-716) . T) ((-1037 (-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 |#1|) . T) ((-1053 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-1053 |#1|) . T) ((-1053 $) -2198 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-2016 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-842)))) (-3908 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4520))) (($ $) NIL (-12 (|has| $ (-6 -4520)) (|has| |#1| (-842))))) (-3644 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-842)))) (-2510 (((-121) $ (-763)) NIL)) (-3535 (((-121) (-121)) NIL)) (-2436 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4520))) ((|#1| $ (-1210 (-568)) |#1|) NIL (|has| $ (-6 -4520)))) (-3507 (($ (-1 (-121) |#1|) $) NIL)) (-2801 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-2671 (($) NIL T CONST)) (-1578 (($ $) NIL (|has| $ (-6 -4520)))) (-3943 (($ $) NIL)) (-3369 (($ $) NIL (|has| |#1| (-1090)))) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3405 (($ |#1| $) NIL (|has| |#1| (-1090))) (($ (-1 (-121) |#1|) $) NIL)) (-4328 (($ |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4519)))) (-3989 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-568)) NIL)) (-2764 (((-568) (-1 (-121) |#1|) $) NIL) (((-568) |#1| $) NIL (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) NIL (|has| |#1| (-1090)))) (-3428 (($ $ (-568)) NIL)) (-3575 (((-763) $) NIL)) (-4360 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-1849 (($ (-763) |#1|) NIL)) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) NIL (|has| (-568) (-842)))) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-3349 (($ $ $) NIL (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $ $) NIL)) (-1347 (($ (-1 (-121) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-842)))) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2223 (((-568) $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-3674 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4450 (($ $ $ (-568)) NIL) (($ |#1| $ (-568)) NIL)) (-4122 (($ |#1| $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3802 (($ (-634 |#1|)) NIL)) (-3876 ((|#1| $) NIL (|has| (-568) (-842)))) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3724 (($ $ |#1|) NIL (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#1| $ (-568) |#1|) NIL) ((|#1| $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-1783 (($ $ (-1210 (-568))) NIL) (($ $ (-568)) NIL)) (-2826 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2256 (($ $ $ (-568)) NIL (|has| $ (-6 -4520)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) NIL)) (-3845 (($ $ $) NIL) (($ $ |#1|) NIL)) (-2768 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-634 $)) NIL)) (-2745 (((-850) $) NIL (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-325 |#1|) (-13 (-19 |#1|) (-277 |#1|) (-10 -8 (-15 -3802 ($ (-634 |#1|))) (-15 -3575 ((-763) $)) (-15 -3428 ($ $ (-568))) (-15 -3535 ((-121) (-121))))) (-1195)) (T -325)) 
-((-3802 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-325 *3)))) (-3575 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-325 *3)) (-4 *3 (-1195)))) (-3428 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-325 *3)) (-4 *3 (-1195)))) (-3535 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-325 *3)) (-4 *3 (-1195))))) 
-(-13 (-19 |#1|) (-277 |#1|) (-10 -8 (-15 -3802 ($ (-634 |#1|))) (-15 -3575 ((-763) $)) (-15 -3428 ($ $ (-568))) (-15 -3535 ((-121) (-121))))) 
-((-2615 (((-121) $) 37)) (-1739 (((-763)) 22)) (-1932 ((|#2| $) 41) (($ $ (-917)) 99)) (-3983 (((-763)) 93)) (-3498 (($ (-1244 |#2|)) 20)) (-3917 (((-121) $) 111)) (-2657 ((|#2| $) 43) (($ $ (-917)) 97)) (-2045 (((-1157 |#2|) $) NIL) (((-1157 $) $ (-917)) 88)) (-2035 (((-1157 |#2|) $) 78)) (-1422 (((-1157 |#2|) $) 75) (((-3 (-1157 |#2|) "failed") $ $) 72)) (-2109 (($ $ (-1157 |#2|)) 48)) (-1553 (((-828 (-917))) 91) (((-917)) 38)) (-4321 (((-139)) 25)) (-3206 (((-828 (-917)) $) NIL) (((-917) $) 112)) (-2027 (($) 105)) (-4073 (((-1244 |#2|) $) NIL) (((-679 |#2|) (-1244 $)) 34)) (-4371 (($ $) NIL) (((-3 $ "failed") $) 81)) (-4390 (((-121) $) 36))) 
-(((-326 |#1| |#2|) (-10 -8 (-15 -4371 ((-3 |#1| "failed") |#1|)) (-15 -3983 ((-763))) (-15 -4371 (|#1| |#1|)) (-15 -1422 ((-3 (-1157 |#2|) "failed") |#1| |#1|)) (-15 -1422 ((-1157 |#2|) |#1|)) (-15 -2035 ((-1157 |#2|) |#1|)) (-15 -2109 (|#1| |#1| (-1157 |#2|))) (-15 -3917 ((-121) |#1|)) (-15 -2027 (|#1|)) (-15 -1932 (|#1| |#1| (-917))) (-15 -2657 (|#1| |#1| (-917))) (-15 -2045 ((-1157 |#1|) |#1| (-917))) (-15 -1932 (|#2| |#1|)) (-15 -2657 (|#2| |#1|)) (-15 -3206 ((-917) |#1|)) (-15 -1553 ((-917))) (-15 -2045 ((-1157 |#2|) |#1|)) (-15 -3498 (|#1| (-1244 |#2|))) (-15 -4073 ((-679 |#2|) (-1244 |#1|))) (-15 -4073 ((-1244 |#2|) |#1|)) (-15 -1739 ((-763))) (-15 -1553 ((-828 (-917)))) (-15 -3206 ((-828 (-917)) |#1|)) (-15 -2615 ((-121) |#1|)) (-15 -4390 ((-121) |#1|)) (-15 -4321 ((-139)))) (-327 |#2|) (-365)) (T -326)) 
-((-4321 (*1 *2) (-12 (-4 *4 (-365)) (-5 *2 (-139)) (-5 *1 (-326 *3 *4)) (-4 *3 (-327 *4)))) (-1553 (*1 *2) (-12 (-4 *4 (-365)) (-5 *2 (-828 (-917))) (-5 *1 (-326 *3 *4)) (-4 *3 (-327 *4)))) (-1739 (*1 *2) (-12 (-4 *4 (-365)) (-5 *2 (-763)) (-5 *1 (-326 *3 *4)) (-4 *3 (-327 *4)))) (-1553 (*1 *2) (-12 (-4 *4 (-365)) (-5 *2 (-917)) (-5 *1 (-326 *3 *4)) (-4 *3 (-327 *4)))) (-3983 (*1 *2) (-12 (-4 *4 (-365)) (-5 *2 (-763)) (-5 *1 (-326 *3 *4)) (-4 *3 (-327 *4))))) 
-(-10 -8 (-15 -4371 ((-3 |#1| "failed") |#1|)) (-15 -3983 ((-763))) (-15 -4371 (|#1| |#1|)) (-15 -1422 ((-3 (-1157 |#2|) "failed") |#1| |#1|)) (-15 -1422 ((-1157 |#2|) |#1|)) (-15 -2035 ((-1157 |#2|) |#1|)) (-15 -2109 (|#1| |#1| (-1157 |#2|))) (-15 -3917 ((-121) |#1|)) (-15 -2027 (|#1|)) (-15 -1932 (|#1| |#1| (-917))) (-15 -2657 (|#1| |#1| (-917))) (-15 -2045 ((-1157 |#1|) |#1| (-917))) (-15 -1932 (|#2| |#1|)) (-15 -2657 (|#2| |#1|)) (-15 -3206 ((-917) |#1|)) (-15 -1553 ((-917))) (-15 -2045 ((-1157 |#2|) |#1|)) (-15 -3498 (|#1| (-1244 |#2|))) (-15 -4073 ((-679 |#2|) (-1244 |#1|))) (-15 -4073 ((-1244 |#2|) |#1|)) (-15 -1739 ((-763))) (-15 -1553 ((-828 (-917)))) (-15 -3206 ((-828 (-917)) |#1|)) (-15 -2615 ((-121) |#1|)) (-15 -4390 ((-121) |#1|)) (-15 -4321 ((-139)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-2615 (((-121) $) 90)) (-1739 (((-763)) 86)) (-1932 ((|#1| $) 133) (($ $ (-917)) 130 (|has| |#1| (-370)))) (-3211 (((-1169 (-917) (-763)) (-568)) 115 (|has| |#1| (-370)))) (-3134 (((-3 $ "failed") $ $) 18)) (-4305 (($ $) 71)) (-1678 (((-420 $) $) 70)) (-1497 (((-121) $ $) 57)) (-3983 (((-763)) 105 (|has| |#1| (-370)))) (-2671 (($) 16 T CONST)) (-3666 (((-3 |#1| "failed") $) 97)) (-2854 ((|#1| $) 96)) (-3498 (($ (-1244 |#1|)) 139)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) 121 (|has| |#1| (-370)))) (-2401 (($ $ $) 53)) (-2925 (((-3 $ "failed") $) 33)) (-1731 (($) 102 (|has| |#1| (-370)))) (-2412 (($ $ $) 54)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 49)) (-4220 (($) 117 (|has| |#1| (-370)))) (-4456 (((-121) $) 118 (|has| |#1| (-370)))) (-3218 (($ $ (-763)) 83 (-2198 (|has| |#1| (-148)) (|has| |#1| (-370)))) (($ $) 82 (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3927 (((-121) $) 69)) (-4477 (((-917) $) 120 (|has| |#1| (-370))) (((-828 (-917)) $) 80 (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-2735 (((-121) $) 30)) (-2883 (($) 128 (|has| |#1| (-370)))) (-3917 (((-121) $) 127 (|has| |#1| (-370)))) (-2657 ((|#1| $) 134) (($ $ (-917)) 131 (|has| |#1| (-370)))) (-3038 (((-3 $ "failed") $) 106 (|has| |#1| (-370)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-2045 (((-1157 |#1|) $) 138) (((-1157 $) $ (-917)) 132 (|has| |#1| (-370)))) (-3683 (((-917) $) 103 (|has| |#1| (-370)))) (-2035 (((-1157 |#1|) $) 124 (|has| |#1| (-370)))) (-1422 (((-1157 |#1|) $) 123 (|has| |#1| (-370))) (((-3 (-1157 |#1|) "failed") $ $) 122 (|has| |#1| (-370)))) (-2109 (($ $ (-1157 |#1|)) 125 (|has| |#1| (-370)))) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-2081 (($ $) 68)) (-4434 (($) 107 (|has| |#1| (-370)) CONST)) (-4355 (($ (-917)) 104 (|has| |#1| (-370)))) (-2864 (((-121) $) 89)) (-4022 (((-1108) $) 10)) (-2704 (($) 126 (|has| |#1| (-370)))) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) 114 (|has| |#1| (-370)))) (-3848 (((-420 $) $) 72)) (-1553 (((-828 (-917))) 87) (((-917)) 136)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2595 (((-3 $ "failed") $ $) 41)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-2709 (((-763) $) 56)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 55)) (-3143 (((-763) $) 119 (|has| |#1| (-370))) (((-3 (-763) "failed") $ $) 81 (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-4321 (((-139)) 95)) (-4189 (($ $) 111 (|has| |#1| (-370))) (($ $ (-763)) 109 (|has| |#1| (-370)))) (-3206 (((-828 (-917)) $) 88) (((-917) $) 135)) (-1626 (((-1157 |#1|)) 137)) (-3065 (($) 116 (|has| |#1| (-370)))) (-2027 (($) 129 (|has| |#1| (-370)))) (-4073 (((-1244 |#1|) $) 141) (((-679 |#1|) (-1244 $)) 140)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) 113 (|has| |#1| (-370)))) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63) (($ |#1|) 98)) (-4371 (($ $) 112 (|has| |#1| (-370))) (((-3 $ "failed") $) 79 (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-4078 (((-763)) 28)) (-3746 (((-1244 $)) 143) (((-1244 $) (-917)) 142)) (-1826 (((-121) $ $) 38)) (-4390 (((-121) $) 91)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1316 (($ $) 85 (|has| |#1| (-370))) (($ $ (-763)) 84 (|has| |#1| (-370)))) (-3190 (($ $) 110 (|has| |#1| (-370))) (($ $ (-763)) 108 (|has| |#1| (-370)))) (-1717 (((-121) $ $) 6)) (-1779 (($ $ $) 62) (($ $ |#1|) 94)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64) (($ $ |#1|) 93) (($ |#1| $) 92))) 
+((-2088 (*1 *2 *1) (-12 (-4 *1 (-324 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-121)))) (-2093 (*1 *2 *1) (-12 (-4 *1 (-324 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047)))) (-3304 (*1 *2 *1) (-12 (-4 *1 (-324 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-634 *3)))) (-3971 (*1 *2 *1) (-12 (-4 *1 (-324 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-763)))) (-3524 (*1 *2 *1) (-12 (-4 *1 (-324 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787)))) (-1865 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-324 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)))) (-2453 (*1 *1 *1 *2 *3 *1) (-12 (-4 *1 (-324 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)))) (-3925 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-324 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-4 *3 (-172)))) (-2597 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-324 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)) (-4 *2 (-558)))) (-1364 (*1 *2 *1) (-12 (-4 *1 (-324 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047)) (-4 *2 (-453)))) (-1998 (*1 *1 *1) (-12 (-4 *1 (-324 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)) (-4 *2 (-453))))) 
+(-13 (-52 |t#1| |t#2|) (-413 |t#1|) (-10 -8 (-15 -2088 ((-121) $)) (-15 -2093 (|t#1| $)) (-15 -3304 ((-634 |t#1|) $)) (-15 -3971 ((-763) $)) (-15 -3524 (|t#2| $)) (-15 -1865 ($ (-1 |t#2| |t#2|) $)) (-15 -2453 ($ $ |t#1| |t#2| $)) (IF (|has| |t#1| (-172)) (-15 -3925 ($ $ $ (-763))) |noBranch|) (IF (|has| |t#1| (-558)) (-15 -2597 ((-3 $ "failed") $ |t#1|)) |noBranch|) (IF (|has| |t#1| (-453)) (PROGN (-15 -1364 (|t#1| $)) (-15 -1998 ($ $))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| |#2|) . T) ((-25) . T) ((-43 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) |has| |#1| (-558)) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2199 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2199 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-285) |has| |#1| (-558)) ((-413 |#1|) . T) ((-558) |has| |#1| (-558)) ((-637 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) |has| |#1| (-558)) ((-716) . T) ((-1037 (-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 |#1|) . T) ((-1053 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-1053 |#1|) . T) ((-1053 $) -2199 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-1324 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-842)))) (-2109 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4522))) (($ $) NIL (-12 (|has| $ (-6 -4522)) (|has| |#1| (-842))))) (-3647 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-842)))) (-1667 (((-121) $ (-763)) NIL)) (-4161 (((-121) (-121)) NIL)) (-2438 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4522))) ((|#1| $ (-1210 (-568)) |#1|) NIL (|has| $ (-6 -4522)))) (-3963 (($ (-1 (-121) |#1|) $) NIL)) (-2803 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-4490 (($) NIL T CONST)) (-4452 (($ $) NIL (|has| $ (-6 -4522)))) (-3945 (($ $) NIL)) (-1377 (($ $) NIL (|has| |#1| (-1090)))) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1568 (($ |#1| $) NIL (|has| |#1| (-1090))) (($ (-1 (-121) |#1|) $) NIL)) (-4330 (($ |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4521)))) (-1292 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-568)) NIL)) (-2766 (((-568) (-1 (-121) |#1|) $) NIL) (((-568) |#1| $) NIL (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) NIL (|has| |#1| (-1090)))) (-3400 (($ $ (-568)) NIL)) (-2906 (((-763) $) NIL)) (-3317 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-1851 (($ (-763) |#1|) NIL)) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) NIL (|has| (-568) (-842)))) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-4496 (($ $ $) NIL (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $ $) NIL)) (-3645 (($ (-1 (-121) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-842)))) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3631 (((-568) $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-2253 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-1708 (($ $ $ (-568)) NIL) (($ |#1| $ (-568)) NIL)) (-4124 (($ |#1| $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-1697 (($ (-634 |#1|)) NIL)) (-3877 ((|#1| $) NIL (|has| (-568) (-842)))) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-2490 (($ $ |#1|) NIL (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#1| $ (-568) |#1|) NIL) ((|#1| $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-4031 (($ $ (-1210 (-568))) NIL) (($ $ (-568)) NIL)) (-2828 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3306 (($ $ $ (-568)) NIL (|has| $ (-6 -4522)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) NIL)) (-1876 (($ $ $) NIL) (($ $ |#1|) NIL)) (-2770 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-634 $)) NIL)) (-2747 (((-850) $) NIL (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-325 |#1|) (-13 (-19 |#1|) (-277 |#1|) (-10 -8 (-15 -1697 ($ (-634 |#1|))) (-15 -2906 ((-763) $)) (-15 -3400 ($ $ (-568))) (-15 -4161 ((-121) (-121))))) (-1195)) (T -325)) 
+((-1697 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-325 *3)))) (-2906 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-325 *3)) (-4 *3 (-1195)))) (-3400 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-325 *3)) (-4 *3 (-1195)))) (-4161 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-325 *3)) (-4 *3 (-1195))))) 
+(-13 (-19 |#1|) (-277 |#1|) (-10 -8 (-15 -1697 ($ (-634 |#1|))) (-15 -2906 ((-763) $)) (-15 -3400 ($ $ (-568))) (-15 -4161 ((-121) (-121))))) 
+((-2134 (((-121) $) 37)) (-3800 (((-763)) 22)) (-1934 ((|#2| $) 41) (($ $ (-917)) 99)) (-3986 (((-763)) 93)) (-3899 (($ (-1244 |#2|)) 20)) (-2151 (((-121) $) 111)) (-4417 ((|#2| $) 43) (($ $ (-917)) 97)) (-1497 (((-1157 |#2|) $) NIL) (((-1157 $) $ (-917)) 88)) (-1447 (((-1157 |#2|) $) 78)) (-2193 (((-1157 |#2|) $) 75) (((-3 (-1157 |#2|) "failed") $ $) 72)) (-3257 (($ $ (-1157 |#2|)) 48)) (-4321 (((-828 (-917))) 91) (((-917)) 38)) (-3108 (((-139)) 25)) (-1836 (((-828 (-917)) $) NIL) (((-917) $) 112)) (-1398 (($) 105)) (-1656 (((-1244 |#2|) $) NIL) (((-679 |#2|) (-1244 $)) 34)) (-3385 (($ $) NIL) (((-3 $ "failed") $) 81)) (-1413 (((-121) $) 36))) 
+(((-326 |#1| |#2|) (-10 -8 (-15 -3385 ((-3 |#1| "failed") |#1|)) (-15 -3986 ((-763))) (-15 -3385 (|#1| |#1|)) (-15 -2193 ((-3 (-1157 |#2|) "failed") |#1| |#1|)) (-15 -2193 ((-1157 |#2|) |#1|)) (-15 -1447 ((-1157 |#2|) |#1|)) (-15 -3257 (|#1| |#1| (-1157 |#2|))) (-15 -2151 ((-121) |#1|)) (-15 -1398 (|#1|)) (-15 -1934 (|#1| |#1| (-917))) (-15 -4417 (|#1| |#1| (-917))) (-15 -1497 ((-1157 |#1|) |#1| (-917))) (-15 -1934 (|#2| |#1|)) (-15 -4417 (|#2| |#1|)) (-15 -1836 ((-917) |#1|)) (-15 -4321 ((-917))) (-15 -1497 ((-1157 |#2|) |#1|)) (-15 -3899 (|#1| (-1244 |#2|))) (-15 -1656 ((-679 |#2|) (-1244 |#1|))) (-15 -1656 ((-1244 |#2|) |#1|)) (-15 -3800 ((-763))) (-15 -4321 ((-828 (-917)))) (-15 -1836 ((-828 (-917)) |#1|)) (-15 -2134 ((-121) |#1|)) (-15 -1413 ((-121) |#1|)) (-15 -3108 ((-139)))) (-327 |#2|) (-365)) (T -326)) 
+((-3108 (*1 *2) (-12 (-4 *4 (-365)) (-5 *2 (-139)) (-5 *1 (-326 *3 *4)) (-4 *3 (-327 *4)))) (-4321 (*1 *2) (-12 (-4 *4 (-365)) (-5 *2 (-828 (-917))) (-5 *1 (-326 *3 *4)) (-4 *3 (-327 *4)))) (-3800 (*1 *2) (-12 (-4 *4 (-365)) (-5 *2 (-763)) (-5 *1 (-326 *3 *4)) (-4 *3 (-327 *4)))) (-4321 (*1 *2) (-12 (-4 *4 (-365)) (-5 *2 (-917)) (-5 *1 (-326 *3 *4)) (-4 *3 (-327 *4)))) (-3986 (*1 *2) (-12 (-4 *4 (-365)) (-5 *2 (-763)) (-5 *1 (-326 *3 *4)) (-4 *3 (-327 *4))))) 
+(-10 -8 (-15 -3385 ((-3 |#1| "failed") |#1|)) (-15 -3986 ((-763))) (-15 -3385 (|#1| |#1|)) (-15 -2193 ((-3 (-1157 |#2|) "failed") |#1| |#1|)) (-15 -2193 ((-1157 |#2|) |#1|)) (-15 -1447 ((-1157 |#2|) |#1|)) (-15 -3257 (|#1| |#1| (-1157 |#2|))) (-15 -2151 ((-121) |#1|)) (-15 -1398 (|#1|)) (-15 -1934 (|#1| |#1| (-917))) (-15 -4417 (|#1| |#1| (-917))) (-15 -1497 ((-1157 |#1|) |#1| (-917))) (-15 -1934 (|#2| |#1|)) (-15 -4417 (|#2| |#1|)) (-15 -1836 ((-917) |#1|)) (-15 -4321 ((-917))) (-15 -1497 ((-1157 |#2|) |#1|)) (-15 -3899 (|#1| (-1244 |#2|))) (-15 -1656 ((-679 |#2|) (-1244 |#1|))) (-15 -1656 ((-1244 |#2|) |#1|)) (-15 -3800 ((-763))) (-15 -4321 ((-828 (-917)))) (-15 -1836 ((-828 (-917)) |#1|)) (-15 -2134 ((-121) |#1|)) (-15 -1413 ((-121) |#1|)) (-15 -3108 ((-139)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-2134 (((-121) $) 90)) (-3800 (((-763)) 86)) (-1934 ((|#1| $) 133) (($ $ (-917)) 130 (|has| |#1| (-370)))) (-1856 (((-1169 (-917) (-763)) (-568)) 115 (|has| |#1| (-370)))) (-2689 (((-3 $ "failed") $ $) 18)) (-3045 (($ $) 71)) (-3498 (((-420 $) $) 70)) (-2589 (((-121) $ $) 57)) (-3986 (((-763)) 105 (|has| |#1| (-370)))) (-4490 (($) 16 T CONST)) (-3668 (((-3 |#1| "failed") $) 97)) (-2857 ((|#1| $) 96)) (-3899 (($ (-1244 |#1|)) 139)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) 121 (|has| |#1| (-370)))) (-2403 (($ $ $) 53)) (-2902 (((-3 $ "failed") $) 33)) (-1733 (($) 102 (|has| |#1| (-370)))) (-2414 (($ $ $) 54)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 49)) (-4188 (($) 117 (|has| |#1| (-370)))) (-1748 (((-121) $) 118 (|has| |#1| (-370)))) (-1887 (($ $ (-763)) 83 (-2199 (|has| |#1| (-148)) (|has| |#1| (-370)))) (($ $) 82 (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-2197 (((-121) $) 69)) (-1844 (((-917) $) 120 (|has| |#1| (-370))) (((-828 (-917)) $) 80 (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-1598 (((-121) $) 30)) (-2769 (($) 128 (|has| |#1| (-370)))) (-2151 (((-121) $) 127 (|has| |#1| (-370)))) (-4417 ((|#1| $) 134) (($ $ (-917)) 131 (|has| |#1| (-370)))) (-2214 (((-3 $ "failed") $) 106 (|has| |#1| (-370)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-1497 (((-1157 |#1|) $) 138) (((-1157 $) $ (-917)) 132 (|has| |#1| (-370)))) (-2291 (((-917) $) 103 (|has| |#1| (-370)))) (-1447 (((-1157 |#1|) $) 124 (|has| |#1| (-370)))) (-2193 (((-1157 |#1|) $) 123 (|has| |#1| (-370))) (((-3 (-1157 |#1|) "failed") $ $) 122 (|has| |#1| (-370)))) (-3257 (($ $ (-1157 |#1|)) 125 (|has| |#1| (-370)))) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-2083 (($ $) 68)) (-4436 (($) 107 (|has| |#1| (-370)) CONST)) (-4357 (($ (-917)) 104 (|has| |#1| (-370)))) (-4051 (((-121) $) 89)) (-4025 (((-1108) $) 10)) (-2707 (($) 126 (|has| |#1| (-370)))) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) 114 (|has| |#1| (-370)))) (-3850 (((-420 $) $) 72)) (-4321 (((-828 (-917))) 87) (((-917)) 136)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2597 (((-3 $ "failed") $ $) 41)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-1466 (((-763) $) 56)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 55)) (-2721 (((-763) $) 119 (|has| |#1| (-370))) (((-3 (-763) "failed") $ $) 81 (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3108 (((-139)) 95)) (-4191 (($ $) 111 (|has| |#1| (-370))) (($ $ (-763)) 109 (|has| |#1| (-370)))) (-1836 (((-828 (-917)) $) 88) (((-917) $) 135)) (-1492 (((-1157 |#1|)) 137)) (-2330 (($) 116 (|has| |#1| (-370)))) (-1398 (($) 129 (|has| |#1| (-370)))) (-1656 (((-1244 |#1|) $) 141) (((-679 |#1|) (-1244 $)) 140)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) 113 (|has| |#1| (-370)))) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63) (($ |#1|) 98)) (-3385 (($ $) 112 (|has| |#1| (-370))) (((-3 $ "failed") $) 79 (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3425 (((-763)) 28)) (-2588 (((-1244 $)) 143) (((-1244 $) (-917)) 142)) (-2273 (((-121) $ $) 38)) (-1413 (((-121) $) 91)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3412 (($ $) 85 (|has| |#1| (-370))) (($ $ (-763)) 84 (|has| |#1| (-370)))) (-3192 (($ $) 110 (|has| |#1| (-370))) (($ $ (-763)) 108 (|has| |#1| (-370)))) (-1719 (((-121) $ $) 6)) (-1781 (($ $ $) 62) (($ $ |#1|) 94)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64) (($ $ |#1|) 93) (($ |#1| $) 92))) 
 (((-327 |#1|) (-1275) (-365)) (T -327)) 
-((-3746 (*1 *2) (-12 (-4 *3 (-365)) (-5 *2 (-1244 *1)) (-4 *1 (-327 *3)))) (-3746 (*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-365)) (-5 *2 (-1244 *1)) (-4 *1 (-327 *4)))) (-4073 (*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-5 *2 (-1244 *3)))) (-4073 (*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-327 *4)) (-4 *4 (-365)) (-5 *2 (-679 *4)))) (-3498 (*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-365)) (-4 *1 (-327 *3)))) (-2045 (*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-5 *2 (-1157 *3)))) (-1626 (*1 *2) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-5 *2 (-1157 *3)))) (-1553 (*1 *2) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-5 *2 (-917)))) (-3206 (*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-5 *2 (-917)))) (-2657 (*1 *2 *1) (-12 (-4 *1 (-327 *2)) (-4 *2 (-365)))) (-1932 (*1 *2 *1) (-12 (-4 *1 (-327 *2)) (-4 *2 (-365)))) (-2045 (*1 *2 *1 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-5 *2 (-1157 *1)) (-4 *1 (-327 *4)))) (-2657 (*1 *1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)))) (-1932 (*1 *1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)))) (-2027 (*1 *1) (-12 (-4 *1 (-327 *2)) (-4 *2 (-370)) (-4 *2 (-365)))) (-2883 (*1 *1) (-12 (-4 *1 (-327 *2)) (-4 *2 (-370)) (-4 *2 (-365)))) (-3917 (*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)) (-5 *2 (-121)))) (-2704 (*1 *1) (-12 (-4 *1 (-327 *2)) (-4 *2 (-370)) (-4 *2 (-365)))) (-2109 (*1 *1 *1 *2) (-12 (-5 *2 (-1157 *3)) (-4 *3 (-370)) (-4 *1 (-327 *3)) (-4 *3 (-365)))) (-2035 (*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)) (-5 *2 (-1157 *3)))) (-1422 (*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)) (-5 *2 (-1157 *3)))) (-1422 (*1 *2 *1 *1) (|partial| -12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)) (-5 *2 (-1157 *3))))) 
-(-13 (-1261 |t#1|) (-1037 |t#1|) (-10 -8 (-15 -3746 ((-1244 $))) (-15 -3746 ((-1244 $) (-917))) (-15 -4073 ((-1244 |t#1|) $)) (-15 -4073 ((-679 |t#1|) (-1244 $))) (-15 -3498 ($ (-1244 |t#1|))) (-15 -2045 ((-1157 |t#1|) $)) (-15 -1626 ((-1157 |t#1|))) (-15 -1553 ((-917))) (-15 -3206 ((-917) $)) (-15 -2657 (|t#1| $)) (-15 -1932 (|t#1| $)) (IF (|has| |t#1| (-370)) (PROGN (-6 (-350)) (-15 -2045 ((-1157 $) $ (-917))) (-15 -2657 ($ $ (-917))) (-15 -1932 ($ $ (-917))) (-15 -2027 ($)) (-15 -2883 ($)) (-15 -3917 ((-121) $)) (-15 -2704 ($)) (-15 -2109 ($ $ (-1157 |t#1|))) (-15 -2035 ((-1157 |t#1|) $)) (-15 -1422 ((-1157 |t#1|) $)) (-15 -1422 ((-3 (-1157 |t#1|) "failed") $ $))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 |#1| |#1|) . T) ((-120 $ $) . T) ((-137) . T) ((-148) -2198 (|has| |#1| (-370)) (|has| |#1| (-148))) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) . T) ((-225) |has| |#1| (-370)) ((-238) . T) ((-285) . T) ((-301) . T) ((-1261 |#1|) . T) ((-365) . T) ((-404) -2198 (|has| |#1| (-370)) (|has| |#1| (-148))) ((-370) |has| |#1| (-370)) ((-350) |has| |#1| (-370)) ((-453) . T) ((-558) . T) ((-637 (-409 (-568))) . T) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) . T) ((-707 |#1|) . T) ((-707 $) . T) ((-716) . T) ((-916) . T) ((-1037 |#1|) . T) ((-1053 (-409 (-568))) . T) ((-1053 |#1|) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1136) |has| |#1| (-370)) ((-1199) . T) ((-1251 |#1|) . T)) 
-((-2447 (((-121) $ $) NIL)) (-1430 (($ (-1160) $) 88)) (-3480 (($) 76)) (-3301 (((-1108) (-1108)) 11)) (-2330 (($) 77)) (-2592 (($) 90) (($ (-310 (-688))) 96) (($ (-310 (-690))) 93) (($ (-310 (-683))) 99) (($ (-310 (-381))) 105) (($ (-310 (-568))) 102) (($ (-310 (-169 (-381)))) 108)) (-4082 (($ (-1160) $) 89)) (-2214 (($ (-634 (-850))) 79)) (-3725 (((-1249) $) 73)) (-3406 (((-3 (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print")) $) 27)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-3487 (($ (-1108)) 45)) (-1491 (((-1094) $) 25)) (-4465 (($ (-1082 (-953 (-568))) $) 85) (($ (-1082 (-953 (-568))) (-953 (-568)) $) 86)) (-2909 (($ (-1108)) 87)) (-4133 (($ (-1160) $) 110) (($ (-1160) $ $) 111)) (-1921 (($ (-1161) (-634 (-1161))) 75)) (-1707 (($ (-1143)) 82) (($ (-634 (-1143))) 80)) (-2745 (((-850) $) 113)) (-2845 (((-3 (|:| |nullBranch| "null") (|:| |assignmentBranch| (-2 (|:| |var| (-1161)) (|:| |arrayIndex| (-634 (-953 (-568)))) (|:| |rand| (-2 (|:| |ints2Floats?| (-121)) (|:| -4151 (-850)))))) (|:| |arrayAssignmentBranch| (-2 (|:| |var| (-1161)) (|:| |rand| (-850)) (|:| |ints2Floats?| (-121)))) (|:| |conditionalBranch| (-2 (|:| |switch| (-1160)) (|:| |thenClause| $) (|:| |elseClause| $))) (|:| |returnBranch| (-2 (|:| -3084 (-121)) (|:| -2850 (-2 (|:| |ints2Floats?| (-121)) (|:| -4151 (-850)))))) (|:| |blockBranch| (-634 $)) (|:| |commentBranch| (-634 (-1143))) (|:| |callBranch| (-1143)) (|:| |forBranch| (-2 (|:| -1338 (-1082 (-953 (-568)))) (|:| |span| (-953 (-568))) (|:| |body| $))) (|:| |labelBranch| (-1108)) (|:| |loopBranch| (-2 (|:| |switch| (-1160)) (|:| |body| $))) (|:| |commonBranch| (-2 (|:| -3391 (-1161)) (|:| |contents| (-634 (-1161))))) (|:| |printBranch| (-634 (-850)))) $) 37)) (-2683 (($ (-1143)) 182)) (-2414 (($ (-634 $)) 109)) (-3870 (($ (-1161) (-1143)) 115) (($ (-1161) (-310 (-690))) 155) (($ (-1161) (-310 (-688))) 156) (($ (-1161) (-310 (-683))) 157) (($ (-1161) (-679 (-690))) 118) (($ (-1161) (-679 (-688))) 121) (($ (-1161) (-679 (-683))) 124) (($ (-1161) (-1244 (-690))) 127) (($ (-1161) (-1244 (-688))) 130) (($ (-1161) (-1244 (-683))) 133) (($ (-1161) (-679 (-310 (-690)))) 136) (($ (-1161) (-679 (-310 (-688)))) 139) (($ (-1161) (-679 (-310 (-683)))) 142) (($ (-1161) (-1244 (-310 (-690)))) 145) (($ (-1161) (-1244 (-310 (-688)))) 148) (($ (-1161) (-1244 (-310 (-683)))) 151) (($ (-1161) (-634 (-953 (-568))) (-310 (-690))) 152) (($ (-1161) (-634 (-953 (-568))) (-310 (-688))) 153) (($ (-1161) (-634 (-953 (-568))) (-310 (-683))) 154) (($ (-1161) (-310 (-568))) 179) (($ (-1161) (-310 (-381))) 180) (($ (-1161) (-310 (-169 (-381)))) 181) (($ (-1161) (-679 (-310 (-568)))) 160) (($ (-1161) (-679 (-310 (-381)))) 163) (($ (-1161) (-679 (-310 (-169 (-381))))) 166) (($ (-1161) (-1244 (-310 (-568)))) 169) (($ (-1161) (-1244 (-310 (-381)))) 172) (($ (-1161) (-1244 (-310 (-169 (-381))))) 175) (($ (-1161) (-634 (-953 (-568))) (-310 (-568))) 176) (($ (-1161) (-634 (-953 (-568))) (-310 (-381))) 177) (($ (-1161) (-634 (-953 (-568))) (-310 (-169 (-381)))) 178)) (-1717 (((-121) $ $) NIL))) 
-(((-328) (-13 (-1090) (-10 -8 (-15 -2745 ((-850) $)) (-15 -4465 ($ (-1082 (-953 (-568))) $)) (-15 -4465 ($ (-1082 (-953 (-568))) (-953 (-568)) $)) (-15 -1430 ($ (-1160) $)) (-15 -4082 ($ (-1160) $)) (-15 -3487 ($ (-1108))) (-15 -2909 ($ (-1108))) (-15 -1707 ($ (-1143))) (-15 -1707 ($ (-634 (-1143)))) (-15 -2683 ($ (-1143))) (-15 -2592 ($)) (-15 -2592 ($ (-310 (-688)))) (-15 -2592 ($ (-310 (-690)))) (-15 -2592 ($ (-310 (-683)))) (-15 -2592 ($ (-310 (-381)))) (-15 -2592 ($ (-310 (-568)))) (-15 -2592 ($ (-310 (-169 (-381))))) (-15 -4133 ($ (-1160) $)) (-15 -4133 ($ (-1160) $ $)) (-15 -3870 ($ (-1161) (-1143))) (-15 -3870 ($ (-1161) (-310 (-690)))) (-15 -3870 ($ (-1161) (-310 (-688)))) (-15 -3870 ($ (-1161) (-310 (-683)))) (-15 -3870 ($ (-1161) (-679 (-690)))) (-15 -3870 ($ (-1161) (-679 (-688)))) (-15 -3870 ($ (-1161) (-679 (-683)))) (-15 -3870 ($ (-1161) (-1244 (-690)))) (-15 -3870 ($ (-1161) (-1244 (-688)))) (-15 -3870 ($ (-1161) (-1244 (-683)))) (-15 -3870 ($ (-1161) (-679 (-310 (-690))))) (-15 -3870 ($ (-1161) (-679 (-310 (-688))))) (-15 -3870 ($ (-1161) (-679 (-310 (-683))))) (-15 -3870 ($ (-1161) (-1244 (-310 (-690))))) (-15 -3870 ($ (-1161) (-1244 (-310 (-688))))) (-15 -3870 ($ (-1161) (-1244 (-310 (-683))))) (-15 -3870 ($ (-1161) (-634 (-953 (-568))) (-310 (-690)))) (-15 -3870 ($ (-1161) (-634 (-953 (-568))) (-310 (-688)))) (-15 -3870 ($ (-1161) (-634 (-953 (-568))) (-310 (-683)))) (-15 -3870 ($ (-1161) (-310 (-568)))) (-15 -3870 ($ (-1161) (-310 (-381)))) (-15 -3870 ($ (-1161) (-310 (-169 (-381))))) (-15 -3870 ($ (-1161) (-679 (-310 (-568))))) (-15 -3870 ($ (-1161) (-679 (-310 (-381))))) (-15 -3870 ($ (-1161) (-679 (-310 (-169 (-381)))))) (-15 -3870 ($ (-1161) (-1244 (-310 (-568))))) (-15 -3870 ($ (-1161) (-1244 (-310 (-381))))) (-15 -3870 ($ (-1161) (-1244 (-310 (-169 (-381)))))) (-15 -3870 ($ (-1161) (-634 (-953 (-568))) (-310 (-568)))) (-15 -3870 ($ (-1161) (-634 (-953 (-568))) (-310 (-381)))) (-15 -3870 ($ (-1161) (-634 (-953 (-568))) (-310 (-169 (-381))))) (-15 -2414 ($ (-634 $))) (-15 -3480 ($)) (-15 -2330 ($)) (-15 -2214 ($ (-634 (-850)))) (-15 -1921 ($ (-1161) (-634 (-1161)))) (-15 -3406 ((-3 (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print")) $)) (-15 -2845 ((-3 (|:| |nullBranch| "null") (|:| |assignmentBranch| (-2 (|:| |var| (-1161)) (|:| |arrayIndex| (-634 (-953 (-568)))) (|:| |rand| (-2 (|:| |ints2Floats?| (-121)) (|:| -4151 (-850)))))) (|:| |arrayAssignmentBranch| (-2 (|:| |var| (-1161)) (|:| |rand| (-850)) (|:| |ints2Floats?| (-121)))) (|:| |conditionalBranch| (-2 (|:| |switch| (-1160)) (|:| |thenClause| $) (|:| |elseClause| $))) (|:| |returnBranch| (-2 (|:| -3084 (-121)) (|:| -2850 (-2 (|:| |ints2Floats?| (-121)) (|:| -4151 (-850)))))) (|:| |blockBranch| (-634 $)) (|:| |commentBranch| (-634 (-1143))) (|:| |callBranch| (-1143)) (|:| |forBranch| (-2 (|:| -1338 (-1082 (-953 (-568)))) (|:| |span| (-953 (-568))) (|:| |body| $))) (|:| |labelBranch| (-1108)) (|:| |loopBranch| (-2 (|:| |switch| (-1160)) (|:| |body| $))) (|:| |commonBranch| (-2 (|:| -3391 (-1161)) (|:| |contents| (-634 (-1161))))) (|:| |printBranch| (-634 (-850)))) $)) (-15 -3725 ((-1249) $)) (-15 -1491 ((-1094) $)) (-15 -3301 ((-1108) (-1108)))))) (T -328)) 
-((-2745 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-328)))) (-4465 (*1 *1 *2 *1) (-12 (-5 *2 (-1082 (-953 (-568)))) (-5 *1 (-328)))) (-4465 (*1 *1 *2 *3 *1) (-12 (-5 *2 (-1082 (-953 (-568)))) (-5 *3 (-953 (-568))) (-5 *1 (-328)))) (-1430 (*1 *1 *2 *1) (-12 (-5 *2 (-1160)) (-5 *1 (-328)))) (-4082 (*1 *1 *2 *1) (-12 (-5 *2 (-1160)) (-5 *1 (-328)))) (-3487 (*1 *1 *2) (-12 (-5 *2 (-1108)) (-5 *1 (-328)))) (-2909 (*1 *1 *2) (-12 (-5 *2 (-1108)) (-5 *1 (-328)))) (-1707 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-328)))) (-1707 (*1 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-328)))) (-2683 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-328)))) (-2592 (*1 *1) (-5 *1 (-328))) (-2592 (*1 *1 *2) (-12 (-5 *2 (-310 (-688))) (-5 *1 (-328)))) (-2592 (*1 *1 *2) (-12 (-5 *2 (-310 (-690))) (-5 *1 (-328)))) (-2592 (*1 *1 *2) (-12 (-5 *2 (-310 (-683))) (-5 *1 (-328)))) (-2592 (*1 *1 *2) (-12 (-5 *2 (-310 (-381))) (-5 *1 (-328)))) (-2592 (*1 *1 *2) (-12 (-5 *2 (-310 (-568))) (-5 *1 (-328)))) (-2592 (*1 *1 *2) (-12 (-5 *2 (-310 (-169 (-381)))) (-5 *1 (-328)))) (-4133 (*1 *1 *2 *1) (-12 (-5 *2 (-1160)) (-5 *1 (-328)))) (-4133 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1160)) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1143)) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-690))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-688))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-683))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-690))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-688))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-683))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-690))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-688))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-683))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-690)))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-688)))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-683)))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-690)))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-688)))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-683)))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-690))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-688))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-683))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-568))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-381))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-169 (-381)))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-568)))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-381)))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-169 (-381))))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-568)))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-381)))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-169 (-381))))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-568))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-381))) (-5 *1 (-328)))) (-3870 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-169 (-381)))) (-5 *1 (-328)))) (-2414 (*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-5 *1 (-328)))) (-3480 (*1 *1) (-5 *1 (-328))) (-2330 (*1 *1) (-5 *1 (-328))) (-2214 (*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-328)))) (-1921 (*1 *1 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-5 *2 (-1161)) (-5 *1 (-328)))) (-3406 (*1 *2 *1) (-12 (-5 *2 (-3 (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print"))) (-5 *1 (-328)))) (-2845 (*1 *2 *1) (-12 (-5 *2 (-3 (|:| |nullBranch| "null") (|:| |assignmentBranch| (-2 (|:| |var| (-1161)) (|:| |arrayIndex| (-634 (-953 (-568)))) (|:| |rand| (-2 (|:| |ints2Floats?| (-121)) (|:| -4151 (-850)))))) (|:| |arrayAssignmentBranch| (-2 (|:| |var| (-1161)) (|:| |rand| (-850)) (|:| |ints2Floats?| (-121)))) (|:| |conditionalBranch| (-2 (|:| |switch| (-1160)) (|:| |thenClause| (-328)) (|:| |elseClause| (-328)))) (|:| |returnBranch| (-2 (|:| -3084 (-121)) (|:| -2850 (-2 (|:| |ints2Floats?| (-121)) (|:| -4151 (-850)))))) (|:| |blockBranch| (-634 (-328))) (|:| |commentBranch| (-634 (-1143))) (|:| |callBranch| (-1143)) (|:| |forBranch| (-2 (|:| -1338 (-1082 (-953 (-568)))) (|:| |span| (-953 (-568))) (|:| |body| (-328)))) (|:| |labelBranch| (-1108)) (|:| |loopBranch| (-2 (|:| |switch| (-1160)) (|:| |body| (-328)))) (|:| |commonBranch| (-2 (|:| -3391 (-1161)) (|:| |contents| (-634 (-1161))))) (|:| |printBranch| (-634 (-850))))) (-5 *1 (-328)))) (-3725 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-328)))) (-1491 (*1 *2 *1) (-12 (-5 *2 (-1094)) (-5 *1 (-328)))) (-3301 (*1 *2 *2) (-12 (-5 *2 (-1108)) (-5 *1 (-328))))) 
-(-13 (-1090) (-10 -8 (-15 -2745 ((-850) $)) (-15 -4465 ($ (-1082 (-953 (-568))) $)) (-15 -4465 ($ (-1082 (-953 (-568))) (-953 (-568)) $)) (-15 -1430 ($ (-1160) $)) (-15 -4082 ($ (-1160) $)) (-15 -3487 ($ (-1108))) (-15 -2909 ($ (-1108))) (-15 -1707 ($ (-1143))) (-15 -1707 ($ (-634 (-1143)))) (-15 -2683 ($ (-1143))) (-15 -2592 ($)) (-15 -2592 ($ (-310 (-688)))) (-15 -2592 ($ (-310 (-690)))) (-15 -2592 ($ (-310 (-683)))) (-15 -2592 ($ (-310 (-381)))) (-15 -2592 ($ (-310 (-568)))) (-15 -2592 ($ (-310 (-169 (-381))))) (-15 -4133 ($ (-1160) $)) (-15 -4133 ($ (-1160) $ $)) (-15 -3870 ($ (-1161) (-1143))) (-15 -3870 ($ (-1161) (-310 (-690)))) (-15 -3870 ($ (-1161) (-310 (-688)))) (-15 -3870 ($ (-1161) (-310 (-683)))) (-15 -3870 ($ (-1161) (-679 (-690)))) (-15 -3870 ($ (-1161) (-679 (-688)))) (-15 -3870 ($ (-1161) (-679 (-683)))) (-15 -3870 ($ (-1161) (-1244 (-690)))) (-15 -3870 ($ (-1161) (-1244 (-688)))) (-15 -3870 ($ (-1161) (-1244 (-683)))) (-15 -3870 ($ (-1161) (-679 (-310 (-690))))) (-15 -3870 ($ (-1161) (-679 (-310 (-688))))) (-15 -3870 ($ (-1161) (-679 (-310 (-683))))) (-15 -3870 ($ (-1161) (-1244 (-310 (-690))))) (-15 -3870 ($ (-1161) (-1244 (-310 (-688))))) (-15 -3870 ($ (-1161) (-1244 (-310 (-683))))) (-15 -3870 ($ (-1161) (-634 (-953 (-568))) (-310 (-690)))) (-15 -3870 ($ (-1161) (-634 (-953 (-568))) (-310 (-688)))) (-15 -3870 ($ (-1161) (-634 (-953 (-568))) (-310 (-683)))) (-15 -3870 ($ (-1161) (-310 (-568)))) (-15 -3870 ($ (-1161) (-310 (-381)))) (-15 -3870 ($ (-1161) (-310 (-169 (-381))))) (-15 -3870 ($ (-1161) (-679 (-310 (-568))))) (-15 -3870 ($ (-1161) (-679 (-310 (-381))))) (-15 -3870 ($ (-1161) (-679 (-310 (-169 (-381)))))) (-15 -3870 ($ (-1161) (-1244 (-310 (-568))))) (-15 -3870 ($ (-1161) (-1244 (-310 (-381))))) (-15 -3870 ($ (-1161) (-1244 (-310 (-169 (-381)))))) (-15 -3870 ($ (-1161) (-634 (-953 (-568))) (-310 (-568)))) (-15 -3870 ($ (-1161) (-634 (-953 (-568))) (-310 (-381)))) (-15 -3870 ($ (-1161) (-634 (-953 (-568))) (-310 (-169 (-381))))) (-15 -2414 ($ (-634 $))) (-15 -3480 ($)) (-15 -2330 ($)) (-15 -2214 ($ (-634 (-850)))) (-15 -1921 ($ (-1161) (-634 (-1161)))) (-15 -3406 ((-3 (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print")) $)) (-15 -2845 ((-3 (|:| |nullBranch| "null") (|:| |assignmentBranch| (-2 (|:| |var| (-1161)) (|:| |arrayIndex| (-634 (-953 (-568)))) (|:| |rand| (-2 (|:| |ints2Floats?| (-121)) (|:| -4151 (-850)))))) (|:| |arrayAssignmentBranch| (-2 (|:| |var| (-1161)) (|:| |rand| (-850)) (|:| |ints2Floats?| (-121)))) (|:| |conditionalBranch| (-2 (|:| |switch| (-1160)) (|:| |thenClause| $) (|:| |elseClause| $))) (|:| |returnBranch| (-2 (|:| -3084 (-121)) (|:| -2850 (-2 (|:| |ints2Floats?| (-121)) (|:| -4151 (-850)))))) (|:| |blockBranch| (-634 $)) (|:| |commentBranch| (-634 (-1143))) (|:| |callBranch| (-1143)) (|:| |forBranch| (-2 (|:| -1338 (-1082 (-953 (-568)))) (|:| |span| (-953 (-568))) (|:| |body| $))) (|:| |labelBranch| (-1108)) (|:| |loopBranch| (-2 (|:| |switch| (-1160)) (|:| |body| $))) (|:| |commonBranch| (-2 (|:| -3391 (-1161)) (|:| |contents| (-634 (-1161))))) (|:| |printBranch| (-634 (-850)))) $)) (-15 -3725 ((-1249) $)) (-15 -1491 ((-1094) $)) (-15 -3301 ((-1108) (-1108))))) 
-((-2447 (((-121) $ $) NIL)) (-4431 (((-121) $) 11)) (-2786 (($ |#1|) 8)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2790 (($ |#1|) 9)) (-2745 (((-850) $) 17)) (-3256 ((|#1| $) 12)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 19))) 
-(((-329 |#1|) (-13 (-842) (-10 -8 (-15 -2786 ($ |#1|)) (-15 -2790 ($ |#1|)) (-15 -4431 ((-121) $)) (-15 -3256 (|#1| $)))) (-842)) (T -329)) 
-((-2786 (*1 *1 *2) (-12 (-5 *1 (-329 *2)) (-4 *2 (-842)))) (-2790 (*1 *1 *2) (-12 (-5 *1 (-329 *2)) (-4 *2 (-842)))) (-4431 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-329 *3)) (-4 *3 (-842)))) (-3256 (*1 *2 *1) (-12 (-5 *1 (-329 *2)) (-4 *2 (-842))))) 
-(-13 (-842) (-10 -8 (-15 -2786 ($ |#1|)) (-15 -2790 ($ |#1|)) (-15 -4431 ((-121) $)) (-15 -3256 (|#1| $)))) 
-((-1353 (((-328) (-1161) (-953 (-568))) 22)) (-4249 (((-328) (-1161) (-953 (-568))) 26)) (-2820 (((-328) (-1161) (-1082 (-953 (-568))) (-1082 (-953 (-568)))) 25) (((-328) (-1161) (-953 (-568)) (-953 (-568))) 23)) (-1616 (((-328) (-1161) (-953 (-568))) 30))) 
-(((-330) (-10 -7 (-15 -1353 ((-328) (-1161) (-953 (-568)))) (-15 -2820 ((-328) (-1161) (-953 (-568)) (-953 (-568)))) (-15 -2820 ((-328) (-1161) (-1082 (-953 (-568))) (-1082 (-953 (-568))))) (-15 -4249 ((-328) (-1161) (-953 (-568)))) (-15 -1616 ((-328) (-1161) (-953 (-568)))))) (T -330)) 
-((-1616 (*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-953 (-568))) (-5 *2 (-328)) (-5 *1 (-330)))) (-4249 (*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-953 (-568))) (-5 *2 (-328)) (-5 *1 (-330)))) (-2820 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-1082 (-953 (-568)))) (-5 *2 (-328)) (-5 *1 (-330)))) (-2820 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-953 (-568))) (-5 *2 (-328)) (-5 *1 (-330)))) (-1353 (*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-953 (-568))) (-5 *2 (-328)) (-5 *1 (-330))))) 
-(-10 -7 (-15 -1353 ((-328) (-1161) (-953 (-568)))) (-15 -2820 ((-328) (-1161) (-953 (-568)) (-953 (-568)))) (-15 -2820 ((-328) (-1161) (-1082 (-953 (-568))) (-1082 (-953 (-568))))) (-15 -4249 ((-328) (-1161) (-953 (-568)))) (-15 -1616 ((-328) (-1161) (-953 (-568))))) 
-((-2795 (((-334 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-334 |#1| |#2| |#3| |#4|)) 31))) 
-(((-331 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -2795 ((-334 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-334 |#1| |#2| |#3| |#4|)))) (-365) (-1219 |#1|) (-1219 (-409 |#2|)) (-340 |#1| |#2| |#3|) (-365) (-1219 |#5|) (-1219 (-409 |#6|)) (-340 |#5| |#6| |#7|)) (T -331)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *5)) (-5 *4 (-334 *5 *6 *7 *8)) (-4 *5 (-365)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-4 *8 (-340 *5 *6 *7)) (-4 *9 (-365)) (-4 *10 (-1219 *9)) (-4 *11 (-1219 (-409 *10))) (-5 *2 (-334 *9 *10 *11 *12)) (-5 *1 (-331 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *12 (-340 *9 *10 *11))))) 
-(-10 -7 (-15 -2795 ((-334 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-334 |#1| |#2| |#3| |#4|)))) 
-((-2886 (((-121) $) 14))) 
-(((-332 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 -2886 ((-121) |#1|))) (-333 |#2| |#3| |#4| |#5|) (-365) (-1219 |#2|) (-1219 (-409 |#3|)) (-340 |#2| |#3| |#4|)) (T -332)) 
-NIL 
-(-10 -8 (-15 -2886 ((-121) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-3092 (($ $) 25)) (-2886 (((-121) $) 24)) (-4487 (((-1143) $) 9)) (-1552 (((-415 |#2| (-409 |#2|) |#3| |#4|) $) 31)) (-4022 (((-1108) $) 10)) (-2704 (((-3 |#4| "failed") $) 23)) (-2849 (($ (-415 |#2| (-409 |#2|) |#3| |#4|)) 30) (($ |#4|) 29) (($ |#1| |#1|) 28) (($ |#1| |#1| (-568)) 27) (($ |#4| |#2| |#2| |#2| |#1|) 22)) (-2847 (((-2 (|:| -1713 (-415 |#2| (-409 |#2|) |#3| |#4|)) (|:| |principalPart| |#4|)) $) 26)) (-2745 (((-850) $) 11)) (-3056 (($) 17 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19))) 
+((-2588 (*1 *2) (-12 (-4 *3 (-365)) (-5 *2 (-1244 *1)) (-4 *1 (-327 *3)))) (-2588 (*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-365)) (-5 *2 (-1244 *1)) (-4 *1 (-327 *4)))) (-1656 (*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-5 *2 (-1244 *3)))) (-1656 (*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-327 *4)) (-4 *4 (-365)) (-5 *2 (-679 *4)))) (-3899 (*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-365)) (-4 *1 (-327 *3)))) (-1497 (*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-5 *2 (-1157 *3)))) (-1492 (*1 *2) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-5 *2 (-1157 *3)))) (-4321 (*1 *2) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-5 *2 (-917)))) (-1836 (*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-5 *2 (-917)))) (-4417 (*1 *2 *1) (-12 (-4 *1 (-327 *2)) (-4 *2 (-365)))) (-1934 (*1 *2 *1) (-12 (-4 *1 (-327 *2)) (-4 *2 (-365)))) (-1497 (*1 *2 *1 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-5 *2 (-1157 *1)) (-4 *1 (-327 *4)))) (-4417 (*1 *1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)))) (-1934 (*1 *1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)))) (-1398 (*1 *1) (-12 (-4 *1 (-327 *2)) (-4 *2 (-370)) (-4 *2 (-365)))) (-2769 (*1 *1) (-12 (-4 *1 (-327 *2)) (-4 *2 (-370)) (-4 *2 (-365)))) (-2151 (*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)) (-5 *2 (-121)))) (-2707 (*1 *1) (-12 (-4 *1 (-327 *2)) (-4 *2 (-370)) (-4 *2 (-365)))) (-3257 (*1 *1 *1 *2) (-12 (-5 *2 (-1157 *3)) (-4 *3 (-370)) (-4 *1 (-327 *3)) (-4 *3 (-365)))) (-1447 (*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)) (-5 *2 (-1157 *3)))) (-2193 (*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)) (-5 *2 (-1157 *3)))) (-2193 (*1 *2 *1 *1) (|partial| -12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)) (-5 *2 (-1157 *3))))) 
+(-13 (-1261 |t#1|) (-1037 |t#1|) (-10 -8 (-15 -2588 ((-1244 $))) (-15 -2588 ((-1244 $) (-917))) (-15 -1656 ((-1244 |t#1|) $)) (-15 -1656 ((-679 |t#1|) (-1244 $))) (-15 -3899 ($ (-1244 |t#1|))) (-15 -1497 ((-1157 |t#1|) $)) (-15 -1492 ((-1157 |t#1|))) (-15 -4321 ((-917))) (-15 -1836 ((-917) $)) (-15 -4417 (|t#1| $)) (-15 -1934 (|t#1| $)) (IF (|has| |t#1| (-370)) (PROGN (-6 (-350)) (-15 -1497 ((-1157 $) $ (-917))) (-15 -4417 ($ $ (-917))) (-15 -1934 ($ $ (-917))) (-15 -1398 ($)) (-15 -2769 ($)) (-15 -2151 ((-121) $)) (-15 -2707 ($)) (-15 -3257 ($ $ (-1157 |t#1|))) (-15 -1447 ((-1157 |t#1|) $)) (-15 -2193 ((-1157 |t#1|) $)) (-15 -2193 ((-3 (-1157 |t#1|) "failed") $ $))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 |#1| |#1|) . T) ((-120 $ $) . T) ((-137) . T) ((-148) -2199 (|has| |#1| (-370)) (|has| |#1| (-148))) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) . T) ((-225) |has| |#1| (-370)) ((-238) . T) ((-285) . T) ((-301) . T) ((-1261 |#1|) . T) ((-365) . T) ((-404) -2199 (|has| |#1| (-370)) (|has| |#1| (-148))) ((-370) |has| |#1| (-370)) ((-350) |has| |#1| (-370)) ((-453) . T) ((-558) . T) ((-637 (-409 (-568))) . T) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) . T) ((-707 |#1|) . T) ((-707 $) . T) ((-716) . T) ((-916) . T) ((-1037 |#1|) . T) ((-1053 (-409 (-568))) . T) ((-1053 |#1|) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1136) |has| |#1| (-370)) ((-1199) . T) ((-1251 |#1|) . T)) 
+((-2449 (((-121) $ $) NIL)) (-2238 (($ (-1160) $) 88)) (-3785 (($) 76)) (-4237 (((-1108) (-1108)) 11)) (-2332 (($) 77)) (-2042 (($) 90) (($ (-310 (-688))) 96) (($ (-310 (-690))) 93) (($ (-310 (-683))) 99) (($ (-310 (-381))) 105) (($ (-310 (-568))) 102) (($ (-310 (-169 (-381)))) 108)) (-3459 (($ (-1160) $) 89)) (-3411 (($ (-634 (-850))) 79)) (-2496 (((-1249) $) 73)) (-1573 (((-3 (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print")) $) 27)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-3838 (($ (-1108)) 45)) (-2558 (((-1094) $) 25)) (-1791 (($ (-1082 (-953 (-568))) $) 85) (($ (-1082 (-953 (-568))) (-953 (-568)) $) 86)) (-2911 (($ (-1108)) 87)) (-4135 (($ (-1160) $) 110) (($ (-1160) $ $) 111)) (-4131 (($ (-1161) (-634 (-1161))) 75)) (-1709 (($ (-1143)) 82) (($ (-634 (-1143))) 80)) (-2747 (((-850) $) 113)) (-2848 (((-3 (|:| |nullBranch| "null") (|:| |assignmentBranch| (-2 (|:| |var| (-1161)) (|:| |arrayIndex| (-634 (-953 (-568)))) (|:| |rand| (-2 (|:| |ints2Floats?| (-121)) (|:| -4153 (-850)))))) (|:| |arrayAssignmentBranch| (-2 (|:| |var| (-1161)) (|:| |rand| (-850)) (|:| |ints2Floats?| (-121)))) (|:| |conditionalBranch| (-2 (|:| |switch| (-1160)) (|:| |thenClause| $) (|:| |elseClause| $))) (|:| |returnBranch| (-2 (|:| -2436 (-121)) (|:| -2852 (-2 (|:| |ints2Floats?| (-121)) (|:| -4153 (-850)))))) (|:| |blockBranch| (-634 $)) (|:| |commentBranch| (-634 (-1143))) (|:| |callBranch| (-1143)) (|:| |forBranch| (-2 (|:| -3581 (-1082 (-953 (-568)))) (|:| |span| (-953 (-568))) (|:| |body| $))) (|:| |labelBranch| (-1108)) (|:| |loopBranch| (-2 (|:| |switch| (-1160)) (|:| |body| $))) (|:| |commonBranch| (-2 (|:| -3393 (-1161)) (|:| |contents| (-634 (-1161))))) (|:| |printBranch| (-634 (-850)))) $) 37)) (-2685 (($ (-1143)) 182)) (-2347 (($ (-634 $)) 109)) (-1963 (($ (-1161) (-1143)) 115) (($ (-1161) (-310 (-690))) 155) (($ (-1161) (-310 (-688))) 156) (($ (-1161) (-310 (-683))) 157) (($ (-1161) (-679 (-690))) 118) (($ (-1161) (-679 (-688))) 121) (($ (-1161) (-679 (-683))) 124) (($ (-1161) (-1244 (-690))) 127) (($ (-1161) (-1244 (-688))) 130) (($ (-1161) (-1244 (-683))) 133) (($ (-1161) (-679 (-310 (-690)))) 136) (($ (-1161) (-679 (-310 (-688)))) 139) (($ (-1161) (-679 (-310 (-683)))) 142) (($ (-1161) (-1244 (-310 (-690)))) 145) (($ (-1161) (-1244 (-310 (-688)))) 148) (($ (-1161) (-1244 (-310 (-683)))) 151) (($ (-1161) (-634 (-953 (-568))) (-310 (-690))) 152) (($ (-1161) (-634 (-953 (-568))) (-310 (-688))) 153) (($ (-1161) (-634 (-953 (-568))) (-310 (-683))) 154) (($ (-1161) (-310 (-568))) 179) (($ (-1161) (-310 (-381))) 180) (($ (-1161) (-310 (-169 (-381)))) 181) (($ (-1161) (-679 (-310 (-568)))) 160) (($ (-1161) (-679 (-310 (-381)))) 163) (($ (-1161) (-679 (-310 (-169 (-381))))) 166) (($ (-1161) (-1244 (-310 (-568)))) 169) (($ (-1161) (-1244 (-310 (-381)))) 172) (($ (-1161) (-1244 (-310 (-169 (-381))))) 175) (($ (-1161) (-634 (-953 (-568))) (-310 (-568))) 176) (($ (-1161) (-634 (-953 (-568))) (-310 (-381))) 177) (($ (-1161) (-634 (-953 (-568))) (-310 (-169 (-381)))) 178)) (-1719 (((-121) $ $) NIL))) 
+(((-328) (-13 (-1090) (-10 -8 (-15 -2747 ((-850) $)) (-15 -1791 ($ (-1082 (-953 (-568))) $)) (-15 -1791 ($ (-1082 (-953 (-568))) (-953 (-568)) $)) (-15 -2238 ($ (-1160) $)) (-15 -3459 ($ (-1160) $)) (-15 -3838 ($ (-1108))) (-15 -2911 ($ (-1108))) (-15 -1709 ($ (-1143))) (-15 -1709 ($ (-634 (-1143)))) (-15 -2685 ($ (-1143))) (-15 -2042 ($)) (-15 -2042 ($ (-310 (-688)))) (-15 -2042 ($ (-310 (-690)))) (-15 -2042 ($ (-310 (-683)))) (-15 -2042 ($ (-310 (-381)))) (-15 -2042 ($ (-310 (-568)))) (-15 -2042 ($ (-310 (-169 (-381))))) (-15 -4135 ($ (-1160) $)) (-15 -4135 ($ (-1160) $ $)) (-15 -1963 ($ (-1161) (-1143))) (-15 -1963 ($ (-1161) (-310 (-690)))) (-15 -1963 ($ (-1161) (-310 (-688)))) (-15 -1963 ($ (-1161) (-310 (-683)))) (-15 -1963 ($ (-1161) (-679 (-690)))) (-15 -1963 ($ (-1161) (-679 (-688)))) (-15 -1963 ($ (-1161) (-679 (-683)))) (-15 -1963 ($ (-1161) (-1244 (-690)))) (-15 -1963 ($ (-1161) (-1244 (-688)))) (-15 -1963 ($ (-1161) (-1244 (-683)))) (-15 -1963 ($ (-1161) (-679 (-310 (-690))))) (-15 -1963 ($ (-1161) (-679 (-310 (-688))))) (-15 -1963 ($ (-1161) (-679 (-310 (-683))))) (-15 -1963 ($ (-1161) (-1244 (-310 (-690))))) (-15 -1963 ($ (-1161) (-1244 (-310 (-688))))) (-15 -1963 ($ (-1161) (-1244 (-310 (-683))))) (-15 -1963 ($ (-1161) (-634 (-953 (-568))) (-310 (-690)))) (-15 -1963 ($ (-1161) (-634 (-953 (-568))) (-310 (-688)))) (-15 -1963 ($ (-1161) (-634 (-953 (-568))) (-310 (-683)))) (-15 -1963 ($ (-1161) (-310 (-568)))) (-15 -1963 ($ (-1161) (-310 (-381)))) (-15 -1963 ($ (-1161) (-310 (-169 (-381))))) (-15 -1963 ($ (-1161) (-679 (-310 (-568))))) (-15 -1963 ($ (-1161) (-679 (-310 (-381))))) (-15 -1963 ($ (-1161) (-679 (-310 (-169 (-381)))))) (-15 -1963 ($ (-1161) (-1244 (-310 (-568))))) (-15 -1963 ($ (-1161) (-1244 (-310 (-381))))) (-15 -1963 ($ (-1161) (-1244 (-310 (-169 (-381)))))) (-15 -1963 ($ (-1161) (-634 (-953 (-568))) (-310 (-568)))) (-15 -1963 ($ (-1161) (-634 (-953 (-568))) (-310 (-381)))) (-15 -1963 ($ (-1161) (-634 (-953 (-568))) (-310 (-169 (-381))))) (-15 -2347 ($ (-634 $))) (-15 -3785 ($)) (-15 -2332 ($)) (-15 -3411 ($ (-634 (-850)))) (-15 -4131 ($ (-1161) (-634 (-1161)))) (-15 -1573 ((-3 (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print")) $)) (-15 -2848 ((-3 (|:| |nullBranch| "null") (|:| |assignmentBranch| (-2 (|:| |var| (-1161)) (|:| |arrayIndex| (-634 (-953 (-568)))) (|:| |rand| (-2 (|:| |ints2Floats?| (-121)) (|:| -4153 (-850)))))) (|:| |arrayAssignmentBranch| (-2 (|:| |var| (-1161)) (|:| |rand| (-850)) (|:| |ints2Floats?| (-121)))) (|:| |conditionalBranch| (-2 (|:| |switch| (-1160)) (|:| |thenClause| $) (|:| |elseClause| $))) (|:| |returnBranch| (-2 (|:| -2436 (-121)) (|:| -2852 (-2 (|:| |ints2Floats?| (-121)) (|:| -4153 (-850)))))) (|:| |blockBranch| (-634 $)) (|:| |commentBranch| (-634 (-1143))) (|:| |callBranch| (-1143)) (|:| |forBranch| (-2 (|:| -3581 (-1082 (-953 (-568)))) (|:| |span| (-953 (-568))) (|:| |body| $))) (|:| |labelBranch| (-1108)) (|:| |loopBranch| (-2 (|:| |switch| (-1160)) (|:| |body| $))) (|:| |commonBranch| (-2 (|:| -3393 (-1161)) (|:| |contents| (-634 (-1161))))) (|:| |printBranch| (-634 (-850)))) $)) (-15 -2496 ((-1249) $)) (-15 -2558 ((-1094) $)) (-15 -4237 ((-1108) (-1108)))))) (T -328)) 
+((-2747 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-328)))) (-1791 (*1 *1 *2 *1) (-12 (-5 *2 (-1082 (-953 (-568)))) (-5 *1 (-328)))) (-1791 (*1 *1 *2 *3 *1) (-12 (-5 *2 (-1082 (-953 (-568)))) (-5 *3 (-953 (-568))) (-5 *1 (-328)))) (-2238 (*1 *1 *2 *1) (-12 (-5 *2 (-1160)) (-5 *1 (-328)))) (-3459 (*1 *1 *2 *1) (-12 (-5 *2 (-1160)) (-5 *1 (-328)))) (-3838 (*1 *1 *2) (-12 (-5 *2 (-1108)) (-5 *1 (-328)))) (-2911 (*1 *1 *2) (-12 (-5 *2 (-1108)) (-5 *1 (-328)))) (-1709 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-328)))) (-1709 (*1 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-328)))) (-2685 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-328)))) (-2042 (*1 *1) (-5 *1 (-328))) (-2042 (*1 *1 *2) (-12 (-5 *2 (-310 (-688))) (-5 *1 (-328)))) (-2042 (*1 *1 *2) (-12 (-5 *2 (-310 (-690))) (-5 *1 (-328)))) (-2042 (*1 *1 *2) (-12 (-5 *2 (-310 (-683))) (-5 *1 (-328)))) (-2042 (*1 *1 *2) (-12 (-5 *2 (-310 (-381))) (-5 *1 (-328)))) (-2042 (*1 *1 *2) (-12 (-5 *2 (-310 (-568))) (-5 *1 (-328)))) (-2042 (*1 *1 *2) (-12 (-5 *2 (-310 (-169 (-381)))) (-5 *1 (-328)))) (-4135 (*1 *1 *2 *1) (-12 (-5 *2 (-1160)) (-5 *1 (-328)))) (-4135 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1160)) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1143)) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-690))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-688))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-683))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-690))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-688))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-683))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-690))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-688))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-683))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-690)))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-688)))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-683)))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-690)))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-688)))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-683)))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-690))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-688))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-683))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-568))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-381))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-169 (-381)))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-568)))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-381)))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-169 (-381))))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-568)))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-381)))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-169 (-381))))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-568))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-381))) (-5 *1 (-328)))) (-1963 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-169 (-381)))) (-5 *1 (-328)))) (-2347 (*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-5 *1 (-328)))) (-3785 (*1 *1) (-5 *1 (-328))) (-2332 (*1 *1) (-5 *1 (-328))) (-3411 (*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-328)))) (-4131 (*1 *1 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-5 *2 (-1161)) (-5 *1 (-328)))) (-1573 (*1 *2 *1) (-12 (-5 *2 (-3 (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print"))) (-5 *1 (-328)))) (-2848 (*1 *2 *1) (-12 (-5 *2 (-3 (|:| |nullBranch| "null") (|:| |assignmentBranch| (-2 (|:| |var| (-1161)) (|:| |arrayIndex| (-634 (-953 (-568)))) (|:| |rand| (-2 (|:| |ints2Floats?| (-121)) (|:| -4153 (-850)))))) (|:| |arrayAssignmentBranch| (-2 (|:| |var| (-1161)) (|:| |rand| (-850)) (|:| |ints2Floats?| (-121)))) (|:| |conditionalBranch| (-2 (|:| |switch| (-1160)) (|:| |thenClause| (-328)) (|:| |elseClause| (-328)))) (|:| |returnBranch| (-2 (|:| -2436 (-121)) (|:| -2852 (-2 (|:| |ints2Floats?| (-121)) (|:| -4153 (-850)))))) (|:| |blockBranch| (-634 (-328))) (|:| |commentBranch| (-634 (-1143))) (|:| |callBranch| (-1143)) (|:| |forBranch| (-2 (|:| -3581 (-1082 (-953 (-568)))) (|:| |span| (-953 (-568))) (|:| |body| (-328)))) (|:| |labelBranch| (-1108)) (|:| |loopBranch| (-2 (|:| |switch| (-1160)) (|:| |body| (-328)))) (|:| |commonBranch| (-2 (|:| -3393 (-1161)) (|:| |contents| (-634 (-1161))))) (|:| |printBranch| (-634 (-850))))) (-5 *1 (-328)))) (-2496 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-328)))) (-2558 (*1 *2 *1) (-12 (-5 *2 (-1094)) (-5 *1 (-328)))) (-4237 (*1 *2 *2) (-12 (-5 *2 (-1108)) (-5 *1 (-328))))) 
+(-13 (-1090) (-10 -8 (-15 -2747 ((-850) $)) (-15 -1791 ($ (-1082 (-953 (-568))) $)) (-15 -1791 ($ (-1082 (-953 (-568))) (-953 (-568)) $)) (-15 -2238 ($ (-1160) $)) (-15 -3459 ($ (-1160) $)) (-15 -3838 ($ (-1108))) (-15 -2911 ($ (-1108))) (-15 -1709 ($ (-1143))) (-15 -1709 ($ (-634 (-1143)))) (-15 -2685 ($ (-1143))) (-15 -2042 ($)) (-15 -2042 ($ (-310 (-688)))) (-15 -2042 ($ (-310 (-690)))) (-15 -2042 ($ (-310 (-683)))) (-15 -2042 ($ (-310 (-381)))) (-15 -2042 ($ (-310 (-568)))) (-15 -2042 ($ (-310 (-169 (-381))))) (-15 -4135 ($ (-1160) $)) (-15 -4135 ($ (-1160) $ $)) (-15 -1963 ($ (-1161) (-1143))) (-15 -1963 ($ (-1161) (-310 (-690)))) (-15 -1963 ($ (-1161) (-310 (-688)))) (-15 -1963 ($ (-1161) (-310 (-683)))) (-15 -1963 ($ (-1161) (-679 (-690)))) (-15 -1963 ($ (-1161) (-679 (-688)))) (-15 -1963 ($ (-1161) (-679 (-683)))) (-15 -1963 ($ (-1161) (-1244 (-690)))) (-15 -1963 ($ (-1161) (-1244 (-688)))) (-15 -1963 ($ (-1161) (-1244 (-683)))) (-15 -1963 ($ (-1161) (-679 (-310 (-690))))) (-15 -1963 ($ (-1161) (-679 (-310 (-688))))) (-15 -1963 ($ (-1161) (-679 (-310 (-683))))) (-15 -1963 ($ (-1161) (-1244 (-310 (-690))))) (-15 -1963 ($ (-1161) (-1244 (-310 (-688))))) (-15 -1963 ($ (-1161) (-1244 (-310 (-683))))) (-15 -1963 ($ (-1161) (-634 (-953 (-568))) (-310 (-690)))) (-15 -1963 ($ (-1161) (-634 (-953 (-568))) (-310 (-688)))) (-15 -1963 ($ (-1161) (-634 (-953 (-568))) (-310 (-683)))) (-15 -1963 ($ (-1161) (-310 (-568)))) (-15 -1963 ($ (-1161) (-310 (-381)))) (-15 -1963 ($ (-1161) (-310 (-169 (-381))))) (-15 -1963 ($ (-1161) (-679 (-310 (-568))))) (-15 -1963 ($ (-1161) (-679 (-310 (-381))))) (-15 -1963 ($ (-1161) (-679 (-310 (-169 (-381)))))) (-15 -1963 ($ (-1161) (-1244 (-310 (-568))))) (-15 -1963 ($ (-1161) (-1244 (-310 (-381))))) (-15 -1963 ($ (-1161) (-1244 (-310 (-169 (-381)))))) (-15 -1963 ($ (-1161) (-634 (-953 (-568))) (-310 (-568)))) (-15 -1963 ($ (-1161) (-634 (-953 (-568))) (-310 (-381)))) (-15 -1963 ($ (-1161) (-634 (-953 (-568))) (-310 (-169 (-381))))) (-15 -2347 ($ (-634 $))) (-15 -3785 ($)) (-15 -2332 ($)) (-15 -3411 ($ (-634 (-850)))) (-15 -4131 ($ (-1161) (-634 (-1161)))) (-15 -1573 ((-3 (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print")) $)) (-15 -2848 ((-3 (|:| |nullBranch| "null") (|:| |assignmentBranch| (-2 (|:| |var| (-1161)) (|:| |arrayIndex| (-634 (-953 (-568)))) (|:| |rand| (-2 (|:| |ints2Floats?| (-121)) (|:| -4153 (-850)))))) (|:| |arrayAssignmentBranch| (-2 (|:| |var| (-1161)) (|:| |rand| (-850)) (|:| |ints2Floats?| (-121)))) (|:| |conditionalBranch| (-2 (|:| |switch| (-1160)) (|:| |thenClause| $) (|:| |elseClause| $))) (|:| |returnBranch| (-2 (|:| -2436 (-121)) (|:| -2852 (-2 (|:| |ints2Floats?| (-121)) (|:| -4153 (-850)))))) (|:| |blockBranch| (-634 $)) (|:| |commentBranch| (-634 (-1143))) (|:| |callBranch| (-1143)) (|:| |forBranch| (-2 (|:| -3581 (-1082 (-953 (-568)))) (|:| |span| (-953 (-568))) (|:| |body| $))) (|:| |labelBranch| (-1108)) (|:| |loopBranch| (-2 (|:| |switch| (-1160)) (|:| |body| $))) (|:| |commonBranch| (-2 (|:| -3393 (-1161)) (|:| |contents| (-634 (-1161))))) (|:| |printBranch| (-634 (-850)))) $)) (-15 -2496 ((-1249) $)) (-15 -2558 ((-1094) $)) (-15 -4237 ((-1108) (-1108))))) 
+((-2449 (((-121) $ $) NIL)) (-1619 (((-121) $) 11)) (-2788 (($ |#1|) 8)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2792 (($ |#1|) 9)) (-2747 (((-850) $) 17)) (-2014 ((|#1| $) 12)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 19))) 
+(((-329 |#1|) (-13 (-842) (-10 -8 (-15 -2788 ($ |#1|)) (-15 -2792 ($ |#1|)) (-15 -1619 ((-121) $)) (-15 -2014 (|#1| $)))) (-842)) (T -329)) 
+((-2788 (*1 *1 *2) (-12 (-5 *1 (-329 *2)) (-4 *2 (-842)))) (-2792 (*1 *1 *2) (-12 (-5 *1 (-329 *2)) (-4 *2 (-842)))) (-1619 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-329 *3)) (-4 *3 (-842)))) (-2014 (*1 *2 *1) (-12 (-5 *1 (-329 *2)) (-4 *2 (-842))))) 
+(-13 (-842) (-10 -8 (-15 -2788 ($ |#1|)) (-15 -2792 ($ |#1|)) (-15 -1619 ((-121) $)) (-15 -2014 (|#1| $)))) 
+((-3697 (((-328) (-1161) (-953 (-568))) 22)) (-2869 (((-328) (-1161) (-953 (-568))) 26)) (-3775 (((-328) (-1161) (-1082 (-953 (-568))) (-1082 (-953 (-568)))) 25) (((-328) (-1161) (-953 (-568)) (-953 (-568))) 23)) (-1429 (((-328) (-1161) (-953 (-568))) 30))) 
+(((-330) (-10 -7 (-15 -3697 ((-328) (-1161) (-953 (-568)))) (-15 -3775 ((-328) (-1161) (-953 (-568)) (-953 (-568)))) (-15 -3775 ((-328) (-1161) (-1082 (-953 (-568))) (-1082 (-953 (-568))))) (-15 -2869 ((-328) (-1161) (-953 (-568)))) (-15 -1429 ((-328) (-1161) (-953 (-568)))))) (T -330)) 
+((-1429 (*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-953 (-568))) (-5 *2 (-328)) (-5 *1 (-330)))) (-2869 (*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-953 (-568))) (-5 *2 (-328)) (-5 *1 (-330)))) (-3775 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-1082 (-953 (-568)))) (-5 *2 (-328)) (-5 *1 (-330)))) (-3775 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-953 (-568))) (-5 *2 (-328)) (-5 *1 (-330)))) (-3697 (*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-953 (-568))) (-5 *2 (-328)) (-5 *1 (-330))))) 
+(-10 -7 (-15 -3697 ((-328) (-1161) (-953 (-568)))) (-15 -3775 ((-328) (-1161) (-953 (-568)) (-953 (-568)))) (-15 -3775 ((-328) (-1161) (-1082 (-953 (-568))) (-1082 (-953 (-568))))) (-15 -2869 ((-328) (-1161) (-953 (-568)))) (-15 -1429 ((-328) (-1161) (-953 (-568))))) 
+((-2797 (((-334 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-334 |#1| |#2| |#3| |#4|)) 31))) 
+(((-331 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -2797 ((-334 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-334 |#1| |#2| |#3| |#4|)))) (-365) (-1219 |#1|) (-1219 (-409 |#2|)) (-340 |#1| |#2| |#3|) (-365) (-1219 |#5|) (-1219 (-409 |#6|)) (-340 |#5| |#6| |#7|)) (T -331)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *5)) (-5 *4 (-334 *5 *6 *7 *8)) (-4 *5 (-365)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-4 *8 (-340 *5 *6 *7)) (-4 *9 (-365)) (-4 *10 (-1219 *9)) (-4 *11 (-1219 (-409 *10))) (-5 *2 (-334 *9 *10 *11 *12)) (-5 *1 (-331 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *12 (-340 *9 *10 *11))))) 
+(-10 -7 (-15 -2797 ((-334 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-334 |#1| |#2| |#3| |#4|)))) 
+((-2776 (((-121) $) 14))) 
+(((-332 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 -2776 ((-121) |#1|))) (-333 |#2| |#3| |#4| |#5|) (-365) (-1219 |#2|) (-1219 (-409 |#3|)) (-340 |#2| |#3| |#4|)) (T -332)) 
+NIL 
+(-10 -8 (-15 -2776 ((-121) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-3094 (($ $) 25)) (-2776 (((-121) $) 24)) (-1893 (((-1143) $) 9)) (-4314 (((-415 |#2| (-409 |#2|) |#3| |#4|) $) 31)) (-4025 (((-1108) $) 10)) (-2707 (((-3 |#4| "failed") $) 23)) (-3957 (($ (-415 |#2| (-409 |#2|) |#3| |#4|)) 30) (($ |#4|) 29) (($ |#1| |#1|) 28) (($ |#1| |#1| (-568)) 27) (($ |#4| |#2| |#2| |#2| |#1|) 22)) (-3946 (((-2 (|:| -1716 (-415 |#2| (-409 |#2|) |#3| |#4|)) (|:| |principalPart| |#4|)) $) 26)) (-2747 (((-850) $) 11)) (-3058 (($) 17 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19))) 
 (((-333 |#1| |#2| |#3| |#4|) (-1275) (-365) (-1219 |t#1|) (-1219 (-409 |t#2|)) (-340 |t#1| |t#2| |t#3|)) (T -333)) 
-((-1552 (*1 *2 *1) (-12 (-4 *1 (-333 *3 *4 *5 *6)) (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 *3 *4 *5)) (-5 *2 (-415 *4 (-409 *4) *5 *6)))) (-2849 (*1 *1 *2) (-12 (-5 *2 (-415 *4 (-409 *4) *5 *6)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 *3 *4 *5)) (-4 *3 (-365)) (-4 *1 (-333 *3 *4 *5 *6)))) (-2849 (*1 *1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *1 (-333 *3 *4 *5 *2)) (-4 *2 (-340 *3 *4 *5)))) (-2849 (*1 *1 *2 *2) (-12 (-4 *2 (-365)) (-4 *3 (-1219 *2)) (-4 *4 (-1219 (-409 *3))) (-4 *1 (-333 *2 *3 *4 *5)) (-4 *5 (-340 *2 *3 *4)))) (-2849 (*1 *1 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *2 (-365)) (-4 *4 (-1219 *2)) (-4 *5 (-1219 (-409 *4))) (-4 *1 (-333 *2 *4 *5 *6)) (-4 *6 (-340 *2 *4 *5)))) (-2847 (*1 *2 *1) (-12 (-4 *1 (-333 *3 *4 *5 *6)) (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 *3 *4 *5)) (-5 *2 (-2 (|:| -1713 (-415 *4 (-409 *4) *5 *6)) (|:| |principalPart| *6))))) (-3092 (*1 *1 *1) (-12 (-4 *1 (-333 *2 *3 *4 *5)) (-4 *2 (-365)) (-4 *3 (-1219 *2)) (-4 *4 (-1219 (-409 *3))) (-4 *5 (-340 *2 *3 *4)))) (-2886 (*1 *2 *1) (-12 (-4 *1 (-333 *3 *4 *5 *6)) (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 *3 *4 *5)) (-5 *2 (-121)))) (-2704 (*1 *2 *1) (|partial| -12 (-4 *1 (-333 *3 *4 *5 *2)) (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *2 (-340 *3 *4 *5)))) (-2849 (*1 *1 *2 *3 *3 *3 *4) (-12 (-4 *4 (-365)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 (-409 *3))) (-4 *1 (-333 *4 *3 *5 *2)) (-4 *2 (-340 *4 *3 *5))))) 
-(-13 (-21) (-10 -8 (-15 -1552 ((-415 |t#2| (-409 |t#2|) |t#3| |t#4|) $)) (-15 -2849 ($ (-415 |t#2| (-409 |t#2|) |t#3| |t#4|))) (-15 -2849 ($ |t#4|)) (-15 -2849 ($ |t#1| |t#1|)) (-15 -2849 ($ |t#1| |t#1| (-568))) (-15 -2847 ((-2 (|:| -1713 (-415 |t#2| (-409 |t#2|) |t#3| |t#4|)) (|:| |principalPart| |t#4|)) $)) (-15 -3092 ($ $)) (-15 -2886 ((-121) $)) (-15 -2704 ((-3 |t#4| "failed") $)) (-15 -2849 ($ |t#4| |t#2| |t#2| |t#2| |t#1|)))) 
+((-4314 (*1 *2 *1) (-12 (-4 *1 (-333 *3 *4 *5 *6)) (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 *3 *4 *5)) (-5 *2 (-415 *4 (-409 *4) *5 *6)))) (-3957 (*1 *1 *2) (-12 (-5 *2 (-415 *4 (-409 *4) *5 *6)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 *3 *4 *5)) (-4 *3 (-365)) (-4 *1 (-333 *3 *4 *5 *6)))) (-3957 (*1 *1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *1 (-333 *3 *4 *5 *2)) (-4 *2 (-340 *3 *4 *5)))) (-3957 (*1 *1 *2 *2) (-12 (-4 *2 (-365)) (-4 *3 (-1219 *2)) (-4 *4 (-1219 (-409 *3))) (-4 *1 (-333 *2 *3 *4 *5)) (-4 *5 (-340 *2 *3 *4)))) (-3957 (*1 *1 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *2 (-365)) (-4 *4 (-1219 *2)) (-4 *5 (-1219 (-409 *4))) (-4 *1 (-333 *2 *4 *5 *6)) (-4 *6 (-340 *2 *4 *5)))) (-3946 (*1 *2 *1) (-12 (-4 *1 (-333 *3 *4 *5 *6)) (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 *3 *4 *5)) (-5 *2 (-2 (|:| -1716 (-415 *4 (-409 *4) *5 *6)) (|:| |principalPart| *6))))) (-3094 (*1 *1 *1) (-12 (-4 *1 (-333 *2 *3 *4 *5)) (-4 *2 (-365)) (-4 *3 (-1219 *2)) (-4 *4 (-1219 (-409 *3))) (-4 *5 (-340 *2 *3 *4)))) (-2776 (*1 *2 *1) (-12 (-4 *1 (-333 *3 *4 *5 *6)) (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 *3 *4 *5)) (-5 *2 (-121)))) (-2707 (*1 *2 *1) (|partial| -12 (-4 *1 (-333 *3 *4 *5 *2)) (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *2 (-340 *3 *4 *5)))) (-3957 (*1 *1 *2 *3 *3 *3 *4) (-12 (-4 *4 (-365)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 (-409 *3))) (-4 *1 (-333 *4 *3 *5 *2)) (-4 *2 (-340 *4 *3 *5))))) 
+(-13 (-21) (-10 -8 (-15 -4314 ((-415 |t#2| (-409 |t#2|) |t#3| |t#4|) $)) (-15 -3957 ($ (-415 |t#2| (-409 |t#2|) |t#3| |t#4|))) (-15 -3957 ($ |t#4|)) (-15 -3957 ($ |t#1| |t#1|)) (-15 -3957 ($ |t#1| |t#1| (-568))) (-15 -3946 ((-2 (|:| -1716 (-415 |t#2| (-409 |t#2|) |t#3| |t#4|)) (|:| |principalPart| |t#4|)) $)) (-15 -3094 ($ $)) (-15 -2776 ((-121) $)) (-15 -2707 ((-3 |t#4| "failed") $)) (-15 -3957 ($ |t#4| |t#2| |t#2| |t#2| |t#1|)))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-137) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-3092 (($ $) 32)) (-2886 (((-121) $) NIL)) (-4487 (((-1143) $) NIL)) (-4147 (((-1244 |#4|) $) 124)) (-1552 (((-415 |#2| (-409 |#2|) |#3| |#4|) $) 30)) (-4022 (((-1108) $) NIL)) (-2704 (((-3 |#4| "failed") $) 35)) (-2442 (((-1244 |#4|) $) 117)) (-2849 (($ (-415 |#2| (-409 |#2|) |#3| |#4|)) 40) (($ |#4|) 42) (($ |#1| |#1|) 44) (($ |#1| |#1| (-568)) 46) (($ |#4| |#2| |#2| |#2| |#1|) 48)) (-2847 (((-2 (|:| -1713 (-415 |#2| (-409 |#2|) |#3| |#4|)) (|:| |principalPart| |#4|)) $) 38)) (-2745 (((-850) $) 17)) (-3056 (($) 14 T CONST)) (-1717 (((-121) $ $) 20)) (-1773 (($ $) 27) (($ $ $) NIL)) (-1767 (($ $ $) 25)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 23))) 
-(((-334 |#1| |#2| |#3| |#4|) (-13 (-333 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -2442 ((-1244 |#4|) $)) (-15 -4147 ((-1244 |#4|) $)))) (-365) (-1219 |#1|) (-1219 (-409 |#2|)) (-340 |#1| |#2| |#3|)) (T -334)) 
-((-2442 (*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-1244 *6)) (-5 *1 (-334 *3 *4 *5 *6)) (-4 *6 (-340 *3 *4 *5)))) (-4147 (*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-1244 *6)) (-5 *1 (-334 *3 *4 *5 *6)) (-4 *6 (-340 *3 *4 *5))))) 
-(-13 (-333 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -2442 ((-1244 |#4|) $)) (-15 -4147 ((-1244 |#4|) $)))) 
-((-1339 (($ $ (-1161) |#2|) NIL) (($ $ (-634 (-1161)) (-634 |#2|)) 18) (($ $ (-634 (-288 |#2|))) 14) (($ $ (-288 |#2|)) NIL) (($ $ |#2| |#2|) NIL) (($ $ (-634 |#2|) (-634 |#2|)) NIL)) (-2779 (($ $ |#2|) 11))) 
-(((-335 |#1| |#2|) (-10 -8 (-15 -2779 (|#1| |#1| |#2|)) (-15 -1339 (|#1| |#1| (-634 |#2|) (-634 |#2|))) (-15 -1339 (|#1| |#1| |#2| |#2|)) (-15 -1339 (|#1| |#1| (-288 |#2|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#2|)))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 |#2|))) (-15 -1339 (|#1| |#1| (-1161) |#2|))) (-336 |#2|) (-1090)) (T -335)) 
-NIL 
-(-10 -8 (-15 -2779 (|#1| |#1| |#2|)) (-15 -1339 (|#1| |#1| (-634 |#2|) (-634 |#2|))) (-15 -1339 (|#1| |#1| |#2| |#2|)) (-15 -1339 (|#1| |#1| (-288 |#2|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#2|)))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 |#2|))) (-15 -1339 (|#1| |#1| (-1161) |#2|))) 
-((-2795 (($ (-1 |#1| |#1|) $) 6)) (-1339 (($ $ (-1161) |#1|) 16 (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-634 (-1161)) (-634 |#1|)) 15 (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-634 (-288 |#1|))) 14 (|has| |#1| (-303 |#1|))) (($ $ (-288 |#1|)) 13 (|has| |#1| (-303 |#1|))) (($ $ |#1| |#1|) 12 (|has| |#1| (-303 |#1|))) (($ $ (-634 |#1|) (-634 |#1|)) 11 (|has| |#1| (-303 |#1|)))) (-2779 (($ $ |#1|) 10 (|has| |#1| (-281 |#1| |#1|))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-3094 (($ $) 32)) (-2776 (((-121) $) NIL)) (-1893 (((-1143) $) NIL)) (-3804 (((-1244 |#4|) $) 124)) (-4314 (((-415 |#2| (-409 |#2|) |#3| |#4|) $) 30)) (-4025 (((-1108) $) NIL)) (-2707 (((-3 |#4| "failed") $) 35)) (-2482 (((-1244 |#4|) $) 117)) (-3957 (($ (-415 |#2| (-409 |#2|) |#3| |#4|)) 40) (($ |#4|) 42) (($ |#1| |#1|) 44) (($ |#1| |#1| (-568)) 46) (($ |#4| |#2| |#2| |#2| |#1|) 48)) (-3946 (((-2 (|:| -1716 (-415 |#2| (-409 |#2|) |#3| |#4|)) (|:| |principalPart| |#4|)) $) 38)) (-2747 (((-850) $) 17)) (-3058 (($) 14 T CONST)) (-1719 (((-121) $ $) 20)) (-1775 (($ $) 27) (($ $ $) NIL)) (-1769 (($ $ $) 25)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 23))) 
+(((-334 |#1| |#2| |#3| |#4|) (-13 (-333 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -2482 ((-1244 |#4|) $)) (-15 -3804 ((-1244 |#4|) $)))) (-365) (-1219 |#1|) (-1219 (-409 |#2|)) (-340 |#1| |#2| |#3|)) (T -334)) 
+((-2482 (*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-1244 *6)) (-5 *1 (-334 *3 *4 *5 *6)) (-4 *6 (-340 *3 *4 *5)))) (-3804 (*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-1244 *6)) (-5 *1 (-334 *3 *4 *5 *6)) (-4 *6 (-340 *3 *4 *5))))) 
+(-13 (-333 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -2482 ((-1244 |#4|) $)) (-15 -3804 ((-1244 |#4|) $)))) 
+((-1339 (($ $ (-1161) |#2|) NIL) (($ $ (-634 (-1161)) (-634 |#2|)) 18) (($ $ (-634 (-288 |#2|))) 14) (($ $ (-288 |#2|)) NIL) (($ $ |#2| |#2|) NIL) (($ $ (-634 |#2|) (-634 |#2|)) NIL)) (-2781 (($ $ |#2|) 11))) 
+(((-335 |#1| |#2|) (-10 -8 (-15 -2781 (|#1| |#1| |#2|)) (-15 -1339 (|#1| |#1| (-634 |#2|) (-634 |#2|))) (-15 -1339 (|#1| |#1| |#2| |#2|)) (-15 -1339 (|#1| |#1| (-288 |#2|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#2|)))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 |#2|))) (-15 -1339 (|#1| |#1| (-1161) |#2|))) (-336 |#2|) (-1090)) (T -335)) 
+NIL 
+(-10 -8 (-15 -2781 (|#1| |#1| |#2|)) (-15 -1339 (|#1| |#1| (-634 |#2|) (-634 |#2|))) (-15 -1339 (|#1| |#1| |#2| |#2|)) (-15 -1339 (|#1| |#1| (-288 |#2|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#2|)))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 |#2|))) (-15 -1339 (|#1| |#1| (-1161) |#2|))) 
+((-2797 (($ (-1 |#1| |#1|) $) 6)) (-1339 (($ $ (-1161) |#1|) 16 (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-634 (-1161)) (-634 |#1|)) 15 (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-634 (-288 |#1|))) 14 (|has| |#1| (-303 |#1|))) (($ $ (-288 |#1|)) 13 (|has| |#1| (-303 |#1|))) (($ $ |#1| |#1|) 12 (|has| |#1| (-303 |#1|))) (($ $ (-634 |#1|) (-634 |#1|)) 11 (|has| |#1| (-303 |#1|)))) (-2781 (($ $ |#1|) 10 (|has| |#1| (-281 |#1| |#1|))))) 
 (((-336 |#1|) (-1275) (-1090)) (T -336)) 
-((-2795 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-336 *3)) (-4 *3 (-1090))))) 
-(-13 (-10 -8 (-15 -2795 ($ (-1 |t#1| |t#1|) $)) (IF (|has| |t#1| (-281 |t#1| |t#1|)) (-6 (-281 |t#1| $)) |noBranch|) (IF (|has| |t#1| (-303 |t#1|)) (-6 (-303 |t#1|)) |noBranch|) (IF (|has| |t#1| (-523 (-1161) |t#1|)) (-6 (-523 (-1161) |t#1|)) |noBranch|))) 
+((-2797 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-336 *3)) (-4 *3 (-1090))))) 
+(-13 (-10 -8 (-15 -2797 ($ (-1 |t#1| |t#1|) $)) (IF (|has| |t#1| (-281 |t#1| |t#1|)) (-6 (-281 |t#1| $)) |noBranch|) (IF (|has| |t#1| (-303 |t#1|)) (-6 (-303 |t#1|)) |noBranch|) (IF (|has| |t#1| (-523 (-1161) |t#1|)) (-6 (-523 (-1161) |t#1|)) |noBranch|))) 
 (((-281 |#1| $) |has| |#1| (-281 |#1| |#1|)) ((-303 |#1|) |has| |#1| (-303 |#1|)) ((-523 (-1161) |#1|) |has| |#1| (-523 (-1161) |#1|)) ((-523 |#1| |#1|) |has| |#1| (-303 |#1|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2055 (((-634 (-1161)) $) NIL)) (-3610 (((-121)) 87) (((-121) (-121)) 88)) (-3001 (((-634 (-607 $)) $) NIL)) (-1982 (($ $) NIL)) (-1933 (($ $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2366 (($ $ (-288 $)) NIL) (($ $ (-634 (-288 $))) NIL) (($ $ (-634 (-607 $)) (-634 $)) NIL)) (-1902 (($ $) NIL)) (-1974 (($ $) NIL)) (-2786 (($ $) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-607 $) "failed") $) NIL) (((-3 |#3| "failed") $) NIL) (((-3 $ "failed") (-310 |#3|)) 69) (((-3 $ "failed") (-1161)) 93) (((-3 $ "failed") (-310 (-568))) 56 (|has| |#3| (-1037 (-568)))) (((-3 $ "failed") (-409 (-953 (-568)))) 62 (|has| |#3| (-1037 (-568)))) (((-3 $ "failed") (-953 (-568))) 57 (|has| |#3| (-1037 (-568)))) (((-3 $ "failed") (-310 (-381))) 74 (|has| |#3| (-1037 (-381)))) (((-3 $ "failed") (-409 (-953 (-381)))) 80 (|has| |#3| (-1037 (-381)))) (((-3 $ "failed") (-953 (-381))) 75 (|has| |#3| (-1037 (-381))))) (-2854 (((-607 $) $) NIL) ((|#3| $) NIL) (($ (-310 |#3|)) 70) (($ (-1161)) 94) (($ (-310 (-568))) 58 (|has| |#3| (-1037 (-568)))) (($ (-409 (-953 (-568)))) 63 (|has| |#3| (-1037 (-568)))) (($ (-953 (-568))) 59 (|has| |#3| (-1037 (-568)))) (($ (-310 (-381))) 76 (|has| |#3| (-1037 (-381)))) (($ (-409 (-953 (-381)))) 81 (|has| |#3| (-1037 (-381)))) (($ (-953 (-381))) 77 (|has| |#3| (-1037 (-381))))) (-2925 (((-3 $ "failed") $) NIL)) (-1897 (($) 10)) (-4499 (($ $) NIL) (($ (-634 $)) NIL)) (-3296 (((-634 (-123)) $) NIL)) (-3488 (((-123) (-123)) NIL)) (-2735 (((-121) $) NIL)) (-1825 (((-121) $) NIL (|has| $ (-1037 (-568))))) (-3007 (((-1157 $) (-607 $)) NIL (|has| $ (-1047)))) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-2795 (($ (-1 $ $) (-607 $)) NIL)) (-3693 (((-3 (-607 $) "failed") $) NIL)) (-1907 (($ $) 90)) (-4416 (($ $) NIL)) (-4487 (((-1143) $) NIL)) (-3804 (((-634 (-607 $)) $) NIL)) (-3443 (($ (-123) $) 89) (($ (-123) (-634 $)) NIL)) (-2841 (((-121) $ (-123)) NIL) (((-121) $ (-1161)) NIL)) (-2961 (((-763) $) NIL)) (-4022 (((-1108) $) NIL)) (-4059 (((-121) $ $) NIL) (((-121) $ (-1161)) NIL)) (-1892 (($ $) NIL)) (-3277 (((-121) $) NIL (|has| $ (-1037 (-568))))) (-1339 (($ $ (-607 $) $) NIL) (($ $ (-634 (-607 $)) (-634 $)) NIL) (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ $))) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-1161) (-1 $ (-634 $))) NIL) (($ $ (-1161) (-1 $ $)) NIL) (($ $ (-634 (-123)) (-634 (-1 $ $))) NIL) (($ $ (-634 (-123)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-123) (-1 $ (-634 $))) NIL) (($ $ (-123) (-1 $ $)) NIL)) (-2779 (($ (-123) $) NIL) (($ (-123) $ $) NIL) (($ (-123) $ $ $) NIL) (($ (-123) $ $ $ $) NIL) (($ (-123) (-634 $)) NIL)) (-3502 (($ $) NIL) (($ $ $) NIL)) (-4189 (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) NIL)) (-1626 (($ $) NIL (|has| $ (-1047)))) (-1978 (($ $) NIL)) (-2790 (($ $) NIL)) (-2745 (((-850) $) NIL) (($ (-607 $)) NIL) (($ |#3|) NIL) (($ (-568)) NIL) (((-310 |#3|) $) 92)) (-4078 (((-763)) NIL)) (-2092 (($ $) NIL) (($ (-634 $)) NIL)) (-2887 (((-121) (-123)) NIL)) (-1958 (($ $) NIL)) (-1949 (($ $) NIL)) (-1953 (($ $) NIL)) (-2897 (($ $) NIL)) (-1887 (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (-3056 (($) 91 T CONST)) (-1556 (($) 22 T CONST)) (-3190 (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) NIL)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) NIL)) (-1773 (($ $ $) NIL) (($ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (* (($ |#3| $) NIL) (($ $ |#3|) NIL) (($ $ $) NIL) (($ (-568) $) NIL) (($ (-763) $) NIL) (($ (-917) $) NIL))) 
-(((-337 |#1| |#2| |#3|) (-13 (-296) (-43 |#3|) (-1037 |#3|) (-895 (-1161)) (-10 -8 (-15 -2854 ($ (-310 |#3|))) (-15 -3666 ((-3 $ "failed") (-310 |#3|))) (-15 -2854 ($ (-1161))) (-15 -3666 ((-3 $ "failed") (-1161))) (-15 -2745 ((-310 |#3|) $)) (IF (|has| |#3| (-1037 (-568))) (PROGN (-15 -2854 ($ (-310 (-568)))) (-15 -3666 ((-3 $ "failed") (-310 (-568)))) (-15 -2854 ($ (-409 (-953 (-568))))) (-15 -3666 ((-3 $ "failed") (-409 (-953 (-568))))) (-15 -2854 ($ (-953 (-568)))) (-15 -3666 ((-3 $ "failed") (-953 (-568))))) |noBranch|) (IF (|has| |#3| (-1037 (-381))) (PROGN (-15 -2854 ($ (-310 (-381)))) (-15 -3666 ((-3 $ "failed") (-310 (-381)))) (-15 -2854 ($ (-409 (-953 (-381))))) (-15 -3666 ((-3 $ "failed") (-409 (-953 (-381))))) (-15 -2854 ($ (-953 (-381)))) (-15 -3666 ((-3 $ "failed") (-953 (-381))))) |noBranch|) (-15 -2897 ($ $)) (-15 -1902 ($ $)) (-15 -1892 ($ $)) (-15 -4416 ($ $)) (-15 -1907 ($ $)) (-15 -2786 ($ $)) (-15 -2790 ($ $)) (-15 -1933 ($ $)) (-15 -1949 ($ $)) (-15 -1953 ($ $)) (-15 -1958 ($ $)) (-15 -1974 ($ $)) (-15 -1978 ($ $)) (-15 -1982 ($ $)) (-15 -1897 ($)) (-15 -2055 ((-634 (-1161)) $)) (-15 -3610 ((-121))) (-15 -3610 ((-121) (-121))))) (-634 (-1161)) (-634 (-1161)) (-389)) (T -337)) 
-((-2854 (*1 *1 *2) (-12 (-5 *2 (-310 *5)) (-4 *5 (-389)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-310 *5)) (-4 *5 (-389)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 *2)) (-14 *4 (-634 *2)) (-4 *5 (-389)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-1161)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 *2)) (-14 *4 (-634 *2)) (-4 *5 (-389)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-310 *5)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-310 (-568))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-310 (-568))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-409 (-953 (-568)))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-409 (-953 (-568)))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-953 (-568))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-953 (-568))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-310 (-381))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-310 (-381))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-409 (-953 (-381)))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-409 (-953 (-381)))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-953 (-381))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-953 (-381))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-2897 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-1902 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-1892 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-4416 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-1907 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-2786 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-2790 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-1933 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-1949 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-1953 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-1958 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-1974 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-1978 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-1982 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-1897 (*1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-2055 (*1 *2 *1) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-337 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-389)))) (-3610 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-3610 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389))))) 
-(-13 (-296) (-43 |#3|) (-1037 |#3|) (-895 (-1161)) (-10 -8 (-15 -2854 ($ (-310 |#3|))) (-15 -3666 ((-3 $ "failed") (-310 |#3|))) (-15 -2854 ($ (-1161))) (-15 -3666 ((-3 $ "failed") (-1161))) (-15 -2745 ((-310 |#3|) $)) (IF (|has| |#3| (-1037 (-568))) (PROGN (-15 -2854 ($ (-310 (-568)))) (-15 -3666 ((-3 $ "failed") (-310 (-568)))) (-15 -2854 ($ (-409 (-953 (-568))))) (-15 -3666 ((-3 $ "failed") (-409 (-953 (-568))))) (-15 -2854 ($ (-953 (-568)))) (-15 -3666 ((-3 $ "failed") (-953 (-568))))) |noBranch|) (IF (|has| |#3| (-1037 (-381))) (PROGN (-15 -2854 ($ (-310 (-381)))) (-15 -3666 ((-3 $ "failed") (-310 (-381)))) (-15 -2854 ($ (-409 (-953 (-381))))) (-15 -3666 ((-3 $ "failed") (-409 (-953 (-381))))) (-15 -2854 ($ (-953 (-381)))) (-15 -3666 ((-3 $ "failed") (-953 (-381))))) |noBranch|) (-15 -2897 ($ $)) (-15 -1902 ($ $)) (-15 -1892 ($ $)) (-15 -4416 ($ $)) (-15 -1907 ($ $)) (-15 -2786 ($ $)) (-15 -2790 ($ $)) (-15 -1933 ($ $)) (-15 -1949 ($ $)) (-15 -1953 ($ $)) (-15 -1958 ($ $)) (-15 -1974 ($ $)) (-15 -1978 ($ $)) (-15 -1982 ($ $)) (-15 -1897 ($)) (-15 -2055 ((-634 (-1161)) $)) (-15 -3610 ((-121))) (-15 -3610 ((-121) (-121))))) 
-((-2795 ((|#8| (-1 |#5| |#1|) |#4|) 19))) 
-(((-338 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -2795 (|#8| (-1 |#5| |#1|) |#4|))) (-1199) (-1219 |#1|) (-1219 (-409 |#2|)) (-340 |#1| |#2| |#3|) (-1199) (-1219 |#5|) (-1219 (-409 |#6|)) (-340 |#5| |#6| |#7|)) (T -338)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *5)) (-4 *5 (-1199)) (-4 *8 (-1199)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-4 *9 (-1219 *8)) (-4 *2 (-340 *8 *9 *10)) (-5 *1 (-338 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-340 *5 *6 *7)) (-4 *10 (-1219 (-409 *9)))))) 
-(-10 -7 (-15 -2795 (|#8| (-1 |#5| |#1|) |#4|))) 
-((-2646 (((-2 (|:| |num| (-1244 |#3|)) (|:| |den| |#3|)) $) 37)) (-3498 (($ (-1244 (-409 |#3|)) (-1244 $)) NIL) (($ (-1244 (-409 |#3|))) NIL) (($ (-1244 |#3|) |#3|) 158)) (-3692 (((-1244 $) (-1244 $)) 142)) (-1895 (((-634 (-634 |#2|))) 115)) (-2234 (((-121) |#2| |#2|) 71)) (-3250 (($ $) 136)) (-3900 (((-763)) 30)) (-3017 (((-1244 $) (-1244 $)) 195)) (-1296 (((-634 (-953 |#2|)) (-1161)) 108)) (-3874 (((-121) $) 155)) (-1489 (((-121) $) 24) (((-121) $ |#2|) 28) (((-121) $ |#3|) 199)) (-3541 (((-3 |#3| "failed")) 48)) (-2126 (((-763)) 167)) (-2779 ((|#2| $ |#2| |#2|) 129)) (-3633 (((-3 |#3| "failed")) 66)) (-4189 (($ $ (-1 (-409 |#3|) (-409 |#3|)) (-763)) NIL) (($ $ (-1 (-409 |#3|) (-409 |#3|))) NIL) (($ $ (-1 |#3| |#3|)) 203) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) NIL) (($ $ (-763)) NIL) (($ $) NIL)) (-3016 (((-1244 $) (-1244 $)) 148)) (-3223 (((-2 (|:| |num| $) (|:| |den| |#3|) (|:| |derivden| |#3|) (|:| |gd| |#3|)) $ (-1 |#3| |#3|)) 64)) (-2262 (((-121)) 32))) 
-(((-339 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -4189 (|#1| |#1|)) (-15 -4189 (|#1| |#1| (-763))) (-15 -4189 (|#1| |#1| (-1161))) (-15 -4189 (|#1| |#1| (-634 (-1161)))) (-15 -4189 (|#1| |#1| (-1161) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -1895 ((-634 (-634 |#2|)))) (-15 -1296 ((-634 (-953 |#2|)) (-1161))) (-15 -3223 ((-2 (|:| |num| |#1|) (|:| |den| |#3|) (|:| |derivden| |#3|) (|:| |gd| |#3|)) |#1| (-1 |#3| |#3|))) (-15 -3541 ((-3 |#3| "failed"))) (-15 -3633 ((-3 |#3| "failed"))) (-15 -2779 (|#2| |#1| |#2| |#2|)) (-15 -3250 (|#1| |#1|)) (-15 -3498 (|#1| (-1244 |#3|) |#3|)) (-15 -4189 (|#1| |#1| (-1 |#3| |#3|))) (-15 -1489 ((-121) |#1| |#3|)) (-15 -1489 ((-121) |#1| |#2|)) (-15 -2646 ((-2 (|:| |num| (-1244 |#3|)) (|:| |den| |#3|)) |#1|)) (-15 -3692 ((-1244 |#1|) (-1244 |#1|))) (-15 -3017 ((-1244 |#1|) (-1244 |#1|))) (-15 -3016 ((-1244 |#1|) (-1244 |#1|))) (-15 -1489 ((-121) |#1|)) (-15 -3874 ((-121) |#1|)) (-15 -2234 ((-121) |#2| |#2|)) (-15 -2262 ((-121))) (-15 -2126 ((-763))) (-15 -3900 ((-763))) (-15 -4189 (|#1| |#1| (-1 (-409 |#3|) (-409 |#3|)))) (-15 -4189 (|#1| |#1| (-1 (-409 |#3|) (-409 |#3|)) (-763))) (-15 -3498 (|#1| (-1244 (-409 |#3|)))) (-15 -3498 (|#1| (-1244 (-409 |#3|)) (-1244 |#1|)))) (-340 |#2| |#3| |#4|) (-1199) (-1219 |#2|) (-1219 (-409 |#3|))) (T -339)) 
-((-3900 (*1 *2) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-763)) (-5 *1 (-339 *3 *4 *5 *6)) (-4 *3 (-340 *4 *5 *6)))) (-2126 (*1 *2) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-763)) (-5 *1 (-339 *3 *4 *5 *6)) (-4 *3 (-340 *4 *5 *6)))) (-2262 (*1 *2) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-121)) (-5 *1 (-339 *3 *4 *5 *6)) (-4 *3 (-340 *4 *5 *6)))) (-2234 (*1 *2 *3 *3) (-12 (-4 *3 (-1199)) (-4 *5 (-1219 *3)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-121)) (-5 *1 (-339 *4 *3 *5 *6)) (-4 *4 (-340 *3 *5 *6)))) (-3633 (*1 *2) (|partial| -12 (-4 *4 (-1199)) (-4 *5 (-1219 (-409 *2))) (-4 *2 (-1219 *4)) (-5 *1 (-339 *3 *4 *2 *5)) (-4 *3 (-340 *4 *2 *5)))) (-3541 (*1 *2) (|partial| -12 (-4 *4 (-1199)) (-4 *5 (-1219 (-409 *2))) (-4 *2 (-1219 *4)) (-5 *1 (-339 *3 *4 *2 *5)) (-4 *3 (-340 *4 *2 *5)))) (-1296 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *5 (-1199)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-5 *2 (-634 (-953 *5))) (-5 *1 (-339 *4 *5 *6 *7)) (-4 *4 (-340 *5 *6 *7)))) (-1895 (*1 *2) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-634 (-634 *4))) (-5 *1 (-339 *3 *4 *5 *6)) (-4 *3 (-340 *4 *5 *6))))) 
-(-10 -8 (-15 -4189 (|#1| |#1|)) (-15 -4189 (|#1| |#1| (-763))) (-15 -4189 (|#1| |#1| (-1161))) (-15 -4189 (|#1| |#1| (-634 (-1161)))) (-15 -4189 (|#1| |#1| (-1161) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -1895 ((-634 (-634 |#2|)))) (-15 -1296 ((-634 (-953 |#2|)) (-1161))) (-15 -3223 ((-2 (|:| |num| |#1|) (|:| |den| |#3|) (|:| |derivden| |#3|) (|:| |gd| |#3|)) |#1| (-1 |#3| |#3|))) (-15 -3541 ((-3 |#3| "failed"))) (-15 -3633 ((-3 |#3| "failed"))) (-15 -2779 (|#2| |#1| |#2| |#2|)) (-15 -3250 (|#1| |#1|)) (-15 -3498 (|#1| (-1244 |#3|) |#3|)) (-15 -4189 (|#1| |#1| (-1 |#3| |#3|))) (-15 -1489 ((-121) |#1| |#3|)) (-15 -1489 ((-121) |#1| |#2|)) (-15 -2646 ((-2 (|:| |num| (-1244 |#3|)) (|:| |den| |#3|)) |#1|)) (-15 -3692 ((-1244 |#1|) (-1244 |#1|))) (-15 -3017 ((-1244 |#1|) (-1244 |#1|))) (-15 -3016 ((-1244 |#1|) (-1244 |#1|))) (-15 -1489 ((-121) |#1|)) (-15 -3874 ((-121) |#1|)) (-15 -2234 ((-121) |#2| |#2|)) (-15 -2262 ((-121))) (-15 -2126 ((-763))) (-15 -3900 ((-763))) (-15 -4189 (|#1| |#1| (-1 (-409 |#3|) (-409 |#3|)))) (-15 -4189 (|#1| |#1| (-1 (-409 |#3|) (-409 |#3|)) (-763))) (-15 -3498 (|#1| (-1244 (-409 |#3|)))) (-15 -3498 (|#1| (-1244 (-409 |#3|)) (-1244 |#1|)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-2646 (((-2 (|:| |num| (-1244 |#2|)) (|:| |den| |#2|)) $) 180)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 87 (|has| (-409 |#2|) (-365)))) (-2227 (($ $) 88 (|has| (-409 |#2|) (-365)))) (-1573 (((-121) $) 90 (|has| (-409 |#2|) (-365)))) (-4255 (((-679 (-409 |#2|)) (-1244 $)) 44) (((-679 (-409 |#2|))) 55)) (-1932 (((-409 |#2|) $) 50)) (-3211 (((-1169 (-917) (-763)) (-568)) 141 (|has| (-409 |#2|) (-350)))) (-3134 (((-3 $ "failed") $ $) 18)) (-4305 (($ $) 107 (|has| (-409 |#2|) (-365)))) (-1678 (((-420 $) $) 108 (|has| (-409 |#2|) (-365)))) (-1497 (((-121) $ $) 98 (|has| (-409 |#2|) (-365)))) (-3983 (((-763)) 81 (|has| (-409 |#2|) (-370)))) (-3926 (((-121)) 197)) (-1965 (((-121) |#1|) 196) (((-121) |#2|) 195)) (-2671 (($) 16 T CONST)) (-3666 (((-3 (-568) "failed") $) 163 (|has| (-409 |#2|) (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) 161 (|has| (-409 |#2|) (-1037 (-409 (-568))))) (((-3 (-409 |#2|) "failed") $) 160)) (-2854 (((-568) $) 164 (|has| (-409 |#2|) (-1037 (-568)))) (((-409 (-568)) $) 162 (|has| (-409 |#2|) (-1037 (-409 (-568))))) (((-409 |#2|) $) 159)) (-3498 (($ (-1244 (-409 |#2|)) (-1244 $)) 46) (($ (-1244 (-409 |#2|))) 58) (($ (-1244 |#2|) |#2|) 173)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) 147 (|has| (-409 |#2|) (-350)))) (-2401 (($ $ $) 102 (|has| (-409 |#2|) (-365)))) (-1709 (((-679 (-409 |#2|)) $ (-1244 $)) 51) (((-679 (-409 |#2|)) $) 53)) (-3164 (((-679 (-568)) (-679 $)) 158 (|has| (-409 |#2|) (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 157 (|has| (-409 |#2|) (-630 (-568)))) (((-2 (|:| -2928 (-679 (-409 |#2|))) (|:| |vec| (-1244 (-409 |#2|)))) (-679 $) (-1244 $)) 156) (((-679 (-409 |#2|)) (-679 $)) 155)) (-3692 (((-1244 $) (-1244 $)) 185)) (-3092 (($ |#3|) 152) (((-3 $ "failed") (-409 |#3|)) 149 (|has| (-409 |#2|) (-365)))) (-2925 (((-3 $ "failed") $) 33)) (-1895 (((-634 (-634 |#1|))) 166 (|has| |#1| (-370)))) (-2234 (((-121) |#1| |#1|) 201)) (-3700 (((-917)) 52)) (-1731 (($) 84 (|has| (-409 |#2|) (-370)))) (-4449 (((-121)) 194)) (-4481 (((-121) |#1|) 193) (((-121) |#2|) 192)) (-2412 (($ $ $) 101 (|has| (-409 |#2|) (-365)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 96 (|has| (-409 |#2|) (-365)))) (-3250 (($ $) 172)) (-4220 (($) 143 (|has| (-409 |#2|) (-350)))) (-4456 (((-121) $) 144 (|has| (-409 |#2|) (-350)))) (-3218 (($ $ (-763)) 135 (|has| (-409 |#2|) (-350))) (($ $) 134 (|has| (-409 |#2|) (-350)))) (-3927 (((-121) $) 109 (|has| (-409 |#2|) (-365)))) (-4477 (((-917) $) 146 (|has| (-409 |#2|) (-350))) (((-828 (-917)) $) 132 (|has| (-409 |#2|) (-350)))) (-2735 (((-121) $) 30)) (-3900 (((-763)) 204)) (-3017 (((-1244 $) (-1244 $)) 186)) (-2657 (((-409 |#2|) $) 49)) (-1296 (((-634 (-953 |#1|)) (-1161)) 167 (|has| |#1| (-365)))) (-3038 (((-3 $ "failed") $) 136 (|has| (-409 |#2|) (-350)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 105 (|has| (-409 |#2|) (-365)))) (-2045 ((|#3| $) 42 (|has| (-409 |#2|) (-365)))) (-3683 (((-917) $) 83 (|has| (-409 |#2|) (-370)))) (-3085 ((|#3| $) 150)) (-2495 (($ (-634 $)) 94 (|has| (-409 |#2|) (-365))) (($ $ $) 93 (|has| (-409 |#2|) (-365)))) (-4487 (((-1143) $) 9)) (-1300 (((-679 (-409 |#2|))) 181)) (-4472 (((-679 (-409 |#2|))) 183)) (-2081 (($ $) 110 (|has| (-409 |#2|) (-365)))) (-4368 (($ (-1244 |#2|) |#2|) 178)) (-3036 (((-679 (-409 |#2|))) 182)) (-1630 (((-679 (-409 |#2|))) 184)) (-1557 (((-2 (|:| |num| (-679 |#2|)) (|:| |den| |#2|)) (-1 |#2| |#2|)) 177)) (-1658 (((-2 (|:| |num| (-1244 |#2|)) (|:| |den| |#2|)) $) 179)) (-1820 (((-1244 $)) 190)) (-3661 (((-1244 $)) 191)) (-3874 (((-121) $) 189)) (-1489 (((-121) $) 188) (((-121) $ |#1|) 176) (((-121) $ |#2|) 175)) (-4434 (($) 137 (|has| (-409 |#2|) (-350)) CONST)) (-4355 (($ (-917)) 82 (|has| (-409 |#2|) (-370)))) (-3541 (((-3 |#2| "failed")) 169)) (-4022 (((-1108) $) 10)) (-2126 (((-763)) 203)) (-2704 (($) 154)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 95 (|has| (-409 |#2|) (-365)))) (-2721 (($ (-634 $)) 92 (|has| (-409 |#2|) (-365))) (($ $ $) 91 (|has| (-409 |#2|) (-365)))) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) 140 (|has| (-409 |#2|) (-350)))) (-3848 (((-420 $) $) 106 (|has| (-409 |#2|) (-365)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 104 (|has| (-409 |#2|) (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 103 (|has| (-409 |#2|) (-365)))) (-2595 (((-3 $ "failed") $ $) 86 (|has| (-409 |#2|) (-365)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 97 (|has| (-409 |#2|) (-365)))) (-2709 (((-763) $) 99 (|has| (-409 |#2|) (-365)))) (-2779 ((|#1| $ |#1| |#1|) 171)) (-3633 (((-3 |#2| "failed")) 170)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 100 (|has| (-409 |#2|) (-365)))) (-2217 (((-409 |#2|) (-1244 $)) 45) (((-409 |#2|)) 54)) (-3143 (((-763) $) 145 (|has| (-409 |#2|) (-350))) (((-3 (-763) "failed") $ $) 133 (|has| (-409 |#2|) (-350)))) (-4189 (($ $ (-1 (-409 |#2|) (-409 |#2|)) (-763)) 117 (|has| (-409 |#2|) (-365))) (($ $ (-1 (-409 |#2|) (-409 |#2|))) 116 (|has| (-409 |#2|) (-365))) (($ $ (-1 |#2| |#2|)) 174) (($ $ (-634 (-1161)) (-634 (-763))) 124 (-2198 (-2139 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161)))) (-2139 (|has| (-409 |#2|) (-895 (-1161))) (|has| (-409 |#2|) (-365))))) (($ $ (-1161) (-763)) 125 (-2198 (-2139 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161)))) (-2139 (|has| (-409 |#2|) (-895 (-1161))) (|has| (-409 |#2|) (-365))))) (($ $ (-634 (-1161))) 126 (-2198 (-2139 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161)))) (-2139 (|has| (-409 |#2|) (-895 (-1161))) (|has| (-409 |#2|) (-365))))) (($ $ (-1161)) 127 (-2198 (-2139 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161)))) (-2139 (|has| (-409 |#2|) (-895 (-1161))) (|has| (-409 |#2|) (-365))))) (($ $ (-763)) 129 (-2198 (-2139 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-225))) (-2139 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350)))) (($ $) 131 (-2198 (-2139 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-225))) (-2139 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350))))) (-4387 (((-679 (-409 |#2|)) (-1244 $) (-1 (-409 |#2|) (-409 |#2|))) 148 (|has| (-409 |#2|) (-365)))) (-1626 ((|#3|) 153)) (-3065 (($) 142 (|has| (-409 |#2|) (-350)))) (-4073 (((-1244 (-409 |#2|)) $ (-1244 $)) 48) (((-679 (-409 |#2|)) (-1244 $) (-1244 $)) 47) (((-1244 (-409 |#2|)) $) 60) (((-679 (-409 |#2|)) (-1244 $)) 59)) (-4278 (((-1244 (-409 |#2|)) $) 57) (($ (-1244 (-409 |#2|))) 56) ((|#3| $) 165) (($ |#3|) 151)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) 139 (|has| (-409 |#2|) (-350)))) (-3016 (((-1244 $) (-1244 $)) 187)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ (-409 |#2|)) 36) (($ (-409 (-568))) 80 (-2198 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-1037 (-409 (-568)))))) (($ $) 85 (|has| (-409 |#2|) (-365)))) (-4371 (($ $) 138 (|has| (-409 |#2|) (-350))) (((-3 $ "failed") $) 41 (|has| (-409 |#2|) (-148)))) (-2678 ((|#3| $) 43)) (-4078 (((-763)) 28)) (-4199 (((-121)) 200)) (-2712 (((-121) |#1|) 199) (((-121) |#2|) 198)) (-3746 (((-1244 $)) 61)) (-1826 (((-121) $ $) 89 (|has| (-409 |#2|) (-365)))) (-3223 (((-2 (|:| |num| $) (|:| |den| |#2|) (|:| |derivden| |#2|) (|:| |gd| |#2|)) $ (-1 |#2| |#2|)) 168)) (-2262 (((-121)) 202)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 111 (|has| (-409 |#2|) (-365)))) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $ (-1 (-409 |#2|) (-409 |#2|)) (-763)) 119 (|has| (-409 |#2|) (-365))) (($ $ (-1 (-409 |#2|) (-409 |#2|))) 118 (|has| (-409 |#2|) (-365))) (($ $ (-634 (-1161)) (-634 (-763))) 120 (-2198 (-2139 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161)))) (-2139 (|has| (-409 |#2|) (-895 (-1161))) (|has| (-409 |#2|) (-365))))) (($ $ (-1161) (-763)) 121 (-2198 (-2139 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161)))) (-2139 (|has| (-409 |#2|) (-895 (-1161))) (|has| (-409 |#2|) (-365))))) (($ $ (-634 (-1161))) 122 (-2198 (-2139 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161)))) (-2139 (|has| (-409 |#2|) (-895 (-1161))) (|has| (-409 |#2|) (-365))))) (($ $ (-1161)) 123 (-2198 (-2139 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161)))) (-2139 (|has| (-409 |#2|) (-895 (-1161))) (|has| (-409 |#2|) (-365))))) (($ $ (-763)) 128 (-2198 (-2139 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-225))) (-2139 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350)))) (($ $) 130 (-2198 (-2139 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-225))) (-2139 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350))))) (-1717 (((-121) $ $) 6)) (-1779 (($ $ $) 115 (|has| (-409 |#2|) (-365)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 112 (|has| (-409 |#2|) (-365)))) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 |#2|)) 38) (($ (-409 |#2|) $) 37) (($ (-409 (-568)) $) 114 (|has| (-409 |#2|) (-365))) (($ $ (-409 (-568))) 113 (|has| (-409 |#2|) (-365))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2057 (((-634 (-1161)) $) NIL)) (-3044 (((-121)) 87) (((-121) (-121)) 88)) (-3145 (((-634 (-607 $)) $) NIL)) (-1984 (($ $) NIL)) (-1935 (($ $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4069 (($ $ (-288 $)) NIL) (($ $ (-634 (-288 $))) NIL) (($ $ (-634 (-607 $)) (-634 $)) NIL)) (-1904 (($ $) NIL)) (-1976 (($ $) NIL)) (-2788 (($ $) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-607 $) "failed") $) NIL) (((-3 |#3| "failed") $) NIL) (((-3 $ "failed") (-310 |#3|)) 69) (((-3 $ "failed") (-1161)) 93) (((-3 $ "failed") (-310 (-568))) 56 (|has| |#3| (-1037 (-568)))) (((-3 $ "failed") (-409 (-953 (-568)))) 62 (|has| |#3| (-1037 (-568)))) (((-3 $ "failed") (-953 (-568))) 57 (|has| |#3| (-1037 (-568)))) (((-3 $ "failed") (-310 (-381))) 74 (|has| |#3| (-1037 (-381)))) (((-3 $ "failed") (-409 (-953 (-381)))) 80 (|has| |#3| (-1037 (-381)))) (((-3 $ "failed") (-953 (-381))) 75 (|has| |#3| (-1037 (-381))))) (-2857 (((-607 $) $) NIL) ((|#3| $) NIL) (($ (-310 |#3|)) 70) (($ (-1161)) 94) (($ (-310 (-568))) 58 (|has| |#3| (-1037 (-568)))) (($ (-409 (-953 (-568)))) 63 (|has| |#3| (-1037 (-568)))) (($ (-953 (-568))) 59 (|has| |#3| (-1037 (-568)))) (($ (-310 (-381))) 76 (|has| |#3| (-1037 (-381)))) (($ (-409 (-953 (-381)))) 81 (|has| |#3| (-1037 (-381)))) (($ (-953 (-381))) 77 (|has| |#3| (-1037 (-381))))) (-2902 (((-3 $ "failed") $) NIL)) (-1899 (($) 10)) (-3855 (($ $) NIL) (($ (-634 $)) NIL)) (-2160 (((-634 (-123)) $) NIL)) (-3842 (((-123) (-123)) NIL)) (-1598 (((-121) $) NIL)) (-2268 (((-121) $) NIL (|has| $ (-1037 (-568))))) (-3170 (((-1157 $) (-607 $)) NIL (|has| $ (-1047)))) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-2797 (($ (-1 $ $) (-607 $)) NIL)) (-2337 (((-3 (-607 $) "failed") $) NIL)) (-2658 (($ $) 90)) (-4418 (($ $) NIL)) (-1893 (((-1143) $) NIL)) (-3832 (((-634 (-607 $)) $) NIL)) (-3446 (($ (-123) $) 89) (($ (-123) (-634 $)) NIL)) (-3910 (((-121) $ (-123)) NIL) (((-121) $ (-1161)) NIL)) (-2963 (((-763) $) NIL)) (-4025 (((-1108) $) NIL)) (-1609 (((-121) $ $) NIL) (((-121) $ (-1161)) NIL)) (-1894 (($ $) NIL)) (-2080 (((-121) $) NIL (|has| $ (-1037 (-568))))) (-1339 (($ $ (-607 $) $) NIL) (($ $ (-634 (-607 $)) (-634 $)) NIL) (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ $))) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-1161) (-1 $ (-634 $))) NIL) (($ $ (-1161) (-1 $ $)) NIL) (($ $ (-634 (-123)) (-634 (-1 $ $))) NIL) (($ $ (-634 (-123)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-123) (-1 $ (-634 $))) NIL) (($ $ (-123) (-1 $ $)) NIL)) (-2781 (($ (-123) $) NIL) (($ (-123) $ $) NIL) (($ (-123) $ $ $) NIL) (($ (-123) $ $ $ $) NIL) (($ (-123) (-634 $)) NIL)) (-3924 (($ $) NIL) (($ $ $) NIL)) (-4191 (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) NIL)) (-1492 (($ $) NIL (|has| $ (-1047)))) (-1980 (($ $) NIL)) (-2792 (($ $) NIL)) (-2747 (((-850) $) NIL) (($ (-607 $)) NIL) (($ |#3|) NIL) (($ (-568)) NIL) (((-310 |#3|) $) 92)) (-3425 (((-763)) NIL)) (-3159 (($ $) NIL) (($ (-634 $)) NIL)) (-2779 (((-121) (-123)) NIL)) (-1959 (($ $) NIL)) (-1951 (($ $) NIL)) (-1955 (($ $) NIL)) (-2811 (($ $) NIL)) (-1889 (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (-3058 (($) 91 T CONST)) (-1557 (($) 22 T CONST)) (-3192 (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) NIL)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) NIL)) (-1775 (($ $ $) NIL) (($ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (* (($ |#3| $) NIL) (($ $ |#3|) NIL) (($ $ $) NIL) (($ (-568) $) NIL) (($ (-763) $) NIL) (($ (-917) $) NIL))) 
+(((-337 |#1| |#2| |#3|) (-13 (-296) (-43 |#3|) (-1037 |#3|) (-895 (-1161)) (-10 -8 (-15 -2857 ($ (-310 |#3|))) (-15 -3668 ((-3 $ "failed") (-310 |#3|))) (-15 -2857 ($ (-1161))) (-15 -3668 ((-3 $ "failed") (-1161))) (-15 -2747 ((-310 |#3|) $)) (IF (|has| |#3| (-1037 (-568))) (PROGN (-15 -2857 ($ (-310 (-568)))) (-15 -3668 ((-3 $ "failed") (-310 (-568)))) (-15 -2857 ($ (-409 (-953 (-568))))) (-15 -3668 ((-3 $ "failed") (-409 (-953 (-568))))) (-15 -2857 ($ (-953 (-568)))) (-15 -3668 ((-3 $ "failed") (-953 (-568))))) |noBranch|) (IF (|has| |#3| (-1037 (-381))) (PROGN (-15 -2857 ($ (-310 (-381)))) (-15 -3668 ((-3 $ "failed") (-310 (-381)))) (-15 -2857 ($ (-409 (-953 (-381))))) (-15 -3668 ((-3 $ "failed") (-409 (-953 (-381))))) (-15 -2857 ($ (-953 (-381)))) (-15 -3668 ((-3 $ "failed") (-953 (-381))))) |noBranch|) (-15 -2811 ($ $)) (-15 -1904 ($ $)) (-15 -1894 ($ $)) (-15 -4418 ($ $)) (-15 -2658 ($ $)) (-15 -2788 ($ $)) (-15 -2792 ($ $)) (-15 -1935 ($ $)) (-15 -1951 ($ $)) (-15 -1955 ($ $)) (-15 -1959 ($ $)) (-15 -1976 ($ $)) (-15 -1980 ($ $)) (-15 -1984 ($ $)) (-15 -1899 ($)) (-15 -2057 ((-634 (-1161)) $)) (-15 -3044 ((-121))) (-15 -3044 ((-121) (-121))))) (-634 (-1161)) (-634 (-1161)) (-389)) (T -337)) 
+((-2857 (*1 *1 *2) (-12 (-5 *2 (-310 *5)) (-4 *5 (-389)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-310 *5)) (-4 *5 (-389)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 *2)) (-14 *4 (-634 *2)) (-4 *5 (-389)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-1161)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 *2)) (-14 *4 (-634 *2)) (-4 *5 (-389)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-310 *5)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-310 (-568))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-310 (-568))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-409 (-953 (-568)))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-409 (-953 (-568)))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-953 (-568))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-953 (-568))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-310 (-381))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-310 (-381))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-409 (-953 (-381)))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-409 (-953 (-381)))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-953 (-381))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-953 (-381))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-2811 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-1904 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-1894 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-4418 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-2658 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-2788 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-2792 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-1935 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-1951 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-1955 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-1959 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-1976 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-1980 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-1984 (*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-1899 (*1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) (-2057 (*1 *2 *1) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-337 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-389)))) (-3044 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) (-3044 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389))))) 
+(-13 (-296) (-43 |#3|) (-1037 |#3|) (-895 (-1161)) (-10 -8 (-15 -2857 ($ (-310 |#3|))) (-15 -3668 ((-3 $ "failed") (-310 |#3|))) (-15 -2857 ($ (-1161))) (-15 -3668 ((-3 $ "failed") (-1161))) (-15 -2747 ((-310 |#3|) $)) (IF (|has| |#3| (-1037 (-568))) (PROGN (-15 -2857 ($ (-310 (-568)))) (-15 -3668 ((-3 $ "failed") (-310 (-568)))) (-15 -2857 ($ (-409 (-953 (-568))))) (-15 -3668 ((-3 $ "failed") (-409 (-953 (-568))))) (-15 -2857 ($ (-953 (-568)))) (-15 -3668 ((-3 $ "failed") (-953 (-568))))) |noBranch|) (IF (|has| |#3| (-1037 (-381))) (PROGN (-15 -2857 ($ (-310 (-381)))) (-15 -3668 ((-3 $ "failed") (-310 (-381)))) (-15 -2857 ($ (-409 (-953 (-381))))) (-15 -3668 ((-3 $ "failed") (-409 (-953 (-381))))) (-15 -2857 ($ (-953 (-381)))) (-15 -3668 ((-3 $ "failed") (-953 (-381))))) |noBranch|) (-15 -2811 ($ $)) (-15 -1904 ($ $)) (-15 -1894 ($ $)) (-15 -4418 ($ $)) (-15 -2658 ($ $)) (-15 -2788 ($ $)) (-15 -2792 ($ $)) (-15 -1935 ($ $)) (-15 -1951 ($ $)) (-15 -1955 ($ $)) (-15 -1959 ($ $)) (-15 -1976 ($ $)) (-15 -1980 ($ $)) (-15 -1984 ($ $)) (-15 -1899 ($)) (-15 -2057 ((-634 (-1161)) $)) (-15 -3044 ((-121))) (-15 -3044 ((-121) (-121))))) 
+((-2797 ((|#8| (-1 |#5| |#1|) |#4|) 19))) 
+(((-338 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -2797 (|#8| (-1 |#5| |#1|) |#4|))) (-1199) (-1219 |#1|) (-1219 (-409 |#2|)) (-340 |#1| |#2| |#3|) (-1199) (-1219 |#5|) (-1219 (-409 |#6|)) (-340 |#5| |#6| |#7|)) (T -338)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *5)) (-4 *5 (-1199)) (-4 *8 (-1199)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-4 *9 (-1219 *8)) (-4 *2 (-340 *8 *9 *10)) (-5 *1 (-338 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-340 *5 *6 *7)) (-4 *10 (-1219 (-409 *9)))))) 
+(-10 -7 (-15 -2797 (|#8| (-1 |#5| |#1|) |#4|))) 
+((-4354 (((-2 (|:| |num| (-1244 |#3|)) (|:| |den| |#3|)) $) 37)) (-3899 (($ (-1244 (-409 |#3|)) (-1244 $)) NIL) (($ (-1244 (-409 |#3|))) NIL) (($ (-1244 |#3|) |#3|) 158)) (-2331 (((-1244 $) (-1244 $)) 142)) (-2603 (((-634 (-634 |#2|))) 115)) (-2679 (((-121) |#2| |#2|) 71)) (-1998 (($ $) 136)) (-2066 (((-763)) 30)) (-3233 (((-1244 $) (-1244 $)) 195)) (-3247 (((-634 (-953 |#2|)) (-1161)) 108)) (-1979 (((-121) $) 155)) (-2548 (((-121) $) 24) (((-121) $ |#2|) 28) (((-121) $ |#3|) 199)) (-4201 (((-3 |#3| "failed")) 48)) (-3383 (((-763)) 167)) (-2781 ((|#2| $ |#2| |#2|) 129)) (-3146 (((-3 |#3| "failed")) 66)) (-4191 (($ $ (-1 (-409 |#3|) (-409 |#3|)) (-763)) NIL) (($ $ (-1 (-409 |#3|) (-409 |#3|))) NIL) (($ $ (-1 |#3| |#3|)) 203) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) NIL) (($ $ (-763)) NIL) (($ $) NIL)) (-3224 (((-1244 $) (-1244 $)) 148)) (-1900 (((-2 (|:| |num| $) (|:| |den| |#3|) (|:| |derivden| |#3|) (|:| |gd| |#3|)) $ (-1 |#3| |#3|)) 64)) (-3341 (((-121)) 32))) 
+(((-339 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -4191 (|#1| |#1|)) (-15 -4191 (|#1| |#1| (-763))) (-15 -4191 (|#1| |#1| (-1161))) (-15 -4191 (|#1| |#1| (-634 (-1161)))) (-15 -4191 (|#1| |#1| (-1161) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -2603 ((-634 (-634 |#2|)))) (-15 -3247 ((-634 (-953 |#2|)) (-1161))) (-15 -1900 ((-2 (|:| |num| |#1|) (|:| |den| |#3|) (|:| |derivden| |#3|) (|:| |gd| |#3|)) |#1| (-1 |#3| |#3|))) (-15 -4201 ((-3 |#3| "failed"))) (-15 -3146 ((-3 |#3| "failed"))) (-15 -2781 (|#2| |#1| |#2| |#2|)) (-15 -1998 (|#1| |#1|)) (-15 -3899 (|#1| (-1244 |#3|) |#3|)) (-15 -4191 (|#1| |#1| (-1 |#3| |#3|))) (-15 -2548 ((-121) |#1| |#3|)) (-15 -2548 ((-121) |#1| |#2|)) (-15 -4354 ((-2 (|:| |num| (-1244 |#3|)) (|:| |den| |#3|)) |#1|)) (-15 -2331 ((-1244 |#1|) (-1244 |#1|))) (-15 -3233 ((-1244 |#1|) (-1244 |#1|))) (-15 -3224 ((-1244 |#1|) (-1244 |#1|))) (-15 -2548 ((-121) |#1|)) (-15 -1979 ((-121) |#1|)) (-15 -2679 ((-121) |#2| |#2|)) (-15 -3341 ((-121))) (-15 -3383 ((-763))) (-15 -2066 ((-763))) (-15 -4191 (|#1| |#1| (-1 (-409 |#3|) (-409 |#3|)))) (-15 -4191 (|#1| |#1| (-1 (-409 |#3|) (-409 |#3|)) (-763))) (-15 -3899 (|#1| (-1244 (-409 |#3|)))) (-15 -3899 (|#1| (-1244 (-409 |#3|)) (-1244 |#1|)))) (-340 |#2| |#3| |#4|) (-1199) (-1219 |#2|) (-1219 (-409 |#3|))) (T -339)) 
+((-2066 (*1 *2) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-763)) (-5 *1 (-339 *3 *4 *5 *6)) (-4 *3 (-340 *4 *5 *6)))) (-3383 (*1 *2) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-763)) (-5 *1 (-339 *3 *4 *5 *6)) (-4 *3 (-340 *4 *5 *6)))) (-3341 (*1 *2) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-121)) (-5 *1 (-339 *3 *4 *5 *6)) (-4 *3 (-340 *4 *5 *6)))) (-2679 (*1 *2 *3 *3) (-12 (-4 *3 (-1199)) (-4 *5 (-1219 *3)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-121)) (-5 *1 (-339 *4 *3 *5 *6)) (-4 *4 (-340 *3 *5 *6)))) (-3146 (*1 *2) (|partial| -12 (-4 *4 (-1199)) (-4 *5 (-1219 (-409 *2))) (-4 *2 (-1219 *4)) (-5 *1 (-339 *3 *4 *2 *5)) (-4 *3 (-340 *4 *2 *5)))) (-4201 (*1 *2) (|partial| -12 (-4 *4 (-1199)) (-4 *5 (-1219 (-409 *2))) (-4 *2 (-1219 *4)) (-5 *1 (-339 *3 *4 *2 *5)) (-4 *3 (-340 *4 *2 *5)))) (-3247 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *5 (-1199)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-5 *2 (-634 (-953 *5))) (-5 *1 (-339 *4 *5 *6 *7)) (-4 *4 (-340 *5 *6 *7)))) (-2603 (*1 *2) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-634 (-634 *4))) (-5 *1 (-339 *3 *4 *5 *6)) (-4 *3 (-340 *4 *5 *6))))) 
+(-10 -8 (-15 -4191 (|#1| |#1|)) (-15 -4191 (|#1| |#1| (-763))) (-15 -4191 (|#1| |#1| (-1161))) (-15 -4191 (|#1| |#1| (-634 (-1161)))) (-15 -4191 (|#1| |#1| (-1161) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -2603 ((-634 (-634 |#2|)))) (-15 -3247 ((-634 (-953 |#2|)) (-1161))) (-15 -1900 ((-2 (|:| |num| |#1|) (|:| |den| |#3|) (|:| |derivden| |#3|) (|:| |gd| |#3|)) |#1| (-1 |#3| |#3|))) (-15 -4201 ((-3 |#3| "failed"))) (-15 -3146 ((-3 |#3| "failed"))) (-15 -2781 (|#2| |#1| |#2| |#2|)) (-15 -1998 (|#1| |#1|)) (-15 -3899 (|#1| (-1244 |#3|) |#3|)) (-15 -4191 (|#1| |#1| (-1 |#3| |#3|))) (-15 -2548 ((-121) |#1| |#3|)) (-15 -2548 ((-121) |#1| |#2|)) (-15 -4354 ((-2 (|:| |num| (-1244 |#3|)) (|:| |den| |#3|)) |#1|)) (-15 -2331 ((-1244 |#1|) (-1244 |#1|))) (-15 -3233 ((-1244 |#1|) (-1244 |#1|))) (-15 -3224 ((-1244 |#1|) (-1244 |#1|))) (-15 -2548 ((-121) |#1|)) (-15 -1979 ((-121) |#1|)) (-15 -2679 ((-121) |#2| |#2|)) (-15 -3341 ((-121))) (-15 -3383 ((-763))) (-15 -2066 ((-763))) (-15 -4191 (|#1| |#1| (-1 (-409 |#3|) (-409 |#3|)))) (-15 -4191 (|#1| |#1| (-1 (-409 |#3|) (-409 |#3|)) (-763))) (-15 -3899 (|#1| (-1244 (-409 |#3|)))) (-15 -3899 (|#1| (-1244 (-409 |#3|)) (-1244 |#1|)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-4354 (((-2 (|:| |num| (-1244 |#2|)) (|:| |den| |#2|)) $) 180)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 87 (|has| (-409 |#2|) (-365)))) (-3661 (($ $) 88 (|has| (-409 |#2|) (-365)))) (-4426 (((-121) $) 90 (|has| (-409 |#2|) (-365)))) (-2883 (((-679 (-409 |#2|)) (-1244 $)) 44) (((-679 (-409 |#2|))) 55)) (-1934 (((-409 |#2|) $) 50)) (-1856 (((-1169 (-917) (-763)) (-568)) 141 (|has| (-409 |#2|) (-350)))) (-2689 (((-3 $ "failed") $ $) 18)) (-3045 (($ $) 107 (|has| (-409 |#2|) (-365)))) (-3498 (((-420 $) $) 108 (|has| (-409 |#2|) (-365)))) (-2589 (((-121) $ $) 98 (|has| (-409 |#2|) (-365)))) (-3986 (((-763)) 81 (|has| (-409 |#2|) (-370)))) (-2191 (((-121)) 197)) (-4347 (((-121) |#1|) 196) (((-121) |#2|) 195)) (-4490 (($) 16 T CONST)) (-3668 (((-3 (-568) "failed") $) 163 (|has| (-409 |#2|) (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) 161 (|has| (-409 |#2|) (-1037 (-409 (-568))))) (((-3 (-409 |#2|) "failed") $) 160)) (-2857 (((-568) $) 164 (|has| (-409 |#2|) (-1037 (-568)))) (((-409 (-568)) $) 162 (|has| (-409 |#2|) (-1037 (-409 (-568))))) (((-409 |#2|) $) 159)) (-3899 (($ (-1244 (-409 |#2|)) (-1244 $)) 46) (($ (-1244 (-409 |#2|))) 58) (($ (-1244 |#2|) |#2|) 173)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) 147 (|has| (-409 |#2|) (-350)))) (-2403 (($ $ $) 102 (|has| (-409 |#2|) (-365)))) (-3653 (((-679 (-409 |#2|)) $ (-1244 $)) 51) (((-679 (-409 |#2|)) $) 53)) (-1668 (((-679 (-568)) (-679 $)) 158 (|has| (-409 |#2|) (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 157 (|has| (-409 |#2|) (-630 (-568)))) (((-2 (|:| -2908 (-679 (-409 |#2|))) (|:| |vec| (-1244 (-409 |#2|)))) (-679 $) (-1244 $)) 156) (((-679 (-409 |#2|)) (-679 $)) 155)) (-2331 (((-1244 $) (-1244 $)) 185)) (-3094 (($ |#3|) 152) (((-3 $ "failed") (-409 |#3|)) 149 (|has| (-409 |#2|) (-365)))) (-2902 (((-3 $ "failed") $) 33)) (-2603 (((-634 (-634 |#1|))) 166 (|has| |#1| (-370)))) (-2679 (((-121) |#1| |#1|) 201)) (-2371 (((-917)) 52)) (-1733 (($) 84 (|has| (-409 |#2|) (-370)))) (-1700 (((-121)) 194)) (-1862 (((-121) |#1|) 193) (((-121) |#2|) 192)) (-2414 (($ $ $) 101 (|has| (-409 |#2|) (-365)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 96 (|has| (-409 |#2|) (-365)))) (-1998 (($ $) 172)) (-4188 (($) 143 (|has| (-409 |#2|) (-350)))) (-1748 (((-121) $) 144 (|has| (-409 |#2|) (-350)))) (-1887 (($ $ (-763)) 135 (|has| (-409 |#2|) (-350))) (($ $) 134 (|has| (-409 |#2|) (-350)))) (-2197 (((-121) $) 109 (|has| (-409 |#2|) (-365)))) (-1844 (((-917) $) 146 (|has| (-409 |#2|) (-350))) (((-828 (-917)) $) 132 (|has| (-409 |#2|) (-350)))) (-1598 (((-121) $) 30)) (-2066 (((-763)) 204)) (-3233 (((-1244 $) (-1244 $)) 186)) (-4417 (((-409 |#2|) $) 49)) (-3247 (((-634 (-953 |#1|)) (-1161)) 167 (|has| |#1| (-365)))) (-2214 (((-3 $ "failed") $) 136 (|has| (-409 |#2|) (-350)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 105 (|has| (-409 |#2|) (-365)))) (-1497 ((|#3| $) 42 (|has| (-409 |#2|) (-365)))) (-2291 (((-917) $) 83 (|has| (-409 |#2|) (-370)))) (-3087 ((|#3| $) 150)) (-2498 (($ (-634 $)) 94 (|has| (-409 |#2|) (-365))) (($ $ $) 93 (|has| (-409 |#2|) (-365)))) (-1893 (((-1143) $) 9)) (-3281 (((-679 (-409 |#2|))) 181)) (-1822 (((-679 (-409 |#2|))) 183)) (-2083 (($ $) 110 (|has| (-409 |#2|) (-365)))) (-3368 (($ (-1244 |#2|) |#2|) 178)) (-2208 (((-679 (-409 |#2|))) 182)) (-1515 (((-679 (-409 |#2|))) 184)) (-4339 (((-2 (|:| |num| (-679 |#2|)) (|:| |den| |#2|)) (-1 |#2| |#2|)) 177)) (-3363 (((-2 (|:| |num| (-1244 |#2|)) (|:| |den| |#2|)) $) 179)) (-2239 (((-1244 $)) 190)) (-3330 (((-1244 $)) 191)) (-1979 (((-121) $) 189)) (-2548 (((-121) $) 188) (((-121) $ |#1|) 176) (((-121) $ |#2|) 175)) (-4436 (($) 137 (|has| (-409 |#2|) (-350)) CONST)) (-4357 (($ (-917)) 82 (|has| (-409 |#2|) (-370)))) (-4201 (((-3 |#2| "failed")) 169)) (-4025 (((-1108) $) 10)) (-3383 (((-763)) 203)) (-2707 (($) 154)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 95 (|has| (-409 |#2|) (-365)))) (-2723 (($ (-634 $)) 92 (|has| (-409 |#2|) (-365))) (($ $ $) 91 (|has| (-409 |#2|) (-365)))) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) 140 (|has| (-409 |#2|) (-350)))) (-3850 (((-420 $) $) 106 (|has| (-409 |#2|) (-365)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 104 (|has| (-409 |#2|) (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 103 (|has| (-409 |#2|) (-365)))) (-2597 (((-3 $ "failed") $ $) 86 (|has| (-409 |#2|) (-365)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 97 (|has| (-409 |#2|) (-365)))) (-1466 (((-763) $) 99 (|has| (-409 |#2|) (-365)))) (-2781 ((|#1| $ |#1| |#1|) 171)) (-3146 (((-3 |#2| "failed")) 170)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 100 (|has| (-409 |#2|) (-365)))) (-3440 (((-409 |#2|) (-1244 $)) 45) (((-409 |#2|)) 54)) (-2721 (((-763) $) 145 (|has| (-409 |#2|) (-350))) (((-3 (-763) "failed") $ $) 133 (|has| (-409 |#2|) (-350)))) (-4191 (($ $ (-1 (-409 |#2|) (-409 |#2|)) (-763)) 117 (|has| (-409 |#2|) (-365))) (($ $ (-1 (-409 |#2|) (-409 |#2|))) 116 (|has| (-409 |#2|) (-365))) (($ $ (-1 |#2| |#2|)) 174) (($ $ (-634 (-1161)) (-634 (-763))) 124 (-2199 (-2141 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161)))) (-2141 (|has| (-409 |#2|) (-895 (-1161))) (|has| (-409 |#2|) (-365))))) (($ $ (-1161) (-763)) 125 (-2199 (-2141 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161)))) (-2141 (|has| (-409 |#2|) (-895 (-1161))) (|has| (-409 |#2|) (-365))))) (($ $ (-634 (-1161))) 126 (-2199 (-2141 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161)))) (-2141 (|has| (-409 |#2|) (-895 (-1161))) (|has| (-409 |#2|) (-365))))) (($ $ (-1161)) 127 (-2199 (-2141 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161)))) (-2141 (|has| (-409 |#2|) (-895 (-1161))) (|has| (-409 |#2|) (-365))))) (($ $ (-763)) 129 (-2199 (-2141 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-225))) (-2141 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350)))) (($ $) 131 (-2199 (-2141 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-225))) (-2141 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350))))) (-1391 (((-679 (-409 |#2|)) (-1244 $) (-1 (-409 |#2|) (-409 |#2|))) 148 (|has| (-409 |#2|) (-365)))) (-1492 ((|#3|) 153)) (-2330 (($) 142 (|has| (-409 |#2|) (-350)))) (-1656 (((-1244 (-409 |#2|)) $ (-1244 $)) 48) (((-679 (-409 |#2|)) (-1244 $) (-1244 $)) 47) (((-1244 (-409 |#2|)) $) 60) (((-679 (-409 |#2|)) (-1244 $)) 59)) (-4280 (((-1244 (-409 |#2|)) $) 57) (($ (-1244 (-409 |#2|))) 56) ((|#3| $) 165) (($ |#3|) 151)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) 139 (|has| (-409 |#2|) (-350)))) (-3224 (((-1244 $) (-1244 $)) 187)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ (-409 |#2|)) 36) (($ (-409 (-568))) 80 (-2199 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-1037 (-409 (-568)))))) (($ $) 85 (|has| (-409 |#2|) (-365)))) (-3385 (($ $) 138 (|has| (-409 |#2|) (-350))) (((-3 $ "failed") $) 41 (|has| (-409 |#2|) (-148)))) (-1295 ((|#3| $) 43)) (-3425 (((-763)) 28)) (-4077 (((-121)) 200)) (-1487 (((-121) |#1|) 199) (((-121) |#2|) 198)) (-2588 (((-1244 $)) 61)) (-2273 (((-121) $ $) 89 (|has| (-409 |#2|) (-365)))) (-1900 (((-2 (|:| |num| $) (|:| |den| |#2|) (|:| |derivden| |#2|) (|:| |gd| |#2|)) $ (-1 |#2| |#2|)) 168)) (-3341 (((-121)) 202)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 111 (|has| (-409 |#2|) (-365)))) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $ (-1 (-409 |#2|) (-409 |#2|)) (-763)) 119 (|has| (-409 |#2|) (-365))) (($ $ (-1 (-409 |#2|) (-409 |#2|))) 118 (|has| (-409 |#2|) (-365))) (($ $ (-634 (-1161)) (-634 (-763))) 120 (-2199 (-2141 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161)))) (-2141 (|has| (-409 |#2|) (-895 (-1161))) (|has| (-409 |#2|) (-365))))) (($ $ (-1161) (-763)) 121 (-2199 (-2141 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161)))) (-2141 (|has| (-409 |#2|) (-895 (-1161))) (|has| (-409 |#2|) (-365))))) (($ $ (-634 (-1161))) 122 (-2199 (-2141 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161)))) (-2141 (|has| (-409 |#2|) (-895 (-1161))) (|has| (-409 |#2|) (-365))))) (($ $ (-1161)) 123 (-2199 (-2141 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161)))) (-2141 (|has| (-409 |#2|) (-895 (-1161))) (|has| (-409 |#2|) (-365))))) (($ $ (-763)) 128 (-2199 (-2141 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-225))) (-2141 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350)))) (($ $) 130 (-2199 (-2141 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-225))) (-2141 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350))))) (-1719 (((-121) $ $) 6)) (-1781 (($ $ $) 115 (|has| (-409 |#2|) (-365)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 112 (|has| (-409 |#2|) (-365)))) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 |#2|)) 38) (($ (-409 |#2|) $) 37) (($ (-409 (-568)) $) 114 (|has| (-409 |#2|) (-365))) (($ $ (-409 (-568))) 113 (|has| (-409 |#2|) (-365))))) 
 (((-340 |#1| |#2| |#3|) (-1275) (-1199) (-1219 |t#1|) (-1219 (-409 |t#2|))) (T -340)) 
-((-3900 (*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-763)))) (-2126 (*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-763)))) (-2262 (*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) (-2234 (*1 *2 *3 *3) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) (-4199 (*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) (-2712 (*1 *2 *3) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) (-2712 (*1 *2 *3) (-12 (-4 *1 (-340 *4 *3 *5)) (-4 *4 (-1199)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 (-409 *3))) (-5 *2 (-121)))) (-3926 (*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) (-1965 (*1 *2 *3) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) (-1965 (*1 *2 *3) (-12 (-4 *1 (-340 *4 *3 *5)) (-4 *4 (-1199)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 (-409 *3))) (-5 *2 (-121)))) (-4449 (*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) (-4481 (*1 *2 *3) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) (-4481 (*1 *2 *3) (-12 (-4 *1 (-340 *4 *3 *5)) (-4 *4 (-1199)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 (-409 *3))) (-5 *2 (-121)))) (-3661 (*1 *2) (-12 (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-1244 *1)) (-4 *1 (-340 *3 *4 *5)))) (-1820 (*1 *2) (-12 (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-1244 *1)) (-4 *1 (-340 *3 *4 *5)))) (-3874 (*1 *2 *1) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) (-1489 (*1 *2 *1) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) (-3016 (*1 *2 *2) (-12 (-5 *2 (-1244 *1)) (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))))) (-3017 (*1 *2 *2) (-12 (-5 *2 (-1244 *1)) (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))))) (-3692 (*1 *2 *2) (-12 (-5 *2 (-1244 *1)) (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))))) (-1630 (*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-679 (-409 *4))))) (-4472 (*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-679 (-409 *4))))) (-3036 (*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-679 (-409 *4))))) (-1300 (*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-679 (-409 *4))))) (-2646 (*1 *2 *1) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-2 (|:| |num| (-1244 *4)) (|:| |den| *4))))) (-1658 (*1 *2 *1) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-2 (|:| |num| (-1244 *4)) (|:| |den| *4))))) (-4368 (*1 *1 *2 *3) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-1219 *4)) (-4 *4 (-1199)) (-4 *1 (-340 *4 *3 *5)) (-4 *5 (-1219 (-409 *3))))) (-1557 (*1 *2 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *1 (-340 *4 *5 *6)) (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-2 (|:| |num| (-679 *5)) (|:| |den| *5))))) (-1489 (*1 *2 *1 *3) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) (-1489 (*1 *2 *1 *3) (-12 (-4 *1 (-340 *4 *3 *5)) (-4 *4 (-1199)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 (-409 *3))) (-5 *2 (-121)))) (-4189 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))))) (-3498 (*1 *1 *2 *3) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-1219 *4)) (-4 *4 (-1199)) (-4 *1 (-340 *4 *3 *5)) (-4 *5 (-1219 (-409 *3))))) (-3250 (*1 *1 *1) (-12 (-4 *1 (-340 *2 *3 *4)) (-4 *2 (-1199)) (-4 *3 (-1219 *2)) (-4 *4 (-1219 (-409 *3))))) (-2779 (*1 *2 *1 *2 *2) (-12 (-4 *1 (-340 *2 *3 *4)) (-4 *2 (-1199)) (-4 *3 (-1219 *2)) (-4 *4 (-1219 (-409 *3))))) (-3633 (*1 *2) (|partial| -12 (-4 *1 (-340 *3 *2 *4)) (-4 *3 (-1199)) (-4 *4 (-1219 (-409 *2))) (-4 *2 (-1219 *3)))) (-3541 (*1 *2) (|partial| -12 (-4 *1 (-340 *3 *2 *4)) (-4 *3 (-1199)) (-4 *4 (-1219 (-409 *2))) (-4 *2 (-1219 *3)))) (-3223 (*1 *2 *1 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-1219 *4)) (-4 *4 (-1199)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-2 (|:| |num| *1) (|:| |den| *5) (|:| |derivden| *5) (|:| |gd| *5))) (-4 *1 (-340 *4 *5 *6)))) (-1296 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *1 (-340 *4 *5 *6)) (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-4 *4 (-365)) (-5 *2 (-634 (-953 *4))))) (-1895 (*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *3 (-370)) (-5 *2 (-634 (-634 *3)))))) 
-(-13 (-714 (-409 |t#2|) |t#3|) (-10 -8 (-15 -3900 ((-763))) (-15 -2126 ((-763))) (-15 -2262 ((-121))) (-15 -2234 ((-121) |t#1| |t#1|)) (-15 -4199 ((-121))) (-15 -2712 ((-121) |t#1|)) (-15 -2712 ((-121) |t#2|)) (-15 -3926 ((-121))) (-15 -1965 ((-121) |t#1|)) (-15 -1965 ((-121) |t#2|)) (-15 -4449 ((-121))) (-15 -4481 ((-121) |t#1|)) (-15 -4481 ((-121) |t#2|)) (-15 -3661 ((-1244 $))) (-15 -1820 ((-1244 $))) (-15 -3874 ((-121) $)) (-15 -1489 ((-121) $)) (-15 -3016 ((-1244 $) (-1244 $))) (-15 -3017 ((-1244 $) (-1244 $))) (-15 -3692 ((-1244 $) (-1244 $))) (-15 -1630 ((-679 (-409 |t#2|)))) (-15 -4472 ((-679 (-409 |t#2|)))) (-15 -3036 ((-679 (-409 |t#2|)))) (-15 -1300 ((-679 (-409 |t#2|)))) (-15 -2646 ((-2 (|:| |num| (-1244 |t#2|)) (|:| |den| |t#2|)) $)) (-15 -3498 ($ (-1244 |t#2|) |t#2|)) (-15 -1658 ((-2 (|:| |num| (-1244 |t#2|)) (|:| |den| |t#2|)) $)) (-15 -4368 ($ (-1244 |t#2|) |t#2|)) (-15 -1557 ((-2 (|:| |num| (-679 |t#2|)) (|:| |den| |t#2|)) (-1 |t#2| |t#2|))) (-15 -1489 ((-121) $ |t#1|)) (-15 -1489 ((-121) $ |t#2|)) (-15 -4189 ($ $ (-1 |t#2| |t#2|))) (-15 -3498 ($ (-1244 |t#2|) |t#2|)) (-15 -3250 ($ $)) (-15 -2779 (|t#1| $ |t#1| |t#1|)) (-15 -3633 ((-3 |t#2| "failed"))) (-15 -3541 ((-3 |t#2| "failed"))) (-15 -3223 ((-2 (|:| |num| $) (|:| |den| |t#2|) (|:| |derivden| |t#2|) (|:| |gd| |t#2|)) $ (-1 |t#2| |t#2|))) (IF (|has| |t#1| (-365)) (-15 -1296 ((-634 (-953 |t#1|)) (-1161))) |noBranch|) (IF (|has| |t#1| (-370)) (-15 -1895 ((-634 (-634 |t#1|)))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) -2198 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-43 (-409 |#2|)) . T) ((-43 $) -2198 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) -2198 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-120 (-409 |#2|) (-409 |#2|)) . T) ((-120 $ $) . T) ((-137) . T) ((-148) -2198 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-148))) ((-150) |has| (-409 |#2|) (-150)) ((-608 (-850)) . T) ((-172) . T) ((-609 |#3|) . T) ((-223 (-409 |#2|)) |has| (-409 |#2|) (-365)) ((-225) -2198 (|has| (-409 |#2|) (-350)) (-12 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365)))) ((-238) -2198 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-285) -2198 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-301) -2198 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-365) -2198 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-404) |has| (-409 |#2|) (-350)) ((-370) -2198 (|has| (-409 |#2|) (-370)) (|has| (-409 |#2|) (-350))) ((-350) |has| (-409 |#2|) (-350)) ((-372 (-409 |#2|) |#3|) . T) ((-411 (-409 |#2|) |#3|) . T) ((-379 (-409 |#2|)) . T) ((-413 (-409 |#2|)) . T) ((-453) -2198 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-558) -2198 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-637 (-409 (-568))) -2198 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-637 (-409 |#2|)) . T) ((-637 $) . T) ((-630 (-409 |#2|)) . T) ((-630 (-568)) |has| (-409 |#2|) (-630 (-568))) ((-707 (-409 (-568))) -2198 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-707 (-409 |#2|)) . T) ((-707 $) -2198 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-714 (-409 |#2|) |#3|) . T) ((-716) . T) ((-895 (-1161)) -12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161)))) ((-916) -2198 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-1037 (-409 (-568))) |has| (-409 |#2|) (-1037 (-409 (-568)))) ((-1037 (-409 |#2|)) . T) ((-1037 (-568)) |has| (-409 |#2|) (-1037 (-568))) ((-1053 (-409 (-568))) -2198 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-1053 (-409 |#2|)) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1136) |has| (-409 |#2|) (-350)) ((-1199) -2198 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-2615 (((-121) $) NIL)) (-1739 (((-763)) NIL)) (-1932 (((-905 |#1|) $) NIL) (($ $ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-3211 (((-1169 (-917) (-763)) (-568)) NIL (|has| (-905 |#1|) (-370)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1497 (((-121) $ $) NIL)) (-3983 (((-763)) NIL (|has| (-905 |#1|) (-370)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-905 |#1|) "failed") $) NIL)) (-2854 (((-905 |#1|) $) NIL)) (-3498 (($ (-1244 (-905 |#1|))) NIL)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-905 |#1|) (-370)))) (-2401 (($ $ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1731 (($) NIL (|has| (-905 |#1|) (-370)))) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-4220 (($) NIL (|has| (-905 |#1|) (-370)))) (-4456 (((-121) $) NIL (|has| (-905 |#1|) (-370)))) (-3218 (($ $ (-763)) NIL (-2198 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370)))) (($ $) NIL (-2198 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-3927 (((-121) $) NIL)) (-4477 (((-917) $) NIL (|has| (-905 |#1|) (-370))) (((-828 (-917)) $) NIL (-2198 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-2735 (((-121) $) NIL)) (-2883 (($) NIL (|has| (-905 |#1|) (-370)))) (-3917 (((-121) $) NIL (|has| (-905 |#1|) (-370)))) (-2657 (((-905 |#1|) $) NIL) (($ $ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-3038 (((-3 $ "failed") $) NIL (|has| (-905 |#1|) (-370)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2045 (((-1157 (-905 |#1|)) $) NIL) (((-1157 $) $ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-3683 (((-917) $) NIL (|has| (-905 |#1|) (-370)))) (-2035 (((-1157 (-905 |#1|)) $) NIL (|has| (-905 |#1|) (-370)))) (-1422 (((-1157 (-905 |#1|)) $) NIL (|has| (-905 |#1|) (-370))) (((-3 (-1157 (-905 |#1|)) "failed") $ $) NIL (|has| (-905 |#1|) (-370)))) (-2109 (($ $ (-1157 (-905 |#1|))) NIL (|has| (-905 |#1|) (-370)))) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4434 (($) NIL (|has| (-905 |#1|) (-370)) CONST)) (-4355 (($ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-2864 (((-121) $) NIL)) (-4022 (((-1108) $) NIL)) (-1936 (((-958 (-1108))) NIL)) (-2704 (($) NIL (|has| (-905 |#1|) (-370)))) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) NIL (|has| (-905 |#1|) (-370)))) (-3848 (((-420 $) $) NIL)) (-1553 (((-828 (-917))) NIL) (((-917)) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3143 (((-763) $) NIL (|has| (-905 |#1|) (-370))) (((-3 (-763) "failed") $ $) NIL (-2198 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-4321 (((-139)) NIL)) (-4189 (($ $) NIL (|has| (-905 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-905 |#1|) (-370)))) (-3206 (((-828 (-917)) $) NIL) (((-917) $) NIL)) (-1626 (((-1157 (-905 |#1|))) NIL)) (-3065 (($) NIL (|has| (-905 |#1|) (-370)))) (-2027 (($) NIL (|has| (-905 |#1|) (-370)))) (-4073 (((-1244 (-905 |#1|)) $) NIL) (((-679 (-905 |#1|)) (-1244 $)) NIL)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| (-905 |#1|) (-370)))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ (-905 |#1|)) NIL)) (-4371 (($ $) NIL (|has| (-905 |#1|) (-370))) (((-3 $ "failed") $) NIL (-2198 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-4078 (((-763)) NIL)) (-3746 (((-1244 $)) NIL) (((-1244 $) (-917)) NIL)) (-1826 (((-121) $ $) NIL)) (-4390 (((-121) $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-1316 (($ $) NIL (|has| (-905 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-905 |#1|) (-370)))) (-3190 (($ $) NIL (|has| (-905 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-905 |#1|) (-370)))) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ $) NIL) (($ $ (-905 |#1|)) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ $ (-905 |#1|)) NIL) (($ (-905 |#1|) $) NIL))) 
-(((-341 |#1| |#2|) (-13 (-327 (-905 |#1|)) (-10 -7 (-15 -1936 ((-958 (-1108)))))) (-917) (-917)) (T -341)) 
-((-1936 (*1 *2) (-12 (-5 *2 (-958 (-1108))) (-5 *1 (-341 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917))))) 
-(-13 (-327 (-905 |#1|)) (-10 -7 (-15 -1936 ((-958 (-1108)))))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 46)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-2615 (((-121) $) NIL)) (-1739 (((-763)) NIL)) (-1932 ((|#1| $) NIL) (($ $ (-917)) NIL (|has| |#1| (-370)))) (-3211 (((-1169 (-917) (-763)) (-568)) 43 (|has| |#1| (-370)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1497 (((-121) $ $) NIL)) (-3983 (((-763)) NIL (|has| |#1| (-370)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) 113)) (-2854 ((|#1| $) 84)) (-3498 (($ (-1244 |#1|)) 102)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) 93 (|has| |#1| (-370)))) (-2401 (($ $ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1731 (($) 96 (|has| |#1| (-370)))) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-4220 (($) 128 (|has| |#1| (-370)))) (-4456 (((-121) $) 49 (|has| |#1| (-370)))) (-3218 (($ $ (-763)) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370)))) (($ $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3927 (((-121) $) NIL)) (-4477 (((-917) $) 47 (|has| |#1| (-370))) (((-828 (-917)) $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-2735 (((-121) $) NIL)) (-2883 (($) 130 (|has| |#1| (-370)))) (-3917 (((-121) $) NIL (|has| |#1| (-370)))) (-2657 ((|#1| $) NIL) (($ $ (-917)) NIL (|has| |#1| (-370)))) (-3038 (((-3 $ "failed") $) NIL (|has| |#1| (-370)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2045 (((-1157 |#1|) $) 88) (((-1157 $) $ (-917)) NIL (|has| |#1| (-370)))) (-3683 (((-917) $) 138 (|has| |#1| (-370)))) (-2035 (((-1157 |#1|) $) NIL (|has| |#1| (-370)))) (-1422 (((-1157 |#1|) $) NIL (|has| |#1| (-370))) (((-3 (-1157 |#1|) "failed") $ $) NIL (|has| |#1| (-370)))) (-2109 (($ $ (-1157 |#1|)) NIL (|has| |#1| (-370)))) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) 145)) (-4434 (($) NIL (|has| |#1| (-370)) CONST)) (-4355 (($ (-917)) 70 (|has| |#1| (-370)))) (-2864 (((-121) $) 116)) (-4022 (((-1108) $) NIL)) (-1936 (((-958 (-1108))) 44)) (-2704 (($) 126 (|has| |#1| (-370)))) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) 91 (|has| |#1| (-370)))) (-3848 (((-420 $) $) NIL)) (-1553 (((-828 (-917))) 67) (((-917)) 68)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3143 (((-763) $) 129 (|has| |#1| (-370))) (((-3 (-763) "failed") $ $) 123 (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-4321 (((-139)) NIL)) (-4189 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-3206 (((-828 (-917)) $) NIL) (((-917) $) NIL)) (-1626 (((-1157 |#1|)) 94)) (-3065 (($) 127 (|has| |#1| (-370)))) (-2027 (($) 135 (|has| |#1| (-370)))) (-4073 (((-1244 |#1|) $) 59) (((-679 |#1|) (-1244 $)) NIL)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| |#1| (-370)))) (-2745 (((-850) $) 141) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ |#1|) 74)) (-4371 (($ $) NIL (|has| |#1| (-370))) (((-3 $ "failed") $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-4078 (((-763)) 137)) (-3746 (((-1244 $)) 115) (((-1244 $) (-917)) 72)) (-1826 (((-121) $ $) NIL)) (-4390 (((-121) $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) 32 T CONST)) (-1556 (($) 19 T CONST)) (-1316 (($ $) 80 (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-3190 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-1717 (((-121) $ $) 48)) (-1779 (($ $ $) 143) (($ $ |#1|) 144)) (-1773 (($ $) 125) (($ $ $) NIL)) (-1767 (($ $ $) 61)) (** (($ $ (-917)) 147) (($ $ (-763)) 148) (($ $ (-568)) 146)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 76) (($ $ $) 75) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) 142))) 
-(((-342 |#1| |#2|) (-13 (-327 |#1|) (-10 -7 (-15 -1936 ((-958 (-1108)))))) (-350) (-1157 |#1|)) (T -342)) 
-((-1936 (*1 *2) (-12 (-5 *2 (-958 (-1108))) (-5 *1 (-342 *3 *4)) (-4 *3 (-350)) (-14 *4 (-1157 *3))))) 
-(-13 (-327 |#1|) (-10 -7 (-15 -1936 ((-958 (-1108)))))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-2615 (((-121) $) NIL)) (-1739 (((-763)) NIL)) (-1932 ((|#1| $) NIL) (($ $ (-917)) NIL (|has| |#1| (-370)))) (-3211 (((-1169 (-917) (-763)) (-568)) NIL (|has| |#1| (-370)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1497 (((-121) $ $) NIL)) (-3983 (((-763)) NIL (|has| |#1| (-370)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) NIL)) (-2854 ((|#1| $) NIL)) (-3498 (($ (-1244 |#1|)) NIL)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| |#1| (-370)))) (-2401 (($ $ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1731 (($) NIL (|has| |#1| (-370)))) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-4220 (($) NIL (|has| |#1| (-370)))) (-4456 (((-121) $) NIL (|has| |#1| (-370)))) (-3218 (($ $ (-763)) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370)))) (($ $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3927 (((-121) $) NIL)) (-4477 (((-917) $) NIL (|has| |#1| (-370))) (((-828 (-917)) $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-2735 (((-121) $) NIL)) (-2883 (($) NIL (|has| |#1| (-370)))) (-3917 (((-121) $) NIL (|has| |#1| (-370)))) (-2657 ((|#1| $) NIL) (($ $ (-917)) NIL (|has| |#1| (-370)))) (-3038 (((-3 $ "failed") $) NIL (|has| |#1| (-370)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2045 (((-1157 |#1|) $) NIL) (((-1157 $) $ (-917)) NIL (|has| |#1| (-370)))) (-3683 (((-917) $) NIL (|has| |#1| (-370)))) (-2035 (((-1157 |#1|) $) NIL (|has| |#1| (-370)))) (-1422 (((-1157 |#1|) $) NIL (|has| |#1| (-370))) (((-3 (-1157 |#1|) "failed") $ $) NIL (|has| |#1| (-370)))) (-2109 (($ $ (-1157 |#1|)) NIL (|has| |#1| (-370)))) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4434 (($) NIL (|has| |#1| (-370)) CONST)) (-4355 (($ (-917)) NIL (|has| |#1| (-370)))) (-2864 (((-121) $) NIL)) (-4022 (((-1108) $) NIL)) (-1936 (((-958 (-1108))) NIL)) (-2704 (($) NIL (|has| |#1| (-370)))) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) NIL (|has| |#1| (-370)))) (-3848 (((-420 $) $) NIL)) (-1553 (((-828 (-917))) NIL) (((-917)) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3143 (((-763) $) NIL (|has| |#1| (-370))) (((-3 (-763) "failed") $ $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-4321 (((-139)) NIL)) (-4189 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-3206 (((-828 (-917)) $) NIL) (((-917) $) NIL)) (-1626 (((-1157 |#1|)) NIL)) (-3065 (($) NIL (|has| |#1| (-370)))) (-2027 (($) NIL (|has| |#1| (-370)))) (-4073 (((-1244 |#1|) $) NIL) (((-679 |#1|) (-1244 $)) NIL)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| |#1| (-370)))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ |#1|) NIL)) (-4371 (($ $) NIL (|has| |#1| (-370))) (((-3 $ "failed") $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-4078 (((-763)) NIL)) (-3746 (((-1244 $)) NIL) (((-1244 $) (-917)) NIL)) (-1826 (((-121) $ $) NIL)) (-4390 (((-121) $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-1316 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-3190 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ $) NIL) (($ $ |#1|) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
-(((-343 |#1| |#2|) (-13 (-327 |#1|) (-10 -7 (-15 -1936 ((-958 (-1108)))))) (-350) (-917)) (T -343)) 
-((-1936 (*1 *2) (-12 (-5 *2 (-958 (-1108))) (-5 *1 (-343 *3 *4)) (-4 *3 (-350)) (-14 *4 (-917))))) 
-(-13 (-327 |#1|) (-10 -7 (-15 -1936 ((-958 (-1108)))))) 
-((-4067 (((-121) |#2|) 68)) (-3593 (((-420 |#2|) |#2|) 56)) (-2477 (((-420 |#2|) |#2|) 58)) (-2630 (((-634 |#2|) |#2|) 61)) (-3161 (((-634 |#2|) |#2| (-763)) 62)) (-3848 (((-420 |#2|) |#2|) 59))) 
-(((-344 |#1| |#2|) (-10 -7 (-15 -2630 ((-634 |#2|) |#2|)) (-15 -3161 ((-634 |#2|) |#2| (-763))) (-15 -3848 ((-420 |#2|) |#2|)) (-15 -3593 ((-420 |#2|) |#2|)) (-15 -2477 ((-420 |#2|) |#2|)) (-15 -4067 ((-121) |#2|))) (-350) (-1219 |#1|)) (T -344)) 
-((-4067 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-121)) (-5 *1 (-344 *4 *3)) (-4 *3 (-1219 *4)))) (-2477 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-344 *4 *3)) (-4 *3 (-1219 *4)))) (-3593 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-344 *4 *3)) (-4 *3 (-1219 *4)))) (-3848 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-344 *4 *3)) (-4 *3 (-1219 *4)))) (-3161 (*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-350)) (-5 *2 (-634 *3)) (-5 *1 (-344 *5 *3)) (-4 *3 (-1219 *5)))) (-2630 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-634 *3)) (-5 *1 (-344 *4 *3)) (-4 *3 (-1219 *4))))) 
-(-10 -7 (-15 -2630 ((-634 |#2|) |#2|)) (-15 -3161 ((-634 |#2|) |#2| (-763))) (-15 -3848 ((-420 |#2|) |#2|)) (-15 -3593 ((-420 |#2|) |#2|)) (-15 -2477 ((-420 |#2|) |#2|)) (-15 -4067 ((-121) |#2|))) 
-((-4415 (((-1141 (-679 (-1157 |#1|))) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#3|) (-763) (-763)) 54) (((-679 (-1157 |#1|)) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#3|) (-634 (-763))) 42))) 
-(((-345 |#1| |#2| |#3|) (-10 -7 (-15 -4415 ((-679 (-1157 |#1|)) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#3|) (-634 (-763)))) (-15 -4415 ((-1141 (-679 (-1157 |#1|))) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#3|) (-763) (-763)))) (-13 (-558) (-453)) (-324 |#1| (-763)) (-324 (-409 |#1|) (-763))) (T -345)) 
-((-4415 (*1 *2 *3 *4 *5 *6 *6) (-12 (-5 *3 (-634 *7)) (-5 *4 (-1 *7 (-763) (-763) *8)) (-5 *5 (-1244 *9)) (-5 *6 (-763)) (-4 *7 (-13 (-558) (-453))) (-4 *8 (-324 *7 *6)) (-4 *9 (-324 (-409 *7) *6)) (-5 *2 (-1141 (-679 (-1157 *7)))) (-5 *1 (-345 *7 *8 *9)))) (-4415 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-634 *7)) (-5 *4 (-1 *7 (-763) (-763) *8)) (-5 *5 (-1244 *9)) (-5 *6 (-634 (-763))) (-4 *7 (-13 (-558) (-453))) (-4 *8 (-324 *7 (-763))) (-4 *9 (-324 (-409 *7) (-763))) (-5 *2 (-679 (-1157 *7))) (-5 *1 (-345 *7 *8 *9))))) 
-(-10 -7 (-15 -4415 ((-679 (-1157 |#1|)) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#3|) (-634 (-763)))) (-15 -4415 ((-1141 (-679 (-1157 |#1|))) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#3|) (-763) (-763)))) 
-((-4197 (((-634 |#1|) |#1| (-763)) 21)) (-4320 ((|#1| |#1| (-763) (-763) |#2|) 20)) (-1919 (((-409 (-1157 |#1|)) (-634 (-409 |#1|)) (-634 (-409 |#1|)) (-763)) 75) (((-409 (-1157 |#1|)) (-634 |#1|) (-634 |#1|) (-763)) 68)) (-4415 (((-1141 (-679 (-1157 |#1|))) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#2|) (-763) (-763)) 62) (((-679 (-1157 |#1|)) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#2|) (-634 (-763))) 44)) (-1294 ((|#1| (-1 |#1| (-763) (-763) |#2|) (-1244 |#2|) (-763) (-1244 (-1157 |#1|))) 37)) (-1442 (((-679 (-1157 |#1|)) (-634 |#1|) (-1 |#1| (-763) (-1244 (-1157 |#1|))) (-634 (-763))) 43)) (-1564 (((-634 |#1|) (-763)) 17)) (-3325 ((|#1| (-763) (-763) |#2|) 11)) (-3097 (((-634 |#1|) (-763)) 24)) (-3155 ((|#1| (-763) (-763) |#2|) 22))) 
-(((-346 |#1| |#2|) (-10 -7 (-15 -1442 ((-679 (-1157 |#1|)) (-634 |#1|) (-1 |#1| (-763) (-1244 (-1157 |#1|))) (-634 (-763)))) (-15 -1919 ((-409 (-1157 |#1|)) (-634 |#1|) (-634 |#1|) (-763))) (-15 -1919 ((-409 (-1157 |#1|)) (-634 (-409 |#1|)) (-634 (-409 |#1|)) (-763))) (-15 -4415 ((-679 (-1157 |#1|)) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#2|) (-634 (-763)))) (-15 -4415 ((-1141 (-679 (-1157 |#1|))) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#2|) (-763) (-763))) (-15 -1294 (|#1| (-1 |#1| (-763) (-763) |#2|) (-1244 |#2|) (-763) (-1244 (-1157 |#1|)))) (-15 -3325 (|#1| (-763) (-763) |#2|)) (-15 -1564 ((-634 |#1|) (-763))) (-15 -3155 (|#1| (-763) (-763) |#2|)) (-15 -3097 ((-634 |#1|) (-763))) (-15 -4320 (|#1| |#1| (-763) (-763) |#2|)) (-15 -4197 ((-634 |#1|) |#1| (-763)))) (-13 (-558) (-453)) (-52 |#1| (-763))) (T -346)) 
-((-4197 (*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-4 *3 (-13 (-558) (-453))) (-5 *2 (-634 *3)) (-5 *1 (-346 *3 *5)) (-4 *5 (-52 *3 *4)))) (-4320 (*1 *2 *2 *3 *3 *4) (-12 (-5 *3 (-763)) (-4 *2 (-13 (-558) (-453))) (-5 *1 (-346 *2 *4)) (-4 *4 (-52 *2 *3)))) (-3097 (*1 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-13 (-558) (-453))) (-5 *2 (-634 *4)) (-5 *1 (-346 *4 *5)) (-4 *5 (-52 *4 *3)))) (-3155 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-763)) (-4 *2 (-13 (-558) (-453))) (-5 *1 (-346 *2 *4)) (-4 *4 (-52 *2 *3)))) (-1564 (*1 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-13 (-558) (-453))) (-5 *2 (-634 *4)) (-5 *1 (-346 *4 *5)) (-4 *5 (-52 *4 *3)))) (-3325 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-763)) (-4 *2 (-13 (-558) (-453))) (-5 *1 (-346 *2 *4)) (-4 *4 (-52 *2 *3)))) (-1294 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *2 (-763) (-763) *7)) (-5 *4 (-1244 *7)) (-5 *5 (-763)) (-5 *6 (-1244 (-1157 *2))) (-4 *7 (-52 *2 *5)) (-4 *2 (-13 (-558) (-453))) (-5 *1 (-346 *2 *7)))) (-4415 (*1 *2 *3 *4 *5 *6 *6) (-12 (-5 *3 (-634 *7)) (-5 *4 (-1 *7 (-763) (-763) *8)) (-5 *5 (-1244 *8)) (-5 *6 (-763)) (-4 *7 (-13 (-558) (-453))) (-4 *8 (-52 *7 *6)) (-5 *2 (-1141 (-679 (-1157 *7)))) (-5 *1 (-346 *7 *8)))) (-4415 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-634 *7)) (-5 *4 (-1 *7 (-763) (-763) *8)) (-5 *5 (-1244 *8)) (-5 *6 (-634 (-763))) (-4 *7 (-13 (-558) (-453))) (-4 *8 (-52 *7 (-763))) (-5 *2 (-679 (-1157 *7))) (-5 *1 (-346 *7 *8)))) (-1919 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-634 (-409 *5))) (-4 *5 (-13 (-558) (-453))) (-5 *4 (-763)) (-5 *2 (-409 (-1157 *5))) (-5 *1 (-346 *5 *6)) (-4 *6 (-52 *5 *4)))) (-1919 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-634 *5)) (-4 *5 (-13 (-558) (-453))) (-5 *4 (-763)) (-5 *2 (-409 (-1157 *5))) (-5 *1 (-346 *5 *6)) (-4 *6 (-52 *5 *4)))) (-1442 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 *6)) (-5 *4 (-1 *6 (-763) (-1244 (-1157 *6)))) (-5 *5 (-634 (-763))) (-4 *6 (-13 (-558) (-453))) (-5 *2 (-679 (-1157 *6))) (-5 *1 (-346 *6 *7)) (-4 *7 (-52 *6 (-763)))))) 
-(-10 -7 (-15 -1442 ((-679 (-1157 |#1|)) (-634 |#1|) (-1 |#1| (-763) (-1244 (-1157 |#1|))) (-634 (-763)))) (-15 -1919 ((-409 (-1157 |#1|)) (-634 |#1|) (-634 |#1|) (-763))) (-15 -1919 ((-409 (-1157 |#1|)) (-634 (-409 |#1|)) (-634 (-409 |#1|)) (-763))) (-15 -4415 ((-679 (-1157 |#1|)) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#2|) (-634 (-763)))) (-15 -4415 ((-1141 (-679 (-1157 |#1|))) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#2|) (-763) (-763))) (-15 -1294 (|#1| (-1 |#1| (-763) (-763) |#2|) (-1244 |#2|) (-763) (-1244 (-1157 |#1|)))) (-15 -3325 (|#1| (-763) (-763) |#2|)) (-15 -1564 ((-634 |#1|) (-763))) (-15 -3155 (|#1| (-763) (-763) |#2|)) (-15 -3097 ((-634 |#1|) (-763))) (-15 -4320 (|#1| |#1| (-763) (-763) |#2|)) (-15 -4197 ((-634 |#1|) |#1| (-763)))) 
-((-4433 (((-763) (-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108)))))) 40)) (-1453 (((-958 (-1108)) (-1157 |#1|)) 84)) (-4420 (((-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108))))) (-1157 |#1|)) 77)) (-2405 (((-679 |#1|) (-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108)))))) 85)) (-4298 (((-3 (-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108))))) "failed") (-917)) 10)) (-2001 (((-3 (-1157 |#1|) (-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108)))))) (-917)) 15))) 
-(((-347 |#1|) (-10 -7 (-15 -1453 ((-958 (-1108)) (-1157 |#1|))) (-15 -4420 ((-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108))))) (-1157 |#1|))) (-15 -2405 ((-679 |#1|) (-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108))))))) (-15 -4433 ((-763) (-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108))))))) (-15 -4298 ((-3 (-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108))))) "failed") (-917))) (-15 -2001 ((-3 (-1157 |#1|) (-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108)))))) (-917)))) (-350)) (T -347)) 
-((-2001 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-3 (-1157 *4) (-1244 (-634 (-2 (|:| -2850 *4) (|:| -4355 (-1108))))))) (-5 *1 (-347 *4)) (-4 *4 (-350)))) (-4298 (*1 *2 *3) (|partial| -12 (-5 *3 (-917)) (-5 *2 (-1244 (-634 (-2 (|:| -2850 *4) (|:| -4355 (-1108)))))) (-5 *1 (-347 *4)) (-4 *4 (-350)))) (-4433 (*1 *2 *3) (-12 (-5 *3 (-1244 (-634 (-2 (|:| -2850 *4) (|:| -4355 (-1108)))))) (-4 *4 (-350)) (-5 *2 (-763)) (-5 *1 (-347 *4)))) (-2405 (*1 *2 *3) (-12 (-5 *3 (-1244 (-634 (-2 (|:| -2850 *4) (|:| -4355 (-1108)))))) (-4 *4 (-350)) (-5 *2 (-679 *4)) (-5 *1 (-347 *4)))) (-4420 (*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-350)) (-5 *2 (-1244 (-634 (-2 (|:| -2850 *4) (|:| -4355 (-1108)))))) (-5 *1 (-347 *4)))) (-1453 (*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-350)) (-5 *2 (-958 (-1108))) (-5 *1 (-347 *4))))) 
-(-10 -7 (-15 -1453 ((-958 (-1108)) (-1157 |#1|))) (-15 -4420 ((-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108))))) (-1157 |#1|))) (-15 -2405 ((-679 |#1|) (-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108))))))) (-15 -4433 ((-763) (-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108))))))) (-15 -4298 ((-3 (-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108))))) "failed") (-917))) (-15 -2001 ((-3 (-1157 |#1|) (-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108)))))) (-917)))) 
-((-2745 ((|#1| |#3|) 84) ((|#3| |#1|) 68))) 
-(((-348 |#1| |#2| |#3|) (-10 -7 (-15 -2745 (|#3| |#1|)) (-15 -2745 (|#1| |#3|))) (-327 |#2|) (-350) (-327 |#2|)) (T -348)) 
-((-2745 (*1 *2 *3) (-12 (-4 *4 (-350)) (-4 *2 (-327 *4)) (-5 *1 (-348 *2 *4 *3)) (-4 *3 (-327 *4)))) (-2745 (*1 *2 *3) (-12 (-4 *4 (-350)) (-4 *2 (-327 *4)) (-5 *1 (-348 *3 *4 *2)) (-4 *3 (-327 *4))))) 
-(-10 -7 (-15 -2745 (|#3| |#1|)) (-15 -2745 (|#1| |#3|))) 
-((-4456 (((-121) $) 50)) (-4477 (((-828 (-917)) $) 21) (((-917) $) 51)) (-3038 (((-3 $ "failed") $) 16)) (-4434 (($) 9)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 91)) (-3143 (((-3 (-763) "failed") $ $) 70) (((-763) $) 59)) (-4189 (($ $ (-763)) NIL) (($ $) 8)) (-3065 (($) 44)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) 33)) (-4371 (((-3 $ "failed") $) 39) (($ $) 38))) 
-(((-349 |#1|) (-10 -8 (-15 -4477 ((-917) |#1|)) (-15 -3143 ((-763) |#1|)) (-15 -4456 ((-121) |#1|)) (-15 -3065 (|#1|)) (-15 -2979 ((-3 (-1244 |#1|) "failed") (-679 |#1|))) (-15 -4371 (|#1| |#1|)) (-15 -4189 (|#1| |#1|)) (-15 -4189 (|#1| |#1| (-763))) (-15 -4434 (|#1|)) (-15 -3038 ((-3 |#1| "failed") |#1|)) (-15 -3143 ((-3 (-763) "failed") |#1| |#1|)) (-15 -4477 ((-828 (-917)) |#1|)) (-15 -4371 ((-3 |#1| "failed") |#1|)) (-15 -2155 ((-1157 |#1|) (-1157 |#1|) (-1157 |#1|)))) (-350)) (T -349)) 
-NIL 
-(-10 -8 (-15 -4477 ((-917) |#1|)) (-15 -3143 ((-763) |#1|)) (-15 -4456 ((-121) |#1|)) (-15 -3065 (|#1|)) (-15 -2979 ((-3 (-1244 |#1|) "failed") (-679 |#1|))) (-15 -4371 (|#1| |#1|)) (-15 -4189 (|#1| |#1|)) (-15 -4189 (|#1| |#1| (-763))) (-15 -4434 (|#1|)) (-15 -3038 ((-3 |#1| "failed") |#1|)) (-15 -3143 ((-3 (-763) "failed") |#1| |#1|)) (-15 -4477 ((-828 (-917)) |#1|)) (-15 -4371 ((-3 |#1| "failed") |#1|)) (-15 -2155 ((-1157 |#1|) (-1157 |#1|) (-1157 |#1|)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-3211 (((-1169 (-917) (-763)) (-568)) 88)) (-3134 (((-3 $ "failed") $ $) 18)) (-4305 (($ $) 71)) (-1678 (((-420 $) $) 70)) (-1497 (((-121) $ $) 57)) (-3983 (((-763)) 98)) (-2671 (($) 16 T CONST)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) 82)) (-2401 (($ $ $) 53)) (-2925 (((-3 $ "failed") $) 33)) (-1731 (($) 101)) (-2412 (($ $ $) 54)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 49)) (-4220 (($) 86)) (-4456 (((-121) $) 85)) (-3218 (($ $) 75) (($ $ (-763)) 74)) (-3927 (((-121) $) 69)) (-4477 (((-828 (-917)) $) 77) (((-917) $) 83)) (-2735 (((-121) $) 30)) (-3038 (((-3 $ "failed") $) 97)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-3683 (((-917) $) 100)) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-2081 (($ $) 68)) (-4434 (($) 96 T CONST)) (-4355 (($ (-917)) 99)) (-4022 (((-1108) $) 10)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) 89)) (-3848 (((-420 $) $) 72)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2595 (((-3 $ "failed") $ $) 41)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-2709 (((-763) $) 56)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 55)) (-3143 (((-3 (-763) "failed") $ $) 76) (((-763) $) 84)) (-4189 (($ $ (-763)) 94) (($ $) 92)) (-3065 (($) 87)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) 90)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63)) (-4371 (((-3 $ "failed") $) 78) (($ $) 91)) (-4078 (((-763)) 28)) (-1826 (((-121) $ $) 38)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $ (-763)) 95) (($ $) 93)) (-1717 (((-121) $ $) 6)) (-1779 (($ $ $) 62)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64))) 
+((-2066 (*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-763)))) (-3383 (*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-763)))) (-3341 (*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) (-2679 (*1 *2 *3 *3) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) (-4077 (*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) (-1487 (*1 *2 *3) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) (-1487 (*1 *2 *3) (-12 (-4 *1 (-340 *4 *3 *5)) (-4 *4 (-1199)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 (-409 *3))) (-5 *2 (-121)))) (-2191 (*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) (-4347 (*1 *2 *3) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) (-4347 (*1 *2 *3) (-12 (-4 *1 (-340 *4 *3 *5)) (-4 *4 (-1199)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 (-409 *3))) (-5 *2 (-121)))) (-1700 (*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) (-1862 (*1 *2 *3) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) (-1862 (*1 *2 *3) (-12 (-4 *1 (-340 *4 *3 *5)) (-4 *4 (-1199)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 (-409 *3))) (-5 *2 (-121)))) (-3330 (*1 *2) (-12 (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-1244 *1)) (-4 *1 (-340 *3 *4 *5)))) (-2239 (*1 *2) (-12 (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-1244 *1)) (-4 *1 (-340 *3 *4 *5)))) (-1979 (*1 *2 *1) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) (-2548 (*1 *2 *1) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) (-3224 (*1 *2 *2) (-12 (-5 *2 (-1244 *1)) (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))))) (-3233 (*1 *2 *2) (-12 (-5 *2 (-1244 *1)) (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))))) (-2331 (*1 *2 *2) (-12 (-5 *2 (-1244 *1)) (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))))) (-1515 (*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-679 (-409 *4))))) (-1822 (*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-679 (-409 *4))))) (-2208 (*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-679 (-409 *4))))) (-3281 (*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-679 (-409 *4))))) (-4354 (*1 *2 *1) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-2 (|:| |num| (-1244 *4)) (|:| |den| *4))))) (-3363 (*1 *2 *1) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-2 (|:| |num| (-1244 *4)) (|:| |den| *4))))) (-3368 (*1 *1 *2 *3) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-1219 *4)) (-4 *4 (-1199)) (-4 *1 (-340 *4 *3 *5)) (-4 *5 (-1219 (-409 *3))))) (-4339 (*1 *2 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *1 (-340 *4 *5 *6)) (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-2 (|:| |num| (-679 *5)) (|:| |den| *5))))) (-2548 (*1 *2 *1 *3) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) (-2548 (*1 *2 *1 *3) (-12 (-4 *1 (-340 *4 *3 *5)) (-4 *4 (-1199)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 (-409 *3))) (-5 *2 (-121)))) (-4191 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))))) (-3899 (*1 *1 *2 *3) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-1219 *4)) (-4 *4 (-1199)) (-4 *1 (-340 *4 *3 *5)) (-4 *5 (-1219 (-409 *3))))) (-1998 (*1 *1 *1) (-12 (-4 *1 (-340 *2 *3 *4)) (-4 *2 (-1199)) (-4 *3 (-1219 *2)) (-4 *4 (-1219 (-409 *3))))) (-2781 (*1 *2 *1 *2 *2) (-12 (-4 *1 (-340 *2 *3 *4)) (-4 *2 (-1199)) (-4 *3 (-1219 *2)) (-4 *4 (-1219 (-409 *3))))) (-3146 (*1 *2) (|partial| -12 (-4 *1 (-340 *3 *2 *4)) (-4 *3 (-1199)) (-4 *4 (-1219 (-409 *2))) (-4 *2 (-1219 *3)))) (-4201 (*1 *2) (|partial| -12 (-4 *1 (-340 *3 *2 *4)) (-4 *3 (-1199)) (-4 *4 (-1219 (-409 *2))) (-4 *2 (-1219 *3)))) (-1900 (*1 *2 *1 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-1219 *4)) (-4 *4 (-1199)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-2 (|:| |num| *1) (|:| |den| *5) (|:| |derivden| *5) (|:| |gd| *5))) (-4 *1 (-340 *4 *5 *6)))) (-3247 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *1 (-340 *4 *5 *6)) (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-4 *4 (-365)) (-5 *2 (-634 (-953 *4))))) (-2603 (*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *3 (-370)) (-5 *2 (-634 (-634 *3)))))) 
+(-13 (-714 (-409 |t#2|) |t#3|) (-10 -8 (-15 -2066 ((-763))) (-15 -3383 ((-763))) (-15 -3341 ((-121))) (-15 -2679 ((-121) |t#1| |t#1|)) (-15 -4077 ((-121))) (-15 -1487 ((-121) |t#1|)) (-15 -1487 ((-121) |t#2|)) (-15 -2191 ((-121))) (-15 -4347 ((-121) |t#1|)) (-15 -4347 ((-121) |t#2|)) (-15 -1700 ((-121))) (-15 -1862 ((-121) |t#1|)) (-15 -1862 ((-121) |t#2|)) (-15 -3330 ((-1244 $))) (-15 -2239 ((-1244 $))) (-15 -1979 ((-121) $)) (-15 -2548 ((-121) $)) (-15 -3224 ((-1244 $) (-1244 $))) (-15 -3233 ((-1244 $) (-1244 $))) (-15 -2331 ((-1244 $) (-1244 $))) (-15 -1515 ((-679 (-409 |t#2|)))) (-15 -1822 ((-679 (-409 |t#2|)))) (-15 -2208 ((-679 (-409 |t#2|)))) (-15 -3281 ((-679 (-409 |t#2|)))) (-15 -4354 ((-2 (|:| |num| (-1244 |t#2|)) (|:| |den| |t#2|)) $)) (-15 -3899 ($ (-1244 |t#2|) |t#2|)) (-15 -3363 ((-2 (|:| |num| (-1244 |t#2|)) (|:| |den| |t#2|)) $)) (-15 -3368 ($ (-1244 |t#2|) |t#2|)) (-15 -4339 ((-2 (|:| |num| (-679 |t#2|)) (|:| |den| |t#2|)) (-1 |t#2| |t#2|))) (-15 -2548 ((-121) $ |t#1|)) (-15 -2548 ((-121) $ |t#2|)) (-15 -4191 ($ $ (-1 |t#2| |t#2|))) (-15 -3899 ($ (-1244 |t#2|) |t#2|)) (-15 -1998 ($ $)) (-15 -2781 (|t#1| $ |t#1| |t#1|)) (-15 -3146 ((-3 |t#2| "failed"))) (-15 -4201 ((-3 |t#2| "failed"))) (-15 -1900 ((-2 (|:| |num| $) (|:| |den| |t#2|) (|:| |derivden| |t#2|) (|:| |gd| |t#2|)) $ (-1 |t#2| |t#2|))) (IF (|has| |t#1| (-365)) (-15 -3247 ((-634 (-953 |t#1|)) (-1161))) |noBranch|) (IF (|has| |t#1| (-370)) (-15 -2603 ((-634 (-634 |t#1|)))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) -2199 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-43 (-409 |#2|)) . T) ((-43 $) -2199 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) -2199 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-120 (-409 |#2|) (-409 |#2|)) . T) ((-120 $ $) . T) ((-137) . T) ((-148) -2199 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-148))) ((-150) |has| (-409 |#2|) (-150)) ((-608 (-850)) . T) ((-172) . T) ((-609 |#3|) . T) ((-223 (-409 |#2|)) |has| (-409 |#2|) (-365)) ((-225) -2199 (|has| (-409 |#2|) (-350)) (-12 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365)))) ((-238) -2199 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-285) -2199 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-301) -2199 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-365) -2199 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-404) |has| (-409 |#2|) (-350)) ((-370) -2199 (|has| (-409 |#2|) (-370)) (|has| (-409 |#2|) (-350))) ((-350) |has| (-409 |#2|) (-350)) ((-372 (-409 |#2|) |#3|) . T) ((-411 (-409 |#2|) |#3|) . T) ((-379 (-409 |#2|)) . T) ((-413 (-409 |#2|)) . T) ((-453) -2199 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-558) -2199 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-637 (-409 (-568))) -2199 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-637 (-409 |#2|)) . T) ((-637 $) . T) ((-630 (-409 |#2|)) . T) ((-630 (-568)) |has| (-409 |#2|) (-630 (-568))) ((-707 (-409 (-568))) -2199 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-707 (-409 |#2|)) . T) ((-707 $) -2199 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-714 (-409 |#2|) |#3|) . T) ((-716) . T) ((-895 (-1161)) -12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161)))) ((-916) -2199 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-1037 (-409 (-568))) |has| (-409 |#2|) (-1037 (-409 (-568)))) ((-1037 (-409 |#2|)) . T) ((-1037 (-568)) |has| (-409 |#2|) (-1037 (-568))) ((-1053 (-409 (-568))) -2199 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365))) ((-1053 (-409 |#2|)) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1136) |has| (-409 |#2|) (-350)) ((-1199) -2199 (|has| (-409 |#2|) (-350)) (|has| (-409 |#2|) (-365)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2134 (((-121) $) NIL)) (-3800 (((-763)) NIL)) (-1934 (((-905 |#1|) $) NIL) (($ $ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-1856 (((-1169 (-917) (-763)) (-568)) NIL (|has| (-905 |#1|) (-370)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2589 (((-121) $ $) NIL)) (-3986 (((-763)) NIL (|has| (-905 |#1|) (-370)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-905 |#1|) "failed") $) NIL)) (-2857 (((-905 |#1|) $) NIL)) (-3899 (($ (-1244 (-905 |#1|))) NIL)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-905 |#1|) (-370)))) (-2403 (($ $ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1733 (($) NIL (|has| (-905 |#1|) (-370)))) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-4188 (($) NIL (|has| (-905 |#1|) (-370)))) (-1748 (((-121) $) NIL (|has| (-905 |#1|) (-370)))) (-1887 (($ $ (-763)) NIL (-2199 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370)))) (($ $) NIL (-2199 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-2197 (((-121) $) NIL)) (-1844 (((-917) $) NIL (|has| (-905 |#1|) (-370))) (((-828 (-917)) $) NIL (-2199 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-1598 (((-121) $) NIL)) (-2769 (($) NIL (|has| (-905 |#1|) (-370)))) (-2151 (((-121) $) NIL (|has| (-905 |#1|) (-370)))) (-4417 (((-905 |#1|) $) NIL) (($ $ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-2214 (((-3 $ "failed") $) NIL (|has| (-905 |#1|) (-370)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1497 (((-1157 (-905 |#1|)) $) NIL) (((-1157 $) $ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-2291 (((-917) $) NIL (|has| (-905 |#1|) (-370)))) (-1447 (((-1157 (-905 |#1|)) $) NIL (|has| (-905 |#1|) (-370)))) (-2193 (((-1157 (-905 |#1|)) $) NIL (|has| (-905 |#1|) (-370))) (((-3 (-1157 (-905 |#1|)) "failed") $ $) NIL (|has| (-905 |#1|) (-370)))) (-3257 (($ $ (-1157 (-905 |#1|))) NIL (|has| (-905 |#1|) (-370)))) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4436 (($) NIL (|has| (-905 |#1|) (-370)) CONST)) (-4357 (($ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-4051 (((-121) $) NIL)) (-4025 (((-1108) $) NIL)) (-4212 (((-958 (-1108))) NIL)) (-2707 (($) NIL (|has| (-905 |#1|) (-370)))) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) NIL (|has| (-905 |#1|) (-370)))) (-3850 (((-420 $) $) NIL)) (-4321 (((-828 (-917))) NIL) (((-917)) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-2721 (((-763) $) NIL (|has| (-905 |#1|) (-370))) (((-3 (-763) "failed") $ $) NIL (-2199 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-3108 (((-139)) NIL)) (-4191 (($ $) NIL (|has| (-905 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-905 |#1|) (-370)))) (-1836 (((-828 (-917)) $) NIL) (((-917) $) NIL)) (-1492 (((-1157 (-905 |#1|))) NIL)) (-2330 (($) NIL (|has| (-905 |#1|) (-370)))) (-1398 (($) NIL (|has| (-905 |#1|) (-370)))) (-1656 (((-1244 (-905 |#1|)) $) NIL) (((-679 (-905 |#1|)) (-1244 $)) NIL)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| (-905 |#1|) (-370)))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ (-905 |#1|)) NIL)) (-3385 (($ $) NIL (|has| (-905 |#1|) (-370))) (((-3 $ "failed") $) NIL (-2199 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-3425 (((-763)) NIL)) (-2588 (((-1244 $)) NIL) (((-1244 $) (-917)) NIL)) (-2273 (((-121) $ $) NIL)) (-1413 (((-121) $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3412 (($ $) NIL (|has| (-905 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-905 |#1|) (-370)))) (-3192 (($ $) NIL (|has| (-905 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-905 |#1|) (-370)))) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ $) NIL) (($ $ (-905 |#1|)) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ $ (-905 |#1|)) NIL) (($ (-905 |#1|) $) NIL))) 
+(((-341 |#1| |#2|) (-13 (-327 (-905 |#1|)) (-10 -7 (-15 -4212 ((-958 (-1108)))))) (-917) (-917)) (T -341)) 
+((-4212 (*1 *2) (-12 (-5 *2 (-958 (-1108))) (-5 *1 (-341 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917))))) 
+(-13 (-327 (-905 |#1|)) (-10 -7 (-15 -4212 ((-958 (-1108)))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 46)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2134 (((-121) $) NIL)) (-3800 (((-763)) NIL)) (-1934 ((|#1| $) NIL) (($ $ (-917)) NIL (|has| |#1| (-370)))) (-1856 (((-1169 (-917) (-763)) (-568)) 43 (|has| |#1| (-370)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2589 (((-121) $ $) NIL)) (-3986 (((-763)) NIL (|has| |#1| (-370)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) 113)) (-2857 ((|#1| $) 84)) (-3899 (($ (-1244 |#1|)) 102)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) 93 (|has| |#1| (-370)))) (-2403 (($ $ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1733 (($) 96 (|has| |#1| (-370)))) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-4188 (($) 128 (|has| |#1| (-370)))) (-1748 (((-121) $) 49 (|has| |#1| (-370)))) (-1887 (($ $ (-763)) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370)))) (($ $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-2197 (((-121) $) NIL)) (-1844 (((-917) $) 47 (|has| |#1| (-370))) (((-828 (-917)) $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-1598 (((-121) $) NIL)) (-2769 (($) 130 (|has| |#1| (-370)))) (-2151 (((-121) $) NIL (|has| |#1| (-370)))) (-4417 ((|#1| $) NIL) (($ $ (-917)) NIL (|has| |#1| (-370)))) (-2214 (((-3 $ "failed") $) NIL (|has| |#1| (-370)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1497 (((-1157 |#1|) $) 88) (((-1157 $) $ (-917)) NIL (|has| |#1| (-370)))) (-2291 (((-917) $) 138 (|has| |#1| (-370)))) (-1447 (((-1157 |#1|) $) NIL (|has| |#1| (-370)))) (-2193 (((-1157 |#1|) $) NIL (|has| |#1| (-370))) (((-3 (-1157 |#1|) "failed") $ $) NIL (|has| |#1| (-370)))) (-3257 (($ $ (-1157 |#1|)) NIL (|has| |#1| (-370)))) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) 145)) (-4436 (($) NIL (|has| |#1| (-370)) CONST)) (-4357 (($ (-917)) 70 (|has| |#1| (-370)))) (-4051 (((-121) $) 116)) (-4025 (((-1108) $) NIL)) (-4212 (((-958 (-1108))) 44)) (-2707 (($) 126 (|has| |#1| (-370)))) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) 91 (|has| |#1| (-370)))) (-3850 (((-420 $) $) NIL)) (-4321 (((-828 (-917))) 67) (((-917)) 68)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-2721 (((-763) $) 129 (|has| |#1| (-370))) (((-3 (-763) "failed") $ $) 123 (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3108 (((-139)) NIL)) (-4191 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-1836 (((-828 (-917)) $) NIL) (((-917) $) NIL)) (-1492 (((-1157 |#1|)) 94)) (-2330 (($) 127 (|has| |#1| (-370)))) (-1398 (($) 135 (|has| |#1| (-370)))) (-1656 (((-1244 |#1|) $) 59) (((-679 |#1|) (-1244 $)) NIL)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| |#1| (-370)))) (-2747 (((-850) $) 141) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ |#1|) 74)) (-3385 (($ $) NIL (|has| |#1| (-370))) (((-3 $ "failed") $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3425 (((-763)) 137)) (-2588 (((-1244 $)) 115) (((-1244 $) (-917)) 72)) (-2273 (((-121) $ $) NIL)) (-1413 (((-121) $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) 32 T CONST)) (-1557 (($) 19 T CONST)) (-3412 (($ $) 80 (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-3192 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-1719 (((-121) $ $) 48)) (-1781 (($ $ $) 143) (($ $ |#1|) 144)) (-1775 (($ $) 125) (($ $ $) NIL)) (-1769 (($ $ $) 61)) (** (($ $ (-917)) 147) (($ $ (-763)) 148) (($ $ (-568)) 146)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 76) (($ $ $) 75) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) 142))) 
+(((-342 |#1| |#2|) (-13 (-327 |#1|) (-10 -7 (-15 -4212 ((-958 (-1108)))))) (-350) (-1157 |#1|)) (T -342)) 
+((-4212 (*1 *2) (-12 (-5 *2 (-958 (-1108))) (-5 *1 (-342 *3 *4)) (-4 *3 (-350)) (-14 *4 (-1157 *3))))) 
+(-13 (-327 |#1|) (-10 -7 (-15 -4212 ((-958 (-1108)))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2134 (((-121) $) NIL)) (-3800 (((-763)) NIL)) (-1934 ((|#1| $) NIL) (($ $ (-917)) NIL (|has| |#1| (-370)))) (-1856 (((-1169 (-917) (-763)) (-568)) NIL (|has| |#1| (-370)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2589 (((-121) $ $) NIL)) (-3986 (((-763)) NIL (|has| |#1| (-370)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) NIL)) (-2857 ((|#1| $) NIL)) (-3899 (($ (-1244 |#1|)) NIL)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| |#1| (-370)))) (-2403 (($ $ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1733 (($) NIL (|has| |#1| (-370)))) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-4188 (($) NIL (|has| |#1| (-370)))) (-1748 (((-121) $) NIL (|has| |#1| (-370)))) (-1887 (($ $ (-763)) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370)))) (($ $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-2197 (((-121) $) NIL)) (-1844 (((-917) $) NIL (|has| |#1| (-370))) (((-828 (-917)) $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-1598 (((-121) $) NIL)) (-2769 (($) NIL (|has| |#1| (-370)))) (-2151 (((-121) $) NIL (|has| |#1| (-370)))) (-4417 ((|#1| $) NIL) (($ $ (-917)) NIL (|has| |#1| (-370)))) (-2214 (((-3 $ "failed") $) NIL (|has| |#1| (-370)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1497 (((-1157 |#1|) $) NIL) (((-1157 $) $ (-917)) NIL (|has| |#1| (-370)))) (-2291 (((-917) $) NIL (|has| |#1| (-370)))) (-1447 (((-1157 |#1|) $) NIL (|has| |#1| (-370)))) (-2193 (((-1157 |#1|) $) NIL (|has| |#1| (-370))) (((-3 (-1157 |#1|) "failed") $ $) NIL (|has| |#1| (-370)))) (-3257 (($ $ (-1157 |#1|)) NIL (|has| |#1| (-370)))) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4436 (($) NIL (|has| |#1| (-370)) CONST)) (-4357 (($ (-917)) NIL (|has| |#1| (-370)))) (-4051 (((-121) $) NIL)) (-4025 (((-1108) $) NIL)) (-4212 (((-958 (-1108))) NIL)) (-2707 (($) NIL (|has| |#1| (-370)))) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) NIL (|has| |#1| (-370)))) (-3850 (((-420 $) $) NIL)) (-4321 (((-828 (-917))) NIL) (((-917)) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-2721 (((-763) $) NIL (|has| |#1| (-370))) (((-3 (-763) "failed") $ $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3108 (((-139)) NIL)) (-4191 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-1836 (((-828 (-917)) $) NIL) (((-917) $) NIL)) (-1492 (((-1157 |#1|)) NIL)) (-2330 (($) NIL (|has| |#1| (-370)))) (-1398 (($) NIL (|has| |#1| (-370)))) (-1656 (((-1244 |#1|) $) NIL) (((-679 |#1|) (-1244 $)) NIL)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| |#1| (-370)))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ |#1|) NIL)) (-3385 (($ $) NIL (|has| |#1| (-370))) (((-3 $ "failed") $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3425 (((-763)) NIL)) (-2588 (((-1244 $)) NIL) (((-1244 $) (-917)) NIL)) (-2273 (((-121) $ $) NIL)) (-1413 (((-121) $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3412 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-3192 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ $) NIL) (($ $ |#1|) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
+(((-343 |#1| |#2|) (-13 (-327 |#1|) (-10 -7 (-15 -4212 ((-958 (-1108)))))) (-350) (-917)) (T -343)) 
+((-4212 (*1 *2) (-12 (-5 *2 (-958 (-1108))) (-5 *1 (-343 *3 *4)) (-4 *3 (-350)) (-14 *4 (-917))))) 
+(-13 (-327 |#1|) (-10 -7 (-15 -4212 ((-958 (-1108)))))) 
+((-1634 (((-121) |#2|) 68)) (-2977 (((-420 |#2|) |#2|) 56)) (-2654 (((-420 |#2|) |#2|) 58)) (-4254 (((-634 |#2|) |#2|) 61)) (-1654 (((-634 |#2|) |#2| (-763)) 62)) (-3850 (((-420 |#2|) |#2|) 59))) 
+(((-344 |#1| |#2|) (-10 -7 (-15 -4254 ((-634 |#2|) |#2|)) (-15 -1654 ((-634 |#2|) |#2| (-763))) (-15 -3850 ((-420 |#2|) |#2|)) (-15 -2977 ((-420 |#2|) |#2|)) (-15 -2654 ((-420 |#2|) |#2|)) (-15 -1634 ((-121) |#2|))) (-350) (-1219 |#1|)) (T -344)) 
+((-1634 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-121)) (-5 *1 (-344 *4 *3)) (-4 *3 (-1219 *4)))) (-2654 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-344 *4 *3)) (-4 *3 (-1219 *4)))) (-2977 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-344 *4 *3)) (-4 *3 (-1219 *4)))) (-3850 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-344 *4 *3)) (-4 *3 (-1219 *4)))) (-1654 (*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-350)) (-5 *2 (-634 *3)) (-5 *1 (-344 *5 *3)) (-4 *3 (-1219 *5)))) (-4254 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-634 *3)) (-5 *1 (-344 *4 *3)) (-4 *3 (-1219 *4))))) 
+(-10 -7 (-15 -4254 ((-634 |#2|) |#2|)) (-15 -1654 ((-634 |#2|) |#2| (-763))) (-15 -3850 ((-420 |#2|) |#2|)) (-15 -2977 ((-420 |#2|) |#2|)) (-15 -2654 ((-420 |#2|) |#2|)) (-15 -1634 ((-121) |#2|))) 
+((-1546 (((-1141 (-679 (-1157 |#1|))) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#3|) (-763) (-763)) 54) (((-679 (-1157 |#1|)) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#3|) (-634 (-763))) 42))) 
+(((-345 |#1| |#2| |#3|) (-10 -7 (-15 -1546 ((-679 (-1157 |#1|)) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#3|) (-634 (-763)))) (-15 -1546 ((-1141 (-679 (-1157 |#1|))) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#3|) (-763) (-763)))) (-13 (-558) (-453)) (-324 |#1| (-763)) (-324 (-409 |#1|) (-763))) (T -345)) 
+((-1546 (*1 *2 *3 *4 *5 *6 *6) (-12 (-5 *3 (-634 *7)) (-5 *4 (-1 *7 (-763) (-763) *8)) (-5 *5 (-1244 *9)) (-5 *6 (-763)) (-4 *7 (-13 (-558) (-453))) (-4 *8 (-324 *7 *6)) (-4 *9 (-324 (-409 *7) *6)) (-5 *2 (-1141 (-679 (-1157 *7)))) (-5 *1 (-345 *7 *8 *9)))) (-1546 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-634 *7)) (-5 *4 (-1 *7 (-763) (-763) *8)) (-5 *5 (-1244 *9)) (-5 *6 (-634 (-763))) (-4 *7 (-13 (-558) (-453))) (-4 *8 (-324 *7 (-763))) (-4 *9 (-324 (-409 *7) (-763))) (-5 *2 (-679 (-1157 *7))) (-5 *1 (-345 *7 *8 *9))))) 
+(-10 -7 (-15 -1546 ((-679 (-1157 |#1|)) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#3|) (-634 (-763)))) (-15 -1546 ((-1141 (-679 (-1157 |#1|))) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#3|) (-763) (-763)))) 
+((-4066 (((-634 |#1|) |#1| (-763)) 21)) (-3099 ((|#1| |#1| (-763) (-763) |#2|) 20)) (-2709 (((-409 (-1157 |#1|)) (-634 (-409 |#1|)) (-634 (-409 |#1|)) (-763)) 75) (((-409 (-1157 |#1|)) (-634 |#1|) (-634 |#1|) (-763)) 68)) (-1546 (((-1141 (-679 (-1157 |#1|))) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#2|) (-763) (-763)) 62) (((-679 (-1157 |#1|)) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#2|) (-634 (-763))) 44)) (-3237 ((|#1| (-1 |#1| (-763) (-763) |#2|) (-1244 |#2|) (-763) (-1244 (-1157 |#1|))) 37)) (-2303 (((-679 (-1157 |#1|)) (-634 |#1|) (-1 |#1| (-763) (-1244 (-1157 |#1|))) (-634 (-763))) 43)) (-4376 (((-634 |#1|) (-763)) 17)) (-4368 ((|#1| (-763) (-763) |#2|) 11)) (-2495 (((-634 |#1|) (-763)) 24)) (-2760 ((|#1| (-763) (-763) |#2|) 22))) 
+(((-346 |#1| |#2|) (-10 -7 (-15 -2303 ((-679 (-1157 |#1|)) (-634 |#1|) (-1 |#1| (-763) (-1244 (-1157 |#1|))) (-634 (-763)))) (-15 -2709 ((-409 (-1157 |#1|)) (-634 |#1|) (-634 |#1|) (-763))) (-15 -2709 ((-409 (-1157 |#1|)) (-634 (-409 |#1|)) (-634 (-409 |#1|)) (-763))) (-15 -1546 ((-679 (-1157 |#1|)) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#2|) (-634 (-763)))) (-15 -1546 ((-1141 (-679 (-1157 |#1|))) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#2|) (-763) (-763))) (-15 -3237 (|#1| (-1 |#1| (-763) (-763) |#2|) (-1244 |#2|) (-763) (-1244 (-1157 |#1|)))) (-15 -4368 (|#1| (-763) (-763) |#2|)) (-15 -4376 ((-634 |#1|) (-763))) (-15 -2760 (|#1| (-763) (-763) |#2|)) (-15 -2495 ((-634 |#1|) (-763))) (-15 -3099 (|#1| |#1| (-763) (-763) |#2|)) (-15 -4066 ((-634 |#1|) |#1| (-763)))) (-13 (-558) (-453)) (-52 |#1| (-763))) (T -346)) 
+((-4066 (*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-4 *3 (-13 (-558) (-453))) (-5 *2 (-634 *3)) (-5 *1 (-346 *3 *5)) (-4 *5 (-52 *3 *4)))) (-3099 (*1 *2 *2 *3 *3 *4) (-12 (-5 *3 (-763)) (-4 *2 (-13 (-558) (-453))) (-5 *1 (-346 *2 *4)) (-4 *4 (-52 *2 *3)))) (-2495 (*1 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-13 (-558) (-453))) (-5 *2 (-634 *4)) (-5 *1 (-346 *4 *5)) (-4 *5 (-52 *4 *3)))) (-2760 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-763)) (-4 *2 (-13 (-558) (-453))) (-5 *1 (-346 *2 *4)) (-4 *4 (-52 *2 *3)))) (-4376 (*1 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-13 (-558) (-453))) (-5 *2 (-634 *4)) (-5 *1 (-346 *4 *5)) (-4 *5 (-52 *4 *3)))) (-4368 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-763)) (-4 *2 (-13 (-558) (-453))) (-5 *1 (-346 *2 *4)) (-4 *4 (-52 *2 *3)))) (-3237 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *2 (-763) (-763) *7)) (-5 *4 (-1244 *7)) (-5 *5 (-763)) (-5 *6 (-1244 (-1157 *2))) (-4 *7 (-52 *2 *5)) (-4 *2 (-13 (-558) (-453))) (-5 *1 (-346 *2 *7)))) (-1546 (*1 *2 *3 *4 *5 *6 *6) (-12 (-5 *3 (-634 *7)) (-5 *4 (-1 *7 (-763) (-763) *8)) (-5 *5 (-1244 *8)) (-5 *6 (-763)) (-4 *7 (-13 (-558) (-453))) (-4 *8 (-52 *7 *6)) (-5 *2 (-1141 (-679 (-1157 *7)))) (-5 *1 (-346 *7 *8)))) (-1546 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-634 *7)) (-5 *4 (-1 *7 (-763) (-763) *8)) (-5 *5 (-1244 *8)) (-5 *6 (-634 (-763))) (-4 *7 (-13 (-558) (-453))) (-4 *8 (-52 *7 (-763))) (-5 *2 (-679 (-1157 *7))) (-5 *1 (-346 *7 *8)))) (-2709 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-634 (-409 *5))) (-4 *5 (-13 (-558) (-453))) (-5 *4 (-763)) (-5 *2 (-409 (-1157 *5))) (-5 *1 (-346 *5 *6)) (-4 *6 (-52 *5 *4)))) (-2709 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-634 *5)) (-4 *5 (-13 (-558) (-453))) (-5 *4 (-763)) (-5 *2 (-409 (-1157 *5))) (-5 *1 (-346 *5 *6)) (-4 *6 (-52 *5 *4)))) (-2303 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 *6)) (-5 *4 (-1 *6 (-763) (-1244 (-1157 *6)))) (-5 *5 (-634 (-763))) (-4 *6 (-13 (-558) (-453))) (-5 *2 (-679 (-1157 *6))) (-5 *1 (-346 *6 *7)) (-4 *7 (-52 *6 (-763)))))) 
+(-10 -7 (-15 -2303 ((-679 (-1157 |#1|)) (-634 |#1|) (-1 |#1| (-763) (-1244 (-1157 |#1|))) (-634 (-763)))) (-15 -2709 ((-409 (-1157 |#1|)) (-634 |#1|) (-634 |#1|) (-763))) (-15 -2709 ((-409 (-1157 |#1|)) (-634 (-409 |#1|)) (-634 (-409 |#1|)) (-763))) (-15 -1546 ((-679 (-1157 |#1|)) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#2|) (-634 (-763)))) (-15 -1546 ((-1141 (-679 (-1157 |#1|))) (-634 |#1|) (-1 |#1| (-763) (-763) |#2|) (-1244 |#2|) (-763) (-763))) (-15 -3237 (|#1| (-1 |#1| (-763) (-763) |#2|) (-1244 |#2|) (-763) (-1244 (-1157 |#1|)))) (-15 -4368 (|#1| (-763) (-763) |#2|)) (-15 -4376 ((-634 |#1|) (-763))) (-15 -2760 (|#1| (-763) (-763) |#2|)) (-15 -2495 ((-634 |#1|) (-763))) (-15 -3099 (|#1| |#1| (-763) (-763) |#2|)) (-15 -4066 ((-634 |#1|) |#1| (-763)))) 
+((-1628 (((-763) (-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108)))))) 40)) (-2362 (((-958 (-1108)) (-1157 |#1|)) 84)) (-1570 (((-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108))))) (-1157 |#1|)) 77)) (-2299 (((-679 |#1|) (-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108)))))) 85)) (-3021 (((-3 (-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108))))) "failed") (-917)) 10)) (-4494 (((-3 (-1157 |#1|) (-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108)))))) (-917)) 15))) 
+(((-347 |#1|) (-10 -7 (-15 -2362 ((-958 (-1108)) (-1157 |#1|))) (-15 -1570 ((-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108))))) (-1157 |#1|))) (-15 -2299 ((-679 |#1|) (-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108))))))) (-15 -1628 ((-763) (-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108))))))) (-15 -3021 ((-3 (-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108))))) "failed") (-917))) (-15 -4494 ((-3 (-1157 |#1|) (-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108)))))) (-917)))) (-350)) (T -347)) 
+((-4494 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-3 (-1157 *4) (-1244 (-634 (-2 (|:| -2852 *4) (|:| -4357 (-1108))))))) (-5 *1 (-347 *4)) (-4 *4 (-350)))) (-3021 (*1 *2 *3) (|partial| -12 (-5 *3 (-917)) (-5 *2 (-1244 (-634 (-2 (|:| -2852 *4) (|:| -4357 (-1108)))))) (-5 *1 (-347 *4)) (-4 *4 (-350)))) (-1628 (*1 *2 *3) (-12 (-5 *3 (-1244 (-634 (-2 (|:| -2852 *4) (|:| -4357 (-1108)))))) (-4 *4 (-350)) (-5 *2 (-763)) (-5 *1 (-347 *4)))) (-2299 (*1 *2 *3) (-12 (-5 *3 (-1244 (-634 (-2 (|:| -2852 *4) (|:| -4357 (-1108)))))) (-4 *4 (-350)) (-5 *2 (-679 *4)) (-5 *1 (-347 *4)))) (-1570 (*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-350)) (-5 *2 (-1244 (-634 (-2 (|:| -2852 *4) (|:| -4357 (-1108)))))) (-5 *1 (-347 *4)))) (-2362 (*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-350)) (-5 *2 (-958 (-1108))) (-5 *1 (-347 *4))))) 
+(-10 -7 (-15 -2362 ((-958 (-1108)) (-1157 |#1|))) (-15 -1570 ((-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108))))) (-1157 |#1|))) (-15 -2299 ((-679 |#1|) (-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108))))))) (-15 -1628 ((-763) (-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108))))))) (-15 -3021 ((-3 (-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108))))) "failed") (-917))) (-15 -4494 ((-3 (-1157 |#1|) (-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108)))))) (-917)))) 
+((-2747 ((|#1| |#3|) 84) ((|#3| |#1|) 68))) 
+(((-348 |#1| |#2| |#3|) (-10 -7 (-15 -2747 (|#3| |#1|)) (-15 -2747 (|#1| |#3|))) (-327 |#2|) (-350) (-327 |#2|)) (T -348)) 
+((-2747 (*1 *2 *3) (-12 (-4 *4 (-350)) (-4 *2 (-327 *4)) (-5 *1 (-348 *2 *4 *3)) (-4 *3 (-327 *4)))) (-2747 (*1 *2 *3) (-12 (-4 *4 (-350)) (-4 *2 (-327 *4)) (-5 *1 (-348 *3 *4 *2)) (-4 *3 (-327 *4))))) 
+(-10 -7 (-15 -2747 (|#3| |#1|)) (-15 -2747 (|#1| |#3|))) 
+((-1748 (((-121) $) 50)) (-1844 (((-828 (-917)) $) 21) (((-917) $) 51)) (-2214 (((-3 $ "failed") $) 16)) (-4436 (($) 9)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 91)) (-2721 (((-3 (-763) "failed") $ $) 70) (((-763) $) 59)) (-4191 (($ $ (-763)) NIL) (($ $) 8)) (-2330 (($) 44)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) 33)) (-3385 (((-3 $ "failed") $) 39) (($ $) 38))) 
+(((-349 |#1|) (-10 -8 (-15 -1844 ((-917) |#1|)) (-15 -2721 ((-763) |#1|)) (-15 -1748 ((-121) |#1|)) (-15 -2330 (|#1|)) (-15 -3070 ((-3 (-1244 |#1|) "failed") (-679 |#1|))) (-15 -3385 (|#1| |#1|)) (-15 -4191 (|#1| |#1|)) (-15 -4191 (|#1| |#1| (-763))) (-15 -4436 (|#1|)) (-15 -2214 ((-3 |#1| "failed") |#1|)) (-15 -2721 ((-3 (-763) "failed") |#1| |#1|)) (-15 -1844 ((-828 (-917)) |#1|)) (-15 -3385 ((-3 |#1| "failed") |#1|)) (-15 -3603 ((-1157 |#1|) (-1157 |#1|) (-1157 |#1|)))) (-350)) (T -349)) 
+NIL 
+(-10 -8 (-15 -1844 ((-917) |#1|)) (-15 -2721 ((-763) |#1|)) (-15 -1748 ((-121) |#1|)) (-15 -2330 (|#1|)) (-15 -3070 ((-3 (-1244 |#1|) "failed") (-679 |#1|))) (-15 -3385 (|#1| |#1|)) (-15 -4191 (|#1| |#1|)) (-15 -4191 (|#1| |#1| (-763))) (-15 -4436 (|#1|)) (-15 -2214 ((-3 |#1| "failed") |#1|)) (-15 -2721 ((-3 (-763) "failed") |#1| |#1|)) (-15 -1844 ((-828 (-917)) |#1|)) (-15 -3385 ((-3 |#1| "failed") |#1|)) (-15 -3603 ((-1157 |#1|) (-1157 |#1|) (-1157 |#1|)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-1856 (((-1169 (-917) (-763)) (-568)) 88)) (-2689 (((-3 $ "failed") $ $) 18)) (-3045 (($ $) 71)) (-3498 (((-420 $) $) 70)) (-2589 (((-121) $ $) 57)) (-3986 (((-763)) 98)) (-4490 (($) 16 T CONST)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) 82)) (-2403 (($ $ $) 53)) (-2902 (((-3 $ "failed") $) 33)) (-1733 (($) 101)) (-2414 (($ $ $) 54)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 49)) (-4188 (($) 86)) (-1748 (((-121) $) 85)) (-1887 (($ $) 75) (($ $ (-763)) 74)) (-2197 (((-121) $) 69)) (-1844 (((-828 (-917)) $) 77) (((-917) $) 83)) (-1598 (((-121) $) 30)) (-2214 (((-3 $ "failed") $) 97)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-2291 (((-917) $) 100)) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-2083 (($ $) 68)) (-4436 (($) 96 T CONST)) (-4357 (($ (-917)) 99)) (-4025 (((-1108) $) 10)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) 89)) (-3850 (((-420 $) $) 72)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2597 (((-3 $ "failed") $ $) 41)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-1466 (((-763) $) 56)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 55)) (-2721 (((-3 (-763) "failed") $ $) 76) (((-763) $) 84)) (-4191 (($ $ (-763)) 94) (($ $) 92)) (-2330 (($) 87)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) 90)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63)) (-3385 (((-3 $ "failed") $) 78) (($ $) 91)) (-3425 (((-763)) 28)) (-2273 (((-121) $ $) 38)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $ (-763)) 95) (($ $) 93)) (-1719 (((-121) $ $) 6)) (-1781 (($ $ $) 62)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64))) 
 (((-350) (-1275)) (T -350)) 
-((-4371 (*1 *1 *1) (-4 *1 (-350))) (-2979 (*1 *2 *3) (|partial| -12 (-5 *3 (-679 *1)) (-4 *1 (-350)) (-5 *2 (-1244 *1)))) (-1418 (*1 *2) (-12 (-4 *1 (-350)) (-5 *2 (-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))))) (-3211 (*1 *2 *3) (-12 (-4 *1 (-350)) (-5 *3 (-568)) (-5 *2 (-1169 (-917) (-763))))) (-3065 (*1 *1) (-4 *1 (-350))) (-4220 (*1 *1) (-4 *1 (-350))) (-4456 (*1 *2 *1) (-12 (-4 *1 (-350)) (-5 *2 (-121)))) (-3143 (*1 *2 *1) (-12 (-4 *1 (-350)) (-5 *2 (-763)))) (-4477 (*1 *2 *1) (-12 (-4 *1 (-350)) (-5 *2 (-917)))) (-2022 (*1 *2) (-12 (-4 *1 (-350)) (-5 *2 (-3 "prime" "polynomial" "normal" "cyclic"))))) 
-(-13 (-404) (-370) (-1136) (-225) (-10 -8 (-15 -4371 ($ $)) (-15 -2979 ((-3 (-1244 $) "failed") (-679 $))) (-15 -1418 ((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568)))))) (-15 -3211 ((-1169 (-917) (-763)) (-568))) (-15 -3065 ($)) (-15 -4220 ($)) (-15 -4456 ((-121) $)) (-15 -3143 ((-763) $)) (-15 -4477 ((-917) $)) (-15 -2022 ((-3 "prime" "polynomial" "normal" "cyclic"))))) 
+((-3385 (*1 *1 *1) (-4 *1 (-350))) (-3070 (*1 *2 *3) (|partial| -12 (-5 *3 (-679 *1)) (-4 *1 (-350)) (-5 *2 (-1244 *1)))) (-2172 (*1 *2) (-12 (-4 *1 (-350)) (-5 *2 (-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))))) (-1856 (*1 *2 *3) (-12 (-4 *1 (-350)) (-5 *3 (-568)) (-5 *2 (-1169 (-917) (-763))))) (-2330 (*1 *1) (-4 *1 (-350))) (-4188 (*1 *1) (-4 *1 (-350))) (-1748 (*1 *2 *1) (-12 (-4 *1 (-350)) (-5 *2 (-121)))) (-2721 (*1 *2 *1) (-12 (-4 *1 (-350)) (-5 *2 (-763)))) (-1844 (*1 *2 *1) (-12 (-4 *1 (-350)) (-5 *2 (-917)))) (-1368 (*1 *2) (-12 (-4 *1 (-350)) (-5 *2 (-3 "prime" "polynomial" "normal" "cyclic"))))) 
+(-13 (-404) (-370) (-1136) (-225) (-10 -8 (-15 -3385 ($ $)) (-15 -3070 ((-3 (-1244 $) "failed") (-679 $))) (-15 -2172 ((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568)))))) (-15 -1856 ((-1169 (-917) (-763)) (-568))) (-15 -2330 ($)) (-15 -4188 ($)) (-15 -1748 ((-121) $)) (-15 -2721 ((-763) $)) (-15 -1844 ((-917) $)) (-15 -1368 ((-3 "prime" "polynomial" "normal" "cyclic"))))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 $ $) . T) ((-137) . T) ((-148) . T) ((-608 (-850)) . T) ((-172) . T) ((-225) . T) ((-238) . T) ((-285) . T) ((-301) . T) ((-365) . T) ((-404) . T) ((-370) . T) ((-453) . T) ((-558) . T) ((-637 (-409 (-568))) . T) ((-637 $) . T) ((-707 (-409 (-568))) . T) ((-707 $) . T) ((-716) . T) ((-916) . T) ((-1053 (-409 (-568))) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1136) . T) ((-1199) . T)) 
-((-3714 (((-2 (|:| -3746 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|))) |#1|) 51)) (-3661 (((-2 (|:| -3746 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|)))) 49))) 
-(((-351 |#1| |#2| |#3|) (-10 -7 (-15 -3661 ((-2 (|:| -3746 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|))))) (-15 -3714 ((-2 (|:| -3746 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|))) |#1|))) (-13 (-301) (-10 -8 (-15 -1678 ((-420 $) $)))) (-1219 |#1|) (-411 |#1| |#2|)) (T -351)) 
-((-3714 (*1 *2 *3) (-12 (-4 *3 (-13 (-301) (-10 -8 (-15 -1678 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *2 (-2 (|:| -3746 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-5 *1 (-351 *3 *4 *5)) (-4 *5 (-411 *3 *4)))) (-3661 (*1 *2) (-12 (-4 *3 (-13 (-301) (-10 -8 (-15 -1678 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *2 (-2 (|:| -3746 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-5 *1 (-351 *3 *4 *5)) (-4 *5 (-411 *3 *4))))) 
-(-10 -7 (-15 -3661 ((-2 (|:| -3746 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|))))) (-15 -3714 ((-2 (|:| -3746 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|))) |#1|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-2615 (((-121) $) NIL)) (-1739 (((-763)) NIL)) (-1932 (((-905 |#1|) $) NIL) (($ $ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-3211 (((-1169 (-917) (-763)) (-568)) NIL (|has| (-905 |#1|) (-370)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-4433 (((-763)) NIL)) (-1497 (((-121) $ $) NIL)) (-3983 (((-763)) NIL (|has| (-905 |#1|) (-370)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-905 |#1|) "failed") $) NIL)) (-2854 (((-905 |#1|) $) NIL)) (-3498 (($ (-1244 (-905 |#1|))) NIL)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-905 |#1|) (-370)))) (-2401 (($ $ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1731 (($) NIL (|has| (-905 |#1|) (-370)))) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-4220 (($) NIL (|has| (-905 |#1|) (-370)))) (-4456 (((-121) $) NIL (|has| (-905 |#1|) (-370)))) (-3218 (($ $ (-763)) NIL (-2198 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370)))) (($ $) NIL (-2198 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-3927 (((-121) $) NIL)) (-4477 (((-917) $) NIL (|has| (-905 |#1|) (-370))) (((-828 (-917)) $) NIL (-2198 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-2735 (((-121) $) NIL)) (-2883 (($) NIL (|has| (-905 |#1|) (-370)))) (-3917 (((-121) $) NIL (|has| (-905 |#1|) (-370)))) (-2657 (((-905 |#1|) $) NIL) (($ $ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-3038 (((-3 $ "failed") $) NIL (|has| (-905 |#1|) (-370)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2045 (((-1157 (-905 |#1|)) $) NIL) (((-1157 $) $ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-3683 (((-917) $) NIL (|has| (-905 |#1|) (-370)))) (-2035 (((-1157 (-905 |#1|)) $) NIL (|has| (-905 |#1|) (-370)))) (-1422 (((-1157 (-905 |#1|)) $) NIL (|has| (-905 |#1|) (-370))) (((-3 (-1157 (-905 |#1|)) "failed") $ $) NIL (|has| (-905 |#1|) (-370)))) (-2109 (($ $ (-1157 (-905 |#1|))) NIL (|has| (-905 |#1|) (-370)))) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4434 (($) NIL (|has| (-905 |#1|) (-370)) CONST)) (-4355 (($ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-2864 (((-121) $) NIL)) (-4022 (((-1108) $) NIL)) (-2758 (((-1244 (-634 (-2 (|:| -2850 (-905 |#1|)) (|:| -4355 (-1108)))))) NIL)) (-4181 (((-679 (-905 |#1|))) NIL)) (-2704 (($) NIL (|has| (-905 |#1|) (-370)))) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) NIL (|has| (-905 |#1|) (-370)))) (-3848 (((-420 $) $) NIL)) (-1553 (((-828 (-917))) NIL) (((-917)) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3143 (((-763) $) NIL (|has| (-905 |#1|) (-370))) (((-3 (-763) "failed") $ $) NIL (-2198 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-4321 (((-139)) NIL)) (-4189 (($ $) NIL (|has| (-905 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-905 |#1|) (-370)))) (-3206 (((-828 (-917)) $) NIL) (((-917) $) NIL)) (-1626 (((-1157 (-905 |#1|))) NIL)) (-3065 (($) NIL (|has| (-905 |#1|) (-370)))) (-2027 (($) NIL (|has| (-905 |#1|) (-370)))) (-4073 (((-1244 (-905 |#1|)) $) NIL) (((-679 (-905 |#1|)) (-1244 $)) NIL)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| (-905 |#1|) (-370)))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ (-905 |#1|)) NIL)) (-4371 (($ $) NIL (|has| (-905 |#1|) (-370))) (((-3 $ "failed") $) NIL (-2198 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-4078 (((-763)) NIL)) (-3746 (((-1244 $)) NIL) (((-1244 $) (-917)) NIL)) (-1826 (((-121) $ $) NIL)) (-4390 (((-121) $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-1316 (($ $) NIL (|has| (-905 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-905 |#1|) (-370)))) (-3190 (($ $) NIL (|has| (-905 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-905 |#1|) (-370)))) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ $) NIL) (($ $ (-905 |#1|)) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ $ (-905 |#1|)) NIL) (($ (-905 |#1|) $) NIL))) 
-(((-352 |#1| |#2|) (-13 (-327 (-905 |#1|)) (-10 -7 (-15 -2758 ((-1244 (-634 (-2 (|:| -2850 (-905 |#1|)) (|:| -4355 (-1108))))))) (-15 -4181 ((-679 (-905 |#1|)))) (-15 -4433 ((-763))))) (-917) (-917)) (T -352)) 
-((-2758 (*1 *2) (-12 (-5 *2 (-1244 (-634 (-2 (|:| -2850 (-905 *3)) (|:| -4355 (-1108)))))) (-5 *1 (-352 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917)))) (-4181 (*1 *2) (-12 (-5 *2 (-679 (-905 *3))) (-5 *1 (-352 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917)))) (-4433 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-352 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917))))) 
-(-13 (-327 (-905 |#1|)) (-10 -7 (-15 -2758 ((-1244 (-634 (-2 (|:| -2850 (-905 |#1|)) (|:| -4355 (-1108))))))) (-15 -4181 ((-679 (-905 |#1|)))) (-15 -4433 ((-763))))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 74)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-2615 (((-121) $) NIL)) (-1739 (((-763)) NIL)) (-1932 ((|#1| $) 92) (($ $ (-917)) 90 (|has| |#1| (-370)))) (-3211 (((-1169 (-917) (-763)) (-568)) 148 (|has| |#1| (-370)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-4433 (((-763)) 89)) (-1497 (((-121) $ $) NIL)) (-3983 (((-763)) 162 (|has| |#1| (-370)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) 111)) (-2854 ((|#1| $) 91)) (-3498 (($ (-1244 |#1|)) 57)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) 187 (|has| |#1| (-370)))) (-2401 (($ $ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1731 (($) 158 (|has| |#1| (-370)))) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-4220 (($) 149 (|has| |#1| (-370)))) (-4456 (((-121) $) NIL (|has| |#1| (-370)))) (-3218 (($ $ (-763)) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370)))) (($ $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3927 (((-121) $) NIL)) (-4477 (((-917) $) NIL (|has| |#1| (-370))) (((-828 (-917)) $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-2735 (((-121) $) NIL)) (-2883 (($) 97 (|has| |#1| (-370)))) (-3917 (((-121) $) 175 (|has| |#1| (-370)))) (-2657 ((|#1| $) 94) (($ $ (-917)) 93 (|has| |#1| (-370)))) (-3038 (((-3 $ "failed") $) NIL (|has| |#1| (-370)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2045 (((-1157 |#1|) $) 188) (((-1157 $) $ (-917)) NIL (|has| |#1| (-370)))) (-3683 (((-917) $) 133 (|has| |#1| (-370)))) (-2035 (((-1157 |#1|) $) 73 (|has| |#1| (-370)))) (-1422 (((-1157 |#1|) $) 70 (|has| |#1| (-370))) (((-3 (-1157 |#1|) "failed") $ $) 82 (|has| |#1| (-370)))) (-2109 (($ $ (-1157 |#1|)) 69 (|has| |#1| (-370)))) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) 191)) (-4434 (($) NIL (|has| |#1| (-370)) CONST)) (-4355 (($ (-917)) 136 (|has| |#1| (-370)))) (-2864 (((-121) $) 107)) (-4022 (((-1108) $) NIL)) (-2758 (((-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108)))))) 83)) (-4181 (((-679 |#1|)) 87)) (-2704 (($) 96 (|has| |#1| (-370)))) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) 150 (|has| |#1| (-370)))) (-3848 (((-420 $) $) NIL)) (-1553 (((-828 (-917))) NIL) (((-917)) 151)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3143 (((-763) $) NIL (|has| |#1| (-370))) (((-3 (-763) "failed") $ $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-4321 (((-139)) NIL)) (-4189 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-3206 (((-828 (-917)) $) NIL) (((-917) $) 62)) (-1626 (((-1157 |#1|)) 152)) (-3065 (($) 132 (|has| |#1| (-370)))) (-2027 (($) NIL (|has| |#1| (-370)))) (-4073 (((-1244 |#1|) $) 105) (((-679 |#1|) (-1244 $)) NIL)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| |#1| (-370)))) (-2745 (((-850) $) 123) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ |#1|) 56)) (-4371 (($ $) NIL (|has| |#1| (-370))) (((-3 $ "failed") $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-4078 (((-763)) 156)) (-3746 (((-1244 $)) 172) (((-1244 $) (-917)) 100)) (-1826 (((-121) $ $) NIL)) (-4390 (((-121) $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) 30 T CONST)) (-1556 (($) 22 T CONST)) (-1316 (($ $) 106 (|has| |#1| (-370))) (($ $ (-763)) 98 (|has| |#1| (-370)))) (-3190 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-1717 (((-121) $ $) 60)) (-1779 (($ $ $) 103) (($ $ |#1|) 104)) (-1773 (($ $) 177) (($ $ $) 181)) (-1767 (($ $ $) 179)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) 137)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 185) (($ $ $) 142) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) 102))) 
-(((-353 |#1| |#2|) (-13 (-327 |#1|) (-10 -7 (-15 -2758 ((-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108))))))) (-15 -4181 ((-679 |#1|))) (-15 -4433 ((-763))))) (-350) (-3 (-1157 |#1|) (-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108))))))) (T -353)) 
-((-2758 (*1 *2) (-12 (-5 *2 (-1244 (-634 (-2 (|:| -2850 *3) (|:| -4355 (-1108)))))) (-5 *1 (-353 *3 *4)) (-4 *3 (-350)) (-14 *4 (-3 (-1157 *3) *2)))) (-4181 (*1 *2) (-12 (-5 *2 (-679 *3)) (-5 *1 (-353 *3 *4)) (-4 *3 (-350)) (-14 *4 (-3 (-1157 *3) (-1244 (-634 (-2 (|:| -2850 *3) (|:| -4355 (-1108))))))))) (-4433 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-353 *3 *4)) (-4 *3 (-350)) (-14 *4 (-3 (-1157 *3) (-1244 (-634 (-2 (|:| -2850 *3) (|:| -4355 (-1108)))))))))) 
-(-13 (-327 |#1|) (-10 -7 (-15 -2758 ((-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108))))))) (-15 -4181 ((-679 |#1|))) (-15 -4433 ((-763))))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-2615 (((-121) $) NIL)) (-1739 (((-763)) NIL)) (-1932 ((|#1| $) NIL) (($ $ (-917)) NIL (|has| |#1| (-370)))) (-3211 (((-1169 (-917) (-763)) (-568)) NIL (|has| |#1| (-370)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-4433 (((-763)) NIL)) (-1497 (((-121) $ $) NIL)) (-3983 (((-763)) NIL (|has| |#1| (-370)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) NIL)) (-2854 ((|#1| $) NIL)) (-3498 (($ (-1244 |#1|)) NIL)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| |#1| (-370)))) (-2401 (($ $ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1731 (($) NIL (|has| |#1| (-370)))) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-4220 (($) NIL (|has| |#1| (-370)))) (-4456 (((-121) $) NIL (|has| |#1| (-370)))) (-3218 (($ $ (-763)) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370)))) (($ $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3927 (((-121) $) NIL)) (-4477 (((-917) $) NIL (|has| |#1| (-370))) (((-828 (-917)) $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-2735 (((-121) $) NIL)) (-2883 (($) NIL (|has| |#1| (-370)))) (-3917 (((-121) $) NIL (|has| |#1| (-370)))) (-2657 ((|#1| $) NIL) (($ $ (-917)) NIL (|has| |#1| (-370)))) (-3038 (((-3 $ "failed") $) NIL (|has| |#1| (-370)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2045 (((-1157 |#1|) $) NIL) (((-1157 $) $ (-917)) NIL (|has| |#1| (-370)))) (-3683 (((-917) $) NIL (|has| |#1| (-370)))) (-2035 (((-1157 |#1|) $) NIL (|has| |#1| (-370)))) (-1422 (((-1157 |#1|) $) NIL (|has| |#1| (-370))) (((-3 (-1157 |#1|) "failed") $ $) NIL (|has| |#1| (-370)))) (-2109 (($ $ (-1157 |#1|)) NIL (|has| |#1| (-370)))) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4434 (($) NIL (|has| |#1| (-370)) CONST)) (-4355 (($ (-917)) NIL (|has| |#1| (-370)))) (-2864 (((-121) $) NIL)) (-4022 (((-1108) $) NIL)) (-2758 (((-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108)))))) NIL)) (-4181 (((-679 |#1|)) NIL)) (-2704 (($) NIL (|has| |#1| (-370)))) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) NIL (|has| |#1| (-370)))) (-3848 (((-420 $) $) NIL)) (-1553 (((-828 (-917))) NIL) (((-917)) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3143 (((-763) $) NIL (|has| |#1| (-370))) (((-3 (-763) "failed") $ $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-4321 (((-139)) NIL)) (-4189 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-3206 (((-828 (-917)) $) NIL) (((-917) $) NIL)) (-1626 (((-1157 |#1|)) NIL)) (-3065 (($) NIL (|has| |#1| (-370)))) (-2027 (($) NIL (|has| |#1| (-370)))) (-4073 (((-1244 |#1|) $) NIL) (((-679 |#1|) (-1244 $)) NIL)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| |#1| (-370)))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ |#1|) NIL)) (-4371 (($ $) NIL (|has| |#1| (-370))) (((-3 $ "failed") $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-4078 (((-763)) NIL)) (-3746 (((-1244 $)) NIL) (((-1244 $) (-917)) NIL)) (-1826 (((-121) $ $) NIL)) (-4390 (((-121) $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-1316 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-3190 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ $) NIL) (($ $ |#1|) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
-(((-354 |#1| |#2|) (-13 (-327 |#1|) (-10 -7 (-15 -2758 ((-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108))))))) (-15 -4181 ((-679 |#1|))) (-15 -4433 ((-763))))) (-350) (-917)) (T -354)) 
-((-2758 (*1 *2) (-12 (-5 *2 (-1244 (-634 (-2 (|:| -2850 *3) (|:| -4355 (-1108)))))) (-5 *1 (-354 *3 *4)) (-4 *3 (-350)) (-14 *4 (-917)))) (-4181 (*1 *2) (-12 (-5 *2 (-679 *3)) (-5 *1 (-354 *3 *4)) (-4 *3 (-350)) (-14 *4 (-917)))) (-4433 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-354 *3 *4)) (-4 *3 (-350)) (-14 *4 (-917))))) 
-(-13 (-327 |#1|) (-10 -7 (-15 -2758 ((-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108))))))) (-15 -4181 ((-679 |#1|))) (-15 -4433 ((-763))))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-2615 (((-121) $) NIL)) (-1739 (((-763)) NIL)) (-1932 (((-905 |#1|) $) NIL) (($ $ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-3211 (((-1169 (-917) (-763)) (-568)) NIL (|has| (-905 |#1|) (-370)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1497 (((-121) $ $) NIL)) (-3983 (((-763)) NIL (|has| (-905 |#1|) (-370)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-905 |#1|) "failed") $) NIL)) (-2854 (((-905 |#1|) $) NIL)) (-3498 (($ (-1244 (-905 |#1|))) NIL)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-905 |#1|) (-370)))) (-2401 (($ $ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1731 (($) NIL (|has| (-905 |#1|) (-370)))) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-4220 (($) NIL (|has| (-905 |#1|) (-370)))) (-4456 (((-121) $) NIL (|has| (-905 |#1|) (-370)))) (-3218 (($ $ (-763)) NIL (-2198 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370)))) (($ $) NIL (-2198 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-3927 (((-121) $) NIL)) (-4477 (((-917) $) NIL (|has| (-905 |#1|) (-370))) (((-828 (-917)) $) NIL (-2198 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-2735 (((-121) $) NIL)) (-2883 (($) NIL (|has| (-905 |#1|) (-370)))) (-3917 (((-121) $) NIL (|has| (-905 |#1|) (-370)))) (-2657 (((-905 |#1|) $) NIL) (($ $ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-3038 (((-3 $ "failed") $) NIL (|has| (-905 |#1|) (-370)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2045 (((-1157 (-905 |#1|)) $) NIL) (((-1157 $) $ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-3683 (((-917) $) NIL (|has| (-905 |#1|) (-370)))) (-2035 (((-1157 (-905 |#1|)) $) NIL (|has| (-905 |#1|) (-370)))) (-1422 (((-1157 (-905 |#1|)) $) NIL (|has| (-905 |#1|) (-370))) (((-3 (-1157 (-905 |#1|)) "failed") $ $) NIL (|has| (-905 |#1|) (-370)))) (-2109 (($ $ (-1157 (-905 |#1|))) NIL (|has| (-905 |#1|) (-370)))) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4434 (($) NIL (|has| (-905 |#1|) (-370)) CONST)) (-4355 (($ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-2864 (((-121) $) NIL)) (-4022 (((-1108) $) NIL)) (-2704 (($) NIL (|has| (-905 |#1|) (-370)))) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) NIL (|has| (-905 |#1|) (-370)))) (-3848 (((-420 $) $) NIL)) (-1553 (((-828 (-917))) NIL) (((-917)) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3143 (((-763) $) NIL (|has| (-905 |#1|) (-370))) (((-3 (-763) "failed") $ $) NIL (-2198 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-4321 (((-139)) NIL)) (-4189 (($ $) NIL (|has| (-905 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-905 |#1|) (-370)))) (-3206 (((-828 (-917)) $) NIL) (((-917) $) NIL)) (-1626 (((-1157 (-905 |#1|))) NIL)) (-3065 (($) NIL (|has| (-905 |#1|) (-370)))) (-2027 (($) NIL (|has| (-905 |#1|) (-370)))) (-4073 (((-1244 (-905 |#1|)) $) NIL) (((-679 (-905 |#1|)) (-1244 $)) NIL)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| (-905 |#1|) (-370)))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ (-905 |#1|)) NIL)) (-4371 (($ $) NIL (|has| (-905 |#1|) (-370))) (((-3 $ "failed") $) NIL (-2198 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-4078 (((-763)) NIL)) (-3746 (((-1244 $)) NIL) (((-1244 $) (-917)) NIL)) (-1826 (((-121) $ $) NIL)) (-4390 (((-121) $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-1316 (($ $) NIL (|has| (-905 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-905 |#1|) (-370)))) (-3190 (($ $) NIL (|has| (-905 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-905 |#1|) (-370)))) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ $) NIL) (($ $ (-905 |#1|)) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ $ (-905 |#1|)) NIL) (($ (-905 |#1|) $) NIL))) 
+((-2443 (((-2 (|:| -2588 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|))) |#1|) 51)) (-3330 (((-2 (|:| -2588 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|)))) 49))) 
+(((-351 |#1| |#2| |#3|) (-10 -7 (-15 -3330 ((-2 (|:| -2588 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|))))) (-15 -2443 ((-2 (|:| -2588 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|))) |#1|))) (-13 (-301) (-10 -8 (-15 -3498 ((-420 $) $)))) (-1219 |#1|) (-411 |#1| |#2|)) (T -351)) 
+((-2443 (*1 *2 *3) (-12 (-4 *3 (-13 (-301) (-10 -8 (-15 -3498 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *2 (-2 (|:| -2588 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-5 *1 (-351 *3 *4 *5)) (-4 *5 (-411 *3 *4)))) (-3330 (*1 *2) (-12 (-4 *3 (-13 (-301) (-10 -8 (-15 -3498 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *2 (-2 (|:| -2588 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-5 *1 (-351 *3 *4 *5)) (-4 *5 (-411 *3 *4))))) 
+(-10 -7 (-15 -3330 ((-2 (|:| -2588 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|))))) (-15 -2443 ((-2 (|:| -2588 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|))) |#1|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2134 (((-121) $) NIL)) (-3800 (((-763)) NIL)) (-1934 (((-905 |#1|) $) NIL) (($ $ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-1856 (((-1169 (-917) (-763)) (-568)) NIL (|has| (-905 |#1|) (-370)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-1628 (((-763)) NIL)) (-2589 (((-121) $ $) NIL)) (-3986 (((-763)) NIL (|has| (-905 |#1|) (-370)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-905 |#1|) "failed") $) NIL)) (-2857 (((-905 |#1|) $) NIL)) (-3899 (($ (-1244 (-905 |#1|))) NIL)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-905 |#1|) (-370)))) (-2403 (($ $ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1733 (($) NIL (|has| (-905 |#1|) (-370)))) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-4188 (($) NIL (|has| (-905 |#1|) (-370)))) (-1748 (((-121) $) NIL (|has| (-905 |#1|) (-370)))) (-1887 (($ $ (-763)) NIL (-2199 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370)))) (($ $) NIL (-2199 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-2197 (((-121) $) NIL)) (-1844 (((-917) $) NIL (|has| (-905 |#1|) (-370))) (((-828 (-917)) $) NIL (-2199 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-1598 (((-121) $) NIL)) (-2769 (($) NIL (|has| (-905 |#1|) (-370)))) (-2151 (((-121) $) NIL (|has| (-905 |#1|) (-370)))) (-4417 (((-905 |#1|) $) NIL) (($ $ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-2214 (((-3 $ "failed") $) NIL (|has| (-905 |#1|) (-370)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1497 (((-1157 (-905 |#1|)) $) NIL) (((-1157 $) $ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-2291 (((-917) $) NIL (|has| (-905 |#1|) (-370)))) (-1447 (((-1157 (-905 |#1|)) $) NIL (|has| (-905 |#1|) (-370)))) (-2193 (((-1157 (-905 |#1|)) $) NIL (|has| (-905 |#1|) (-370))) (((-3 (-1157 (-905 |#1|)) "failed") $ $) NIL (|has| (-905 |#1|) (-370)))) (-3257 (($ $ (-1157 (-905 |#1|))) NIL (|has| (-905 |#1|) (-370)))) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4436 (($) NIL (|has| (-905 |#1|) (-370)) CONST)) (-4357 (($ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-4051 (((-121) $) NIL)) (-4025 (((-1108) $) NIL)) (-3432 (((-1244 (-634 (-2 (|:| -2852 (-905 |#1|)) (|:| -4357 (-1108)))))) NIL)) (-3996 (((-679 (-905 |#1|))) NIL)) (-2707 (($) NIL (|has| (-905 |#1|) (-370)))) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) NIL (|has| (-905 |#1|) (-370)))) (-3850 (((-420 $) $) NIL)) (-4321 (((-828 (-917))) NIL) (((-917)) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-2721 (((-763) $) NIL (|has| (-905 |#1|) (-370))) (((-3 (-763) "failed") $ $) NIL (-2199 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-3108 (((-139)) NIL)) (-4191 (($ $) NIL (|has| (-905 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-905 |#1|) (-370)))) (-1836 (((-828 (-917)) $) NIL) (((-917) $) NIL)) (-1492 (((-1157 (-905 |#1|))) NIL)) (-2330 (($) NIL (|has| (-905 |#1|) (-370)))) (-1398 (($) NIL (|has| (-905 |#1|) (-370)))) (-1656 (((-1244 (-905 |#1|)) $) NIL) (((-679 (-905 |#1|)) (-1244 $)) NIL)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| (-905 |#1|) (-370)))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ (-905 |#1|)) NIL)) (-3385 (($ $) NIL (|has| (-905 |#1|) (-370))) (((-3 $ "failed") $) NIL (-2199 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-3425 (((-763)) NIL)) (-2588 (((-1244 $)) NIL) (((-1244 $) (-917)) NIL)) (-2273 (((-121) $ $) NIL)) (-1413 (((-121) $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3412 (($ $) NIL (|has| (-905 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-905 |#1|) (-370)))) (-3192 (($ $) NIL (|has| (-905 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-905 |#1|) (-370)))) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ $) NIL) (($ $ (-905 |#1|)) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ $ (-905 |#1|)) NIL) (($ (-905 |#1|) $) NIL))) 
+(((-352 |#1| |#2|) (-13 (-327 (-905 |#1|)) (-10 -7 (-15 -3432 ((-1244 (-634 (-2 (|:| -2852 (-905 |#1|)) (|:| -4357 (-1108))))))) (-15 -3996 ((-679 (-905 |#1|)))) (-15 -1628 ((-763))))) (-917) (-917)) (T -352)) 
+((-3432 (*1 *2) (-12 (-5 *2 (-1244 (-634 (-2 (|:| -2852 (-905 *3)) (|:| -4357 (-1108)))))) (-5 *1 (-352 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917)))) (-3996 (*1 *2) (-12 (-5 *2 (-679 (-905 *3))) (-5 *1 (-352 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917)))) (-1628 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-352 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917))))) 
+(-13 (-327 (-905 |#1|)) (-10 -7 (-15 -3432 ((-1244 (-634 (-2 (|:| -2852 (-905 |#1|)) (|:| -4357 (-1108))))))) (-15 -3996 ((-679 (-905 |#1|)))) (-15 -1628 ((-763))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 74)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2134 (((-121) $) NIL)) (-3800 (((-763)) NIL)) (-1934 ((|#1| $) 92) (($ $ (-917)) 90 (|has| |#1| (-370)))) (-1856 (((-1169 (-917) (-763)) (-568)) 148 (|has| |#1| (-370)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-1628 (((-763)) 89)) (-2589 (((-121) $ $) NIL)) (-3986 (((-763)) 162 (|has| |#1| (-370)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) 111)) (-2857 ((|#1| $) 91)) (-3899 (($ (-1244 |#1|)) 57)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) 187 (|has| |#1| (-370)))) (-2403 (($ $ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1733 (($) 158 (|has| |#1| (-370)))) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-4188 (($) 149 (|has| |#1| (-370)))) (-1748 (((-121) $) NIL (|has| |#1| (-370)))) (-1887 (($ $ (-763)) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370)))) (($ $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-2197 (((-121) $) NIL)) (-1844 (((-917) $) NIL (|has| |#1| (-370))) (((-828 (-917)) $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-1598 (((-121) $) NIL)) (-2769 (($) 97 (|has| |#1| (-370)))) (-2151 (((-121) $) 175 (|has| |#1| (-370)))) (-4417 ((|#1| $) 94) (($ $ (-917)) 93 (|has| |#1| (-370)))) (-2214 (((-3 $ "failed") $) NIL (|has| |#1| (-370)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1497 (((-1157 |#1|) $) 188) (((-1157 $) $ (-917)) NIL (|has| |#1| (-370)))) (-2291 (((-917) $) 133 (|has| |#1| (-370)))) (-1447 (((-1157 |#1|) $) 73 (|has| |#1| (-370)))) (-2193 (((-1157 |#1|) $) 70 (|has| |#1| (-370))) (((-3 (-1157 |#1|) "failed") $ $) 82 (|has| |#1| (-370)))) (-3257 (($ $ (-1157 |#1|)) 69 (|has| |#1| (-370)))) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) 191)) (-4436 (($) NIL (|has| |#1| (-370)) CONST)) (-4357 (($ (-917)) 136 (|has| |#1| (-370)))) (-4051 (((-121) $) 107)) (-4025 (((-1108) $) NIL)) (-3432 (((-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108)))))) 83)) (-3996 (((-679 |#1|)) 87)) (-2707 (($) 96 (|has| |#1| (-370)))) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) 150 (|has| |#1| (-370)))) (-3850 (((-420 $) $) NIL)) (-4321 (((-828 (-917))) NIL) (((-917)) 151)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-2721 (((-763) $) NIL (|has| |#1| (-370))) (((-3 (-763) "failed") $ $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3108 (((-139)) NIL)) (-4191 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-1836 (((-828 (-917)) $) NIL) (((-917) $) 62)) (-1492 (((-1157 |#1|)) 152)) (-2330 (($) 132 (|has| |#1| (-370)))) (-1398 (($) NIL (|has| |#1| (-370)))) (-1656 (((-1244 |#1|) $) 105) (((-679 |#1|) (-1244 $)) NIL)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| |#1| (-370)))) (-2747 (((-850) $) 123) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ |#1|) 56)) (-3385 (($ $) NIL (|has| |#1| (-370))) (((-3 $ "failed") $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3425 (((-763)) 156)) (-2588 (((-1244 $)) 172) (((-1244 $) (-917)) 100)) (-2273 (((-121) $ $) NIL)) (-1413 (((-121) $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) 30 T CONST)) (-1557 (($) 22 T CONST)) (-3412 (($ $) 106 (|has| |#1| (-370))) (($ $ (-763)) 98 (|has| |#1| (-370)))) (-3192 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-1719 (((-121) $ $) 60)) (-1781 (($ $ $) 103) (($ $ |#1|) 104)) (-1775 (($ $) 177) (($ $ $) 181)) (-1769 (($ $ $) 179)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) 137)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 185) (($ $ $) 142) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) 102))) 
+(((-353 |#1| |#2|) (-13 (-327 |#1|) (-10 -7 (-15 -3432 ((-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108))))))) (-15 -3996 ((-679 |#1|))) (-15 -1628 ((-763))))) (-350) (-3 (-1157 |#1|) (-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108))))))) (T -353)) 
+((-3432 (*1 *2) (-12 (-5 *2 (-1244 (-634 (-2 (|:| -2852 *3) (|:| -4357 (-1108)))))) (-5 *1 (-353 *3 *4)) (-4 *3 (-350)) (-14 *4 (-3 (-1157 *3) *2)))) (-3996 (*1 *2) (-12 (-5 *2 (-679 *3)) (-5 *1 (-353 *3 *4)) (-4 *3 (-350)) (-14 *4 (-3 (-1157 *3) (-1244 (-634 (-2 (|:| -2852 *3) (|:| -4357 (-1108))))))))) (-1628 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-353 *3 *4)) (-4 *3 (-350)) (-14 *4 (-3 (-1157 *3) (-1244 (-634 (-2 (|:| -2852 *3) (|:| -4357 (-1108)))))))))) 
+(-13 (-327 |#1|) (-10 -7 (-15 -3432 ((-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108))))))) (-15 -3996 ((-679 |#1|))) (-15 -1628 ((-763))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2134 (((-121) $) NIL)) (-3800 (((-763)) NIL)) (-1934 ((|#1| $) NIL) (($ $ (-917)) NIL (|has| |#1| (-370)))) (-1856 (((-1169 (-917) (-763)) (-568)) NIL (|has| |#1| (-370)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-1628 (((-763)) NIL)) (-2589 (((-121) $ $) NIL)) (-3986 (((-763)) NIL (|has| |#1| (-370)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) NIL)) (-2857 ((|#1| $) NIL)) (-3899 (($ (-1244 |#1|)) NIL)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| |#1| (-370)))) (-2403 (($ $ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1733 (($) NIL (|has| |#1| (-370)))) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-4188 (($) NIL (|has| |#1| (-370)))) (-1748 (((-121) $) NIL (|has| |#1| (-370)))) (-1887 (($ $ (-763)) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370)))) (($ $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-2197 (((-121) $) NIL)) (-1844 (((-917) $) NIL (|has| |#1| (-370))) (((-828 (-917)) $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-1598 (((-121) $) NIL)) (-2769 (($) NIL (|has| |#1| (-370)))) (-2151 (((-121) $) NIL (|has| |#1| (-370)))) (-4417 ((|#1| $) NIL) (($ $ (-917)) NIL (|has| |#1| (-370)))) (-2214 (((-3 $ "failed") $) NIL (|has| |#1| (-370)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1497 (((-1157 |#1|) $) NIL) (((-1157 $) $ (-917)) NIL (|has| |#1| (-370)))) (-2291 (((-917) $) NIL (|has| |#1| (-370)))) (-1447 (((-1157 |#1|) $) NIL (|has| |#1| (-370)))) (-2193 (((-1157 |#1|) $) NIL (|has| |#1| (-370))) (((-3 (-1157 |#1|) "failed") $ $) NIL (|has| |#1| (-370)))) (-3257 (($ $ (-1157 |#1|)) NIL (|has| |#1| (-370)))) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4436 (($) NIL (|has| |#1| (-370)) CONST)) (-4357 (($ (-917)) NIL (|has| |#1| (-370)))) (-4051 (((-121) $) NIL)) (-4025 (((-1108) $) NIL)) (-3432 (((-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108)))))) NIL)) (-3996 (((-679 |#1|)) NIL)) (-2707 (($) NIL (|has| |#1| (-370)))) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) NIL (|has| |#1| (-370)))) (-3850 (((-420 $) $) NIL)) (-4321 (((-828 (-917))) NIL) (((-917)) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-2721 (((-763) $) NIL (|has| |#1| (-370))) (((-3 (-763) "failed") $ $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3108 (((-139)) NIL)) (-4191 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-1836 (((-828 (-917)) $) NIL) (((-917) $) NIL)) (-1492 (((-1157 |#1|)) NIL)) (-2330 (($) NIL (|has| |#1| (-370)))) (-1398 (($) NIL (|has| |#1| (-370)))) (-1656 (((-1244 |#1|) $) NIL) (((-679 |#1|) (-1244 $)) NIL)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| |#1| (-370)))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ |#1|) NIL)) (-3385 (($ $) NIL (|has| |#1| (-370))) (((-3 $ "failed") $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3425 (((-763)) NIL)) (-2588 (((-1244 $)) NIL) (((-1244 $) (-917)) NIL)) (-2273 (((-121) $ $) NIL)) (-1413 (((-121) $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3412 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-3192 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ $) NIL) (($ $ |#1|) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
+(((-354 |#1| |#2|) (-13 (-327 |#1|) (-10 -7 (-15 -3432 ((-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108))))))) (-15 -3996 ((-679 |#1|))) (-15 -1628 ((-763))))) (-350) (-917)) (T -354)) 
+((-3432 (*1 *2) (-12 (-5 *2 (-1244 (-634 (-2 (|:| -2852 *3) (|:| -4357 (-1108)))))) (-5 *1 (-354 *3 *4)) (-4 *3 (-350)) (-14 *4 (-917)))) (-3996 (*1 *2) (-12 (-5 *2 (-679 *3)) (-5 *1 (-354 *3 *4)) (-4 *3 (-350)) (-14 *4 (-917)))) (-1628 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-354 *3 *4)) (-4 *3 (-350)) (-14 *4 (-917))))) 
+(-13 (-327 |#1|) (-10 -7 (-15 -3432 ((-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108))))))) (-15 -3996 ((-679 |#1|))) (-15 -1628 ((-763))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2134 (((-121) $) NIL)) (-3800 (((-763)) NIL)) (-1934 (((-905 |#1|) $) NIL) (($ $ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-1856 (((-1169 (-917) (-763)) (-568)) NIL (|has| (-905 |#1|) (-370)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2589 (((-121) $ $) NIL)) (-3986 (((-763)) NIL (|has| (-905 |#1|) (-370)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-905 |#1|) "failed") $) NIL)) (-2857 (((-905 |#1|) $) NIL)) (-3899 (($ (-1244 (-905 |#1|))) NIL)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-905 |#1|) (-370)))) (-2403 (($ $ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1733 (($) NIL (|has| (-905 |#1|) (-370)))) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-4188 (($) NIL (|has| (-905 |#1|) (-370)))) (-1748 (((-121) $) NIL (|has| (-905 |#1|) (-370)))) (-1887 (($ $ (-763)) NIL (-2199 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370)))) (($ $) NIL (-2199 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-2197 (((-121) $) NIL)) (-1844 (((-917) $) NIL (|has| (-905 |#1|) (-370))) (((-828 (-917)) $) NIL (-2199 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-1598 (((-121) $) NIL)) (-2769 (($) NIL (|has| (-905 |#1|) (-370)))) (-2151 (((-121) $) NIL (|has| (-905 |#1|) (-370)))) (-4417 (((-905 |#1|) $) NIL) (($ $ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-2214 (((-3 $ "failed") $) NIL (|has| (-905 |#1|) (-370)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1497 (((-1157 (-905 |#1|)) $) NIL) (((-1157 $) $ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-2291 (((-917) $) NIL (|has| (-905 |#1|) (-370)))) (-1447 (((-1157 (-905 |#1|)) $) NIL (|has| (-905 |#1|) (-370)))) (-2193 (((-1157 (-905 |#1|)) $) NIL (|has| (-905 |#1|) (-370))) (((-3 (-1157 (-905 |#1|)) "failed") $ $) NIL (|has| (-905 |#1|) (-370)))) (-3257 (($ $ (-1157 (-905 |#1|))) NIL (|has| (-905 |#1|) (-370)))) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4436 (($) NIL (|has| (-905 |#1|) (-370)) CONST)) (-4357 (($ (-917)) NIL (|has| (-905 |#1|) (-370)))) (-4051 (((-121) $) NIL)) (-4025 (((-1108) $) NIL)) (-2707 (($) NIL (|has| (-905 |#1|) (-370)))) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) NIL (|has| (-905 |#1|) (-370)))) (-3850 (((-420 $) $) NIL)) (-4321 (((-828 (-917))) NIL) (((-917)) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-2721 (((-763) $) NIL (|has| (-905 |#1|) (-370))) (((-3 (-763) "failed") $ $) NIL (-2199 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-3108 (((-139)) NIL)) (-4191 (($ $) NIL (|has| (-905 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-905 |#1|) (-370)))) (-1836 (((-828 (-917)) $) NIL) (((-917) $) NIL)) (-1492 (((-1157 (-905 |#1|))) NIL)) (-2330 (($) NIL (|has| (-905 |#1|) (-370)))) (-1398 (($) NIL (|has| (-905 |#1|) (-370)))) (-1656 (((-1244 (-905 |#1|)) $) NIL) (((-679 (-905 |#1|)) (-1244 $)) NIL)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| (-905 |#1|) (-370)))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ (-905 |#1|)) NIL)) (-3385 (($ $) NIL (|has| (-905 |#1|) (-370))) (((-3 $ "failed") $) NIL (-2199 (|has| (-905 |#1|) (-148)) (|has| (-905 |#1|) (-370))))) (-3425 (((-763)) NIL)) (-2588 (((-1244 $)) NIL) (((-1244 $) (-917)) NIL)) (-2273 (((-121) $ $) NIL)) (-1413 (((-121) $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3412 (($ $) NIL (|has| (-905 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-905 |#1|) (-370)))) (-3192 (($ $) NIL (|has| (-905 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-905 |#1|) (-370)))) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ $) NIL) (($ $ (-905 |#1|)) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ $ (-905 |#1|)) NIL) (($ (-905 |#1|) $) NIL))) 
 (((-355 |#1| |#2|) (-327 (-905 |#1|)) (-917) (-917)) (T -355)) 
 NIL 
 (-327 (-905 |#1|)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-2615 (((-121) $) NIL)) (-1739 (((-763)) NIL)) (-1932 ((|#1| $) NIL) (($ $ (-917)) NIL (|has| |#1| (-370)))) (-3211 (((-1169 (-917) (-763)) (-568)) 119 (|has| |#1| (-370)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1497 (((-121) $ $) NIL)) (-3983 (((-763)) 138 (|has| |#1| (-370)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) 91)) (-2854 ((|#1| $) 88)) (-3498 (($ (-1244 |#1|)) 83)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) 115 (|has| |#1| (-370)))) (-2401 (($ $ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1731 (($) 80 (|has| |#1| (-370)))) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-4220 (($) 39 (|has| |#1| (-370)))) (-4456 (((-121) $) NIL (|has| |#1| (-370)))) (-3218 (($ $ (-763)) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370)))) (($ $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3927 (((-121) $) NIL)) (-4477 (((-917) $) NIL (|has| |#1| (-370))) (((-828 (-917)) $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-2735 (((-121) $) NIL)) (-2883 (($) 120 (|has| |#1| (-370)))) (-3917 (((-121) $) 72 (|has| |#1| (-370)))) (-2657 ((|#1| $) 38) (($ $ (-917)) 40 (|has| |#1| (-370)))) (-3038 (((-3 $ "failed") $) NIL (|has| |#1| (-370)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2045 (((-1157 |#1|) $) 62) (((-1157 $) $ (-917)) NIL (|has| |#1| (-370)))) (-3683 (((-917) $) 95 (|has| |#1| (-370)))) (-2035 (((-1157 |#1|) $) NIL (|has| |#1| (-370)))) (-1422 (((-1157 |#1|) $) NIL (|has| |#1| (-370))) (((-3 (-1157 |#1|) "failed") $ $) NIL (|has| |#1| (-370)))) (-2109 (($ $ (-1157 |#1|)) NIL (|has| |#1| (-370)))) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4434 (($) NIL (|has| |#1| (-370)) CONST)) (-4355 (($ (-917)) 93 (|has| |#1| (-370)))) (-2864 (((-121) $) 140)) (-4022 (((-1108) $) NIL)) (-2704 (($) 35 (|has| |#1| (-370)))) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) 113 (|has| |#1| (-370)))) (-3848 (((-420 $) $) NIL)) (-1553 (((-828 (-917))) NIL) (((-917)) 137)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3143 (((-763) $) NIL (|has| |#1| (-370))) (((-3 (-763) "failed") $ $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-4321 (((-139)) NIL)) (-4189 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-3206 (((-828 (-917)) $) NIL) (((-917) $) 56)) (-1626 (((-1157 |#1|)) 86)) (-3065 (($) 125 (|has| |#1| (-370)))) (-2027 (($) NIL (|has| |#1| (-370)))) (-4073 (((-1244 |#1|) $) 50) (((-679 |#1|) (-1244 $)) NIL)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| |#1| (-370)))) (-2745 (((-850) $) 136) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ |#1|) 85)) (-4371 (($ $) NIL (|has| |#1| (-370))) (((-3 $ "failed") $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-4078 (((-763)) 142)) (-3746 (((-1244 $)) 107) (((-1244 $) (-917)) 46)) (-1826 (((-121) $ $) NIL)) (-4390 (((-121) $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) 109 T CONST)) (-1556 (($) 31 T CONST)) (-1316 (($ $) 65 (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-3190 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-1717 (((-121) $ $) 105)) (-1779 (($ $ $) 97) (($ $ |#1|) 98)) (-1773 (($ $) 78) (($ $ $) 103)) (-1767 (($ $ $) 101)) (** (($ $ (-917)) NIL) (($ $ (-763)) 41) (($ $ (-568)) 128)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 76) (($ $ $) 53) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) 74))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2134 (((-121) $) NIL)) (-3800 (((-763)) NIL)) (-1934 ((|#1| $) NIL) (($ $ (-917)) NIL (|has| |#1| (-370)))) (-1856 (((-1169 (-917) (-763)) (-568)) 119 (|has| |#1| (-370)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2589 (((-121) $ $) NIL)) (-3986 (((-763)) 138 (|has| |#1| (-370)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) 91)) (-2857 ((|#1| $) 88)) (-3899 (($ (-1244 |#1|)) 83)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) 115 (|has| |#1| (-370)))) (-2403 (($ $ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1733 (($) 80 (|has| |#1| (-370)))) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-4188 (($) 39 (|has| |#1| (-370)))) (-1748 (((-121) $) NIL (|has| |#1| (-370)))) (-1887 (($ $ (-763)) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370)))) (($ $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-2197 (((-121) $) NIL)) (-1844 (((-917) $) NIL (|has| |#1| (-370))) (((-828 (-917)) $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-1598 (((-121) $) NIL)) (-2769 (($) 120 (|has| |#1| (-370)))) (-2151 (((-121) $) 72 (|has| |#1| (-370)))) (-4417 ((|#1| $) 38) (($ $ (-917)) 40 (|has| |#1| (-370)))) (-2214 (((-3 $ "failed") $) NIL (|has| |#1| (-370)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1497 (((-1157 |#1|) $) 62) (((-1157 $) $ (-917)) NIL (|has| |#1| (-370)))) (-2291 (((-917) $) 95 (|has| |#1| (-370)))) (-1447 (((-1157 |#1|) $) NIL (|has| |#1| (-370)))) (-2193 (((-1157 |#1|) $) NIL (|has| |#1| (-370))) (((-3 (-1157 |#1|) "failed") $ $) NIL (|has| |#1| (-370)))) (-3257 (($ $ (-1157 |#1|)) NIL (|has| |#1| (-370)))) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4436 (($) NIL (|has| |#1| (-370)) CONST)) (-4357 (($ (-917)) 93 (|has| |#1| (-370)))) (-4051 (((-121) $) 140)) (-4025 (((-1108) $) NIL)) (-2707 (($) 35 (|has| |#1| (-370)))) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) 113 (|has| |#1| (-370)))) (-3850 (((-420 $) $) NIL)) (-4321 (((-828 (-917))) NIL) (((-917)) 137)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-2721 (((-763) $) NIL (|has| |#1| (-370))) (((-3 (-763) "failed") $ $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3108 (((-139)) NIL)) (-4191 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-1836 (((-828 (-917)) $) NIL) (((-917) $) 56)) (-1492 (((-1157 |#1|)) 86)) (-2330 (($) 125 (|has| |#1| (-370)))) (-1398 (($) NIL (|has| |#1| (-370)))) (-1656 (((-1244 |#1|) $) 50) (((-679 |#1|) (-1244 $)) NIL)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| |#1| (-370)))) (-2747 (((-850) $) 136) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ |#1|) 85)) (-3385 (($ $) NIL (|has| |#1| (-370))) (((-3 $ "failed") $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3425 (((-763)) 142)) (-2588 (((-1244 $)) 107) (((-1244 $) (-917)) 46)) (-2273 (((-121) $ $) NIL)) (-1413 (((-121) $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) 109 T CONST)) (-1557 (($) 31 T CONST)) (-3412 (($ $) 65 (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-3192 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-1719 (((-121) $ $) 105)) (-1781 (($ $ $) 97) (($ $ |#1|) 98)) (-1775 (($ $) 78) (($ $ $) 103)) (-1769 (($ $ $) 101)) (** (($ $ (-917)) NIL) (($ $ (-763)) 41) (($ $ (-568)) 128)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 76) (($ $ $) 53) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) 74))) 
 (((-356 |#1| |#2|) (-327 |#1|) (-350) (-1157 |#1|)) (T -356)) 
 NIL 
 (-327 |#1|) 
-((-1411 ((|#1| (-1157 |#2|)) 51))) 
-(((-357 |#1| |#2|) (-10 -7 (-15 -1411 (|#1| (-1157 |#2|)))) (-13 (-404) (-10 -7 (-15 -2745 (|#1| |#2|)) (-15 -3683 ((-917) |#1|)) (-15 -3746 ((-1244 |#1|) (-917))) (-15 -1316 (|#1| |#1|)))) (-350)) (T -357)) 
-((-1411 (*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-350)) (-4 *2 (-13 (-404) (-10 -7 (-15 -2745 (*2 *4)) (-15 -3683 ((-917) *2)) (-15 -3746 ((-1244 *2) (-917))) (-15 -1316 (*2 *2))))) (-5 *1 (-357 *2 *4))))) 
-(-10 -7 (-15 -1411 (|#1| (-1157 |#2|)))) 
-((-3671 (((-958 (-1157 |#1|)) (-1157 |#1|)) 36)) (-1731 (((-1157 |#1|) (-917) (-917)) 109) (((-1157 |#1|) (-917)) 108)) (-4456 (((-121) (-1157 |#1|)) 81)) (-1617 (((-917) (-917)) 71)) (-2113 (((-917) (-917)) 73)) (-3520 (((-917) (-917)) 69)) (-3917 (((-121) (-1157 |#1|)) 85)) (-1306 (((-3 (-1157 |#1|) "failed") (-1157 |#1|)) 97)) (-3383 (((-3 (-1157 |#1|) "failed") (-1157 |#1|)) 100)) (-4039 (((-3 (-1157 |#1|) "failed") (-1157 |#1|)) 99)) (-3356 (((-3 (-1157 |#1|) "failed") (-1157 |#1|)) 98)) (-1451 (((-3 (-1157 |#1|) "failed") (-1157 |#1|)) 94)) (-2118 (((-1157 |#1|) (-1157 |#1|)) 62)) (-2454 (((-1157 |#1|) (-917)) 103)) (-2744 (((-1157 |#1|) (-917)) 106)) (-4136 (((-1157 |#1|) (-917)) 105)) (-2441 (((-1157 |#1|) (-917)) 104)) (-3805 (((-1157 |#1|) (-917)) 101))) 
-(((-358 |#1|) (-10 -7 (-15 -4456 ((-121) (-1157 |#1|))) (-15 -3917 ((-121) (-1157 |#1|))) (-15 -3520 ((-917) (-917))) (-15 -1617 ((-917) (-917))) (-15 -2113 ((-917) (-917))) (-15 -3805 ((-1157 |#1|) (-917))) (-15 -2454 ((-1157 |#1|) (-917))) (-15 -2441 ((-1157 |#1|) (-917))) (-15 -4136 ((-1157 |#1|) (-917))) (-15 -2744 ((-1157 |#1|) (-917))) (-15 -1451 ((-3 (-1157 |#1|) "failed") (-1157 |#1|))) (-15 -1306 ((-3 (-1157 |#1|) "failed") (-1157 |#1|))) (-15 -3356 ((-3 (-1157 |#1|) "failed") (-1157 |#1|))) (-15 -4039 ((-3 (-1157 |#1|) "failed") (-1157 |#1|))) (-15 -3383 ((-3 (-1157 |#1|) "failed") (-1157 |#1|))) (-15 -1731 ((-1157 |#1|) (-917))) (-15 -1731 ((-1157 |#1|) (-917) (-917))) (-15 -2118 ((-1157 |#1|) (-1157 |#1|))) (-15 -3671 ((-958 (-1157 |#1|)) (-1157 |#1|)))) (-350)) (T -358)) 
-((-3671 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-958 (-1157 *4))) (-5 *1 (-358 *4)) (-5 *3 (-1157 *4)))) (-2118 (*1 *2 *2) (-12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3)))) (-1731 (*1 *2 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350)))) (-1731 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350)))) (-3383 (*1 *2 *2) (|partial| -12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3)))) (-4039 (*1 *2 *2) (|partial| -12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3)))) (-3356 (*1 *2 *2) (|partial| -12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3)))) (-1306 (*1 *2 *2) (|partial| -12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3)))) (-1451 (*1 *2 *2) (|partial| -12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3)))) (-2744 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350)))) (-4136 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350)))) (-2441 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350)))) (-2454 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350)))) (-3805 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350)))) (-2113 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-358 *3)) (-4 *3 (-350)))) (-1617 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-358 *3)) (-4 *3 (-350)))) (-3520 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-358 *3)) (-4 *3 (-350)))) (-3917 (*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-350)) (-5 *2 (-121)) (-5 *1 (-358 *4)))) (-4456 (*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-350)) (-5 *2 (-121)) (-5 *1 (-358 *4))))) 
-(-10 -7 (-15 -4456 ((-121) (-1157 |#1|))) (-15 -3917 ((-121) (-1157 |#1|))) (-15 -3520 ((-917) (-917))) (-15 -1617 ((-917) (-917))) (-15 -2113 ((-917) (-917))) (-15 -3805 ((-1157 |#1|) (-917))) (-15 -2454 ((-1157 |#1|) (-917))) (-15 -2441 ((-1157 |#1|) (-917))) (-15 -4136 ((-1157 |#1|) (-917))) (-15 -2744 ((-1157 |#1|) (-917))) (-15 -1451 ((-3 (-1157 |#1|) "failed") (-1157 |#1|))) (-15 -1306 ((-3 (-1157 |#1|) "failed") (-1157 |#1|))) (-15 -3356 ((-3 (-1157 |#1|) "failed") (-1157 |#1|))) (-15 -4039 ((-3 (-1157 |#1|) "failed") (-1157 |#1|))) (-15 -3383 ((-3 (-1157 |#1|) "failed") (-1157 |#1|))) (-15 -1731 ((-1157 |#1|) (-917))) (-15 -1731 ((-1157 |#1|) (-917) (-917))) (-15 -2118 ((-1157 |#1|) (-1157 |#1|))) (-15 -3671 ((-958 (-1157 |#1|)) (-1157 |#1|)))) 
-((-1858 (((-3 (-634 |#3|) "failed") (-634 |#3|) |#3|) 33))) 
-(((-359 |#1| |#2| |#3|) (-10 -7 (-15 -1858 ((-3 (-634 |#3|) "failed") (-634 |#3|) |#3|))) (-350) (-1219 |#1|) (-1219 |#2|)) (T -359)) 
-((-1858 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-1219 *4)) (-4 *4 (-350)) (-5 *1 (-359 *4 *5 *3))))) 
-(-10 -7 (-15 -1858 ((-3 (-634 |#3|) "failed") (-634 |#3|) |#3|))) 
-((-2133 (((-420 |#2|) |#2|) 46)) (-4484 (((-420 |#2|) |#2|) 36))) 
-(((-360 |#1| |#2|) (-10 -7 (-15 -4484 ((-420 |#2|) |#2|)) (-15 -2133 ((-420 |#2|) |#2|))) (-350) (-1219 |#1|)) (T -360)) 
-((-2133 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-360 *4 *3)) (-4 *3 (-1219 *4)))) (-4484 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-360 *4 *3)) (-4 *3 (-1219 *4))))) 
-(-10 -7 (-15 -4484 ((-420 |#2|) |#2|)) (-15 -2133 ((-420 |#2|) |#2|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-2615 (((-121) $) NIL)) (-1739 (((-763)) NIL)) (-1932 ((|#1| $) NIL) (($ $ (-917)) NIL (|has| |#1| (-370)))) (-3211 (((-1169 (-917) (-763)) (-568)) NIL (|has| |#1| (-370)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1497 (((-121) $ $) NIL)) (-3983 (((-763)) NIL (|has| |#1| (-370)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) NIL)) (-2854 ((|#1| $) NIL)) (-3498 (($ (-1244 |#1|)) NIL)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| |#1| (-370)))) (-2401 (($ $ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1731 (($) NIL (|has| |#1| (-370)))) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-4220 (($) NIL (|has| |#1| (-370)))) (-4456 (((-121) $) NIL (|has| |#1| (-370)))) (-3218 (($ $ (-763)) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370)))) (($ $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3927 (((-121) $) NIL)) (-4477 (((-917) $) NIL (|has| |#1| (-370))) (((-828 (-917)) $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-2735 (((-121) $) NIL)) (-2883 (($) NIL (|has| |#1| (-370)))) (-3917 (((-121) $) NIL (|has| |#1| (-370)))) (-2657 ((|#1| $) NIL) (($ $ (-917)) NIL (|has| |#1| (-370)))) (-3038 (((-3 $ "failed") $) NIL (|has| |#1| (-370)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2045 (((-1157 |#1|) $) NIL) (((-1157 $) $ (-917)) NIL (|has| |#1| (-370)))) (-3683 (((-917) $) NIL (|has| |#1| (-370)))) (-2035 (((-1157 |#1|) $) NIL (|has| |#1| (-370)))) (-1422 (((-1157 |#1|) $) NIL (|has| |#1| (-370))) (((-3 (-1157 |#1|) "failed") $ $) NIL (|has| |#1| (-370)))) (-2109 (($ $ (-1157 |#1|)) NIL (|has| |#1| (-370)))) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4434 (($) NIL (|has| |#1| (-370)) CONST)) (-4355 (($ (-917)) NIL (|has| |#1| (-370)))) (-2864 (((-121) $) NIL)) (-4022 (((-1108) $) NIL)) (-2704 (($) NIL (|has| |#1| (-370)))) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) NIL (|has| |#1| (-370)))) (-3848 (((-420 $) $) NIL)) (-1553 (((-828 (-917))) NIL) (((-917)) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3143 (((-763) $) NIL (|has| |#1| (-370))) (((-3 (-763) "failed") $ $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-4321 (((-139)) NIL)) (-4189 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-3206 (((-828 (-917)) $) NIL) (((-917) $) NIL)) (-1626 (((-1157 |#1|)) NIL)) (-3065 (($) NIL (|has| |#1| (-370)))) (-2027 (($) NIL (|has| |#1| (-370)))) (-4073 (((-1244 |#1|) $) NIL) (((-679 |#1|) (-1244 $)) NIL)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| |#1| (-370)))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ |#1|) NIL)) (-4371 (($ $) NIL (|has| |#1| (-370))) (((-3 $ "failed") $) NIL (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-4078 (((-763)) NIL)) (-3746 (((-1244 $)) NIL) (((-1244 $) (-917)) NIL)) (-1826 (((-121) $ $) NIL)) (-4390 (((-121) $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-1316 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-3190 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ $) NIL) (($ $ |#1|) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
+((-2137 ((|#1| (-1157 |#2|)) 51))) 
+(((-357 |#1| |#2|) (-10 -7 (-15 -2137 (|#1| (-1157 |#2|)))) (-13 (-404) (-10 -7 (-15 -2747 (|#1| |#2|)) (-15 -2291 ((-917) |#1|)) (-15 -2588 ((-1244 |#1|) (-917))) (-15 -3412 (|#1| |#1|)))) (-350)) (T -357)) 
+((-2137 (*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-350)) (-4 *2 (-13 (-404) (-10 -7 (-15 -2747 (*2 *4)) (-15 -2291 ((-917) *2)) (-15 -2588 ((-1244 *2) (-917))) (-15 -3412 (*2 *2))))) (-5 *1 (-357 *2 *4))))) 
+(-10 -7 (-15 -2137 (|#1| (-1157 |#2|)))) 
+((-2242 (((-958 (-1157 |#1|)) (-1157 |#1|)) 36)) (-1733 (((-1157 |#1|) (-917) (-917)) 109) (((-1157 |#1|) (-917)) 108)) (-1748 (((-121) (-1157 |#1|)) 81)) (-1434 (((-917) (-917)) 71)) (-3290 (((-917) (-917)) 73)) (-4058 (((-917) (-917)) 69)) (-2151 (((-121) (-1157 |#1|)) 85)) (-3332 (((-3 (-1157 |#1|) "failed") (-1157 |#1|)) 97)) (-1457 (((-3 (-1157 |#1|) "failed") (-1157 |#1|)) 100)) (-1528 (((-3 (-1157 |#1|) "failed") (-1157 |#1|)) 99)) (-1306 (((-3 (-1157 |#1|) "failed") (-1157 |#1|)) 98)) (-2351 (((-3 (-1157 |#1|) "failed") (-1157 |#1|)) 94)) (-3324 (((-1157 |#1|) (-1157 |#1|)) 62)) (-2540 (((-1157 |#1|) (-917)) 103)) (-3356 (((-1157 |#1|) (-917)) 106)) (-3730 (((-1157 |#1|) (-917)) 105)) (-2476 (((-1157 |#1|) (-917)) 104)) (-1707 (((-1157 |#1|) (-917)) 101))) 
+(((-358 |#1|) (-10 -7 (-15 -1748 ((-121) (-1157 |#1|))) (-15 -2151 ((-121) (-1157 |#1|))) (-15 -4058 ((-917) (-917))) (-15 -1434 ((-917) (-917))) (-15 -3290 ((-917) (-917))) (-15 -1707 ((-1157 |#1|) (-917))) (-15 -2540 ((-1157 |#1|) (-917))) (-15 -2476 ((-1157 |#1|) (-917))) (-15 -3730 ((-1157 |#1|) (-917))) (-15 -3356 ((-1157 |#1|) (-917))) (-15 -2351 ((-3 (-1157 |#1|) "failed") (-1157 |#1|))) (-15 -3332 ((-3 (-1157 |#1|) "failed") (-1157 |#1|))) (-15 -1306 ((-3 (-1157 |#1|) "failed") (-1157 |#1|))) (-15 -1528 ((-3 (-1157 |#1|) "failed") (-1157 |#1|))) (-15 -1457 ((-3 (-1157 |#1|) "failed") (-1157 |#1|))) (-15 -1733 ((-1157 |#1|) (-917))) (-15 -1733 ((-1157 |#1|) (-917) (-917))) (-15 -3324 ((-1157 |#1|) (-1157 |#1|))) (-15 -2242 ((-958 (-1157 |#1|)) (-1157 |#1|)))) (-350)) (T -358)) 
+((-2242 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-958 (-1157 *4))) (-5 *1 (-358 *4)) (-5 *3 (-1157 *4)))) (-3324 (*1 *2 *2) (-12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3)))) (-1733 (*1 *2 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350)))) (-1733 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350)))) (-1457 (*1 *2 *2) (|partial| -12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3)))) (-1528 (*1 *2 *2) (|partial| -12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3)))) (-1306 (*1 *2 *2) (|partial| -12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3)))) (-3332 (*1 *2 *2) (|partial| -12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3)))) (-2351 (*1 *2 *2) (|partial| -12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3)))) (-3356 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350)))) (-3730 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350)))) (-2476 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350)))) (-2540 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350)))) (-1707 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350)))) (-3290 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-358 *3)) (-4 *3 (-350)))) (-1434 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-358 *3)) (-4 *3 (-350)))) (-4058 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-358 *3)) (-4 *3 (-350)))) (-2151 (*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-350)) (-5 *2 (-121)) (-5 *1 (-358 *4)))) (-1748 (*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-350)) (-5 *2 (-121)) (-5 *1 (-358 *4))))) 
+(-10 -7 (-15 -1748 ((-121) (-1157 |#1|))) (-15 -2151 ((-121) (-1157 |#1|))) (-15 -4058 ((-917) (-917))) (-15 -1434 ((-917) (-917))) (-15 -3290 ((-917) (-917))) (-15 -1707 ((-1157 |#1|) (-917))) (-15 -2540 ((-1157 |#1|) (-917))) (-15 -2476 ((-1157 |#1|) (-917))) (-15 -3730 ((-1157 |#1|) (-917))) (-15 -3356 ((-1157 |#1|) (-917))) (-15 -2351 ((-3 (-1157 |#1|) "failed") (-1157 |#1|))) (-15 -3332 ((-3 (-1157 |#1|) "failed") (-1157 |#1|))) (-15 -1306 ((-3 (-1157 |#1|) "failed") (-1157 |#1|))) (-15 -1528 ((-3 (-1157 |#1|) "failed") (-1157 |#1|))) (-15 -1457 ((-3 (-1157 |#1|) "failed") (-1157 |#1|))) (-15 -1733 ((-1157 |#1|) (-917))) (-15 -1733 ((-1157 |#1|) (-917) (-917))) (-15 -3324 ((-1157 |#1|) (-1157 |#1|))) (-15 -2242 ((-958 (-1157 |#1|)) (-1157 |#1|)))) 
+((-2434 (((-3 (-634 |#3|) "failed") (-634 |#3|) |#3|) 33))) 
+(((-359 |#1| |#2| |#3|) (-10 -7 (-15 -2434 ((-3 (-634 |#3|) "failed") (-634 |#3|) |#3|))) (-350) (-1219 |#1|) (-1219 |#2|)) (T -359)) 
+((-2434 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-1219 *4)) (-4 *4 (-350)) (-5 *1 (-359 *4 *5 *3))))) 
+(-10 -7 (-15 -2434 ((-3 (-634 |#3|) "failed") (-634 |#3|) |#3|))) 
+((-3444 (((-420 |#2|) |#2|) 46)) (-1877 (((-420 |#2|) |#2|) 36))) 
+(((-360 |#1| |#2|) (-10 -7 (-15 -1877 ((-420 |#2|) |#2|)) (-15 -3444 ((-420 |#2|) |#2|))) (-350) (-1219 |#1|)) (T -360)) 
+((-3444 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-360 *4 *3)) (-4 *3 (-1219 *4)))) (-1877 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-360 *4 *3)) (-4 *3 (-1219 *4))))) 
+(-10 -7 (-15 -1877 ((-420 |#2|) |#2|)) (-15 -3444 ((-420 |#2|) |#2|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2134 (((-121) $) NIL)) (-3800 (((-763)) NIL)) (-1934 ((|#1| $) NIL) (($ $ (-917)) NIL (|has| |#1| (-370)))) (-1856 (((-1169 (-917) (-763)) (-568)) NIL (|has| |#1| (-370)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2589 (((-121) $ $) NIL)) (-3986 (((-763)) NIL (|has| |#1| (-370)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) NIL)) (-2857 ((|#1| $) NIL)) (-3899 (($ (-1244 |#1|)) NIL)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| |#1| (-370)))) (-2403 (($ $ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1733 (($) NIL (|has| |#1| (-370)))) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-4188 (($) NIL (|has| |#1| (-370)))) (-1748 (((-121) $) NIL (|has| |#1| (-370)))) (-1887 (($ $ (-763)) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370)))) (($ $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-2197 (((-121) $) NIL)) (-1844 (((-917) $) NIL (|has| |#1| (-370))) (((-828 (-917)) $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-1598 (((-121) $) NIL)) (-2769 (($) NIL (|has| |#1| (-370)))) (-2151 (((-121) $) NIL (|has| |#1| (-370)))) (-4417 ((|#1| $) NIL) (($ $ (-917)) NIL (|has| |#1| (-370)))) (-2214 (((-3 $ "failed") $) NIL (|has| |#1| (-370)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1497 (((-1157 |#1|) $) NIL) (((-1157 $) $ (-917)) NIL (|has| |#1| (-370)))) (-2291 (((-917) $) NIL (|has| |#1| (-370)))) (-1447 (((-1157 |#1|) $) NIL (|has| |#1| (-370)))) (-2193 (((-1157 |#1|) $) NIL (|has| |#1| (-370))) (((-3 (-1157 |#1|) "failed") $ $) NIL (|has| |#1| (-370)))) (-3257 (($ $ (-1157 |#1|)) NIL (|has| |#1| (-370)))) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4436 (($) NIL (|has| |#1| (-370)) CONST)) (-4357 (($ (-917)) NIL (|has| |#1| (-370)))) (-4051 (((-121) $) NIL)) (-4025 (((-1108) $) NIL)) (-2707 (($) NIL (|has| |#1| (-370)))) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) NIL (|has| |#1| (-370)))) (-3850 (((-420 $) $) NIL)) (-4321 (((-828 (-917))) NIL) (((-917)) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-2721 (((-763) $) NIL (|has| |#1| (-370))) (((-3 (-763) "failed") $ $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3108 (((-139)) NIL)) (-4191 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-1836 (((-828 (-917)) $) NIL) (((-917) $) NIL)) (-1492 (((-1157 |#1|)) NIL)) (-2330 (($) NIL (|has| |#1| (-370)))) (-1398 (($) NIL (|has| |#1| (-370)))) (-1656 (((-1244 |#1|) $) NIL) (((-679 |#1|) (-1244 $)) NIL)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| |#1| (-370)))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ |#1|) NIL)) (-3385 (($ $) NIL (|has| |#1| (-370))) (((-3 $ "failed") $) NIL (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3425 (((-763)) NIL)) (-2588 (((-1244 $)) NIL) (((-1244 $) (-917)) NIL)) (-2273 (((-121) $ $) NIL)) (-1413 (((-121) $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3412 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-3192 (($ $) NIL (|has| |#1| (-370))) (($ $ (-763)) NIL (|has| |#1| (-370)))) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ $) NIL) (($ $ |#1|) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
 (((-361 |#1| |#2|) (-327 |#1|) (-350) (-917)) (T -361)) 
 NIL 
 (-327 |#1|) 
-((-3624 (((-121) (-634 (-953 |#1|))) 31)) (-2715 (((-634 (-953 |#1|)) (-634 (-953 |#1|))) 42)) (-1560 (((-3 (-634 (-953 |#1|)) "failed") (-634 (-953 |#1|))) 38))) 
-(((-362 |#1| |#2|) (-10 -7 (-15 -3624 ((-121) (-634 (-953 |#1|)))) (-15 -1560 ((-3 (-634 (-953 |#1|)) "failed") (-634 (-953 |#1|)))) (-15 -2715 ((-634 (-953 |#1|)) (-634 (-953 |#1|))))) (-453) (-634 (-1161))) (T -362)) 
-((-2715 (*1 *2 *2) (-12 (-5 *2 (-634 (-953 *3))) (-4 *3 (-453)) (-5 *1 (-362 *3 *4)) (-14 *4 (-634 (-1161))))) (-1560 (*1 *2 *2) (|partial| -12 (-5 *2 (-634 (-953 *3))) (-4 *3 (-453)) (-5 *1 (-362 *3 *4)) (-14 *4 (-634 (-1161))))) (-3624 (*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-453)) (-5 *2 (-121)) (-5 *1 (-362 *4 *5)) (-14 *5 (-634 (-1161)))))) 
-(-10 -7 (-15 -3624 ((-121) (-634 (-953 |#1|)))) (-15 -1560 ((-3 (-634 (-953 |#1|)) "failed") (-634 (-953 |#1|)))) (-15 -2715 ((-634 (-953 |#1|)) (-634 (-953 |#1|))))) 
-((-2447 (((-121) $ $) NIL)) (-3983 (((-763) $) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) NIL)) (-2854 ((|#1| $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-2735 (((-121) $) 14)) (-2882 ((|#1| $ (-568)) NIL)) (-2408 (((-568) $ (-568)) NIL)) (-2096 (($ (-1 |#1| |#1|) $) 32)) (-2505 (($ (-1 (-568) (-568)) $) 24)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) 26)) (-4022 (((-1108) $) NIL)) (-3276 (((-634 (-2 (|:| |gen| |#1|) (|:| -1892 (-568)))) $) 28)) (-1458 (($ $ $) NIL)) (-2353 (($ $ $) NIL)) (-2745 (((-850) $) 38) (($ |#1|) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-1556 (($) 9 T CONST)) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL) (($ |#1| (-568)) 17)) (* (($ $ $) 43) (($ |#1| $) 21) (($ $ |#1|) 19))) 
-(((-363 |#1|) (-13 (-478) (-1037 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-568))) (-15 -3983 ((-763) $)) (-15 -2408 ((-568) $ (-568))) (-15 -2882 (|#1| $ (-568))) (-15 -2505 ($ (-1 (-568) (-568)) $)) (-15 -2096 ($ (-1 |#1| |#1|) $)) (-15 -3276 ((-634 (-2 (|:| |gen| |#1|) (|:| -1892 (-568)))) $)))) (-1090)) (T -363)) 
-((* (*1 *1 *2 *1) (-12 (-5 *1 (-363 *2)) (-4 *2 (-1090)))) (* (*1 *1 *1 *2) (-12 (-5 *1 (-363 *2)) (-4 *2 (-1090)))) (** (*1 *1 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-363 *2)) (-4 *2 (-1090)))) (-3983 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-363 *3)) (-4 *3 (-1090)))) (-2408 (*1 *2 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-363 *3)) (-4 *3 (-1090)))) (-2882 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-363 *2)) (-4 *2 (-1090)))) (-2505 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-568) (-568))) (-5 *1 (-363 *3)) (-4 *3 (-1090)))) (-2096 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-363 *3)))) (-3276 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1892 (-568))))) (-5 *1 (-363 *3)) (-4 *3 (-1090))))) 
-(-13 (-478) (-1037 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-568))) (-15 -3983 ((-763) $)) (-15 -2408 ((-568) $ (-568))) (-15 -2882 (|#1| $ (-568))) (-15 -2505 ($ (-1 (-568) (-568)) $)) (-15 -2096 ($ (-1 |#1| |#1|) $)) (-15 -3276 ((-634 (-2 (|:| |gen| |#1|) (|:| -1892 (-568)))) $)))) 
-((-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 13)) (-2227 (($ $) 14)) (-1678 (((-420 $) $) 29)) (-3927 (((-121) $) 25)) (-2081 (($ $) 18)) (-2721 (($ $ $) 22) (($ (-634 $)) NIL)) (-3848 (((-420 $) $) 30)) (-2595 (((-3 $ "failed") $ $) 21)) (-2709 (((-763) $) 24)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 34)) (-1826 (((-121) $ $) 15)) (-1779 (($ $ $) 32))) 
-(((-364 |#1|) (-10 -8 (-15 -1779 (|#1| |#1| |#1|)) (-15 -2081 (|#1| |#1|)) (-15 -3927 ((-121) |#1|)) (-15 -1678 ((-420 |#1|) |#1|)) (-15 -3848 ((-420 |#1|) |#1|)) (-15 -3210 ((-2 (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1|)) (-15 -2709 ((-763) |#1|)) (-15 -2721 (|#1| (-634 |#1|))) (-15 -2721 (|#1| |#1| |#1|)) (-15 -1826 ((-121) |#1| |#1|)) (-15 -2227 (|#1| |#1|)) (-15 -3712 ((-2 (|:| -2295 |#1|) (|:| -4506 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -2595 ((-3 |#1| "failed") |#1| |#1|))) (-365)) (T -364)) 
-NIL 
-(-10 -8 (-15 -1779 (|#1| |#1| |#1|)) (-15 -2081 (|#1| |#1|)) (-15 -3927 ((-121) |#1|)) (-15 -1678 ((-420 |#1|) |#1|)) (-15 -3848 ((-420 |#1|) |#1|)) (-15 -3210 ((-2 (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1|)) (-15 -2709 ((-763) |#1|)) (-15 -2721 (|#1| (-634 |#1|))) (-15 -2721 (|#1| |#1| |#1|)) (-15 -1826 ((-121) |#1| |#1|)) (-15 -2227 (|#1| |#1|)) (-15 -3712 ((-2 (|:| -2295 |#1|) (|:| -4506 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -2595 ((-3 |#1| "failed") |#1| |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-3134 (((-3 $ "failed") $ $) 18)) (-4305 (($ $) 71)) (-1678 (((-420 $) $) 70)) (-1497 (((-121) $ $) 57)) (-2671 (($) 16 T CONST)) (-2401 (($ $ $) 53)) (-2925 (((-3 $ "failed") $) 33)) (-2412 (($ $ $) 54)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 49)) (-3927 (((-121) $) 69)) (-2735 (((-121) $) 30)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-2081 (($ $) 68)) (-4022 (((-1108) $) 10)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-3848 (((-420 $) $) 72)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2595 (((-3 $ "failed") $ $) 41)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-2709 (((-763) $) 56)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 55)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63)) (-4078 (((-763)) 28)) (-1826 (((-121) $ $) 38)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1779 (($ $ $) 62)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64))) 
+((-3106 (((-121) (-634 (-953 |#1|))) 31)) (-1506 (((-634 (-953 |#1|)) (-634 (-953 |#1|))) 42)) (-4358 (((-3 (-634 (-953 |#1|)) "failed") (-634 (-953 |#1|))) 38))) 
+(((-362 |#1| |#2|) (-10 -7 (-15 -3106 ((-121) (-634 (-953 |#1|)))) (-15 -4358 ((-3 (-634 (-953 |#1|)) "failed") (-634 (-953 |#1|)))) (-15 -1506 ((-634 (-953 |#1|)) (-634 (-953 |#1|))))) (-453) (-634 (-1161))) (T -362)) 
+((-1506 (*1 *2 *2) (-12 (-5 *2 (-634 (-953 *3))) (-4 *3 (-453)) (-5 *1 (-362 *3 *4)) (-14 *4 (-634 (-1161))))) (-4358 (*1 *2 *2) (|partial| -12 (-5 *2 (-634 (-953 *3))) (-4 *3 (-453)) (-5 *1 (-362 *3 *4)) (-14 *4 (-634 (-1161))))) (-3106 (*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-453)) (-5 *2 (-121)) (-5 *1 (-362 *4 *5)) (-14 *5 (-634 (-1161)))))) 
+(-10 -7 (-15 -3106 ((-121) (-634 (-953 |#1|)))) (-15 -4358 ((-3 (-634 (-953 |#1|)) "failed") (-634 (-953 |#1|)))) (-15 -1506 ((-634 (-953 |#1|)) (-634 (-953 |#1|))))) 
+((-2449 (((-121) $ $) NIL)) (-3986 (((-763) $) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) NIL)) (-2857 ((|#1| $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1598 (((-121) $) 14)) (-4167 ((|#1| $ (-568)) NIL)) (-2315 (((-568) $ (-568)) NIL)) (-3177 (($ (-1 |#1| |#1|) $) 32)) (-1644 (($ (-1 (-568) (-568)) $) 24)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) 26)) (-4025 (((-1108) $) NIL)) (-2075 (((-634 (-2 (|:| |gen| |#1|) (|:| -1894 (-568)))) $) 28)) (-2387 (($ $ $) NIL)) (-3985 (($ $ $) NIL)) (-2747 (((-850) $) 38) (($ |#1|) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-1557 (($) 9 T CONST)) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL) (($ |#1| (-568)) 17)) (* (($ $ $) 43) (($ |#1| $) 21) (($ $ |#1|) 19))) 
+(((-363 |#1|) (-13 (-478) (-1037 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-568))) (-15 -3986 ((-763) $)) (-15 -2315 ((-568) $ (-568))) (-15 -4167 (|#1| $ (-568))) (-15 -1644 ($ (-1 (-568) (-568)) $)) (-15 -3177 ($ (-1 |#1| |#1|) $)) (-15 -2075 ((-634 (-2 (|:| |gen| |#1|) (|:| -1894 (-568)))) $)))) (-1090)) (T -363)) 
+((* (*1 *1 *2 *1) (-12 (-5 *1 (-363 *2)) (-4 *2 (-1090)))) (* (*1 *1 *1 *2) (-12 (-5 *1 (-363 *2)) (-4 *2 (-1090)))) (** (*1 *1 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-363 *2)) (-4 *2 (-1090)))) (-3986 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-363 *3)) (-4 *3 (-1090)))) (-2315 (*1 *2 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-363 *3)) (-4 *3 (-1090)))) (-4167 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-363 *2)) (-4 *2 (-1090)))) (-1644 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-568) (-568))) (-5 *1 (-363 *3)) (-4 *3 (-1090)))) (-3177 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-363 *3)))) (-2075 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1894 (-568))))) (-5 *1 (-363 *3)) (-4 *3 (-1090))))) 
+(-13 (-478) (-1037 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-568))) (-15 -3986 ((-763) $)) (-15 -2315 ((-568) $ (-568))) (-15 -4167 (|#1| $ (-568))) (-15 -1644 ($ (-1 (-568) (-568)) $)) (-15 -3177 ($ (-1 |#1| |#1|) $)) (-15 -2075 ((-634 (-2 (|:| |gen| |#1|) (|:| -1894 (-568)))) $)))) 
+((-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 13)) (-3661 (($ $) 14)) (-3498 (((-420 $) $) 29)) (-2197 (((-121) $) 25)) (-2083 (($ $) 18)) (-2723 (($ $ $) 22) (($ (-634 $)) NIL)) (-3850 (((-420 $) $) 30)) (-2597 (((-3 $ "failed") $ $) 21)) (-1466 (((-763) $) 24)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 34)) (-2273 (((-121) $ $) 15)) (-1781 (($ $ $) 32))) 
+(((-364 |#1|) (-10 -8 (-15 -1781 (|#1| |#1| |#1|)) (-15 -2083 (|#1| |#1|)) (-15 -2197 ((-121) |#1|)) (-15 -3498 ((-420 |#1|) |#1|)) (-15 -3850 ((-420 |#1|) |#1|)) (-15 -1854 ((-2 (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1|)) (-15 -1466 ((-763) |#1|)) (-15 -2723 (|#1| (-634 |#1|))) (-15 -2723 (|#1| |#1| |#1|)) (-15 -2273 ((-121) |#1| |#1|)) (-15 -3661 (|#1| |#1|)) (-15 -2431 ((-2 (|:| -3591 |#1|) (|:| -4508 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -2597 ((-3 |#1| "failed") |#1| |#1|))) (-365)) (T -364)) 
+NIL 
+(-10 -8 (-15 -1781 (|#1| |#1| |#1|)) (-15 -2083 (|#1| |#1|)) (-15 -2197 ((-121) |#1|)) (-15 -3498 ((-420 |#1|) |#1|)) (-15 -3850 ((-420 |#1|) |#1|)) (-15 -1854 ((-2 (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1|)) (-15 -1466 ((-763) |#1|)) (-15 -2723 (|#1| (-634 |#1|))) (-15 -2723 (|#1| |#1| |#1|)) (-15 -2273 ((-121) |#1| |#1|)) (-15 -3661 (|#1| |#1|)) (-15 -2431 ((-2 (|:| -3591 |#1|) (|:| -4508 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -2597 ((-3 |#1| "failed") |#1| |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-2689 (((-3 $ "failed") $ $) 18)) (-3045 (($ $) 71)) (-3498 (((-420 $) $) 70)) (-2589 (((-121) $ $) 57)) (-4490 (($) 16 T CONST)) (-2403 (($ $ $) 53)) (-2902 (((-3 $ "failed") $) 33)) (-2414 (($ $ $) 54)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 49)) (-2197 (((-121) $) 69)) (-1598 (((-121) $) 30)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-2083 (($ $) 68)) (-4025 (((-1108) $) 10)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-3850 (((-420 $) $) 72)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2597 (((-3 $ "failed") $ $) 41)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-1466 (((-763) $) 56)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 55)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63)) (-3425 (((-763)) 28)) (-2273 (((-121) $ $) 38)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1781 (($ $ $) 62)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64))) 
 (((-365) (-1275)) (T -365)) 
-((-1779 (*1 *1 *1 *1) (-4 *1 (-365)))) 
-(-13 (-301) (-1199) (-238) (-10 -8 (-15 -1779 ($ $ $)) (-6 -4517) (-6 -4511))) 
+((-1781 (*1 *1 *1 *1) (-4 *1 (-365)))) 
+(-13 (-301) (-1199) (-238) (-10 -8 (-15 -1781 ($ $ $)) (-6 -4519) (-6 -4513))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 $ $) . T) ((-137) . T) ((-608 (-850)) . T) ((-172) . T) ((-238) . T) ((-285) . T) ((-301) . T) ((-453) . T) ((-558) . T) ((-637 (-409 (-568))) . T) ((-637 $) . T) ((-707 (-409 (-568))) . T) ((-707 $) . T) ((-716) . T) ((-916) . T) ((-1053 (-409 (-568))) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1199) . T)) 
-((-2447 (((-121) $ $) 7)) (-1705 ((|#2| $ |#2|) 13)) (-2511 (($ $ (-1143)) 18)) (-3327 ((|#2| $) 14)) (-1798 (($ |#1|) 20) (($ |#1| (-1143)) 19)) (-3391 ((|#1| $) 16)) (-4487 (((-1143) $) 9)) (-3305 (((-1143) $) 15)) (-4022 (((-1108) $) 10)) (-4169 (((-1249) $) 12)) (-2745 (((-850) $) 11)) (-3637 (($ $) 17)) (-1717 (((-121) $ $) 6))) 
+((-2449 (((-121) $ $) 7)) (-3637 ((|#2| $ |#2|) 13)) (-1672 (($ $ (-1143)) 18)) (-4379 ((|#2| $) 14)) (-2133 (($ |#1|) 20) (($ |#1| (-1143)) 19)) (-3393 ((|#1| $) 16)) (-1893 (((-1143) $) 9)) (-4249 (((-1143) $) 15)) (-4025 (((-1108) $) 10)) (-3919 (((-1249) $) 12)) (-2747 (((-850) $) 11)) (-3171 (($ $) 17)) (-1719 (((-121) $ $) 6))) 
 (((-366 |#1| |#2|) (-1275) (-1090) (-1090)) (T -366)) 
-((-1798 (*1 *1 *2) (-12 (-4 *1 (-366 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090)))) (-1798 (*1 *1 *2 *3) (-12 (-5 *3 (-1143)) (-4 *1 (-366 *2 *4)) (-4 *2 (-1090)) (-4 *4 (-1090)))) (-2511 (*1 *1 *1 *2) (-12 (-5 *2 (-1143)) (-4 *1 (-366 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)))) (-3637 (*1 *1 *1) (-12 (-4 *1 (-366 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090)))) (-3391 (*1 *2 *1) (-12 (-4 *1 (-366 *2 *3)) (-4 *3 (-1090)) (-4 *2 (-1090)))) (-3305 (*1 *2 *1) (-12 (-4 *1 (-366 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-5 *2 (-1143)))) (-3327 (*1 *2 *1) (-12 (-4 *1 (-366 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090)))) (-1705 (*1 *2 *1 *2) (-12 (-4 *1 (-366 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090)))) (-4169 (*1 *2 *1) (-12 (-4 *1 (-366 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-5 *2 (-1249))))) 
-(-13 (-1090) (-10 -8 (-15 -1798 ($ |t#1|)) (-15 -1798 ($ |t#1| (-1143))) (-15 -2511 ($ $ (-1143))) (-15 -3637 ($ $)) (-15 -3391 (|t#1| $)) (-15 -3305 ((-1143) $)) (-15 -3327 (|t#2| $)) (-15 -1705 (|t#2| $ |t#2|)) (-15 -4169 ((-1249) $)))) 
+((-2133 (*1 *1 *2) (-12 (-4 *1 (-366 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090)))) (-2133 (*1 *1 *2 *3) (-12 (-5 *3 (-1143)) (-4 *1 (-366 *2 *4)) (-4 *2 (-1090)) (-4 *4 (-1090)))) (-1672 (*1 *1 *1 *2) (-12 (-5 *2 (-1143)) (-4 *1 (-366 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)))) (-3171 (*1 *1 *1) (-12 (-4 *1 (-366 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090)))) (-3393 (*1 *2 *1) (-12 (-4 *1 (-366 *2 *3)) (-4 *3 (-1090)) (-4 *2 (-1090)))) (-4249 (*1 *2 *1) (-12 (-4 *1 (-366 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-5 *2 (-1143)))) (-4379 (*1 *2 *1) (-12 (-4 *1 (-366 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090)))) (-3637 (*1 *2 *1 *2) (-12 (-4 *1 (-366 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090)))) (-3919 (*1 *2 *1) (-12 (-4 *1 (-366 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-5 *2 (-1249))))) 
+(-13 (-1090) (-10 -8 (-15 -2133 ($ |t#1|)) (-15 -2133 ($ |t#1| (-1143))) (-15 -1672 ($ $ (-1143))) (-15 -3171 ($ $)) (-15 -3393 (|t#1| $)) (-15 -4249 ((-1143) $)) (-15 -4379 (|t#2| $)) (-15 -3637 (|t#2| $ |t#2|)) (-15 -3919 ((-1249) $)))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-1705 ((|#1| $ |#1|) 29)) (-2511 (($ $ (-1143)) 22)) (-3861 (((-3 |#1| "failed") $) 28)) (-3327 ((|#1| $) 26)) (-1798 (($ (-390)) 21) (($ (-390) (-1143)) 20)) (-3391 (((-390) $) 24)) (-4487 (((-1143) $) NIL)) (-3305 (((-1143) $) 25)) (-4022 (((-1108) $) NIL)) (-4169 (((-1249) $) 31)) (-2745 (((-850) $) 19)) (-3637 (($ $) 23)) (-1717 (((-121) $ $) 18))) 
-(((-367 |#1|) (-13 (-366 (-390) |#1|) (-10 -8 (-15 -3861 ((-3 |#1| "failed") $)))) (-1090)) (T -367)) 
-((-3861 (*1 *2 *1) (|partial| -12 (-5 *1 (-367 *2)) (-4 *2 (-1090))))) 
-(-13 (-366 (-390) |#1|) (-10 -8 (-15 -3861 ((-3 |#1| "failed") $)))) 
-((-2776 (((-1244 (-679 |#2|)) (-1244 $)) 62)) (-1631 (((-679 |#2|) (-1244 $)) 120)) (-1866 ((|#2| $) 32)) (-3042 (((-679 |#2|) $ (-1244 $)) 124)) (-3550 (((-3 $ "failed") $) 76)) (-4409 ((|#2| $) 35)) (-1371 (((-1157 |#2|) $) 84)) (-3569 ((|#2| (-1244 $)) 107)) (-2989 (((-1157 |#2|) $) 28)) (-3384 (((-121)) 101)) (-3498 (($ (-1244 |#2|) (-1244 $)) 114)) (-2925 (((-3 $ "failed") $) 80)) (-1537 (((-121)) 96)) (-1580 (((-121)) 91)) (-1695 (((-121)) 54)) (-4210 (((-679 |#2|) (-1244 $)) 118)) (-2889 ((|#2| $) 31)) (-4333 (((-679 |#2|) $ (-1244 $)) 123)) (-3243 (((-3 $ "failed") $) 74)) (-3329 ((|#2| $) 34)) (-2265 (((-1157 |#2|) $) 83)) (-3898 ((|#2| (-1244 $)) 105)) (-3626 (((-1157 |#2|) $) 26)) (-2767 (((-121)) 100)) (-1804 (((-121)) 93)) (-2919 (((-121)) 52)) (-3840 (((-121)) 88)) (-1346 (((-121)) 102)) (-4073 (((-1244 |#2|) $ (-1244 $)) NIL) (((-679 |#2|) (-1244 $) (-1244 $)) 112)) (-3433 (((-121)) 98)) (-1509 (((-634 (-1244 |#2|))) 87)) (-4177 (((-121)) 99)) (-2433 (((-121)) 97)) (-2189 (((-121)) 46)) (-4107 (((-121)) 103))) 
-(((-368 |#1| |#2|) (-10 -8 (-15 -1371 ((-1157 |#2|) |#1|)) (-15 -2265 ((-1157 |#2|) |#1|)) (-15 -1509 ((-634 (-1244 |#2|)))) (-15 -3550 ((-3 |#1| "failed") |#1|)) (-15 -3243 ((-3 |#1| "failed") |#1|)) (-15 -2925 ((-3 |#1| "failed") |#1|)) (-15 -1580 ((-121))) (-15 -1804 ((-121))) (-15 -1537 ((-121))) (-15 -2919 ((-121))) (-15 -1695 ((-121))) (-15 -3840 ((-121))) (-15 -4107 ((-121))) (-15 -1346 ((-121))) (-15 -3384 ((-121))) (-15 -2767 ((-121))) (-15 -2189 ((-121))) (-15 -4177 ((-121))) (-15 -2433 ((-121))) (-15 -3433 ((-121))) (-15 -2989 ((-1157 |#2|) |#1|)) (-15 -3626 ((-1157 |#2|) |#1|)) (-15 -1631 ((-679 |#2|) (-1244 |#1|))) (-15 -4210 ((-679 |#2|) (-1244 |#1|))) (-15 -3569 (|#2| (-1244 |#1|))) (-15 -3898 (|#2| (-1244 |#1|))) (-15 -3498 (|#1| (-1244 |#2|) (-1244 |#1|))) (-15 -4073 ((-679 |#2|) (-1244 |#1|) (-1244 |#1|))) (-15 -4073 ((-1244 |#2|) |#1| (-1244 |#1|))) (-15 -4409 (|#2| |#1|)) (-15 -3329 (|#2| |#1|)) (-15 -1866 (|#2| |#1|)) (-15 -2889 (|#2| |#1|)) (-15 -3042 ((-679 |#2|) |#1| (-1244 |#1|))) (-15 -4333 ((-679 |#2|) |#1| (-1244 |#1|))) (-15 -2776 ((-1244 (-679 |#2|)) (-1244 |#1|)))) (-369 |#2|) (-172)) (T -368)) 
-((-3433 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-2433 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-4177 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-2189 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-2767 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-3384 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-1346 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-4107 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-3840 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-1695 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-2919 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-1537 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-1804 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-1580 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-1509 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-634 (-1244 *4))) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4))))) 
-(-10 -8 (-15 -1371 ((-1157 |#2|) |#1|)) (-15 -2265 ((-1157 |#2|) |#1|)) (-15 -1509 ((-634 (-1244 |#2|)))) (-15 -3550 ((-3 |#1| "failed") |#1|)) (-15 -3243 ((-3 |#1| "failed") |#1|)) (-15 -2925 ((-3 |#1| "failed") |#1|)) (-15 -1580 ((-121))) (-15 -1804 ((-121))) (-15 -1537 ((-121))) (-15 -2919 ((-121))) (-15 -1695 ((-121))) (-15 -3840 ((-121))) (-15 -4107 ((-121))) (-15 -1346 ((-121))) (-15 -3384 ((-121))) (-15 -2767 ((-121))) (-15 -2189 ((-121))) (-15 -4177 ((-121))) (-15 -2433 ((-121))) (-15 -3433 ((-121))) (-15 -2989 ((-1157 |#2|) |#1|)) (-15 -3626 ((-1157 |#2|) |#1|)) (-15 -1631 ((-679 |#2|) (-1244 |#1|))) (-15 -4210 ((-679 |#2|) (-1244 |#1|))) (-15 -3569 (|#2| (-1244 |#1|))) (-15 -3898 (|#2| (-1244 |#1|))) (-15 -3498 (|#1| (-1244 |#2|) (-1244 |#1|))) (-15 -4073 ((-679 |#2|) (-1244 |#1|) (-1244 |#1|))) (-15 -4073 ((-1244 |#2|) |#1| (-1244 |#1|))) (-15 -4409 (|#2| |#1|)) (-15 -3329 (|#2| |#1|)) (-15 -1866 (|#2| |#1|)) (-15 -2889 (|#2| |#1|)) (-15 -3042 ((-679 |#2|) |#1| (-1244 |#1|))) (-15 -4333 ((-679 |#2|) |#1| (-1244 |#1|))) (-15 -2776 ((-1244 (-679 |#2|)) (-1244 |#1|)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-2295 (((-3 $ "failed")) 35 (|has| |#1| (-558)))) (-3134 (((-3 $ "failed") $ $) 18)) (-2776 (((-1244 (-679 |#1|)) (-1244 $)) 76)) (-1741 (((-1244 $)) 79)) (-2671 (($) 16 T CONST)) (-1309 (((-3 (-2 (|:| |particular| $) (|:| -3746 (-634 $))) "failed")) 38 (|has| |#1| (-558)))) (-2593 (((-3 $ "failed")) 36 (|has| |#1| (-558)))) (-1631 (((-679 |#1|) (-1244 $)) 63)) (-1866 ((|#1| $) 72)) (-3042 (((-679 |#1|) $ (-1244 $)) 74)) (-3550 (((-3 $ "failed") $) 43 (|has| |#1| (-558)))) (-3551 (($ $ (-917)) 27)) (-4409 ((|#1| $) 70)) (-1371 (((-1157 |#1|) $) 40 (|has| |#1| (-558)))) (-3569 ((|#1| (-1244 $)) 65)) (-2989 (((-1157 |#1|) $) 61)) (-3384 (((-121)) 55)) (-3498 (($ (-1244 |#1|) (-1244 $)) 67)) (-2925 (((-3 $ "failed") $) 45 (|has| |#1| (-558)))) (-3700 (((-917)) 78)) (-4370 (((-121)) 52)) (-4373 (($ $ (-917)) 32)) (-1537 (((-121)) 48)) (-1580 (((-121)) 46)) (-1695 (((-121)) 50)) (-3116 (((-3 (-2 (|:| |particular| $) (|:| -3746 (-634 $))) "failed")) 39 (|has| |#1| (-558)))) (-2599 (((-3 $ "failed")) 37 (|has| |#1| (-558)))) (-4210 (((-679 |#1|) (-1244 $)) 64)) (-2889 ((|#1| $) 73)) (-4333 (((-679 |#1|) $ (-1244 $)) 75)) (-3243 (((-3 $ "failed") $) 44 (|has| |#1| (-558)))) (-4222 (($ $ (-917)) 28)) (-3329 ((|#1| $) 71)) (-2265 (((-1157 |#1|) $) 41 (|has| |#1| (-558)))) (-3898 ((|#1| (-1244 $)) 66)) (-3626 (((-1157 |#1|) $) 62)) (-2767 (((-121)) 56)) (-4487 (((-1143) $) 9)) (-1804 (((-121)) 47)) (-2919 (((-121)) 49)) (-3840 (((-121)) 51)) (-4022 (((-1108) $) 10)) (-1346 (((-121)) 54)) (-4073 (((-1244 |#1|) $ (-1244 $)) 69) (((-679 |#1|) (-1244 $) (-1244 $)) 68)) (-3295 (((-634 (-953 |#1|)) (-1244 $)) 77)) (-2353 (($ $ $) 24)) (-3433 (((-121)) 60)) (-2745 (((-850) $) 11)) (-1509 (((-634 (-1244 |#1|))) 42 (|has| |#1| (-558)))) (-3882 (($ $ $ $) 25)) (-4177 (((-121)) 58)) (-3500 (($ $ $) 23)) (-2433 (((-121)) 59)) (-2189 (((-121)) 57)) (-4107 (((-121)) 53)) (-3056 (($) 17 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 29)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 26) (($ $ |#1|) 34) (($ |#1| $) 33))) 
+((-2449 (((-121) $ $) NIL)) (-3637 ((|#1| $ |#1|) 29)) (-1672 (($ $ (-1143)) 22)) (-1933 (((-3 |#1| "failed") $) 28)) (-4379 ((|#1| $) 26)) (-2133 (($ (-390)) 21) (($ (-390) (-1143)) 20)) (-3393 (((-390) $) 24)) (-1893 (((-1143) $) NIL)) (-4249 (((-1143) $) 25)) (-4025 (((-1108) $) NIL)) (-3919 (((-1249) $) 31)) (-2747 (((-850) $) 19)) (-3171 (($ $) 23)) (-1719 (((-121) $ $) 18))) 
+(((-367 |#1|) (-13 (-366 (-390) |#1|) (-10 -8 (-15 -1933 ((-3 |#1| "failed") $)))) (-1090)) (T -367)) 
+((-1933 (*1 *2 *1) (|partial| -12 (-5 *1 (-367 *2)) (-4 *2 (-1090))))) 
+(-13 (-366 (-390) |#1|) (-10 -8 (-15 -1933 ((-3 |#1| "failed") $)))) 
+((-3542 (((-1244 (-679 |#2|)) (-1244 $)) 62)) (-1524 (((-679 |#2|) (-1244 $)) 120)) (-2467 ((|#2| $) 32)) (-2235 (((-679 |#2|) $ (-1244 $)) 124)) (-2812 (((-3 $ "failed") $) 76)) (-1509 ((|#2| $) 35)) (-3839 (((-1157 |#2|) $) 84)) (-2886 ((|#2| (-1244 $)) 107)) (-3105 (((-1157 |#2|) $) 28)) (-1463 (((-121)) 101)) (-3899 (($ (-1244 |#2|) (-1244 $)) 114)) (-2902 (((-3 $ "failed") $) 80)) (-4221 (((-121)) 96)) (-4463 (((-121)) 91)) (-3582 (((-121)) 54)) (-4134 (((-679 |#2|) (-1244 $)) 118)) (-2786 ((|#2| $) 31)) (-3147 (((-679 |#2|) $ (-1244 $)) 123)) (-1974 (((-3 $ "failed") $) 74)) (-4390 ((|#2| $) 34)) (-3364 (((-1157 |#2|) $) 83)) (-2060 ((|#2| (-1244 $)) 105)) (-3114 (((-1157 |#2|) $) 26)) (-3487 (((-121)) 100)) (-2153 (((-121)) 93)) (-2889 (((-121)) 52)) (-1852 (((-121)) 88)) (-3636 (((-121)) 102)) (-1656 (((-1244 |#2|) $ (-1244 $)) NIL) (((-679 |#2|) (-1244 $) (-1244 $)) 112)) (-3441 (((-121)) 98)) (-2657 (((-634 (-1244 |#2|))) 87)) (-3964 (((-121)) 99)) (-2435 (((-121)) 97)) (-2984 (((-121)) 46)) (-3579 (((-121)) 103))) 
+(((-368 |#1| |#2|) (-10 -8 (-15 -3839 ((-1157 |#2|) |#1|)) (-15 -3364 ((-1157 |#2|) |#1|)) (-15 -2657 ((-634 (-1244 |#2|)))) (-15 -2812 ((-3 |#1| "failed") |#1|)) (-15 -1974 ((-3 |#1| "failed") |#1|)) (-15 -2902 ((-3 |#1| "failed") |#1|)) (-15 -4463 ((-121))) (-15 -2153 ((-121))) (-15 -4221 ((-121))) (-15 -2889 ((-121))) (-15 -3582 ((-121))) (-15 -1852 ((-121))) (-15 -3579 ((-121))) (-15 -3636 ((-121))) (-15 -1463 ((-121))) (-15 -3487 ((-121))) (-15 -2984 ((-121))) (-15 -3964 ((-121))) (-15 -2435 ((-121))) (-15 -3441 ((-121))) (-15 -3105 ((-1157 |#2|) |#1|)) (-15 -3114 ((-1157 |#2|) |#1|)) (-15 -1524 ((-679 |#2|) (-1244 |#1|))) (-15 -4134 ((-679 |#2|) (-1244 |#1|))) (-15 -2886 (|#2| (-1244 |#1|))) (-15 -2060 (|#2| (-1244 |#1|))) (-15 -3899 (|#1| (-1244 |#2|) (-1244 |#1|))) (-15 -1656 ((-679 |#2|) (-1244 |#1|) (-1244 |#1|))) (-15 -1656 ((-1244 |#2|) |#1| (-1244 |#1|))) (-15 -1509 (|#2| |#1|)) (-15 -4390 (|#2| |#1|)) (-15 -2467 (|#2| |#1|)) (-15 -2786 (|#2| |#1|)) (-15 -2235 ((-679 |#2|) |#1| (-1244 |#1|))) (-15 -3147 ((-679 |#2|) |#1| (-1244 |#1|))) (-15 -3542 ((-1244 (-679 |#2|)) (-1244 |#1|)))) (-369 |#2|) (-172)) (T -368)) 
+((-3441 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-2435 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-3964 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-2984 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-3487 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-1463 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-3636 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-3579 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-1852 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-3582 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-2889 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-4221 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-2153 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-4463 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) (-2657 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-634 (-1244 *4))) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4))))) 
+(-10 -8 (-15 -3839 ((-1157 |#2|) |#1|)) (-15 -3364 ((-1157 |#2|) |#1|)) (-15 -2657 ((-634 (-1244 |#2|)))) (-15 -2812 ((-3 |#1| "failed") |#1|)) (-15 -1974 ((-3 |#1| "failed") |#1|)) (-15 -2902 ((-3 |#1| "failed") |#1|)) (-15 -4463 ((-121))) (-15 -2153 ((-121))) (-15 -4221 ((-121))) (-15 -2889 ((-121))) (-15 -3582 ((-121))) (-15 -1852 ((-121))) (-15 -3579 ((-121))) (-15 -3636 ((-121))) (-15 -1463 ((-121))) (-15 -3487 ((-121))) (-15 -2984 ((-121))) (-15 -3964 ((-121))) (-15 -2435 ((-121))) (-15 -3441 ((-121))) (-15 -3105 ((-1157 |#2|) |#1|)) (-15 -3114 ((-1157 |#2|) |#1|)) (-15 -1524 ((-679 |#2|) (-1244 |#1|))) (-15 -4134 ((-679 |#2|) (-1244 |#1|))) (-15 -2886 (|#2| (-1244 |#1|))) (-15 -2060 (|#2| (-1244 |#1|))) (-15 -3899 (|#1| (-1244 |#2|) (-1244 |#1|))) (-15 -1656 ((-679 |#2|) (-1244 |#1|) (-1244 |#1|))) (-15 -1656 ((-1244 |#2|) |#1| (-1244 |#1|))) (-15 -1509 (|#2| |#1|)) (-15 -4390 (|#2| |#1|)) (-15 -2467 (|#2| |#1|)) (-15 -2786 (|#2| |#1|)) (-15 -2235 ((-679 |#2|) |#1| (-1244 |#1|))) (-15 -3147 ((-679 |#2|) |#1| (-1244 |#1|))) (-15 -3542 ((-1244 (-679 |#2|)) (-1244 |#1|)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-3591 (((-3 $ "failed")) 35 (|has| |#1| (-558)))) (-2689 (((-3 $ "failed") $ $) 18)) (-3542 (((-1244 (-679 |#1|)) (-1244 $)) 76)) (-3818 (((-1244 $)) 79)) (-4490 (($) 16 T CONST)) (-3354 (((-3 (-2 (|:| |particular| $) (|:| -2588 (-634 $))) "failed")) 38 (|has| |#1| (-558)))) (-2046 (((-3 $ "failed")) 36 (|has| |#1| (-558)))) (-1524 (((-679 |#1|) (-1244 $)) 63)) (-2467 ((|#1| $) 72)) (-2235 (((-679 |#1|) $ (-1244 $)) 74)) (-2812 (((-3 $ "failed") $) 43 (|has| |#1| (-558)))) (-2815 (($ $ (-917)) 27)) (-1509 ((|#1| $) 70)) (-3839 (((-1157 |#1|) $) 40 (|has| |#1| (-558)))) (-2886 ((|#1| (-1244 $)) 65)) (-3105 (((-1157 |#1|) $) 61)) (-1463 (((-121)) 55)) (-3899 (($ (-1244 |#1|) (-1244 $)) 67)) (-2902 (((-3 $ "failed") $) 45 (|has| |#1| (-558)))) (-2371 (((-917)) 78)) (-3375 (((-121)) 52)) (-3402 (($ $ (-917)) 32)) (-4221 (((-121)) 48)) (-4463 (((-121)) 46)) (-3582 (((-121)) 50)) (-2587 (((-3 (-2 (|:| |particular| $) (|:| -2588 (-634 $))) "failed")) 39 (|has| |#1| (-558)))) (-2061 (((-3 $ "failed")) 37 (|has| |#1| (-558)))) (-4134 (((-679 |#1|) (-1244 $)) 64)) (-2786 ((|#1| $) 73)) (-3147 (((-679 |#1|) $ (-1244 $)) 75)) (-1974 (((-3 $ "failed") $) 44 (|has| |#1| (-558)))) (-4202 (($ $ (-917)) 28)) (-4390 ((|#1| $) 71)) (-3364 (((-1157 |#1|) $) 41 (|has| |#1| (-558)))) (-2060 ((|#1| (-1244 $)) 66)) (-3114 (((-1157 |#1|) $) 62)) (-3487 (((-121)) 56)) (-1893 (((-1143) $) 9)) (-2153 (((-121)) 47)) (-2889 (((-121)) 49)) (-1852 (((-121)) 51)) (-4025 (((-1108) $) 10)) (-3636 (((-121)) 54)) (-1656 (((-1244 |#1|) $ (-1244 $)) 69) (((-679 |#1|) (-1244 $) (-1244 $)) 68)) (-2155 (((-634 (-953 |#1|)) (-1244 $)) 77)) (-3985 (($ $ $) 24)) (-3441 (((-121)) 60)) (-2747 (((-850) $) 11)) (-2657 (((-634 (-1244 |#1|))) 42 (|has| |#1| (-558)))) (-2007 (($ $ $ $) 25)) (-3964 (((-121)) 58)) (-3911 (($ $ $) 23)) (-2435 (((-121)) 59)) (-2984 (((-121)) 57)) (-3579 (((-121)) 53)) (-3058 (($) 17 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 29)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 26) (($ $ |#1|) 34) (($ |#1| $) 33))) 
 (((-369 |#1|) (-1275) (-172)) (T -369)) 
-((-1741 (*1 *2) (-12 (-4 *3 (-172)) (-5 *2 (-1244 *1)) (-4 *1 (-369 *3)))) (-3700 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-917)))) (-3295 (*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-634 (-953 *4))))) (-2776 (*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-1244 (-679 *4))))) (-4333 (*1 *2 *1 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-679 *4)))) (-3042 (*1 *2 *1 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-679 *4)))) (-2889 (*1 *2 *1) (-12 (-4 *1 (-369 *2)) (-4 *2 (-172)))) (-1866 (*1 *2 *1) (-12 (-4 *1 (-369 *2)) (-4 *2 (-172)))) (-3329 (*1 *2 *1) (-12 (-4 *1 (-369 *2)) (-4 *2 (-172)))) (-4409 (*1 *2 *1) (-12 (-4 *1 (-369 *2)) (-4 *2 (-172)))) (-4073 (*1 *2 *1 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-1244 *4)))) (-4073 (*1 *2 *3 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-679 *4)))) (-3498 (*1 *1 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-1244 *1)) (-4 *4 (-172)) (-4 *1 (-369 *4)))) (-3898 (*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *2)) (-4 *2 (-172)))) (-3569 (*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *2)) (-4 *2 (-172)))) (-4210 (*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-679 *4)))) (-1631 (*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-679 *4)))) (-3626 (*1 *2 *1) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-1157 *3)))) (-2989 (*1 *2 *1) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-1157 *3)))) (-3433 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-2433 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-4177 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-2189 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-2767 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-3384 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-1346 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-4107 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-4370 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-3840 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-1695 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-2919 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-1537 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-1804 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-1580 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-2925 (*1 *1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-172)) (-4 *2 (-558)))) (-3243 (*1 *1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-172)) (-4 *2 (-558)))) (-3550 (*1 *1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-172)) (-4 *2 (-558)))) (-1509 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-4 *3 (-558)) (-5 *2 (-634 (-1244 *3))))) (-2265 (*1 *2 *1) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-4 *3 (-558)) (-5 *2 (-1157 *3)))) (-1371 (*1 *2 *1) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-4 *3 (-558)) (-5 *2 (-1157 *3)))) (-3116 (*1 *2) (|partial| -12 (-4 *3 (-558)) (-4 *3 (-172)) (-5 *2 (-2 (|:| |particular| *1) (|:| -3746 (-634 *1)))) (-4 *1 (-369 *3)))) (-1309 (*1 *2) (|partial| -12 (-4 *3 (-558)) (-4 *3 (-172)) (-5 *2 (-2 (|:| |particular| *1) (|:| -3746 (-634 *1)))) (-4 *1 (-369 *3)))) (-2599 (*1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-558)) (-4 *2 (-172)))) (-2593 (*1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-558)) (-4 *2 (-172)))) (-2295 (*1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-558)) (-4 *2 (-172))))) 
-(-13 (-736 |t#1|) (-10 -8 (-15 -1741 ((-1244 $))) (-15 -3700 ((-917))) (-15 -3295 ((-634 (-953 |t#1|)) (-1244 $))) (-15 -2776 ((-1244 (-679 |t#1|)) (-1244 $))) (-15 -4333 ((-679 |t#1|) $ (-1244 $))) (-15 -3042 ((-679 |t#1|) $ (-1244 $))) (-15 -2889 (|t#1| $)) (-15 -1866 (|t#1| $)) (-15 -3329 (|t#1| $)) (-15 -4409 (|t#1| $)) (-15 -4073 ((-1244 |t#1|) $ (-1244 $))) (-15 -4073 ((-679 |t#1|) (-1244 $) (-1244 $))) (-15 -3498 ($ (-1244 |t#1|) (-1244 $))) (-15 -3898 (|t#1| (-1244 $))) (-15 -3569 (|t#1| (-1244 $))) (-15 -4210 ((-679 |t#1|) (-1244 $))) (-15 -1631 ((-679 |t#1|) (-1244 $))) (-15 -3626 ((-1157 |t#1|) $)) (-15 -2989 ((-1157 |t#1|) $)) (-15 -3433 ((-121))) (-15 -2433 ((-121))) (-15 -4177 ((-121))) (-15 -2189 ((-121))) (-15 -2767 ((-121))) (-15 -3384 ((-121))) (-15 -1346 ((-121))) (-15 -4107 ((-121))) (-15 -4370 ((-121))) (-15 -3840 ((-121))) (-15 -1695 ((-121))) (-15 -2919 ((-121))) (-15 -1537 ((-121))) (-15 -1804 ((-121))) (-15 -1580 ((-121))) (IF (|has| |t#1| (-558)) (PROGN (-15 -2925 ((-3 $ "failed") $)) (-15 -3243 ((-3 $ "failed") $)) (-15 -3550 ((-3 $ "failed") $)) (-15 -1509 ((-634 (-1244 |t#1|)))) (-15 -2265 ((-1157 |t#1|) $)) (-15 -1371 ((-1157 |t#1|) $)) (-15 -3116 ((-3 (-2 (|:| |particular| $) (|:| -3746 (-634 $))) "failed"))) (-15 -1309 ((-3 (-2 (|:| |particular| $) (|:| -3746 (-634 $))) "failed"))) (-15 -2599 ((-3 $ "failed"))) (-15 -2593 ((-3 $ "failed"))) (-15 -2295 ((-3 $ "failed"))) (-6 -4516)) |noBranch|))) 
+((-3818 (*1 *2) (-12 (-4 *3 (-172)) (-5 *2 (-1244 *1)) (-4 *1 (-369 *3)))) (-2371 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-917)))) (-2155 (*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-634 (-953 *4))))) (-3542 (*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-1244 (-679 *4))))) (-3147 (*1 *2 *1 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-679 *4)))) (-2235 (*1 *2 *1 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-679 *4)))) (-2786 (*1 *2 *1) (-12 (-4 *1 (-369 *2)) (-4 *2 (-172)))) (-2467 (*1 *2 *1) (-12 (-4 *1 (-369 *2)) (-4 *2 (-172)))) (-4390 (*1 *2 *1) (-12 (-4 *1 (-369 *2)) (-4 *2 (-172)))) (-1509 (*1 *2 *1) (-12 (-4 *1 (-369 *2)) (-4 *2 (-172)))) (-1656 (*1 *2 *1 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-1244 *4)))) (-1656 (*1 *2 *3 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-679 *4)))) (-3899 (*1 *1 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-1244 *1)) (-4 *4 (-172)) (-4 *1 (-369 *4)))) (-2060 (*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *2)) (-4 *2 (-172)))) (-2886 (*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *2)) (-4 *2 (-172)))) (-4134 (*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-679 *4)))) (-1524 (*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-679 *4)))) (-3114 (*1 *2 *1) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-1157 *3)))) (-3105 (*1 *2 *1) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-1157 *3)))) (-3441 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-2435 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-3964 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-2984 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-3487 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-1463 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-3636 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-3579 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-3375 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-1852 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-3582 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-2889 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-4221 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-2153 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-4463 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121)))) (-2902 (*1 *1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-172)) (-4 *2 (-558)))) (-1974 (*1 *1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-172)) (-4 *2 (-558)))) (-2812 (*1 *1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-172)) (-4 *2 (-558)))) (-2657 (*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-4 *3 (-558)) (-5 *2 (-634 (-1244 *3))))) (-3364 (*1 *2 *1) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-4 *3 (-558)) (-5 *2 (-1157 *3)))) (-3839 (*1 *2 *1) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-4 *3 (-558)) (-5 *2 (-1157 *3)))) (-2587 (*1 *2) (|partial| -12 (-4 *3 (-558)) (-4 *3 (-172)) (-5 *2 (-2 (|:| |particular| *1) (|:| -2588 (-634 *1)))) (-4 *1 (-369 *3)))) (-3354 (*1 *2) (|partial| -12 (-4 *3 (-558)) (-4 *3 (-172)) (-5 *2 (-2 (|:| |particular| *1) (|:| -2588 (-634 *1)))) (-4 *1 (-369 *3)))) (-2061 (*1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-558)) (-4 *2 (-172)))) (-2046 (*1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-558)) (-4 *2 (-172)))) (-3591 (*1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-558)) (-4 *2 (-172))))) 
+(-13 (-736 |t#1|) (-10 -8 (-15 -3818 ((-1244 $))) (-15 -2371 ((-917))) (-15 -2155 ((-634 (-953 |t#1|)) (-1244 $))) (-15 -3542 ((-1244 (-679 |t#1|)) (-1244 $))) (-15 -3147 ((-679 |t#1|) $ (-1244 $))) (-15 -2235 ((-679 |t#1|) $ (-1244 $))) (-15 -2786 (|t#1| $)) (-15 -2467 (|t#1| $)) (-15 -4390 (|t#1| $)) (-15 -1509 (|t#1| $)) (-15 -1656 ((-1244 |t#1|) $ (-1244 $))) (-15 -1656 ((-679 |t#1|) (-1244 $) (-1244 $))) (-15 -3899 ($ (-1244 |t#1|) (-1244 $))) (-15 -2060 (|t#1| (-1244 $))) (-15 -2886 (|t#1| (-1244 $))) (-15 -4134 ((-679 |t#1|) (-1244 $))) (-15 -1524 ((-679 |t#1|) (-1244 $))) (-15 -3114 ((-1157 |t#1|) $)) (-15 -3105 ((-1157 |t#1|) $)) (-15 -3441 ((-121))) (-15 -2435 ((-121))) (-15 -3964 ((-121))) (-15 -2984 ((-121))) (-15 -3487 ((-121))) (-15 -1463 ((-121))) (-15 -3636 ((-121))) (-15 -3579 ((-121))) (-15 -3375 ((-121))) (-15 -1852 ((-121))) (-15 -3582 ((-121))) (-15 -2889 ((-121))) (-15 -4221 ((-121))) (-15 -2153 ((-121))) (-15 -4463 ((-121))) (IF (|has| |t#1| (-558)) (PROGN (-15 -2902 ((-3 $ "failed") $)) (-15 -1974 ((-3 $ "failed") $)) (-15 -2812 ((-3 $ "failed") $)) (-15 -2657 ((-634 (-1244 |t#1|)))) (-15 -3364 ((-1157 |t#1|) $)) (-15 -3839 ((-1157 |t#1|) $)) (-15 -2587 ((-3 (-2 (|:| |particular| $) (|:| -2588 (-634 $))) "failed"))) (-15 -3354 ((-3 (-2 (|:| |particular| $) (|:| -2588 (-634 $))) "failed"))) (-15 -2061 ((-3 $ "failed"))) (-15 -2046 ((-3 $ "failed"))) (-15 -3591 ((-3 $ "failed"))) (-6 -4518)) |noBranch|))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 |#1| |#1|) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 |#1|) . T) ((-707 |#1|) . T) ((-710) . T) ((-736 |#1|) . T) ((-753) . T) ((-1053 |#1|) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) 7)) (-3983 (((-763)) 15)) (-1731 (($) 12)) (-3683 (((-917) $) 13)) (-4487 (((-1143) $) 9)) (-4355 (($ (-917)) 14)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-1717 (((-121) $ $) 6))) 
+((-2449 (((-121) $ $) 7)) (-3986 (((-763)) 15)) (-1733 (($) 12)) (-2291 (((-917) $) 13)) (-1893 (((-1143) $) 9)) (-4357 (($ (-917)) 14)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-1719 (((-121) $ $) 6))) 
 (((-370) (-1275)) (T -370)) 
-((-3983 (*1 *2) (-12 (-4 *1 (-370)) (-5 *2 (-763)))) (-4355 (*1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-370)))) (-3683 (*1 *2 *1) (-12 (-4 *1 (-370)) (-5 *2 (-917)))) (-1731 (*1 *1) (-4 *1 (-370)))) 
-(-13 (-1090) (-10 -8 (-15 -3983 ((-763))) (-15 -4355 ($ (-917))) (-15 -3683 ((-917) $)) (-15 -1731 ($)))) 
+((-3986 (*1 *2) (-12 (-4 *1 (-370)) (-5 *2 (-763)))) (-4357 (*1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-370)))) (-2291 (*1 *2 *1) (-12 (-4 *1 (-370)) (-5 *2 (-917)))) (-1733 (*1 *1) (-4 *1 (-370)))) 
+(-13 (-1090) (-10 -8 (-15 -3986 ((-763))) (-15 -4357 ($ (-917))) (-15 -2291 ((-917) $)) (-15 -1733 ($)))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-4255 (((-679 |#2|) (-1244 $)) 40)) (-3498 (($ (-1244 |#2|) (-1244 $)) 35)) (-1709 (((-679 |#2|) $ (-1244 $)) 43)) (-2217 ((|#2| (-1244 $)) 13)) (-4073 (((-1244 |#2|) $ (-1244 $)) NIL) (((-679 |#2|) (-1244 $) (-1244 $)) 25))) 
-(((-371 |#1| |#2| |#3|) (-10 -8 (-15 -4255 ((-679 |#2|) (-1244 |#1|))) (-15 -2217 (|#2| (-1244 |#1|))) (-15 -3498 (|#1| (-1244 |#2|) (-1244 |#1|))) (-15 -4073 ((-679 |#2|) (-1244 |#1|) (-1244 |#1|))) (-15 -4073 ((-1244 |#2|) |#1| (-1244 |#1|))) (-15 -1709 ((-679 |#2|) |#1| (-1244 |#1|)))) (-372 |#2| |#3|) (-172) (-1219 |#2|)) (T -371)) 
+((-2883 (((-679 |#2|) (-1244 $)) 40)) (-3899 (($ (-1244 |#2|) (-1244 $)) 35)) (-3653 (((-679 |#2|) $ (-1244 $)) 43)) (-3440 ((|#2| (-1244 $)) 13)) (-1656 (((-1244 |#2|) $ (-1244 $)) NIL) (((-679 |#2|) (-1244 $) (-1244 $)) 25))) 
+(((-371 |#1| |#2| |#3|) (-10 -8 (-15 -2883 ((-679 |#2|) (-1244 |#1|))) (-15 -3440 (|#2| (-1244 |#1|))) (-15 -3899 (|#1| (-1244 |#2|) (-1244 |#1|))) (-15 -1656 ((-679 |#2|) (-1244 |#1|) (-1244 |#1|))) (-15 -1656 ((-1244 |#2|) |#1| (-1244 |#1|))) (-15 -3653 ((-679 |#2|) |#1| (-1244 |#1|)))) (-372 |#2| |#3|) (-172) (-1219 |#2|)) (T -371)) 
 NIL 
-(-10 -8 (-15 -4255 ((-679 |#2|) (-1244 |#1|))) (-15 -2217 (|#2| (-1244 |#1|))) (-15 -3498 (|#1| (-1244 |#2|) (-1244 |#1|))) (-15 -4073 ((-679 |#2|) (-1244 |#1|) (-1244 |#1|))) (-15 -4073 ((-1244 |#2|) |#1| (-1244 |#1|))) (-15 -1709 ((-679 |#2|) |#1| (-1244 |#1|)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-4255 (((-679 |#1|) (-1244 $)) 44)) (-1932 ((|#1| $) 50)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-3498 (($ (-1244 |#1|) (-1244 $)) 46)) (-1709 (((-679 |#1|) $ (-1244 $)) 51)) (-2925 (((-3 $ "failed") $) 33)) (-3700 (((-917)) 52)) (-2735 (((-121) $) 30)) (-2657 ((|#1| $) 49)) (-2045 ((|#2| $) 42 (|has| |#1| (-365)))) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2217 ((|#1| (-1244 $)) 45)) (-4073 (((-1244 |#1|) $ (-1244 $)) 48) (((-679 |#1|) (-1244 $) (-1244 $)) 47)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 36)) (-4371 (((-3 $ "failed") $) 41 (|has| |#1| (-148)))) (-2678 ((|#2| $) 43)) (-4078 (((-763)) 28)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37))) 
+(-10 -8 (-15 -2883 ((-679 |#2|) (-1244 |#1|))) (-15 -3440 (|#2| (-1244 |#1|))) (-15 -3899 (|#1| (-1244 |#2|) (-1244 |#1|))) (-15 -1656 ((-679 |#2|) (-1244 |#1|) (-1244 |#1|))) (-15 -1656 ((-1244 |#2|) |#1| (-1244 |#1|))) (-15 -3653 ((-679 |#2|) |#1| (-1244 |#1|)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2883 (((-679 |#1|) (-1244 $)) 44)) (-1934 ((|#1| $) 50)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-3899 (($ (-1244 |#1|) (-1244 $)) 46)) (-3653 (((-679 |#1|) $ (-1244 $)) 51)) (-2902 (((-3 $ "failed") $) 33)) (-2371 (((-917)) 52)) (-1598 (((-121) $) 30)) (-4417 ((|#1| $) 49)) (-1497 ((|#2| $) 42 (|has| |#1| (-365)))) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-3440 ((|#1| (-1244 $)) 45)) (-1656 (((-1244 |#1|) $ (-1244 $)) 48) (((-679 |#1|) (-1244 $) (-1244 $)) 47)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 36)) (-3385 (((-3 $ "failed") $) 41 (|has| |#1| (-148)))) (-1295 ((|#2| $) 43)) (-3425 (((-763)) 28)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37))) 
 (((-372 |#1| |#2|) (-1275) (-172) (-1219 |t#1|)) (T -372)) 
-((-3700 (*1 *2) (-12 (-4 *1 (-372 *3 *4)) (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-917)))) (-1709 (*1 *2 *1 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-372 *4 *5)) (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-679 *4)))) (-1932 (*1 *2 *1) (-12 (-4 *1 (-372 *2 *3)) (-4 *3 (-1219 *2)) (-4 *2 (-172)))) (-2657 (*1 *2 *1) (-12 (-4 *1 (-372 *2 *3)) (-4 *3 (-1219 *2)) (-4 *2 (-172)))) (-4073 (*1 *2 *1 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-372 *4 *5)) (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-1244 *4)))) (-4073 (*1 *2 *3 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-372 *4 *5)) (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-679 *4)))) (-3498 (*1 *1 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-1244 *1)) (-4 *4 (-172)) (-4 *1 (-372 *4 *5)) (-4 *5 (-1219 *4)))) (-2217 (*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-372 *2 *4)) (-4 *4 (-1219 *2)) (-4 *2 (-172)))) (-4255 (*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-372 *4 *5)) (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-679 *4)))) (-2678 (*1 *2 *1) (-12 (-4 *1 (-372 *3 *2)) (-4 *3 (-172)) (-4 *2 (-1219 *3)))) (-2045 (*1 *2 *1) (-12 (-4 *1 (-372 *3 *2)) (-4 *3 (-172)) (-4 *3 (-365)) (-4 *2 (-1219 *3))))) 
-(-13 (-43 |t#1|) (-10 -8 (-15 -3700 ((-917))) (-15 -1709 ((-679 |t#1|) $ (-1244 $))) (-15 -1932 (|t#1| $)) (-15 -2657 (|t#1| $)) (-15 -4073 ((-1244 |t#1|) $ (-1244 $))) (-15 -4073 ((-679 |t#1|) (-1244 $) (-1244 $))) (-15 -3498 ($ (-1244 |t#1|) (-1244 $))) (-15 -2217 (|t#1| (-1244 $))) (-15 -4255 ((-679 |t#1|) (-1244 $))) (-15 -2678 (|t#2| $)) (IF (|has| |t#1| (-365)) (-15 -2045 (|t#2| $)) |noBranch|) (IF (|has| |t#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |t#1| (-148)) (-6 (-148)) |noBranch|))) 
+((-2371 (*1 *2) (-12 (-4 *1 (-372 *3 *4)) (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-917)))) (-3653 (*1 *2 *1 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-372 *4 *5)) (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-679 *4)))) (-1934 (*1 *2 *1) (-12 (-4 *1 (-372 *2 *3)) (-4 *3 (-1219 *2)) (-4 *2 (-172)))) (-4417 (*1 *2 *1) (-12 (-4 *1 (-372 *2 *3)) (-4 *3 (-1219 *2)) (-4 *2 (-172)))) (-1656 (*1 *2 *1 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-372 *4 *5)) (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-1244 *4)))) (-1656 (*1 *2 *3 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-372 *4 *5)) (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-679 *4)))) (-3899 (*1 *1 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-1244 *1)) (-4 *4 (-172)) (-4 *1 (-372 *4 *5)) (-4 *5 (-1219 *4)))) (-3440 (*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-372 *2 *4)) (-4 *4 (-1219 *2)) (-4 *2 (-172)))) (-2883 (*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-372 *4 *5)) (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-679 *4)))) (-1295 (*1 *2 *1) (-12 (-4 *1 (-372 *3 *2)) (-4 *3 (-172)) (-4 *2 (-1219 *3)))) (-1497 (*1 *2 *1) (-12 (-4 *1 (-372 *3 *2)) (-4 *3 (-172)) (-4 *3 (-365)) (-4 *2 (-1219 *3))))) 
+(-13 (-43 |t#1|) (-10 -8 (-15 -2371 ((-917))) (-15 -3653 ((-679 |t#1|) $ (-1244 $))) (-15 -1934 (|t#1| $)) (-15 -4417 (|t#1| $)) (-15 -1656 ((-1244 |t#1|) $ (-1244 $))) (-15 -1656 ((-679 |t#1|) (-1244 $) (-1244 $))) (-15 -3899 ($ (-1244 |t#1|) (-1244 $))) (-15 -3440 (|t#1| (-1244 $))) (-15 -2883 ((-679 |t#1|) (-1244 $))) (-15 -1295 (|t#2| $)) (IF (|has| |t#1| (-365)) (-15 -1497 (|t#2| $)) |noBranch|) (IF (|has| |t#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |t#1| (-148)) (-6 (-148)) |noBranch|))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#1|) . T) ((-105) . T) ((-120 |#1| |#1|) . T) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-637 |#1|) . T) ((-637 $) . T) ((-707 |#1|) . T) ((-716) . T) ((-1053 |#1|) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-2512 ((|#4| (-1 |#3| |#1| |#3|) |#2| |#3|) 23)) (-3092 ((|#3| (-1 |#3| |#1| |#3|) |#2| |#3|) 15)) (-2795 ((|#4| (-1 |#3| |#1|) |#2|) 21))) 
-(((-373 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2795 (|#4| (-1 |#3| |#1|) |#2|)) (-15 -3092 (|#3| (-1 |#3| |#1| |#3|) |#2| |#3|)) (-15 -2512 (|#4| (-1 |#3| |#1| |#3|) |#2| |#3|))) (-1195) (-375 |#1|) (-1195) (-375 |#3|)) (T -373)) 
-((-2512 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-4 *6 (-1195)) (-4 *5 (-1195)) (-4 *2 (-375 *5)) (-5 *1 (-373 *6 *4 *5 *2)) (-4 *4 (-375 *6)))) (-3092 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-373 *5 *4 *2 *6)) (-4 *4 (-375 *5)) (-4 *6 (-375 *2)))) (-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-4 *2 (-375 *6)) (-5 *1 (-373 *5 *4 *6 *2)) (-4 *4 (-375 *5))))) 
-(-10 -7 (-15 -2795 (|#4| (-1 |#3| |#1|) |#2|)) (-15 -3092 (|#3| (-1 |#3| |#1| |#3|) |#2| |#3|)) (-15 -2512 (|#4| (-1 |#3| |#1| |#3|) |#2| |#3|))) 
-((-2016 (((-121) (-1 (-121) |#2| |#2|) $) NIL) (((-121) $) 18)) (-3908 (($ (-1 (-121) |#2| |#2|) $) NIL) (($ $) 28)) (-3644 (($ (-1 (-121) |#2| |#2|) $) 27) (($ $) 22)) (-3943 (($ $) 25)) (-2764 (((-568) (-1 (-121) |#2|) $) NIL) (((-568) |#2| $) 11) (((-568) |#2| $ (-568)) NIL)) (-1347 (($ (-1 (-121) |#2| |#2|) $ $) NIL) (($ $ $) 20))) 
-(((-374 |#1| |#2|) (-10 -8 (-15 -3908 (|#1| |#1|)) (-15 -3908 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -2016 ((-121) |#1|)) (-15 -3644 (|#1| |#1|)) (-15 -1347 (|#1| |#1| |#1|)) (-15 -2764 ((-568) |#2| |#1| (-568))) (-15 -2764 ((-568) |#2| |#1|)) (-15 -2764 ((-568) (-1 (-121) |#2|) |#1|)) (-15 -2016 ((-121) (-1 (-121) |#2| |#2|) |#1|)) (-15 -3644 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -3943 (|#1| |#1|)) (-15 -1347 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|))) (-375 |#2|) (-1195)) (T -374)) 
-NIL 
-(-10 -8 (-15 -3908 (|#1| |#1|)) (-15 -3908 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -2016 ((-121) |#1|)) (-15 -3644 (|#1| |#1|)) (-15 -1347 (|#1| |#1| |#1|)) (-15 -2764 ((-568) |#2| |#1| (-568))) (-15 -2764 ((-568) |#2| |#1|)) (-15 -2764 ((-568) (-1 (-121) |#2|) |#1|)) (-15 -2016 ((-121) (-1 (-121) |#2| |#2|) |#1|)) (-15 -3644 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -3943 (|#1| |#1|)) (-15 -1347 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-1868 (((-1249) $ (-568) (-568)) 37 (|has| $ (-6 -4520)))) (-2016 (((-121) (-1 (-121) |#1| |#1|) $) 91) (((-121) $) 85 (|has| |#1| (-842)))) (-3908 (($ (-1 (-121) |#1| |#1|) $) 82 (|has| $ (-6 -4520))) (($ $) 81 (-12 (|has| |#1| (-842)) (|has| $ (-6 -4520))))) (-3644 (($ (-1 (-121) |#1| |#1|) $) 92) (($ $) 86 (|has| |#1| (-842)))) (-2510 (((-121) $ (-763)) 8)) (-2436 ((|#1| $ (-568) |#1|) 49 (|has| $ (-6 -4520))) ((|#1| $ (-1210 (-568)) |#1|) 53 (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) |#1|) $) 70 (|has| $ (-6 -4519)))) (-2671 (($) 7 T CONST)) (-1578 (($ $) 83 (|has| $ (-6 -4520)))) (-3943 (($ $) 93)) (-3924 (($ $) 73 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-4328 (($ |#1| $) 72 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) |#1|) $) 69 (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4519)))) (-3989 ((|#1| $ (-568) |#1|) 50 (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-568)) 48)) (-2764 (((-568) (-1 (-121) |#1|) $) 90) (((-568) |#1| $) 89 (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) 88 (|has| |#1| (-1090)))) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-1849 (($ (-763) |#1|) 64)) (-1737 (((-121) $ (-763)) 9)) (-1881 (((-568) $) 40 (|has| (-568) (-842)))) (-2521 (($ $ $) 80 (|has| |#1| (-842)))) (-1347 (($ (-1 (-121) |#1| |#1|) $ $) 94) (($ $ $) 87 (|has| |#1| (-842)))) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-2223 (((-568) $) 41 (|has| (-568) (-842)))) (-3268 (($ $ $) 79 (|has| |#1| (-842)))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-2166 (((-121) $ (-763)) 10)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4122 (($ |#1| $ (-568)) 55) (($ $ $ (-568)) 54)) (-4174 (((-634 (-568)) $) 43)) (-3578 (((-121) (-568) $) 44)) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3876 ((|#1| $) 39 (|has| (-568) (-842)))) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 66)) (-3724 (($ $ |#1|) 38 (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-4467 (((-121) |#1| $) 42 (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) 45)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 ((|#1| $ (-568) |#1|) 47) ((|#1| $ (-568)) 46) (($ $ (-1210 (-568))) 58)) (-2826 (($ $ (-568)) 57) (($ $ (-1210 (-568))) 56)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-2256 (($ $ $ (-568)) 84 (|has| $ (-6 -4520)))) (-3863 (($ $) 13)) (-4278 (((-541) $) 74 (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) 65)) (-2768 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-634 $)) 60)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1751 (((-121) $ $) 77 (|has| |#1| (-842)))) (-1738 (((-121) $ $) 76 (|has| |#1| (-842)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1745 (((-121) $ $) 78 (|has| |#1| (-842)))) (-1732 (((-121) $ $) 75 (|has| |#1| (-842)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-1678 ((|#4| (-1 |#3| |#1| |#3|) |#2| |#3|) 23)) (-3094 ((|#3| (-1 |#3| |#1| |#3|) |#2| |#3|) 15)) (-2797 ((|#4| (-1 |#3| |#1|) |#2|) 21))) 
+(((-373 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2797 (|#4| (-1 |#3| |#1|) |#2|)) (-15 -3094 (|#3| (-1 |#3| |#1| |#3|) |#2| |#3|)) (-15 -1678 (|#4| (-1 |#3| |#1| |#3|) |#2| |#3|))) (-1195) (-375 |#1|) (-1195) (-375 |#3|)) (T -373)) 
+((-1678 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-4 *6 (-1195)) (-4 *5 (-1195)) (-4 *2 (-375 *5)) (-5 *1 (-373 *6 *4 *5 *2)) (-4 *4 (-375 *6)))) (-3094 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-373 *5 *4 *2 *6)) (-4 *4 (-375 *5)) (-4 *6 (-375 *2)))) (-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-4 *2 (-375 *6)) (-5 *1 (-373 *5 *4 *6 *2)) (-4 *4 (-375 *5))))) 
+(-10 -7 (-15 -2797 (|#4| (-1 |#3| |#1|) |#2|)) (-15 -3094 (|#3| (-1 |#3| |#1| |#3|) |#2| |#3|)) (-15 -1678 (|#4| (-1 |#3| |#1| |#3|) |#2| |#3|))) 
+((-1324 (((-121) (-1 (-121) |#2| |#2|) $) NIL) (((-121) $) 18)) (-2109 (($ (-1 (-121) |#2| |#2|) $) NIL) (($ $) 28)) (-3647 (($ (-1 (-121) |#2| |#2|) $) 27) (($ $) 22)) (-3945 (($ $) 25)) (-2766 (((-568) (-1 (-121) |#2|) $) NIL) (((-568) |#2| $) 11) (((-568) |#2| $ (-568)) NIL)) (-3645 (($ (-1 (-121) |#2| |#2|) $ $) NIL) (($ $ $) 20))) 
+(((-374 |#1| |#2|) (-10 -8 (-15 -2109 (|#1| |#1|)) (-15 -2109 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -1324 ((-121) |#1|)) (-15 -3647 (|#1| |#1|)) (-15 -3645 (|#1| |#1| |#1|)) (-15 -2766 ((-568) |#2| |#1| (-568))) (-15 -2766 ((-568) |#2| |#1|)) (-15 -2766 ((-568) (-1 (-121) |#2|) |#1|)) (-15 -1324 ((-121) (-1 (-121) |#2| |#2|) |#1|)) (-15 -3647 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -3945 (|#1| |#1|)) (-15 -3645 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|))) (-375 |#2|) (-1195)) (T -374)) 
+NIL 
+(-10 -8 (-15 -2109 (|#1| |#1|)) (-15 -2109 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -1324 ((-121) |#1|)) (-15 -3647 (|#1| |#1|)) (-15 -3645 (|#1| |#1| |#1|)) (-15 -2766 ((-568) |#2| |#1| (-568))) (-15 -2766 ((-568) |#2| |#1|)) (-15 -2766 ((-568) (-1 (-121) |#2|) |#1|)) (-15 -1324 ((-121) (-1 (-121) |#2| |#2|) |#1|)) (-15 -3647 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -3945 (|#1| |#1|)) (-15 -3645 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2481 (((-1249) $ (-568) (-568)) 37 (|has| $ (-6 -4522)))) (-1324 (((-121) (-1 (-121) |#1| |#1|) $) 91) (((-121) $) 85 (|has| |#1| (-842)))) (-2109 (($ (-1 (-121) |#1| |#1|) $) 82 (|has| $ (-6 -4522))) (($ $) 81 (-12 (|has| |#1| (-842)) (|has| $ (-6 -4522))))) (-3647 (($ (-1 (-121) |#1| |#1|) $) 92) (($ $) 86 (|has| |#1| (-842)))) (-1667 (((-121) $ (-763)) 8)) (-2438 ((|#1| $ (-568) |#1|) 49 (|has| $ (-6 -4522))) ((|#1| $ (-1210 (-568)) |#1|) 53 (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) |#1|) $) 70 (|has| $ (-6 -4521)))) (-4490 (($) 7 T CONST)) (-4452 (($ $) 83 (|has| $ (-6 -4522)))) (-3945 (($ $) 93)) (-3926 (($ $) 73 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-4330 (($ |#1| $) 72 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) |#1|) $) 69 (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4521)))) (-1292 ((|#1| $ (-568) |#1|) 50 (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-568)) 48)) (-2766 (((-568) (-1 (-121) |#1|) $) 90) (((-568) |#1| $) 89 (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) 88 (|has| |#1| (-1090)))) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-1851 (($ (-763) |#1|) 64)) (-3791 (((-121) $ (-763)) 9)) (-2539 (((-568) $) 40 (|has| (-568) (-842)))) (-1732 (($ $ $) 80 (|has| |#1| (-842)))) (-3645 (($ (-1 (-121) |#1| |#1|) $ $) 94) (($ $ $) 87 (|has| |#1| (-842)))) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3631 (((-568) $) 41 (|has| (-568) (-842)))) (-2047 (($ $ $) 79 (|has| |#1| (-842)))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-3796 (((-121) $ (-763)) 10)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4124 (($ |#1| $ (-568)) 55) (($ $ $ (-568)) 54)) (-3948 (((-634 (-568)) $) 43)) (-2916 (((-121) (-568) $) 44)) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3877 ((|#1| $) 39 (|has| (-568) (-842)))) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 66)) (-2490 (($ $ |#1|) 38 (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-1801 (((-121) |#1| $) 42 (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) 45)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 ((|#1| $ (-568) |#1|) 47) ((|#1| $ (-568)) 46) (($ $ (-1210 (-568))) 58)) (-2828 (($ $ (-568)) 57) (($ $ (-1210 (-568))) 56)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3306 (($ $ $ (-568)) 84 (|has| $ (-6 -4522)))) (-3865 (($ $) 13)) (-4280 (((-541) $) 74 (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) 65)) (-2770 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-634 $)) 60)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1753 (((-121) $ $) 77 (|has| |#1| (-842)))) (-1740 (((-121) $ $) 76 (|has| |#1| (-842)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1747 (((-121) $ $) 78 (|has| |#1| (-842)))) (-1734 (((-121) $ $) 75 (|has| |#1| (-842)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-375 |#1|) (-1275) (-1195)) (T -375)) 
-((-1347 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (-4 *1 (-375 *3)) (-4 *3 (-1195)))) (-3943 (*1 *1 *1) (-12 (-4 *1 (-375 *2)) (-4 *2 (-1195)))) (-3644 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (-4 *1 (-375 *3)) (-4 *3 (-1195)))) (-2016 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *1 (-375 *4)) (-4 *4 (-1195)) (-5 *2 (-121)))) (-2764 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (-4 *1 (-375 *4)) (-4 *4 (-1195)) (-5 *2 (-568)))) (-2764 (*1 *2 *3 *1) (-12 (-4 *1 (-375 *3)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-568)))) (-2764 (*1 *2 *3 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-375 *3)) (-4 *3 (-1195)) (-4 *3 (-1090)))) (-1347 (*1 *1 *1 *1) (-12 (-4 *1 (-375 *2)) (-4 *2 (-1195)) (-4 *2 (-842)))) (-3644 (*1 *1 *1) (-12 (-4 *1 (-375 *2)) (-4 *2 (-1195)) (-4 *2 (-842)))) (-2016 (*1 *2 *1) (-12 (-4 *1 (-375 *3)) (-4 *3 (-1195)) (-4 *3 (-842)) (-5 *2 (-121)))) (-2256 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-568)) (|has| *1 (-6 -4520)) (-4 *1 (-375 *3)) (-4 *3 (-1195)))) (-1578 (*1 *1 *1) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-375 *2)) (-4 *2 (-1195)))) (-3908 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (|has| *1 (-6 -4520)) (-4 *1 (-375 *3)) (-4 *3 (-1195)))) (-3908 (*1 *1 *1) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-375 *2)) (-4 *2 (-1195)) (-4 *2 (-842))))) 
-(-13 (-640 |t#1|) (-10 -8 (-6 -4519) (-15 -1347 ($ (-1 (-121) |t#1| |t#1|) $ $)) (-15 -3943 ($ $)) (-15 -3644 ($ (-1 (-121) |t#1| |t#1|) $)) (-15 -2016 ((-121) (-1 (-121) |t#1| |t#1|) $)) (-15 -2764 ((-568) (-1 (-121) |t#1|) $)) (IF (|has| |t#1| (-1090)) (PROGN (-15 -2764 ((-568) |t#1| $)) (-15 -2764 ((-568) |t#1| $ (-568)))) |noBranch|) (IF (|has| |t#1| (-842)) (PROGN (-6 (-842)) (-15 -1347 ($ $ $)) (-15 -3644 ($ $)) (-15 -2016 ((-121) $))) |noBranch|) (IF (|has| $ (-6 -4520)) (PROGN (-15 -2256 ($ $ $ (-568))) (-15 -1578 ($ $)) (-15 -3908 ($ (-1 (-121) |t#1| |t#1|) $)) (IF (|has| |t#1| (-842)) (-15 -3908 ($ $)) |noBranch|)) |noBranch|))) 
-(((-39) . T) ((-105) -2198 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-608 (-850)) -2198 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-154 |#1|) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-281 (-568) |#1|) . T) ((-283 (-568) |#1|) . T) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-601 (-568) |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-640 |#1|) . T) ((-842) |has| |#1| (-842)) ((-1090) -2198 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-1195) . T)) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3595 (((-634 |#1|) $) 29)) (-2821 (($ $ (-763)) 30)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-2628 (((-1266 |#1| |#2|) (-1266 |#1| |#2|) $) 33)) (-2407 (($ $) 31)) (-2532 (((-1266 |#1| |#2|) (-1266 |#1| |#2|) $) 34)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-1339 (($ $ |#1| $) 28) (($ $ (-634 |#1|) (-634 $)) 27)) (-3206 (((-763) $) 35)) (-4287 (($ $ $) 26)) (-2745 (((-850) $) 11) (($ |#1|) 38) (((-1257 |#1| |#2|) $) 37) (((-1266 |#1| |#2|) $) 36)) (-2348 ((|#2| (-1266 |#1| |#2|) $) 39)) (-3056 (($) 17 T CONST)) (-3903 (($ (-663 |#1|)) 32)) (-1717 (((-121) $ $) 6)) (-1779 (($ $ |#2|) 25 (|has| |#2| (-365)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ |#2| $) 22) (($ $ |#2|) 24))) 
+((-3645 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (-4 *1 (-375 *3)) (-4 *3 (-1195)))) (-3945 (*1 *1 *1) (-12 (-4 *1 (-375 *2)) (-4 *2 (-1195)))) (-3647 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (-4 *1 (-375 *3)) (-4 *3 (-1195)))) (-1324 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *1 (-375 *4)) (-4 *4 (-1195)) (-5 *2 (-121)))) (-2766 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (-4 *1 (-375 *4)) (-4 *4 (-1195)) (-5 *2 (-568)))) (-2766 (*1 *2 *3 *1) (-12 (-4 *1 (-375 *3)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-568)))) (-2766 (*1 *2 *3 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-375 *3)) (-4 *3 (-1195)) (-4 *3 (-1090)))) (-3645 (*1 *1 *1 *1) (-12 (-4 *1 (-375 *2)) (-4 *2 (-1195)) (-4 *2 (-842)))) (-3647 (*1 *1 *1) (-12 (-4 *1 (-375 *2)) (-4 *2 (-1195)) (-4 *2 (-842)))) (-1324 (*1 *2 *1) (-12 (-4 *1 (-375 *3)) (-4 *3 (-1195)) (-4 *3 (-842)) (-5 *2 (-121)))) (-3306 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-568)) (|has| *1 (-6 -4522)) (-4 *1 (-375 *3)) (-4 *3 (-1195)))) (-4452 (*1 *1 *1) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-375 *2)) (-4 *2 (-1195)))) (-2109 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (|has| *1 (-6 -4522)) (-4 *1 (-375 *3)) (-4 *3 (-1195)))) (-2109 (*1 *1 *1) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-375 *2)) (-4 *2 (-1195)) (-4 *2 (-842))))) 
+(-13 (-640 |t#1|) (-10 -8 (-6 -4521) (-15 -3645 ($ (-1 (-121) |t#1| |t#1|) $ $)) (-15 -3945 ($ $)) (-15 -3647 ($ (-1 (-121) |t#1| |t#1|) $)) (-15 -1324 ((-121) (-1 (-121) |t#1| |t#1|) $)) (-15 -2766 ((-568) (-1 (-121) |t#1|) $)) (IF (|has| |t#1| (-1090)) (PROGN (-15 -2766 ((-568) |t#1| $)) (-15 -2766 ((-568) |t#1| $ (-568)))) |noBranch|) (IF (|has| |t#1| (-842)) (PROGN (-6 (-842)) (-15 -3645 ($ $ $)) (-15 -3647 ($ $)) (-15 -1324 ((-121) $))) |noBranch|) (IF (|has| $ (-6 -4522)) (PROGN (-15 -3306 ($ $ $ (-568))) (-15 -4452 ($ $)) (-15 -2109 ($ (-1 (-121) |t#1| |t#1|) $)) (IF (|has| |t#1| (-842)) (-15 -2109 ($ $)) |noBranch|)) |noBranch|))) 
+(((-39) . T) ((-105) -2199 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-608 (-850)) -2199 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-154 |#1|) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-281 (-568) |#1|) . T) ((-283 (-568) |#1|) . T) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-601 (-568) |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-640 |#1|) . T) ((-842) |has| |#1| (-842)) ((-1090) -2199 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-1195) . T)) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2981 (((-634 |#1|) $) 29)) (-3784 (($ $ (-763)) 30)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-4242 (((-1266 |#1| |#2|) (-1266 |#1| |#2|) $) 33)) (-2310 (($ $) 31)) (-1797 (((-1266 |#1| |#2|) (-1266 |#1| |#2|) $) 34)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-1339 (($ $ |#1| $) 28) (($ $ (-634 |#1|) (-634 $)) 27)) (-1836 (((-763) $) 35)) (-4289 (($ $ $) 26)) (-2747 (((-850) $) 11) (($ |#1|) 38) (((-1257 |#1| |#2|) $) 37) (((-1266 |#1| |#2|) $) 36)) (-2350 ((|#2| (-1266 |#1| |#2|) $) 39)) (-3058 (($) 17 T CONST)) (-2081 (($ (-663 |#1|)) 32)) (-1719 (((-121) $ $) 6)) (-1781 (($ $ |#2|) 25 (|has| |#2| (-365)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ |#2| $) 22) (($ $ |#2|) 24))) 
 (((-376 |#1| |#2|) (-1275) (-842) (-172)) (T -376)) 
-((-2348 (*1 *2 *3 *1) (-12 (-5 *3 (-1266 *4 *2)) (-4 *1 (-376 *4 *2)) (-4 *4 (-842)) (-4 *2 (-172)))) (-2745 (*1 *1 *2) (-12 (-4 *1 (-376 *2 *3)) (-4 *2 (-842)) (-4 *3 (-172)))) (-2745 (*1 *2 *1) (-12 (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *2 (-1257 *3 *4)))) (-2745 (*1 *2 *1) (-12 (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *2 (-1266 *3 *4)))) (-3206 (*1 *2 *1) (-12 (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *2 (-763)))) (-2532 (*1 *2 *2 *1) (-12 (-5 *2 (-1266 *3 *4)) (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) (-2628 (*1 *2 *2 *1) (-12 (-5 *2 (-1266 *3 *4)) (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) (-3903 (*1 *1 *2) (-12 (-5 *2 (-663 *3)) (-4 *3 (-842)) (-4 *1 (-376 *3 *4)) (-4 *4 (-172)))) (-2407 (*1 *1 *1) (-12 (-4 *1 (-376 *2 *3)) (-4 *2 (-842)) (-4 *3 (-172)))) (-2821 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) (-3595 (*1 *2 *1) (-12 (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *2 (-634 *3)))) (-1339 (*1 *1 *1 *2 *1) (-12 (-4 *1 (-376 *2 *3)) (-4 *2 (-842)) (-4 *3 (-172)))) (-1339 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *4)) (-5 *3 (-634 *1)) (-4 *1 (-376 *4 *5)) (-4 *4 (-842)) (-4 *5 (-172))))) 
-(-13 (-625 |t#2|) (-10 -8 (-15 -2348 (|t#2| (-1266 |t#1| |t#2|) $)) (-15 -2745 ($ |t#1|)) (-15 -2745 ((-1257 |t#1| |t#2|) $)) (-15 -2745 ((-1266 |t#1| |t#2|) $)) (-15 -3206 ((-763) $)) (-15 -2532 ((-1266 |t#1| |t#2|) (-1266 |t#1| |t#2|) $)) (-15 -2628 ((-1266 |t#1| |t#2|) (-1266 |t#1| |t#2|) $)) (-15 -3903 ($ (-663 |t#1|))) (-15 -2407 ($ $)) (-15 -2821 ($ $ (-763))) (-15 -3595 ((-634 |t#1|) $)) (-15 -1339 ($ $ |t#1| $)) (-15 -1339 ($ $ (-634 |t#1|) (-634 $))))) 
+((-2350 (*1 *2 *3 *1) (-12 (-5 *3 (-1266 *4 *2)) (-4 *1 (-376 *4 *2)) (-4 *4 (-842)) (-4 *2 (-172)))) (-2747 (*1 *1 *2) (-12 (-4 *1 (-376 *2 *3)) (-4 *2 (-842)) (-4 *3 (-172)))) (-2747 (*1 *2 *1) (-12 (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *2 (-1257 *3 *4)))) (-2747 (*1 *2 *1) (-12 (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *2 (-1266 *3 *4)))) (-1836 (*1 *2 *1) (-12 (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *2 (-763)))) (-1797 (*1 *2 *2 *1) (-12 (-5 *2 (-1266 *3 *4)) (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) (-4242 (*1 *2 *2 *1) (-12 (-5 *2 (-1266 *3 *4)) (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) (-2081 (*1 *1 *2) (-12 (-5 *2 (-663 *3)) (-4 *3 (-842)) (-4 *1 (-376 *3 *4)) (-4 *4 (-172)))) (-2310 (*1 *1 *1) (-12 (-4 *1 (-376 *2 *3)) (-4 *2 (-842)) (-4 *3 (-172)))) (-3784 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) (-2981 (*1 *2 *1) (-12 (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *2 (-634 *3)))) (-1339 (*1 *1 *1 *2 *1) (-12 (-4 *1 (-376 *2 *3)) (-4 *2 (-842)) (-4 *3 (-172)))) (-1339 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *4)) (-5 *3 (-634 *1)) (-4 *1 (-376 *4 *5)) (-4 *4 (-842)) (-4 *5 (-172))))) 
+(-13 (-625 |t#2|) (-10 -8 (-15 -2350 (|t#2| (-1266 |t#1| |t#2|) $)) (-15 -2747 ($ |t#1|)) (-15 -2747 ((-1257 |t#1| |t#2|) $)) (-15 -2747 ((-1266 |t#1| |t#2|) $)) (-15 -1836 ((-763) $)) (-15 -1797 ((-1266 |t#1| |t#2|) (-1266 |t#1| |t#2|) $)) (-15 -4242 ((-1266 |t#1| |t#2|) (-1266 |t#1| |t#2|) $)) (-15 -2081 ($ (-663 |t#1|))) (-15 -2310 ($ $)) (-15 -3784 ($ $ (-763))) (-15 -2981 ((-634 |t#1|) $)) (-15 -1339 ($ $ |t#1| $)) (-15 -1339 ($ $ (-634 |t#1|) (-634 $))))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 |#2| |#2|) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 |#2|) . T) ((-625 |#2|) . T) ((-707 |#2|) . T) ((-1053 |#2|) . T) ((-1090) . T)) 
-((-4001 ((|#2| (-1 (-121) |#1| |#1|) |#2|) 22)) (-3376 ((|#2| (-1 (-121) |#1| |#1|) |#2|) 12)) (-2362 ((|#2| (-1 (-121) |#1| |#1|) |#2|) 21))) 
-(((-377 |#1| |#2|) (-10 -7 (-15 -3376 (|#2| (-1 (-121) |#1| |#1|) |#2|)) (-15 -2362 (|#2| (-1 (-121) |#1| |#1|) |#2|)) (-15 -4001 (|#2| (-1 (-121) |#1| |#1|) |#2|))) (-1195) (-13 (-375 |#1|) (-10 -7 (-6 -4520)))) (T -377)) 
-((-4001 (*1 *2 *3 *2) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1195)) (-5 *1 (-377 *4 *2)) (-4 *2 (-13 (-375 *4) (-10 -7 (-6 -4520)))))) (-2362 (*1 *2 *3 *2) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1195)) (-5 *1 (-377 *4 *2)) (-4 *2 (-13 (-375 *4) (-10 -7 (-6 -4520)))))) (-3376 (*1 *2 *3 *2) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1195)) (-5 *1 (-377 *4 *2)) (-4 *2 (-13 (-375 *4) (-10 -7 (-6 -4520))))))) 
-(-10 -7 (-15 -3376 (|#2| (-1 (-121) |#1| |#1|) |#2|)) (-15 -2362 (|#2| (-1 (-121) |#1| |#1|) |#2|)) (-15 -4001 (|#2| (-1 (-121) |#1| |#1|) |#2|))) 
-((-3164 (((-679 |#2|) (-679 $)) NIL) (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 19) (((-679 (-568)) (-679 $)) 13))) 
-(((-378 |#1| |#2|) (-10 -8 (-15 -3164 ((-679 (-568)) (-679 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 |#1|) (-1244 |#1|))) (-15 -3164 ((-679 |#2|) (-679 |#1|)))) (-379 |#2|) (-1047)) (T -378)) 
-NIL 
-(-10 -8 (-15 -3164 ((-679 (-568)) (-679 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 |#1|) (-1244 |#1|))) (-15 -3164 ((-679 |#2|) (-679 |#1|)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-3164 (((-679 |#1|) (-679 $)) 35) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 34) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 38 (|has| |#1| (-630 (-568)))) (((-679 (-568)) (-679 $)) 37 (|has| |#1| (-630 (-568))))) (-2925 (((-3 $ "failed") $) 33)) (-2735 (((-121) $) 30)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11) (($ (-568)) 27)) (-4078 (((-763)) 28)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
+((-1344 ((|#2| (-1 (-121) |#1| |#1|) |#2|) 22)) (-1420 ((|#2| (-1 (-121) |#1| |#1|) |#2|) 12)) (-4044 ((|#2| (-1 (-121) |#1| |#1|) |#2|) 21))) 
+(((-377 |#1| |#2|) (-10 -7 (-15 -1420 (|#2| (-1 (-121) |#1| |#1|) |#2|)) (-15 -4044 (|#2| (-1 (-121) |#1| |#1|) |#2|)) (-15 -1344 (|#2| (-1 (-121) |#1| |#1|) |#2|))) (-1195) (-13 (-375 |#1|) (-10 -7 (-6 -4522)))) (T -377)) 
+((-1344 (*1 *2 *3 *2) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1195)) (-5 *1 (-377 *4 *2)) (-4 *2 (-13 (-375 *4) (-10 -7 (-6 -4522)))))) (-4044 (*1 *2 *3 *2) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1195)) (-5 *1 (-377 *4 *2)) (-4 *2 (-13 (-375 *4) (-10 -7 (-6 -4522)))))) (-1420 (*1 *2 *3 *2) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1195)) (-5 *1 (-377 *4 *2)) (-4 *2 (-13 (-375 *4) (-10 -7 (-6 -4522))))))) 
+(-10 -7 (-15 -1420 (|#2| (-1 (-121) |#1| |#1|) |#2|)) (-15 -4044 (|#2| (-1 (-121) |#1| |#1|) |#2|)) (-15 -1344 (|#2| (-1 (-121) |#1| |#1|) |#2|))) 
+((-1668 (((-679 |#2|) (-679 $)) NIL) (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 19) (((-679 (-568)) (-679 $)) 13))) 
+(((-378 |#1| |#2|) (-10 -8 (-15 -1668 ((-679 (-568)) (-679 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 |#1|) (-1244 |#1|))) (-15 -1668 ((-679 |#2|) (-679 |#1|)))) (-379 |#2|) (-1047)) (T -378)) 
+NIL 
+(-10 -8 (-15 -1668 ((-679 (-568)) (-679 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 |#1|) (-1244 |#1|))) (-15 -1668 ((-679 |#2|) (-679 |#1|)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-1668 (((-679 |#1|) (-679 $)) 35) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 34) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 38 (|has| |#1| (-630 (-568)))) (((-679 (-568)) (-679 $)) 37 (|has| |#1| (-630 (-568))))) (-2902 (((-3 $ "failed") $) 33)) (-1598 (((-121) $) 30)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11) (($ (-568)) 27)) (-3425 (((-763)) 28)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
 (((-379 |#1|) (-1275) (-1047)) (T -379)) 
 NIL 
 (-13 (-630 |t#1|) (-10 -7 (IF (|has| |t#1| (-630 (-568))) (-6 (-630 (-568))) |noBranch|))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 $) . T) ((-630 (-568)) |has| |#1| (-630 (-568))) ((-630 |#1|) . T) ((-716) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-3881 (((-634 (-288 (-953 (-169 |#1|)))) (-288 (-409 (-953 (-169 (-568))))) |#1|) 52) (((-634 (-288 (-953 (-169 |#1|)))) (-409 (-953 (-169 (-568)))) |#1|) 51) (((-634 (-634 (-288 (-953 (-169 |#1|))))) (-634 (-288 (-409 (-953 (-169 (-568)))))) |#1|) 47) (((-634 (-634 (-288 (-953 (-169 |#1|))))) (-634 (-409 (-953 (-169 (-568))))) |#1|) 40)) (-3471 (((-634 (-634 (-169 |#1|))) (-634 (-409 (-953 (-169 (-568))))) (-634 (-1161)) |#1|) 28) (((-634 (-169 |#1|)) (-409 (-953 (-169 (-568)))) |#1|) 15))) 
-(((-380 |#1|) (-10 -7 (-15 -3881 ((-634 (-634 (-288 (-953 (-169 |#1|))))) (-634 (-409 (-953 (-169 (-568))))) |#1|)) (-15 -3881 ((-634 (-634 (-288 (-953 (-169 |#1|))))) (-634 (-288 (-409 (-953 (-169 (-568)))))) |#1|)) (-15 -3881 ((-634 (-288 (-953 (-169 |#1|)))) (-409 (-953 (-169 (-568)))) |#1|)) (-15 -3881 ((-634 (-288 (-953 (-169 |#1|)))) (-288 (-409 (-953 (-169 (-568))))) |#1|)) (-15 -3471 ((-634 (-169 |#1|)) (-409 (-953 (-169 (-568)))) |#1|)) (-15 -3471 ((-634 (-634 (-169 |#1|))) (-634 (-409 (-953 (-169 (-568))))) (-634 (-1161)) |#1|))) (-13 (-365) (-840))) (T -380)) 
-((-3471 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-409 (-953 (-169 (-568)))))) (-5 *4 (-634 (-1161))) (-5 *2 (-634 (-634 (-169 *5)))) (-5 *1 (-380 *5)) (-4 *5 (-13 (-365) (-840))))) (-3471 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 (-169 (-568))))) (-5 *2 (-634 (-169 *4))) (-5 *1 (-380 *4)) (-4 *4 (-13 (-365) (-840))))) (-3881 (*1 *2 *3 *4) (-12 (-5 *3 (-288 (-409 (-953 (-169 (-568)))))) (-5 *2 (-634 (-288 (-953 (-169 *4))))) (-5 *1 (-380 *4)) (-4 *4 (-13 (-365) (-840))))) (-3881 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 (-169 (-568))))) (-5 *2 (-634 (-288 (-953 (-169 *4))))) (-5 *1 (-380 *4)) (-4 *4 (-13 (-365) (-840))))) (-3881 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-288 (-409 (-953 (-169 (-568))))))) (-5 *2 (-634 (-634 (-288 (-953 (-169 *4)))))) (-5 *1 (-380 *4)) (-4 *4 (-13 (-365) (-840))))) (-3881 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-169 (-568)))))) (-5 *2 (-634 (-634 (-288 (-953 (-169 *4)))))) (-5 *1 (-380 *4)) (-4 *4 (-13 (-365) (-840)))))) 
-(-10 -7 (-15 -3881 ((-634 (-634 (-288 (-953 (-169 |#1|))))) (-634 (-409 (-953 (-169 (-568))))) |#1|)) (-15 -3881 ((-634 (-634 (-288 (-953 (-169 |#1|))))) (-634 (-288 (-409 (-953 (-169 (-568)))))) |#1|)) (-15 -3881 ((-634 (-288 (-953 (-169 |#1|)))) (-409 (-953 (-169 (-568)))) |#1|)) (-15 -3881 ((-634 (-288 (-953 (-169 |#1|)))) (-288 (-409 (-953 (-169 (-568))))) |#1|)) (-15 -3471 ((-634 (-169 |#1|)) (-409 (-953 (-169 (-568)))) |#1|)) (-15 -3471 ((-634 (-634 (-169 |#1|))) (-634 (-409 (-953 (-169 (-568))))) (-634 (-1161)) |#1|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 33)) (-1492 (((-568) $) 55)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-2617 (($ $) 109)) (-1982 (($ $) 81)) (-1933 (($ $) 70)) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1902 (($ $) 44)) (-1497 (((-121) $ $) NIL)) (-1974 (($ $) 79)) (-2786 (($ $) 68)) (-3662 (((-568) $) 63)) (-1870 (($ $ (-568)) 62)) (-1990 (($ $) NIL)) (-1941 (($ $) NIL)) (-2671 (($) NIL T CONST)) (-3047 (($ $) 111)) (-3666 (((-3 (-568) "failed") $) 187) (((-3 (-409 (-568)) "failed") $) 183)) (-2854 (((-568) $) 185) (((-409 (-568)) $) 181)) (-2401 (($ $ $) NIL)) (-3670 (((-568) $ $) 101)) (-2925 (((-3 $ "failed") $) 113)) (-4036 (((-409 (-568)) $ (-763)) 188) (((-409 (-568)) $ (-763) (-763)) 180)) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-3359 (((-917)) 72) (((-917) (-917)) 97 (|has| $ (-6 -4510)))) (-2033 (((-121) $) 105)) (-1897 (($) 40)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL)) (-3958 (((-1249) (-763)) 150)) (-2761 (((-1249)) 155) (((-1249) (-763)) 156)) (-2470 (((-1249)) 157) (((-1249) (-763)) 158)) (-1441 (((-1249)) 153) (((-1249) (-763)) 154)) (-4477 (((-568) $) 58)) (-2735 (((-121) $) 103)) (-4044 (($ $ (-568)) NIL)) (-3628 (($ $) 48)) (-2657 (($ $) NIL)) (-2245 (((-121) $) 35)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2521 (($ $ $) NIL) (($) NIL (-12 (-3044 (|has| $ (-6 -4502))) (-3044 (|has| $ (-6 -4510)))))) (-3268 (($ $ $) NIL) (($) 98 (-12 (-3044 (|has| $ (-6 -4502))) (-3044 (|has| $ (-6 -4510)))))) (-3544 (((-568) $) 17)) (-4299 (($) 86) (($ $) 91)) (-1907 (($) 90) (($ $) 92)) (-4416 (($ $) 82)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) 115)) (-2719 (((-917) (-568)) 43 (|has| $ (-6 -4510)))) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3880 (($ $) 53)) (-1519 (($ $) 108)) (-3768 (($ (-568) (-568)) 106) (($ (-568) (-568) (-917)) 107)) (-3848 (((-420 $) $) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3438 (((-568) $) 19)) (-2078 (($) 93)) (-1892 (($ $) 78)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3396 (((-917)) 99) (((-917) (-917)) 100 (|has| $ (-6 -4510)))) (-4189 (($ $ (-763)) NIL) (($ $) 114)) (-2573 (((-917) (-568)) 47 (|has| $ (-6 -4510)))) (-1994 (($ $) NIL)) (-1945 (($ $) NIL)) (-1986 (($ $) NIL)) (-1937 (($ $) NIL)) (-1978 (($ $) 80)) (-2790 (($ $) 69)) (-4278 (((-381) $) 173) (((-215) $) 175) (((-887 (-381)) $) NIL) (((-1143) $) 160) (((-541) $) 171) (($ (-215)) 179)) (-2745 (((-850) $) 162) (($ (-568)) 184) (($ $) NIL) (($ (-409 (-568))) NIL) (($ (-568)) 184) (($ (-409 (-568))) NIL) (((-215) $) 176)) (-4078 (((-763)) NIL)) (-2285 (($ $) 110)) (-4042 (((-917)) 54) (((-917) (-917)) 65 (|has| $ (-6 -4510)))) (-1461 (((-917)) 102)) (-2006 (($ $) 85)) (-1958 (($ $) 46) (($ $ $) 52)) (-1826 (((-121) $ $) NIL)) (-1998 (($ $) 83)) (-1949 (($ $) 37)) (-2014 (($ $) NIL)) (-1966 (($ $) NIL)) (-4023 (($ $) NIL)) (-1970 (($ $) NIL)) (-2010 (($ $) NIL)) (-1962 (($ $) NIL)) (-2002 (($ $) 84)) (-1953 (($ $) 49)) (-2897 (($ $) 51)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) 34 T CONST)) (-1556 (($) 38 T CONST)) (-3754 (((-1143) $) 27) (((-1143) $ (-121)) 29) (((-1249) (-817) $) 30) (((-1249) (-817) $ (-121)) 31)) (-3190 (($ $ (-763)) NIL) (($ $) NIL)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 39)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 42)) (-1779 (($ $ $) 45) (($ $ (-568)) 41)) (-1773 (($ $) 36) (($ $ $) 50)) (-1767 (($ $ $) 61)) (** (($ $ (-917)) 66) (($ $ (-763)) NIL) (($ $ (-568)) 87) (($ $ (-409 (-568))) 124) (($ $ $) 116)) (* (($ (-917) $) 64) (($ (-763) $) NIL) (($ (-568) $) 67) (($ $ $) 60) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL))) 
-(((-381) (-13 (-406) (-225) (-609 (-1143)) (-823) (-608 (-215)) (-1181) (-609 (-541)) (-10 -8 (-15 -1779 ($ $ (-568))) (-15 ** ($ $ $)) (-15 -3628 ($ $)) (-15 -3670 ((-568) $ $)) (-15 -1870 ($ $ (-568))) (-15 -4036 ((-409 (-568)) $ (-763))) (-15 -4036 ((-409 (-568)) $ (-763) (-763))) (-15 -4299 ($)) (-15 -1907 ($)) (-15 -2078 ($)) (-15 -1958 ($ $ $)) (-15 -4299 ($ $)) (-15 -1907 ($ $)) (-15 -4278 ($ (-215))) (-15 -2470 ((-1249))) (-15 -2470 ((-1249) (-763))) (-15 -1441 ((-1249))) (-15 -1441 ((-1249) (-763))) (-15 -2761 ((-1249))) (-15 -2761 ((-1249) (-763))) (-15 -3958 ((-1249) (-763))) (-6 -4510) (-6 -4502)))) (T -381)) 
-((** (*1 *1 *1 *1) (-5 *1 (-381))) (-1779 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-381)))) (-3628 (*1 *1 *1) (-5 *1 (-381))) (-3670 (*1 *2 *1 *1) (-12 (-5 *2 (-568)) (-5 *1 (-381)))) (-1870 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-381)))) (-4036 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-409 (-568))) (-5 *1 (-381)))) (-4036 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-409 (-568))) (-5 *1 (-381)))) (-4299 (*1 *1) (-5 *1 (-381))) (-1907 (*1 *1) (-5 *1 (-381))) (-2078 (*1 *1) (-5 *1 (-381))) (-1958 (*1 *1 *1 *1) (-5 *1 (-381))) (-4299 (*1 *1 *1) (-5 *1 (-381))) (-1907 (*1 *1 *1) (-5 *1 (-381))) (-4278 (*1 *1 *2) (-12 (-5 *2 (-215)) (-5 *1 (-381)))) (-2470 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-381)))) (-2470 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-381)))) (-1441 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-381)))) (-1441 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-381)))) (-2761 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-381)))) (-2761 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-381)))) (-3958 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-381))))) 
-(-13 (-406) (-225) (-609 (-1143)) (-823) (-608 (-215)) (-1181) (-609 (-541)) (-10 -8 (-15 -1779 ($ $ (-568))) (-15 ** ($ $ $)) (-15 -3628 ($ $)) (-15 -3670 ((-568) $ $)) (-15 -1870 ($ $ (-568))) (-15 -4036 ((-409 (-568)) $ (-763))) (-15 -4036 ((-409 (-568)) $ (-763) (-763))) (-15 -4299 ($)) (-15 -1907 ($)) (-15 -2078 ($)) (-15 -1958 ($ $ $)) (-15 -4299 ($ $)) (-15 -1907 ($ $)) (-15 -4278 ($ (-215))) (-15 -2470 ((-1249))) (-15 -2470 ((-1249) (-763))) (-15 -1441 ((-1249))) (-15 -1441 ((-1249) (-763))) (-15 -2761 ((-1249))) (-15 -2761 ((-1249) (-763))) (-15 -3958 ((-1249) (-763))) (-6 -4510) (-6 -4502))) 
-((-4351 (((-634 (-288 (-953 |#1|))) (-288 (-409 (-953 (-568)))) |#1|) 47) (((-634 (-288 (-953 |#1|))) (-409 (-953 (-568))) |#1|) 46) (((-634 (-634 (-288 (-953 |#1|)))) (-634 (-288 (-409 (-953 (-568))))) |#1|) 42) (((-634 (-634 (-288 (-953 |#1|)))) (-634 (-409 (-953 (-568)))) |#1|) 36)) (-4231 (((-634 |#1|) (-409 (-953 (-568))) |#1|) 19) (((-634 (-634 |#1|)) (-634 (-409 (-953 (-568)))) (-634 (-1161)) |#1|) 31))) 
-(((-382 |#1|) (-10 -7 (-15 -4351 ((-634 (-634 (-288 (-953 |#1|)))) (-634 (-409 (-953 (-568)))) |#1|)) (-15 -4351 ((-634 (-634 (-288 (-953 |#1|)))) (-634 (-288 (-409 (-953 (-568))))) |#1|)) (-15 -4351 ((-634 (-288 (-953 |#1|))) (-409 (-953 (-568))) |#1|)) (-15 -4351 ((-634 (-288 (-953 |#1|))) (-288 (-409 (-953 (-568)))) |#1|)) (-15 -4231 ((-634 (-634 |#1|)) (-634 (-409 (-953 (-568)))) (-634 (-1161)) |#1|)) (-15 -4231 ((-634 |#1|) (-409 (-953 (-568))) |#1|))) (-13 (-840) (-365))) (T -382)) 
-((-4231 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 (-568)))) (-5 *2 (-634 *4)) (-5 *1 (-382 *4)) (-4 *4 (-13 (-840) (-365))))) (-4231 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-1161))) (-5 *2 (-634 (-634 *5))) (-5 *1 (-382 *5)) (-4 *5 (-13 (-840) (-365))))) (-4351 (*1 *2 *3 *4) (-12 (-5 *3 (-288 (-409 (-953 (-568))))) (-5 *2 (-634 (-288 (-953 *4)))) (-5 *1 (-382 *4)) (-4 *4 (-13 (-840) (-365))))) (-4351 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 (-568)))) (-5 *2 (-634 (-288 (-953 *4)))) (-5 *1 (-382 *4)) (-4 *4 (-13 (-840) (-365))))) (-4351 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-288 (-409 (-953 (-568)))))) (-5 *2 (-634 (-634 (-288 (-953 *4))))) (-5 *1 (-382 *4)) (-4 *4 (-13 (-840) (-365))))) (-4351 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-634 (-288 (-953 *4))))) (-5 *1 (-382 *4)) (-4 *4 (-13 (-840) (-365)))))) 
-(-10 -7 (-15 -4351 ((-634 (-634 (-288 (-953 |#1|)))) (-634 (-409 (-953 (-568)))) |#1|)) (-15 -4351 ((-634 (-634 (-288 (-953 |#1|)))) (-634 (-288 (-409 (-953 (-568))))) |#1|)) (-15 -4351 ((-634 (-288 (-953 |#1|))) (-409 (-953 (-568))) |#1|)) (-15 -4351 ((-634 (-288 (-953 |#1|))) (-288 (-409 (-953 (-568)))) |#1|)) (-15 -4231 ((-634 (-634 |#1|)) (-634 (-409 (-953 (-568)))) (-634 (-1161)) |#1|)) (-15 -4231 ((-634 |#1|) (-409 (-953 (-568))) |#1|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#2| "failed") $) 25)) (-2854 ((|#2| $) 27)) (-2114 (($ $) NIL)) (-4178 (((-763) $) 10)) (-2976 (((-634 $) $) 20)) (-3921 (((-121) $) NIL)) (-2354 (($ |#2| |#1|) 18)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-4297 (((-634 (-2 (|:| |k| |#2|) (|:| |c| |#1|))) $) 13)) (-2315 (((-2 (|:| |k| |#2|) (|:| |c| |#1|)) $) 14)) (-2097 ((|#2| $) 15)) (-2102 ((|#1| $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 43) (($ |#2|) 26)) (-1302 (((-634 |#1|) $) 17)) (-2604 ((|#1| $ |#2|) 45)) (-3056 (($) 28 T CONST)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ |#1| $) 31) (($ $ |#1|) 32) (($ |#1| |#2|) 33) (($ |#2| |#1|) 34))) 
+((-2003 (((-634 (-288 (-953 (-169 |#1|)))) (-288 (-409 (-953 (-169 (-568))))) |#1|) 52) (((-634 (-288 (-953 (-169 |#1|)))) (-409 (-953 (-169 (-568)))) |#1|) 51) (((-634 (-634 (-288 (-953 (-169 |#1|))))) (-634 (-288 (-409 (-953 (-169 (-568)))))) |#1|) 47) (((-634 (-634 (-288 (-953 (-169 |#1|))))) (-634 (-409 (-953 (-169 (-568))))) |#1|) 40)) (-3722 (((-634 (-634 (-169 |#1|))) (-634 (-409 (-953 (-169 (-568))))) (-634 (-1161)) |#1|) 28) (((-634 (-169 |#1|)) (-409 (-953 (-169 (-568)))) |#1|) 15))) 
+(((-380 |#1|) (-10 -7 (-15 -2003 ((-634 (-634 (-288 (-953 (-169 |#1|))))) (-634 (-409 (-953 (-169 (-568))))) |#1|)) (-15 -2003 ((-634 (-634 (-288 (-953 (-169 |#1|))))) (-634 (-288 (-409 (-953 (-169 (-568)))))) |#1|)) (-15 -2003 ((-634 (-288 (-953 (-169 |#1|)))) (-409 (-953 (-169 (-568)))) |#1|)) (-15 -2003 ((-634 (-288 (-953 (-169 |#1|)))) (-288 (-409 (-953 (-169 (-568))))) |#1|)) (-15 -3722 ((-634 (-169 |#1|)) (-409 (-953 (-169 (-568)))) |#1|)) (-15 -3722 ((-634 (-634 (-169 |#1|))) (-634 (-409 (-953 (-169 (-568))))) (-634 (-1161)) |#1|))) (-13 (-365) (-840))) (T -380)) 
+((-3722 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-409 (-953 (-169 (-568)))))) (-5 *4 (-634 (-1161))) (-5 *2 (-634 (-634 (-169 *5)))) (-5 *1 (-380 *5)) (-4 *5 (-13 (-365) (-840))))) (-3722 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 (-169 (-568))))) (-5 *2 (-634 (-169 *4))) (-5 *1 (-380 *4)) (-4 *4 (-13 (-365) (-840))))) (-2003 (*1 *2 *3 *4) (-12 (-5 *3 (-288 (-409 (-953 (-169 (-568)))))) (-5 *2 (-634 (-288 (-953 (-169 *4))))) (-5 *1 (-380 *4)) (-4 *4 (-13 (-365) (-840))))) (-2003 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 (-169 (-568))))) (-5 *2 (-634 (-288 (-953 (-169 *4))))) (-5 *1 (-380 *4)) (-4 *4 (-13 (-365) (-840))))) (-2003 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-288 (-409 (-953 (-169 (-568))))))) (-5 *2 (-634 (-634 (-288 (-953 (-169 *4)))))) (-5 *1 (-380 *4)) (-4 *4 (-13 (-365) (-840))))) (-2003 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-169 (-568)))))) (-5 *2 (-634 (-634 (-288 (-953 (-169 *4)))))) (-5 *1 (-380 *4)) (-4 *4 (-13 (-365) (-840)))))) 
+(-10 -7 (-15 -2003 ((-634 (-634 (-288 (-953 (-169 |#1|))))) (-634 (-409 (-953 (-169 (-568))))) |#1|)) (-15 -2003 ((-634 (-634 (-288 (-953 (-169 |#1|))))) (-634 (-288 (-409 (-953 (-169 (-568)))))) |#1|)) (-15 -2003 ((-634 (-288 (-953 (-169 |#1|)))) (-409 (-953 (-169 (-568)))) |#1|)) (-15 -2003 ((-634 (-288 (-953 (-169 |#1|)))) (-288 (-409 (-953 (-169 (-568))))) |#1|)) (-15 -3722 ((-634 (-169 |#1|)) (-409 (-953 (-169 (-568)))) |#1|)) (-15 -3722 ((-634 (-634 (-169 |#1|))) (-634 (-409 (-953 (-169 (-568))))) (-634 (-1161)) |#1|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 33)) (-2563 (((-568) $) 55)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-4179 (($ $) 109)) (-1984 (($ $) 81)) (-1935 (($ $) 70)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-1904 (($ $) 44)) (-2589 (((-121) $ $) NIL)) (-1976 (($ $) 79)) (-2788 (($ $) 68)) (-3337 (((-568) $) 63)) (-1872 (($ $ (-568)) 62)) (-1992 (($ $) NIL)) (-1943 (($ $) NIL)) (-4490 (($) NIL T CONST)) (-2252 (($ $) 111)) (-3668 (((-3 (-568) "failed") $) 187) (((-3 (-409 (-568)) "failed") $) 183)) (-2857 (((-568) $) 185) (((-409 (-568)) $) 181)) (-2403 (($ $ $) NIL)) (-2236 (((-568) $ $) 101)) (-2902 (((-3 $ "failed") $) 113)) (-1508 (((-409 (-568)) $ (-763)) 188) (((-409 (-568)) $ (-763) (-763)) 180)) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-3359 (((-917)) 72) (((-917) (-917)) 97 (|has| $ (-6 -4512)))) (-1436 (((-121) $) 105)) (-1899 (($) 40)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL)) (-4396 (((-1249) (-763)) 150)) (-3455 (((-1249)) 155) (((-1249) (-763)) 156)) (-2615 (((-1249)) 157) (((-1249) (-763)) 158)) (-2297 (((-1249)) 153) (((-1249) (-763)) 154)) (-1844 (((-568) $) 58)) (-1598 (((-121) $) 103)) (-1550 (($ $ (-568)) NIL)) (-3126 (($ $) 48)) (-4417 (($ $) NIL)) (-2859 (((-121) $) 35)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1732 (($ $ $) NIL) (($) NIL (-12 (-3046 (|has| $ (-6 -4504))) (-3046 (|has| $ (-6 -4512)))))) (-2047 (($ $ $) NIL) (($) 98 (-12 (-3046 (|has| $ (-6 -4504))) (-3046 (|has| $ (-6 -4512)))))) (-2790 (((-568) $) 17)) (-3025 (($) 86) (($ $) 91)) (-2658 (($) 90) (($ $) 92)) (-4418 (($ $) 82)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) 115)) (-1529 (((-917) (-568)) 43 (|has| $ (-6 -4512)))) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1999 (($ $) 53)) (-4115 (($ $) 108)) (-3770 (($ (-568) (-568)) 106) (($ (-568) (-568) (-917)) 107)) (-3850 (((-420 $) $) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3483 (((-568) $) 19)) (-3111 (($) 93)) (-1894 (($ $) 78)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-1513 (((-917)) 99) (((-917) (-917)) 100 (|has| $ (-6 -4512)))) (-4191 (($ $ (-763)) NIL) (($ $) 114)) (-1973 (((-917) (-568)) 47 (|has| $ (-6 -4512)))) (-1996 (($ $) NIL)) (-1947 (($ $) NIL)) (-1988 (($ $) NIL)) (-1939 (($ $) NIL)) (-1980 (($ $) 80)) (-2792 (($ $) 69)) (-4280 (((-381) $) 173) (((-215) $) 175) (((-887 (-381)) $) NIL) (((-1143) $) 160) (((-541) $) 171) (($ (-215)) 179)) (-2747 (((-850) $) 162) (($ (-568)) 184) (($ $) NIL) (($ (-409 (-568))) NIL) (($ (-568)) 184) (($ (-409 (-568))) NIL) (((-215) $) 176)) (-3425 (((-763)) NIL)) (-3520 (($ $) 110)) (-1540 (((-917)) 54) (((-917) (-917)) 65 (|has| $ (-6 -4512)))) (-2404 (((-917)) 102)) (-2008 (($ $) 85)) (-1959 (($ $) 46) (($ $ $) 52)) (-2273 (((-121) $ $) NIL)) (-2000 (($ $) 83)) (-1951 (($ $) 37)) (-2016 (($ $) NIL)) (-1968 (($ $) NIL)) (-1439 (($ $) NIL)) (-1972 (($ $) NIL)) (-2012 (($ $) NIL)) (-1964 (($ $) NIL)) (-2004 (($ $) 84)) (-1955 (($ $) 49)) (-2811 (($ $) 51)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) 34 T CONST)) (-1557 (($) 38 T CONST)) (-2628 (((-1143) $) 27) (((-1143) $ (-121)) 29) (((-1249) (-817) $) 30) (((-1249) (-817) $ (-121)) 31)) (-3192 (($ $ (-763)) NIL) (($ $) NIL)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 39)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 42)) (-1781 (($ $ $) 45) (($ $ (-568)) 41)) (-1775 (($ $) 36) (($ $ $) 50)) (-1769 (($ $ $) 61)) (** (($ $ (-917)) 66) (($ $ (-763)) NIL) (($ $ (-568)) 87) (($ $ (-409 (-568))) 124) (($ $ $) 116)) (* (($ (-917) $) 64) (($ (-763) $) NIL) (($ (-568) $) 67) (($ $ $) 60) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL))) 
+(((-381) (-13 (-406) (-225) (-609 (-1143)) (-823) (-608 (-215)) (-1181) (-609 (-541)) (-10 -8 (-15 -1781 ($ $ (-568))) (-15 ** ($ $ $)) (-15 -3126 ($ $)) (-15 -2236 ((-568) $ $)) (-15 -1872 ($ $ (-568))) (-15 -1508 ((-409 (-568)) $ (-763))) (-15 -1508 ((-409 (-568)) $ (-763) (-763))) (-15 -3025 ($)) (-15 -2658 ($)) (-15 -3111 ($)) (-15 -1959 ($ $ $)) (-15 -3025 ($ $)) (-15 -2658 ($ $)) (-15 -4280 ($ (-215))) (-15 -2615 ((-1249))) (-15 -2615 ((-1249) (-763))) (-15 -2297 ((-1249))) (-15 -2297 ((-1249) (-763))) (-15 -3455 ((-1249))) (-15 -3455 ((-1249) (-763))) (-15 -4396 ((-1249) (-763))) (-6 -4512) (-6 -4504)))) (T -381)) 
+((** (*1 *1 *1 *1) (-5 *1 (-381))) (-1781 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-381)))) (-3126 (*1 *1 *1) (-5 *1 (-381))) (-2236 (*1 *2 *1 *1) (-12 (-5 *2 (-568)) (-5 *1 (-381)))) (-1872 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-381)))) (-1508 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-409 (-568))) (-5 *1 (-381)))) (-1508 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-409 (-568))) (-5 *1 (-381)))) (-3025 (*1 *1) (-5 *1 (-381))) (-2658 (*1 *1) (-5 *1 (-381))) (-3111 (*1 *1) (-5 *1 (-381))) (-1959 (*1 *1 *1 *1) (-5 *1 (-381))) (-3025 (*1 *1 *1) (-5 *1 (-381))) (-2658 (*1 *1 *1) (-5 *1 (-381))) (-4280 (*1 *1 *2) (-12 (-5 *2 (-215)) (-5 *1 (-381)))) (-2615 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-381)))) (-2615 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-381)))) (-2297 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-381)))) (-2297 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-381)))) (-3455 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-381)))) (-3455 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-381)))) (-4396 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-381))))) 
+(-13 (-406) (-225) (-609 (-1143)) (-823) (-608 (-215)) (-1181) (-609 (-541)) (-10 -8 (-15 -1781 ($ $ (-568))) (-15 ** ($ $ $)) (-15 -3126 ($ $)) (-15 -2236 ((-568) $ $)) (-15 -1872 ($ $ (-568))) (-15 -1508 ((-409 (-568)) $ (-763))) (-15 -1508 ((-409 (-568)) $ (-763) (-763))) (-15 -3025 ($)) (-15 -2658 ($)) (-15 -3111 ($)) (-15 -1959 ($ $ $)) (-15 -3025 ($ $)) (-15 -2658 ($ $)) (-15 -4280 ($ (-215))) (-15 -2615 ((-1249))) (-15 -2615 ((-1249) (-763))) (-15 -2297 ((-1249))) (-15 -2297 ((-1249) (-763))) (-15 -3455 ((-1249))) (-15 -3455 ((-1249) (-763))) (-15 -4396 ((-1249) (-763))) (-6 -4512) (-6 -4504))) 
+((-3259 (((-634 (-288 (-953 |#1|))) (-288 (-409 (-953 (-568)))) |#1|) 47) (((-634 (-288 (-953 |#1|))) (-409 (-953 (-568))) |#1|) 46) (((-634 (-634 (-288 (-953 |#1|)))) (-634 (-288 (-409 (-953 (-568))))) |#1|) 42) (((-634 (-634 (-288 (-953 |#1|)))) (-634 (-409 (-953 (-568)))) |#1|) 36)) (-4250 (((-634 |#1|) (-409 (-953 (-568))) |#1|) 19) (((-634 (-634 |#1|)) (-634 (-409 (-953 (-568)))) (-634 (-1161)) |#1|) 31))) 
+(((-382 |#1|) (-10 -7 (-15 -3259 ((-634 (-634 (-288 (-953 |#1|)))) (-634 (-409 (-953 (-568)))) |#1|)) (-15 -3259 ((-634 (-634 (-288 (-953 |#1|)))) (-634 (-288 (-409 (-953 (-568))))) |#1|)) (-15 -3259 ((-634 (-288 (-953 |#1|))) (-409 (-953 (-568))) |#1|)) (-15 -3259 ((-634 (-288 (-953 |#1|))) (-288 (-409 (-953 (-568)))) |#1|)) (-15 -4250 ((-634 (-634 |#1|)) (-634 (-409 (-953 (-568)))) (-634 (-1161)) |#1|)) (-15 -4250 ((-634 |#1|) (-409 (-953 (-568))) |#1|))) (-13 (-840) (-365))) (T -382)) 
+((-4250 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 (-568)))) (-5 *2 (-634 *4)) (-5 *1 (-382 *4)) (-4 *4 (-13 (-840) (-365))))) (-4250 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-1161))) (-5 *2 (-634 (-634 *5))) (-5 *1 (-382 *5)) (-4 *5 (-13 (-840) (-365))))) (-3259 (*1 *2 *3 *4) (-12 (-5 *3 (-288 (-409 (-953 (-568))))) (-5 *2 (-634 (-288 (-953 *4)))) (-5 *1 (-382 *4)) (-4 *4 (-13 (-840) (-365))))) (-3259 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 (-568)))) (-5 *2 (-634 (-288 (-953 *4)))) (-5 *1 (-382 *4)) (-4 *4 (-13 (-840) (-365))))) (-3259 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-288 (-409 (-953 (-568)))))) (-5 *2 (-634 (-634 (-288 (-953 *4))))) (-5 *1 (-382 *4)) (-4 *4 (-13 (-840) (-365))))) (-3259 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-634 (-288 (-953 *4))))) (-5 *1 (-382 *4)) (-4 *4 (-13 (-840) (-365)))))) 
+(-10 -7 (-15 -3259 ((-634 (-634 (-288 (-953 |#1|)))) (-634 (-409 (-953 (-568)))) |#1|)) (-15 -3259 ((-634 (-634 (-288 (-953 |#1|)))) (-634 (-288 (-409 (-953 (-568))))) |#1|)) (-15 -3259 ((-634 (-288 (-953 |#1|))) (-409 (-953 (-568))) |#1|)) (-15 -3259 ((-634 (-288 (-953 |#1|))) (-288 (-409 (-953 (-568)))) |#1|)) (-15 -4250 ((-634 (-634 |#1|)) (-634 (-409 (-953 (-568)))) (-634 (-1161)) |#1|)) (-15 -4250 ((-634 |#1|) (-409 (-953 (-568))) |#1|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#2| "failed") $) 25)) (-2857 ((|#2| $) 27)) (-2116 (($ $) NIL)) (-3971 (((-763) $) 10)) (-3062 (((-634 $) $) 20)) (-2171 (((-121) $) NIL)) (-2356 (($ |#2| |#1|) 18)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-3016 (((-634 (-2 (|:| |k| |#2|) (|:| |c| |#1|))) $) 13)) (-3749 (((-2 (|:| |k| |#2|) (|:| |c| |#1|)) $) 14)) (-2099 ((|#2| $) 15)) (-2104 ((|#1| $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 43) (($ |#2|) 26)) (-3304 (((-634 |#1|) $) 17)) (-2079 ((|#1| $ |#2|) 45)) (-3058 (($) 28 T CONST)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ |#1| $) 31) (($ $ |#1|) 32) (($ |#1| |#2|) 33) (($ |#2| |#1|) 34))) 
 (((-383 |#1| |#2|) (-13 (-384 |#1| |#2|) (-10 -8 (-15 * ($ |#2| |#1|)))) (-1047) (-842)) (T -383)) 
 ((* (*1 *1 *2 *3) (-12 (-5 *1 (-383 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-842))))) 
 (-13 (-384 |#1| |#2|) (-10 -8 (-15 * ($ |#2| |#1|)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-3666 (((-3 |#2| "failed") $) 41)) (-2854 ((|#2| $) 40)) (-2114 (($ $) 27)) (-4178 (((-763) $) 31)) (-2976 (((-634 $) $) 32)) (-3921 (((-121) $) 35)) (-2354 (($ |#2| |#1|) 36)) (-2795 (($ (-1 |#1| |#1|) $) 37)) (-4297 (((-634 (-2 (|:| |k| |#2|) (|:| |c| |#1|))) $) 34)) (-2315 (((-2 (|:| |k| |#2|) (|:| |c| |#1|)) $) 28)) (-2097 ((|#2| $) 30)) (-2102 ((|#1| $) 29)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11) (($ |#2|) 42)) (-1302 (((-634 |#1|) $) 33)) (-2604 ((|#1| $ |#2|) 38)) (-3056 (($) 17 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ |#1| $) 22) (($ $ |#1|) 24) (($ |#1| |#2|) 39))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-3668 (((-3 |#2| "failed") $) 41)) (-2857 ((|#2| $) 40)) (-2116 (($ $) 27)) (-3971 (((-763) $) 31)) (-3062 (((-634 $) $) 32)) (-2171 (((-121) $) 35)) (-2356 (($ |#2| |#1|) 36)) (-2797 (($ (-1 |#1| |#1|) $) 37)) (-3016 (((-634 (-2 (|:| |k| |#2|) (|:| |c| |#1|))) $) 34)) (-3749 (((-2 (|:| |k| |#2|) (|:| |c| |#1|)) $) 28)) (-2099 ((|#2| $) 30)) (-2104 ((|#1| $) 29)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11) (($ |#2|) 42)) (-3304 (((-634 |#1|) $) 33)) (-2079 ((|#1| $ |#2|) 38)) (-3058 (($) 17 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ |#1| $) 22) (($ $ |#1|) 24) (($ |#1| |#2|) 39))) 
 (((-384 |#1| |#2|) (-1275) (-1047) (-1090)) (T -384)) 
-((* (*1 *1 *2 *3) (-12 (-4 *1 (-384 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-1090)))) (-2604 (*1 *2 *1 *3) (-12 (-4 *1 (-384 *2 *3)) (-4 *3 (-1090)) (-4 *2 (-1047)))) (-2795 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)))) (-2354 (*1 *1 *2 *3) (-12 (-4 *1 (-384 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1090)))) (-3921 (*1 *2 *1) (-12 (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-121)))) (-4297 (*1 *2 *1) (-12 (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-634 (-2 (|:| |k| *4) (|:| |c| *3)))))) (-1302 (*1 *2 *1) (-12 (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-634 *3)))) (-2976 (*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-634 *1)) (-4 *1 (-384 *3 *4)))) (-4178 (*1 *2 *1) (-12 (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-763)))) (-2097 (*1 *2 *1) (-12 (-4 *1 (-384 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1090)))) (-2102 (*1 *2 *1) (-12 (-4 *1 (-384 *2 *3)) (-4 *3 (-1090)) (-4 *2 (-1047)))) (-2315 (*1 *2 *1) (-12 (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-2 (|:| |k| *4) (|:| |c| *3))))) (-2114 (*1 *1 *1) (-12 (-4 *1 (-384 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-1090))))) 
-(-13 (-120 |t#1| |t#1|) (-1037 |t#2|) (-10 -8 (-15 * ($ |t#1| |t#2|)) (-15 -2604 (|t#1| $ |t#2|)) (-15 -2795 ($ (-1 |t#1| |t#1|) $)) (-15 -2354 ($ |t#2| |t#1|)) (-15 -3921 ((-121) $)) (-15 -4297 ((-634 (-2 (|:| |k| |t#2|) (|:| |c| |t#1|))) $)) (-15 -1302 ((-634 |t#1|) $)) (-15 -2976 ((-634 $) $)) (-15 -4178 ((-763) $)) (-15 -2097 (|t#2| $)) (-15 -2102 (|t#1| $)) (-15 -2315 ((-2 (|:| |k| |t#2|) (|:| |c| |t#1|)) $)) (-15 -2114 ($ $)) (IF (|has| |t#1| (-172)) (-6 (-707 |t#1|)) |noBranch|))) 
+((* (*1 *1 *2 *3) (-12 (-4 *1 (-384 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-1090)))) (-2079 (*1 *2 *1 *3) (-12 (-4 *1 (-384 *2 *3)) (-4 *3 (-1090)) (-4 *2 (-1047)))) (-2797 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)))) (-2356 (*1 *1 *2 *3) (-12 (-4 *1 (-384 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1090)))) (-2171 (*1 *2 *1) (-12 (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-121)))) (-3016 (*1 *2 *1) (-12 (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-634 (-2 (|:| |k| *4) (|:| |c| *3)))))) (-3304 (*1 *2 *1) (-12 (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-634 *3)))) (-3062 (*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-634 *1)) (-4 *1 (-384 *3 *4)))) (-3971 (*1 *2 *1) (-12 (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-763)))) (-2099 (*1 *2 *1) (-12 (-4 *1 (-384 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1090)))) (-2104 (*1 *2 *1) (-12 (-4 *1 (-384 *2 *3)) (-4 *3 (-1090)) (-4 *2 (-1047)))) (-3749 (*1 *2 *1) (-12 (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-2 (|:| |k| *4) (|:| |c| *3))))) (-2116 (*1 *1 *1) (-12 (-4 *1 (-384 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-1090))))) 
+(-13 (-120 |t#1| |t#1|) (-1037 |t#2|) (-10 -8 (-15 * ($ |t#1| |t#2|)) (-15 -2079 (|t#1| $ |t#2|)) (-15 -2797 ($ (-1 |t#1| |t#1|) $)) (-15 -2356 ($ |t#2| |t#1|)) (-15 -2171 ((-121) $)) (-15 -3016 ((-634 (-2 (|:| |k| |t#2|) (|:| |c| |t#1|))) $)) (-15 -3304 ((-634 |t#1|) $)) (-15 -3062 ((-634 $) $)) (-15 -3971 ((-763) $)) (-15 -2099 (|t#2| $)) (-15 -2104 (|t#1| $)) (-15 -3749 ((-2 (|:| |k| |t#2|) (|:| |c| |t#1|)) $)) (-15 -2116 ($ $)) (IF (|has| |t#1| (-172)) (-6 (-707 |t#1|)) |noBranch|))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 |#1| |#1|) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 |#1|) . T) ((-707 |#1|) |has| |#1| (-172)) ((-1037 |#2|) . T) ((-1053 |#1|) . T) ((-1090) . T)) 
-((-4128 (((-1249) $) 7)) (-2745 (((-850) $) 8) (($ (-679 (-688))) 12) (($ (-634 (-328))) 11) (($ (-328)) 10) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 9))) 
+((-4130 (((-1249) $) 7)) (-2747 (((-850) $) 8) (($ (-679 (-688))) 12) (($ (-634 (-328))) 11) (($ (-328)) 10) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 9))) 
 (((-385) (-1275)) (T -385)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-679 (-688))) (-4 *1 (-385)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-4 *1 (-385)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-328)) (-4 *1 (-385)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) (-4 *1 (-385))))) 
-(-13 (-397) (-10 -8 (-15 -2745 ($ (-679 (-688)))) (-15 -2745 ($ (-634 (-328)))) (-15 -2745 ($ (-328))) (-15 -2745 ($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328)))))))) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-679 (-688))) (-4 *1 (-385)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-4 *1 (-385)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-328)) (-4 *1 (-385)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) (-4 *1 (-385))))) 
+(-13 (-397) (-10 -8 (-15 -2747 ($ (-679 (-688)))) (-15 -2747 ($ (-634 (-328)))) (-15 -2747 ($ (-328))) (-15 -2747 ($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328)))))))) 
 (((-608 (-850)) . T) ((-397) . T) ((-1195) . T)) 
-((-3666 (((-3 $ "failed") (-679 (-310 (-381)))) 19) (((-3 $ "failed") (-679 (-310 (-568)))) 17) (((-3 $ "failed") (-679 (-953 (-381)))) 15) (((-3 $ "failed") (-679 (-953 (-568)))) 13) (((-3 $ "failed") (-679 (-409 (-953 (-381))))) 11) (((-3 $ "failed") (-679 (-409 (-953 (-568))))) 9)) (-2854 (($ (-679 (-310 (-381)))) 20) (($ (-679 (-310 (-568)))) 18) (($ (-679 (-953 (-381)))) 16) (($ (-679 (-953 (-568)))) 14) (($ (-679 (-409 (-953 (-381))))) 12) (($ (-679 (-409 (-953 (-568))))) 10)) (-4128 (((-1249) $) 7)) (-2745 (((-850) $) 8) (($ (-634 (-328))) 23) (($ (-328)) 22) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 21))) 
+((-3668 (((-3 $ "failed") (-679 (-310 (-381)))) 19) (((-3 $ "failed") (-679 (-310 (-568)))) 17) (((-3 $ "failed") (-679 (-953 (-381)))) 15) (((-3 $ "failed") (-679 (-953 (-568)))) 13) (((-3 $ "failed") (-679 (-409 (-953 (-381))))) 11) (((-3 $ "failed") (-679 (-409 (-953 (-568))))) 9)) (-2857 (($ (-679 (-310 (-381)))) 20) (($ (-679 (-310 (-568)))) 18) (($ (-679 (-953 (-381)))) 16) (($ (-679 (-953 (-568)))) 14) (($ (-679 (-409 (-953 (-381))))) 12) (($ (-679 (-409 (-953 (-568))))) 10)) (-4130 (((-1249) $) 7)) (-2747 (((-850) $) 8) (($ (-634 (-328))) 23) (($ (-328)) 22) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 21))) 
 (((-386) (-1275)) (T -386)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-4 *1 (-386)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-328)) (-4 *1 (-386)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) (-4 *1 (-386)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-679 (-310 (-381)))) (-4 *1 (-386)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-310 (-381)))) (-4 *1 (-386)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-679 (-310 (-568)))) (-4 *1 (-386)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-310 (-568)))) (-4 *1 (-386)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-679 (-953 (-381)))) (-4 *1 (-386)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-953 (-381)))) (-4 *1 (-386)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-679 (-953 (-568)))) (-4 *1 (-386)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-953 (-568)))) (-4 *1 (-386)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-679 (-409 (-953 (-381))))) (-4 *1 (-386)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-409 (-953 (-381))))) (-4 *1 (-386)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-679 (-409 (-953 (-568))))) (-4 *1 (-386)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-409 (-953 (-568))))) (-4 *1 (-386))))) 
-(-13 (-397) (-10 -8 (-15 -2745 ($ (-634 (-328)))) (-15 -2745 ($ (-328))) (-15 -2745 ($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328)))))) (-15 -2854 ($ (-679 (-310 (-381))))) (-15 -3666 ((-3 $ "failed") (-679 (-310 (-381))))) (-15 -2854 ($ (-679 (-310 (-568))))) (-15 -3666 ((-3 $ "failed") (-679 (-310 (-568))))) (-15 -2854 ($ (-679 (-953 (-381))))) (-15 -3666 ((-3 $ "failed") (-679 (-953 (-381))))) (-15 -2854 ($ (-679 (-953 (-568))))) (-15 -3666 ((-3 $ "failed") (-679 (-953 (-568))))) (-15 -2854 ($ (-679 (-409 (-953 (-381)))))) (-15 -3666 ((-3 $ "failed") (-679 (-409 (-953 (-381)))))) (-15 -2854 ($ (-679 (-409 (-953 (-568)))))) (-15 -3666 ((-3 $ "failed") (-679 (-409 (-953 (-568)))))))) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-4 *1 (-386)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-328)) (-4 *1 (-386)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) (-4 *1 (-386)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-679 (-310 (-381)))) (-4 *1 (-386)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-310 (-381)))) (-4 *1 (-386)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-679 (-310 (-568)))) (-4 *1 (-386)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-310 (-568)))) (-4 *1 (-386)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-679 (-953 (-381)))) (-4 *1 (-386)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-953 (-381)))) (-4 *1 (-386)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-679 (-953 (-568)))) (-4 *1 (-386)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-953 (-568)))) (-4 *1 (-386)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-679 (-409 (-953 (-381))))) (-4 *1 (-386)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-409 (-953 (-381))))) (-4 *1 (-386)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-679 (-409 (-953 (-568))))) (-4 *1 (-386)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-409 (-953 (-568))))) (-4 *1 (-386))))) 
+(-13 (-397) (-10 -8 (-15 -2747 ($ (-634 (-328)))) (-15 -2747 ($ (-328))) (-15 -2747 ($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328)))))) (-15 -2857 ($ (-679 (-310 (-381))))) (-15 -3668 ((-3 $ "failed") (-679 (-310 (-381))))) (-15 -2857 ($ (-679 (-310 (-568))))) (-15 -3668 ((-3 $ "failed") (-679 (-310 (-568))))) (-15 -2857 ($ (-679 (-953 (-381))))) (-15 -3668 ((-3 $ "failed") (-679 (-953 (-381))))) (-15 -2857 ($ (-679 (-953 (-568))))) (-15 -3668 ((-3 $ "failed") (-679 (-953 (-568))))) (-15 -2857 ($ (-679 (-409 (-953 (-381)))))) (-15 -3668 ((-3 $ "failed") (-679 (-409 (-953 (-381)))))) (-15 -2857 ($ (-679 (-409 (-953 (-568)))))) (-15 -3668 ((-3 $ "failed") (-679 (-409 (-953 (-568)))))))) 
 (((-608 (-850)) . T) ((-397) . T) ((-1195) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-2114 (($ $) NIL)) (-2047 (($ |#1| |#2|) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-1311 ((|#2| $) NIL)) (-2102 ((|#1| $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 27)) (-3056 (($) 12 T CONST)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ |#1| $) 16) (($ $ |#1|) 18))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-2116 (($ $) NIL)) (-2049 (($ |#1| |#2|) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-3369 ((|#2| $) NIL)) (-2104 ((|#1| $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 27)) (-3058 (($) 12 T CONST)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ |#1| $) 16) (($ $ |#1|) 18))) 
 (((-387 |#1| |#2|) (-13 (-120 |#1| |#1|) (-518 |#1| |#2|) (-10 -7 (IF (|has| |#1| (-172)) (-6 (-707 |#1|)) |noBranch|))) (-1047) (-842)) (T -387)) 
 NIL 
 (-13 (-120 |#1| |#1|) (-518 |#1| |#2|) (-10 -7 (IF (|has| |#1| (-172)) (-6 (-707 |#1|)) |noBranch|))) 
-((-2447 (((-121) $ $) NIL)) (-3983 (((-763) $) 56)) (-2671 (($) NIL T CONST)) (-2628 (((-3 $ "failed") $ $) 58)) (-3666 (((-3 |#1| "failed") $) NIL)) (-2854 ((|#1| $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1715 (((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $) 52)) (-2735 (((-121) $) 14)) (-2882 ((|#1| $ (-568)) NIL)) (-2408 (((-763) $ (-568)) NIL)) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-2096 (($ (-1 |#1| |#1|) $) 37)) (-2505 (($ (-1 (-763) (-763)) $) 34)) (-2532 (((-3 $ "failed") $ $) 49)) (-4487 (((-1143) $) NIL)) (-2403 (($ $ $) 25)) (-3078 (($ $ $) 23)) (-4022 (((-1108) $) NIL)) (-3276 (((-634 (-2 (|:| |gen| |#1|) (|:| -1892 (-763)))) $) 31)) (-3210 (((-3 (-2 (|:| |lm| $) (|:| |rm| $)) "failed") $ $) 55)) (-2745 (((-850) $) 21) (($ |#1|) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-1556 (($) 9 T CONST)) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) 41)) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) 60 (|has| |#1| (-842)))) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ |#1| (-763)) 40)) (* (($ $ $) 47) (($ |#1| $) 29) (($ $ |#1|) 27))) 
-(((-388 |#1|) (-13 (-716) (-1037 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-763))) (-15 -3078 ($ $ $)) (-15 -2403 ($ $ $)) (-15 -2532 ((-3 $ "failed") $ $)) (-15 -2628 ((-3 $ "failed") $ $)) (-15 -3210 ((-3 (-2 (|:| |lm| $) (|:| |rm| $)) "failed") $ $)) (-15 -1715 ((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $)) (-15 -3983 ((-763) $)) (-15 -3276 ((-634 (-2 (|:| |gen| |#1|) (|:| -1892 (-763)))) $)) (-15 -2408 ((-763) $ (-568))) (-15 -2882 (|#1| $ (-568))) (-15 -2505 ($ (-1 (-763) (-763)) $)) (-15 -2096 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-842)) (-6 (-842)) |noBranch|))) (-1090)) (T -388)) 
-((* (*1 *1 *2 *1) (-12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) (* (*1 *1 *1 *2) (-12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) (** (*1 *1 *2 *3) (-12 (-5 *3 (-763)) (-5 *1 (-388 *2)) (-4 *2 (-1090)))) (-3078 (*1 *1 *1 *1) (-12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) (-2403 (*1 *1 *1 *1) (-12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) (-2532 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) (-2628 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) (-3210 (*1 *2 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |lm| (-388 *3)) (|:| |rm| (-388 *3)))) (-5 *1 (-388 *3)) (-4 *3 (-1090)))) (-1715 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |lm| (-388 *3)) (|:| |mm| (-388 *3)) (|:| |rm| (-388 *3)))) (-5 *1 (-388 *3)) (-4 *3 (-1090)))) (-3983 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-388 *3)) (-4 *3 (-1090)))) (-3276 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1892 (-763))))) (-5 *1 (-388 *3)) (-4 *3 (-1090)))) (-2408 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-763)) (-5 *1 (-388 *4)) (-4 *4 (-1090)))) (-2882 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-388 *2)) (-4 *2 (-1090)))) (-2505 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-763) (-763))) (-5 *1 (-388 *3)) (-4 *3 (-1090)))) (-2096 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-388 *3))))) 
-(-13 (-716) (-1037 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-763))) (-15 -3078 ($ $ $)) (-15 -2403 ($ $ $)) (-15 -2532 ((-3 $ "failed") $ $)) (-15 -2628 ((-3 $ "failed") $ $)) (-15 -3210 ((-3 (-2 (|:| |lm| $) (|:| |rm| $)) "failed") $ $)) (-15 -1715 ((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $)) (-15 -3983 ((-763) $)) (-15 -3276 ((-634 (-2 (|:| |gen| |#1|) (|:| -1892 (-763)))) $)) (-15 -2408 ((-763) $ (-568))) (-15 -2882 (|#1| $ (-568))) (-15 -2505 ($ (-1 (-763) (-763)) $)) (-15 -2096 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-842)) (-6 (-842)) |noBranch|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-3666 (((-3 (-568) "failed") $) 46)) (-2854 (((-568) $) 45)) (-2925 (((-3 $ "failed") $) 33)) (-2735 (((-121) $) 30)) (-2521 (($ $ $) 53)) (-3268 (($ $ $) 52)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2595 (((-3 $ "failed") $ $) 41)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-568)) 47)) (-4078 (((-763)) 28)) (-1826 (((-121) $ $) 38)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1751 (((-121) $ $) 50)) (-1738 (((-121) $ $) 49)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 51)) (-1732 (((-121) $ $) 48)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
+((-2449 (((-121) $ $) NIL)) (-3986 (((-763) $) 56)) (-4490 (($) NIL T CONST)) (-4242 (((-3 $ "failed") $ $) 58)) (-3668 (((-3 |#1| "failed") $) NIL)) (-2857 ((|#1| $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-3690 (((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $) 52)) (-1598 (((-121) $) 14)) (-4167 ((|#1| $ (-568)) NIL)) (-2315 (((-763) $ (-568)) NIL)) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-3177 (($ (-1 |#1| |#1|) $) 37)) (-1644 (($ (-1 (-763) (-763)) $) 34)) (-1797 (((-3 $ "failed") $ $) 49)) (-1893 (((-1143) $) NIL)) (-2289 (($ $ $) 25)) (-2400 (($ $ $) 23)) (-4025 (((-1108) $) NIL)) (-2075 (((-634 (-2 (|:| |gen| |#1|) (|:| -1894 (-763)))) $) 31)) (-1854 (((-3 (-2 (|:| |lm| $) (|:| |rm| $)) "failed") $ $) 55)) (-2747 (((-850) $) 21) (($ |#1|) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-1557 (($) 9 T CONST)) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) 41)) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) 60 (|has| |#1| (-842)))) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ |#1| (-763)) 40)) (* (($ $ $) 47) (($ |#1| $) 29) (($ $ |#1|) 27))) 
+(((-388 |#1|) (-13 (-716) (-1037 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-763))) (-15 -2400 ($ $ $)) (-15 -2289 ($ $ $)) (-15 -1797 ((-3 $ "failed") $ $)) (-15 -4242 ((-3 $ "failed") $ $)) (-15 -1854 ((-3 (-2 (|:| |lm| $) (|:| |rm| $)) "failed") $ $)) (-15 -3690 ((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $)) (-15 -3986 ((-763) $)) (-15 -2075 ((-634 (-2 (|:| |gen| |#1|) (|:| -1894 (-763)))) $)) (-15 -2315 ((-763) $ (-568))) (-15 -4167 (|#1| $ (-568))) (-15 -1644 ($ (-1 (-763) (-763)) $)) (-15 -3177 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-842)) (-6 (-842)) |noBranch|))) (-1090)) (T -388)) 
+((* (*1 *1 *2 *1) (-12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) (* (*1 *1 *1 *2) (-12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) (** (*1 *1 *2 *3) (-12 (-5 *3 (-763)) (-5 *1 (-388 *2)) (-4 *2 (-1090)))) (-2400 (*1 *1 *1 *1) (-12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) (-2289 (*1 *1 *1 *1) (-12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) (-1797 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) (-4242 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) (-1854 (*1 *2 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |lm| (-388 *3)) (|:| |rm| (-388 *3)))) (-5 *1 (-388 *3)) (-4 *3 (-1090)))) (-3690 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |lm| (-388 *3)) (|:| |mm| (-388 *3)) (|:| |rm| (-388 *3)))) (-5 *1 (-388 *3)) (-4 *3 (-1090)))) (-3986 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-388 *3)) (-4 *3 (-1090)))) (-2075 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1894 (-763))))) (-5 *1 (-388 *3)) (-4 *3 (-1090)))) (-2315 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-763)) (-5 *1 (-388 *4)) (-4 *4 (-1090)))) (-4167 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-388 *2)) (-4 *2 (-1090)))) (-1644 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-763) (-763))) (-5 *1 (-388 *3)) (-4 *3 (-1090)))) (-3177 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-388 *3))))) 
+(-13 (-716) (-1037 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-763))) (-15 -2400 ($ $ $)) (-15 -2289 ($ $ $)) (-15 -1797 ((-3 $ "failed") $ $)) (-15 -4242 ((-3 $ "failed") $ $)) (-15 -1854 ((-3 (-2 (|:| |lm| $) (|:| |rm| $)) "failed") $ $)) (-15 -3690 ((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $)) (-15 -3986 ((-763) $)) (-15 -2075 ((-634 (-2 (|:| |gen| |#1|) (|:| -1894 (-763)))) $)) (-15 -2315 ((-763) $ (-568))) (-15 -4167 (|#1| $ (-568))) (-15 -1644 ($ (-1 (-763) (-763)) $)) (-15 -3177 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-842)) (-6 (-842)) |noBranch|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-3668 (((-3 (-568) "failed") $) 46)) (-2857 (((-568) $) 45)) (-2902 (((-3 $ "failed") $) 33)) (-1598 (((-121) $) 30)) (-1732 (($ $ $) 53)) (-2047 (($ $ $) 52)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2597 (((-3 $ "failed") $ $) 41)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-568)) 47)) (-3425 (((-763)) 28)) (-2273 (((-121) $ $) 38)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1753 (((-121) $ $) 50)) (-1740 (((-121) $ $) 49)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 51)) (-1734 (((-121) $ $) 48)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
 (((-389) (-1275)) (T -389)) 
 NIL 
 (-13 (-558) (-842) (-1037 (-568))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-105) . T) ((-120 $ $) . T) ((-137) . T) ((-608 (-850)) . T) ((-172) . T) ((-285) . T) ((-558) . T) ((-637 $) . T) ((-707 $) . T) ((-716) . T) ((-842) . T) ((-1037 (-568)) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-3377 (((-121) $) 20)) (-3596 (((-121) $) 19)) (-1849 (($ (-1143) (-1143) (-1143)) 21)) (-3391 (((-1143) $) 16)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-4111 (($ (-1143) (-1143) (-1143)) 14)) (-3887 (((-1143) $) 17)) (-2689 (((-121) $) 18)) (-3424 (((-1143) $) 15)) (-2745 (((-850) $) 12) (($ (-1143)) 13) (((-1143) $) 9)) (-1717 (((-121) $ $) 7))) 
+((-2449 (((-121) $ $) NIL)) (-1426 (((-121) $) 20)) (-2987 (((-121) $) 19)) (-1851 (($ (-1143) (-1143) (-1143)) 21)) (-3393 (((-1143) $) 16)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-4113 (($ (-1143) (-1143) (-1143)) 14)) (-2025 (((-1143) $) 17)) (-1349 (((-121) $) 18)) (-3428 (((-1143) $) 15)) (-2747 (((-850) $) 12) (($ (-1143)) 13) (((-1143) $) 9)) (-1719 (((-121) $ $) 7))) 
 (((-390) (-391)) (T -390)) 
 NIL 
 (-391) 
-((-2447 (((-121) $ $) 7)) (-3377 (((-121) $) 13)) (-3596 (((-121) $) 14)) (-1849 (($ (-1143) (-1143) (-1143)) 12)) (-3391 (((-1143) $) 17)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-4111 (($ (-1143) (-1143) (-1143)) 19)) (-3887 (((-1143) $) 16)) (-2689 (((-121) $) 15)) (-3424 (((-1143) $) 18)) (-2745 (((-850) $) 11) (($ (-1143)) 21) (((-1143) $) 20)) (-1717 (((-121) $ $) 6))) 
+((-2449 (((-121) $ $) 7)) (-1426 (((-121) $) 13)) (-2987 (((-121) $) 14)) (-1851 (($ (-1143) (-1143) (-1143)) 12)) (-3393 (((-1143) $) 17)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-4113 (($ (-1143) (-1143) (-1143)) 19)) (-2025 (((-1143) $) 16)) (-1349 (((-121) $) 15)) (-3428 (((-1143) $) 18)) (-2747 (((-850) $) 11) (($ (-1143)) 21) (((-1143) $) 20)) (-1719 (((-121) $ $) 6))) 
 (((-391) (-1275)) (T -391)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-4 *1 (-391)))) (-2745 (*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-1143)))) (-4111 (*1 *1 *2 *2 *2) (-12 (-5 *2 (-1143)) (-4 *1 (-391)))) (-3424 (*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-1143)))) (-3391 (*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-1143)))) (-3887 (*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-1143)))) (-2689 (*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-121)))) (-3596 (*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-121)))) (-3377 (*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-121)))) (-1849 (*1 *1 *2 *2 *2) (-12 (-5 *2 (-1143)) (-4 *1 (-391))))) 
-(-13 (-1090) (-10 -8 (-15 -2745 ($ (-1143))) (-15 -2745 ((-1143) $)) (-15 -4111 ($ (-1143) (-1143) (-1143))) (-15 -3424 ((-1143) $)) (-15 -3391 ((-1143) $)) (-15 -3887 ((-1143) $)) (-15 -2689 ((-121) $)) (-15 -3596 ((-121) $)) (-15 -3377 ((-121) $)) (-15 -1849 ($ (-1143) (-1143) (-1143))))) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-4 *1 (-391)))) (-2747 (*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-1143)))) (-4113 (*1 *1 *2 *2 *2) (-12 (-5 *2 (-1143)) (-4 *1 (-391)))) (-3428 (*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-1143)))) (-3393 (*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-1143)))) (-2025 (*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-1143)))) (-1349 (*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-121)))) (-2987 (*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-121)))) (-1426 (*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-121)))) (-1851 (*1 *1 *2 *2 *2) (-12 (-5 *2 (-1143)) (-4 *1 (-391))))) 
+(-13 (-1090) (-10 -8 (-15 -2747 ($ (-1143))) (-15 -2747 ((-1143) $)) (-15 -4113 ($ (-1143) (-1143) (-1143))) (-15 -3428 ((-1143) $)) (-15 -3393 ((-1143) $)) (-15 -2025 ((-1143) $)) (-15 -1349 ((-121) $)) (-15 -2987 ((-121) $)) (-15 -1426 ((-121) $)) (-15 -1851 ($ (-1143) (-1143) (-1143))))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2576 (((-850) $) 50)) (-2671 (($) NIL T CONST)) (-3551 (($ $ (-917)) NIL)) (-4373 (($ $ (-917)) NIL)) (-4222 (($ $ (-917)) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2704 (($ (-763)) 26)) (-4321 (((-763)) 15)) (-2673 (((-850) $) 52)) (-2353 (($ $ $) NIL)) (-2745 (((-850) $) NIL)) (-3882 (($ $ $ $) NIL)) (-3500 (($ $ $) NIL)) (-3056 (($) 20 T CONST)) (-1717 (((-121) $ $) 28)) (-1773 (($ $) 34) (($ $ $) 36)) (-1767 (($ $ $) 37)) (** (($ $ (-917)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 38) (($ $ |#3|) NIL) (($ |#3| $) 33))) 
-(((-392 |#1| |#2| |#3|) (-13 (-736 |#3|) (-10 -8 (-15 -4321 ((-763))) (-15 -2673 ((-850) $)) (-15 -2576 ((-850) $)) (-15 -2704 ($ (-763))))) (-763) (-763) (-172)) (T -392)) 
-((-4321 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-392 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-172)))) (-2673 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-392 *3 *4 *5)) (-14 *3 (-763)) (-14 *4 (-763)) (-4 *5 (-172)))) (-2576 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-392 *3 *4 *5)) (-14 *3 (-763)) (-14 *4 (-763)) (-4 *5 (-172)))) (-2704 (*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-392 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-172))))) 
-(-13 (-736 |#3|) (-10 -8 (-15 -4321 ((-763))) (-15 -2673 ((-850) $)) (-15 -2576 ((-850) $)) (-15 -2704 ($ (-763))))) 
-((-4389 (((-1143)) 10)) (-4066 (((-1132 (-1143))) 28)) (-4104 (((-1249) (-1143)) 25) (((-1249) (-390)) 24)) (-4119 (((-1249)) 26)) (-4437 (((-1132 (-1143))) 27))) 
-(((-393) (-10 -7 (-15 -4437 ((-1132 (-1143)))) (-15 -4066 ((-1132 (-1143)))) (-15 -4119 ((-1249))) (-15 -4104 ((-1249) (-390))) (-15 -4104 ((-1249) (-1143))) (-15 -4389 ((-1143))))) (T -393)) 
-((-4389 (*1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-393)))) (-4104 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-393)))) (-4104 (*1 *2 *3) (-12 (-5 *3 (-390)) (-5 *2 (-1249)) (-5 *1 (-393)))) (-4119 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-393)))) (-4066 (*1 *2) (-12 (-5 *2 (-1132 (-1143))) (-5 *1 (-393)))) (-4437 (*1 *2) (-12 (-5 *2 (-1132 (-1143))) (-5 *1 (-393))))) 
-(-10 -7 (-15 -4437 ((-1132 (-1143)))) (-15 -4066 ((-1132 (-1143)))) (-15 -4119 ((-1249))) (-15 -4104 ((-1249) (-390))) (-15 -4104 ((-1249) (-1143))) (-15 -4389 ((-1143)))) 
-((-4477 (((-763) (-334 |#1| |#2| |#3| |#4|)) 16))) 
-(((-394 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4477 ((-763) (-334 |#1| |#2| |#3| |#4|)))) (-13 (-370) (-365)) (-1219 |#1|) (-1219 (-409 |#2|)) (-340 |#1| |#2| |#3|)) (T -394)) 
-((-4477 (*1 *2 *3) (-12 (-5 *3 (-334 *4 *5 *6 *7)) (-4 *4 (-13 (-370) (-365))) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-4 *7 (-340 *4 *5 *6)) (-5 *2 (-763)) (-5 *1 (-394 *4 *5 *6 *7))))) 
-(-10 -7 (-15 -4477 ((-763) (-334 |#1| |#2| |#3| |#4|)))) 
-((-2745 (((-396) |#1|) 11))) 
-(((-395 |#1|) (-10 -7 (-15 -2745 ((-396) |#1|))) (-1090)) (T -395)) 
-((-2745 (*1 *2 *3) (-12 (-5 *2 (-396)) (-5 *1 (-395 *3)) (-4 *3 (-1090))))) 
-(-10 -7 (-15 -2745 ((-396) |#1|))) 
-((-2447 (((-121) $ $) NIL)) (-1688 (((-634 (-1143)) $ (-634 (-1143))) 37)) (-1292 (((-634 (-1143)) $ (-634 (-1143))) 38)) (-3371 (((-634 (-1143)) $ (-634 (-1143))) 39)) (-1538 (((-634 (-1143)) $) 34)) (-1849 (($) 23)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-4296 (((-634 (-1143)) $) 35)) (-3224 (((-634 (-1143)) $) 36)) (-4125 (((-1249) $ (-568)) 32) (((-1249) $) 33)) (-4278 (($ (-850) (-568)) 29)) (-2745 (((-850) $) 41) (($ (-850)) 25)) (-1717 (((-121) $ $) NIL))) 
-(((-396) (-13 (-1090) (-10 -8 (-15 -2745 ($ (-850))) (-15 -4278 ($ (-850) (-568))) (-15 -4125 ((-1249) $ (-568))) (-15 -4125 ((-1249) $)) (-15 -3224 ((-634 (-1143)) $)) (-15 -4296 ((-634 (-1143)) $)) (-15 -1849 ($)) (-15 -1538 ((-634 (-1143)) $)) (-15 -3371 ((-634 (-1143)) $ (-634 (-1143)))) (-15 -1292 ((-634 (-1143)) $ (-634 (-1143)))) (-15 -1688 ((-634 (-1143)) $ (-634 (-1143))))))) (T -396)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-850)) (-5 *1 (-396)))) (-4278 (*1 *1 *2 *3) (-12 (-5 *2 (-850)) (-5 *3 (-568)) (-5 *1 (-396)))) (-4125 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-396)))) (-4125 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-396)))) (-3224 (*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396)))) (-4296 (*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396)))) (-1849 (*1 *1) (-5 *1 (-396))) (-1538 (*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396)))) (-3371 (*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396)))) (-1292 (*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396)))) (-1688 (*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396))))) 
-(-13 (-1090) (-10 -8 (-15 -2745 ($ (-850))) (-15 -4278 ($ (-850) (-568))) (-15 -4125 ((-1249) $ (-568))) (-15 -4125 ((-1249) $)) (-15 -3224 ((-634 (-1143)) $)) (-15 -4296 ((-634 (-1143)) $)) (-15 -1849 ($)) (-15 -1538 ((-634 (-1143)) $)) (-15 -3371 ((-634 (-1143)) $ (-634 (-1143)))) (-15 -1292 ((-634 (-1143)) $ (-634 (-1143)))) (-15 -1688 ((-634 (-1143)) $ (-634 (-1143)))))) 
-((-4128 (((-1249) $) 7)) (-2745 (((-850) $) 8))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-1985 (((-850) $) 50)) (-4490 (($) NIL T CONST)) (-2815 (($ $ (-917)) NIL)) (-3402 (($ $ (-917)) NIL)) (-4202 (($ $ (-917)) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2707 (($ (-763)) 26)) (-3108 (((-763)) 15)) (-4500 (((-850) $) 52)) (-3985 (($ $ $) NIL)) (-2747 (((-850) $) NIL)) (-2007 (($ $ $ $) NIL)) (-3911 (($ $ $) NIL)) (-3058 (($) 20 T CONST)) (-1719 (((-121) $ $) 28)) (-1775 (($ $) 34) (($ $ $) 36)) (-1769 (($ $ $) 37)) (** (($ $ (-917)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 38) (($ $ |#3|) NIL) (($ |#3| $) 33))) 
+(((-392 |#1| |#2| |#3|) (-13 (-736 |#3|) (-10 -8 (-15 -3108 ((-763))) (-15 -4500 ((-850) $)) (-15 -1985 ((-850) $)) (-15 -2707 ($ (-763))))) (-763) (-763) (-172)) (T -392)) 
+((-3108 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-392 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-172)))) (-4500 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-392 *3 *4 *5)) (-14 *3 (-763)) (-14 *4 (-763)) (-4 *5 (-172)))) (-1985 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-392 *3 *4 *5)) (-14 *3 (-763)) (-14 *4 (-763)) (-4 *5 (-172)))) (-2707 (*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-392 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-172))))) 
+(-13 (-736 |#3|) (-10 -8 (-15 -3108 ((-763))) (-15 -4500 ((-850) $)) (-15 -1985 ((-850) $)) (-15 -2707 ($ (-763))))) 
+((-1404 (((-1143)) 10)) (-1630 (((-1132 (-1143))) 28)) (-4106 (((-1249) (-1143)) 25) (((-1249) (-390)) 24)) (-4120 (((-1249)) 26)) (-1640 (((-1132 (-1143))) 27))) 
+(((-393) (-10 -7 (-15 -1640 ((-1132 (-1143)))) (-15 -1630 ((-1132 (-1143)))) (-15 -4120 ((-1249))) (-15 -4106 ((-1249) (-390))) (-15 -4106 ((-1249) (-1143))) (-15 -1404 ((-1143))))) (T -393)) 
+((-1404 (*1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-393)))) (-4106 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-393)))) (-4106 (*1 *2 *3) (-12 (-5 *3 (-390)) (-5 *2 (-1249)) (-5 *1 (-393)))) (-4120 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-393)))) (-1630 (*1 *2) (-12 (-5 *2 (-1132 (-1143))) (-5 *1 (-393)))) (-1640 (*1 *2) (-12 (-5 *2 (-1132 (-1143))) (-5 *1 (-393))))) 
+(-10 -7 (-15 -1640 ((-1132 (-1143)))) (-15 -1630 ((-1132 (-1143)))) (-15 -4120 ((-1249))) (-15 -4106 ((-1249) (-390))) (-15 -4106 ((-1249) (-1143))) (-15 -1404 ((-1143)))) 
+((-1844 (((-763) (-334 |#1| |#2| |#3| |#4|)) 16))) 
+(((-394 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1844 ((-763) (-334 |#1| |#2| |#3| |#4|)))) (-13 (-370) (-365)) (-1219 |#1|) (-1219 (-409 |#2|)) (-340 |#1| |#2| |#3|)) (T -394)) 
+((-1844 (*1 *2 *3) (-12 (-5 *3 (-334 *4 *5 *6 *7)) (-4 *4 (-13 (-370) (-365))) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-4 *7 (-340 *4 *5 *6)) (-5 *2 (-763)) (-5 *1 (-394 *4 *5 *6 *7))))) 
+(-10 -7 (-15 -1844 ((-763) (-334 |#1| |#2| |#3| |#4|)))) 
+((-2747 (((-396) |#1|) 11))) 
+(((-395 |#1|) (-10 -7 (-15 -2747 ((-396) |#1|))) (-1090)) (T -395)) 
+((-2747 (*1 *2 *3) (-12 (-5 *2 (-396)) (-5 *1 (-395 *3)) (-4 *3 (-1090))))) 
+(-10 -7 (-15 -2747 ((-396) |#1|))) 
+((-2449 (((-121) $ $) NIL)) (-3547 (((-634 (-1143)) $ (-634 (-1143))) 37)) (-3217 (((-634 (-1143)) $ (-634 (-1143))) 38)) (-1389 (((-634 (-1143)) $ (-634 (-1143))) 39)) (-4228 (((-634 (-1143)) $) 34)) (-1851 (($) 23)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-3009 (((-634 (-1143)) $) 35)) (-1907 (((-634 (-1143)) $) 36)) (-4127 (((-1249) $ (-568)) 32) (((-1249) $) 33)) (-4280 (($ (-850) (-568)) 29)) (-2747 (((-850) $) 41) (($ (-850)) 25)) (-1719 (((-121) $ $) NIL))) 
+(((-396) (-13 (-1090) (-10 -8 (-15 -2747 ($ (-850))) (-15 -4280 ($ (-850) (-568))) (-15 -4127 ((-1249) $ (-568))) (-15 -4127 ((-1249) $)) (-15 -1907 ((-634 (-1143)) $)) (-15 -3009 ((-634 (-1143)) $)) (-15 -1851 ($)) (-15 -4228 ((-634 (-1143)) $)) (-15 -1389 ((-634 (-1143)) $ (-634 (-1143)))) (-15 -3217 ((-634 (-1143)) $ (-634 (-1143)))) (-15 -3547 ((-634 (-1143)) $ (-634 (-1143))))))) (T -396)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-850)) (-5 *1 (-396)))) (-4280 (*1 *1 *2 *3) (-12 (-5 *2 (-850)) (-5 *3 (-568)) (-5 *1 (-396)))) (-4127 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-396)))) (-4127 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-396)))) (-1907 (*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396)))) (-3009 (*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396)))) (-1851 (*1 *1) (-5 *1 (-396))) (-4228 (*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396)))) (-1389 (*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396)))) (-3217 (*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396)))) (-3547 (*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396))))) 
+(-13 (-1090) (-10 -8 (-15 -2747 ($ (-850))) (-15 -4280 ($ (-850) (-568))) (-15 -4127 ((-1249) $ (-568))) (-15 -4127 ((-1249) $)) (-15 -1907 ((-634 (-1143)) $)) (-15 -3009 ((-634 (-1143)) $)) (-15 -1851 ($)) (-15 -4228 ((-634 (-1143)) $)) (-15 -1389 ((-634 (-1143)) $ (-634 (-1143)))) (-15 -3217 ((-634 (-1143)) $ (-634 (-1143)))) (-15 -3547 ((-634 (-1143)) $ (-634 (-1143)))))) 
+((-4130 (((-1249) $) 7)) (-2747 (((-850) $) 8))) 
 (((-397) (-1275)) (T -397)) 
-((-4128 (*1 *2 *1) (-12 (-4 *1 (-397)) (-5 *2 (-1249))))) 
-(-13 (-1195) (-608 (-850)) (-10 -8 (-15 -4128 ((-1249) $)))) 
+((-4130 (*1 *2 *1) (-12 (-4 *1 (-397)) (-5 *2 (-1249))))) 
+(-13 (-1195) (-608 (-850)) (-10 -8 (-15 -4130 ((-1249) $)))) 
 (((-608 (-850)) . T) ((-1195) . T)) 
-((-3666 (((-3 $ "failed") (-310 (-381))) 19) (((-3 $ "failed") (-310 (-568))) 17) (((-3 $ "failed") (-953 (-381))) 15) (((-3 $ "failed") (-953 (-568))) 13) (((-3 $ "failed") (-409 (-953 (-381)))) 11) (((-3 $ "failed") (-409 (-953 (-568)))) 9)) (-2854 (($ (-310 (-381))) 20) (($ (-310 (-568))) 18) (($ (-953 (-381))) 16) (($ (-953 (-568))) 14) (($ (-409 (-953 (-381)))) 12) (($ (-409 (-953 (-568)))) 10)) (-4128 (((-1249) $) 7)) (-2745 (((-850) $) 8) (($ (-634 (-328))) 23) (($ (-328)) 22) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 21))) 
+((-3668 (((-3 $ "failed") (-310 (-381))) 19) (((-3 $ "failed") (-310 (-568))) 17) (((-3 $ "failed") (-953 (-381))) 15) (((-3 $ "failed") (-953 (-568))) 13) (((-3 $ "failed") (-409 (-953 (-381)))) 11) (((-3 $ "failed") (-409 (-953 (-568)))) 9)) (-2857 (($ (-310 (-381))) 20) (($ (-310 (-568))) 18) (($ (-953 (-381))) 16) (($ (-953 (-568))) 14) (($ (-409 (-953 (-381)))) 12) (($ (-409 (-953 (-568)))) 10)) (-4130 (((-1249) $) 7)) (-2747 (((-850) $) 8) (($ (-634 (-328))) 23) (($ (-328)) 22) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 21))) 
 (((-398) (-1275)) (T -398)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-4 *1 (-398)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-328)) (-4 *1 (-398)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) (-4 *1 (-398)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-310 (-381))) (-4 *1 (-398)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-310 (-381))) (-4 *1 (-398)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-310 (-568))) (-4 *1 (-398)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-310 (-568))) (-4 *1 (-398)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-953 (-381))) (-4 *1 (-398)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-953 (-381))) (-4 *1 (-398)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-953 (-568))) (-4 *1 (-398)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-953 (-568))) (-4 *1 (-398)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-409 (-953 (-381)))) (-4 *1 (-398)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-409 (-953 (-381)))) (-4 *1 (-398)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-409 (-953 (-568)))) (-4 *1 (-398)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-409 (-953 (-568)))) (-4 *1 (-398))))) 
-(-13 (-397) (-10 -8 (-15 -2745 ($ (-634 (-328)))) (-15 -2745 ($ (-328))) (-15 -2745 ($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328)))))) (-15 -2854 ($ (-310 (-381)))) (-15 -3666 ((-3 $ "failed") (-310 (-381)))) (-15 -2854 ($ (-310 (-568)))) (-15 -3666 ((-3 $ "failed") (-310 (-568)))) (-15 -2854 ($ (-953 (-381)))) (-15 -3666 ((-3 $ "failed") (-953 (-381)))) (-15 -2854 ($ (-953 (-568)))) (-15 -3666 ((-3 $ "failed") (-953 (-568)))) (-15 -2854 ($ (-409 (-953 (-381))))) (-15 -3666 ((-3 $ "failed") (-409 (-953 (-381))))) (-15 -2854 ($ (-409 (-953 (-568))))) (-15 -3666 ((-3 $ "failed") (-409 (-953 (-568))))))) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-4 *1 (-398)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-328)) (-4 *1 (-398)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) (-4 *1 (-398)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-310 (-381))) (-4 *1 (-398)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-310 (-381))) (-4 *1 (-398)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-310 (-568))) (-4 *1 (-398)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-310 (-568))) (-4 *1 (-398)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-953 (-381))) (-4 *1 (-398)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-953 (-381))) (-4 *1 (-398)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-953 (-568))) (-4 *1 (-398)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-953 (-568))) (-4 *1 (-398)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-409 (-953 (-381)))) (-4 *1 (-398)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-409 (-953 (-381)))) (-4 *1 (-398)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-409 (-953 (-568)))) (-4 *1 (-398)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-409 (-953 (-568)))) (-4 *1 (-398))))) 
+(-13 (-397) (-10 -8 (-15 -2747 ($ (-634 (-328)))) (-15 -2747 ($ (-328))) (-15 -2747 ($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328)))))) (-15 -2857 ($ (-310 (-381)))) (-15 -3668 ((-3 $ "failed") (-310 (-381)))) (-15 -2857 ($ (-310 (-568)))) (-15 -3668 ((-3 $ "failed") (-310 (-568)))) (-15 -2857 ($ (-953 (-381)))) (-15 -3668 ((-3 $ "failed") (-953 (-381)))) (-15 -2857 ($ (-953 (-568)))) (-15 -3668 ((-3 $ "failed") (-953 (-568)))) (-15 -2857 ($ (-409 (-953 (-381))))) (-15 -3668 ((-3 $ "failed") (-409 (-953 (-381))))) (-15 -2857 ($ (-409 (-953 (-568))))) (-15 -3668 ((-3 $ "failed") (-409 (-953 (-568))))))) 
 (((-608 (-850)) . T) ((-397) . T) ((-1195) . T)) 
-((-2334 (((-634 (-1143)) (-634 (-1143))) 8)) (-4128 (((-1249) (-390)) 27)) (-2949 (((-1094) (-1161) (-634 (-1161)) (-1164) (-634 (-1161))) 59) (((-1094) (-1161) (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161)))) (-634 (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161))))) (-634 (-1161)) (-1161)) 35) (((-1094) (-1161) (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161)))) (-634 (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161))))) (-634 (-1161))) 34))) 
-(((-399) (-10 -7 (-15 -2949 ((-1094) (-1161) (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161)))) (-634 (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161))))) (-634 (-1161)))) (-15 -2949 ((-1094) (-1161) (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161)))) (-634 (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161))))) (-634 (-1161)) (-1161))) (-15 -2949 ((-1094) (-1161) (-634 (-1161)) (-1164) (-634 (-1161)))) (-15 -4128 ((-1249) (-390))) (-15 -2334 ((-634 (-1143)) (-634 (-1143)))))) (T -399)) 
-((-2334 (*1 *2 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-399)))) (-4128 (*1 *2 *3) (-12 (-5 *3 (-390)) (-5 *2 (-1249)) (-5 *1 (-399)))) (-2949 (*1 *2 *3 *4 *5 *4) (-12 (-5 *4 (-634 (-1161))) (-5 *5 (-1164)) (-5 *3 (-1161)) (-5 *2 (-1094)) (-5 *1 (-399)))) (-2949 (*1 *2 *3 *4 *5 *6 *3) (-12 (-5 *5 (-634 (-634 (-3 (|:| |array| *6) (|:| |scalar| *3))))) (-5 *4 (-634 (-3 (|:| |array| (-634 *3)) (|:| |scalar| (-1161))))) (-5 *6 (-634 (-1161))) (-5 *3 (-1161)) (-5 *2 (-1094)) (-5 *1 (-399)))) (-2949 (*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-634 (-634 (-3 (|:| |array| *6) (|:| |scalar| *3))))) (-5 *4 (-634 (-3 (|:| |array| (-634 *3)) (|:| |scalar| (-1161))))) (-5 *6 (-634 (-1161))) (-5 *3 (-1161)) (-5 *2 (-1094)) (-5 *1 (-399))))) 
-(-10 -7 (-15 -2949 ((-1094) (-1161) (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161)))) (-634 (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161))))) (-634 (-1161)))) (-15 -2949 ((-1094) (-1161) (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161)))) (-634 (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161))))) (-634 (-1161)) (-1161))) (-15 -2949 ((-1094) (-1161) (-634 (-1161)) (-1164) (-634 (-1161)))) (-15 -4128 ((-1249) (-390))) (-15 -2334 ((-634 (-1143)) (-634 (-1143))))) 
-((-4128 (((-1249) $) 37)) (-2745 (((-850) $) 89) (($ (-328)) 92) (($ (-634 (-328))) 91) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 88) (($ (-310 (-690))) 52) (($ (-310 (-688))) 66) (($ (-310 (-683))) 78) (($ (-288 (-310 (-690)))) 62) (($ (-288 (-310 (-688)))) 74) (($ (-288 (-310 (-683)))) 86) (($ (-310 (-568))) 96) (($ (-310 (-381))) 108) (($ (-310 (-169 (-381)))) 120) (($ (-288 (-310 (-568)))) 104) (($ (-288 (-310 (-381)))) 116) (($ (-288 (-310 (-169 (-381))))) 128))) 
-(((-400 |#1| |#2| |#3| |#4|) (-13 (-397) (-10 -8 (-15 -2745 ($ (-328))) (-15 -2745 ($ (-634 (-328)))) (-15 -2745 ($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328)))))) (-15 -2745 ($ (-310 (-690)))) (-15 -2745 ($ (-310 (-688)))) (-15 -2745 ($ (-310 (-683)))) (-15 -2745 ($ (-288 (-310 (-690))))) (-15 -2745 ($ (-288 (-310 (-688))))) (-15 -2745 ($ (-288 (-310 (-683))))) (-15 -2745 ($ (-310 (-568)))) (-15 -2745 ($ (-310 (-381)))) (-15 -2745 ($ (-310 (-169 (-381))))) (-15 -2745 ($ (-288 (-310 (-568))))) (-15 -2745 ($ (-288 (-310 (-381))))) (-15 -2745 ($ (-288 (-310 (-169 (-381)))))))) (-1161) (-3 (|:| |fst| (-436)) (|:| -3611 "void")) (-634 (-1161)) (-1165)) (T -400)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-328)) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-310 (-690))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-310 (-688))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-310 (-683))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-690)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-688)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-683)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-310 (-568))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-310 (-381))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-310 (-169 (-381)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-568)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-381)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-169 (-381))))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165))))) 
-(-13 (-397) (-10 -8 (-15 -2745 ($ (-328))) (-15 -2745 ($ (-634 (-328)))) (-15 -2745 ($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328)))))) (-15 -2745 ($ (-310 (-690)))) (-15 -2745 ($ (-310 (-688)))) (-15 -2745 ($ (-310 (-683)))) (-15 -2745 ($ (-288 (-310 (-690))))) (-15 -2745 ($ (-288 (-310 (-688))))) (-15 -2745 ($ (-288 (-310 (-683))))) (-15 -2745 ($ (-310 (-568)))) (-15 -2745 ($ (-310 (-381)))) (-15 -2745 ($ (-310 (-169 (-381))))) (-15 -2745 ($ (-288 (-310 (-568))))) (-15 -2745 ($ (-288 (-310 (-381))))) (-15 -2745 ($ (-288 (-310 (-169 (-381)))))))) 
-((-2447 (((-121) $ $) NIL)) (-2848 ((|#2| $) 36)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-3425 (($ (-409 |#2|)) 84)) (-4367 (((-634 (-2 (|:| -3438 (-763)) (|:| -1374 |#2|) (|:| |num| |#2|))) $) 37)) (-4189 (($ $) 32) (($ $ (-763)) 34)) (-4278 (((-409 |#2|) $) 46)) (-4287 (($ (-634 (-2 (|:| -3438 (-763)) (|:| -1374 |#2|) (|:| |num| |#2|)))) 31)) (-2745 (((-850) $) 120)) (-3190 (($ $) 33) (($ $ (-763)) 35)) (-1717 (((-121) $ $) NIL)) (-1767 (($ |#2| $) 39))) 
-(((-401 |#1| |#2|) (-13 (-1090) (-609 (-409 |#2|)) (-10 -8 (-15 -1767 ($ |#2| $)) (-15 -3425 ($ (-409 |#2|))) (-15 -2848 (|#2| $)) (-15 -4367 ((-634 (-2 (|:| -3438 (-763)) (|:| -1374 |#2|) (|:| |num| |#2|))) $)) (-15 -4287 ($ (-634 (-2 (|:| -3438 (-763)) (|:| -1374 |#2|) (|:| |num| |#2|))))) (-15 -4189 ($ $)) (-15 -3190 ($ $)) (-15 -4189 ($ $ (-763))) (-15 -3190 ($ $ (-763))))) (-13 (-365) (-150)) (-1219 |#1|)) (T -401)) 
-((-1767 (*1 *1 *2 *1) (-12 (-4 *3 (-13 (-365) (-150))) (-5 *1 (-401 *3 *2)) (-4 *2 (-1219 *3)))) (-3425 (*1 *1 *2) (-12 (-5 *2 (-409 *4)) (-4 *4 (-1219 *3)) (-4 *3 (-13 (-365) (-150))) (-5 *1 (-401 *3 *4)))) (-2848 (*1 *2 *1) (-12 (-4 *2 (-1219 *3)) (-5 *1 (-401 *3 *2)) (-4 *3 (-13 (-365) (-150))))) (-4367 (*1 *2 *1) (-12 (-4 *3 (-13 (-365) (-150))) (-5 *2 (-634 (-2 (|:| -3438 (-763)) (|:| -1374 *4) (|:| |num| *4)))) (-5 *1 (-401 *3 *4)) (-4 *4 (-1219 *3)))) (-4287 (*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3438 (-763)) (|:| -1374 *4) (|:| |num| *4)))) (-4 *4 (-1219 *3)) (-4 *3 (-13 (-365) (-150))) (-5 *1 (-401 *3 *4)))) (-4189 (*1 *1 *1) (-12 (-4 *2 (-13 (-365) (-150))) (-5 *1 (-401 *2 *3)) (-4 *3 (-1219 *2)))) (-3190 (*1 *1 *1) (-12 (-4 *2 (-13 (-365) (-150))) (-5 *1 (-401 *2 *3)) (-4 *3 (-1219 *2)))) (-4189 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *3 (-13 (-365) (-150))) (-5 *1 (-401 *3 *4)) (-4 *4 (-1219 *3)))) (-3190 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *3 (-13 (-365) (-150))) (-5 *1 (-401 *3 *4)) (-4 *4 (-1219 *3))))) 
-(-13 (-1090) (-609 (-409 |#2|)) (-10 -8 (-15 -1767 ($ |#2| $)) (-15 -3425 ($ (-409 |#2|))) (-15 -2848 (|#2| $)) (-15 -4367 ((-634 (-2 (|:| -3438 (-763)) (|:| -1374 |#2|) (|:| |num| |#2|))) $)) (-15 -4287 ($ (-634 (-2 (|:| -3438 (-763)) (|:| -1374 |#2|) (|:| |num| |#2|))))) (-15 -4189 ($ $)) (-15 -3190 ($ $)) (-15 -4189 ($ $ (-763))) (-15 -3190 ($ $ (-763))))) 
-((-2447 (((-121) $ $) 9 (-2198 (|has| |#1| (-881 (-568))) (|has| |#1| (-881 (-381)))))) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 15 (|has| |#1| (-881 (-381)))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 14 (|has| |#1| (-881 (-568))))) (-4487 (((-1143) $) 13 (-2198 (|has| |#1| (-881 (-568))) (|has| |#1| (-881 (-381)))))) (-4022 (((-1108) $) 12 (-2198 (|has| |#1| (-881 (-568))) (|has| |#1| (-881 (-381)))))) (-2745 (((-850) $) 11 (-2198 (|has| |#1| (-881 (-568))) (|has| |#1| (-881 (-381)))))) (-1717 (((-121) $ $) 10 (-2198 (|has| |#1| (-881 (-568))) (|has| |#1| (-881 (-381))))))) 
+((-3871 (((-634 (-1143)) (-634 (-1143))) 8)) (-4130 (((-1249) (-390)) 27)) (-2976 (((-1094) (-1161) (-634 (-1161)) (-1164) (-634 (-1161))) 59) (((-1094) (-1161) (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161)))) (-634 (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161))))) (-634 (-1161)) (-1161)) 35) (((-1094) (-1161) (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161)))) (-634 (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161))))) (-634 (-1161))) 34))) 
+(((-399) (-10 -7 (-15 -2976 ((-1094) (-1161) (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161)))) (-634 (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161))))) (-634 (-1161)))) (-15 -2976 ((-1094) (-1161) (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161)))) (-634 (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161))))) (-634 (-1161)) (-1161))) (-15 -2976 ((-1094) (-1161) (-634 (-1161)) (-1164) (-634 (-1161)))) (-15 -4130 ((-1249) (-390))) (-15 -3871 ((-634 (-1143)) (-634 (-1143)))))) (T -399)) 
+((-3871 (*1 *2 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-399)))) (-4130 (*1 *2 *3) (-12 (-5 *3 (-390)) (-5 *2 (-1249)) (-5 *1 (-399)))) (-2976 (*1 *2 *3 *4 *5 *4) (-12 (-5 *4 (-634 (-1161))) (-5 *5 (-1164)) (-5 *3 (-1161)) (-5 *2 (-1094)) (-5 *1 (-399)))) (-2976 (*1 *2 *3 *4 *5 *6 *3) (-12 (-5 *5 (-634 (-634 (-3 (|:| |array| *6) (|:| |scalar| *3))))) (-5 *4 (-634 (-3 (|:| |array| (-634 *3)) (|:| |scalar| (-1161))))) (-5 *6 (-634 (-1161))) (-5 *3 (-1161)) (-5 *2 (-1094)) (-5 *1 (-399)))) (-2976 (*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-634 (-634 (-3 (|:| |array| *6) (|:| |scalar| *3))))) (-5 *4 (-634 (-3 (|:| |array| (-634 *3)) (|:| |scalar| (-1161))))) (-5 *6 (-634 (-1161))) (-5 *3 (-1161)) (-5 *2 (-1094)) (-5 *1 (-399))))) 
+(-10 -7 (-15 -2976 ((-1094) (-1161) (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161)))) (-634 (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161))))) (-634 (-1161)))) (-15 -2976 ((-1094) (-1161) (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161)))) (-634 (-634 (-3 (|:| |array| (-634 (-1161))) (|:| |scalar| (-1161))))) (-634 (-1161)) (-1161))) (-15 -2976 ((-1094) (-1161) (-634 (-1161)) (-1164) (-634 (-1161)))) (-15 -4130 ((-1249) (-390))) (-15 -3871 ((-634 (-1143)) (-634 (-1143))))) 
+((-4130 (((-1249) $) 37)) (-2747 (((-850) $) 89) (($ (-328)) 92) (($ (-634 (-328))) 91) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 88) (($ (-310 (-690))) 52) (($ (-310 (-688))) 66) (($ (-310 (-683))) 78) (($ (-288 (-310 (-690)))) 62) (($ (-288 (-310 (-688)))) 74) (($ (-288 (-310 (-683)))) 86) (($ (-310 (-568))) 96) (($ (-310 (-381))) 108) (($ (-310 (-169 (-381)))) 120) (($ (-288 (-310 (-568)))) 104) (($ (-288 (-310 (-381)))) 116) (($ (-288 (-310 (-169 (-381))))) 128))) 
+(((-400 |#1| |#2| |#3| |#4|) (-13 (-397) (-10 -8 (-15 -2747 ($ (-328))) (-15 -2747 ($ (-634 (-328)))) (-15 -2747 ($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328)))))) (-15 -2747 ($ (-310 (-690)))) (-15 -2747 ($ (-310 (-688)))) (-15 -2747 ($ (-310 (-683)))) (-15 -2747 ($ (-288 (-310 (-690))))) (-15 -2747 ($ (-288 (-310 (-688))))) (-15 -2747 ($ (-288 (-310 (-683))))) (-15 -2747 ($ (-310 (-568)))) (-15 -2747 ($ (-310 (-381)))) (-15 -2747 ($ (-310 (-169 (-381))))) (-15 -2747 ($ (-288 (-310 (-568))))) (-15 -2747 ($ (-288 (-310 (-381))))) (-15 -2747 ($ (-288 (-310 (-169 (-381)))))))) (-1161) (-3 (|:| |fst| (-436)) (|:| -3613 "void")) (-634 (-1161)) (-1165)) (T -400)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-328)) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-310 (-690))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-310 (-688))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-310 (-683))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-690)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-688)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-683)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-310 (-568))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-310 (-381))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-310 (-169 (-381)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-568)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-381)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-169 (-381))))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165))))) 
+(-13 (-397) (-10 -8 (-15 -2747 ($ (-328))) (-15 -2747 ($ (-634 (-328)))) (-15 -2747 ($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328)))))) (-15 -2747 ($ (-310 (-690)))) (-15 -2747 ($ (-310 (-688)))) (-15 -2747 ($ (-310 (-683)))) (-15 -2747 ($ (-288 (-310 (-690))))) (-15 -2747 ($ (-288 (-310 (-688))))) (-15 -2747 ($ (-288 (-310 (-683))))) (-15 -2747 ($ (-310 (-568)))) (-15 -2747 ($ (-310 (-381)))) (-15 -2747 ($ (-310 (-169 (-381))))) (-15 -2747 ($ (-288 (-310 (-568))))) (-15 -2747 ($ (-288 (-310 (-381))))) (-15 -2747 ($ (-288 (-310 (-169 (-381)))))))) 
+((-2449 (((-121) $ $) NIL)) (-3949 ((|#2| $) 36)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-3373 (($ (-409 |#2|)) 84)) (-3358 (((-634 (-2 (|:| -3483 (-763)) (|:| -1374 |#2|) (|:| |num| |#2|))) $) 37)) (-4191 (($ $) 32) (($ $ (-763)) 34)) (-4280 (((-409 |#2|) $) 46)) (-4289 (($ (-634 (-2 (|:| -3483 (-763)) (|:| -1374 |#2|) (|:| |num| |#2|)))) 31)) (-2747 (((-850) $) 120)) (-3192 (($ $) 33) (($ $ (-763)) 35)) (-1719 (((-121) $ $) NIL)) (-1769 (($ |#2| $) 39))) 
+(((-401 |#1| |#2|) (-13 (-1090) (-609 (-409 |#2|)) (-10 -8 (-15 -1769 ($ |#2| $)) (-15 -3373 ($ (-409 |#2|))) (-15 -3949 (|#2| $)) (-15 -3358 ((-634 (-2 (|:| -3483 (-763)) (|:| -1374 |#2|) (|:| |num| |#2|))) $)) (-15 -4289 ($ (-634 (-2 (|:| -3483 (-763)) (|:| -1374 |#2|) (|:| |num| |#2|))))) (-15 -4191 ($ $)) (-15 -3192 ($ $)) (-15 -4191 ($ $ (-763))) (-15 -3192 ($ $ (-763))))) (-13 (-365) (-150)) (-1219 |#1|)) (T -401)) 
+((-1769 (*1 *1 *2 *1) (-12 (-4 *3 (-13 (-365) (-150))) (-5 *1 (-401 *3 *2)) (-4 *2 (-1219 *3)))) (-3373 (*1 *1 *2) (-12 (-5 *2 (-409 *4)) (-4 *4 (-1219 *3)) (-4 *3 (-13 (-365) (-150))) (-5 *1 (-401 *3 *4)))) (-3949 (*1 *2 *1) (-12 (-4 *2 (-1219 *3)) (-5 *1 (-401 *3 *2)) (-4 *3 (-13 (-365) (-150))))) (-3358 (*1 *2 *1) (-12 (-4 *3 (-13 (-365) (-150))) (-5 *2 (-634 (-2 (|:| -3483 (-763)) (|:| -1374 *4) (|:| |num| *4)))) (-5 *1 (-401 *3 *4)) (-4 *4 (-1219 *3)))) (-4289 (*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3483 (-763)) (|:| -1374 *4) (|:| |num| *4)))) (-4 *4 (-1219 *3)) (-4 *3 (-13 (-365) (-150))) (-5 *1 (-401 *3 *4)))) (-4191 (*1 *1 *1) (-12 (-4 *2 (-13 (-365) (-150))) (-5 *1 (-401 *2 *3)) (-4 *3 (-1219 *2)))) (-3192 (*1 *1 *1) (-12 (-4 *2 (-13 (-365) (-150))) (-5 *1 (-401 *2 *3)) (-4 *3 (-1219 *2)))) (-4191 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *3 (-13 (-365) (-150))) (-5 *1 (-401 *3 *4)) (-4 *4 (-1219 *3)))) (-3192 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *3 (-13 (-365) (-150))) (-5 *1 (-401 *3 *4)) (-4 *4 (-1219 *3))))) 
+(-13 (-1090) (-609 (-409 |#2|)) (-10 -8 (-15 -1769 ($ |#2| $)) (-15 -3373 ($ (-409 |#2|))) (-15 -3949 (|#2| $)) (-15 -3358 ((-634 (-2 (|:| -3483 (-763)) (|:| -1374 |#2|) (|:| |num| |#2|))) $)) (-15 -4289 ($ (-634 (-2 (|:| -3483 (-763)) (|:| -1374 |#2|) (|:| |num| |#2|))))) (-15 -4191 ($ $)) (-15 -3192 ($ $)) (-15 -4191 ($ $ (-763))) (-15 -3192 ($ $ (-763))))) 
+((-2449 (((-121) $ $) 9 (-2199 (|has| |#1| (-881 (-568))) (|has| |#1| (-881 (-381)))))) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 15 (|has| |#1| (-881 (-381)))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 14 (|has| |#1| (-881 (-568))))) (-1893 (((-1143) $) 13 (-2199 (|has| |#1| (-881 (-568))) (|has| |#1| (-881 (-381)))))) (-4025 (((-1108) $) 12 (-2199 (|has| |#1| (-881 (-568))) (|has| |#1| (-881 (-381)))))) (-2747 (((-850) $) 11 (-2199 (|has| |#1| (-881 (-568))) (|has| |#1| (-881 (-381)))))) (-1719 (((-121) $ $) 10 (-2199 (|has| |#1| (-881 (-568))) (|has| |#1| (-881 (-381))))))) 
 (((-402 |#1|) (-1275) (-1195)) (T -402)) 
 NIL 
 (-13 (-1195) (-10 -7 (IF (|has| |t#1| (-881 (-568))) (-6 (-881 (-568))) |noBranch|) (IF (|has| |t#1| (-881 (-381))) (-6 (-881 (-381))) |noBranch|))) 
-(((-105) -2198 (|has| |#1| (-881 (-568))) (|has| |#1| (-881 (-381)))) ((-608 (-850)) -2198 (|has| |#1| (-881 (-568))) (|has| |#1| (-881 (-381)))) ((-881 (-381)) |has| |#1| (-881 (-381))) ((-881 (-568)) |has| |#1| (-881 (-568))) ((-1090) -2198 (|has| |#1| (-881 (-568))) (|has| |#1| (-881 (-381)))) ((-1195) . T)) 
-((-3218 (($ $) 10) (($ $ (-763)) 11))) 
-(((-403 |#1|) (-10 -8 (-15 -3218 (|#1| |#1| (-763))) (-15 -3218 (|#1| |#1|))) (-404)) (T -403)) 
+(((-105) -2199 (|has| |#1| (-881 (-568))) (|has| |#1| (-881 (-381)))) ((-608 (-850)) -2199 (|has| |#1| (-881 (-568))) (|has| |#1| (-881 (-381)))) ((-881 (-381)) |has| |#1| (-881 (-381))) ((-881 (-568)) |has| |#1| (-881 (-568))) ((-1090) -2199 (|has| |#1| (-881 (-568))) (|has| |#1| (-881 (-381)))) ((-1195) . T)) 
+((-1887 (($ $) 10) (($ $ (-763)) 11))) 
+(((-403 |#1|) (-10 -8 (-15 -1887 (|#1| |#1| (-763))) (-15 -1887 (|#1| |#1|))) (-404)) (T -403)) 
 NIL 
-(-10 -8 (-15 -3218 (|#1| |#1| (-763))) (-15 -3218 (|#1| |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-3134 (((-3 $ "failed") $ $) 18)) (-4305 (($ $) 71)) (-1678 (((-420 $) $) 70)) (-1497 (((-121) $ $) 57)) (-2671 (($) 16 T CONST)) (-2401 (($ $ $) 53)) (-2925 (((-3 $ "failed") $) 33)) (-2412 (($ $ $) 54)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 49)) (-3218 (($ $) 75) (($ $ (-763)) 74)) (-3927 (((-121) $) 69)) (-4477 (((-828 (-917)) $) 77)) (-2735 (((-121) $) 30)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-2081 (($ $) 68)) (-4022 (((-1108) $) 10)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-3848 (((-420 $) $) 72)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2595 (((-3 $ "failed") $ $) 41)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-2709 (((-763) $) 56)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 55)) (-3143 (((-3 (-763) "failed") $ $) 76)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63)) (-4371 (((-3 $ "failed") $) 78)) (-4078 (((-763)) 28)) (-1826 (((-121) $ $) 38)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1779 (($ $ $) 62)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64))) 
+(-10 -8 (-15 -1887 (|#1| |#1| (-763))) (-15 -1887 (|#1| |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-2689 (((-3 $ "failed") $ $) 18)) (-3045 (($ $) 71)) (-3498 (((-420 $) $) 70)) (-2589 (((-121) $ $) 57)) (-4490 (($) 16 T CONST)) (-2403 (($ $ $) 53)) (-2902 (((-3 $ "failed") $) 33)) (-2414 (($ $ $) 54)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 49)) (-1887 (($ $) 75) (($ $ (-763)) 74)) (-2197 (((-121) $) 69)) (-1844 (((-828 (-917)) $) 77)) (-1598 (((-121) $) 30)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-2083 (($ $) 68)) (-4025 (((-1108) $) 10)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-3850 (((-420 $) $) 72)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2597 (((-3 $ "failed") $ $) 41)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-1466 (((-763) $) 56)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 55)) (-2721 (((-3 (-763) "failed") $ $) 76)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63)) (-3385 (((-3 $ "failed") $) 78)) (-3425 (((-763)) 28)) (-2273 (((-121) $ $) 38)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1781 (($ $ $) 62)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64))) 
 (((-404) (-1275)) (T -404)) 
-((-4477 (*1 *2 *1) (-12 (-4 *1 (-404)) (-5 *2 (-828 (-917))))) (-3143 (*1 *2 *1 *1) (|partial| -12 (-4 *1 (-404)) (-5 *2 (-763)))) (-3218 (*1 *1 *1) (-4 *1 (-404))) (-3218 (*1 *1 *1 *2) (-12 (-4 *1 (-404)) (-5 *2 (-763))))) 
-(-13 (-365) (-148) (-10 -8 (-15 -4477 ((-828 (-917)) $)) (-15 -3143 ((-3 (-763) "failed") $ $)) (-15 -3218 ($ $)) (-15 -3218 ($ $ (-763))))) 
+((-1844 (*1 *2 *1) (-12 (-4 *1 (-404)) (-5 *2 (-828 (-917))))) (-2721 (*1 *2 *1 *1) (|partial| -12 (-4 *1 (-404)) (-5 *2 (-763)))) (-1887 (*1 *1 *1) (-4 *1 (-404))) (-1887 (*1 *1 *1 *2) (-12 (-4 *1 (-404)) (-5 *2 (-763))))) 
+(-13 (-365) (-148) (-10 -8 (-15 -1844 ((-828 (-917)) $)) (-15 -2721 ((-3 (-763) "failed") $ $)) (-15 -1887 ($ $)) (-15 -1887 ($ $ (-763))))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 $ $) . T) ((-137) . T) ((-148) . T) ((-608 (-850)) . T) ((-172) . T) ((-238) . T) ((-285) . T) ((-301) . T) ((-365) . T) ((-453) . T) ((-558) . T) ((-637 (-409 (-568))) . T) ((-637 $) . T) ((-707 (-409 (-568))) . T) ((-707 $) . T) ((-716) . T) ((-916) . T) ((-1053 (-409 (-568))) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1199) . T)) 
-((-3768 (($ (-568) (-568)) 11) (($ (-568) (-568) (-917)) NIL)) (-3396 (((-917)) 16) (((-917) (-917)) NIL))) 
-(((-405 |#1|) (-10 -8 (-15 -3396 ((-917) (-917))) (-15 -3396 ((-917))) (-15 -3768 (|#1| (-568) (-568) (-917))) (-15 -3768 (|#1| (-568) (-568)))) (-406)) (T -405)) 
-((-3396 (*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-405 *3)) (-4 *3 (-406)))) (-3396 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-405 *3)) (-4 *3 (-406))))) 
-(-10 -8 (-15 -3396 ((-917) (-917))) (-15 -3396 ((-917))) (-15 -3768 (|#1| (-568) (-568) (-917))) (-15 -3768 (|#1| (-568) (-568)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-1492 (((-568) $) 85)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-2617 (($ $) 83)) (-3134 (((-3 $ "failed") $ $) 18)) (-4305 (($ $) 71)) (-1678 (((-420 $) $) 70)) (-1902 (($ $) 93)) (-1497 (((-121) $ $) 57)) (-3662 (((-568) $) 110)) (-2671 (($) 16 T CONST)) (-3047 (($ $) 82)) (-3666 (((-3 (-568) "failed") $) 98) (((-3 (-409 (-568)) "failed") $) 95)) (-2854 (((-568) $) 97) (((-409 (-568)) $) 94)) (-2401 (($ $ $) 53)) (-2925 (((-3 $ "failed") $) 33)) (-2412 (($ $ $) 54)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 49)) (-3927 (((-121) $) 69)) (-3359 (((-917)) 119) (((-917) (-917)) 116 (|has| $ (-6 -4510)))) (-2033 (((-121) $) 108)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 89)) (-4477 (((-568) $) 125)) (-2735 (((-121) $) 30)) (-4044 (($ $ (-568)) 92)) (-2657 (($ $) 88)) (-2245 (((-121) $) 109)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-2521 (($ $ $) 107) (($) 113 (-12 (-3044 (|has| $ (-6 -4510))) (-3044 (|has| $ (-6 -4502)))))) (-3268 (($ $ $) 106) (($) 112 (-12 (-3044 (|has| $ (-6 -4510))) (-3044 (|has| $ (-6 -4502)))))) (-3544 (((-568) $) 122)) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-2081 (($ $) 68)) (-2719 (((-917) (-568)) 115 (|has| $ (-6 -4510)))) (-4022 (((-1108) $) 10)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-3880 (($ $) 84)) (-1519 (($ $) 86)) (-3768 (($ (-568) (-568)) 127) (($ (-568) (-568) (-917)) 126)) (-3848 (((-420 $) $) 72)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2595 (((-3 $ "failed") $ $) 41)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-3438 (((-568) $) 123)) (-2709 (((-763) $) 56)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 55)) (-3396 (((-917)) 120) (((-917) (-917)) 117 (|has| $ (-6 -4510)))) (-2573 (((-917) (-568)) 114 (|has| $ (-6 -4510)))) (-4278 (((-381) $) 101) (((-215) $) 100) (((-887 (-381)) $) 90)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63) (($ (-568)) 99) (($ (-409 (-568))) 96)) (-4078 (((-763)) 28)) (-2285 (($ $) 87)) (-4042 (((-917)) 121) (((-917) (-917)) 118 (|has| $ (-6 -4510)))) (-1461 (((-917)) 124)) (-1826 (((-121) $ $) 38)) (-2897 (($ $) 111)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1751 (((-121) $ $) 104)) (-1738 (((-121) $ $) 103)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 105)) (-1732 (((-121) $ $) 102)) (-1779 (($ $ $) 62)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66) (($ $ (-409 (-568))) 91)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64))) 
+((-3770 (($ (-568) (-568)) 11) (($ (-568) (-568) (-917)) NIL)) (-1513 (((-917)) 16) (((-917) (-917)) NIL))) 
+(((-405 |#1|) (-10 -8 (-15 -1513 ((-917) (-917))) (-15 -1513 ((-917))) (-15 -3770 (|#1| (-568) (-568) (-917))) (-15 -3770 (|#1| (-568) (-568)))) (-406)) (T -405)) 
+((-1513 (*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-405 *3)) (-4 *3 (-406)))) (-1513 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-405 *3)) (-4 *3 (-406))))) 
+(-10 -8 (-15 -1513 ((-917) (-917))) (-15 -1513 ((-917))) (-15 -3770 (|#1| (-568) (-568) (-917))) (-15 -3770 (|#1| (-568) (-568)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2563 (((-568) $) 85)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-4179 (($ $) 83)) (-2689 (((-3 $ "failed") $ $) 18)) (-3045 (($ $) 71)) (-3498 (((-420 $) $) 70)) (-1904 (($ $) 93)) (-2589 (((-121) $ $) 57)) (-3337 (((-568) $) 110)) (-4490 (($) 16 T CONST)) (-2252 (($ $) 82)) (-3668 (((-3 (-568) "failed") $) 98) (((-3 (-409 (-568)) "failed") $) 95)) (-2857 (((-568) $) 97) (((-409 (-568)) $) 94)) (-2403 (($ $ $) 53)) (-2902 (((-3 $ "failed") $) 33)) (-2414 (($ $ $) 54)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 49)) (-2197 (((-121) $) 69)) (-3359 (((-917)) 119) (((-917) (-917)) 116 (|has| $ (-6 -4512)))) (-1436 (((-121) $) 108)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 89)) (-1844 (((-568) $) 125)) (-1598 (((-121) $) 30)) (-1550 (($ $ (-568)) 92)) (-4417 (($ $) 88)) (-2859 (((-121) $) 109)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-1732 (($ $ $) 107) (($) 113 (-12 (-3046 (|has| $ (-6 -4512))) (-3046 (|has| $ (-6 -4504)))))) (-2047 (($ $ $) 106) (($) 112 (-12 (-3046 (|has| $ (-6 -4512))) (-3046 (|has| $ (-6 -4504)))))) (-2790 (((-568) $) 122)) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-2083 (($ $) 68)) (-1529 (((-917) (-568)) 115 (|has| $ (-6 -4512)))) (-4025 (((-1108) $) 10)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-1999 (($ $) 84)) (-4115 (($ $) 86)) (-3770 (($ (-568) (-568)) 127) (($ (-568) (-568) (-917)) 126)) (-3850 (((-420 $) $) 72)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2597 (((-3 $ "failed") $ $) 41)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-3483 (((-568) $) 123)) (-1466 (((-763) $) 56)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 55)) (-1513 (((-917)) 120) (((-917) (-917)) 117 (|has| $ (-6 -4512)))) (-1973 (((-917) (-568)) 114 (|has| $ (-6 -4512)))) (-4280 (((-381) $) 101) (((-215) $) 100) (((-887 (-381)) $) 90)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63) (($ (-568)) 99) (($ (-409 (-568))) 96)) (-3425 (((-763)) 28)) (-3520 (($ $) 87)) (-1540 (((-917)) 121) (((-917) (-917)) 118 (|has| $ (-6 -4512)))) (-2404 (((-917)) 124)) (-2273 (((-121) $ $) 38)) (-2811 (($ $) 111)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1753 (((-121) $ $) 104)) (-1740 (((-121) $ $) 103)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 105)) (-1734 (((-121) $ $) 102)) (-1781 (($ $ $) 62)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66) (($ $ (-409 (-568))) 91)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64))) 
 (((-406) (-1275)) (T -406)) 
-((-3768 (*1 *1 *2 *2) (-12 (-5 *2 (-568)) (-4 *1 (-406)))) (-3768 (*1 *1 *2 *2 *3) (-12 (-5 *2 (-568)) (-5 *3 (-917)) (-4 *1 (-406)))) (-4477 (*1 *2 *1) (-12 (-4 *1 (-406)) (-5 *2 (-568)))) (-1461 (*1 *2) (-12 (-4 *1 (-406)) (-5 *2 (-917)))) (-3438 (*1 *2 *1) (-12 (-4 *1 (-406)) (-5 *2 (-568)))) (-3544 (*1 *2 *1) (-12 (-4 *1 (-406)) (-5 *2 (-568)))) (-4042 (*1 *2) (-12 (-4 *1 (-406)) (-5 *2 (-917)))) (-3396 (*1 *2) (-12 (-4 *1 (-406)) (-5 *2 (-917)))) (-3359 (*1 *2) (-12 (-4 *1 (-406)) (-5 *2 (-917)))) (-4042 (*1 *2 *2) (-12 (-5 *2 (-917)) (|has| *1 (-6 -4510)) (-4 *1 (-406)))) (-3396 (*1 *2 *2) (-12 (-5 *2 (-917)) (|has| *1 (-6 -4510)) (-4 *1 (-406)))) (-3359 (*1 *2 *2) (-12 (-5 *2 (-917)) (|has| *1 (-6 -4510)) (-4 *1 (-406)))) (-2719 (*1 *2 *3) (-12 (-5 *3 (-568)) (|has| *1 (-6 -4510)) (-4 *1 (-406)) (-5 *2 (-917)))) (-2573 (*1 *2 *3) (-12 (-5 *3 (-568)) (|has| *1 (-6 -4510)) (-4 *1 (-406)) (-5 *2 (-917)))) (-2521 (*1 *1) (-12 (-4 *1 (-406)) (-3044 (|has| *1 (-6 -4510))) (-3044 (|has| *1 (-6 -4502))))) (-3268 (*1 *1) (-12 (-4 *1 (-406)) (-3044 (|has| *1 (-6 -4510))) (-3044 (|has| *1 (-6 -4502)))))) 
-(-13 (-1056) (-10 -8 (-6 -3996) (-15 -3768 ($ (-568) (-568))) (-15 -3768 ($ (-568) (-568) (-917))) (-15 -4477 ((-568) $)) (-15 -1461 ((-917))) (-15 -3438 ((-568) $)) (-15 -3544 ((-568) $)) (-15 -4042 ((-917))) (-15 -3396 ((-917))) (-15 -3359 ((-917))) (IF (|has| $ (-6 -4510)) (PROGN (-15 -4042 ((-917) (-917))) (-15 -3396 ((-917) (-917))) (-15 -3359 ((-917) (-917))) (-15 -2719 ((-917) (-568))) (-15 -2573 ((-917) (-568)))) |noBranch|) (IF (|has| $ (-6 -4502)) |noBranch| (IF (|has| $ (-6 -4510)) |noBranch| (PROGN (-15 -2521 ($)) (-15 -3268 ($))))))) 
+((-3770 (*1 *1 *2 *2) (-12 (-5 *2 (-568)) (-4 *1 (-406)))) (-3770 (*1 *1 *2 *2 *3) (-12 (-5 *2 (-568)) (-5 *3 (-917)) (-4 *1 (-406)))) (-1844 (*1 *2 *1) (-12 (-4 *1 (-406)) (-5 *2 (-568)))) (-2404 (*1 *2) (-12 (-4 *1 (-406)) (-5 *2 (-917)))) (-3483 (*1 *2 *1) (-12 (-4 *1 (-406)) (-5 *2 (-568)))) (-2790 (*1 *2 *1) (-12 (-4 *1 (-406)) (-5 *2 (-568)))) (-1540 (*1 *2) (-12 (-4 *1 (-406)) (-5 *2 (-917)))) (-1513 (*1 *2) (-12 (-4 *1 (-406)) (-5 *2 (-917)))) (-3359 (*1 *2) (-12 (-4 *1 (-406)) (-5 *2 (-917)))) (-1540 (*1 *2 *2) (-12 (-5 *2 (-917)) (|has| *1 (-6 -4512)) (-4 *1 (-406)))) (-1513 (*1 *2 *2) (-12 (-5 *2 (-917)) (|has| *1 (-6 -4512)) (-4 *1 (-406)))) (-3359 (*1 *2 *2) (-12 (-5 *2 (-917)) (|has| *1 (-6 -4512)) (-4 *1 (-406)))) (-1529 (*1 *2 *3) (-12 (-5 *3 (-568)) (|has| *1 (-6 -4512)) (-4 *1 (-406)) (-5 *2 (-917)))) (-1973 (*1 *2 *3) (-12 (-5 *3 (-568)) (|has| *1 (-6 -4512)) (-4 *1 (-406)) (-5 *2 (-917)))) (-1732 (*1 *1) (-12 (-4 *1 (-406)) (-3046 (|has| *1 (-6 -4512))) (-3046 (|has| *1 (-6 -4504))))) (-2047 (*1 *1) (-12 (-4 *1 (-406)) (-3046 (|has| *1 (-6 -4512))) (-3046 (|has| *1 (-6 -4504)))))) 
+(-13 (-1056) (-10 -8 (-6 -3999) (-15 -3770 ($ (-568) (-568))) (-15 -3770 ($ (-568) (-568) (-917))) (-15 -1844 ((-568) $)) (-15 -2404 ((-917))) (-15 -3483 ((-568) $)) (-15 -2790 ((-568) $)) (-15 -1540 ((-917))) (-15 -1513 ((-917))) (-15 -3359 ((-917))) (IF (|has| $ (-6 -4512)) (PROGN (-15 -1540 ((-917) (-917))) (-15 -1513 ((-917) (-917))) (-15 -3359 ((-917) (-917))) (-15 -1529 ((-917) (-568))) (-15 -1973 ((-917) (-568)))) |noBranch|) (IF (|has| $ (-6 -4504)) |noBranch| (IF (|has| $ (-6 -4512)) |noBranch| (PROGN (-15 -1732 ($)) (-15 -2047 ($))))))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 $ $) . T) ((-137) . T) ((-150) . T) ((-608 (-850)) . T) ((-172) . T) ((-609 (-215)) . T) ((-609 (-381)) . T) ((-609 (-887 (-381))) . T) ((-238) . T) ((-285) . T) ((-301) . T) ((-365) . T) ((-453) . T) ((-558) . T) ((-637 (-409 (-568))) . T) ((-637 $) . T) ((-707 (-409 (-568))) . T) ((-707 $) . T) ((-716) . T) ((-786) . T) ((-787) . T) ((-789) . T) ((-790) . T) ((-840) . T) ((-842) . T) ((-881 (-381)) . T) ((-916) . T) ((-1002) . T) ((-1021) . T) ((-1056) . T) ((-1037 (-409 (-568))) . T) ((-1037 (-568)) . T) ((-1053 (-409 (-568))) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1199) . T)) 
-((-2795 (((-420 |#2|) (-1 |#2| |#1|) (-420 |#1|)) 20))) 
-(((-407 |#1| |#2|) (-10 -7 (-15 -2795 ((-420 |#2|) (-1 |#2| |#1|) (-420 |#1|)))) (-558) (-558)) (T -407)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-420 *5)) (-4 *5 (-558)) (-4 *6 (-558)) (-5 *2 (-420 *6)) (-5 *1 (-407 *5 *6))))) 
-(-10 -7 (-15 -2795 ((-420 |#2|) (-1 |#2| |#1|) (-420 |#1|)))) 
-((-2795 (((-409 |#2|) (-1 |#2| |#1|) (-409 |#1|)) 13))) 
-(((-408 |#1| |#2|) (-10 -7 (-15 -2795 ((-409 |#2|) (-1 |#2| |#1|) (-409 |#1|)))) (-558) (-558)) (T -408)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-409 *5)) (-4 *5 (-558)) (-4 *6 (-558)) (-5 *2 (-409 *6)) (-5 *1 (-408 *5 *6))))) 
-(-10 -7 (-15 -2795 ((-409 |#2|) (-1 |#2| |#1|) (-409 |#1|)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 13)) (-1492 ((|#1| $) 21 (|has| |#1| (-301)))) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-1497 (((-121) $ $) NIL)) (-3662 (((-568) $) NIL (|has| |#1| (-815)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) 17) (((-3 (-1161) "failed") $) NIL (|has| |#1| (-1037 (-1161)))) (((-3 (-409 (-568)) "failed") $) 70 (|has| |#1| (-1037 (-568)))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568))))) (-2854 ((|#1| $) 15) (((-1161) $) NIL (|has| |#1| (-1037 (-1161)))) (((-409 (-568)) $) 67 (|has| |#1| (-1037 (-568)))) (((-568) $) NIL (|has| |#1| (-1037 (-568))))) (-2401 (($ $ $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) 50)) (-1731 (($) NIL (|has| |#1| (-550)))) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-2033 (((-121) $) NIL (|has| |#1| (-815)))) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| |#1| (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| |#1| (-881 (-381))))) (-2735 (((-121) $) 64)) (-1332 (($ $) NIL)) (-2317 ((|#1| $) 71)) (-3038 (((-3 $ "failed") $) NIL (|has| |#1| (-1136)))) (-2245 (((-121) $) NIL (|has| |#1| (-815)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4434 (($) NIL (|has| |#1| (-1136)) CONST)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 97)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3880 (($ $) NIL (|has| |#1| (-301)))) (-1519 ((|#1| $) 28 (|has| |#1| (-550)))) (-2905 (((-420 (-1157 $)) (-1157 $)) 133 (|has| |#1| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) 129 (|has| |#1| (-904)))) (-3848 (((-420 $) $) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1339 (($ $ (-634 |#1|) (-634 |#1|)) NIL (|has| |#1| (-303 |#1|))) (($ $ |#1| |#1|) NIL (|has| |#1| (-303 |#1|))) (($ $ (-288 |#1|)) NIL (|has| |#1| (-303 |#1|))) (($ $ (-634 (-288 |#1|))) NIL (|has| |#1| (-303 |#1|))) (($ $ (-634 (-1161)) (-634 |#1|)) NIL (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-1161) |#1|) NIL (|has| |#1| (-523 (-1161) |#1|)))) (-2709 (((-763) $) NIL)) (-2779 (($ $ |#1|) NIL (|has| |#1| (-281 |#1| |#1|)))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-4189 (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) 63)) (-3013 (($ $) NIL)) (-2324 ((|#1| $) 73)) (-4278 (((-887 (-568)) $) NIL (|has| |#1| (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| |#1| (-609 (-887 (-381))))) (((-541) $) NIL (|has| |#1| (-609 (-541)))) (((-381) $) NIL (|has| |#1| (-1021))) (((-215) $) NIL (|has| |#1| (-1021)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) 113 (-12 (|has| $ (-148)) (|has| |#1| (-904))))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ |#1|) 10) (($ (-1161)) NIL (|has| |#1| (-1037 (-1161))))) (-4371 (((-3 $ "failed") $) 99 (-2198 (-12 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-4078 (((-763)) 100)) (-2285 ((|#1| $) 26 (|has| |#1| (-550)))) (-1826 (((-121) $ $) NIL)) (-2897 (($ $) NIL (|has| |#1| (-815)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) 22 T CONST)) (-1556 (($) 8 T CONST)) (-3754 (((-1143) $) 43 (-12 (|has| |#1| (-550)) (|has| |#1| (-823)))) (((-1143) $ (-121)) 44 (-12 (|has| |#1| (-550)) (|has| |#1| (-823)))) (((-1249) (-817) $) 45 (-12 (|has| |#1| (-550)) (|has| |#1| (-823)))) (((-1249) (-817) $ (-121)) 46 (-12 (|has| |#1| (-550)) (|has| |#1| (-823))))) (-3190 (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) 56)) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) 24 (|has| |#1| (-842)))) (-1779 (($ $ $) 124) (($ |#1| |#1|) 52)) (-1773 (($ $) 25) (($ $ $) 55)) (-1767 (($ $ $) 53)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) 123)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 60) (($ $ $) 57) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ |#1| $) 61) (($ $ |#1|) 85))) 
-(((-409 |#1|) (-13 (-993 |#1|) (-10 -7 (IF (|has| |#1| (-550)) (IF (|has| |#1| (-823)) (-6 (-823)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4506)) (IF (|has| |#1| (-453)) (IF (|has| |#1| (-6 -4517)) (-6 -4506) |noBranch|) |noBranch|) |noBranch|))) (-558)) (T -409)) 
-NIL 
-(-13 (-993 |#1|) (-10 -7 (IF (|has| |#1| (-550)) (IF (|has| |#1| (-823)) (-6 (-823)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4506)) (IF (|has| |#1| (-453)) (IF (|has| |#1| (-6 -4517)) (-6 -4506) |noBranch|) |noBranch|) |noBranch|))) 
-((-4255 (((-679 |#2|) (-1244 $)) NIL) (((-679 |#2|)) 18)) (-3498 (($ (-1244 |#2|) (-1244 $)) NIL) (($ (-1244 |#2|)) 26)) (-1709 (((-679 |#2|) $ (-1244 $)) NIL) (((-679 |#2|) $) 22)) (-2045 ((|#3| $) 59)) (-2217 ((|#2| (-1244 $)) NIL) ((|#2|) 20)) (-4073 (((-1244 |#2|) $ (-1244 $)) NIL) (((-679 |#2|) (-1244 $) (-1244 $)) NIL) (((-1244 |#2|) $) NIL) (((-679 |#2|) (-1244 $)) 24)) (-4278 (((-1244 |#2|) $) 11) (($ (-1244 |#2|)) 13)) (-2678 ((|#3| $) 51))) 
-(((-410 |#1| |#2| |#3|) (-10 -8 (-15 -1709 ((-679 |#2|) |#1|)) (-15 -2217 (|#2|)) (-15 -4255 ((-679 |#2|))) (-15 -4278 (|#1| (-1244 |#2|))) (-15 -4278 ((-1244 |#2|) |#1|)) (-15 -3498 (|#1| (-1244 |#2|))) (-15 -4073 ((-679 |#2|) (-1244 |#1|))) (-15 -4073 ((-1244 |#2|) |#1|)) (-15 -2045 (|#3| |#1|)) (-15 -2678 (|#3| |#1|)) (-15 -4255 ((-679 |#2|) (-1244 |#1|))) (-15 -2217 (|#2| (-1244 |#1|))) (-15 -3498 (|#1| (-1244 |#2|) (-1244 |#1|))) (-15 -4073 ((-679 |#2|) (-1244 |#1|) (-1244 |#1|))) (-15 -4073 ((-1244 |#2|) |#1| (-1244 |#1|))) (-15 -1709 ((-679 |#2|) |#1| (-1244 |#1|)))) (-411 |#2| |#3|) (-172) (-1219 |#2|)) (T -410)) 
-((-4255 (*1 *2) (-12 (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-679 *4)) (-5 *1 (-410 *3 *4 *5)) (-4 *3 (-411 *4 *5)))) (-2217 (*1 *2) (-12 (-4 *4 (-1219 *2)) (-4 *2 (-172)) (-5 *1 (-410 *3 *2 *4)) (-4 *3 (-411 *2 *4))))) 
-(-10 -8 (-15 -1709 ((-679 |#2|) |#1|)) (-15 -2217 (|#2|)) (-15 -4255 ((-679 |#2|))) (-15 -4278 (|#1| (-1244 |#2|))) (-15 -4278 ((-1244 |#2|) |#1|)) (-15 -3498 (|#1| (-1244 |#2|))) (-15 -4073 ((-679 |#2|) (-1244 |#1|))) (-15 -4073 ((-1244 |#2|) |#1|)) (-15 -2045 (|#3| |#1|)) (-15 -2678 (|#3| |#1|)) (-15 -4255 ((-679 |#2|) (-1244 |#1|))) (-15 -2217 (|#2| (-1244 |#1|))) (-15 -3498 (|#1| (-1244 |#2|) (-1244 |#1|))) (-15 -4073 ((-679 |#2|) (-1244 |#1|) (-1244 |#1|))) (-15 -4073 ((-1244 |#2|) |#1| (-1244 |#1|))) (-15 -1709 ((-679 |#2|) |#1| (-1244 |#1|)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-4255 (((-679 |#1|) (-1244 $)) 44) (((-679 |#1|)) 55)) (-1932 ((|#1| $) 50)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-3498 (($ (-1244 |#1|) (-1244 $)) 46) (($ (-1244 |#1|)) 58)) (-1709 (((-679 |#1|) $ (-1244 $)) 51) (((-679 |#1|) $) 53)) (-2925 (((-3 $ "failed") $) 33)) (-3700 (((-917)) 52)) (-2735 (((-121) $) 30)) (-2657 ((|#1| $) 49)) (-2045 ((|#2| $) 42 (|has| |#1| (-365)))) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2217 ((|#1| (-1244 $)) 45) ((|#1|) 54)) (-4073 (((-1244 |#1|) $ (-1244 $)) 48) (((-679 |#1|) (-1244 $) (-1244 $)) 47) (((-1244 |#1|) $) 60) (((-679 |#1|) (-1244 $)) 59)) (-4278 (((-1244 |#1|) $) 57) (($ (-1244 |#1|)) 56)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 36)) (-4371 (((-3 $ "failed") $) 41 (|has| |#1| (-148)))) (-2678 ((|#2| $) 43)) (-4078 (((-763)) 28)) (-3746 (((-1244 $)) 61)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37))) 
+((-2797 (((-420 |#2|) (-1 |#2| |#1|) (-420 |#1|)) 20))) 
+(((-407 |#1| |#2|) (-10 -7 (-15 -2797 ((-420 |#2|) (-1 |#2| |#1|) (-420 |#1|)))) (-558) (-558)) (T -407)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-420 *5)) (-4 *5 (-558)) (-4 *6 (-558)) (-5 *2 (-420 *6)) (-5 *1 (-407 *5 *6))))) 
+(-10 -7 (-15 -2797 ((-420 |#2|) (-1 |#2| |#1|) (-420 |#1|)))) 
+((-2797 (((-409 |#2|) (-1 |#2| |#1|) (-409 |#1|)) 13))) 
+(((-408 |#1| |#2|) (-10 -7 (-15 -2797 ((-409 |#2|) (-1 |#2| |#1|) (-409 |#1|)))) (-558) (-558)) (T -408)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-409 *5)) (-4 *5 (-558)) (-4 *6 (-558)) (-5 *2 (-409 *6)) (-5 *1 (-408 *5 *6))))) 
+(-10 -7 (-15 -2797 ((-409 |#2|) (-1 |#2| |#1|) (-409 |#1|)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 13)) (-2563 ((|#1| $) 21 (|has| |#1| (-301)))) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-2589 (((-121) $ $) NIL)) (-3337 (((-568) $) NIL (|has| |#1| (-815)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) 17) (((-3 (-1161) "failed") $) NIL (|has| |#1| (-1037 (-1161)))) (((-3 (-409 (-568)) "failed") $) 70 (|has| |#1| (-1037 (-568)))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568))))) (-2857 ((|#1| $) 15) (((-1161) $) NIL (|has| |#1| (-1037 (-1161)))) (((-409 (-568)) $) 67 (|has| |#1| (-1037 (-568)))) (((-568) $) NIL (|has| |#1| (-1037 (-568))))) (-2403 (($ $ $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) 50)) (-1733 (($) NIL (|has| |#1| (-550)))) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-1436 (((-121) $) NIL (|has| |#1| (-815)))) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| |#1| (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| |#1| (-881 (-381))))) (-1598 (((-121) $) 64)) (-3539 (($ $) NIL)) (-2319 ((|#1| $) 71)) (-2214 (((-3 $ "failed") $) NIL (|has| |#1| (-1136)))) (-2859 (((-121) $) NIL (|has| |#1| (-815)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4436 (($) NIL (|has| |#1| (-1136)) CONST)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 97)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1999 (($ $) NIL (|has| |#1| (-301)))) (-4115 ((|#1| $) 28 (|has| |#1| (-550)))) (-2841 (((-420 (-1157 $)) (-1157 $)) 133 (|has| |#1| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) 129 (|has| |#1| (-904)))) (-3850 (((-420 $) $) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1339 (($ $ (-634 |#1|) (-634 |#1|)) NIL (|has| |#1| (-303 |#1|))) (($ $ |#1| |#1|) NIL (|has| |#1| (-303 |#1|))) (($ $ (-288 |#1|)) NIL (|has| |#1| (-303 |#1|))) (($ $ (-634 (-288 |#1|))) NIL (|has| |#1| (-303 |#1|))) (($ $ (-634 (-1161)) (-634 |#1|)) NIL (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-1161) |#1|) NIL (|has| |#1| (-523 (-1161) |#1|)))) (-1466 (((-763) $) NIL)) (-2781 (($ $ |#1|) NIL (|has| |#1| (-281 |#1| |#1|)))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-4191 (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) 63)) (-3210 (($ $) NIL)) (-2326 ((|#1| $) 73)) (-4280 (((-887 (-568)) $) NIL (|has| |#1| (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| |#1| (-609 (-887 (-381))))) (((-541) $) NIL (|has| |#1| (-609 (-541)))) (((-381) $) NIL (|has| |#1| (-1021))) (((-215) $) NIL (|has| |#1| (-1021)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) 113 (-12 (|has| $ (-148)) (|has| |#1| (-904))))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ |#1|) 10) (($ (-1161)) NIL (|has| |#1| (-1037 (-1161))))) (-3385 (((-3 $ "failed") $) 99 (-2199 (-12 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-3425 (((-763)) 100)) (-3520 ((|#1| $) 26 (|has| |#1| (-550)))) (-2273 (((-121) $ $) NIL)) (-2811 (($ $) NIL (|has| |#1| (-815)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) 22 T CONST)) (-1557 (($) 8 T CONST)) (-2628 (((-1143) $) 43 (-12 (|has| |#1| (-550)) (|has| |#1| (-823)))) (((-1143) $ (-121)) 44 (-12 (|has| |#1| (-550)) (|has| |#1| (-823)))) (((-1249) (-817) $) 45 (-12 (|has| |#1| (-550)) (|has| |#1| (-823)))) (((-1249) (-817) $ (-121)) 46 (-12 (|has| |#1| (-550)) (|has| |#1| (-823))))) (-3192 (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) 56)) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) 24 (|has| |#1| (-842)))) (-1781 (($ $ $) 124) (($ |#1| |#1|) 52)) (-1775 (($ $) 25) (($ $ $) 55)) (-1769 (($ $ $) 53)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) 123)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 60) (($ $ $) 57) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ |#1| $) 61) (($ $ |#1|) 85))) 
+(((-409 |#1|) (-13 (-993 |#1|) (-10 -7 (IF (|has| |#1| (-550)) (IF (|has| |#1| (-823)) (-6 (-823)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4508)) (IF (|has| |#1| (-453)) (IF (|has| |#1| (-6 -4519)) (-6 -4508) |noBranch|) |noBranch|) |noBranch|))) (-558)) (T -409)) 
+NIL 
+(-13 (-993 |#1|) (-10 -7 (IF (|has| |#1| (-550)) (IF (|has| |#1| (-823)) (-6 (-823)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4508)) (IF (|has| |#1| (-453)) (IF (|has| |#1| (-6 -4519)) (-6 -4508) |noBranch|) |noBranch|) |noBranch|))) 
+((-2883 (((-679 |#2|) (-1244 $)) NIL) (((-679 |#2|)) 18)) (-3899 (($ (-1244 |#2|) (-1244 $)) NIL) (($ (-1244 |#2|)) 26)) (-3653 (((-679 |#2|) $ (-1244 $)) NIL) (((-679 |#2|) $) 22)) (-1497 ((|#3| $) 59)) (-3440 ((|#2| (-1244 $)) NIL) ((|#2|) 20)) (-1656 (((-1244 |#2|) $ (-1244 $)) NIL) (((-679 |#2|) (-1244 $) (-1244 $)) NIL) (((-1244 |#2|) $) NIL) (((-679 |#2|) (-1244 $)) 24)) (-4280 (((-1244 |#2|) $) 11) (($ (-1244 |#2|)) 13)) (-1295 ((|#3| $) 51))) 
+(((-410 |#1| |#2| |#3|) (-10 -8 (-15 -3653 ((-679 |#2|) |#1|)) (-15 -3440 (|#2|)) (-15 -2883 ((-679 |#2|))) (-15 -4280 (|#1| (-1244 |#2|))) (-15 -4280 ((-1244 |#2|) |#1|)) (-15 -3899 (|#1| (-1244 |#2|))) (-15 -1656 ((-679 |#2|) (-1244 |#1|))) (-15 -1656 ((-1244 |#2|) |#1|)) (-15 -1497 (|#3| |#1|)) (-15 -1295 (|#3| |#1|)) (-15 -2883 ((-679 |#2|) (-1244 |#1|))) (-15 -3440 (|#2| (-1244 |#1|))) (-15 -3899 (|#1| (-1244 |#2|) (-1244 |#1|))) (-15 -1656 ((-679 |#2|) (-1244 |#1|) (-1244 |#1|))) (-15 -1656 ((-1244 |#2|) |#1| (-1244 |#1|))) (-15 -3653 ((-679 |#2|) |#1| (-1244 |#1|)))) (-411 |#2| |#3|) (-172) (-1219 |#2|)) (T -410)) 
+((-2883 (*1 *2) (-12 (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-679 *4)) (-5 *1 (-410 *3 *4 *5)) (-4 *3 (-411 *4 *5)))) (-3440 (*1 *2) (-12 (-4 *4 (-1219 *2)) (-4 *2 (-172)) (-5 *1 (-410 *3 *2 *4)) (-4 *3 (-411 *2 *4))))) 
+(-10 -8 (-15 -3653 ((-679 |#2|) |#1|)) (-15 -3440 (|#2|)) (-15 -2883 ((-679 |#2|))) (-15 -4280 (|#1| (-1244 |#2|))) (-15 -4280 ((-1244 |#2|) |#1|)) (-15 -3899 (|#1| (-1244 |#2|))) (-15 -1656 ((-679 |#2|) (-1244 |#1|))) (-15 -1656 ((-1244 |#2|) |#1|)) (-15 -1497 (|#3| |#1|)) (-15 -1295 (|#3| |#1|)) (-15 -2883 ((-679 |#2|) (-1244 |#1|))) (-15 -3440 (|#2| (-1244 |#1|))) (-15 -3899 (|#1| (-1244 |#2|) (-1244 |#1|))) (-15 -1656 ((-679 |#2|) (-1244 |#1|) (-1244 |#1|))) (-15 -1656 ((-1244 |#2|) |#1| (-1244 |#1|))) (-15 -3653 ((-679 |#2|) |#1| (-1244 |#1|)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2883 (((-679 |#1|) (-1244 $)) 44) (((-679 |#1|)) 55)) (-1934 ((|#1| $) 50)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-3899 (($ (-1244 |#1|) (-1244 $)) 46) (($ (-1244 |#1|)) 58)) (-3653 (((-679 |#1|) $ (-1244 $)) 51) (((-679 |#1|) $) 53)) (-2902 (((-3 $ "failed") $) 33)) (-2371 (((-917)) 52)) (-1598 (((-121) $) 30)) (-4417 ((|#1| $) 49)) (-1497 ((|#2| $) 42 (|has| |#1| (-365)))) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-3440 ((|#1| (-1244 $)) 45) ((|#1|) 54)) (-1656 (((-1244 |#1|) $ (-1244 $)) 48) (((-679 |#1|) (-1244 $) (-1244 $)) 47) (((-1244 |#1|) $) 60) (((-679 |#1|) (-1244 $)) 59)) (-4280 (((-1244 |#1|) $) 57) (($ (-1244 |#1|)) 56)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 36)) (-3385 (((-3 $ "failed") $) 41 (|has| |#1| (-148)))) (-1295 ((|#2| $) 43)) (-3425 (((-763)) 28)) (-2588 (((-1244 $)) 61)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37))) 
 (((-411 |#1| |#2|) (-1275) (-172) (-1219 |t#1|)) (T -411)) 
-((-3746 (*1 *2) (-12 (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-1244 *1)) (-4 *1 (-411 *3 *4)))) (-4073 (*1 *2 *1) (-12 (-4 *1 (-411 *3 *4)) (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-1244 *3)))) (-4073 (*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-411 *4 *5)) (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-679 *4)))) (-3498 (*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-172)) (-4 *1 (-411 *3 *4)) (-4 *4 (-1219 *3)))) (-4278 (*1 *2 *1) (-12 (-4 *1 (-411 *3 *4)) (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-1244 *3)))) (-4278 (*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-172)) (-4 *1 (-411 *3 *4)) (-4 *4 (-1219 *3)))) (-4255 (*1 *2) (-12 (-4 *1 (-411 *3 *4)) (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-679 *3)))) (-2217 (*1 *2) (-12 (-4 *1 (-411 *2 *3)) (-4 *3 (-1219 *2)) (-4 *2 (-172)))) (-1709 (*1 *2 *1) (-12 (-4 *1 (-411 *3 *4)) (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-679 *3))))) 
-(-13 (-372 |t#1| |t#2|) (-10 -8 (-15 -3746 ((-1244 $))) (-15 -4073 ((-1244 |t#1|) $)) (-15 -4073 ((-679 |t#1|) (-1244 $))) (-15 -3498 ($ (-1244 |t#1|))) (-15 -4278 ((-1244 |t#1|) $)) (-15 -4278 ($ (-1244 |t#1|))) (-15 -4255 ((-679 |t#1|))) (-15 -2217 (|t#1|)) (-15 -1709 ((-679 |t#1|) $)))) 
+((-2588 (*1 *2) (-12 (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-1244 *1)) (-4 *1 (-411 *3 *4)))) (-1656 (*1 *2 *1) (-12 (-4 *1 (-411 *3 *4)) (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-1244 *3)))) (-1656 (*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-411 *4 *5)) (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-679 *4)))) (-3899 (*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-172)) (-4 *1 (-411 *3 *4)) (-4 *4 (-1219 *3)))) (-4280 (*1 *2 *1) (-12 (-4 *1 (-411 *3 *4)) (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-1244 *3)))) (-4280 (*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-172)) (-4 *1 (-411 *3 *4)) (-4 *4 (-1219 *3)))) (-2883 (*1 *2) (-12 (-4 *1 (-411 *3 *4)) (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-679 *3)))) (-3440 (*1 *2) (-12 (-4 *1 (-411 *2 *3)) (-4 *3 (-1219 *2)) (-4 *2 (-172)))) (-3653 (*1 *2 *1) (-12 (-4 *1 (-411 *3 *4)) (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-679 *3))))) 
+(-13 (-372 |t#1| |t#2|) (-10 -8 (-15 -2588 ((-1244 $))) (-15 -1656 ((-1244 |t#1|) $)) (-15 -1656 ((-679 |t#1|) (-1244 $))) (-15 -3899 ($ (-1244 |t#1|))) (-15 -4280 ((-1244 |t#1|) $)) (-15 -4280 ($ (-1244 |t#1|))) (-15 -2883 ((-679 |t#1|))) (-15 -3440 (|t#1|)) (-15 -3653 ((-679 |t#1|) $)))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#1|) . T) ((-105) . T) ((-120 |#1| |#1|) . T) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-372 |#1| |#2|) . T) ((-637 |#1|) . T) ((-637 $) . T) ((-707 |#1|) . T) ((-716) . T) ((-1053 |#1|) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-3666 (((-3 |#2| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) 27) (((-3 (-568) "failed") $) 19)) (-2854 ((|#2| $) NIL) (((-409 (-568)) $) 24) (((-568) $) 14)) (-2745 (($ |#2|) NIL) (($ (-409 (-568))) 22) (($ (-568)) 11))) 
-(((-412 |#1| |#2|) (-10 -8 (-15 -2854 ((-568) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2745 (|#1| (-568))) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -2745 (|#1| |#2|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -2854 (|#2| |#1|))) (-413 |#2|) (-1195)) (T -412)) 
+((-3668 (((-3 |#2| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) 27) (((-3 (-568) "failed") $) 19)) (-2857 ((|#2| $) NIL) (((-409 (-568)) $) 24) (((-568) $) 14)) (-2747 (($ |#2|) NIL) (($ (-409 (-568))) 22) (($ (-568)) 11))) 
+(((-412 |#1| |#2|) (-10 -8 (-15 -2857 ((-568) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2747 (|#1| (-568))) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -2747 (|#1| |#2|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -2857 (|#2| |#1|))) (-413 |#2|) (-1195)) (T -412)) 
 NIL 
-(-10 -8 (-15 -2854 ((-568) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2745 (|#1| (-568))) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -2745 (|#1| |#2|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -2854 (|#2| |#1|))) 
-((-3666 (((-3 |#1| "failed") $) 7) (((-3 (-409 (-568)) "failed") $) 15 (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) 12 (|has| |#1| (-1037 (-568))))) (-2854 ((|#1| $) 8) (((-409 (-568)) $) 14 (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) 11 (|has| |#1| (-1037 (-568))))) (-2745 (($ |#1|) 6) (($ (-409 (-568))) 16 (|has| |#1| (-1037 (-409 (-568))))) (($ (-568)) 13 (|has| |#1| (-1037 (-568)))))) 
+(-10 -8 (-15 -2857 ((-568) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2747 (|#1| (-568))) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -2747 (|#1| |#2|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -2857 (|#2| |#1|))) 
+((-3668 (((-3 |#1| "failed") $) 7) (((-3 (-409 (-568)) "failed") $) 15 (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) 12 (|has| |#1| (-1037 (-568))))) (-2857 ((|#1| $) 8) (((-409 (-568)) $) 14 (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) 11 (|has| |#1| (-1037 (-568))))) (-2747 (($ |#1|) 6) (($ (-409 (-568))) 16 (|has| |#1| (-1037 (-409 (-568))))) (($ (-568)) 13 (|has| |#1| (-1037 (-568)))))) 
 (((-413 |#1|) (-1275) (-1195)) (T -413)) 
 NIL 
 (-13 (-1037 |t#1|) (-10 -7 (IF (|has| |t#1| (-1037 (-568))) (-6 (-1037 (-568))) |noBranch|) (IF (|has| |t#1| (-1037 (-409 (-568)))) (-6 (-1037 (-409 (-568)))) |noBranch|))) 
 (((-1037 (-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 |#1|) . T)) 
-((-2795 (((-415 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-415 |#1| |#2| |#3| |#4|)) 33))) 
-(((-414 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -2795 ((-415 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-415 |#1| |#2| |#3| |#4|)))) (-301) (-993 |#1|) (-1219 |#2|) (-13 (-411 |#2| |#3|) (-1037 |#2|)) (-301) (-993 |#5|) (-1219 |#6|) (-13 (-411 |#6| |#7|) (-1037 |#6|))) (T -414)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *5)) (-5 *4 (-415 *5 *6 *7 *8)) (-4 *5 (-301)) (-4 *6 (-993 *5)) (-4 *7 (-1219 *6)) (-4 *8 (-13 (-411 *6 *7) (-1037 *6))) (-4 *9 (-301)) (-4 *10 (-993 *9)) (-4 *11 (-1219 *10)) (-5 *2 (-415 *9 *10 *11 *12)) (-5 *1 (-414 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *12 (-13 (-411 *10 *11) (-1037 *10)))))) 
-(-10 -7 (-15 -2795 ((-415 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-415 |#1| |#2| |#3| |#4|)))) 
-((-2447 (((-121) $ $) NIL)) (-2671 (($) NIL T CONST)) (-2925 (((-3 $ "failed") $) NIL)) (-1770 ((|#4| (-763) (-1244 |#4|)) 55)) (-2735 (((-121) $) NIL)) (-2317 (((-1244 |#4|) $) 17)) (-2657 ((|#2| $) 53)) (-3338 (($ $) 136)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) 98)) (-1552 (($ (-1244 |#4|)) 97)) (-4022 (((-1108) $) NIL)) (-2324 ((|#1| $) 18)) (-1458 (($ $ $) NIL)) (-2353 (($ $ $) NIL)) (-2745 (((-850) $) 131)) (-3746 (((-1244 |#4|) $) 126)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-1556 (($) 11 T CONST)) (-1717 (((-121) $ $) 39)) (-1779 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) 119)) (* (($ $ $) 118))) 
-(((-415 |#1| |#2| |#3| |#4|) (-13 (-478) (-10 -8 (-15 -1552 ($ (-1244 |#4|))) (-15 -3746 ((-1244 |#4|) $)) (-15 -2657 (|#2| $)) (-15 -2317 ((-1244 |#4|) $)) (-15 -2324 (|#1| $)) (-15 -3338 ($ $)) (-15 -1770 (|#4| (-763) (-1244 |#4|))))) (-301) (-993 |#1|) (-1219 |#2|) (-13 (-411 |#2| |#3|) (-1037 |#2|))) (T -415)) 
-((-1552 (*1 *1 *2) (-12 (-5 *2 (-1244 *6)) (-4 *6 (-13 (-411 *4 *5) (-1037 *4))) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-4 *3 (-301)) (-5 *1 (-415 *3 *4 *5 *6)))) (-3746 (*1 *2 *1) (-12 (-4 *3 (-301)) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-5 *2 (-1244 *6)) (-5 *1 (-415 *3 *4 *5 *6)) (-4 *6 (-13 (-411 *4 *5) (-1037 *4))))) (-2657 (*1 *2 *1) (-12 (-4 *4 (-1219 *2)) (-4 *2 (-993 *3)) (-5 *1 (-415 *3 *2 *4 *5)) (-4 *3 (-301)) (-4 *5 (-13 (-411 *2 *4) (-1037 *2))))) (-2317 (*1 *2 *1) (-12 (-4 *3 (-301)) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-5 *2 (-1244 *6)) (-5 *1 (-415 *3 *4 *5 *6)) (-4 *6 (-13 (-411 *4 *5) (-1037 *4))))) (-2324 (*1 *2 *1) (-12 (-4 *3 (-993 *2)) (-4 *4 (-1219 *3)) (-4 *2 (-301)) (-5 *1 (-415 *2 *3 *4 *5)) (-4 *5 (-13 (-411 *3 *4) (-1037 *3))))) (-3338 (*1 *1 *1) (-12 (-4 *2 (-301)) (-4 *3 (-993 *2)) (-4 *4 (-1219 *3)) (-5 *1 (-415 *2 *3 *4 *5)) (-4 *5 (-13 (-411 *3 *4) (-1037 *3))))) (-1770 (*1 *2 *3 *4) (-12 (-5 *3 (-763)) (-5 *4 (-1244 *2)) (-4 *5 (-301)) (-4 *6 (-993 *5)) (-4 *2 (-13 (-411 *6 *7) (-1037 *6))) (-5 *1 (-415 *5 *6 *7 *2)) (-4 *7 (-1219 *6))))) 
-(-13 (-478) (-10 -8 (-15 -1552 ($ (-1244 |#4|))) (-15 -3746 ((-1244 |#4|) $)) (-15 -2657 (|#2| $)) (-15 -2317 ((-1244 |#4|) $)) (-15 -2324 (|#1| $)) (-15 -3338 ($ $)) (-15 -1770 (|#4| (-763) (-1244 |#4|))))) 
-((-2447 (((-121) $ $) NIL)) (-2671 (($) NIL T CONST)) (-2925 (((-3 $ "failed") $) NIL)) (-2735 (((-121) $) NIL)) (-2657 ((|#2| $) 60)) (-1726 (($ (-1244 |#4|)) 25) (($ (-415 |#1| |#2| |#3| |#4|)) 75 (|has| |#4| (-1037 |#2|)))) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 34)) (-3746 (((-1244 |#4|) $) 26)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-1556 (($) 23 T CONST)) (-1717 (((-121) $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ $ $) 72))) 
-(((-416 |#1| |#2| |#3| |#4| |#5|) (-13 (-716) (-10 -8 (-15 -3746 ((-1244 |#4|) $)) (-15 -2657 (|#2| $)) (-15 -1726 ($ (-1244 |#4|))) (IF (|has| |#4| (-1037 |#2|)) (-15 -1726 ($ (-415 |#1| |#2| |#3| |#4|))) |noBranch|))) (-301) (-993 |#1|) (-1219 |#2|) (-411 |#2| |#3|) (-1244 |#4|)) (T -416)) 
-((-3746 (*1 *2 *1) (-12 (-4 *3 (-301)) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-5 *2 (-1244 *6)) (-5 *1 (-416 *3 *4 *5 *6 *7)) (-4 *6 (-411 *4 *5)) (-14 *7 *2))) (-2657 (*1 *2 *1) (-12 (-4 *4 (-1219 *2)) (-4 *2 (-993 *3)) (-5 *1 (-416 *3 *2 *4 *5 *6)) (-4 *3 (-301)) (-4 *5 (-411 *2 *4)) (-14 *6 (-1244 *5)))) (-1726 (*1 *1 *2) (-12 (-5 *2 (-1244 *6)) (-4 *6 (-411 *4 *5)) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-4 *3 (-301)) (-5 *1 (-416 *3 *4 *5 *6 *7)) (-14 *7 *2))) (-1726 (*1 *1 *2) (-12 (-5 *2 (-415 *3 *4 *5 *6)) (-4 *6 (-1037 *4)) (-4 *3 (-301)) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-4 *6 (-411 *4 *5)) (-14 *7 (-1244 *6)) (-5 *1 (-416 *3 *4 *5 *6 *7))))) 
-(-13 (-716) (-10 -8 (-15 -3746 ((-1244 |#4|) $)) (-15 -2657 (|#2| $)) (-15 -1726 ($ (-1244 |#4|))) (IF (|has| |#4| (-1037 |#2|)) (-15 -1726 ($ (-415 |#1| |#2| |#3| |#4|))) |noBranch|))) 
-((-2795 ((|#3| (-1 |#4| |#2|) |#1|) 26))) 
-(((-417 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2795 (|#3| (-1 |#4| |#2|) |#1|))) (-419 |#2|) (-172) (-419 |#4|) (-172)) (T -417)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-172)) (-4 *6 (-172)) (-4 *2 (-419 *6)) (-5 *1 (-417 *4 *5 *2 *6)) (-4 *4 (-419 *5))))) 
-(-10 -7 (-15 -2795 (|#3| (-1 |#4| |#2|) |#1|))) 
-((-2295 (((-3 $ "failed")) 85)) (-2776 (((-1244 (-679 |#2|)) (-1244 $)) NIL) (((-1244 (-679 |#2|))) 90)) (-1309 (((-3 (-2 (|:| |particular| $) (|:| -3746 (-634 $))) "failed")) 84)) (-2593 (((-3 $ "failed")) 83)) (-1631 (((-679 |#2|) (-1244 $)) NIL) (((-679 |#2|)) 101)) (-3042 (((-679 |#2|) $ (-1244 $)) NIL) (((-679 |#2|) $) 109)) (-4408 (((-1157 (-953 |#2|))) 54)) (-3569 ((|#2| (-1244 $)) NIL) ((|#2|) 105)) (-3498 (($ (-1244 |#2|) (-1244 $)) NIL) (($ (-1244 |#2|)) 112)) (-3116 (((-3 (-2 (|:| |particular| $) (|:| -3746 (-634 $))) "failed")) 82)) (-2599 (((-3 $ "failed")) 74)) (-4210 (((-679 |#2|) (-1244 $)) NIL) (((-679 |#2|)) 99)) (-4333 (((-679 |#2|) $ (-1244 $)) NIL) (((-679 |#2|) $) 107)) (-4454 (((-1157 (-953 |#2|))) 53)) (-3898 ((|#2| (-1244 $)) NIL) ((|#2|) 103)) (-4073 (((-1244 |#2|) $ (-1244 $)) NIL) (((-679 |#2|) (-1244 $) (-1244 $)) NIL) (((-1244 |#2|) $) NIL) (((-679 |#2|) (-1244 $)) 111)) (-4278 (((-1244 |#2|) $) 95) (($ (-1244 |#2|)) 97)) (-3295 (((-634 (-953 |#2|)) (-1244 $)) NIL) (((-634 (-953 |#2|))) 93)) (-3823 (($ (-679 |#2|) $) 89))) 
-(((-418 |#1| |#2|) (-10 -8 (-15 -3823 (|#1| (-679 |#2|) |#1|)) (-15 -4408 ((-1157 (-953 |#2|)))) (-15 -4454 ((-1157 (-953 |#2|)))) (-15 -3042 ((-679 |#2|) |#1|)) (-15 -4333 ((-679 |#2|) |#1|)) (-15 -1631 ((-679 |#2|))) (-15 -4210 ((-679 |#2|))) (-15 -3569 (|#2|)) (-15 -3898 (|#2|)) (-15 -4278 (|#1| (-1244 |#2|))) (-15 -4278 ((-1244 |#2|) |#1|)) (-15 -3498 (|#1| (-1244 |#2|))) (-15 -3295 ((-634 (-953 |#2|)))) (-15 -2776 ((-1244 (-679 |#2|)))) (-15 -4073 ((-679 |#2|) (-1244 |#1|))) (-15 -4073 ((-1244 |#2|) |#1|)) (-15 -2295 ((-3 |#1| "failed"))) (-15 -2593 ((-3 |#1| "failed"))) (-15 -2599 ((-3 |#1| "failed"))) (-15 -1309 ((-3 (-2 (|:| |particular| |#1|) (|:| -3746 (-634 |#1|))) "failed"))) (-15 -3116 ((-3 (-2 (|:| |particular| |#1|) (|:| -3746 (-634 |#1|))) "failed"))) (-15 -1631 ((-679 |#2|) (-1244 |#1|))) (-15 -4210 ((-679 |#2|) (-1244 |#1|))) (-15 -3569 (|#2| (-1244 |#1|))) (-15 -3898 (|#2| (-1244 |#1|))) (-15 -3498 (|#1| (-1244 |#2|) (-1244 |#1|))) (-15 -4073 ((-679 |#2|) (-1244 |#1|) (-1244 |#1|))) (-15 -4073 ((-1244 |#2|) |#1| (-1244 |#1|))) (-15 -3042 ((-679 |#2|) |#1| (-1244 |#1|))) (-15 -4333 ((-679 |#2|) |#1| (-1244 |#1|))) (-15 -2776 ((-1244 (-679 |#2|)) (-1244 |#1|))) (-15 -3295 ((-634 (-953 |#2|)) (-1244 |#1|)))) (-419 |#2|) (-172)) (T -418)) 
-((-2776 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-1244 (-679 *4))) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4)))) (-3295 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-634 (-953 *4))) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4)))) (-3898 (*1 *2) (-12 (-4 *2 (-172)) (-5 *1 (-418 *3 *2)) (-4 *3 (-419 *2)))) (-3569 (*1 *2) (-12 (-4 *2 (-172)) (-5 *1 (-418 *3 *2)) (-4 *3 (-419 *2)))) (-4210 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-679 *4)) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4)))) (-1631 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-679 *4)) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4)))) (-4454 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-1157 (-953 *4))) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4)))) (-4408 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-1157 (-953 *4))) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4))))) 
-(-10 -8 (-15 -3823 (|#1| (-679 |#2|) |#1|)) (-15 -4408 ((-1157 (-953 |#2|)))) (-15 -4454 ((-1157 (-953 |#2|)))) (-15 -3042 ((-679 |#2|) |#1|)) (-15 -4333 ((-679 |#2|) |#1|)) (-15 -1631 ((-679 |#2|))) (-15 -4210 ((-679 |#2|))) (-15 -3569 (|#2|)) (-15 -3898 (|#2|)) (-15 -4278 (|#1| (-1244 |#2|))) (-15 -4278 ((-1244 |#2|) |#1|)) (-15 -3498 (|#1| (-1244 |#2|))) (-15 -3295 ((-634 (-953 |#2|)))) (-15 -2776 ((-1244 (-679 |#2|)))) (-15 -4073 ((-679 |#2|) (-1244 |#1|))) (-15 -4073 ((-1244 |#2|) |#1|)) (-15 -2295 ((-3 |#1| "failed"))) (-15 -2593 ((-3 |#1| "failed"))) (-15 -2599 ((-3 |#1| "failed"))) (-15 -1309 ((-3 (-2 (|:| |particular| |#1|) (|:| -3746 (-634 |#1|))) "failed"))) (-15 -3116 ((-3 (-2 (|:| |particular| |#1|) (|:| -3746 (-634 |#1|))) "failed"))) (-15 -1631 ((-679 |#2|) (-1244 |#1|))) (-15 -4210 ((-679 |#2|) (-1244 |#1|))) (-15 -3569 (|#2| (-1244 |#1|))) (-15 -3898 (|#2| (-1244 |#1|))) (-15 -3498 (|#1| (-1244 |#2|) (-1244 |#1|))) (-15 -4073 ((-679 |#2|) (-1244 |#1|) (-1244 |#1|))) (-15 -4073 ((-1244 |#2|) |#1| (-1244 |#1|))) (-15 -3042 ((-679 |#2|) |#1| (-1244 |#1|))) (-15 -4333 ((-679 |#2|) |#1| (-1244 |#1|))) (-15 -2776 ((-1244 (-679 |#2|)) (-1244 |#1|))) (-15 -3295 ((-634 (-953 |#2|)) (-1244 |#1|)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-2295 (((-3 $ "failed")) 35 (|has| |#1| (-558)))) (-3134 (((-3 $ "failed") $ $) 18)) (-2776 (((-1244 (-679 |#1|)) (-1244 $)) 76) (((-1244 (-679 |#1|))) 93)) (-1741 (((-1244 $)) 79)) (-2671 (($) 16 T CONST)) (-1309 (((-3 (-2 (|:| |particular| $) (|:| -3746 (-634 $))) "failed")) 38 (|has| |#1| (-558)))) (-2593 (((-3 $ "failed")) 36 (|has| |#1| (-558)))) (-1631 (((-679 |#1|) (-1244 $)) 63) (((-679 |#1|)) 85)) (-1866 ((|#1| $) 72)) (-3042 (((-679 |#1|) $ (-1244 $)) 74) (((-679 |#1|) $) 83)) (-3550 (((-3 $ "failed") $) 43 (|has| |#1| (-558)))) (-4408 (((-1157 (-953 |#1|))) 81 (|has| |#1| (-365)))) (-3551 (($ $ (-917)) 27)) (-4409 ((|#1| $) 70)) (-1371 (((-1157 |#1|) $) 40 (|has| |#1| (-558)))) (-3569 ((|#1| (-1244 $)) 65) ((|#1|) 87)) (-2989 (((-1157 |#1|) $) 61)) (-3384 (((-121)) 55)) (-3498 (($ (-1244 |#1|) (-1244 $)) 67) (($ (-1244 |#1|)) 91)) (-2925 (((-3 $ "failed") $) 45 (|has| |#1| (-558)))) (-3700 (((-917)) 78)) (-4370 (((-121)) 52)) (-4373 (($ $ (-917)) 32)) (-1537 (((-121)) 48)) (-1580 (((-121)) 46)) (-1695 (((-121)) 50)) (-3116 (((-3 (-2 (|:| |particular| $) (|:| -3746 (-634 $))) "failed")) 39 (|has| |#1| (-558)))) (-2599 (((-3 $ "failed")) 37 (|has| |#1| (-558)))) (-4210 (((-679 |#1|) (-1244 $)) 64) (((-679 |#1|)) 86)) (-2889 ((|#1| $) 73)) (-4333 (((-679 |#1|) $ (-1244 $)) 75) (((-679 |#1|) $) 84)) (-3243 (((-3 $ "failed") $) 44 (|has| |#1| (-558)))) (-4454 (((-1157 (-953 |#1|))) 82 (|has| |#1| (-365)))) (-4222 (($ $ (-917)) 28)) (-3329 ((|#1| $) 71)) (-2265 (((-1157 |#1|) $) 41 (|has| |#1| (-558)))) (-3898 ((|#1| (-1244 $)) 66) ((|#1|) 88)) (-3626 (((-1157 |#1|) $) 62)) (-2767 (((-121)) 56)) (-4487 (((-1143) $) 9)) (-1804 (((-121)) 47)) (-2919 (((-121)) 49)) (-3840 (((-121)) 51)) (-4022 (((-1108) $) 10)) (-1346 (((-121)) 54)) (-2779 ((|#1| $ (-568)) 94)) (-4073 (((-1244 |#1|) $ (-1244 $)) 69) (((-679 |#1|) (-1244 $) (-1244 $)) 68) (((-1244 |#1|) $) 96) (((-679 |#1|) (-1244 $)) 95)) (-4278 (((-1244 |#1|) $) 90) (($ (-1244 |#1|)) 89)) (-3295 (((-634 (-953 |#1|)) (-1244 $)) 77) (((-634 (-953 |#1|))) 92)) (-2353 (($ $ $) 24)) (-3433 (((-121)) 60)) (-2745 (((-850) $) 11)) (-3746 (((-1244 $)) 97)) (-1509 (((-634 (-1244 |#1|))) 42 (|has| |#1| (-558)))) (-3882 (($ $ $ $) 25)) (-4177 (((-121)) 58)) (-3823 (($ (-679 |#1|) $) 80)) (-3500 (($ $ $) 23)) (-2433 (((-121)) 59)) (-2189 (((-121)) 57)) (-4107 (((-121)) 53)) (-3056 (($) 17 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 29)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 26) (($ $ |#1|) 34) (($ |#1| $) 33))) 
+((-2797 (((-415 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-415 |#1| |#2| |#3| |#4|)) 33))) 
+(((-414 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -2797 ((-415 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-415 |#1| |#2| |#3| |#4|)))) (-301) (-993 |#1|) (-1219 |#2|) (-13 (-411 |#2| |#3|) (-1037 |#2|)) (-301) (-993 |#5|) (-1219 |#6|) (-13 (-411 |#6| |#7|) (-1037 |#6|))) (T -414)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *5)) (-5 *4 (-415 *5 *6 *7 *8)) (-4 *5 (-301)) (-4 *6 (-993 *5)) (-4 *7 (-1219 *6)) (-4 *8 (-13 (-411 *6 *7) (-1037 *6))) (-4 *9 (-301)) (-4 *10 (-993 *9)) (-4 *11 (-1219 *10)) (-5 *2 (-415 *9 *10 *11 *12)) (-5 *1 (-414 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *12 (-13 (-411 *10 *11) (-1037 *10)))))) 
+(-10 -7 (-15 -2797 ((-415 |#5| |#6| |#7| |#8|) (-1 |#5| |#1|) (-415 |#1| |#2| |#3| |#4|)))) 
+((-2449 (((-121) $ $) NIL)) (-4490 (($) NIL T CONST)) (-2902 (((-3 $ "failed") $) NIL)) (-3967 ((|#4| (-763) (-1244 |#4|)) 55)) (-1598 (((-121) $) NIL)) (-2319 (((-1244 |#4|) $) 17)) (-4417 ((|#2| $) 53)) (-4440 (($ $) 136)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) 98)) (-4314 (($ (-1244 |#4|)) 97)) (-4025 (((-1108) $) NIL)) (-2326 ((|#1| $) 18)) (-2387 (($ $ $) NIL)) (-3985 (($ $ $) NIL)) (-2747 (((-850) $) 131)) (-2588 (((-1244 |#4|) $) 126)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-1557 (($) 11 T CONST)) (-1719 (((-121) $ $) 39)) (-1781 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) 119)) (* (($ $ $) 118))) 
+(((-415 |#1| |#2| |#3| |#4|) (-13 (-478) (-10 -8 (-15 -4314 ($ (-1244 |#4|))) (-15 -2588 ((-1244 |#4|) $)) (-15 -4417 (|#2| $)) (-15 -2319 ((-1244 |#4|) $)) (-15 -2326 (|#1| $)) (-15 -4440 ($ $)) (-15 -3967 (|#4| (-763) (-1244 |#4|))))) (-301) (-993 |#1|) (-1219 |#2|) (-13 (-411 |#2| |#3|) (-1037 |#2|))) (T -415)) 
+((-4314 (*1 *1 *2) (-12 (-5 *2 (-1244 *6)) (-4 *6 (-13 (-411 *4 *5) (-1037 *4))) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-4 *3 (-301)) (-5 *1 (-415 *3 *4 *5 *6)))) (-2588 (*1 *2 *1) (-12 (-4 *3 (-301)) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-5 *2 (-1244 *6)) (-5 *1 (-415 *3 *4 *5 *6)) (-4 *6 (-13 (-411 *4 *5) (-1037 *4))))) (-4417 (*1 *2 *1) (-12 (-4 *4 (-1219 *2)) (-4 *2 (-993 *3)) (-5 *1 (-415 *3 *2 *4 *5)) (-4 *3 (-301)) (-4 *5 (-13 (-411 *2 *4) (-1037 *2))))) (-2319 (*1 *2 *1) (-12 (-4 *3 (-301)) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-5 *2 (-1244 *6)) (-5 *1 (-415 *3 *4 *5 *6)) (-4 *6 (-13 (-411 *4 *5) (-1037 *4))))) (-2326 (*1 *2 *1) (-12 (-4 *3 (-993 *2)) (-4 *4 (-1219 *3)) (-4 *2 (-301)) (-5 *1 (-415 *2 *3 *4 *5)) (-4 *5 (-13 (-411 *3 *4) (-1037 *3))))) (-4440 (*1 *1 *1) (-12 (-4 *2 (-301)) (-4 *3 (-993 *2)) (-4 *4 (-1219 *3)) (-5 *1 (-415 *2 *3 *4 *5)) (-4 *5 (-13 (-411 *3 *4) (-1037 *3))))) (-3967 (*1 *2 *3 *4) (-12 (-5 *3 (-763)) (-5 *4 (-1244 *2)) (-4 *5 (-301)) (-4 *6 (-993 *5)) (-4 *2 (-13 (-411 *6 *7) (-1037 *6))) (-5 *1 (-415 *5 *6 *7 *2)) (-4 *7 (-1219 *6))))) 
+(-13 (-478) (-10 -8 (-15 -4314 ($ (-1244 |#4|))) (-15 -2588 ((-1244 |#4|) $)) (-15 -4417 (|#2| $)) (-15 -2319 ((-1244 |#4|) $)) (-15 -2326 (|#1| $)) (-15 -4440 ($ $)) (-15 -3967 (|#4| (-763) (-1244 |#4|))))) 
+((-2449 (((-121) $ $) NIL)) (-4490 (($) NIL T CONST)) (-2902 (((-3 $ "failed") $) NIL)) (-1598 (((-121) $) NIL)) (-4417 ((|#2| $) 60)) (-3740 (($ (-1244 |#4|)) 25) (($ (-415 |#1| |#2| |#3| |#4|)) 75 (|has| |#4| (-1037 |#2|)))) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 34)) (-2588 (((-1244 |#4|) $) 26)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-1557 (($) 23 T CONST)) (-1719 (((-121) $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ $ $) 72))) 
+(((-416 |#1| |#2| |#3| |#4| |#5|) (-13 (-716) (-10 -8 (-15 -2588 ((-1244 |#4|) $)) (-15 -4417 (|#2| $)) (-15 -3740 ($ (-1244 |#4|))) (IF (|has| |#4| (-1037 |#2|)) (-15 -3740 ($ (-415 |#1| |#2| |#3| |#4|))) |noBranch|))) (-301) (-993 |#1|) (-1219 |#2|) (-411 |#2| |#3|) (-1244 |#4|)) (T -416)) 
+((-2588 (*1 *2 *1) (-12 (-4 *3 (-301)) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-5 *2 (-1244 *6)) (-5 *1 (-416 *3 *4 *5 *6 *7)) (-4 *6 (-411 *4 *5)) (-14 *7 *2))) (-4417 (*1 *2 *1) (-12 (-4 *4 (-1219 *2)) (-4 *2 (-993 *3)) (-5 *1 (-416 *3 *2 *4 *5 *6)) (-4 *3 (-301)) (-4 *5 (-411 *2 *4)) (-14 *6 (-1244 *5)))) (-3740 (*1 *1 *2) (-12 (-5 *2 (-1244 *6)) (-4 *6 (-411 *4 *5)) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-4 *3 (-301)) (-5 *1 (-416 *3 *4 *5 *6 *7)) (-14 *7 *2))) (-3740 (*1 *1 *2) (-12 (-5 *2 (-415 *3 *4 *5 *6)) (-4 *6 (-1037 *4)) (-4 *3 (-301)) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-4 *6 (-411 *4 *5)) (-14 *7 (-1244 *6)) (-5 *1 (-416 *3 *4 *5 *6 *7))))) 
+(-13 (-716) (-10 -8 (-15 -2588 ((-1244 |#4|) $)) (-15 -4417 (|#2| $)) (-15 -3740 ($ (-1244 |#4|))) (IF (|has| |#4| (-1037 |#2|)) (-15 -3740 ($ (-415 |#1| |#2| |#3| |#4|))) |noBranch|))) 
+((-2797 ((|#3| (-1 |#4| |#2|) |#1|) 26))) 
+(((-417 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2797 (|#3| (-1 |#4| |#2|) |#1|))) (-419 |#2|) (-172) (-419 |#4|) (-172)) (T -417)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-172)) (-4 *6 (-172)) (-4 *2 (-419 *6)) (-5 *1 (-417 *4 *5 *2 *6)) (-4 *4 (-419 *5))))) 
+(-10 -7 (-15 -2797 (|#3| (-1 |#4| |#2|) |#1|))) 
+((-3591 (((-3 $ "failed")) 85)) (-3542 (((-1244 (-679 |#2|)) (-1244 $)) NIL) (((-1244 (-679 |#2|))) 90)) (-3354 (((-3 (-2 (|:| |particular| $) (|:| -2588 (-634 $))) "failed")) 84)) (-2046 (((-3 $ "failed")) 83)) (-1524 (((-679 |#2|) (-1244 $)) NIL) (((-679 |#2|)) 101)) (-2235 (((-679 |#2|) $ (-1244 $)) NIL) (((-679 |#2|) $) 109)) (-1503 (((-1157 (-953 |#2|))) 54)) (-2886 ((|#2| (-1244 $)) NIL) ((|#2|) 105)) (-3899 (($ (-1244 |#2|) (-1244 $)) NIL) (($ (-1244 |#2|)) 112)) (-2587 (((-3 (-2 (|:| |particular| $) (|:| -2588 (-634 $))) "failed")) 82)) (-2061 (((-3 $ "failed")) 74)) (-4134 (((-679 |#2|) (-1244 $)) NIL) (((-679 |#2|)) 99)) (-3147 (((-679 |#2|) $ (-1244 $)) NIL) (((-679 |#2|) $) 107)) (-1730 (((-1157 (-953 |#2|))) 53)) (-2060 ((|#2| (-1244 $)) NIL) ((|#2|) 103)) (-1656 (((-1244 |#2|) $ (-1244 $)) NIL) (((-679 |#2|) (-1244 $) (-1244 $)) NIL) (((-1244 |#2|) $) NIL) (((-679 |#2|) (-1244 $)) 111)) (-4280 (((-1244 |#2|) $) 95) (($ (-1244 |#2|)) 97)) (-2155 (((-634 (-953 |#2|)) (-1244 $)) NIL) (((-634 (-953 |#2|))) 93)) (-3828 (($ (-679 |#2|) $) 89))) 
+(((-418 |#1| |#2|) (-10 -8 (-15 -3828 (|#1| (-679 |#2|) |#1|)) (-15 -1503 ((-1157 (-953 |#2|)))) (-15 -1730 ((-1157 (-953 |#2|)))) (-15 -2235 ((-679 |#2|) |#1|)) (-15 -3147 ((-679 |#2|) |#1|)) (-15 -1524 ((-679 |#2|))) (-15 -4134 ((-679 |#2|))) (-15 -2886 (|#2|)) (-15 -2060 (|#2|)) (-15 -4280 (|#1| (-1244 |#2|))) (-15 -4280 ((-1244 |#2|) |#1|)) (-15 -3899 (|#1| (-1244 |#2|))) (-15 -2155 ((-634 (-953 |#2|)))) (-15 -3542 ((-1244 (-679 |#2|)))) (-15 -1656 ((-679 |#2|) (-1244 |#1|))) (-15 -1656 ((-1244 |#2|) |#1|)) (-15 -3591 ((-3 |#1| "failed"))) (-15 -2046 ((-3 |#1| "failed"))) (-15 -2061 ((-3 |#1| "failed"))) (-15 -3354 ((-3 (-2 (|:| |particular| |#1|) (|:| -2588 (-634 |#1|))) "failed"))) (-15 -2587 ((-3 (-2 (|:| |particular| |#1|) (|:| -2588 (-634 |#1|))) "failed"))) (-15 -1524 ((-679 |#2|) (-1244 |#1|))) (-15 -4134 ((-679 |#2|) (-1244 |#1|))) (-15 -2886 (|#2| (-1244 |#1|))) (-15 -2060 (|#2| (-1244 |#1|))) (-15 -3899 (|#1| (-1244 |#2|) (-1244 |#1|))) (-15 -1656 ((-679 |#2|) (-1244 |#1|) (-1244 |#1|))) (-15 -1656 ((-1244 |#2|) |#1| (-1244 |#1|))) (-15 -2235 ((-679 |#2|) |#1| (-1244 |#1|))) (-15 -3147 ((-679 |#2|) |#1| (-1244 |#1|))) (-15 -3542 ((-1244 (-679 |#2|)) (-1244 |#1|))) (-15 -2155 ((-634 (-953 |#2|)) (-1244 |#1|)))) (-419 |#2|) (-172)) (T -418)) 
+((-3542 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-1244 (-679 *4))) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4)))) (-2155 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-634 (-953 *4))) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4)))) (-2060 (*1 *2) (-12 (-4 *2 (-172)) (-5 *1 (-418 *3 *2)) (-4 *3 (-419 *2)))) (-2886 (*1 *2) (-12 (-4 *2 (-172)) (-5 *1 (-418 *3 *2)) (-4 *3 (-419 *2)))) (-4134 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-679 *4)) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4)))) (-1524 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-679 *4)) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4)))) (-1730 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-1157 (-953 *4))) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4)))) (-1503 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-1157 (-953 *4))) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4))))) 
+(-10 -8 (-15 -3828 (|#1| (-679 |#2|) |#1|)) (-15 -1503 ((-1157 (-953 |#2|)))) (-15 -1730 ((-1157 (-953 |#2|)))) (-15 -2235 ((-679 |#2|) |#1|)) (-15 -3147 ((-679 |#2|) |#1|)) (-15 -1524 ((-679 |#2|))) (-15 -4134 ((-679 |#2|))) (-15 -2886 (|#2|)) (-15 -2060 (|#2|)) (-15 -4280 (|#1| (-1244 |#2|))) (-15 -4280 ((-1244 |#2|) |#1|)) (-15 -3899 (|#1| (-1244 |#2|))) (-15 -2155 ((-634 (-953 |#2|)))) (-15 -3542 ((-1244 (-679 |#2|)))) (-15 -1656 ((-679 |#2|) (-1244 |#1|))) (-15 -1656 ((-1244 |#2|) |#1|)) (-15 -3591 ((-3 |#1| "failed"))) (-15 -2046 ((-3 |#1| "failed"))) (-15 -2061 ((-3 |#1| "failed"))) (-15 -3354 ((-3 (-2 (|:| |particular| |#1|) (|:| -2588 (-634 |#1|))) "failed"))) (-15 -2587 ((-3 (-2 (|:| |particular| |#1|) (|:| -2588 (-634 |#1|))) "failed"))) (-15 -1524 ((-679 |#2|) (-1244 |#1|))) (-15 -4134 ((-679 |#2|) (-1244 |#1|))) (-15 -2886 (|#2| (-1244 |#1|))) (-15 -2060 (|#2| (-1244 |#1|))) (-15 -3899 (|#1| (-1244 |#2|) (-1244 |#1|))) (-15 -1656 ((-679 |#2|) (-1244 |#1|) (-1244 |#1|))) (-15 -1656 ((-1244 |#2|) |#1| (-1244 |#1|))) (-15 -2235 ((-679 |#2|) |#1| (-1244 |#1|))) (-15 -3147 ((-679 |#2|) |#1| (-1244 |#1|))) (-15 -3542 ((-1244 (-679 |#2|)) (-1244 |#1|))) (-15 -2155 ((-634 (-953 |#2|)) (-1244 |#1|)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-3591 (((-3 $ "failed")) 35 (|has| |#1| (-558)))) (-2689 (((-3 $ "failed") $ $) 18)) (-3542 (((-1244 (-679 |#1|)) (-1244 $)) 76) (((-1244 (-679 |#1|))) 93)) (-3818 (((-1244 $)) 79)) (-4490 (($) 16 T CONST)) (-3354 (((-3 (-2 (|:| |particular| $) (|:| -2588 (-634 $))) "failed")) 38 (|has| |#1| (-558)))) (-2046 (((-3 $ "failed")) 36 (|has| |#1| (-558)))) (-1524 (((-679 |#1|) (-1244 $)) 63) (((-679 |#1|)) 85)) (-2467 ((|#1| $) 72)) (-2235 (((-679 |#1|) $ (-1244 $)) 74) (((-679 |#1|) $) 83)) (-2812 (((-3 $ "failed") $) 43 (|has| |#1| (-558)))) (-1503 (((-1157 (-953 |#1|))) 81 (|has| |#1| (-365)))) (-2815 (($ $ (-917)) 27)) (-1509 ((|#1| $) 70)) (-3839 (((-1157 |#1|) $) 40 (|has| |#1| (-558)))) (-2886 ((|#1| (-1244 $)) 65) ((|#1|) 87)) (-3105 (((-1157 |#1|) $) 61)) (-1463 (((-121)) 55)) (-3899 (($ (-1244 |#1|) (-1244 $)) 67) (($ (-1244 |#1|)) 91)) (-2902 (((-3 $ "failed") $) 45 (|has| |#1| (-558)))) (-2371 (((-917)) 78)) (-3375 (((-121)) 52)) (-3402 (($ $ (-917)) 32)) (-4221 (((-121)) 48)) (-4463 (((-121)) 46)) (-3582 (((-121)) 50)) (-2587 (((-3 (-2 (|:| |particular| $) (|:| -2588 (-634 $))) "failed")) 39 (|has| |#1| (-558)))) (-2061 (((-3 $ "failed")) 37 (|has| |#1| (-558)))) (-4134 (((-679 |#1|) (-1244 $)) 64) (((-679 |#1|)) 86)) (-2786 ((|#1| $) 73)) (-3147 (((-679 |#1|) $ (-1244 $)) 75) (((-679 |#1|) $) 84)) (-1974 (((-3 $ "failed") $) 44 (|has| |#1| (-558)))) (-1730 (((-1157 (-953 |#1|))) 82 (|has| |#1| (-365)))) (-4202 (($ $ (-917)) 28)) (-4390 ((|#1| $) 71)) (-3364 (((-1157 |#1|) $) 41 (|has| |#1| (-558)))) (-2060 ((|#1| (-1244 $)) 66) ((|#1|) 88)) (-3114 (((-1157 |#1|) $) 62)) (-3487 (((-121)) 56)) (-1893 (((-1143) $) 9)) (-2153 (((-121)) 47)) (-2889 (((-121)) 49)) (-1852 (((-121)) 51)) (-4025 (((-1108) $) 10)) (-3636 (((-121)) 54)) (-2781 ((|#1| $ (-568)) 94)) (-1656 (((-1244 |#1|) $ (-1244 $)) 69) (((-679 |#1|) (-1244 $) (-1244 $)) 68) (((-1244 |#1|) $) 96) (((-679 |#1|) (-1244 $)) 95)) (-4280 (((-1244 |#1|) $) 90) (($ (-1244 |#1|)) 89)) (-2155 (((-634 (-953 |#1|)) (-1244 $)) 77) (((-634 (-953 |#1|))) 92)) (-3985 (($ $ $) 24)) (-3441 (((-121)) 60)) (-2747 (((-850) $) 11)) (-2588 (((-1244 $)) 97)) (-2657 (((-634 (-1244 |#1|))) 42 (|has| |#1| (-558)))) (-2007 (($ $ $ $) 25)) (-3964 (((-121)) 58)) (-3828 (($ (-679 |#1|) $) 80)) (-3911 (($ $ $) 23)) (-2435 (((-121)) 59)) (-2984 (((-121)) 57)) (-3579 (((-121)) 53)) (-3058 (($) 17 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 29)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 26) (($ $ |#1|) 34) (($ |#1| $) 33))) 
 (((-419 |#1|) (-1275) (-172)) (T -419)) 
-((-3746 (*1 *2) (-12 (-4 *3 (-172)) (-5 *2 (-1244 *1)) (-4 *1 (-419 *3)))) (-4073 (*1 *2 *1) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-1244 *3)))) (-4073 (*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-419 *4)) (-4 *4 (-172)) (-5 *2 (-679 *4)))) (-2779 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-419 *2)) (-4 *2 (-172)))) (-2776 (*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-1244 (-679 *3))))) (-3295 (*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-634 (-953 *3))))) (-3498 (*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-172)) (-4 *1 (-419 *3)))) (-4278 (*1 *2 *1) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-1244 *3)))) (-4278 (*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-172)) (-4 *1 (-419 *3)))) (-3898 (*1 *2) (-12 (-4 *1 (-419 *2)) (-4 *2 (-172)))) (-3569 (*1 *2) (-12 (-4 *1 (-419 *2)) (-4 *2 (-172)))) (-4210 (*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-679 *3)))) (-1631 (*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-679 *3)))) (-4333 (*1 *2 *1) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-679 *3)))) (-3042 (*1 *2 *1) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-679 *3)))) (-4454 (*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-4 *3 (-365)) (-5 *2 (-1157 (-953 *3))))) (-4408 (*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-4 *3 (-365)) (-5 *2 (-1157 (-953 *3))))) (-3823 (*1 *1 *2 *1) (-12 (-5 *2 (-679 *3)) (-4 *1 (-419 *3)) (-4 *3 (-172))))) 
-(-13 (-369 |t#1|) (-10 -8 (-15 -3746 ((-1244 $))) (-15 -4073 ((-1244 |t#1|) $)) (-15 -4073 ((-679 |t#1|) (-1244 $))) (-15 -2779 (|t#1| $ (-568))) (-15 -2776 ((-1244 (-679 |t#1|)))) (-15 -3295 ((-634 (-953 |t#1|)))) (-15 -3498 ($ (-1244 |t#1|))) (-15 -4278 ((-1244 |t#1|) $)) (-15 -4278 ($ (-1244 |t#1|))) (-15 -3898 (|t#1|)) (-15 -3569 (|t#1|)) (-15 -4210 ((-679 |t#1|))) (-15 -1631 ((-679 |t#1|))) (-15 -4333 ((-679 |t#1|) $)) (-15 -3042 ((-679 |t#1|) $)) (IF (|has| |t#1| (-365)) (PROGN (-15 -4454 ((-1157 (-953 |t#1|)))) (-15 -4408 ((-1157 (-953 |t#1|))))) |noBranch|) (-15 -3823 ($ (-679 |t#1|) $)))) 
+((-2588 (*1 *2) (-12 (-4 *3 (-172)) (-5 *2 (-1244 *1)) (-4 *1 (-419 *3)))) (-1656 (*1 *2 *1) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-1244 *3)))) (-1656 (*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-419 *4)) (-4 *4 (-172)) (-5 *2 (-679 *4)))) (-2781 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-419 *2)) (-4 *2 (-172)))) (-3542 (*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-1244 (-679 *3))))) (-2155 (*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-634 (-953 *3))))) (-3899 (*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-172)) (-4 *1 (-419 *3)))) (-4280 (*1 *2 *1) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-1244 *3)))) (-4280 (*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-172)) (-4 *1 (-419 *3)))) (-2060 (*1 *2) (-12 (-4 *1 (-419 *2)) (-4 *2 (-172)))) (-2886 (*1 *2) (-12 (-4 *1 (-419 *2)) (-4 *2 (-172)))) (-4134 (*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-679 *3)))) (-1524 (*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-679 *3)))) (-3147 (*1 *2 *1) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-679 *3)))) (-2235 (*1 *2 *1) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-679 *3)))) (-1730 (*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-4 *3 (-365)) (-5 *2 (-1157 (-953 *3))))) (-1503 (*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-4 *3 (-365)) (-5 *2 (-1157 (-953 *3))))) (-3828 (*1 *1 *2 *1) (-12 (-5 *2 (-679 *3)) (-4 *1 (-419 *3)) (-4 *3 (-172))))) 
+(-13 (-369 |t#1|) (-10 -8 (-15 -2588 ((-1244 $))) (-15 -1656 ((-1244 |t#1|) $)) (-15 -1656 ((-679 |t#1|) (-1244 $))) (-15 -2781 (|t#1| $ (-568))) (-15 -3542 ((-1244 (-679 |t#1|)))) (-15 -2155 ((-634 (-953 |t#1|)))) (-15 -3899 ($ (-1244 |t#1|))) (-15 -4280 ((-1244 |t#1|) $)) (-15 -4280 ($ (-1244 |t#1|))) (-15 -2060 (|t#1|)) (-15 -2886 (|t#1|)) (-15 -4134 ((-679 |t#1|))) (-15 -1524 ((-679 |t#1|))) (-15 -3147 ((-679 |t#1|) $)) (-15 -2235 ((-679 |t#1|) $)) (IF (|has| |t#1| (-365)) (PROGN (-15 -1730 ((-1157 (-953 |t#1|)))) (-15 -1503 ((-1157 (-953 |t#1|))))) |noBranch|) (-15 -3828 ($ (-679 |t#1|) $)))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 |#1| |#1|) . T) ((-137) . T) ((-608 (-850)) . T) ((-369 |#1|) . T) ((-637 |#1|) . T) ((-707 |#1|) . T) ((-710) . T) ((-736 |#1|) . T) ((-753) . T) ((-1053 |#1|) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 40)) (-3904 (($ $) 55)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 142)) (-2227 (($ $) NIL)) (-1573 (((-121) $) 34)) (-2295 ((|#1| $) 12)) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL (|has| |#1| (-1199)))) (-1678 (((-420 $) $) NIL (|has| |#1| (-1199)))) (-2825 (($ |#1| (-568)) 30)) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 112)) (-2854 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) 53)) (-2925 (((-3 $ "failed") $) 127)) (-1642 (((-3 (-409 (-568)) "failed") $) 61 (|has| |#1| (-550)))) (-2688 (((-121) $) 57 (|has| |#1| (-550)))) (-2425 (((-409 (-568)) $) 59 (|has| |#1| (-550)))) (-3779 (($ |#1| (-568)) 32)) (-3927 (((-121) $) 148 (|has| |#1| (-1199)))) (-2735 (((-121) $) 41)) (-3157 (((-763) $) 36)) (-2449 (((-3 "nil" "sqfr" "irred" "prime") $ (-568)) 133)) (-2882 ((|#1| $ (-568)) 132)) (-2660 (((-568) $ (-568)) 131)) (-1543 (($ |#1| (-568)) 29)) (-2795 (($ (-1 |#1| |#1|) $) 139)) (-2936 (($ |#1| (-634 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-568))))) 56)) (-2495 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-4487 (((-1143) $) NIL)) (-1824 (($ |#1| (-568)) 31)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-453)))) (-2721 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) 143 (|has| |#1| (-453)))) (-1925 (($ |#1| (-568) (-3 "nil" "sqfr" "irred" "prime")) 28)) (-3276 (((-634 (-2 (|:| -3848 |#1|) (|:| -3438 (-568)))) $) 52)) (-1385 (((-634 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-568)))) $) 11)) (-3848 (((-420 $) $) NIL (|has| |#1| (-1199)))) (-2595 (((-3 $ "failed") $ $) 134)) (-3438 (((-568) $) 128)) (-2789 ((|#1| $) 54)) (-1339 (($ $ (-634 |#1|) (-634 |#1|)) NIL (|has| |#1| (-303 |#1|))) (($ $ |#1| |#1|) NIL (|has| |#1| (-303 |#1|))) (($ $ (-288 |#1|)) NIL (|has| |#1| (-303 |#1|))) (($ $ (-634 (-288 |#1|))) 76 (|has| |#1| (-303 |#1|))) (($ $ (-634 (-1161)) (-634 |#1|)) 81 (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-1161) |#1|) NIL (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-1161) $) NIL (|has| |#1| (-523 (-1161) $))) (($ $ (-634 (-1161)) (-634 $)) 82 (|has| |#1| (-523 (-1161) $))) (($ $ (-634 (-288 $))) 78 (|has| |#1| (-303 $))) (($ $ (-288 $)) NIL (|has| |#1| (-303 $))) (($ $ $ $) NIL (|has| |#1| (-303 $))) (($ $ (-634 $) (-634 $)) NIL (|has| |#1| (-303 $)))) (-2779 (($ $ |#1|) 68 (|has| |#1| (-281 |#1| |#1|))) (($ $ $) 69 (|has| |#1| (-281 $ $)))) (-4189 (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) 138)) (-4278 (((-541) $) 26 (|has| |#1| (-609 (-541)))) (((-381) $) 88 (|has| |#1| (-1021))) (((-215) $) 91 (|has| |#1| (-1021)))) (-2745 (((-850) $) 110) (($ (-568)) 44) (($ $) NIL) (($ |#1|) 43) (($ (-409 (-568))) NIL (|has| |#1| (-1037 (-409 (-568)))))) (-4078 (((-763)) 46)) (-1826 (((-121) $ $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 38 T CONST)) (-1556 (($) 37 T CONST)) (-3190 (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1717 (((-121) $ $) 92)) (-1773 (($ $) 124) (($ $ $) NIL)) (-1767 (($ $ $) 136)) (** (($ $ (-917)) NIL) (($ $ (-763)) 98)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 48) (($ $ $) 47) (($ |#1| $) 49) (($ $ |#1|) NIL))) 
-(((-420 |#1|) (-13 (-558) (-223 |#1|) (-43 |#1|) (-336 |#1|) (-413 |#1|) (-10 -8 (-15 -2789 (|#1| $)) (-15 -3438 ((-568) $)) (-15 -2936 ($ |#1| (-634 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-568)))))) (-15 -1385 ((-634 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-568)))) $)) (-15 -1543 ($ |#1| (-568))) (-15 -3276 ((-634 (-2 (|:| -3848 |#1|) (|:| -3438 (-568)))) $)) (-15 -1824 ($ |#1| (-568))) (-15 -2660 ((-568) $ (-568))) (-15 -2882 (|#1| $ (-568))) (-15 -2449 ((-3 "nil" "sqfr" "irred" "prime") $ (-568))) (-15 -3157 ((-763) $)) (-15 -3779 ($ |#1| (-568))) (-15 -2825 ($ |#1| (-568))) (-15 -1925 ($ |#1| (-568) (-3 "nil" "sqfr" "irred" "prime"))) (-15 -2295 (|#1| $)) (-15 -3904 ($ $)) (-15 -2795 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-453)) (-6 (-453)) |noBranch|) (IF (|has| |#1| (-1021)) (-6 (-1021)) |noBranch|) (IF (|has| |#1| (-1199)) (-6 (-1199)) |noBranch|) (IF (|has| |#1| (-609 (-541))) (-6 (-609 (-541))) |noBranch|) (IF (|has| |#1| (-550)) (PROGN (-15 -2688 ((-121) $)) (-15 -2425 ((-409 (-568)) $)) (-15 -1642 ((-3 (-409 (-568)) "failed") $))) |noBranch|) (IF (|has| |#1| (-281 $ $)) (-6 (-281 $ $)) |noBranch|) (IF (|has| |#1| (-303 $)) (-6 (-303 $)) |noBranch|) (IF (|has| |#1| (-523 (-1161) $)) (-6 (-523 (-1161) $)) |noBranch|))) (-558)) (T -420)) 
-((-2795 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-558)) (-5 *1 (-420 *3)))) (-2789 (*1 *2 *1) (-12 (-5 *1 (-420 *2)) (-4 *2 (-558)))) (-3438 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-420 *3)) (-4 *3 (-558)))) (-2936 (*1 *1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *2) (|:| |xpnt| (-568))))) (-4 *2 (-558)) (-5 *1 (-420 *2)))) (-1385 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *3) (|:| |xpnt| (-568))))) (-5 *1 (-420 *3)) (-4 *3 (-558)))) (-1543 (*1 *1 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-420 *2)) (-4 *2 (-558)))) (-3276 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| -3848 *3) (|:| -3438 (-568))))) (-5 *1 (-420 *3)) (-4 *3 (-558)))) (-1824 (*1 *1 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-420 *2)) (-4 *2 (-558)))) (-2660 (*1 *2 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-420 *3)) (-4 *3 (-558)))) (-2882 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-420 *2)) (-4 *2 (-558)))) (-2449 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-3 "nil" "sqfr" "irred" "prime")) (-5 *1 (-420 *4)) (-4 *4 (-558)))) (-3157 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-420 *3)) (-4 *3 (-558)))) (-3779 (*1 *1 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-420 *2)) (-4 *2 (-558)))) (-2825 (*1 *1 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-420 *2)) (-4 *2 (-558)))) (-1925 (*1 *1 *2 *3 *4) (-12 (-5 *3 (-568)) (-5 *4 (-3 "nil" "sqfr" "irred" "prime")) (-5 *1 (-420 *2)) (-4 *2 (-558)))) (-2295 (*1 *2 *1) (-12 (-5 *1 (-420 *2)) (-4 *2 (-558)))) (-3904 (*1 *1 *1) (-12 (-5 *1 (-420 *2)) (-4 *2 (-558)))) (-2688 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-420 *3)) (-4 *3 (-550)) (-4 *3 (-558)))) (-2425 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-420 *3)) (-4 *3 (-550)) (-4 *3 (-558)))) (-1642 (*1 *2 *1) (|partial| -12 (-5 *2 (-409 (-568))) (-5 *1 (-420 *3)) (-4 *3 (-550)) (-4 *3 (-558))))) 
-(-13 (-558) (-223 |#1|) (-43 |#1|) (-336 |#1|) (-413 |#1|) (-10 -8 (-15 -2789 (|#1| $)) (-15 -3438 ((-568) $)) (-15 -2936 ($ |#1| (-634 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-568)))))) (-15 -1385 ((-634 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-568)))) $)) (-15 -1543 ($ |#1| (-568))) (-15 -3276 ((-634 (-2 (|:| -3848 |#1|) (|:| -3438 (-568)))) $)) (-15 -1824 ($ |#1| (-568))) (-15 -2660 ((-568) $ (-568))) (-15 -2882 (|#1| $ (-568))) (-15 -2449 ((-3 "nil" "sqfr" "irred" "prime") $ (-568))) (-15 -3157 ((-763) $)) (-15 -3779 ($ |#1| (-568))) (-15 -2825 ($ |#1| (-568))) (-15 -1925 ($ |#1| (-568) (-3 "nil" "sqfr" "irred" "prime"))) (-15 -2295 (|#1| $)) (-15 -3904 ($ $)) (-15 -2795 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-453)) (-6 (-453)) |noBranch|) (IF (|has| |#1| (-1021)) (-6 (-1021)) |noBranch|) (IF (|has| |#1| (-1199)) (-6 (-1199)) |noBranch|) (IF (|has| |#1| (-609 (-541))) (-6 (-609 (-541))) |noBranch|) (IF (|has| |#1| (-550)) (PROGN (-15 -2688 ((-121) $)) (-15 -2425 ((-409 (-568)) $)) (-15 -1642 ((-3 (-409 (-568)) "failed") $))) |noBranch|) (IF (|has| |#1| (-281 $ $)) (-6 (-281 $ $)) |noBranch|) (IF (|has| |#1| (-303 $)) (-6 (-303 $)) |noBranch|) (IF (|has| |#1| (-523 (-1161) $)) (-6 (-523 (-1161) $)) |noBranch|))) 
-((-4069 (((-420 |#1|) (-420 |#1|) (-1 (-420 |#1|) |#1|)) 20)) (-4088 (((-420 |#1|) (-420 |#1|) (-420 |#1|)) 15))) 
-(((-421 |#1|) (-10 -7 (-15 -4069 ((-420 |#1|) (-420 |#1|) (-1 (-420 |#1|) |#1|))) (-15 -4088 ((-420 |#1|) (-420 |#1|) (-420 |#1|)))) (-558)) (T -421)) 
-((-4088 (*1 *2 *2 *2) (-12 (-5 *2 (-420 *3)) (-4 *3 (-558)) (-5 *1 (-421 *3)))) (-4069 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-420 *4) *4)) (-4 *4 (-558)) (-5 *2 (-420 *4)) (-5 *1 (-421 *4))))) 
-(-10 -7 (-15 -4069 ((-420 |#1|) (-420 |#1|) (-1 (-420 |#1|) |#1|))) (-15 -4088 ((-420 |#1|) (-420 |#1|) (-420 |#1|)))) 
-((-3262 ((|#2| |#2|) 160)) (-2487 (((-3 (|:| |%expansion| (-307 |#1| |#2| |#3| |#4|)) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143))))) |#2| (-121)) 55))) 
-(((-422 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2487 ((-3 (|:| |%expansion| (-307 |#1| |#2| |#3| |#4|)) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143))))) |#2| (-121))) (-15 -3262 (|#2| |#2|))) (-13 (-453) (-842) (-1037 (-568)) (-630 (-568))) (-13 (-27) (-1181) (-432 |#1|)) (-1161) |#2|) (T -422)) 
-((-3262 (*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-422 *3 *2 *4 *5)) (-4 *2 (-13 (-27) (-1181) (-432 *3))) (-14 *4 (-1161)) (-14 *5 *2))) (-2487 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |%expansion| (-307 *5 *3 *6 *7)) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143)))))) (-5 *1 (-422 *5 *3 *6 *7)) (-4 *3 (-13 (-27) (-1181) (-432 *5))) (-14 *6 (-1161)) (-14 *7 *3)))) 
-(-10 -7 (-15 -2487 ((-3 (|:| |%expansion| (-307 |#1| |#2| |#3| |#4|)) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143))))) |#2| (-121))) (-15 -3262 (|#2| |#2|))) 
-((-2795 ((|#4| (-1 |#3| |#1|) |#2|) 11))) 
-(((-423 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2795 (|#4| (-1 |#3| |#1|) |#2|))) (-13 (-1047) (-842)) (-432 |#1|) (-13 (-1047) (-842)) (-432 |#3|)) (T -423)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-13 (-1047) (-842))) (-4 *6 (-13 (-1047) (-842))) (-4 *2 (-432 *6)) (-5 *1 (-423 *5 *4 *6 *2)) (-4 *4 (-432 *5))))) 
-(-10 -7 (-15 -2795 (|#4| (-1 |#3| |#1|) |#2|))) 
-((-3262 ((|#2| |#2|) 87)) (-3998 (((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143))))) |#2| (-121) (-1143)) 46)) (-2757 (((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143))))) |#2| (-121) (-1143)) 152))) 
-(((-424 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -3998 ((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143))))) |#2| (-121) (-1143))) (-15 -2757 ((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143))))) |#2| (-121) (-1143))) (-15 -3262 (|#2| |#2|))) (-13 (-453) (-842) (-1037 (-568)) (-630 (-568))) (-13 (-27) (-1181) (-432 |#1|) (-10 -8 (-15 -2745 ($ |#3|)))) (-840) (-13 (-1221 |#2| |#3|) (-365) (-1181) (-10 -8 (-15 -4189 ($ $)) (-15 -3837 ($ $)))) (-984 |#4|) (-1161)) (T -424)) 
-((-3262 (*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-4 *2 (-13 (-27) (-1181) (-432 *3) (-10 -8 (-15 -2745 ($ *4))))) (-4 *4 (-840)) (-4 *5 (-13 (-1221 *2 *4) (-365) (-1181) (-10 -8 (-15 -4189 ($ $)) (-15 -3837 ($ $))))) (-5 *1 (-424 *3 *2 *4 *5 *6 *7)) (-4 *6 (-984 *5)) (-14 *7 (-1161)))) (-2757 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-121)) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-4 *3 (-13 (-27) (-1181) (-432 *6) (-10 -8 (-15 -2745 ($ *7))))) (-4 *7 (-840)) (-4 *8 (-13 (-1221 *3 *7) (-365) (-1181) (-10 -8 (-15 -4189 ($ $)) (-15 -3837 ($ $))))) (-5 *2 (-3 (|:| |%series| *8) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143)))))) (-5 *1 (-424 *6 *3 *7 *8 *9 *10)) (-5 *5 (-1143)) (-4 *9 (-984 *8)) (-14 *10 (-1161)))) (-3998 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-121)) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-4 *3 (-13 (-27) (-1181) (-432 *6) (-10 -8 (-15 -2745 ($ *7))))) (-4 *7 (-840)) (-4 *8 (-13 (-1221 *3 *7) (-365) (-1181) (-10 -8 (-15 -4189 ($ $)) (-15 -3837 ($ $))))) (-5 *2 (-3 (|:| |%series| *8) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143)))))) (-5 *1 (-424 *6 *3 *7 *8 *9 *10)) (-5 *5 (-1143)) (-4 *9 (-984 *8)) (-14 *10 (-1161))))) 
-(-10 -7 (-15 -3998 ((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143))))) |#2| (-121) (-1143))) (-15 -2757 ((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143))))) |#2| (-121) (-1143))) (-15 -3262 (|#2| |#2|))) 
-((-2512 ((|#4| (-1 |#3| |#1| |#3|) |#2| |#3|) 22)) (-3092 ((|#3| (-1 |#3| |#1| |#3|) |#2| |#3|) 20)) (-2795 ((|#4| (-1 |#3| |#1|) |#2|) 17))) 
-(((-425 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2795 (|#4| (-1 |#3| |#1|) |#2|)) (-15 -3092 (|#3| (-1 |#3| |#1| |#3|) |#2| |#3|)) (-15 -2512 (|#4| (-1 |#3| |#1| |#3|) |#2| |#3|))) (-1090) (-427 |#1|) (-1090) (-427 |#3|)) (T -425)) 
-((-2512 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-4 *6 (-1090)) (-4 *5 (-1090)) (-4 *2 (-427 *5)) (-5 *1 (-425 *6 *4 *5 *2)) (-4 *4 (-427 *6)))) (-3092 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1090)) (-4 *2 (-1090)) (-5 *1 (-425 *5 *4 *2 *6)) (-4 *4 (-427 *5)) (-4 *6 (-427 *2)))) (-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-427 *6)) (-5 *1 (-425 *5 *4 *6 *2)) (-4 *4 (-427 *5))))) 
-(-10 -7 (-15 -2795 (|#4| (-1 |#3| |#1|) |#2|)) (-15 -3092 (|#3| (-1 |#3| |#1| |#3|) |#2| |#3|)) (-15 -2512 (|#4| (-1 |#3| |#1| |#3|) |#2| |#3|))) 
-((-3415 (($) 44)) (-1791 (($ |#2| $) NIL) (($ $ |#2|) NIL) (($ $ $) 40)) (-1536 (($ $ $) 39)) (-2032 (((-121) $ $) 28)) (-3983 (((-763)) 47)) (-2749 (($ (-634 |#2|)) 20) (($) NIL)) (-1731 (($) 53)) (-2521 ((|#2| $) 61)) (-3268 ((|#2| $) 59)) (-3683 (((-917) $) 55)) (-3212 (($ $ $) 35)) (-4355 (($ (-917)) 50)) (-4382 (($ $ |#2|) NIL) (($ $ $) 38)) (-4168 (((-763) (-1 (-121) |#2|) $) NIL) (((-763) |#2| $) 26)) (-4287 (($ (-634 |#2|)) 24)) (-2160 (($ $) 46)) (-2745 (((-850) $) 33)) (-2432 (((-763) $) 21)) (-3844 (($ (-634 |#2|)) 19) (($) NIL)) (-1717 (((-121) $ $) 16)) (-1732 (((-121) $ $) 13))) 
-(((-426 |#1| |#2|) (-10 -8 (-15 -3983 ((-763))) (-15 -4355 (|#1| (-917))) (-15 -3683 ((-917) |#1|)) (-15 -1731 (|#1|)) (-15 -2521 (|#2| |#1|)) (-15 -3268 (|#2| |#1|)) (-15 -3415 (|#1|)) (-15 -2160 (|#1| |#1|)) (-15 -2432 ((-763) |#1|)) (-15 -1717 ((-121) |#1| |#1|)) (-15 -2745 ((-850) |#1|)) (-15 -1732 ((-121) |#1| |#1|)) (-15 -3844 (|#1|)) (-15 -3844 (|#1| (-634 |#2|))) (-15 -2749 (|#1|)) (-15 -2749 (|#1| (-634 |#2|))) (-15 -3212 (|#1| |#1| |#1|)) (-15 -4382 (|#1| |#1| |#1|)) (-15 -4382 (|#1| |#1| |#2|)) (-15 -1536 (|#1| |#1| |#1|)) (-15 -2032 ((-121) |#1| |#1|)) (-15 -1791 (|#1| |#1| |#1|)) (-15 -1791 (|#1| |#1| |#2|)) (-15 -1791 (|#1| |#2| |#1|)) (-15 -4287 (|#1| (-634 |#2|))) (-15 -4168 ((-763) |#2| |#1|)) (-15 -4168 ((-763) (-1 (-121) |#2|) |#1|))) (-427 |#2|) (-1090)) (T -426)) 
-((-3983 (*1 *2) (-12 (-4 *4 (-1090)) (-5 *2 (-763)) (-5 *1 (-426 *3 *4)) (-4 *3 (-427 *4))))) 
-(-10 -8 (-15 -3983 ((-763))) (-15 -4355 (|#1| (-917))) (-15 -3683 ((-917) |#1|)) (-15 -1731 (|#1|)) (-15 -2521 (|#2| |#1|)) (-15 -3268 (|#2| |#1|)) (-15 -3415 (|#1|)) (-15 -2160 (|#1| |#1|)) (-15 -2432 ((-763) |#1|)) (-15 -1717 ((-121) |#1| |#1|)) (-15 -2745 ((-850) |#1|)) (-15 -1732 ((-121) |#1| |#1|)) (-15 -3844 (|#1|)) (-15 -3844 (|#1| (-634 |#2|))) (-15 -2749 (|#1|)) (-15 -2749 (|#1| (-634 |#2|))) (-15 -3212 (|#1| |#1| |#1|)) (-15 -4382 (|#1| |#1| |#1|)) (-15 -4382 (|#1| |#1| |#2|)) (-15 -1536 (|#1| |#1| |#1|)) (-15 -2032 ((-121) |#1| |#1|)) (-15 -1791 (|#1| |#1| |#1|)) (-15 -1791 (|#1| |#1| |#2|)) (-15 -1791 (|#1| |#2| |#1|)) (-15 -4287 (|#1| (-634 |#2|))) (-15 -4168 ((-763) |#2| |#1|)) (-15 -4168 ((-763) (-1 (-121) |#2|) |#1|))) 
-((-2447 (((-121) $ $) 18)) (-3415 (($) 63 (|has| |#1| (-370)))) (-1791 (($ |#1| $) 78) (($ $ |#1|) 77) (($ $ $) 76)) (-1536 (($ $ $) 74)) (-2032 (((-121) $ $) 75)) (-2510 (((-121) $ (-763)) 8)) (-3983 (((-763)) 57 (|has| |#1| (-370)))) (-2749 (($ (-634 |#1|)) 70) (($) 69)) (-3507 (($ (-1 (-121) |#1|) $) 42 (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) |#1|) $) 52 (|has| $ (-6 -4519)))) (-2671 (($) 7 T CONST)) (-3924 (($ $) 55 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3405 (($ |#1| $) 44 (|has| $ (-6 -4519))) (($ (-1 (-121) |#1|) $) 43 (|has| $ (-6 -4519)))) (-4328 (($ |#1| $) 54 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) |#1|) $) 51 (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4519)))) (-1731 (($) 60 (|has| |#1| (-370)))) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) 9)) (-2521 ((|#1| $) 61 (|has| |#1| (-842)))) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3268 ((|#1| $) 62 (|has| |#1| (-842)))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35)) (-3683 (((-917) $) 59 (|has| |#1| (-370)))) (-2166 (((-121) $ (-763)) 10)) (-4487 (((-1143) $) 22)) (-3212 (($ $ $) 71)) (-1890 ((|#1| $) 36)) (-4450 (($ |#1| $) 37)) (-4355 (($ (-917)) 58 (|has| |#1| (-370)))) (-4022 (((-1108) $) 21)) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 48)) (-1315 ((|#1| $) 38)) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-4382 (($ $ |#1|) 73) (($ $ $) 72)) (-2085 (($) 46) (($ (-634 |#1|)) 45)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-4278 (((-541) $) 56 (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) 47)) (-2160 (($ $) 64 (|has| |#1| (-370)))) (-2745 (((-850) $) 20)) (-2432 (((-763) $) 65)) (-3844 (($ (-634 |#1|)) 68) (($) 67)) (-2367 (($ (-634 |#1|)) 39)) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19)) (-1732 (((-121) $ $) 66)) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 40)) (-2087 (($ $) 55)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 142)) (-3661 (($ $) NIL)) (-4426 (((-121) $) 34)) (-3591 ((|#1| $) 12)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL (|has| |#1| (-1199)))) (-3498 (((-420 $) $) NIL (|has| |#1| (-1199)))) (-3811 (($ |#1| (-568)) 30)) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 112)) (-2857 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) 53)) (-2902 (((-3 $ "failed") $) 127)) (-3254 (((-3 (-409 (-568)) "failed") $) 61 (|has| |#1| (-550)))) (-1338 (((-121) $) 57 (|has| |#1| (-550)))) (-2394 (((-409 (-568)) $) 59 (|has| |#1| (-550)))) (-2724 (($ |#1| (-568)) 32)) (-2197 (((-121) $) 148 (|has| |#1| (-1199)))) (-1598 (((-121) $) 41)) (-2764 (((-763) $) 36)) (-2515 (((-3 "nil" "sqfr" "irred" "prime") $ (-568)) 133)) (-4167 ((|#1| $ (-568)) 132)) (-4433 (((-568) $ (-568)) 131)) (-4258 (($ |#1| (-568)) 29)) (-2797 (($ (-1 |#1| |#1|) $) 139)) (-2932 (($ |#1| (-634 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-568))))) 56)) (-2498 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-1893 (((-1143) $) NIL)) (-2262 (($ |#1| (-568)) 31)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-453)))) (-2723 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) 143 (|has| |#1| (-453)))) (-4159 (($ |#1| (-568) (-3 "nil" "sqfr" "irred" "prime")) 28)) (-2075 (((-634 (-2 (|:| -3850 |#1|) (|:| -3483 (-568)))) $) 52)) (-3935 (((-634 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-568)))) $) 11)) (-3850 (((-420 $) $) NIL (|has| |#1| (-1199)))) (-2597 (((-3 $ "failed") $ $) 134)) (-3483 (((-568) $) 128)) (-2791 ((|#1| $) 54)) (-1339 (($ $ (-634 |#1|) (-634 |#1|)) NIL (|has| |#1| (-303 |#1|))) (($ $ |#1| |#1|) NIL (|has| |#1| (-303 |#1|))) (($ $ (-288 |#1|)) NIL (|has| |#1| (-303 |#1|))) (($ $ (-634 (-288 |#1|))) 76 (|has| |#1| (-303 |#1|))) (($ $ (-634 (-1161)) (-634 |#1|)) 81 (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-1161) |#1|) NIL (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-1161) $) NIL (|has| |#1| (-523 (-1161) $))) (($ $ (-634 (-1161)) (-634 $)) 82 (|has| |#1| (-523 (-1161) $))) (($ $ (-634 (-288 $))) 78 (|has| |#1| (-303 $))) (($ $ (-288 $)) NIL (|has| |#1| (-303 $))) (($ $ $ $) NIL (|has| |#1| (-303 $))) (($ $ (-634 $) (-634 $)) NIL (|has| |#1| (-303 $)))) (-2781 (($ $ |#1|) 68 (|has| |#1| (-281 |#1| |#1|))) (($ $ $) 69 (|has| |#1| (-281 $ $)))) (-4191 (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) 138)) (-4280 (((-541) $) 26 (|has| |#1| (-609 (-541)))) (((-381) $) 88 (|has| |#1| (-1021))) (((-215) $) 91 (|has| |#1| (-1021)))) (-2747 (((-850) $) 110) (($ (-568)) 44) (($ $) NIL) (($ |#1|) 43) (($ (-409 (-568))) NIL (|has| |#1| (-1037 (-409 (-568)))))) (-3425 (((-763)) 46)) (-2273 (((-121) $ $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 38 T CONST)) (-1557 (($) 37 T CONST)) (-3192 (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1719 (((-121) $ $) 92)) (-1775 (($ $) 124) (($ $ $) NIL)) (-1769 (($ $ $) 136)) (** (($ $ (-917)) NIL) (($ $ (-763)) 98)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 48) (($ $ $) 47) (($ |#1| $) 49) (($ $ |#1|) NIL))) 
+(((-420 |#1|) (-13 (-558) (-223 |#1|) (-43 |#1|) (-336 |#1|) (-413 |#1|) (-10 -8 (-15 -2791 (|#1| $)) (-15 -3483 ((-568) $)) (-15 -2932 ($ |#1| (-634 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-568)))))) (-15 -3935 ((-634 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-568)))) $)) (-15 -4258 ($ |#1| (-568))) (-15 -2075 ((-634 (-2 (|:| -3850 |#1|) (|:| -3483 (-568)))) $)) (-15 -2262 ($ |#1| (-568))) (-15 -4433 ((-568) $ (-568))) (-15 -4167 (|#1| $ (-568))) (-15 -2515 ((-3 "nil" "sqfr" "irred" "prime") $ (-568))) (-15 -2764 ((-763) $)) (-15 -2724 ($ |#1| (-568))) (-15 -3811 ($ |#1| (-568))) (-15 -4159 ($ |#1| (-568) (-3 "nil" "sqfr" "irred" "prime"))) (-15 -3591 (|#1| $)) (-15 -2087 ($ $)) (-15 -2797 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-453)) (-6 (-453)) |noBranch|) (IF (|has| |#1| (-1021)) (-6 (-1021)) |noBranch|) (IF (|has| |#1| (-1199)) (-6 (-1199)) |noBranch|) (IF (|has| |#1| (-609 (-541))) (-6 (-609 (-541))) |noBranch|) (IF (|has| |#1| (-550)) (PROGN (-15 -1338 ((-121) $)) (-15 -2394 ((-409 (-568)) $)) (-15 -3254 ((-3 (-409 (-568)) "failed") $))) |noBranch|) (IF (|has| |#1| (-281 $ $)) (-6 (-281 $ $)) |noBranch|) (IF (|has| |#1| (-303 $)) (-6 (-303 $)) |noBranch|) (IF (|has| |#1| (-523 (-1161) $)) (-6 (-523 (-1161) $)) |noBranch|))) (-558)) (T -420)) 
+((-2797 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-558)) (-5 *1 (-420 *3)))) (-2791 (*1 *2 *1) (-12 (-5 *1 (-420 *2)) (-4 *2 (-558)))) (-3483 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-420 *3)) (-4 *3 (-558)))) (-2932 (*1 *1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *2) (|:| |xpnt| (-568))))) (-4 *2 (-558)) (-5 *1 (-420 *2)))) (-3935 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *3) (|:| |xpnt| (-568))))) (-5 *1 (-420 *3)) (-4 *3 (-558)))) (-4258 (*1 *1 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-420 *2)) (-4 *2 (-558)))) (-2075 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| -3850 *3) (|:| -3483 (-568))))) (-5 *1 (-420 *3)) (-4 *3 (-558)))) (-2262 (*1 *1 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-420 *2)) (-4 *2 (-558)))) (-4433 (*1 *2 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-420 *3)) (-4 *3 (-558)))) (-4167 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-420 *2)) (-4 *2 (-558)))) (-2515 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-3 "nil" "sqfr" "irred" "prime")) (-5 *1 (-420 *4)) (-4 *4 (-558)))) (-2764 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-420 *3)) (-4 *3 (-558)))) (-2724 (*1 *1 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-420 *2)) (-4 *2 (-558)))) (-3811 (*1 *1 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-420 *2)) (-4 *2 (-558)))) (-4159 (*1 *1 *2 *3 *4) (-12 (-5 *3 (-568)) (-5 *4 (-3 "nil" "sqfr" "irred" "prime")) (-5 *1 (-420 *2)) (-4 *2 (-558)))) (-3591 (*1 *2 *1) (-12 (-5 *1 (-420 *2)) (-4 *2 (-558)))) (-2087 (*1 *1 *1) (-12 (-5 *1 (-420 *2)) (-4 *2 (-558)))) (-1338 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-420 *3)) (-4 *3 (-550)) (-4 *3 (-558)))) (-2394 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-420 *3)) (-4 *3 (-550)) (-4 *3 (-558)))) (-3254 (*1 *2 *1) (|partial| -12 (-5 *2 (-409 (-568))) (-5 *1 (-420 *3)) (-4 *3 (-550)) (-4 *3 (-558))))) 
+(-13 (-558) (-223 |#1|) (-43 |#1|) (-336 |#1|) (-413 |#1|) (-10 -8 (-15 -2791 (|#1| $)) (-15 -3483 ((-568) $)) (-15 -2932 ($ |#1| (-634 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-568)))))) (-15 -3935 ((-634 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#1|) (|:| |xpnt| (-568)))) $)) (-15 -4258 ($ |#1| (-568))) (-15 -2075 ((-634 (-2 (|:| -3850 |#1|) (|:| -3483 (-568)))) $)) (-15 -2262 ($ |#1| (-568))) (-15 -4433 ((-568) $ (-568))) (-15 -4167 (|#1| $ (-568))) (-15 -2515 ((-3 "nil" "sqfr" "irred" "prime") $ (-568))) (-15 -2764 ((-763) $)) (-15 -2724 ($ |#1| (-568))) (-15 -3811 ($ |#1| (-568))) (-15 -4159 ($ |#1| (-568) (-3 "nil" "sqfr" "irred" "prime"))) (-15 -3591 (|#1| $)) (-15 -2087 ($ $)) (-15 -2797 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-453)) (-6 (-453)) |noBranch|) (IF (|has| |#1| (-1021)) (-6 (-1021)) |noBranch|) (IF (|has| |#1| (-1199)) (-6 (-1199)) |noBranch|) (IF (|has| |#1| (-609 (-541))) (-6 (-609 (-541))) |noBranch|) (IF (|has| |#1| (-550)) (PROGN (-15 -1338 ((-121) $)) (-15 -2394 ((-409 (-568)) $)) (-15 -3254 ((-3 (-409 (-568)) "failed") $))) |noBranch|) (IF (|has| |#1| (-281 $ $)) (-6 (-281 $ $)) |noBranch|) (IF (|has| |#1| (-303 $)) (-6 (-303 $)) |noBranch|) (IF (|has| |#1| (-523 (-1161) $)) (-6 (-523 (-1161) $)) |noBranch|))) 
+((-1642 (((-420 |#1|) (-420 |#1|) (-1 (-420 |#1|) |#1|)) 20)) (-3484 (((-420 |#1|) (-420 |#1|) (-420 |#1|)) 15))) 
+(((-421 |#1|) (-10 -7 (-15 -1642 ((-420 |#1|) (-420 |#1|) (-1 (-420 |#1|) |#1|))) (-15 -3484 ((-420 |#1|) (-420 |#1|) (-420 |#1|)))) (-558)) (T -421)) 
+((-3484 (*1 *2 *2 *2) (-12 (-5 *2 (-420 *3)) (-4 *3 (-558)) (-5 *1 (-421 *3)))) (-1642 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-420 *4) *4)) (-4 *4 (-558)) (-5 *2 (-420 *4)) (-5 *1 (-421 *4))))) 
+(-10 -7 (-15 -1642 ((-420 |#1|) (-420 |#1|) (-1 (-420 |#1|) |#1|))) (-15 -3484 ((-420 |#1|) (-420 |#1|) (-420 |#1|)))) 
+((-2030 ((|#2| |#2|) 160)) (-2706 (((-3 (|:| |%expansion| (-307 |#1| |#2| |#3| |#4|)) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143))))) |#2| (-121)) 55))) 
+(((-422 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2706 ((-3 (|:| |%expansion| (-307 |#1| |#2| |#3| |#4|)) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143))))) |#2| (-121))) (-15 -2030 (|#2| |#2|))) (-13 (-453) (-842) (-1037 (-568)) (-630 (-568))) (-13 (-27) (-1181) (-432 |#1|)) (-1161) |#2|) (T -422)) 
+((-2030 (*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-422 *3 *2 *4 *5)) (-4 *2 (-13 (-27) (-1181) (-432 *3))) (-14 *4 (-1161)) (-14 *5 *2))) (-2706 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |%expansion| (-307 *5 *3 *6 *7)) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143)))))) (-5 *1 (-422 *5 *3 *6 *7)) (-4 *3 (-13 (-27) (-1181) (-432 *5))) (-14 *6 (-1161)) (-14 *7 *3)))) 
+(-10 -7 (-15 -2706 ((-3 (|:| |%expansion| (-307 |#1| |#2| |#3| |#4|)) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143))))) |#2| (-121))) (-15 -2030 (|#2| |#2|))) 
+((-2797 ((|#4| (-1 |#3| |#1|) |#2|) 11))) 
+(((-423 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2797 (|#4| (-1 |#3| |#1|) |#2|))) (-13 (-1047) (-842)) (-432 |#1|) (-13 (-1047) (-842)) (-432 |#3|)) (T -423)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-13 (-1047) (-842))) (-4 *6 (-13 (-1047) (-842))) (-4 *2 (-432 *6)) (-5 *1 (-423 *5 *4 *6 *2)) (-4 *4 (-432 *5))))) 
+(-10 -7 (-15 -2797 (|#4| (-1 |#3| |#1|) |#2|))) 
+((-2030 ((|#2| |#2|) 87)) (-1323 (((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143))))) |#2| (-121) (-1143)) 46)) (-3418 (((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143))))) |#2| (-121) (-1143)) 152))) 
+(((-424 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -1323 ((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143))))) |#2| (-121) (-1143))) (-15 -3418 ((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143))))) |#2| (-121) (-1143))) (-15 -2030 (|#2| |#2|))) (-13 (-453) (-842) (-1037 (-568)) (-630 (-568))) (-13 (-27) (-1181) (-432 |#1|) (-10 -8 (-15 -2747 ($ |#3|)))) (-840) (-13 (-1221 |#2| |#3|) (-365) (-1181) (-10 -8 (-15 -4191 ($ $)) (-15 -1845 ($ $)))) (-984 |#4|) (-1161)) (T -424)) 
+((-2030 (*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-4 *2 (-13 (-27) (-1181) (-432 *3) (-10 -8 (-15 -2747 ($ *4))))) (-4 *4 (-840)) (-4 *5 (-13 (-1221 *2 *4) (-365) (-1181) (-10 -8 (-15 -4191 ($ $)) (-15 -1845 ($ $))))) (-5 *1 (-424 *3 *2 *4 *5 *6 *7)) (-4 *6 (-984 *5)) (-14 *7 (-1161)))) (-3418 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-121)) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-4 *3 (-13 (-27) (-1181) (-432 *6) (-10 -8 (-15 -2747 ($ *7))))) (-4 *7 (-840)) (-4 *8 (-13 (-1221 *3 *7) (-365) (-1181) (-10 -8 (-15 -4191 ($ $)) (-15 -1845 ($ $))))) (-5 *2 (-3 (|:| |%series| *8) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143)))))) (-5 *1 (-424 *6 *3 *7 *8 *9 *10)) (-5 *5 (-1143)) (-4 *9 (-984 *8)) (-14 *10 (-1161)))) (-1323 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-121)) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-4 *3 (-13 (-27) (-1181) (-432 *6) (-10 -8 (-15 -2747 ($ *7))))) (-4 *7 (-840)) (-4 *8 (-13 (-1221 *3 *7) (-365) (-1181) (-10 -8 (-15 -4191 ($ $)) (-15 -1845 ($ $))))) (-5 *2 (-3 (|:| |%series| *8) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143)))))) (-5 *1 (-424 *6 *3 *7 *8 *9 *10)) (-5 *5 (-1143)) (-4 *9 (-984 *8)) (-14 *10 (-1161))))) 
+(-10 -7 (-15 -1323 ((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143))))) |#2| (-121) (-1143))) (-15 -3418 ((-3 (|:| |%series| |#4|) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143))))) |#2| (-121) (-1143))) (-15 -2030 (|#2| |#2|))) 
+((-1678 ((|#4| (-1 |#3| |#1| |#3|) |#2| |#3|) 22)) (-3094 ((|#3| (-1 |#3| |#1| |#3|) |#2| |#3|) 20)) (-2797 ((|#4| (-1 |#3| |#1|) |#2|) 17))) 
+(((-425 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2797 (|#4| (-1 |#3| |#1|) |#2|)) (-15 -3094 (|#3| (-1 |#3| |#1| |#3|) |#2| |#3|)) (-15 -1678 (|#4| (-1 |#3| |#1| |#3|) |#2| |#3|))) (-1090) (-427 |#1|) (-1090) (-427 |#3|)) (T -425)) 
+((-1678 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-4 *6 (-1090)) (-4 *5 (-1090)) (-4 *2 (-427 *5)) (-5 *1 (-425 *6 *4 *5 *2)) (-4 *4 (-427 *6)))) (-3094 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1090)) (-4 *2 (-1090)) (-5 *1 (-425 *5 *4 *2 *6)) (-4 *4 (-427 *5)) (-4 *6 (-427 *2)))) (-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-427 *6)) (-5 *1 (-425 *5 *4 *6 *2)) (-4 *4 (-427 *5))))) 
+(-10 -7 (-15 -2797 (|#4| (-1 |#3| |#1|) |#2|)) (-15 -3094 (|#3| (-1 |#3| |#1| |#3|) |#2| |#3|)) (-15 -1678 (|#4| (-1 |#3| |#1| |#3|) |#2| |#3|))) 
+((-1611 (($) 44)) (-1793 (($ |#2| $) NIL) (($ $ |#2|) NIL) (($ $ $) 40)) (-4217 (($ $ $) 39)) (-1430 (((-121) $ $) 28)) (-3986 (((-763)) 47)) (-2751 (($ (-634 |#2|)) 20) (($) NIL)) (-1733 (($) 53)) (-1732 ((|#2| $) 61)) (-2047 ((|#2| $) 59)) (-2291 (((-917) $) 55)) (-1864 (($ $ $) 35)) (-4357 (($ (-917)) 50)) (-1363 (($ $ |#2|) NIL) (($ $ $) 38)) (-4170 (((-763) (-1 (-121) |#2|) $) NIL) (((-763) |#2| $) 26)) (-4289 (($ (-634 |#2|)) 24)) (-3695 (($ $) 46)) (-2747 (((-850) $) 33)) (-2429 (((-763) $) 21)) (-3846 (($ (-634 |#2|)) 19) (($) NIL)) (-1719 (((-121) $ $) 16)) (-1734 (((-121) $ $) 13))) 
+(((-426 |#1| |#2|) (-10 -8 (-15 -3986 ((-763))) (-15 -4357 (|#1| (-917))) (-15 -2291 ((-917) |#1|)) (-15 -1733 (|#1|)) (-15 -1732 (|#2| |#1|)) (-15 -2047 (|#2| |#1|)) (-15 -1611 (|#1|)) (-15 -3695 (|#1| |#1|)) (-15 -2429 ((-763) |#1|)) (-15 -1719 ((-121) |#1| |#1|)) (-15 -2747 ((-850) |#1|)) (-15 -1734 ((-121) |#1| |#1|)) (-15 -3846 (|#1|)) (-15 -3846 (|#1| (-634 |#2|))) (-15 -2751 (|#1|)) (-15 -2751 (|#1| (-634 |#2|))) (-15 -1864 (|#1| |#1| |#1|)) (-15 -1363 (|#1| |#1| |#1|)) (-15 -1363 (|#1| |#1| |#2|)) (-15 -4217 (|#1| |#1| |#1|)) (-15 -1430 ((-121) |#1| |#1|)) (-15 -1793 (|#1| |#1| |#1|)) (-15 -1793 (|#1| |#1| |#2|)) (-15 -1793 (|#1| |#2| |#1|)) (-15 -4289 (|#1| (-634 |#2|))) (-15 -4170 ((-763) |#2| |#1|)) (-15 -4170 ((-763) (-1 (-121) |#2|) |#1|))) (-427 |#2|) (-1090)) (T -426)) 
+((-3986 (*1 *2) (-12 (-4 *4 (-1090)) (-5 *2 (-763)) (-5 *1 (-426 *3 *4)) (-4 *3 (-427 *4))))) 
+(-10 -8 (-15 -3986 ((-763))) (-15 -4357 (|#1| (-917))) (-15 -2291 ((-917) |#1|)) (-15 -1733 (|#1|)) (-15 -1732 (|#2| |#1|)) (-15 -2047 (|#2| |#1|)) (-15 -1611 (|#1|)) (-15 -3695 (|#1| |#1|)) (-15 -2429 ((-763) |#1|)) (-15 -1719 ((-121) |#1| |#1|)) (-15 -2747 ((-850) |#1|)) (-15 -1734 ((-121) |#1| |#1|)) (-15 -3846 (|#1|)) (-15 -3846 (|#1| (-634 |#2|))) (-15 -2751 (|#1|)) (-15 -2751 (|#1| (-634 |#2|))) (-15 -1864 (|#1| |#1| |#1|)) (-15 -1363 (|#1| |#1| |#1|)) (-15 -1363 (|#1| |#1| |#2|)) (-15 -4217 (|#1| |#1| |#1|)) (-15 -1430 ((-121) |#1| |#1|)) (-15 -1793 (|#1| |#1| |#1|)) (-15 -1793 (|#1| |#1| |#2|)) (-15 -1793 (|#1| |#2| |#1|)) (-15 -4289 (|#1| (-634 |#2|))) (-15 -4170 ((-763) |#2| |#1|)) (-15 -4170 ((-763) (-1 (-121) |#2|) |#1|))) 
+((-2449 (((-121) $ $) 18)) (-1611 (($) 63 (|has| |#1| (-370)))) (-1793 (($ |#1| $) 78) (($ $ |#1|) 77) (($ $ $) 76)) (-4217 (($ $ $) 74)) (-1430 (((-121) $ $) 75)) (-1667 (((-121) $ (-763)) 8)) (-3986 (((-763)) 57 (|has| |#1| (-370)))) (-2751 (($ (-634 |#1|)) 70) (($) 69)) (-3963 (($ (-1 (-121) |#1|) $) 42 (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) |#1|) $) 52 (|has| $ (-6 -4521)))) (-4490 (($) 7 T CONST)) (-3926 (($ $) 55 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-1568 (($ |#1| $) 44 (|has| $ (-6 -4521))) (($ (-1 (-121) |#1|) $) 43 (|has| $ (-6 -4521)))) (-4330 (($ |#1| $) 54 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) |#1|) $) 51 (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4521)))) (-1733 (($) 60 (|has| |#1| (-370)))) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) 9)) (-1732 ((|#1| $) 61 (|has| |#1| (-842)))) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-2047 ((|#1| $) 62 (|has| |#1| (-842)))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35)) (-2291 (((-917) $) 59 (|has| |#1| (-370)))) (-3796 (((-121) $ (-763)) 10)) (-1893 (((-1143) $) 22)) (-1864 (($ $ $) 71)) (-2580 ((|#1| $) 36)) (-1708 (($ |#1| $) 37)) (-4357 (($ (-917)) 58 (|has| |#1| (-370)))) (-4025 (((-1108) $) 21)) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 48)) (-3403 ((|#1| $) 38)) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-1363 (($ $ |#1|) 73) (($ $ $) 72)) (-3132 (($) 46) (($ (-634 |#1|)) 45)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-4280 (((-541) $) 56 (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) 47)) (-3695 (($ $) 64 (|has| |#1| (-370)))) (-2747 (((-850) $) 20)) (-2429 (((-763) $) 65)) (-3846 (($ (-634 |#1|)) 68) (($) 67)) (-4074 (($ (-634 |#1|)) 39)) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19)) (-1734 (((-121) $ $) 66)) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-427 |#1|) (-1275) (-1090)) (T -427)) 
-((-2432 (*1 *2 *1) (-12 (-4 *1 (-427 *3)) (-4 *3 (-1090)) (-5 *2 (-763)))) (-2160 (*1 *1 *1) (-12 (-4 *1 (-427 *2)) (-4 *2 (-1090)) (-4 *2 (-370)))) (-3415 (*1 *1) (-12 (-4 *1 (-427 *2)) (-4 *2 (-370)) (-4 *2 (-1090)))) (-3268 (*1 *2 *1) (-12 (-4 *1 (-427 *2)) (-4 *2 (-1090)) (-4 *2 (-842)))) (-2521 (*1 *2 *1) (-12 (-4 *1 (-427 *2)) (-4 *2 (-1090)) (-4 *2 (-842))))) 
-(-13 (-221 |t#1|) (-1087 |t#1|) (-10 -8 (-6 -4519) (-15 -2432 ((-763) $)) (IF (|has| |t#1| (-370)) (PROGN (-6 (-370)) (-15 -2160 ($ $)) (-15 -3415 ($))) |noBranch|) (IF (|has| |t#1| (-842)) (PROGN (-15 -3268 (|t#1| $)) (-15 -2521 (|t#1| $))) |noBranch|))) 
+((-2429 (*1 *2 *1) (-12 (-4 *1 (-427 *3)) (-4 *3 (-1090)) (-5 *2 (-763)))) (-3695 (*1 *1 *1) (-12 (-4 *1 (-427 *2)) (-4 *2 (-1090)) (-4 *2 (-370)))) (-1611 (*1 *1) (-12 (-4 *1 (-427 *2)) (-4 *2 (-370)) (-4 *2 (-1090)))) (-2047 (*1 *2 *1) (-12 (-4 *1 (-427 *2)) (-4 *2 (-1090)) (-4 *2 (-842)))) (-1732 (*1 *2 *1) (-12 (-4 *1 (-427 *2)) (-4 *2 (-1090)) (-4 *2 (-842))))) 
+(-13 (-221 |t#1|) (-1087 |t#1|) (-10 -8 (-6 -4521) (-15 -2429 ((-763) $)) (IF (|has| |t#1| (-370)) (PROGN (-6 (-370)) (-15 -3695 ($ $)) (-15 -1611 ($))) |noBranch|) (IF (|has| |t#1| (-842)) (PROGN (-15 -2047 (|t#1| $)) (-15 -1732 (|t#1| $))) |noBranch|))) 
 (((-39) . T) ((-111 |#1|) . T) ((-105) . T) ((-608 (-850)) . T) ((-154 |#1|) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-221 |#1|) . T) ((-227 |#1|) . T) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-370) |has| |#1| (-370)) ((-499 |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-1087 |#1|) . T) ((-1090) . T) ((-1195) . T)) 
-((-1323 (((-585 |#2|) |#2| (-1161)) 35)) (-2005 (((-585 |#2|) |#2| (-1161)) 19)) (-2890 ((|#2| |#2| (-1161)) 24))) 
-(((-428 |#1| |#2|) (-10 -7 (-15 -2005 ((-585 |#2|) |#2| (-1161))) (-15 -1323 ((-585 |#2|) |#2| (-1161))) (-15 -2890 (|#2| |#2| (-1161)))) (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568))) (-13 (-1181) (-29 |#1|))) (T -428)) 
-((-2890 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-428 *4 *2)) (-4 *2 (-13 (-1181) (-29 *4))))) (-1323 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-428 *5 *3)) (-4 *3 (-13 (-1181) (-29 *5))))) (-2005 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-428 *5 *3)) (-4 *3 (-13 (-1181) (-29 *5)))))) 
-(-10 -7 (-15 -2005 ((-585 |#2|) |#2| (-1161))) (-15 -1323 ((-585 |#2|) |#2| (-1161))) (-15 -2890 (|#2| |#2| (-1161)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-2925 (((-3 $ "failed") $) NIL)) (-2735 (((-121) $) NIL)) (-4224 (($ |#2| |#1|) 35)) (-2128 (($ |#2| |#1|) 33)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL) (($ (-329 |#2|)) 25)) (-4078 (((-763)) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 10 T CONST)) (-1556 (($) 16 T CONST)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) 34)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 36) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
-(((-429 |#1| |#2|) (-13 (-43 |#1|) (-10 -8 (IF (|has| |#2| (-6 -4506)) (IF (|has| |#1| (-6 -4506)) (-6 -4506) |noBranch|) |noBranch|) (-15 -2745 ($ |#1|)) (-15 -2745 ($ (-329 |#2|))) (-15 -4224 ($ |#2| |#1|)) (-15 -2128 ($ |#2| |#1|)))) (-13 (-172) (-43 (-409 (-568)))) (-13 (-842) (-21))) (T -429)) 
-((-2745 (*1 *1 *2) (-12 (-5 *1 (-429 *2 *3)) (-4 *2 (-13 (-172) (-43 (-409 (-568))))) (-4 *3 (-13 (-842) (-21))))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-329 *4)) (-4 *4 (-13 (-842) (-21))) (-5 *1 (-429 *3 *4)) (-4 *3 (-13 (-172) (-43 (-409 (-568))))))) (-4224 (*1 *1 *2 *3) (-12 (-5 *1 (-429 *3 *2)) (-4 *3 (-13 (-172) (-43 (-409 (-568))))) (-4 *2 (-13 (-842) (-21))))) (-2128 (*1 *1 *2 *3) (-12 (-5 *1 (-429 *3 *2)) (-4 *3 (-13 (-172) (-43 (-409 (-568))))) (-4 *2 (-13 (-842) (-21)))))) 
-(-13 (-43 |#1|) (-10 -8 (IF (|has| |#2| (-6 -4506)) (IF (|has| |#1| (-6 -4506)) (-6 -4506) |noBranch|) |noBranch|) (-15 -2745 ($ |#1|)) (-15 -2745 ($ (-329 |#2|))) (-15 -4224 ($ |#2| |#1|)) (-15 -2128 ($ |#2| |#1|)))) 
-((-3837 (((-3 |#2| (-634 |#2|)) |#2| (-1161)) 104))) 
-(((-430 |#1| |#2|) (-10 -7 (-15 -3837 ((-3 |#2| (-634 |#2|)) |#2| (-1161)))) (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568))) (-13 (-1181) (-959) (-29 |#1|))) (T -430)) 
-((-3837 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 *3 (-634 *3))) (-5 *1 (-430 *5 *3)) (-4 *3 (-13 (-1181) (-959) (-29 *5)))))) 
-(-10 -7 (-15 -3837 ((-3 |#2| (-634 |#2|)) |#2| (-1161)))) 
-((-2055 (((-634 (-1161)) $) 72)) (-3839 (((-409 (-1157 $)) $ (-607 $)) 268)) (-2366 (($ $ (-288 $)) NIL) (($ $ (-634 (-288 $))) NIL) (($ $ (-634 (-607 $)) (-634 $)) 233)) (-3666 (((-3 (-607 $) "failed") $) NIL) (((-3 (-1161) "failed") $) 75) (((-3 (-568) "failed") $) NIL) (((-3 |#2| "failed") $) 229) (((-3 (-409 (-953 |#2|)) "failed") $) 319) (((-3 (-953 |#2|) "failed") $) 231) (((-3 (-409 (-568)) "failed") $) NIL)) (-2854 (((-607 $) $) NIL) (((-1161) $) 30) (((-568) $) NIL) ((|#2| $) 227) (((-409 (-953 |#2|)) $) 300) (((-953 |#2|) $) 228) (((-409 (-568)) $) NIL)) (-3488 (((-123) (-123)) 47)) (-1332 (($ $) 87)) (-3693 (((-3 (-607 $) "failed") $) 224)) (-3804 (((-634 (-607 $)) $) 225)) (-3324 (((-3 (-634 $) "failed") $) 243)) (-2672 (((-3 (-2 (|:| |val| $) (|:| -3438 (-568))) "failed") $) 250)) (-1794 (((-3 (-634 $) "failed") $) 241)) (-2392 (((-3 (-2 (|:| -2348 (-568)) (|:| |var| (-607 $))) "failed") $) 259)) (-3751 (((-3 (-2 (|:| |var| (-607 $)) (|:| -3438 (-568))) "failed") $) 247) (((-3 (-2 (|:| |var| (-607 $)) (|:| -3438 (-568))) "failed") $ (-123)) 214) (((-3 (-2 (|:| |var| (-607 $)) (|:| -3438 (-568))) "failed") $ (-1161)) 216)) (-2086 (((-121) $) 19)) (-2091 ((|#2| $) 21)) (-1339 (($ $ (-607 $) $) NIL) (($ $ (-634 (-607 $)) (-634 $)) 232) (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ $))) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ (-634 $)))) 96) (($ $ (-1161) (-1 $ (-634 $))) NIL) (($ $ (-1161) (-1 $ $)) NIL) (($ $ (-634 (-123)) (-634 (-1 $ $))) NIL) (($ $ (-634 (-123)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-123) (-1 $ (-634 $))) NIL) (($ $ (-123) (-1 $ $)) NIL) (($ $ (-1161)) 57) (($ $ (-634 (-1161))) 236) (($ $) 237) (($ $ (-123) $ (-1161)) 60) (($ $ (-634 (-123)) (-634 $) (-1161)) 67) (($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ $))) 107) (($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ (-634 $)))) 238) (($ $ (-1161) (-763) (-1 $ (-634 $))) 94) (($ $ (-1161) (-763) (-1 $ $)) 93)) (-2779 (($ (-123) $) NIL) (($ (-123) $ $) NIL) (($ (-123) $ $ $) NIL) (($ (-123) $ $ $ $) NIL) (($ (-123) (-634 $)) 106)) (-4189 (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) 234)) (-3013 (($ $) 279)) (-4278 (((-887 (-568)) $) 253) (((-887 (-381)) $) 256) (($ (-420 $)) 315) (((-541) $) NIL)) (-2745 (((-850) $) 235) (($ (-607 $)) 84) (($ (-1161)) 26) (($ |#2|) NIL) (($ (-1113 |#2| (-607 $))) NIL) (($ (-409 |#2|)) 284) (($ (-953 (-409 |#2|))) 324) (($ (-409 (-953 (-409 |#2|)))) 296) (($ (-409 (-953 |#2|))) 290) (($ $) NIL) (($ (-953 |#2|)) 183) (($ (-409 (-568))) 329) (($ (-568)) NIL)) (-4078 (((-763)) 79)) (-2887 (((-121) (-123)) 41)) (-3058 (($ (-1161) $) 33) (($ (-1161) $ $) 34) (($ (-1161) $ $ $) 35) (($ (-1161) $ $ $ $) 36) (($ (-1161) (-634 $)) 39)) (* (($ (-409 (-568)) $) NIL) (($ $ (-409 (-568))) NIL) (($ |#2| $) 261) (($ $ |#2|) NIL) (($ $ $) NIL) (($ (-568) $) NIL) (($ (-763) $) NIL) (($ (-917) $) NIL))) 
-(((-431 |#1| |#2|) (-10 -8 (-15 * (|#1| (-917) |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 -4078 ((-763))) (-15 -2745 (|#1| (-568))) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -4278 ((-541) |#1|)) (-15 -2854 ((-953 |#2|) |#1|)) (-15 -3666 ((-3 (-953 |#2|) "failed") |#1|)) (-15 -2745 (|#1| (-953 |#2|))) (-15 -4189 (|#1| |#1| (-1161))) (-15 -4189 (|#1| |#1| (-634 (-1161)))) (-15 -4189 (|#1| |#1| (-1161) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 -2745 (|#1| |#1|)) (-15 * (|#1| |#1| (-409 (-568)))) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 -2854 ((-409 (-953 |#2|)) |#1|)) (-15 -3666 ((-3 (-409 (-953 |#2|)) "failed") |#1|)) (-15 -2745 (|#1| (-409 (-953 |#2|)))) (-15 -3839 ((-409 (-1157 |#1|)) |#1| (-607 |#1|))) (-15 -2745 (|#1| (-409 (-953 (-409 |#2|))))) (-15 -2745 (|#1| (-953 (-409 |#2|)))) (-15 -2745 (|#1| (-409 |#2|))) (-15 -3013 (|#1| |#1|)) (-15 -4278 (|#1| (-420 |#1|))) (-15 -1339 (|#1| |#1| (-1161) (-763) (-1 |#1| |#1|))) (-15 -1339 (|#1| |#1| (-1161) (-763) (-1 |#1| (-634 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-763)) (-634 (-1 |#1| (-634 |#1|))))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-763)) (-634 (-1 |#1| |#1|)))) (-15 -2672 ((-3 (-2 (|:| |val| |#1|) (|:| -3438 (-568))) "failed") |#1|)) (-15 -3751 ((-3 (-2 (|:| |var| (-607 |#1|)) (|:| -3438 (-568))) "failed") |#1| (-1161))) (-15 -3751 ((-3 (-2 (|:| |var| (-607 |#1|)) (|:| -3438 (-568))) "failed") |#1| (-123))) (-15 -1332 (|#1| |#1|)) (-15 -2745 (|#1| (-1113 |#2| (-607 |#1|)))) (-15 -2392 ((-3 (-2 (|:| -2348 (-568)) (|:| |var| (-607 |#1|))) "failed") |#1|)) (-15 -1794 ((-3 (-634 |#1|) "failed") |#1|)) (-15 -3751 ((-3 (-2 (|:| |var| (-607 |#1|)) (|:| -3438 (-568))) "failed") |#1|)) (-15 -3324 ((-3 (-634 |#1|) "failed") |#1|)) (-15 -1339 (|#1| |#1| (-634 (-123)) (-634 |#1|) (-1161))) (-15 -1339 (|#1| |#1| (-123) |#1| (-1161))) (-15 -1339 (|#1| |#1|)) (-15 -1339 (|#1| |#1| (-634 (-1161)))) (-15 -1339 (|#1| |#1| (-1161))) (-15 -3058 (|#1| (-1161) (-634 |#1|))) (-15 -3058 (|#1| (-1161) |#1| |#1| |#1| |#1|)) (-15 -3058 (|#1| (-1161) |#1| |#1| |#1|)) (-15 -3058 (|#1| (-1161) |#1| |#1|)) (-15 -3058 (|#1| (-1161) |#1|)) (-15 -2055 ((-634 (-1161)) |#1|)) (-15 -2091 (|#2| |#1|)) (-15 -2086 ((-121) |#1|)) (-15 -2854 (|#2| |#1|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -2745 (|#1| |#2|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2854 ((-568) |#1|)) (-15 -4278 ((-887 (-381)) |#1|)) (-15 -4278 ((-887 (-568)) |#1|)) (-15 -2854 ((-1161) |#1|)) (-15 -3666 ((-3 (-1161) "failed") |#1|)) (-15 -2745 (|#1| (-1161))) (-15 -1339 (|#1| |#1| (-123) (-1 |#1| |#1|))) (-15 -1339 (|#1| |#1| (-123) (-1 |#1| (-634 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-123)) (-634 (-1 |#1| (-634 |#1|))))) (-15 -1339 (|#1| |#1| (-634 (-123)) (-634 (-1 |#1| |#1|)))) (-15 -1339 (|#1| |#1| (-1161) (-1 |#1| |#1|))) (-15 -1339 (|#1| |#1| (-1161) (-1 |#1| (-634 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-1 |#1| (-634 |#1|))))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-1 |#1| |#1|)))) (-15 -2887 ((-121) (-123))) (-15 -3488 ((-123) (-123))) (-15 -3804 ((-634 (-607 |#1|)) |#1|)) (-15 -3693 ((-3 (-607 |#1|) "failed") |#1|)) (-15 -2366 (|#1| |#1| (-634 (-607 |#1|)) (-634 |#1|))) (-15 -2366 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -2366 (|#1| |#1| (-288 |#1|))) (-15 -2779 (|#1| (-123) (-634 |#1|))) (-15 -2779 (|#1| (-123) |#1| |#1| |#1| |#1|)) (-15 -2779 (|#1| (-123) |#1| |#1| |#1|)) (-15 -2779 (|#1| (-123) |#1| |#1|)) (-15 -2779 (|#1| (-123) |#1|)) (-15 -1339 (|#1| |#1| (-634 |#1|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#1| |#1|)) (-15 -1339 (|#1| |#1| (-288 |#1|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-607 |#1|)) (-634 |#1|))) (-15 -1339 (|#1| |#1| (-607 |#1|) |#1|)) (-15 -2854 ((-607 |#1|) |#1|)) (-15 -3666 ((-3 (-607 |#1|) "failed") |#1|)) (-15 -2745 (|#1| (-607 |#1|))) (-15 -2745 ((-850) |#1|))) (-432 |#2|) (-842)) (T -431)) 
-((-3488 (*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *4 (-842)) (-5 *1 (-431 *3 *4)) (-4 *3 (-432 *4)))) (-2887 (*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-431 *4 *5)) (-4 *4 (-432 *5)))) (-4078 (*1 *2) (-12 (-4 *4 (-842)) (-5 *2 (-763)) (-5 *1 (-431 *3 *4)) (-4 *3 (-432 *4))))) 
-(-10 -8 (-15 * (|#1| (-917) |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 -4078 ((-763))) (-15 -2745 (|#1| (-568))) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -4278 ((-541) |#1|)) (-15 -2854 ((-953 |#2|) |#1|)) (-15 -3666 ((-3 (-953 |#2|) "failed") |#1|)) (-15 -2745 (|#1| (-953 |#2|))) (-15 -4189 (|#1| |#1| (-1161))) (-15 -4189 (|#1| |#1| (-634 (-1161)))) (-15 -4189 (|#1| |#1| (-1161) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 -2745 (|#1| |#1|)) (-15 * (|#1| |#1| (-409 (-568)))) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 -2854 ((-409 (-953 |#2|)) |#1|)) (-15 -3666 ((-3 (-409 (-953 |#2|)) "failed") |#1|)) (-15 -2745 (|#1| (-409 (-953 |#2|)))) (-15 -3839 ((-409 (-1157 |#1|)) |#1| (-607 |#1|))) (-15 -2745 (|#1| (-409 (-953 (-409 |#2|))))) (-15 -2745 (|#1| (-953 (-409 |#2|)))) (-15 -2745 (|#1| (-409 |#2|))) (-15 -3013 (|#1| |#1|)) (-15 -4278 (|#1| (-420 |#1|))) (-15 -1339 (|#1| |#1| (-1161) (-763) (-1 |#1| |#1|))) (-15 -1339 (|#1| |#1| (-1161) (-763) (-1 |#1| (-634 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-763)) (-634 (-1 |#1| (-634 |#1|))))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-763)) (-634 (-1 |#1| |#1|)))) (-15 -2672 ((-3 (-2 (|:| |val| |#1|) (|:| -3438 (-568))) "failed") |#1|)) (-15 -3751 ((-3 (-2 (|:| |var| (-607 |#1|)) (|:| -3438 (-568))) "failed") |#1| (-1161))) (-15 -3751 ((-3 (-2 (|:| |var| (-607 |#1|)) (|:| -3438 (-568))) "failed") |#1| (-123))) (-15 -1332 (|#1| |#1|)) (-15 -2745 (|#1| (-1113 |#2| (-607 |#1|)))) (-15 -2392 ((-3 (-2 (|:| -2348 (-568)) (|:| |var| (-607 |#1|))) "failed") |#1|)) (-15 -1794 ((-3 (-634 |#1|) "failed") |#1|)) (-15 -3751 ((-3 (-2 (|:| |var| (-607 |#1|)) (|:| -3438 (-568))) "failed") |#1|)) (-15 -3324 ((-3 (-634 |#1|) "failed") |#1|)) (-15 -1339 (|#1| |#1| (-634 (-123)) (-634 |#1|) (-1161))) (-15 -1339 (|#1| |#1| (-123) |#1| (-1161))) (-15 -1339 (|#1| |#1|)) (-15 -1339 (|#1| |#1| (-634 (-1161)))) (-15 -1339 (|#1| |#1| (-1161))) (-15 -3058 (|#1| (-1161) (-634 |#1|))) (-15 -3058 (|#1| (-1161) |#1| |#1| |#1| |#1|)) (-15 -3058 (|#1| (-1161) |#1| |#1| |#1|)) (-15 -3058 (|#1| (-1161) |#1| |#1|)) (-15 -3058 (|#1| (-1161) |#1|)) (-15 -2055 ((-634 (-1161)) |#1|)) (-15 -2091 (|#2| |#1|)) (-15 -2086 ((-121) |#1|)) (-15 -2854 (|#2| |#1|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -2745 (|#1| |#2|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2854 ((-568) |#1|)) (-15 -4278 ((-887 (-381)) |#1|)) (-15 -4278 ((-887 (-568)) |#1|)) (-15 -2854 ((-1161) |#1|)) (-15 -3666 ((-3 (-1161) "failed") |#1|)) (-15 -2745 (|#1| (-1161))) (-15 -1339 (|#1| |#1| (-123) (-1 |#1| |#1|))) (-15 -1339 (|#1| |#1| (-123) (-1 |#1| (-634 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-123)) (-634 (-1 |#1| (-634 |#1|))))) (-15 -1339 (|#1| |#1| (-634 (-123)) (-634 (-1 |#1| |#1|)))) (-15 -1339 (|#1| |#1| (-1161) (-1 |#1| |#1|))) (-15 -1339 (|#1| |#1| (-1161) (-1 |#1| (-634 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-1 |#1| (-634 |#1|))))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-1 |#1| |#1|)))) (-15 -2887 ((-121) (-123))) (-15 -3488 ((-123) (-123))) (-15 -3804 ((-634 (-607 |#1|)) |#1|)) (-15 -3693 ((-3 (-607 |#1|) "failed") |#1|)) (-15 -2366 (|#1| |#1| (-634 (-607 |#1|)) (-634 |#1|))) (-15 -2366 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -2366 (|#1| |#1| (-288 |#1|))) (-15 -2779 (|#1| (-123) (-634 |#1|))) (-15 -2779 (|#1| (-123) |#1| |#1| |#1| |#1|)) (-15 -2779 (|#1| (-123) |#1| |#1| |#1|)) (-15 -2779 (|#1| (-123) |#1| |#1|)) (-15 -2779 (|#1| (-123) |#1|)) (-15 -1339 (|#1| |#1| (-634 |#1|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#1| |#1|)) (-15 -1339 (|#1| |#1| (-288 |#1|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-607 |#1|)) (-634 |#1|))) (-15 -1339 (|#1| |#1| (-607 |#1|) |#1|)) (-15 -2854 ((-607 |#1|) |#1|)) (-15 -3666 ((-3 (-607 |#1|) "failed") |#1|)) (-15 -2745 (|#1| (-607 |#1|))) (-15 -2745 ((-850) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 108 (|has| |#1| (-25)))) (-2055 (((-634 (-1161)) $) 195)) (-3839 (((-409 (-1157 $)) $ (-607 $)) 163 (|has| |#1| (-558)))) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 135 (|has| |#1| (-558)))) (-2227 (($ $) 136 (|has| |#1| (-558)))) (-1573 (((-121) $) 138 (|has| |#1| (-558)))) (-3001 (((-634 (-607 $)) $) 43)) (-3134 (((-3 $ "failed") $ $) 110 (|has| |#1| (-21)))) (-2366 (($ $ (-288 $)) 55) (($ $ (-634 (-288 $))) 54) (($ $ (-634 (-607 $)) (-634 $)) 53)) (-4305 (($ $) 155 (|has| |#1| (-558)))) (-1678 (((-420 $) $) 156 (|has| |#1| (-558)))) (-1497 (((-121) $ $) 146 (|has| |#1| (-558)))) (-2671 (($) 94 (-2198 (|has| |#1| (-1102)) (|has| |#1| (-25))) CONST)) (-3666 (((-3 (-607 $) "failed") $) 68) (((-3 (-1161) "failed") $) 208) (((-3 (-568) "failed") $) 201 (|has| |#1| (-1037 (-568)))) (((-3 |#1| "failed") $) 199) (((-3 (-409 (-953 |#1|)) "failed") $) 161 (|has| |#1| (-558))) (((-3 (-953 |#1|) "failed") $) 115 (|has| |#1| (-1047))) (((-3 (-409 (-568)) "failed") $) 87 (-2198 (-12 (|has| |#1| (-1037 (-568))) (|has| |#1| (-558))) (|has| |#1| (-1037 (-409 (-568))))))) (-2854 (((-607 $) $) 67) (((-1161) $) 207) (((-568) $) 202 (|has| |#1| (-1037 (-568)))) ((|#1| $) 198) (((-409 (-953 |#1|)) $) 160 (|has| |#1| (-558))) (((-953 |#1|) $) 114 (|has| |#1| (-1047))) (((-409 (-568)) $) 86 (-2198 (-12 (|has| |#1| (-1037 (-568))) (|has| |#1| (-558))) (|has| |#1| (-1037 (-409 (-568))))))) (-2401 (($ $ $) 150 (|has| |#1| (-558)))) (-3164 (((-679 (-568)) (-679 $)) 129 (-2139 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 128 (-2139 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 127 (|has| |#1| (-1047))) (((-679 |#1|) (-679 $)) 126 (|has| |#1| (-1047)))) (-2925 (((-3 $ "failed") $) 97 (|has| |#1| (-1102)))) (-2412 (($ $ $) 149 (|has| |#1| (-558)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 144 (|has| |#1| (-558)))) (-3927 (((-121) $) 157 (|has| |#1| (-558)))) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 204 (|has| |#1| (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 203 (|has| |#1| (-881 (-381))))) (-4499 (($ $) 50) (($ (-634 $)) 49)) (-3296 (((-634 (-123)) $) 42)) (-3488 (((-123) (-123)) 41)) (-2735 (((-121) $) 95 (|has| |#1| (-1102)))) (-1825 (((-121) $) 21 (|has| $ (-1037 (-568))))) (-1332 (($ $) 178 (|has| |#1| (-1047)))) (-2317 (((-1113 |#1| (-607 $)) $) 179 (|has| |#1| (-1047)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 153 (|has| |#1| (-558)))) (-3007 (((-1157 $) (-607 $)) 24 (|has| $ (-1047)))) (-2521 (($ $ $) 12)) (-3268 (($ $ $) 13)) (-2795 (($ (-1 $ $) (-607 $)) 35)) (-3693 (((-3 (-607 $) "failed") $) 45)) (-2495 (($ (-634 $)) 142 (|has| |#1| (-558))) (($ $ $) 141 (|has| |#1| (-558)))) (-4487 (((-1143) $) 9)) (-3804 (((-634 (-607 $)) $) 44)) (-3443 (($ (-123) $) 37) (($ (-123) (-634 $)) 36)) (-3324 (((-3 (-634 $) "failed") $) 184 (|has| |#1| (-1102)))) (-2672 (((-3 (-2 (|:| |val| $) (|:| -3438 (-568))) "failed") $) 175 (|has| |#1| (-1047)))) (-1794 (((-3 (-634 $) "failed") $) 182 (|has| |#1| (-25)))) (-2392 (((-3 (-2 (|:| -2348 (-568)) (|:| |var| (-607 $))) "failed") $) 181 (|has| |#1| (-25)))) (-3751 (((-3 (-2 (|:| |var| (-607 $)) (|:| -3438 (-568))) "failed") $) 183 (|has| |#1| (-1102))) (((-3 (-2 (|:| |var| (-607 $)) (|:| -3438 (-568))) "failed") $ (-123)) 177 (|has| |#1| (-1047))) (((-3 (-2 (|:| |var| (-607 $)) (|:| -3438 (-568))) "failed") $ (-1161)) 176 (|has| |#1| (-1047)))) (-2841 (((-121) $ (-123)) 39) (((-121) $ (-1161)) 38)) (-2081 (($ $) 99 (-2198 (|has| |#1| (-478)) (|has| |#1| (-558))))) (-2961 (((-763) $) 46)) (-4022 (((-1108) $) 10)) (-2086 (((-121) $) 197)) (-2091 ((|#1| $) 196)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 143 (|has| |#1| (-558)))) (-2721 (($ (-634 $)) 140 (|has| |#1| (-558))) (($ $ $) 139 (|has| |#1| (-558)))) (-4059 (((-121) $ $) 34) (((-121) $ (-1161)) 33)) (-3848 (((-420 $) $) 154 (|has| |#1| (-558)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 152 (|has| |#1| (-558))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 151 (|has| |#1| (-558)))) (-2595 (((-3 $ "failed") $ $) 134 (|has| |#1| (-558)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 145 (|has| |#1| (-558)))) (-3277 (((-121) $) 22 (|has| $ (-1037 (-568))))) (-1339 (($ $ (-607 $) $) 66) (($ $ (-634 (-607 $)) (-634 $)) 65) (($ $ (-634 (-288 $))) 64) (($ $ (-288 $)) 63) (($ $ $ $) 62) (($ $ (-634 $) (-634 $)) 61) (($ $ (-634 (-1161)) (-634 (-1 $ $))) 32) (($ $ (-634 (-1161)) (-634 (-1 $ (-634 $)))) 31) (($ $ (-1161) (-1 $ (-634 $))) 30) (($ $ (-1161) (-1 $ $)) 29) (($ $ (-634 (-123)) (-634 (-1 $ $))) 28) (($ $ (-634 (-123)) (-634 (-1 $ (-634 $)))) 27) (($ $ (-123) (-1 $ (-634 $))) 26) (($ $ (-123) (-1 $ $)) 25) (($ $ (-1161)) 189 (|has| |#1| (-609 (-541)))) (($ $ (-634 (-1161))) 188 (|has| |#1| (-609 (-541)))) (($ $) 187 (|has| |#1| (-609 (-541)))) (($ $ (-123) $ (-1161)) 186 (|has| |#1| (-609 (-541)))) (($ $ (-634 (-123)) (-634 $) (-1161)) 185 (|has| |#1| (-609 (-541)))) (($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ $))) 174 (|has| |#1| (-1047))) (($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ (-634 $)))) 173 (|has| |#1| (-1047))) (($ $ (-1161) (-763) (-1 $ (-634 $))) 172 (|has| |#1| (-1047))) (($ $ (-1161) (-763) (-1 $ $)) 171 (|has| |#1| (-1047)))) (-2709 (((-763) $) 147 (|has| |#1| (-558)))) (-2779 (($ (-123) $) 60) (($ (-123) $ $) 59) (($ (-123) $ $ $) 58) (($ (-123) $ $ $ $) 57) (($ (-123) (-634 $)) 56)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 148 (|has| |#1| (-558)))) (-3502 (($ $) 48) (($ $ $) 47)) (-4189 (($ $ (-634 (-1161)) (-634 (-763))) 120 (|has| |#1| (-1047))) (($ $ (-1161) (-763)) 119 (|has| |#1| (-1047))) (($ $ (-634 (-1161))) 118 (|has| |#1| (-1047))) (($ $ (-1161)) 117 (|has| |#1| (-1047)))) (-3013 (($ $) 168 (|has| |#1| (-558)))) (-2324 (((-1113 |#1| (-607 $)) $) 169 (|has| |#1| (-558)))) (-1626 (($ $) 23 (|has| $ (-1047)))) (-4278 (((-887 (-568)) $) 206 (|has| |#1| (-609 (-887 (-568))))) (((-887 (-381)) $) 205 (|has| |#1| (-609 (-887 (-381))))) (($ (-420 $)) 170 (|has| |#1| (-558))) (((-541) $) 89 (|has| |#1| (-609 (-541))))) (-1458 (($ $ $) 103 (|has| |#1| (-478)))) (-2353 (($ $ $) 104 (|has| |#1| (-478)))) (-2745 (((-850) $) 11) (($ (-607 $)) 69) (($ (-1161)) 209) (($ |#1|) 200) (($ (-1113 |#1| (-607 $))) 180 (|has| |#1| (-1047))) (($ (-409 |#1|)) 166 (|has| |#1| (-558))) (($ (-953 (-409 |#1|))) 165 (|has| |#1| (-558))) (($ (-409 (-953 (-409 |#1|)))) 164 (|has| |#1| (-558))) (($ (-409 (-953 |#1|))) 162 (|has| |#1| (-558))) (($ $) 133 (|has| |#1| (-558))) (($ (-953 |#1|)) 116 (|has| |#1| (-1047))) (($ (-409 (-568))) 88 (-2198 (|has| |#1| (-558)) (-12 (|has| |#1| (-1037 (-568))) (|has| |#1| (-558))) (|has| |#1| (-1037 (-409 (-568)))))) (($ (-568)) 85 (-2198 (|has| |#1| (-1047)) (|has| |#1| (-1037 (-568)))))) (-4371 (((-3 $ "failed") $) 130 (|has| |#1| (-148)))) (-4078 (((-763)) 125 (|has| |#1| (-1047)))) (-2092 (($ $) 52) (($ (-634 $)) 51)) (-2887 (((-121) (-123)) 40)) (-1826 (((-121) $ $) 137 (|has| |#1| (-558)))) (-3058 (($ (-1161) $) 194) (($ (-1161) $ $) 193) (($ (-1161) $ $ $) 192) (($ (-1161) $ $ $ $) 191) (($ (-1161) (-634 $)) 190)) (-1887 (($ $ (-568)) 102 (-2198 (|has| |#1| (-478)) (|has| |#1| (-558)))) (($ $ (-763)) 96 (|has| |#1| (-1102))) (($ $ (-917)) 92 (|has| |#1| (-1102)))) (-3056 (($) 107 (|has| |#1| (-25)) CONST)) (-1556 (($) 93 (|has| |#1| (-1102)) CONST)) (-3190 (($ $ (-634 (-1161)) (-634 (-763))) 124 (|has| |#1| (-1047))) (($ $ (-1161) (-763)) 123 (|has| |#1| (-1047))) (($ $ (-634 (-1161))) 122 (|has| |#1| (-1047))) (($ $ (-1161)) 121 (|has| |#1| (-1047)))) (-1751 (((-121) $ $) 15)) (-1738 (((-121) $ $) 16)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 14)) (-1732 (((-121) $ $) 17)) (-1779 (($ (-1113 |#1| (-607 $)) (-1113 |#1| (-607 $))) 167 (|has| |#1| (-558))) (($ $ $) 100 (-2198 (|has| |#1| (-478)) (|has| |#1| (-558))))) (-1773 (($ $ $) 112 (|has| |#1| (-21))) (($ $) 111 (|has| |#1| (-21)))) (-1767 (($ $ $) 105 (|has| |#1| (-25)))) (** (($ $ (-568)) 101 (-2198 (|has| |#1| (-478)) (|has| |#1| (-558)))) (($ $ (-763)) 98 (|has| |#1| (-1102))) (($ $ (-917)) 91 (|has| |#1| (-1102)))) (* (($ (-409 (-568)) $) 159 (|has| |#1| (-558))) (($ $ (-409 (-568))) 158 (|has| |#1| (-558))) (($ |#1| $) 132 (|has| |#1| (-172))) (($ $ |#1|) 131 (|has| |#1| (-172))) (($ (-568) $) 113 (|has| |#1| (-21))) (($ (-763) $) 109 (|has| |#1| (-25))) (($ (-917) $) 106 (|has| |#1| (-25))) (($ $ $) 90 (|has| |#1| (-1102))))) 
+((-3470 (((-585 |#2|) |#2| (-1161)) 35)) (-1284 (((-585 |#2|) |#2| (-1161)) 19)) (-2789 ((|#2| |#2| (-1161)) 24))) 
+(((-428 |#1| |#2|) (-10 -7 (-15 -1284 ((-585 |#2|) |#2| (-1161))) (-15 -3470 ((-585 |#2|) |#2| (-1161))) (-15 -2789 (|#2| |#2| (-1161)))) (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568))) (-13 (-1181) (-29 |#1|))) (T -428)) 
+((-2789 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-428 *4 *2)) (-4 *2 (-13 (-1181) (-29 *4))))) (-3470 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-428 *5 *3)) (-4 *3 (-13 (-1181) (-29 *5))))) (-1284 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-428 *5 *3)) (-4 *3 (-13 (-1181) (-29 *5)))))) 
+(-10 -7 (-15 -1284 ((-585 |#2|) |#2| (-1161))) (-15 -3470 ((-585 |#2|) |#2| (-1161))) (-15 -2789 (|#2| |#2| (-1161)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-2902 (((-3 $ "failed") $) NIL)) (-1598 (((-121) $) NIL)) (-4215 (($ |#2| |#1|) 35)) (-3401 (($ |#2| |#1|) 33)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL) (($ (-329 |#2|)) 25)) (-3425 (((-763)) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 10 T CONST)) (-1557 (($) 16 T CONST)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) 34)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 36) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
+(((-429 |#1| |#2|) (-13 (-43 |#1|) (-10 -8 (IF (|has| |#2| (-6 -4508)) (IF (|has| |#1| (-6 -4508)) (-6 -4508) |noBranch|) |noBranch|) (-15 -2747 ($ |#1|)) (-15 -2747 ($ (-329 |#2|))) (-15 -4215 ($ |#2| |#1|)) (-15 -3401 ($ |#2| |#1|)))) (-13 (-172) (-43 (-409 (-568)))) (-13 (-842) (-21))) (T -429)) 
+((-2747 (*1 *1 *2) (-12 (-5 *1 (-429 *2 *3)) (-4 *2 (-13 (-172) (-43 (-409 (-568))))) (-4 *3 (-13 (-842) (-21))))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-329 *4)) (-4 *4 (-13 (-842) (-21))) (-5 *1 (-429 *3 *4)) (-4 *3 (-13 (-172) (-43 (-409 (-568))))))) (-4215 (*1 *1 *2 *3) (-12 (-5 *1 (-429 *3 *2)) (-4 *3 (-13 (-172) (-43 (-409 (-568))))) (-4 *2 (-13 (-842) (-21))))) (-3401 (*1 *1 *2 *3) (-12 (-5 *1 (-429 *3 *2)) (-4 *3 (-13 (-172) (-43 (-409 (-568))))) (-4 *2 (-13 (-842) (-21)))))) 
+(-13 (-43 |#1|) (-10 -8 (IF (|has| |#2| (-6 -4508)) (IF (|has| |#1| (-6 -4508)) (-6 -4508) |noBranch|) |noBranch|) (-15 -2747 ($ |#1|)) (-15 -2747 ($ (-329 |#2|))) (-15 -4215 ($ |#2| |#1|)) (-15 -3401 ($ |#2| |#1|)))) 
+((-1845 (((-3 |#2| (-634 |#2|)) |#2| (-1161)) 104))) 
+(((-430 |#1| |#2|) (-10 -7 (-15 -1845 ((-3 |#2| (-634 |#2|)) |#2| (-1161)))) (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568))) (-13 (-1181) (-959) (-29 |#1|))) (T -430)) 
+((-1845 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 *3 (-634 *3))) (-5 *1 (-430 *5 *3)) (-4 *3 (-13 (-1181) (-959) (-29 *5)))))) 
+(-10 -7 (-15 -1845 ((-3 |#2| (-634 |#2|)) |#2| (-1161)))) 
+((-2057 (((-634 (-1161)) $) 72)) (-3840 (((-409 (-1157 $)) $ (-607 $)) 268)) (-4069 (($ $ (-288 $)) NIL) (($ $ (-634 (-288 $))) NIL) (($ $ (-634 (-607 $)) (-634 $)) 233)) (-3668 (((-3 (-607 $) "failed") $) NIL) (((-3 (-1161) "failed") $) 75) (((-3 (-568) "failed") $) NIL) (((-3 |#2| "failed") $) 229) (((-3 (-409 (-953 |#2|)) "failed") $) 319) (((-3 (-953 |#2|) "failed") $) 231) (((-3 (-409 (-568)) "failed") $) NIL)) (-2857 (((-607 $) $) NIL) (((-1161) $) 30) (((-568) $) NIL) ((|#2| $) 227) (((-409 (-953 |#2|)) $) 300) (((-953 |#2|) $) 228) (((-409 (-568)) $) NIL)) (-3842 (((-123) (-123)) 47)) (-3539 (($ $) 87)) (-2337 (((-3 (-607 $) "failed") $) 224)) (-3832 (((-634 (-607 $)) $) 225)) (-4362 (((-3 (-634 $) "failed") $) 243)) (-4495 (((-3 (-2 (|:| |val| $) (|:| -3483 (-568))) "failed") $) 250)) (-2112 (((-3 (-634 $) "failed") $) 241)) (-2240 (((-3 (-2 (|:| -2350 (-568)) (|:| |var| (-607 $))) "failed") $) 259)) (-2617 (((-3 (-2 (|:| |var| (-607 $)) (|:| -3483 (-568))) "failed") $) 247) (((-3 (-2 (|:| |var| (-607 $)) (|:| -3483 (-568))) "failed") $ (-123)) 214) (((-3 (-2 (|:| |var| (-607 $)) (|:| -3483 (-568))) "failed") $ (-1161)) 216)) (-2088 (((-121) $) 19)) (-2093 ((|#2| $) 21)) (-1339 (($ $ (-607 $) $) NIL) (($ $ (-634 (-607 $)) (-634 $)) 232) (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ $))) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ (-634 $)))) 96) (($ $ (-1161) (-1 $ (-634 $))) NIL) (($ $ (-1161) (-1 $ $)) NIL) (($ $ (-634 (-123)) (-634 (-1 $ $))) NIL) (($ $ (-634 (-123)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-123) (-1 $ (-634 $))) NIL) (($ $ (-123) (-1 $ $)) NIL) (($ $ (-1161)) 57) (($ $ (-634 (-1161))) 236) (($ $) 237) (($ $ (-123) $ (-1161)) 60) (($ $ (-634 (-123)) (-634 $) (-1161)) 67) (($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ $))) 107) (($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ (-634 $)))) 238) (($ $ (-1161) (-763) (-1 $ (-634 $))) 94) (($ $ (-1161) (-763) (-1 $ $)) 93)) (-2781 (($ (-123) $) NIL) (($ (-123) $ $) NIL) (($ (-123) $ $ $) NIL) (($ (-123) $ $ $ $) NIL) (($ (-123) (-634 $)) 106)) (-4191 (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) 234)) (-3210 (($ $) 279)) (-4280 (((-887 (-568)) $) 253) (((-887 (-381)) $) 256) (($ (-420 $)) 315) (((-541) $) NIL)) (-2747 (((-850) $) 235) (($ (-607 $)) 84) (($ (-1161)) 26) (($ |#2|) NIL) (($ (-1113 |#2| (-607 $))) NIL) (($ (-409 |#2|)) 284) (($ (-953 (-409 |#2|))) 324) (($ (-409 (-953 (-409 |#2|)))) 296) (($ (-409 (-953 |#2|))) 290) (($ $) NIL) (($ (-953 |#2|)) 183) (($ (-409 (-568))) 329) (($ (-568)) NIL)) (-3425 (((-763)) 79)) (-2779 (((-121) (-123)) 41)) (-3060 (($ (-1161) $) 33) (($ (-1161) $ $) 34) (($ (-1161) $ $ $) 35) (($ (-1161) $ $ $ $) 36) (($ (-1161) (-634 $)) 39)) (* (($ (-409 (-568)) $) NIL) (($ $ (-409 (-568))) NIL) (($ |#2| $) 261) (($ $ |#2|) NIL) (($ $ $) NIL) (($ (-568) $) NIL) (($ (-763) $) NIL) (($ (-917) $) NIL))) 
+(((-431 |#1| |#2|) (-10 -8 (-15 * (|#1| (-917) |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 -3425 ((-763))) (-15 -2747 (|#1| (-568))) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -4280 ((-541) |#1|)) (-15 -2857 ((-953 |#2|) |#1|)) (-15 -3668 ((-3 (-953 |#2|) "failed") |#1|)) (-15 -2747 (|#1| (-953 |#2|))) (-15 -4191 (|#1| |#1| (-1161))) (-15 -4191 (|#1| |#1| (-634 (-1161)))) (-15 -4191 (|#1| |#1| (-1161) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 -2747 (|#1| |#1|)) (-15 * (|#1| |#1| (-409 (-568)))) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 -2857 ((-409 (-953 |#2|)) |#1|)) (-15 -3668 ((-3 (-409 (-953 |#2|)) "failed") |#1|)) (-15 -2747 (|#1| (-409 (-953 |#2|)))) (-15 -3840 ((-409 (-1157 |#1|)) |#1| (-607 |#1|))) (-15 -2747 (|#1| (-409 (-953 (-409 |#2|))))) (-15 -2747 (|#1| (-953 (-409 |#2|)))) (-15 -2747 (|#1| (-409 |#2|))) (-15 -3210 (|#1| |#1|)) (-15 -4280 (|#1| (-420 |#1|))) (-15 -1339 (|#1| |#1| (-1161) (-763) (-1 |#1| |#1|))) (-15 -1339 (|#1| |#1| (-1161) (-763) (-1 |#1| (-634 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-763)) (-634 (-1 |#1| (-634 |#1|))))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-763)) (-634 (-1 |#1| |#1|)))) (-15 -4495 ((-3 (-2 (|:| |val| |#1|) (|:| -3483 (-568))) "failed") |#1|)) (-15 -2617 ((-3 (-2 (|:| |var| (-607 |#1|)) (|:| -3483 (-568))) "failed") |#1| (-1161))) (-15 -2617 ((-3 (-2 (|:| |var| (-607 |#1|)) (|:| -3483 (-568))) "failed") |#1| (-123))) (-15 -3539 (|#1| |#1|)) (-15 -2747 (|#1| (-1113 |#2| (-607 |#1|)))) (-15 -2240 ((-3 (-2 (|:| -2350 (-568)) (|:| |var| (-607 |#1|))) "failed") |#1|)) (-15 -2112 ((-3 (-634 |#1|) "failed") |#1|)) (-15 -2617 ((-3 (-2 (|:| |var| (-607 |#1|)) (|:| -3483 (-568))) "failed") |#1|)) (-15 -4362 ((-3 (-634 |#1|) "failed") |#1|)) (-15 -1339 (|#1| |#1| (-634 (-123)) (-634 |#1|) (-1161))) (-15 -1339 (|#1| |#1| (-123) |#1| (-1161))) (-15 -1339 (|#1| |#1|)) (-15 -1339 (|#1| |#1| (-634 (-1161)))) (-15 -1339 (|#1| |#1| (-1161))) (-15 -3060 (|#1| (-1161) (-634 |#1|))) (-15 -3060 (|#1| (-1161) |#1| |#1| |#1| |#1|)) (-15 -3060 (|#1| (-1161) |#1| |#1| |#1|)) (-15 -3060 (|#1| (-1161) |#1| |#1|)) (-15 -3060 (|#1| (-1161) |#1|)) (-15 -2057 ((-634 (-1161)) |#1|)) (-15 -2093 (|#2| |#1|)) (-15 -2088 ((-121) |#1|)) (-15 -2857 (|#2| |#1|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -2747 (|#1| |#2|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2857 ((-568) |#1|)) (-15 -4280 ((-887 (-381)) |#1|)) (-15 -4280 ((-887 (-568)) |#1|)) (-15 -2857 ((-1161) |#1|)) (-15 -3668 ((-3 (-1161) "failed") |#1|)) (-15 -2747 (|#1| (-1161))) (-15 -1339 (|#1| |#1| (-123) (-1 |#1| |#1|))) (-15 -1339 (|#1| |#1| (-123) (-1 |#1| (-634 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-123)) (-634 (-1 |#1| (-634 |#1|))))) (-15 -1339 (|#1| |#1| (-634 (-123)) (-634 (-1 |#1| |#1|)))) (-15 -1339 (|#1| |#1| (-1161) (-1 |#1| |#1|))) (-15 -1339 (|#1| |#1| (-1161) (-1 |#1| (-634 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-1 |#1| (-634 |#1|))))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-1 |#1| |#1|)))) (-15 -2779 ((-121) (-123))) (-15 -3842 ((-123) (-123))) (-15 -3832 ((-634 (-607 |#1|)) |#1|)) (-15 -2337 ((-3 (-607 |#1|) "failed") |#1|)) (-15 -4069 (|#1| |#1| (-634 (-607 |#1|)) (-634 |#1|))) (-15 -4069 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -4069 (|#1| |#1| (-288 |#1|))) (-15 -2781 (|#1| (-123) (-634 |#1|))) (-15 -2781 (|#1| (-123) |#1| |#1| |#1| |#1|)) (-15 -2781 (|#1| (-123) |#1| |#1| |#1|)) (-15 -2781 (|#1| (-123) |#1| |#1|)) (-15 -2781 (|#1| (-123) |#1|)) (-15 -1339 (|#1| |#1| (-634 |#1|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#1| |#1|)) (-15 -1339 (|#1| |#1| (-288 |#1|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-607 |#1|)) (-634 |#1|))) (-15 -1339 (|#1| |#1| (-607 |#1|) |#1|)) (-15 -2857 ((-607 |#1|) |#1|)) (-15 -3668 ((-3 (-607 |#1|) "failed") |#1|)) (-15 -2747 (|#1| (-607 |#1|))) (-15 -2747 ((-850) |#1|))) (-432 |#2|) (-842)) (T -431)) 
+((-3842 (*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *4 (-842)) (-5 *1 (-431 *3 *4)) (-4 *3 (-432 *4)))) (-2779 (*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-431 *4 *5)) (-4 *4 (-432 *5)))) (-3425 (*1 *2) (-12 (-4 *4 (-842)) (-5 *2 (-763)) (-5 *1 (-431 *3 *4)) (-4 *3 (-432 *4))))) 
+(-10 -8 (-15 * (|#1| (-917) |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 -3425 ((-763))) (-15 -2747 (|#1| (-568))) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -4280 ((-541) |#1|)) (-15 -2857 ((-953 |#2|) |#1|)) (-15 -3668 ((-3 (-953 |#2|) "failed") |#1|)) (-15 -2747 (|#1| (-953 |#2|))) (-15 -4191 (|#1| |#1| (-1161))) (-15 -4191 (|#1| |#1| (-634 (-1161)))) (-15 -4191 (|#1| |#1| (-1161) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 -2747 (|#1| |#1|)) (-15 * (|#1| |#1| (-409 (-568)))) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 -2857 ((-409 (-953 |#2|)) |#1|)) (-15 -3668 ((-3 (-409 (-953 |#2|)) "failed") |#1|)) (-15 -2747 (|#1| (-409 (-953 |#2|)))) (-15 -3840 ((-409 (-1157 |#1|)) |#1| (-607 |#1|))) (-15 -2747 (|#1| (-409 (-953 (-409 |#2|))))) (-15 -2747 (|#1| (-953 (-409 |#2|)))) (-15 -2747 (|#1| (-409 |#2|))) (-15 -3210 (|#1| |#1|)) (-15 -4280 (|#1| (-420 |#1|))) (-15 -1339 (|#1| |#1| (-1161) (-763) (-1 |#1| |#1|))) (-15 -1339 (|#1| |#1| (-1161) (-763) (-1 |#1| (-634 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-763)) (-634 (-1 |#1| (-634 |#1|))))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-763)) (-634 (-1 |#1| |#1|)))) (-15 -4495 ((-3 (-2 (|:| |val| |#1|) (|:| -3483 (-568))) "failed") |#1|)) (-15 -2617 ((-3 (-2 (|:| |var| (-607 |#1|)) (|:| -3483 (-568))) "failed") |#1| (-1161))) (-15 -2617 ((-3 (-2 (|:| |var| (-607 |#1|)) (|:| -3483 (-568))) "failed") |#1| (-123))) (-15 -3539 (|#1| |#1|)) (-15 -2747 (|#1| (-1113 |#2| (-607 |#1|)))) (-15 -2240 ((-3 (-2 (|:| -2350 (-568)) (|:| |var| (-607 |#1|))) "failed") |#1|)) (-15 -2112 ((-3 (-634 |#1|) "failed") |#1|)) (-15 -2617 ((-3 (-2 (|:| |var| (-607 |#1|)) (|:| -3483 (-568))) "failed") |#1|)) (-15 -4362 ((-3 (-634 |#1|) "failed") |#1|)) (-15 -1339 (|#1| |#1| (-634 (-123)) (-634 |#1|) (-1161))) (-15 -1339 (|#1| |#1| (-123) |#1| (-1161))) (-15 -1339 (|#1| |#1|)) (-15 -1339 (|#1| |#1| (-634 (-1161)))) (-15 -1339 (|#1| |#1| (-1161))) (-15 -3060 (|#1| (-1161) (-634 |#1|))) (-15 -3060 (|#1| (-1161) |#1| |#1| |#1| |#1|)) (-15 -3060 (|#1| (-1161) |#1| |#1| |#1|)) (-15 -3060 (|#1| (-1161) |#1| |#1|)) (-15 -3060 (|#1| (-1161) |#1|)) (-15 -2057 ((-634 (-1161)) |#1|)) (-15 -2093 (|#2| |#1|)) (-15 -2088 ((-121) |#1|)) (-15 -2857 (|#2| |#1|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -2747 (|#1| |#2|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2857 ((-568) |#1|)) (-15 -4280 ((-887 (-381)) |#1|)) (-15 -4280 ((-887 (-568)) |#1|)) (-15 -2857 ((-1161) |#1|)) (-15 -3668 ((-3 (-1161) "failed") |#1|)) (-15 -2747 (|#1| (-1161))) (-15 -1339 (|#1| |#1| (-123) (-1 |#1| |#1|))) (-15 -1339 (|#1| |#1| (-123) (-1 |#1| (-634 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-123)) (-634 (-1 |#1| (-634 |#1|))))) (-15 -1339 (|#1| |#1| (-634 (-123)) (-634 (-1 |#1| |#1|)))) (-15 -1339 (|#1| |#1| (-1161) (-1 |#1| |#1|))) (-15 -1339 (|#1| |#1| (-1161) (-1 |#1| (-634 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-1 |#1| (-634 |#1|))))) (-15 -1339 (|#1| |#1| (-634 (-1161)) (-634 (-1 |#1| |#1|)))) (-15 -2779 ((-121) (-123))) (-15 -3842 ((-123) (-123))) (-15 -3832 ((-634 (-607 |#1|)) |#1|)) (-15 -2337 ((-3 (-607 |#1|) "failed") |#1|)) (-15 -4069 (|#1| |#1| (-634 (-607 |#1|)) (-634 |#1|))) (-15 -4069 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -4069 (|#1| |#1| (-288 |#1|))) (-15 -2781 (|#1| (-123) (-634 |#1|))) (-15 -2781 (|#1| (-123) |#1| |#1| |#1| |#1|)) (-15 -2781 (|#1| (-123) |#1| |#1| |#1|)) (-15 -2781 (|#1| (-123) |#1| |#1|)) (-15 -2781 (|#1| (-123) |#1|)) (-15 -1339 (|#1| |#1| (-634 |#1|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#1| |#1|)) (-15 -1339 (|#1| |#1| (-288 |#1|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -1339 (|#1| |#1| (-634 (-607 |#1|)) (-634 |#1|))) (-15 -1339 (|#1| |#1| (-607 |#1|) |#1|)) (-15 -2857 ((-607 |#1|) |#1|)) (-15 -3668 ((-3 (-607 |#1|) "failed") |#1|)) (-15 -2747 (|#1| (-607 |#1|))) (-15 -2747 ((-850) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 108 (|has| |#1| (-25)))) (-2057 (((-634 (-1161)) $) 195)) (-3840 (((-409 (-1157 $)) $ (-607 $)) 163 (|has| |#1| (-558)))) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 135 (|has| |#1| (-558)))) (-3661 (($ $) 136 (|has| |#1| (-558)))) (-4426 (((-121) $) 138 (|has| |#1| (-558)))) (-3145 (((-634 (-607 $)) $) 43)) (-2689 (((-3 $ "failed") $ $) 110 (|has| |#1| (-21)))) (-4069 (($ $ (-288 $)) 55) (($ $ (-634 (-288 $))) 54) (($ $ (-634 (-607 $)) (-634 $)) 53)) (-3045 (($ $) 155 (|has| |#1| (-558)))) (-3498 (((-420 $) $) 156 (|has| |#1| (-558)))) (-2589 (((-121) $ $) 146 (|has| |#1| (-558)))) (-4490 (($) 94 (-2199 (|has| |#1| (-1102)) (|has| |#1| (-25))) CONST)) (-3668 (((-3 (-607 $) "failed") $) 68) (((-3 (-1161) "failed") $) 208) (((-3 (-568) "failed") $) 201 (|has| |#1| (-1037 (-568)))) (((-3 |#1| "failed") $) 199) (((-3 (-409 (-953 |#1|)) "failed") $) 161 (|has| |#1| (-558))) (((-3 (-953 |#1|) "failed") $) 115 (|has| |#1| (-1047))) (((-3 (-409 (-568)) "failed") $) 87 (-2199 (-12 (|has| |#1| (-1037 (-568))) (|has| |#1| (-558))) (|has| |#1| (-1037 (-409 (-568))))))) (-2857 (((-607 $) $) 67) (((-1161) $) 207) (((-568) $) 202 (|has| |#1| (-1037 (-568)))) ((|#1| $) 198) (((-409 (-953 |#1|)) $) 160 (|has| |#1| (-558))) (((-953 |#1|) $) 114 (|has| |#1| (-1047))) (((-409 (-568)) $) 86 (-2199 (-12 (|has| |#1| (-1037 (-568))) (|has| |#1| (-558))) (|has| |#1| (-1037 (-409 (-568))))))) (-2403 (($ $ $) 150 (|has| |#1| (-558)))) (-1668 (((-679 (-568)) (-679 $)) 129 (-2141 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 128 (-2141 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 127 (|has| |#1| (-1047))) (((-679 |#1|) (-679 $)) 126 (|has| |#1| (-1047)))) (-2902 (((-3 $ "failed") $) 97 (|has| |#1| (-1102)))) (-2414 (($ $ $) 149 (|has| |#1| (-558)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 144 (|has| |#1| (-558)))) (-2197 (((-121) $) 157 (|has| |#1| (-558)))) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 204 (|has| |#1| (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 203 (|has| |#1| (-881 (-381))))) (-3855 (($ $) 50) (($ (-634 $)) 49)) (-2160 (((-634 (-123)) $) 42)) (-3842 (((-123) (-123)) 41)) (-1598 (((-121) $) 95 (|has| |#1| (-1102)))) (-2268 (((-121) $) 21 (|has| $ (-1037 (-568))))) (-3539 (($ $) 178 (|has| |#1| (-1047)))) (-2319 (((-1113 |#1| (-607 $)) $) 179 (|has| |#1| (-1047)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 153 (|has| |#1| (-558)))) (-3170 (((-1157 $) (-607 $)) 24 (|has| $ (-1047)))) (-1732 (($ $ $) 12)) (-2047 (($ $ $) 13)) (-2797 (($ (-1 $ $) (-607 $)) 35)) (-2337 (((-3 (-607 $) "failed") $) 45)) (-2498 (($ (-634 $)) 142 (|has| |#1| (-558))) (($ $ $) 141 (|has| |#1| (-558)))) (-1893 (((-1143) $) 9)) (-3832 (((-634 (-607 $)) $) 44)) (-3446 (($ (-123) $) 37) (($ (-123) (-634 $)) 36)) (-4362 (((-3 (-634 $) "failed") $) 184 (|has| |#1| (-1102)))) (-4495 (((-3 (-2 (|:| |val| $) (|:| -3483 (-568))) "failed") $) 175 (|has| |#1| (-1047)))) (-2112 (((-3 (-634 $) "failed") $) 182 (|has| |#1| (-25)))) (-2240 (((-3 (-2 (|:| -2350 (-568)) (|:| |var| (-607 $))) "failed") $) 181 (|has| |#1| (-25)))) (-2617 (((-3 (-2 (|:| |var| (-607 $)) (|:| -3483 (-568))) "failed") $) 183 (|has| |#1| (-1102))) (((-3 (-2 (|:| |var| (-607 $)) (|:| -3483 (-568))) "failed") $ (-123)) 177 (|has| |#1| (-1047))) (((-3 (-2 (|:| |var| (-607 $)) (|:| -3483 (-568))) "failed") $ (-1161)) 176 (|has| |#1| (-1047)))) (-3910 (((-121) $ (-123)) 39) (((-121) $ (-1161)) 38)) (-2083 (($ $) 99 (-2199 (|has| |#1| (-478)) (|has| |#1| (-558))))) (-2963 (((-763) $) 46)) (-4025 (((-1108) $) 10)) (-2088 (((-121) $) 197)) (-2093 ((|#1| $) 196)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 143 (|has| |#1| (-558)))) (-2723 (($ (-634 $)) 140 (|has| |#1| (-558))) (($ $ $) 139 (|has| |#1| (-558)))) (-1609 (((-121) $ $) 34) (((-121) $ (-1161)) 33)) (-3850 (((-420 $) $) 154 (|has| |#1| (-558)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 152 (|has| |#1| (-558))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 151 (|has| |#1| (-558)))) (-2597 (((-3 $ "failed") $ $) 134 (|has| |#1| (-558)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 145 (|has| |#1| (-558)))) (-2080 (((-121) $) 22 (|has| $ (-1037 (-568))))) (-1339 (($ $ (-607 $) $) 66) (($ $ (-634 (-607 $)) (-634 $)) 65) (($ $ (-634 (-288 $))) 64) (($ $ (-288 $)) 63) (($ $ $ $) 62) (($ $ (-634 $) (-634 $)) 61) (($ $ (-634 (-1161)) (-634 (-1 $ $))) 32) (($ $ (-634 (-1161)) (-634 (-1 $ (-634 $)))) 31) (($ $ (-1161) (-1 $ (-634 $))) 30) (($ $ (-1161) (-1 $ $)) 29) (($ $ (-634 (-123)) (-634 (-1 $ $))) 28) (($ $ (-634 (-123)) (-634 (-1 $ (-634 $)))) 27) (($ $ (-123) (-1 $ (-634 $))) 26) (($ $ (-123) (-1 $ $)) 25) (($ $ (-1161)) 189 (|has| |#1| (-609 (-541)))) (($ $ (-634 (-1161))) 188 (|has| |#1| (-609 (-541)))) (($ $) 187 (|has| |#1| (-609 (-541)))) (($ $ (-123) $ (-1161)) 186 (|has| |#1| (-609 (-541)))) (($ $ (-634 (-123)) (-634 $) (-1161)) 185 (|has| |#1| (-609 (-541)))) (($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ $))) 174 (|has| |#1| (-1047))) (($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ (-634 $)))) 173 (|has| |#1| (-1047))) (($ $ (-1161) (-763) (-1 $ (-634 $))) 172 (|has| |#1| (-1047))) (($ $ (-1161) (-763) (-1 $ $)) 171 (|has| |#1| (-1047)))) (-1466 (((-763) $) 147 (|has| |#1| (-558)))) (-2781 (($ (-123) $) 60) (($ (-123) $ $) 59) (($ (-123) $ $ $) 58) (($ (-123) $ $ $ $) 57) (($ (-123) (-634 $)) 56)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 148 (|has| |#1| (-558)))) (-3924 (($ $) 48) (($ $ $) 47)) (-4191 (($ $ (-634 (-1161)) (-634 (-763))) 120 (|has| |#1| (-1047))) (($ $ (-1161) (-763)) 119 (|has| |#1| (-1047))) (($ $ (-634 (-1161))) 118 (|has| |#1| (-1047))) (($ $ (-1161)) 117 (|has| |#1| (-1047)))) (-3210 (($ $) 168 (|has| |#1| (-558)))) (-2326 (((-1113 |#1| (-607 $)) $) 169 (|has| |#1| (-558)))) (-1492 (($ $) 23 (|has| $ (-1047)))) (-4280 (((-887 (-568)) $) 206 (|has| |#1| (-609 (-887 (-568))))) (((-887 (-381)) $) 205 (|has| |#1| (-609 (-887 (-381))))) (($ (-420 $)) 170 (|has| |#1| (-558))) (((-541) $) 89 (|has| |#1| (-609 (-541))))) (-2387 (($ $ $) 103 (|has| |#1| (-478)))) (-3985 (($ $ $) 104 (|has| |#1| (-478)))) (-2747 (((-850) $) 11) (($ (-607 $)) 69) (($ (-1161)) 209) (($ |#1|) 200) (($ (-1113 |#1| (-607 $))) 180 (|has| |#1| (-1047))) (($ (-409 |#1|)) 166 (|has| |#1| (-558))) (($ (-953 (-409 |#1|))) 165 (|has| |#1| (-558))) (($ (-409 (-953 (-409 |#1|)))) 164 (|has| |#1| (-558))) (($ (-409 (-953 |#1|))) 162 (|has| |#1| (-558))) (($ $) 133 (|has| |#1| (-558))) (($ (-953 |#1|)) 116 (|has| |#1| (-1047))) (($ (-409 (-568))) 88 (-2199 (|has| |#1| (-558)) (-12 (|has| |#1| (-1037 (-568))) (|has| |#1| (-558))) (|has| |#1| (-1037 (-409 (-568)))))) (($ (-568)) 85 (-2199 (|has| |#1| (-1047)) (|has| |#1| (-1037 (-568)))))) (-3385 (((-3 $ "failed") $) 130 (|has| |#1| (-148)))) (-3425 (((-763)) 125 (|has| |#1| (-1047)))) (-3159 (($ $) 52) (($ (-634 $)) 51)) (-2779 (((-121) (-123)) 40)) (-2273 (((-121) $ $) 137 (|has| |#1| (-558)))) (-3060 (($ (-1161) $) 194) (($ (-1161) $ $) 193) (($ (-1161) $ $ $) 192) (($ (-1161) $ $ $ $) 191) (($ (-1161) (-634 $)) 190)) (-1889 (($ $ (-568)) 102 (-2199 (|has| |#1| (-478)) (|has| |#1| (-558)))) (($ $ (-763)) 96 (|has| |#1| (-1102))) (($ $ (-917)) 92 (|has| |#1| (-1102)))) (-3058 (($) 107 (|has| |#1| (-25)) CONST)) (-1557 (($) 93 (|has| |#1| (-1102)) CONST)) (-3192 (($ $ (-634 (-1161)) (-634 (-763))) 124 (|has| |#1| (-1047))) (($ $ (-1161) (-763)) 123 (|has| |#1| (-1047))) (($ $ (-634 (-1161))) 122 (|has| |#1| (-1047))) (($ $ (-1161)) 121 (|has| |#1| (-1047)))) (-1753 (((-121) $ $) 15)) (-1740 (((-121) $ $) 16)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 14)) (-1734 (((-121) $ $) 17)) (-1781 (($ (-1113 |#1| (-607 $)) (-1113 |#1| (-607 $))) 167 (|has| |#1| (-558))) (($ $ $) 100 (-2199 (|has| |#1| (-478)) (|has| |#1| (-558))))) (-1775 (($ $ $) 112 (|has| |#1| (-21))) (($ $) 111 (|has| |#1| (-21)))) (-1769 (($ $ $) 105 (|has| |#1| (-25)))) (** (($ $ (-568)) 101 (-2199 (|has| |#1| (-478)) (|has| |#1| (-558)))) (($ $ (-763)) 98 (|has| |#1| (-1102))) (($ $ (-917)) 91 (|has| |#1| (-1102)))) (* (($ (-409 (-568)) $) 159 (|has| |#1| (-558))) (($ $ (-409 (-568))) 158 (|has| |#1| (-558))) (($ |#1| $) 132 (|has| |#1| (-172))) (($ $ |#1|) 131 (|has| |#1| (-172))) (($ (-568) $) 113 (|has| |#1| (-21))) (($ (-763) $) 109 (|has| |#1| (-25))) (($ (-917) $) 106 (|has| |#1| (-25))) (($ $ $) 90 (|has| |#1| (-1102))))) 
 (((-432 |#1|) (-1275) (-842)) (T -432)) 
-((-2086 (*1 *2 *1) (-12 (-4 *1 (-432 *3)) (-4 *3 (-842)) (-5 *2 (-121)))) (-2091 (*1 *2 *1) (-12 (-4 *1 (-432 *2)) (-4 *2 (-842)))) (-2055 (*1 *2 *1) (-12 (-4 *1 (-432 *3)) (-4 *3 (-842)) (-5 *2 (-634 (-1161))))) (-3058 (*1 *1 *2 *1) (-12 (-5 *2 (-1161)) (-4 *1 (-432 *3)) (-4 *3 (-842)))) (-3058 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1161)) (-4 *1 (-432 *3)) (-4 *3 (-842)))) (-3058 (*1 *1 *2 *1 *1 *1) (-12 (-5 *2 (-1161)) (-4 *1 (-432 *3)) (-4 *3 (-842)))) (-3058 (*1 *1 *2 *1 *1 *1 *1) (-12 (-5 *2 (-1161)) (-4 *1 (-432 *3)) (-4 *3 (-842)))) (-3058 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-634 *1)) (-4 *1 (-432 *4)) (-4 *4 (-842)))) (-1339 (*1 *1 *1 *2) (-12 (-5 *2 (-1161)) (-4 *1 (-432 *3)) (-4 *3 (-842)) (-4 *3 (-609 (-541))))) (-1339 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-1161))) (-4 *1 (-432 *3)) (-4 *3 (-842)) (-4 *3 (-609 (-541))))) (-1339 (*1 *1 *1) (-12 (-4 *1 (-432 *2)) (-4 *2 (-842)) (-4 *2 (-609 (-541))))) (-1339 (*1 *1 *1 *2 *1 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1161)) (-4 *1 (-432 *4)) (-4 *4 (-842)) (-4 *4 (-609 (-541))))) (-1339 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-634 (-123))) (-5 *3 (-634 *1)) (-5 *4 (-1161)) (-4 *1 (-432 *5)) (-4 *5 (-842)) (-4 *5 (-609 (-541))))) (-3324 (*1 *2 *1) (|partial| -12 (-4 *3 (-1102)) (-4 *3 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-432 *3)))) (-3751 (*1 *2 *1) (|partial| -12 (-4 *3 (-1102)) (-4 *3 (-842)) (-5 *2 (-2 (|:| |var| (-607 *1)) (|:| -3438 (-568)))) (-4 *1 (-432 *3)))) (-1794 (*1 *2 *1) (|partial| -12 (-4 *3 (-25)) (-4 *3 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-432 *3)))) (-2392 (*1 *2 *1) (|partial| -12 (-4 *3 (-25)) (-4 *3 (-842)) (-5 *2 (-2 (|:| -2348 (-568)) (|:| |var| (-607 *1)))) (-4 *1 (-432 *3)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-1113 *3 (-607 *1))) (-4 *3 (-1047)) (-4 *3 (-842)) (-4 *1 (-432 *3)))) (-2317 (*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *3 (-842)) (-5 *2 (-1113 *3 (-607 *1))) (-4 *1 (-432 *3)))) (-1332 (*1 *1 *1) (-12 (-4 *1 (-432 *2)) (-4 *2 (-842)) (-4 *2 (-1047)))) (-3751 (*1 *2 *1 *3) (|partial| -12 (-5 *3 (-123)) (-4 *4 (-1047)) (-4 *4 (-842)) (-5 *2 (-2 (|:| |var| (-607 *1)) (|:| -3438 (-568)))) (-4 *1 (-432 *4)))) (-3751 (*1 *2 *1 *3) (|partial| -12 (-5 *3 (-1161)) (-4 *4 (-1047)) (-4 *4 (-842)) (-5 *2 (-2 (|:| |var| (-607 *1)) (|:| -3438 (-568)))) (-4 *1 (-432 *4)))) (-2672 (*1 *2 *1) (|partial| -12 (-4 *3 (-1047)) (-4 *3 (-842)) (-5 *2 (-2 (|:| |val| *1) (|:| -3438 (-568)))) (-4 *1 (-432 *3)))) (-1339 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-634 (-763))) (-5 *4 (-634 (-1 *1 *1))) (-4 *1 (-432 *5)) (-4 *5 (-842)) (-4 *5 (-1047)))) (-1339 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-634 (-763))) (-5 *4 (-634 (-1 *1 (-634 *1)))) (-4 *1 (-432 *5)) (-4 *5 (-842)) (-4 *5 (-1047)))) (-1339 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-763)) (-5 *4 (-1 *1 (-634 *1))) (-4 *1 (-432 *5)) (-4 *5 (-842)) (-4 *5 (-1047)))) (-1339 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-763)) (-5 *4 (-1 *1 *1)) (-4 *1 (-432 *5)) (-4 *5 (-842)) (-4 *5 (-1047)))) (-4278 (*1 *1 *2) (-12 (-5 *2 (-420 *1)) (-4 *1 (-432 *3)) (-4 *3 (-558)) (-4 *3 (-842)))) (-2324 (*1 *2 *1) (-12 (-4 *3 (-558)) (-4 *3 (-842)) (-5 *2 (-1113 *3 (-607 *1))) (-4 *1 (-432 *3)))) (-3013 (*1 *1 *1) (-12 (-4 *1 (-432 *2)) (-4 *2 (-842)) (-4 *2 (-558)))) (-1779 (*1 *1 *2 *2) (-12 (-5 *2 (-1113 *3 (-607 *1))) (-4 *3 (-558)) (-4 *3 (-842)) (-4 *1 (-432 *3)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-409 *3)) (-4 *3 (-558)) (-4 *3 (-842)) (-4 *1 (-432 *3)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-953 (-409 *3))) (-4 *3 (-558)) (-4 *3 (-842)) (-4 *1 (-432 *3)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-409 (-953 (-409 *3)))) (-4 *3 (-558)) (-4 *3 (-842)) (-4 *1 (-432 *3)))) (-3839 (*1 *2 *1 *3) (-12 (-5 *3 (-607 *1)) (-4 *1 (-432 *4)) (-4 *4 (-842)) (-4 *4 (-558)) (-5 *2 (-409 (-1157 *1))))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-432 *3)) (-4 *3 (-842)) (-4 *3 (-1102))))) 
-(-13 (-296) (-1037 (-1161)) (-879 |t#1|) (-402 |t#1|) (-413 |t#1|) (-10 -8 (-15 -2086 ((-121) $)) (-15 -2091 (|t#1| $)) (-15 -2055 ((-634 (-1161)) $)) (-15 -3058 ($ (-1161) $)) (-15 -3058 ($ (-1161) $ $)) (-15 -3058 ($ (-1161) $ $ $)) (-15 -3058 ($ (-1161) $ $ $ $)) (-15 -3058 ($ (-1161) (-634 $))) (IF (|has| |t#1| (-609 (-541))) (PROGN (-6 (-609 (-541))) (-15 -1339 ($ $ (-1161))) (-15 -1339 ($ $ (-634 (-1161)))) (-15 -1339 ($ $)) (-15 -1339 ($ $ (-123) $ (-1161))) (-15 -1339 ($ $ (-634 (-123)) (-634 $) (-1161)))) |noBranch|) (IF (|has| |t#1| (-1102)) (PROGN (-6 (-716)) (-15 ** ($ $ (-763))) (-15 -3324 ((-3 (-634 $) "failed") $)) (-15 -3751 ((-3 (-2 (|:| |var| (-607 $)) (|:| -3438 (-568))) "failed") $))) |noBranch|) (IF (|has| |t#1| (-478)) (-6 (-478)) |noBranch|) (IF (|has| |t#1| (-25)) (PROGN (-6 (-23)) (-15 -1794 ((-3 (-634 $) "failed") $)) (-15 -2392 ((-3 (-2 (|:| -2348 (-568)) (|:| |var| (-607 $))) "failed") $))) |noBranch|) (IF (|has| |t#1| (-21)) (-6 (-21)) |noBranch|) (IF (|has| |t#1| (-1047)) (PROGN (-6 (-1047)) (-6 (-1037 (-953 |t#1|))) (-6 (-895 (-1161))) (-6 (-379 |t#1|)) (-15 -2745 ($ (-1113 |t#1| (-607 $)))) (-15 -2317 ((-1113 |t#1| (-607 $)) $)) (-15 -1332 ($ $)) (-15 -3751 ((-3 (-2 (|:| |var| (-607 $)) (|:| -3438 (-568))) "failed") $ (-123))) (-15 -3751 ((-3 (-2 (|:| |var| (-607 $)) (|:| -3438 (-568))) "failed") $ (-1161))) (-15 -2672 ((-3 (-2 (|:| |val| $) (|:| -3438 (-568))) "failed") $)) (-15 -1339 ($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ $)))) (-15 -1339 ($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ (-634 $))))) (-15 -1339 ($ $ (-1161) (-763) (-1 $ (-634 $)))) (-15 -1339 ($ $ (-1161) (-763) (-1 $ $)))) |noBranch|) (IF (|has| |t#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |t#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |t#1| (-172)) (-6 (-43 |t#1|)) |noBranch|) (IF (|has| |t#1| (-558)) (PROGN (-6 (-365)) (-6 (-1037 (-409 (-953 |t#1|)))) (-15 -4278 ($ (-420 $))) (-15 -2324 ((-1113 |t#1| (-607 $)) $)) (-15 -3013 ($ $)) (-15 -1779 ($ (-1113 |t#1| (-607 $)) (-1113 |t#1| (-607 $)))) (-15 -2745 ($ (-409 |t#1|))) (-15 -2745 ($ (-953 (-409 |t#1|)))) (-15 -2745 ($ (-409 (-953 (-409 |t#1|))))) (-15 -3839 ((-409 (-1157 $)) $ (-607 $))) (IF (|has| |t#1| (-1037 (-568))) (-6 (-1037 (-409 (-568)))) |noBranch|)) |noBranch|))) 
-(((-21) -2198 (|has| |#1| (-1047)) (|has| |#1| (-558)) (|has| |#1| (-172)) (|has| |#1| (-150)) (|has| |#1| (-148)) (|has| |#1| (-21))) ((-23) -2198 (|has| |#1| (-1047)) (|has| |#1| (-558)) (|has| |#1| (-172)) (|has| |#1| (-150)) (|has| |#1| (-148)) (|has| |#1| (-25)) (|has| |#1| (-21))) ((-25) -2198 (|has| |#1| (-1047)) (|has| |#1| (-558)) (|has| |#1| (-172)) (|has| |#1| (-150)) (|has| |#1| (-148)) (|has| |#1| (-25)) (|has| |#1| (-21))) ((-43 (-409 (-568))) |has| |#1| (-558)) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) |has| |#1| (-558)) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-558)) ((-120 |#1| |#1|) |has| |#1| (-172)) ((-120 $ $) |has| |#1| (-558)) ((-137) -2198 (|has| |#1| (-1047)) (|has| |#1| (-558)) (|has| |#1| (-172)) (|has| |#1| (-150)) (|has| |#1| (-148)) (|has| |#1| (-21))) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) |has| |#1| (-558)) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-609 (-887 (-381))) |has| |#1| (-609 (-887 (-381)))) ((-609 (-887 (-568))) |has| |#1| (-609 (-887 (-568)))) ((-238) |has| |#1| (-558)) ((-285) |has| |#1| (-558)) ((-301) |has| |#1| (-558)) ((-303 $) . T) ((-296) . T) ((-365) |has| |#1| (-558)) ((-379 |#1|) |has| |#1| (-1047)) ((-402 |#1|) . T) ((-413 |#1|) . T) ((-453) |has| |#1| (-558)) ((-478) |has| |#1| (-478)) ((-523 (-607 $) $) . T) ((-523 $ $) . T) ((-558) |has| |#1| (-558)) ((-637 (-409 (-568))) |has| |#1| (-558)) ((-637 |#1|) |has| |#1| (-172)) ((-637 $) -2198 (|has| |#1| (-1047)) (|has| |#1| (-558)) (|has| |#1| (-172)) (|has| |#1| (-150)) (|has| |#1| (-148))) ((-630 (-568)) -12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))) ((-630 |#1|) |has| |#1| (-1047)) ((-707 (-409 (-568))) |has| |#1| (-558)) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) |has| |#1| (-558)) ((-716) -2198 (|has| |#1| (-1102)) (|has| |#1| (-1047)) (|has| |#1| (-558)) (|has| |#1| (-478)) (|has| |#1| (-172)) (|has| |#1| (-150)) (|has| |#1| (-148))) ((-842) . T) ((-895 (-1161)) |has| |#1| (-1047)) ((-881 (-381)) |has| |#1| (-881 (-381))) ((-881 (-568)) |has| |#1| (-881 (-568))) ((-879 |#1|) . T) ((-916) |has| |#1| (-558)) ((-1037 (-409 (-568))) -2198 (|has| |#1| (-1037 (-409 (-568)))) (-12 (|has| |#1| (-558)) (|has| |#1| (-1037 (-568))))) ((-1037 (-409 (-953 |#1|))) |has| |#1| (-558)) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 (-607 $)) . T) ((-1037 (-953 |#1|)) |has| |#1| (-1047)) ((-1037 (-1161)) . T) ((-1037 |#1|) . T) ((-1053 (-409 (-568))) |has| |#1| (-558)) ((-1053 |#1|) |has| |#1| (-172)) ((-1053 $) |has| |#1| (-558)) ((-1047) -2198 (|has| |#1| (-1047)) (|has| |#1| (-558)) (|has| |#1| (-172)) (|has| |#1| (-150)) (|has| |#1| (-148))) ((-1054) -2198 (|has| |#1| (-1047)) (|has| |#1| (-558)) (|has| |#1| (-172)) (|has| |#1| (-150)) (|has| |#1| (-148))) ((-1102) -2198 (|has| |#1| (-1102)) (|has| |#1| (-1047)) (|has| |#1| (-558)) (|has| |#1| (-478)) (|has| |#1| (-172)) (|has| |#1| (-150)) (|has| |#1| (-148))) ((-1090) . T) ((-1195) . T) ((-1199) |has| |#1| (-558))) 
-((-1303 ((|#2| |#2| |#2|) 33)) (-3488 (((-123) (-123)) 44)) (-4221 ((|#2| (-634 |#2|)) 79)) (-3162 ((|#2| |#2|) 77)) (-2303 ((|#2| |#2|) 68)) (-2815 ((|#2| |#2|) 71)) (-1324 ((|#2| (-634 |#2|)) 75)) (-3323 ((|#2| (-634 |#2|)) 83)) (-3603 ((|#2| (-634 |#2|)) 87)) (-2631 ((|#2| (-634 |#2|)) 81)) (-1711 ((|#2| (-634 |#2|)) 85)) (-2163 ((|#2| |#2|) 91)) (-2797 ((|#2| |#2|) 89)) (-1847 ((|#2| |#2|) 32)) (-3657 ((|#2| |#2| |#2|) 35)) (-2375 ((|#2| |#2| |#2|) 37)) (-1369 ((|#2| |#2| |#2|) 34)) (-3737 ((|#2| |#2| |#2|) 36)) (-2887 (((-121) (-123)) 42)) (-3828 ((|#2| |#2|) 39)) (-2357 ((|#2| |#2|) 38)) (-2897 ((|#2| |#2|) 27)) (-3929 ((|#2| |#2| |#2|) 30) ((|#2| |#2|) 28)) (-3792 ((|#2| |#2| |#2|) 31))) 
-(((-433 |#1| |#2|) (-10 -7 (-15 -2887 ((-121) (-123))) (-15 -3488 ((-123) (-123))) (-15 -2897 (|#2| |#2|)) (-15 -3929 (|#2| |#2|)) (-15 -3929 (|#2| |#2| |#2|)) (-15 -3792 (|#2| |#2| |#2|)) (-15 -1847 (|#2| |#2|)) (-15 -1303 (|#2| |#2| |#2|)) (-15 -1369 (|#2| |#2| |#2|)) (-15 -3657 (|#2| |#2| |#2|)) (-15 -3737 (|#2| |#2| |#2|)) (-15 -2375 (|#2| |#2| |#2|)) (-15 -2357 (|#2| |#2|)) (-15 -3828 (|#2| |#2|)) (-15 -2815 (|#2| |#2|)) (-15 -2303 (|#2| |#2|)) (-15 -1324 (|#2| (-634 |#2|))) (-15 -3162 (|#2| |#2|)) (-15 -4221 (|#2| (-634 |#2|))) (-15 -2631 (|#2| (-634 |#2|))) (-15 -3323 (|#2| (-634 |#2|))) (-15 -1711 (|#2| (-634 |#2|))) (-15 -3603 (|#2| (-634 |#2|))) (-15 -2797 (|#2| |#2|)) (-15 -2163 (|#2| |#2|))) (-13 (-842) (-558)) (-432 |#1|)) (T -433)) 
-((-2163 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-2797 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-3603 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-1711 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-3323 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-2631 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-4221 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-3162 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-1324 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-2303 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-2815 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-3828 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-2357 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-2375 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-3737 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-3657 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-1369 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-1303 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-1847 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-3792 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-3929 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-3929 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-2897 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-3488 (*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *4)) (-4 *4 (-432 *3)))) (-2887 (*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-433 *4 *5)) (-4 *5 (-432 *4))))) 
-(-10 -7 (-15 -2887 ((-121) (-123))) (-15 -3488 ((-123) (-123))) (-15 -2897 (|#2| |#2|)) (-15 -3929 (|#2| |#2|)) (-15 -3929 (|#2| |#2| |#2|)) (-15 -3792 (|#2| |#2| |#2|)) (-15 -1847 (|#2| |#2|)) (-15 -1303 (|#2| |#2| |#2|)) (-15 -1369 (|#2| |#2| |#2|)) (-15 -3657 (|#2| |#2| |#2|)) (-15 -3737 (|#2| |#2| |#2|)) (-15 -2375 (|#2| |#2| |#2|)) (-15 -2357 (|#2| |#2|)) (-15 -3828 (|#2| |#2|)) (-15 -2815 (|#2| |#2|)) (-15 -2303 (|#2| |#2|)) (-15 -1324 (|#2| (-634 |#2|))) (-15 -3162 (|#2| |#2|)) (-15 -4221 (|#2| (-634 |#2|))) (-15 -2631 (|#2| (-634 |#2|))) (-15 -3323 (|#2| (-634 |#2|))) (-15 -1711 (|#2| (-634 |#2|))) (-15 -3603 (|#2| (-634 |#2|))) (-15 -2797 (|#2| |#2|)) (-15 -2163 (|#2| |#2|))) 
-((-4220 (((-2 (|:| |primelt| |#2|) (|:| |pol1| (-1157 |#2|)) (|:| |pol2| (-1157 |#2|)) (|:| |prim| (-1157 |#2|))) |#2| |#2|) 93 (|has| |#2| (-27))) (((-2 (|:| |primelt| |#2|) (|:| |poly| (-634 (-1157 |#2|))) (|:| |prim| (-1157 |#2|))) (-634 |#2|)) 58))) 
-(((-434 |#1| |#2|) (-10 -7 (-15 -4220 ((-2 (|:| |primelt| |#2|) (|:| |poly| (-634 (-1157 |#2|))) (|:| |prim| (-1157 |#2|))) (-634 |#2|))) (IF (|has| |#2| (-27)) (-15 -4220 ((-2 (|:| |primelt| |#2|) (|:| |pol1| (-1157 |#2|)) (|:| |pol2| (-1157 |#2|)) (|:| |prim| (-1157 |#2|))) |#2| |#2|)) |noBranch|)) (-13 (-558) (-842) (-150)) (-432 |#1|)) (T -434)) 
-((-4220 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-558) (-842) (-150))) (-5 *2 (-2 (|:| |primelt| *3) (|:| |pol1| (-1157 *3)) (|:| |pol2| (-1157 *3)) (|:| |prim| (-1157 *3)))) (-5 *1 (-434 *4 *3)) (-4 *3 (-27)) (-4 *3 (-432 *4)))) (-4220 (*1 *2 *3) (-12 (-5 *3 (-634 *5)) (-4 *5 (-432 *4)) (-4 *4 (-13 (-558) (-842) (-150))) (-5 *2 (-2 (|:| |primelt| *5) (|:| |poly| (-634 (-1157 *5))) (|:| |prim| (-1157 *5)))) (-5 *1 (-434 *4 *5))))) 
-(-10 -7 (-15 -4220 ((-2 (|:| |primelt| |#2|) (|:| |poly| (-634 (-1157 |#2|))) (|:| |prim| (-1157 |#2|))) (-634 |#2|))) (IF (|has| |#2| (-27)) (-15 -4220 ((-2 (|:| |primelt| |#2|) (|:| |pol1| (-1157 |#2|)) (|:| |pol2| (-1157 |#2|)) (|:| |prim| (-1157 |#2|))) |#2| |#2|)) |noBranch|)) 
-((-1544 (((-1249)) 18)) (-4267 (((-1157 (-409 (-568))) |#2| (-607 |#2|)) 40) (((-409 (-568)) |#2|) 23))) 
-(((-435 |#1| |#2|) (-10 -7 (-15 -4267 ((-409 (-568)) |#2|)) (-15 -4267 ((-1157 (-409 (-568))) |#2| (-607 |#2|))) (-15 -1544 ((-1249)))) (-13 (-842) (-558) (-1037 (-568))) (-432 |#1|)) (T -435)) 
-((-1544 (*1 *2) (-12 (-4 *3 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-1249)) (-5 *1 (-435 *3 *4)) (-4 *4 (-432 *3)))) (-4267 (*1 *2 *3 *4) (-12 (-5 *4 (-607 *3)) (-4 *3 (-432 *5)) (-4 *5 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-1157 (-409 (-568)))) (-5 *1 (-435 *5 *3)))) (-4267 (*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-409 (-568))) (-5 *1 (-435 *4 *3)) (-4 *3 (-432 *4))))) 
-(-10 -7 (-15 -4267 ((-409 (-568)) |#2|)) (-15 -4267 ((-1157 (-409 (-568))) |#2| (-607 |#2|))) (-15 -1544 ((-1249)))) 
-((-2636 (((-121) $) 28)) (-2383 (((-121) $) 30)) (-4469 (((-121) $) 31)) (-2645 (((-121) $) 34)) (-2310 (((-121) $) 29)) (-3319 (((-121) $) 33)) (-2745 (((-850) $) 18) (($ (-1143)) 27) (($ (-1161)) 23) (((-1161) $) 22) (((-1094) $) 21)) (-3597 (((-121) $) 32)) (-1717 (((-121) $ $) 15))) 
-(((-436) (-13 (-608 (-850)) (-10 -8 (-15 -2745 ($ (-1143))) (-15 -2745 ($ (-1161))) (-15 -2745 ((-1161) $)) (-15 -2745 ((-1094) $)) (-15 -2636 ((-121) $)) (-15 -2310 ((-121) $)) (-15 -4469 ((-121) $)) (-15 -3319 ((-121) $)) (-15 -2645 ((-121) $)) (-15 -3597 ((-121) $)) (-15 -2383 ((-121) $)) (-15 -1717 ((-121) $ $))))) (T -436)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-436)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-436)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-436)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-1094)) (-5 *1 (-436)))) (-2636 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436)))) (-2310 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436)))) (-4469 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436)))) (-3319 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436)))) (-2645 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436)))) (-3597 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436)))) (-2383 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436)))) (-1717 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436))))) 
-(-13 (-608 (-850)) (-10 -8 (-15 -2745 ($ (-1143))) (-15 -2745 ($ (-1161))) (-15 -2745 ((-1161) $)) (-15 -2745 ((-1094) $)) (-15 -2636 ((-121) $)) (-15 -2310 ((-121) $)) (-15 -4469 ((-121) $)) (-15 -3319 ((-121) $)) (-15 -2645 ((-121) $)) (-15 -3597 ((-121) $)) (-15 -2383 ((-121) $)) (-15 -1717 ((-121) $ $)))) 
-((-3025 (((-3 (-420 (-1157 (-409 (-568)))) "failed") |#3|) 68)) (-1992 (((-420 |#3|) |#3|) 33)) (-3332 (((-3 (-420 (-1157 (-53))) "failed") |#3|) 27 (|has| |#2| (-1037 (-53))))) (-2499 (((-3 (|:| |overq| (-1157 (-409 (-568)))) (|:| |overan| (-1157 (-53))) (|:| -3483 (-121))) |#3|) 35))) 
-(((-437 |#1| |#2| |#3|) (-10 -7 (-15 -1992 ((-420 |#3|) |#3|)) (-15 -3025 ((-3 (-420 (-1157 (-409 (-568)))) "failed") |#3|)) (-15 -2499 ((-3 (|:| |overq| (-1157 (-409 (-568)))) (|:| |overan| (-1157 (-53))) (|:| -3483 (-121))) |#3|)) (IF (|has| |#2| (-1037 (-53))) (-15 -3332 ((-3 (-420 (-1157 (-53))) "failed") |#3|)) |noBranch|)) (-13 (-558) (-842) (-1037 (-568))) (-432 |#1|) (-1219 |#2|)) (T -437)) 
-((-3332 (*1 *2 *3) (|partial| -12 (-4 *5 (-1037 (-53))) (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-4 *5 (-432 *4)) (-5 *2 (-420 (-1157 (-53)))) (-5 *1 (-437 *4 *5 *3)) (-4 *3 (-1219 *5)))) (-2499 (*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-4 *5 (-432 *4)) (-5 *2 (-3 (|:| |overq| (-1157 (-409 (-568)))) (|:| |overan| (-1157 (-53))) (|:| -3483 (-121)))) (-5 *1 (-437 *4 *5 *3)) (-4 *3 (-1219 *5)))) (-3025 (*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-4 *5 (-432 *4)) (-5 *2 (-420 (-1157 (-409 (-568))))) (-5 *1 (-437 *4 *5 *3)) (-4 *3 (-1219 *5)))) (-1992 (*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-4 *5 (-432 *4)) (-5 *2 (-420 *3)) (-5 *1 (-437 *4 *5 *3)) (-4 *3 (-1219 *5))))) 
-(-10 -7 (-15 -1992 ((-420 |#3|) |#3|)) (-15 -3025 ((-3 (-420 (-1157 (-409 (-568)))) "failed") |#3|)) (-15 -2499 ((-3 (|:| |overq| (-1157 (-409 (-568)))) (|:| |overan| (-1157 (-53))) (|:| -3483 (-121))) |#3|)) (IF (|has| |#2| (-1037 (-53))) (-15 -3332 ((-3 (-420 (-1157 (-53))) "failed") |#3|)) |noBranch|)) 
-((-2447 (((-121) $ $) NIL)) (-1705 (((-1143) $ (-1143)) NIL)) (-2511 (($ $ (-1143)) NIL)) (-3327 (((-1143) $) NIL)) (-3704 (((-390) (-390) (-390)) 17) (((-390) (-390)) 15)) (-1798 (($ (-390)) NIL) (($ (-390) (-1143)) NIL)) (-3391 (((-390) $) NIL)) (-4487 (((-1143) $) NIL)) (-3305 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-3538 (((-1249) (-1143)) 9)) (-3318 (((-1249) (-1143)) 10)) (-2161 (((-1249)) 11)) (-4169 (((-1249) $) NIL)) (-2745 (((-850) $) NIL)) (-3637 (($ $) 34)) (-1717 (((-121) $ $) NIL))) 
-(((-438) (-13 (-366 (-390) (-1143)) (-10 -7 (-15 -3704 ((-390) (-390) (-390))) (-15 -3704 ((-390) (-390))) (-15 -3538 ((-1249) (-1143))) (-15 -3318 ((-1249) (-1143))) (-15 -2161 ((-1249)))))) (T -438)) 
-((-3704 (*1 *2 *2 *2) (-12 (-5 *2 (-390)) (-5 *1 (-438)))) (-3704 (*1 *2 *2) (-12 (-5 *2 (-390)) (-5 *1 (-438)))) (-3538 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-438)))) (-3318 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-438)))) (-2161 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-438))))) 
-(-13 (-366 (-390) (-1143)) (-10 -7 (-15 -3704 ((-390) (-390) (-390))) (-15 -3704 ((-390) (-390))) (-15 -3538 ((-1249) (-1143))) (-15 -3318 ((-1249) (-1143))) (-15 -2161 ((-1249))))) 
-((-2447 (((-121) $ $) NIL)) (-3918 (((-3 (|:| |fst| (-436)) (|:| -3611 "void")) $) 10)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2337 (($) 31)) (-1360 (($) 37)) (-1380 (($) 33)) (-2851 (($) 35)) (-3892 (($) 32)) (-4101 (($) 34)) (-1922 (($) 36)) (-2753 (((-121) $) 8)) (-3273 (((-634 (-953 (-568))) $) 16)) (-4287 (($ (-3 (|:| |fst| (-436)) (|:| -3611 "void")) (-634 (-1161)) (-121)) 25) (($ (-3 (|:| |fst| (-436)) (|:| -3611 "void")) (-634 (-953 (-568))) (-121)) 26)) (-2745 (((-850) $) 21) (($ (-436)) 28)) (-1717 (((-121) $ $) NIL))) 
-(((-439) (-13 (-1090) (-10 -8 (-15 -2745 ((-850) $)) (-15 -2745 ($ (-436))) (-15 -3918 ((-3 (|:| |fst| (-436)) (|:| -3611 "void")) $)) (-15 -3273 ((-634 (-953 (-568))) $)) (-15 -2753 ((-121) $)) (-15 -4287 ($ (-3 (|:| |fst| (-436)) (|:| -3611 "void")) (-634 (-1161)) (-121))) (-15 -4287 ($ (-3 (|:| |fst| (-436)) (|:| -3611 "void")) (-634 (-953 (-568))) (-121))) (-15 -2337 ($)) (-15 -3892 ($)) (-15 -1380 ($)) (-15 -1360 ($)) (-15 -4101 ($)) (-15 -2851 ($)) (-15 -1922 ($))))) (T -439)) 
-((-2745 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-439)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-436)) (-5 *1 (-439)))) (-3918 (*1 *2 *1) (-12 (-5 *2 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-5 *1 (-439)))) (-3273 (*1 *2 *1) (-12 (-5 *2 (-634 (-953 (-568)))) (-5 *1 (-439)))) (-2753 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-439)))) (-4287 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-5 *3 (-634 (-1161))) (-5 *4 (-121)) (-5 *1 (-439)))) (-4287 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-121)) (-5 *1 (-439)))) (-2337 (*1 *1) (-5 *1 (-439))) (-3892 (*1 *1) (-5 *1 (-439))) (-1380 (*1 *1) (-5 *1 (-439))) (-1360 (*1 *1) (-5 *1 (-439))) (-4101 (*1 *1) (-5 *1 (-439))) (-2851 (*1 *1) (-5 *1 (-439))) (-1922 (*1 *1) (-5 *1 (-439)))) 
-(-13 (-1090) (-10 -8 (-15 -2745 ((-850) $)) (-15 -2745 ($ (-436))) (-15 -3918 ((-3 (|:| |fst| (-436)) (|:| -3611 "void")) $)) (-15 -3273 ((-634 (-953 (-568))) $)) (-15 -2753 ((-121) $)) (-15 -4287 ($ (-3 (|:| |fst| (-436)) (|:| -3611 "void")) (-634 (-1161)) (-121))) (-15 -4287 ($ (-3 (|:| |fst| (-436)) (|:| -3611 "void")) (-634 (-953 (-568))) (-121))) (-15 -2337 ($)) (-15 -3892 ($)) (-15 -1380 ($)) (-15 -1360 ($)) (-15 -4101 ($)) (-15 -2851 ($)) (-15 -1922 ($)))) 
-((-2447 (((-121) $ $) NIL)) (-3391 (((-1161) $) 8)) (-4487 (((-1143) $) 16)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 11)) (-1717 (((-121) $ $) 13))) 
-(((-440 |#1|) (-13 (-1090) (-10 -8 (-15 -3391 ((-1161) $)))) (-1161)) (T -440)) 
-((-3391 (*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-440 *3)) (-14 *3 *2)))) 
-(-13 (-1090) (-10 -8 (-15 -3391 ((-1161) $)))) 
-((-4128 (((-1249) $) 7)) (-2745 (((-850) $) 8) (($ (-1244 (-688))) 12) (($ (-634 (-328))) 11) (($ (-328)) 10) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 9))) 
+((-2088 (*1 *2 *1) (-12 (-4 *1 (-432 *3)) (-4 *3 (-842)) (-5 *2 (-121)))) (-2093 (*1 *2 *1) (-12 (-4 *1 (-432 *2)) (-4 *2 (-842)))) (-2057 (*1 *2 *1) (-12 (-4 *1 (-432 *3)) (-4 *3 (-842)) (-5 *2 (-634 (-1161))))) (-3060 (*1 *1 *2 *1) (-12 (-5 *2 (-1161)) (-4 *1 (-432 *3)) (-4 *3 (-842)))) (-3060 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1161)) (-4 *1 (-432 *3)) (-4 *3 (-842)))) (-3060 (*1 *1 *2 *1 *1 *1) (-12 (-5 *2 (-1161)) (-4 *1 (-432 *3)) (-4 *3 (-842)))) (-3060 (*1 *1 *2 *1 *1 *1 *1) (-12 (-5 *2 (-1161)) (-4 *1 (-432 *3)) (-4 *3 (-842)))) (-3060 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-634 *1)) (-4 *1 (-432 *4)) (-4 *4 (-842)))) (-1339 (*1 *1 *1 *2) (-12 (-5 *2 (-1161)) (-4 *1 (-432 *3)) (-4 *3 (-842)) (-4 *3 (-609 (-541))))) (-1339 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-1161))) (-4 *1 (-432 *3)) (-4 *3 (-842)) (-4 *3 (-609 (-541))))) (-1339 (*1 *1 *1) (-12 (-4 *1 (-432 *2)) (-4 *2 (-842)) (-4 *2 (-609 (-541))))) (-1339 (*1 *1 *1 *2 *1 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1161)) (-4 *1 (-432 *4)) (-4 *4 (-842)) (-4 *4 (-609 (-541))))) (-1339 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-634 (-123))) (-5 *3 (-634 *1)) (-5 *4 (-1161)) (-4 *1 (-432 *5)) (-4 *5 (-842)) (-4 *5 (-609 (-541))))) (-4362 (*1 *2 *1) (|partial| -12 (-4 *3 (-1102)) (-4 *3 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-432 *3)))) (-2617 (*1 *2 *1) (|partial| -12 (-4 *3 (-1102)) (-4 *3 (-842)) (-5 *2 (-2 (|:| |var| (-607 *1)) (|:| -3483 (-568)))) (-4 *1 (-432 *3)))) (-2112 (*1 *2 *1) (|partial| -12 (-4 *3 (-25)) (-4 *3 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-432 *3)))) (-2240 (*1 *2 *1) (|partial| -12 (-4 *3 (-25)) (-4 *3 (-842)) (-5 *2 (-2 (|:| -2350 (-568)) (|:| |var| (-607 *1)))) (-4 *1 (-432 *3)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-1113 *3 (-607 *1))) (-4 *3 (-1047)) (-4 *3 (-842)) (-4 *1 (-432 *3)))) (-2319 (*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *3 (-842)) (-5 *2 (-1113 *3 (-607 *1))) (-4 *1 (-432 *3)))) (-3539 (*1 *1 *1) (-12 (-4 *1 (-432 *2)) (-4 *2 (-842)) (-4 *2 (-1047)))) (-2617 (*1 *2 *1 *3) (|partial| -12 (-5 *3 (-123)) (-4 *4 (-1047)) (-4 *4 (-842)) (-5 *2 (-2 (|:| |var| (-607 *1)) (|:| -3483 (-568)))) (-4 *1 (-432 *4)))) (-2617 (*1 *2 *1 *3) (|partial| -12 (-5 *3 (-1161)) (-4 *4 (-1047)) (-4 *4 (-842)) (-5 *2 (-2 (|:| |var| (-607 *1)) (|:| -3483 (-568)))) (-4 *1 (-432 *4)))) (-4495 (*1 *2 *1) (|partial| -12 (-4 *3 (-1047)) (-4 *3 (-842)) (-5 *2 (-2 (|:| |val| *1) (|:| -3483 (-568)))) (-4 *1 (-432 *3)))) (-1339 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-634 (-763))) (-5 *4 (-634 (-1 *1 *1))) (-4 *1 (-432 *5)) (-4 *5 (-842)) (-4 *5 (-1047)))) (-1339 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-634 (-763))) (-5 *4 (-634 (-1 *1 (-634 *1)))) (-4 *1 (-432 *5)) (-4 *5 (-842)) (-4 *5 (-1047)))) (-1339 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-763)) (-5 *4 (-1 *1 (-634 *1))) (-4 *1 (-432 *5)) (-4 *5 (-842)) (-4 *5 (-1047)))) (-1339 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-763)) (-5 *4 (-1 *1 *1)) (-4 *1 (-432 *5)) (-4 *5 (-842)) (-4 *5 (-1047)))) (-4280 (*1 *1 *2) (-12 (-5 *2 (-420 *1)) (-4 *1 (-432 *3)) (-4 *3 (-558)) (-4 *3 (-842)))) (-2326 (*1 *2 *1) (-12 (-4 *3 (-558)) (-4 *3 (-842)) (-5 *2 (-1113 *3 (-607 *1))) (-4 *1 (-432 *3)))) (-3210 (*1 *1 *1) (-12 (-4 *1 (-432 *2)) (-4 *2 (-842)) (-4 *2 (-558)))) (-1781 (*1 *1 *2 *2) (-12 (-5 *2 (-1113 *3 (-607 *1))) (-4 *3 (-558)) (-4 *3 (-842)) (-4 *1 (-432 *3)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-409 *3)) (-4 *3 (-558)) (-4 *3 (-842)) (-4 *1 (-432 *3)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-953 (-409 *3))) (-4 *3 (-558)) (-4 *3 (-842)) (-4 *1 (-432 *3)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-409 (-953 (-409 *3)))) (-4 *3 (-558)) (-4 *3 (-842)) (-4 *1 (-432 *3)))) (-3840 (*1 *2 *1 *3) (-12 (-5 *3 (-607 *1)) (-4 *1 (-432 *4)) (-4 *4 (-842)) (-4 *4 (-558)) (-5 *2 (-409 (-1157 *1))))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-432 *3)) (-4 *3 (-842)) (-4 *3 (-1102))))) 
+(-13 (-296) (-1037 (-1161)) (-879 |t#1|) (-402 |t#1|) (-413 |t#1|) (-10 -8 (-15 -2088 ((-121) $)) (-15 -2093 (|t#1| $)) (-15 -2057 ((-634 (-1161)) $)) (-15 -3060 ($ (-1161) $)) (-15 -3060 ($ (-1161) $ $)) (-15 -3060 ($ (-1161) $ $ $)) (-15 -3060 ($ (-1161) $ $ $ $)) (-15 -3060 ($ (-1161) (-634 $))) (IF (|has| |t#1| (-609 (-541))) (PROGN (-6 (-609 (-541))) (-15 -1339 ($ $ (-1161))) (-15 -1339 ($ $ (-634 (-1161)))) (-15 -1339 ($ $)) (-15 -1339 ($ $ (-123) $ (-1161))) (-15 -1339 ($ $ (-634 (-123)) (-634 $) (-1161)))) |noBranch|) (IF (|has| |t#1| (-1102)) (PROGN (-6 (-716)) (-15 ** ($ $ (-763))) (-15 -4362 ((-3 (-634 $) "failed") $)) (-15 -2617 ((-3 (-2 (|:| |var| (-607 $)) (|:| -3483 (-568))) "failed") $))) |noBranch|) (IF (|has| |t#1| (-478)) (-6 (-478)) |noBranch|) (IF (|has| |t#1| (-25)) (PROGN (-6 (-23)) (-15 -2112 ((-3 (-634 $) "failed") $)) (-15 -2240 ((-3 (-2 (|:| -2350 (-568)) (|:| |var| (-607 $))) "failed") $))) |noBranch|) (IF (|has| |t#1| (-21)) (-6 (-21)) |noBranch|) (IF (|has| |t#1| (-1047)) (PROGN (-6 (-1047)) (-6 (-1037 (-953 |t#1|))) (-6 (-895 (-1161))) (-6 (-379 |t#1|)) (-15 -2747 ($ (-1113 |t#1| (-607 $)))) (-15 -2319 ((-1113 |t#1| (-607 $)) $)) (-15 -3539 ($ $)) (-15 -2617 ((-3 (-2 (|:| |var| (-607 $)) (|:| -3483 (-568))) "failed") $ (-123))) (-15 -2617 ((-3 (-2 (|:| |var| (-607 $)) (|:| -3483 (-568))) "failed") $ (-1161))) (-15 -4495 ((-3 (-2 (|:| |val| $) (|:| -3483 (-568))) "failed") $)) (-15 -1339 ($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ $)))) (-15 -1339 ($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ (-634 $))))) (-15 -1339 ($ $ (-1161) (-763) (-1 $ (-634 $)))) (-15 -1339 ($ $ (-1161) (-763) (-1 $ $)))) |noBranch|) (IF (|has| |t#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |t#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |t#1| (-172)) (-6 (-43 |t#1|)) |noBranch|) (IF (|has| |t#1| (-558)) (PROGN (-6 (-365)) (-6 (-1037 (-409 (-953 |t#1|)))) (-15 -4280 ($ (-420 $))) (-15 -2326 ((-1113 |t#1| (-607 $)) $)) (-15 -3210 ($ $)) (-15 -1781 ($ (-1113 |t#1| (-607 $)) (-1113 |t#1| (-607 $)))) (-15 -2747 ($ (-409 |t#1|))) (-15 -2747 ($ (-953 (-409 |t#1|)))) (-15 -2747 ($ (-409 (-953 (-409 |t#1|))))) (-15 -3840 ((-409 (-1157 $)) $ (-607 $))) (IF (|has| |t#1| (-1037 (-568))) (-6 (-1037 (-409 (-568)))) |noBranch|)) |noBranch|))) 
+(((-21) -2199 (|has| |#1| (-1047)) (|has| |#1| (-558)) (|has| |#1| (-172)) (|has| |#1| (-150)) (|has| |#1| (-148)) (|has| |#1| (-21))) ((-23) -2199 (|has| |#1| (-1047)) (|has| |#1| (-558)) (|has| |#1| (-172)) (|has| |#1| (-150)) (|has| |#1| (-148)) (|has| |#1| (-25)) (|has| |#1| (-21))) ((-25) -2199 (|has| |#1| (-1047)) (|has| |#1| (-558)) (|has| |#1| (-172)) (|has| |#1| (-150)) (|has| |#1| (-148)) (|has| |#1| (-25)) (|has| |#1| (-21))) ((-43 (-409 (-568))) |has| |#1| (-558)) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) |has| |#1| (-558)) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-558)) ((-120 |#1| |#1|) |has| |#1| (-172)) ((-120 $ $) |has| |#1| (-558)) ((-137) -2199 (|has| |#1| (-1047)) (|has| |#1| (-558)) (|has| |#1| (-172)) (|has| |#1| (-150)) (|has| |#1| (-148)) (|has| |#1| (-21))) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) |has| |#1| (-558)) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-609 (-887 (-381))) |has| |#1| (-609 (-887 (-381)))) ((-609 (-887 (-568))) |has| |#1| (-609 (-887 (-568)))) ((-238) |has| |#1| (-558)) ((-285) |has| |#1| (-558)) ((-301) |has| |#1| (-558)) ((-303 $) . T) ((-296) . T) ((-365) |has| |#1| (-558)) ((-379 |#1|) |has| |#1| (-1047)) ((-402 |#1|) . T) ((-413 |#1|) . T) ((-453) |has| |#1| (-558)) ((-478) |has| |#1| (-478)) ((-523 (-607 $) $) . T) ((-523 $ $) . T) ((-558) |has| |#1| (-558)) ((-637 (-409 (-568))) |has| |#1| (-558)) ((-637 |#1|) |has| |#1| (-172)) ((-637 $) -2199 (|has| |#1| (-1047)) (|has| |#1| (-558)) (|has| |#1| (-172)) (|has| |#1| (-150)) (|has| |#1| (-148))) ((-630 (-568)) -12 (|has| |#1| (-630 (-568))) (|has| |#1| (-1047))) ((-630 |#1|) |has| |#1| (-1047)) ((-707 (-409 (-568))) |has| |#1| (-558)) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) |has| |#1| (-558)) ((-716) -2199 (|has| |#1| (-1102)) (|has| |#1| (-1047)) (|has| |#1| (-558)) (|has| |#1| (-478)) (|has| |#1| (-172)) (|has| |#1| (-150)) (|has| |#1| (-148))) ((-842) . T) ((-895 (-1161)) |has| |#1| (-1047)) ((-881 (-381)) |has| |#1| (-881 (-381))) ((-881 (-568)) |has| |#1| (-881 (-568))) ((-879 |#1|) . T) ((-916) |has| |#1| (-558)) ((-1037 (-409 (-568))) -2199 (|has| |#1| (-1037 (-409 (-568)))) (-12 (|has| |#1| (-558)) (|has| |#1| (-1037 (-568))))) ((-1037 (-409 (-953 |#1|))) |has| |#1| (-558)) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 (-607 $)) . T) ((-1037 (-953 |#1|)) |has| |#1| (-1047)) ((-1037 (-1161)) . T) ((-1037 |#1|) . T) ((-1053 (-409 (-568))) |has| |#1| (-558)) ((-1053 |#1|) |has| |#1| (-172)) ((-1053 $) |has| |#1| (-558)) ((-1047) -2199 (|has| |#1| (-1047)) (|has| |#1| (-558)) (|has| |#1| (-172)) (|has| |#1| (-150)) (|has| |#1| (-148))) ((-1054) -2199 (|has| |#1| (-1047)) (|has| |#1| (-558)) (|has| |#1| (-172)) (|has| |#1| (-150)) (|has| |#1| (-148))) ((-1102) -2199 (|has| |#1| (-1102)) (|has| |#1| (-1047)) (|has| |#1| (-558)) (|has| |#1| (-478)) (|has| |#1| (-172)) (|has| |#1| (-150)) (|has| |#1| (-148))) ((-1090) . T) ((-1195) . T) ((-1199) |has| |#1| (-558))) 
+((-3311 ((|#2| |#2| |#2|) 33)) (-3842 (((-123) (-123)) 44)) (-4196 ((|#2| (-634 |#2|)) 79)) (-1659 ((|#2| |#2|) 77)) (-3655 ((|#2| |#2|) 68)) (-3742 ((|#2| |#2|) 71)) (-3478 ((|#2| (-634 |#2|)) 75)) (-4355 ((|#2| (-634 |#2|)) 83)) (-3015 ((|#2| (-634 |#2|)) 87)) (-4261 ((|#2| (-634 |#2|)) 81)) (-3660 ((|#2| (-634 |#2|)) 85)) (-3753 ((|#2| |#2|) 91)) (-3627 ((|#2| |#2|) 89)) (-2383 ((|#2| |#2|) 32)) (-3301 ((|#2| |#2| |#2|) 35)) (-2149 ((|#2| |#2| |#2|) 37)) (-3826 ((|#2| |#2| |#2|) 34)) (-2547 ((|#2| |#2| |#2|) 36)) (-2779 (((-121) (-123)) 42)) (-1813 ((|#2| |#2|) 39)) (-4009 ((|#2| |#2|) 38)) (-2811 ((|#2| |#2|) 27)) (-2209 ((|#2| |#2| |#2|) 30) ((|#2| |#2|) 28)) (-2768 ((|#2| |#2| |#2|) 31))) 
+(((-433 |#1| |#2|) (-10 -7 (-15 -2779 ((-121) (-123))) (-15 -3842 ((-123) (-123))) (-15 -2811 (|#2| |#2|)) (-15 -2209 (|#2| |#2|)) (-15 -2209 (|#2| |#2| |#2|)) (-15 -2768 (|#2| |#2| |#2|)) (-15 -2383 (|#2| |#2|)) (-15 -3311 (|#2| |#2| |#2|)) (-15 -3826 (|#2| |#2| |#2|)) (-15 -3301 (|#2| |#2| |#2|)) (-15 -2547 (|#2| |#2| |#2|)) (-15 -2149 (|#2| |#2| |#2|)) (-15 -4009 (|#2| |#2|)) (-15 -1813 (|#2| |#2|)) (-15 -3742 (|#2| |#2|)) (-15 -3655 (|#2| |#2|)) (-15 -3478 (|#2| (-634 |#2|))) (-15 -1659 (|#2| |#2|)) (-15 -4196 (|#2| (-634 |#2|))) (-15 -4261 (|#2| (-634 |#2|))) (-15 -4355 (|#2| (-634 |#2|))) (-15 -3660 (|#2| (-634 |#2|))) (-15 -3015 (|#2| (-634 |#2|))) (-15 -3627 (|#2| |#2|)) (-15 -3753 (|#2| |#2|))) (-13 (-842) (-558)) (-432 |#1|)) (T -433)) 
+((-3753 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-3627 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-3015 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-3660 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-4355 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-4261 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-4196 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-1659 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-3478 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558))))) (-3655 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-3742 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-1813 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-4009 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-2149 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-2547 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-3301 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-3826 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-3311 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-2383 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-2768 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-2209 (*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-2209 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-2811 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) (-3842 (*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *4)) (-4 *4 (-432 *3)))) (-2779 (*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-433 *4 *5)) (-4 *5 (-432 *4))))) 
+(-10 -7 (-15 -2779 ((-121) (-123))) (-15 -3842 ((-123) (-123))) (-15 -2811 (|#2| |#2|)) (-15 -2209 (|#2| |#2|)) (-15 -2209 (|#2| |#2| |#2|)) (-15 -2768 (|#2| |#2| |#2|)) (-15 -2383 (|#2| |#2|)) (-15 -3311 (|#2| |#2| |#2|)) (-15 -3826 (|#2| |#2| |#2|)) (-15 -3301 (|#2| |#2| |#2|)) (-15 -2547 (|#2| |#2| |#2|)) (-15 -2149 (|#2| |#2| |#2|)) (-15 -4009 (|#2| |#2|)) (-15 -1813 (|#2| |#2|)) (-15 -3742 (|#2| |#2|)) (-15 -3655 (|#2| |#2|)) (-15 -3478 (|#2| (-634 |#2|))) (-15 -1659 (|#2| |#2|)) (-15 -4196 (|#2| (-634 |#2|))) (-15 -4261 (|#2| (-634 |#2|))) (-15 -4355 (|#2| (-634 |#2|))) (-15 -3660 (|#2| (-634 |#2|))) (-15 -3015 (|#2| (-634 |#2|))) (-15 -3627 (|#2| |#2|)) (-15 -3753 (|#2| |#2|))) 
+((-4188 (((-2 (|:| |primelt| |#2|) (|:| |pol1| (-1157 |#2|)) (|:| |pol2| (-1157 |#2|)) (|:| |prim| (-1157 |#2|))) |#2| |#2|) 93 (|has| |#2| (-27))) (((-2 (|:| |primelt| |#2|) (|:| |poly| (-634 (-1157 |#2|))) (|:| |prim| (-1157 |#2|))) (-634 |#2|)) 58))) 
+(((-434 |#1| |#2|) (-10 -7 (-15 -4188 ((-2 (|:| |primelt| |#2|) (|:| |poly| (-634 (-1157 |#2|))) (|:| |prim| (-1157 |#2|))) (-634 |#2|))) (IF (|has| |#2| (-27)) (-15 -4188 ((-2 (|:| |primelt| |#2|) (|:| |pol1| (-1157 |#2|)) (|:| |pol2| (-1157 |#2|)) (|:| |prim| (-1157 |#2|))) |#2| |#2|)) |noBranch|)) (-13 (-558) (-842) (-150)) (-432 |#1|)) (T -434)) 
+((-4188 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-558) (-842) (-150))) (-5 *2 (-2 (|:| |primelt| *3) (|:| |pol1| (-1157 *3)) (|:| |pol2| (-1157 *3)) (|:| |prim| (-1157 *3)))) (-5 *1 (-434 *4 *3)) (-4 *3 (-27)) (-4 *3 (-432 *4)))) (-4188 (*1 *2 *3) (-12 (-5 *3 (-634 *5)) (-4 *5 (-432 *4)) (-4 *4 (-13 (-558) (-842) (-150))) (-5 *2 (-2 (|:| |primelt| *5) (|:| |poly| (-634 (-1157 *5))) (|:| |prim| (-1157 *5)))) (-5 *1 (-434 *4 *5))))) 
+(-10 -7 (-15 -4188 ((-2 (|:| |primelt| |#2|) (|:| |poly| (-634 (-1157 |#2|))) (|:| |prim| (-1157 |#2|))) (-634 |#2|))) (IF (|has| |#2| (-27)) (-15 -4188 ((-2 (|:| |primelt| |#2|) (|:| |pol1| (-1157 |#2|)) (|:| |pol2| (-1157 |#2|)) (|:| |prim| (-1157 |#2|))) |#2| |#2|)) |noBranch|)) 
+((-4263 (((-1249)) 18)) (-2917 (((-1157 (-409 (-568))) |#2| (-607 |#2|)) 40) (((-409 (-568)) |#2|) 23))) 
+(((-435 |#1| |#2|) (-10 -7 (-15 -2917 ((-409 (-568)) |#2|)) (-15 -2917 ((-1157 (-409 (-568))) |#2| (-607 |#2|))) (-15 -4263 ((-1249)))) (-13 (-842) (-558) (-1037 (-568))) (-432 |#1|)) (T -435)) 
+((-4263 (*1 *2) (-12 (-4 *3 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-1249)) (-5 *1 (-435 *3 *4)) (-4 *4 (-432 *3)))) (-2917 (*1 *2 *3 *4) (-12 (-5 *4 (-607 *3)) (-4 *3 (-432 *5)) (-4 *5 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-1157 (-409 (-568)))) (-5 *1 (-435 *5 *3)))) (-2917 (*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-409 (-568))) (-5 *1 (-435 *4 *3)) (-4 *3 (-432 *4))))) 
+(-10 -7 (-15 -2917 ((-409 (-568)) |#2|)) (-15 -2917 ((-1157 (-409 (-568))) |#2| (-607 |#2|))) (-15 -4263 ((-1249)))) 
+((-4293 (((-121) $) 28)) (-2189 (((-121) $) 30)) (-1812 (((-121) $) 31)) (-4348 (((-121) $) 34)) (-3713 (((-121) $) 29)) (-4331 (((-121) $) 33)) (-2747 (((-850) $) 18) (($ (-1143)) 27) (($ (-1161)) 23) (((-1161) $) 22) (((-1094) $) 21)) (-2992 (((-121) $) 32)) (-1719 (((-121) $ $) 15))) 
+(((-436) (-13 (-608 (-850)) (-10 -8 (-15 -2747 ($ (-1143))) (-15 -2747 ($ (-1161))) (-15 -2747 ((-1161) $)) (-15 -2747 ((-1094) $)) (-15 -4293 ((-121) $)) (-15 -3713 ((-121) $)) (-15 -1812 ((-121) $)) (-15 -4331 ((-121) $)) (-15 -4348 ((-121) $)) (-15 -2992 ((-121) $)) (-15 -2189 ((-121) $)) (-15 -1719 ((-121) $ $))))) (T -436)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-436)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-436)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-436)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-1094)) (-5 *1 (-436)))) (-4293 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436)))) (-3713 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436)))) (-1812 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436)))) (-4331 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436)))) (-4348 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436)))) (-2992 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436)))) (-2189 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436)))) (-1719 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436))))) 
+(-13 (-608 (-850)) (-10 -8 (-15 -2747 ($ (-1143))) (-15 -2747 ($ (-1161))) (-15 -2747 ((-1161) $)) (-15 -2747 ((-1094) $)) (-15 -4293 ((-121) $)) (-15 -3713 ((-121) $)) (-15 -1812 ((-121) $)) (-15 -4331 ((-121) $)) (-15 -4348 ((-121) $)) (-15 -2992 ((-121) $)) (-15 -2189 ((-121) $)) (-15 -1719 ((-121) $ $)))) 
+((-3282 (((-3 (-420 (-1157 (-409 (-568)))) "failed") |#3|) 68)) (-4459 (((-420 |#3|) |#3|) 33)) (-4408 (((-3 (-420 (-1157 (-53))) "failed") |#3|) 27 (|has| |#2| (-1037 (-53))))) (-1618 (((-3 (|:| |overq| (-1157 (-409 (-568)))) (|:| |overan| (-1157 (-53))) (|:| -3485 (-121))) |#3|) 35))) 
+(((-437 |#1| |#2| |#3|) (-10 -7 (-15 -4459 ((-420 |#3|) |#3|)) (-15 -3282 ((-3 (-420 (-1157 (-409 (-568)))) "failed") |#3|)) (-15 -1618 ((-3 (|:| |overq| (-1157 (-409 (-568)))) (|:| |overan| (-1157 (-53))) (|:| -3485 (-121))) |#3|)) (IF (|has| |#2| (-1037 (-53))) (-15 -4408 ((-3 (-420 (-1157 (-53))) "failed") |#3|)) |noBranch|)) (-13 (-558) (-842) (-1037 (-568))) (-432 |#1|) (-1219 |#2|)) (T -437)) 
+((-4408 (*1 *2 *3) (|partial| -12 (-4 *5 (-1037 (-53))) (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-4 *5 (-432 *4)) (-5 *2 (-420 (-1157 (-53)))) (-5 *1 (-437 *4 *5 *3)) (-4 *3 (-1219 *5)))) (-1618 (*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-4 *5 (-432 *4)) (-5 *2 (-3 (|:| |overq| (-1157 (-409 (-568)))) (|:| |overan| (-1157 (-53))) (|:| -3485 (-121)))) (-5 *1 (-437 *4 *5 *3)) (-4 *3 (-1219 *5)))) (-3282 (*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-4 *5 (-432 *4)) (-5 *2 (-420 (-1157 (-409 (-568))))) (-5 *1 (-437 *4 *5 *3)) (-4 *3 (-1219 *5)))) (-4459 (*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-4 *5 (-432 *4)) (-5 *2 (-420 *3)) (-5 *1 (-437 *4 *5 *3)) (-4 *3 (-1219 *5))))) 
+(-10 -7 (-15 -4459 ((-420 |#3|) |#3|)) (-15 -3282 ((-3 (-420 (-1157 (-409 (-568)))) "failed") |#3|)) (-15 -1618 ((-3 (|:| |overq| (-1157 (-409 (-568)))) (|:| |overan| (-1157 (-53))) (|:| -3485 (-121))) |#3|)) (IF (|has| |#2| (-1037 (-53))) (-15 -4408 ((-3 (-420 (-1157 (-53))) "failed") |#3|)) |noBranch|)) 
+((-2449 (((-121) $ $) NIL)) (-3637 (((-1143) $ (-1143)) NIL)) (-1672 (($ $ (-1143)) NIL)) (-4379 (((-1143) $) NIL)) (-2386 (((-390) (-390) (-390)) 17) (((-390) (-390)) 15)) (-2133 (($ (-390)) NIL) (($ (-390) (-1143)) NIL)) (-3393 (((-390) $) NIL)) (-1893 (((-1143) $) NIL)) (-4249 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-4180 (((-1249) (-1143)) 9)) (-4324 (((-1249) (-1143)) 10)) (-3710 (((-1249)) 11)) (-3919 (((-1249) $) NIL)) (-2747 (((-850) $) NIL)) (-3171 (($ $) 34)) (-1719 (((-121) $ $) NIL))) 
+(((-438) (-13 (-366 (-390) (-1143)) (-10 -7 (-15 -2386 ((-390) (-390) (-390))) (-15 -2386 ((-390) (-390))) (-15 -4180 ((-1249) (-1143))) (-15 -4324 ((-1249) (-1143))) (-15 -3710 ((-1249)))))) (T -438)) 
+((-2386 (*1 *2 *2 *2) (-12 (-5 *2 (-390)) (-5 *1 (-438)))) (-2386 (*1 *2 *2) (-12 (-5 *2 (-390)) (-5 *1 (-438)))) (-4180 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-438)))) (-4324 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-438)))) (-3710 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-438))))) 
+(-13 (-366 (-390) (-1143)) (-10 -7 (-15 -2386 ((-390) (-390) (-390))) (-15 -2386 ((-390) (-390))) (-15 -4180 ((-1249) (-1143))) (-15 -4324 ((-1249) (-1143))) (-15 -3710 ((-1249))))) 
+((-2449 (((-121) $ $) NIL)) (-2156 (((-3 (|:| |fst| (-436)) (|:| -3613 "void")) $) 10)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-3884 (($) 31)) (-3747 (($) 37)) (-3901 (($) 33)) (-3969 (($) 35)) (-2040 (($) 32)) (-3551 (($) 34)) (-4138 (($) 36)) (-3399 (((-121) $) 8)) (-2065 (((-634 (-953 (-568))) $) 16)) (-4289 (($ (-3 (|:| |fst| (-436)) (|:| -3613 "void")) (-634 (-1161)) (-121)) 25) (($ (-3 (|:| |fst| (-436)) (|:| -3613 "void")) (-634 (-953 (-568))) (-121)) 26)) (-2747 (((-850) $) 21) (($ (-436)) 28)) (-1719 (((-121) $ $) NIL))) 
+(((-439) (-13 (-1090) (-10 -8 (-15 -2747 ((-850) $)) (-15 -2747 ($ (-436))) (-15 -2156 ((-3 (|:| |fst| (-436)) (|:| -3613 "void")) $)) (-15 -2065 ((-634 (-953 (-568))) $)) (-15 -3399 ((-121) $)) (-15 -4289 ($ (-3 (|:| |fst| (-436)) (|:| -3613 "void")) (-634 (-1161)) (-121))) (-15 -4289 ($ (-3 (|:| |fst| (-436)) (|:| -3613 "void")) (-634 (-953 (-568))) (-121))) (-15 -3884 ($)) (-15 -2040 ($)) (-15 -3901 ($)) (-15 -3747 ($)) (-15 -3551 ($)) (-15 -3969 ($)) (-15 -4138 ($))))) (T -439)) 
+((-2747 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-439)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-436)) (-5 *1 (-439)))) (-2156 (*1 *2 *1) (-12 (-5 *2 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-5 *1 (-439)))) (-2065 (*1 *2 *1) (-12 (-5 *2 (-634 (-953 (-568)))) (-5 *1 (-439)))) (-3399 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-439)))) (-4289 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-5 *3 (-634 (-1161))) (-5 *4 (-121)) (-5 *1 (-439)))) (-4289 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-121)) (-5 *1 (-439)))) (-3884 (*1 *1) (-5 *1 (-439))) (-2040 (*1 *1) (-5 *1 (-439))) (-3901 (*1 *1) (-5 *1 (-439))) (-3747 (*1 *1) (-5 *1 (-439))) (-3551 (*1 *1) (-5 *1 (-439))) (-3969 (*1 *1) (-5 *1 (-439))) (-4138 (*1 *1) (-5 *1 (-439)))) 
+(-13 (-1090) (-10 -8 (-15 -2747 ((-850) $)) (-15 -2747 ($ (-436))) (-15 -2156 ((-3 (|:| |fst| (-436)) (|:| -3613 "void")) $)) (-15 -2065 ((-634 (-953 (-568))) $)) (-15 -3399 ((-121) $)) (-15 -4289 ($ (-3 (|:| |fst| (-436)) (|:| -3613 "void")) (-634 (-1161)) (-121))) (-15 -4289 ($ (-3 (|:| |fst| (-436)) (|:| -3613 "void")) (-634 (-953 (-568))) (-121))) (-15 -3884 ($)) (-15 -2040 ($)) (-15 -3901 ($)) (-15 -3747 ($)) (-15 -3551 ($)) (-15 -3969 ($)) (-15 -4138 ($)))) 
+((-2449 (((-121) $ $) NIL)) (-3393 (((-1161) $) 8)) (-1893 (((-1143) $) 16)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 11)) (-1719 (((-121) $ $) 13))) 
+(((-440 |#1|) (-13 (-1090) (-10 -8 (-15 -3393 ((-1161) $)))) (-1161)) (T -440)) 
+((-3393 (*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-440 *3)) (-14 *3 *2)))) 
+(-13 (-1090) (-10 -8 (-15 -3393 ((-1161) $)))) 
+((-4130 (((-1249) $) 7)) (-2747 (((-850) $) 8) (($ (-1244 (-688))) 12) (($ (-634 (-328))) 11) (($ (-328)) 10) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 9))) 
 (((-441) (-1275)) (T -441)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1244 (-688))) (-4 *1 (-441)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-4 *1 (-441)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-328)) (-4 *1 (-441)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) (-4 *1 (-441))))) 
-(-13 (-397) (-10 -8 (-15 -2745 ($ (-1244 (-688)))) (-15 -2745 ($ (-634 (-328)))) (-15 -2745 ($ (-328))) (-15 -2745 ($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328)))))))) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1244 (-688))) (-4 *1 (-441)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-4 *1 (-441)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-328)) (-4 *1 (-441)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) (-4 *1 (-441))))) 
+(-13 (-397) (-10 -8 (-15 -2747 ($ (-1244 (-688)))) (-15 -2747 ($ (-634 (-328)))) (-15 -2747 ($ (-328))) (-15 -2747 ($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328)))))))) 
 (((-608 (-850)) . T) ((-397) . T) ((-1195) . T)) 
-((-3666 (((-3 $ "failed") (-1244 (-310 (-381)))) 19) (((-3 $ "failed") (-1244 (-310 (-568)))) 17) (((-3 $ "failed") (-1244 (-953 (-381)))) 15) (((-3 $ "failed") (-1244 (-953 (-568)))) 13) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 11) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 9)) (-2854 (($ (-1244 (-310 (-381)))) 20) (($ (-1244 (-310 (-568)))) 18) (($ (-1244 (-953 (-381)))) 16) (($ (-1244 (-953 (-568)))) 14) (($ (-1244 (-409 (-953 (-381))))) 12) (($ (-1244 (-409 (-953 (-568))))) 10)) (-4128 (((-1249) $) 7)) (-2745 (((-850) $) 8) (($ (-634 (-328))) 23) (($ (-328)) 22) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) 21))) 
+((-3668 (((-3 $ "failed") (-1244 (-310 (-381)))) 19) (((-3 $ "failed") (-1244 (-310 (-568)))) 17) (((-3 $ "failed") (-1244 (-953 (-381)))) 15) (((-3 $ "failed") (-1244 (-953 (-568)))) 13) (((-3 $ "failed") (-1244 (-409 (-953 (-381))))) 11) (((-3 $ "failed") (-1244 (-409 (-953 (-568))))) 9)) (-2857 (($ (-1244 (-310 (-381)))) 20) (($ (-1244 (-310 (-568)))) 18) (($ (-1244 (-953 (-381)))) 16) (($ (-1244 (-953 (-568)))) 14) (($ (-1244 (-409 (-953 (-381))))) 12) (($ (-1244 (-409 (-953 (-568))))) 10)) (-4130 (((-1249) $) 7)) (-2747 (((-850) $) 8) (($ (-634 (-328))) 23) (($ (-328)) 22) (($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) 21))) 
 (((-442) (-1275)) (T -442)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-4 *1 (-442)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-328)) (-4 *1 (-442)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) (-4 *1 (-442)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-1244 (-310 (-381)))) (-4 *1 (-442)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-310 (-381)))) (-4 *1 (-442)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-1244 (-310 (-568)))) (-4 *1 (-442)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-310 (-568)))) (-4 *1 (-442)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-1244 (-953 (-381)))) (-4 *1 (-442)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-953 (-381)))) (-4 *1 (-442)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-1244 (-953 (-568)))) (-4 *1 (-442)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-953 (-568)))) (-4 *1 (-442)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-1244 (-409 (-953 (-381))))) (-4 *1 (-442)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-409 (-953 (-381))))) (-4 *1 (-442)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-1244 (-409 (-953 (-568))))) (-4 *1 (-442)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-409 (-953 (-568))))) (-4 *1 (-442))))) 
-(-13 (-397) (-10 -8 (-15 -2745 ($ (-634 (-328)))) (-15 -2745 ($ (-328))) (-15 -2745 ($ (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328)))))) (-15 -2854 ($ (-1244 (-310 (-381))))) (-15 -3666 ((-3 $ "failed") (-1244 (-310 (-381))))) (-15 -2854 ($ (-1244 (-310 (-568))))) (-15 -3666 ((-3 $ "failed") (-1244 (-310 (-568))))) (-15 -2854 ($ (-1244 (-953 (-381))))) (-15 -3666 ((-3 $ "failed") (-1244 (-953 (-381))))) (-15 -2854 ($ (-1244 (-953 (-568))))) (-15 -3666 ((-3 $ "failed") (-1244 (-953 (-568))))) (-15 -2854 ($ (-1244 (-409 (-953 (-381)))))) (-15 -3666 ((-3 $ "failed") (-1244 (-409 (-953 (-381)))))) (-15 -2854 ($ (-1244 (-409 (-953 (-568)))))) (-15 -3666 ((-3 $ "failed") (-1244 (-409 (-953 (-568)))))))) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-4 *1 (-442)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-328)) (-4 *1 (-442)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) (-4 *1 (-442)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-1244 (-310 (-381)))) (-4 *1 (-442)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-310 (-381)))) (-4 *1 (-442)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-1244 (-310 (-568)))) (-4 *1 (-442)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-310 (-568)))) (-4 *1 (-442)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-1244 (-953 (-381)))) (-4 *1 (-442)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-953 (-381)))) (-4 *1 (-442)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-1244 (-953 (-568)))) (-4 *1 (-442)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-953 (-568)))) (-4 *1 (-442)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-1244 (-409 (-953 (-381))))) (-4 *1 (-442)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-409 (-953 (-381))))) (-4 *1 (-442)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-1244 (-409 (-953 (-568))))) (-4 *1 (-442)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-409 (-953 (-568))))) (-4 *1 (-442))))) 
+(-13 (-397) (-10 -8 (-15 -2747 ($ (-634 (-328)))) (-15 -2747 ($ (-328))) (-15 -2747 ($ (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328)))))) (-15 -2857 ($ (-1244 (-310 (-381))))) (-15 -3668 ((-3 $ "failed") (-1244 (-310 (-381))))) (-15 -2857 ($ (-1244 (-310 (-568))))) (-15 -3668 ((-3 $ "failed") (-1244 (-310 (-568))))) (-15 -2857 ($ (-1244 (-953 (-381))))) (-15 -3668 ((-3 $ "failed") (-1244 (-953 (-381))))) (-15 -2857 ($ (-1244 (-953 (-568))))) (-15 -3668 ((-3 $ "failed") (-1244 (-953 (-568))))) (-15 -2857 ($ (-1244 (-409 (-953 (-381)))))) (-15 -3668 ((-3 $ "failed") (-1244 (-409 (-953 (-381)))))) (-15 -2857 ($ (-1244 (-409 (-953 (-568)))))) (-15 -3668 ((-3 $ "failed") (-1244 (-409 (-953 (-568)))))))) 
 (((-608 (-850)) . T) ((-397) . T) ((-1195) . T)) 
-((-3362 (((-121)) 17)) (-2320 (((-121) (-121)) 18)) (-1972 (((-121)) 13)) (-1904 (((-121) (-121)) 14)) (-1833 (((-121)) 15)) (-2556 (((-121) (-121)) 16)) (-4488 (((-917) (-917)) 21) (((-917)) 20)) (-3157 (((-763) (-634 (-2 (|:| -3848 |#1|) (|:| -3206 (-568))))) 41)) (-1588 (((-917) (-917)) 23) (((-917)) 22)) (-3938 (((-2 (|:| -4068 (-568)) (|:| -3276 (-634 |#1|))) |#1|) 61)) (-2936 (((-420 |#1|) (-2 (|:| |contp| (-568)) (|:| -3276 (-634 (-2 (|:| |irr| |#1|) (|:| -3959 (-568))))))) 125)) (-2954 (((-2 (|:| |contp| (-568)) (|:| -3276 (-634 (-2 (|:| |irr| |#1|) (|:| -3959 (-568)))))) |#1| (-121)) 151)) (-2630 (((-420 |#1|) |#1| (-763) (-763)) 164) (((-420 |#1|) |#1| (-634 (-763)) (-763)) 161) (((-420 |#1|) |#1| (-634 (-763))) 163) (((-420 |#1|) |#1| (-763)) 162) (((-420 |#1|) |#1|) 160)) (-4448 (((-3 |#1| "failed") (-917) |#1| (-634 (-763)) (-763) (-121)) 166) (((-3 |#1| "failed") (-917) |#1| (-634 (-763)) (-763)) 167) (((-3 |#1| "failed") (-917) |#1| (-634 (-763))) 169) (((-3 |#1| "failed") (-917) |#1| (-763)) 168) (((-3 |#1| "failed") (-917) |#1|) 170)) (-3848 (((-420 |#1|) |#1| (-763) (-763)) 159) (((-420 |#1|) |#1| (-634 (-763)) (-763)) 155) (((-420 |#1|) |#1| (-634 (-763))) 157) (((-420 |#1|) |#1| (-763)) 156) (((-420 |#1|) |#1|) 154)) (-1645 (((-121) |#1|) 36)) (-2468 (((-727 (-763)) (-634 (-2 (|:| -3848 |#1|) (|:| -3206 (-568))))) 66)) (-2953 (((-2 (|:| |contp| (-568)) (|:| -3276 (-634 (-2 (|:| |irr| |#1|) (|:| -3959 (-568)))))) |#1| (-121) (-1092 (-763)) (-763)) 153))) 
-(((-443 |#1|) (-10 -7 (-15 -2936 ((-420 |#1|) (-2 (|:| |contp| (-568)) (|:| -3276 (-634 (-2 (|:| |irr| |#1|) (|:| -3959 (-568)))))))) (-15 -2468 ((-727 (-763)) (-634 (-2 (|:| -3848 |#1|) (|:| -3206 (-568)))))) (-15 -1588 ((-917))) (-15 -1588 ((-917) (-917))) (-15 -4488 ((-917))) (-15 -4488 ((-917) (-917))) (-15 -3157 ((-763) (-634 (-2 (|:| -3848 |#1|) (|:| -3206 (-568)))))) (-15 -3938 ((-2 (|:| -4068 (-568)) (|:| -3276 (-634 |#1|))) |#1|)) (-15 -3362 ((-121))) (-15 -2320 ((-121) (-121))) (-15 -1972 ((-121))) (-15 -1904 ((-121) (-121))) (-15 -1645 ((-121) |#1|)) (-15 -1833 ((-121))) (-15 -2556 ((-121) (-121))) (-15 -3848 ((-420 |#1|) |#1|)) (-15 -3848 ((-420 |#1|) |#1| (-763))) (-15 -3848 ((-420 |#1|) |#1| (-634 (-763)))) (-15 -3848 ((-420 |#1|) |#1| (-634 (-763)) (-763))) (-15 -3848 ((-420 |#1|) |#1| (-763) (-763))) (-15 -2630 ((-420 |#1|) |#1|)) (-15 -2630 ((-420 |#1|) |#1| (-763))) (-15 -2630 ((-420 |#1|) |#1| (-634 (-763)))) (-15 -2630 ((-420 |#1|) |#1| (-634 (-763)) (-763))) (-15 -2630 ((-420 |#1|) |#1| (-763) (-763))) (-15 -4448 ((-3 |#1| "failed") (-917) |#1|)) (-15 -4448 ((-3 |#1| "failed") (-917) |#1| (-763))) (-15 -4448 ((-3 |#1| "failed") (-917) |#1| (-634 (-763)))) (-15 -4448 ((-3 |#1| "failed") (-917) |#1| (-634 (-763)) (-763))) (-15 -4448 ((-3 |#1| "failed") (-917) |#1| (-634 (-763)) (-763) (-121))) (-15 -2954 ((-2 (|:| |contp| (-568)) (|:| -3276 (-634 (-2 (|:| |irr| |#1|) (|:| -3959 (-568)))))) |#1| (-121))) (-15 -2953 ((-2 (|:| |contp| (-568)) (|:| -3276 (-634 (-2 (|:| |irr| |#1|) (|:| -3959 (-568)))))) |#1| (-121) (-1092 (-763)) (-763)))) (-1219 (-568))) (T -443)) 
-((-2953 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-121)) (-5 *5 (-1092 (-763))) (-5 *6 (-763)) (-5 *2 (-2 (|:| |contp| (-568)) (|:| -3276 (-634 (-2 (|:| |irr| *3) (|:| -3959 (-568))))))) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-2954 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-5 *2 (-2 (|:| |contp| (-568)) (|:| -3276 (-634 (-2 (|:| |irr| *3) (|:| -3959 (-568))))))) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-4448 (*1 *2 *3 *2 *4 *5 *6) (|partial| -12 (-5 *3 (-917)) (-5 *4 (-634 (-763))) (-5 *5 (-763)) (-5 *6 (-121)) (-5 *1 (-443 *2)) (-4 *2 (-1219 (-568))))) (-4448 (*1 *2 *3 *2 *4 *5) (|partial| -12 (-5 *3 (-917)) (-5 *4 (-634 (-763))) (-5 *5 (-763)) (-5 *1 (-443 *2)) (-4 *2 (-1219 (-568))))) (-4448 (*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-917)) (-5 *4 (-634 (-763))) (-5 *1 (-443 *2)) (-4 *2 (-1219 (-568))))) (-4448 (*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-917)) (-5 *4 (-763)) (-5 *1 (-443 *2)) (-4 *2 (-1219 (-568))))) (-4448 (*1 *2 *3 *2) (|partial| -12 (-5 *3 (-917)) (-5 *1 (-443 *2)) (-4 *2 (-1219 (-568))))) (-2630 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-2630 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-763))) (-5 *5 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-2630 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-763))) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-2630 (*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-2630 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-3848 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-3848 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-763))) (-5 *5 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-3848 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-763))) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-3848 (*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-3848 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-2556 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-1833 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-1645 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-1904 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-1972 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-2320 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-3362 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-3938 (*1 *2 *3) (-12 (-5 *2 (-2 (|:| -4068 (-568)) (|:| -3276 (-634 *3)))) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-3157 (*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3848 *4) (|:| -3206 (-568))))) (-4 *4 (-1219 (-568))) (-5 *2 (-763)) (-5 *1 (-443 *4)))) (-4488 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-4488 (*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-1588 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-1588 (*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-2468 (*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3848 *4) (|:| -3206 (-568))))) (-4 *4 (-1219 (-568))) (-5 *2 (-727 (-763))) (-5 *1 (-443 *4)))) (-2936 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |contp| (-568)) (|:| -3276 (-634 (-2 (|:| |irr| *4) (|:| -3959 (-568))))))) (-4 *4 (-1219 (-568))) (-5 *2 (-420 *4)) (-5 *1 (-443 *4))))) 
-(-10 -7 (-15 -2936 ((-420 |#1|) (-2 (|:| |contp| (-568)) (|:| -3276 (-634 (-2 (|:| |irr| |#1|) (|:| -3959 (-568)))))))) (-15 -2468 ((-727 (-763)) (-634 (-2 (|:| -3848 |#1|) (|:| -3206 (-568)))))) (-15 -1588 ((-917))) (-15 -1588 ((-917) (-917))) (-15 -4488 ((-917))) (-15 -4488 ((-917) (-917))) (-15 -3157 ((-763) (-634 (-2 (|:| -3848 |#1|) (|:| -3206 (-568)))))) (-15 -3938 ((-2 (|:| -4068 (-568)) (|:| -3276 (-634 |#1|))) |#1|)) (-15 -3362 ((-121))) (-15 -2320 ((-121) (-121))) (-15 -1972 ((-121))) (-15 -1904 ((-121) (-121))) (-15 -1645 ((-121) |#1|)) (-15 -1833 ((-121))) (-15 -2556 ((-121) (-121))) (-15 -3848 ((-420 |#1|) |#1|)) (-15 -3848 ((-420 |#1|) |#1| (-763))) (-15 -3848 ((-420 |#1|) |#1| (-634 (-763)))) (-15 -3848 ((-420 |#1|) |#1| (-634 (-763)) (-763))) (-15 -3848 ((-420 |#1|) |#1| (-763) (-763))) (-15 -2630 ((-420 |#1|) |#1|)) (-15 -2630 ((-420 |#1|) |#1| (-763))) (-15 -2630 ((-420 |#1|) |#1| (-634 (-763)))) (-15 -2630 ((-420 |#1|) |#1| (-634 (-763)) (-763))) (-15 -2630 ((-420 |#1|) |#1| (-763) (-763))) (-15 -4448 ((-3 |#1| "failed") (-917) |#1|)) (-15 -4448 ((-3 |#1| "failed") (-917) |#1| (-763))) (-15 -4448 ((-3 |#1| "failed") (-917) |#1| (-634 (-763)))) (-15 -4448 ((-3 |#1| "failed") (-917) |#1| (-634 (-763)) (-763))) (-15 -4448 ((-3 |#1| "failed") (-917) |#1| (-634 (-763)) (-763) (-121))) (-15 -2954 ((-2 (|:| |contp| (-568)) (|:| -3276 (-634 (-2 (|:| |irr| |#1|) (|:| -3959 (-568)))))) |#1| (-121))) (-15 -2953 ((-2 (|:| |contp| (-568)) (|:| -3276 (-634 (-2 (|:| |irr| |#1|) (|:| -3959 (-568)))))) |#1| (-121) (-1092 (-763)) (-763)))) 
-((-2382 (((-568) |#2|) 48) (((-568) |#2| (-763)) 47)) (-3199 (((-568) |#2|) 55)) (-1498 ((|#3| |#2|) 25)) (-2657 ((|#3| |#2| (-917)) 14)) (-3678 ((|#3| |#2|) 15)) (-3849 ((|#3| |#2|) 9)) (-2961 ((|#3| |#2|) 10)) (-1424 ((|#3| |#2| (-917)) 62) ((|#3| |#2|) 30)) (-1577 (((-568) |#2|) 57))) 
-(((-444 |#1| |#2| |#3|) (-10 -7 (-15 -1577 ((-568) |#2|)) (-15 -1424 (|#3| |#2|)) (-15 -1424 (|#3| |#2| (-917))) (-15 -3199 ((-568) |#2|)) (-15 -2382 ((-568) |#2| (-763))) (-15 -2382 ((-568) |#2|)) (-15 -2657 (|#3| |#2| (-917))) (-15 -1498 (|#3| |#2|)) (-15 -3849 (|#3| |#2|)) (-15 -2961 (|#3| |#2|)) (-15 -3678 (|#3| |#2|))) (-1047) (-1219 |#1|) (-13 (-406) (-1037 |#1|) (-365) (-1181) (-279))) (T -444)) 
-((-3678 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))) (-5 *1 (-444 *4 *3 *2)) (-4 *3 (-1219 *4)))) (-2961 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))) (-5 *1 (-444 *4 *3 *2)) (-4 *3 (-1219 *4)))) (-3849 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))) (-5 *1 (-444 *4 *3 *2)) (-4 *3 (-1219 *4)))) (-1498 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))) (-5 *1 (-444 *4 *3 *2)) (-4 *3 (-1219 *4)))) (-2657 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-1047)) (-4 *2 (-13 (-406) (-1037 *5) (-365) (-1181) (-279))) (-5 *1 (-444 *5 *3 *2)) (-4 *3 (-1219 *5)))) (-2382 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-568)) (-5 *1 (-444 *4 *3 *5)) (-4 *3 (-1219 *4)) (-4 *5 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))))) (-2382 (*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-1047)) (-5 *2 (-568)) (-5 *1 (-444 *5 *3 *6)) (-4 *3 (-1219 *5)) (-4 *6 (-13 (-406) (-1037 *5) (-365) (-1181) (-279))))) (-3199 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-568)) (-5 *1 (-444 *4 *3 *5)) (-4 *3 (-1219 *4)) (-4 *5 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))))) (-1424 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-1047)) (-4 *2 (-13 (-406) (-1037 *5) (-365) (-1181) (-279))) (-5 *1 (-444 *5 *3 *2)) (-4 *3 (-1219 *5)))) (-1424 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))) (-5 *1 (-444 *4 *3 *2)) (-4 *3 (-1219 *4)))) (-1577 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-568)) (-5 *1 (-444 *4 *3 *5)) (-4 *3 (-1219 *4)) (-4 *5 (-13 (-406) (-1037 *4) (-365) (-1181) (-279)))))) 
-(-10 -7 (-15 -1577 ((-568) |#2|)) (-15 -1424 (|#3| |#2|)) (-15 -1424 (|#3| |#2| (-917))) (-15 -3199 ((-568) |#2|)) (-15 -2382 ((-568) |#2| (-763))) (-15 -2382 ((-568) |#2|)) (-15 -2657 (|#3| |#2| (-917))) (-15 -1498 (|#3| |#2|)) (-15 -3849 (|#3| |#2|)) (-15 -2961 (|#3| |#2|)) (-15 -3678 (|#3| |#2|))) 
-((-1654 ((|#2| (-1244 |#1|)) 36)) (-3979 ((|#2| |#2| |#1|) 49)) (-3894 ((|#2| |#2| |#1|) 41)) (-3943 ((|#2| |#2|) 38)) (-2278 (((-121) |#2|) 30)) (-2534 (((-634 |#2|) (-917) (-420 |#2|)) 16)) (-4448 ((|#2| (-917) (-420 |#2|)) 21)) (-2468 (((-727 (-763)) (-420 |#2|)) 25))) 
-(((-445 |#1| |#2|) (-10 -7 (-15 -2278 ((-121) |#2|)) (-15 -1654 (|#2| (-1244 |#1|))) (-15 -3943 (|#2| |#2|)) (-15 -3894 (|#2| |#2| |#1|)) (-15 -3979 (|#2| |#2| |#1|)) (-15 -2468 ((-727 (-763)) (-420 |#2|))) (-15 -4448 (|#2| (-917) (-420 |#2|))) (-15 -2534 ((-634 |#2|) (-917) (-420 |#2|)))) (-1047) (-1219 |#1|)) (T -445)) 
-((-2534 (*1 *2 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-420 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-1047)) (-5 *2 (-634 *6)) (-5 *1 (-445 *5 *6)))) (-4448 (*1 *2 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-420 *2)) (-4 *2 (-1219 *5)) (-5 *1 (-445 *5 *2)) (-4 *5 (-1047)))) (-2468 (*1 *2 *3) (-12 (-5 *3 (-420 *5)) (-4 *5 (-1219 *4)) (-4 *4 (-1047)) (-5 *2 (-727 (-763))) (-5 *1 (-445 *4 *5)))) (-3979 (*1 *2 *2 *3) (-12 (-4 *3 (-1047)) (-5 *1 (-445 *3 *2)) (-4 *2 (-1219 *3)))) (-3894 (*1 *2 *2 *3) (-12 (-4 *3 (-1047)) (-5 *1 (-445 *3 *2)) (-4 *2 (-1219 *3)))) (-3943 (*1 *2 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-445 *3 *2)) (-4 *2 (-1219 *3)))) (-1654 (*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-1047)) (-4 *2 (-1219 *4)) (-5 *1 (-445 *4 *2)))) (-2278 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-121)) (-5 *1 (-445 *4 *3)) (-4 *3 (-1219 *4))))) 
-(-10 -7 (-15 -2278 ((-121) |#2|)) (-15 -1654 (|#2| (-1244 |#1|))) (-15 -3943 (|#2| |#2|)) (-15 -3894 (|#2| |#2| |#1|)) (-15 -3979 (|#2| |#2| |#1|)) (-15 -2468 ((-727 (-763)) (-420 |#2|))) (-15 -4448 (|#2| (-917) (-420 |#2|))) (-15 -2534 ((-634 |#2|) (-917) (-420 |#2|)))) 
-((-3532 (((-763)) 41)) (-2024 (((-763)) 23 (|has| |#1| (-406))) (((-763) (-763)) 22 (|has| |#1| (-406)))) (-2488 (((-568) |#1|) 18 (|has| |#1| (-406)))) (-4060 (((-568) |#1|) 20 (|has| |#1| (-406)))) (-3416 (((-763)) 40) (((-763) (-763)) 39)) (-2028 ((|#1| (-763) (-568)) 29)) (-2381 (((-1249)) 43))) 
-(((-446 |#1|) (-10 -7 (-15 -2028 (|#1| (-763) (-568))) (-15 -3416 ((-763) (-763))) (-15 -3416 ((-763))) (-15 -3532 ((-763))) (-15 -2381 ((-1249))) (IF (|has| |#1| (-406)) (PROGN (-15 -4060 ((-568) |#1|)) (-15 -2488 ((-568) |#1|)) (-15 -2024 ((-763) (-763))) (-15 -2024 ((-763)))) |noBranch|)) (-1047)) (T -446)) 
-((-2024 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-446 *3)) (-4 *3 (-406)) (-4 *3 (-1047)))) (-2024 (*1 *2 *2) (-12 (-5 *2 (-763)) (-5 *1 (-446 *3)) (-4 *3 (-406)) (-4 *3 (-1047)))) (-2488 (*1 *2 *3) (-12 (-5 *2 (-568)) (-5 *1 (-446 *3)) (-4 *3 (-406)) (-4 *3 (-1047)))) (-4060 (*1 *2 *3) (-12 (-5 *2 (-568)) (-5 *1 (-446 *3)) (-4 *3 (-406)) (-4 *3 (-1047)))) (-2381 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-446 *3)) (-4 *3 (-1047)))) (-3532 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-446 *3)) (-4 *3 (-1047)))) (-3416 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-446 *3)) (-4 *3 (-1047)))) (-3416 (*1 *2 *2) (-12 (-5 *2 (-763)) (-5 *1 (-446 *3)) (-4 *3 (-1047)))) (-2028 (*1 *2 *3 *4) (-12 (-5 *3 (-763)) (-5 *4 (-568)) (-5 *1 (-446 *2)) (-4 *2 (-1047))))) 
-(-10 -7 (-15 -2028 (|#1| (-763) (-568))) (-15 -3416 ((-763) (-763))) (-15 -3416 ((-763))) (-15 -3532 ((-763))) (-15 -2381 ((-1249))) (IF (|has| |#1| (-406)) (PROGN (-15 -4060 ((-568) |#1|)) (-15 -2488 ((-568) |#1|)) (-15 -2024 ((-763) (-763))) (-15 -2024 ((-763)))) |noBranch|)) 
-((-3993 (((-634 (-568)) (-568)) 57)) (-3927 (((-121) (-169 (-568))) 61)) (-3848 (((-420 (-169 (-568))) (-169 (-568))) 56))) 
-(((-447) (-10 -7 (-15 -3848 ((-420 (-169 (-568))) (-169 (-568)))) (-15 -3993 ((-634 (-568)) (-568))) (-15 -3927 ((-121) (-169 (-568)))))) (T -447)) 
-((-3927 (*1 *2 *3) (-12 (-5 *3 (-169 (-568))) (-5 *2 (-121)) (-5 *1 (-447)))) (-3993 (*1 *2 *3) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-447)) (-5 *3 (-568)))) (-3848 (*1 *2 *3) (-12 (-5 *2 (-420 (-169 (-568)))) (-5 *1 (-447)) (-5 *3 (-169 (-568)))))) 
-(-10 -7 (-15 -3848 ((-420 (-169 (-568))) (-169 (-568)))) (-15 -3993 ((-634 (-568)) (-568))) (-15 -3927 ((-121) (-169 (-568))))) 
-((-4002 ((|#4| |#4| (-634 |#4|)) 57)) (-1328 (((-634 |#4|) (-634 |#4|) (-1143) (-1143)) 17) (((-634 |#4|) (-634 |#4|) (-1143)) 16) (((-634 |#4|) (-634 |#4|)) 11))) 
-(((-448 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4002 (|#4| |#4| (-634 |#4|))) (-15 -1328 ((-634 |#4|) (-634 |#4|))) (-15 -1328 ((-634 |#4|) (-634 |#4|) (-1143))) (-15 -1328 ((-634 |#4|) (-634 |#4|) (-1143) (-1143)))) (-301) (-788) (-842) (-950 |#1| |#2| |#3|)) (T -448)) 
-((-1328 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-1143)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-301)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-448 *4 *5 *6 *7)))) (-1328 (*1 *2 *2 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-1143)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-301)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-448 *4 *5 *6 *7)))) (-1328 (*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-301)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-448 *3 *4 *5 *6)))) (-4002 (*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *4 *5 *6)) (-4 *4 (-301)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-448 *4 *5 *6 *2))))) 
-(-10 -7 (-15 -4002 (|#4| |#4| (-634 |#4|))) (-15 -1328 ((-634 |#4|) (-634 |#4|))) (-15 -1328 ((-634 |#4|) (-634 |#4|) (-1143))) (-15 -1328 ((-634 |#4|) (-634 |#4|) (-1143) (-1143)))) 
-((-2724 (((-634 (-634 |#4|)) (-634 |#4|) (-121)) 70) (((-634 (-634 |#4|)) (-634 |#4|)) 69) (((-634 (-634 |#4|)) (-634 |#4|) (-634 |#4|) (-121)) 63) (((-634 (-634 |#4|)) (-634 |#4|) (-634 |#4|)) 64)) (-3718 (((-634 (-634 |#4|)) (-634 |#4|) (-121)) 40) (((-634 (-634 |#4|)) (-634 |#4|)) 60))) 
-(((-449 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3718 ((-634 (-634 |#4|)) (-634 |#4|))) (-15 -3718 ((-634 (-634 |#4|)) (-634 |#4|) (-121))) (-15 -2724 ((-634 (-634 |#4|)) (-634 |#4|) (-634 |#4|))) (-15 -2724 ((-634 (-634 |#4|)) (-634 |#4|) (-634 |#4|) (-121))) (-15 -2724 ((-634 (-634 |#4|)) (-634 |#4|))) (-15 -2724 ((-634 (-634 |#4|)) (-634 |#4|) (-121)))) (-13 (-301) (-150)) (-788) (-842) (-950 |#1| |#2| |#3|)) (T -449)) 
-((-2724 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-950 *5 *6 *7)) (-5 *2 (-634 (-634 *8))) (-5 *1 (-449 *5 *6 *7 *8)) (-5 *3 (-634 *8)))) (-2724 (*1 *2 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-950 *4 *5 *6)) (-5 *2 (-634 (-634 *7))) (-5 *1 (-449 *4 *5 *6 *7)) (-5 *3 (-634 *7)))) (-2724 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-950 *5 *6 *7)) (-5 *2 (-634 (-634 *8))) (-5 *1 (-449 *5 *6 *7 *8)) (-5 *3 (-634 *8)))) (-2724 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-950 *4 *5 *6)) (-5 *2 (-634 (-634 *7))) (-5 *1 (-449 *4 *5 *6 *7)) (-5 *3 (-634 *7)))) (-3718 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-950 *5 *6 *7)) (-5 *2 (-634 (-634 *8))) (-5 *1 (-449 *5 *6 *7 *8)) (-5 *3 (-634 *8)))) (-3718 (*1 *2 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-950 *4 *5 *6)) (-5 *2 (-634 (-634 *7))) (-5 *1 (-449 *4 *5 *6 *7)) (-5 *3 (-634 *7))))) 
-(-10 -7 (-15 -3718 ((-634 (-634 |#4|)) (-634 |#4|))) (-15 -3718 ((-634 (-634 |#4|)) (-634 |#4|) (-121))) (-15 -2724 ((-634 (-634 |#4|)) (-634 |#4|) (-634 |#4|))) (-15 -2724 ((-634 (-634 |#4|)) (-634 |#4|) (-634 |#4|) (-121))) (-15 -2724 ((-634 (-634 |#4|)) (-634 |#4|))) (-15 -2724 ((-634 (-634 |#4|)) (-634 |#4|) (-121)))) 
-((-4258 (((-763) |#4|) 12)) (-1766 (((-634 (-2 (|:| |totdeg| (-763)) (|:| -2700 |#4|))) |#4| (-763) (-634 (-2 (|:| |totdeg| (-763)) (|:| -2700 |#4|)))) 31)) (-2600 (((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) 37)) (-2064 ((|#4| (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) 38)) (-1447 ((|#4| |#4| (-634 |#4|)) 39)) (-3798 (((-2 (|:| |poly| |#4|) (|:| |mult| |#1|)) |#4| (-634 |#4|)) 68)) (-1499 (((-1249) |#4|) 41)) (-3242 (((-1249) (-634 |#4|)) 50)) (-3217 (((-568) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-568) (-568) (-568)) 47)) (-1282 (((-1249) (-568)) 75)) (-2861 (((-634 |#4|) (-634 |#4|)) 73)) (-4108 (((-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |totdeg| (-763)) (|:| -2700 |#4|)) |#4| (-763)) 25)) (-2654 (((-568) |#4|) 74)) (-1423 ((|#4| |#4|) 29)) (-1508 (((-634 |#4|) (-634 |#4|) (-568) (-568)) 54)) (-2313 (((-568) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-568) (-568) (-568) (-568)) 85)) (-2374 (((-121) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) 16)) (-2814 (((-121) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) 57)) (-3426 (((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#2| (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) 56)) (-2169 (((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) 35)) (-1629 (((-121) |#2| |#2|) 55)) (-1471 (((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#4| (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) 36)) (-3750 (((-121) |#2| |#2| |#2| |#2|) 58)) (-1477 ((|#4| |#4| (-634 |#4|)) 69))) 
-(((-450 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1477 (|#4| |#4| (-634 |#4|))) (-15 -1447 (|#4| |#4| (-634 |#4|))) (-15 -1508 ((-634 |#4|) (-634 |#4|) (-568) (-568))) (-15 -2814 ((-121) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -1629 ((-121) |#2| |#2|)) (-15 -3750 ((-121) |#2| |#2| |#2| |#2|)) (-15 -1471 ((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#4| (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -2169 ((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -3426 ((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#2| (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -3798 ((-2 (|:| |poly| |#4|) (|:| |mult| |#1|)) |#4| (-634 |#4|))) (-15 -1423 (|#4| |#4|)) (-15 -1766 ((-634 (-2 (|:| |totdeg| (-763)) (|:| -2700 |#4|))) |#4| (-763) (-634 (-2 (|:| |totdeg| (-763)) (|:| -2700 |#4|))))) (-15 -2064 (|#4| (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -2600 ((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -2861 ((-634 |#4|) (-634 |#4|))) (-15 -2654 ((-568) |#4|)) (-15 -1499 ((-1249) |#4|)) (-15 -3217 ((-568) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-568) (-568) (-568))) (-15 -2313 ((-568) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-568) (-568) (-568) (-568))) (-15 -3242 ((-1249) (-634 |#4|))) (-15 -1282 ((-1249) (-568))) (-15 -2374 ((-121) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -4108 ((-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |totdeg| (-763)) (|:| -2700 |#4|)) |#4| (-763))) (-15 -4258 ((-763) |#4|))) (-453) (-788) (-842) (-950 |#1| |#2| |#3|)) (T -450)) 
-((-4258 (*1 *2 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-763)) (-5 *1 (-450 *4 *5 *6 *3)) (-4 *3 (-950 *4 *5 *6)))) (-4108 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-2 (|:| |totdeg| (-763)) (|:| -2700 *4))) (-5 *5 (-763)) (-4 *4 (-950 *6 *7 *8)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-5 *2 (-2 (|:| |lcmfij| *7) (|:| |totdeg| *5) (|:| |poli| *4) (|:| |polj| *4))) (-5 *1 (-450 *6 *7 *8 *4)))) (-2374 (*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-763)) (|:| |poli| *7) (|:| |polj| *7))) (-4 *5 (-788)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-450 *4 *5 *6 *7)))) (-1282 (*1 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1249)) (-5 *1 (-450 *4 *5 *6 *7)) (-4 *7 (-950 *4 *5 *6)))) (-3242 (*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1249)) (-5 *1 (-450 *4 *5 *6 *7)))) (-2313 (*1 *2 *3 *4 *4 *2 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *3 (-2 (|:| |lcmfij| *6) (|:| |totdeg| (-763)) (|:| |poli| *4) (|:| |polj| *4))) (-4 *6 (-788)) (-4 *4 (-950 *5 *6 *7)) (-4 *5 (-453)) (-4 *7 (-842)) (-5 *1 (-450 *5 *6 *7 *4)))) (-3217 (*1 *2 *3 *4 *4 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *3 (-2 (|:| |lcmfij| *6) (|:| |totdeg| (-763)) (|:| |poli| *4) (|:| |polj| *4))) (-4 *6 (-788)) (-4 *4 (-950 *5 *6 *7)) (-4 *5 (-453)) (-4 *7 (-842)) (-5 *1 (-450 *5 *6 *7 *4)))) (-1499 (*1 *2 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1249)) (-5 *1 (-450 *4 *5 *6 *3)) (-4 *3 (-950 *4 *5 *6)))) (-2654 (*1 *2 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-568)) (-5 *1 (-450 *4 *5 *6 *3)) (-4 *3 (-950 *4 *5 *6)))) (-2861 (*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-450 *3 *4 *5 *6)))) (-2600 (*1 *2 *2 *2) (-12 (-5 *2 (-634 (-2 (|:| |lcmfij| *4) (|:| |totdeg| (-763)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *4 (-788)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-453)) (-4 *5 (-842)) (-5 *1 (-450 *3 *4 *5 *6)))) (-2064 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-763)) (|:| |poli| *2) (|:| |polj| *2))) (-4 *5 (-788)) (-4 *2 (-950 *4 *5 *6)) (-5 *1 (-450 *4 *5 *6 *2)) (-4 *4 (-453)) (-4 *6 (-842)))) (-1766 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-634 (-2 (|:| |totdeg| (-763)) (|:| -2700 *3)))) (-5 *4 (-763)) (-4 *3 (-950 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-450 *5 *6 *7 *3)))) (-1423 (*1 *2 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-450 *3 *4 *5 *2)) (-4 *2 (-950 *3 *4 *5)))) (-3798 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-950 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-2 (|:| |poly| *3) (|:| |mult| *5))) (-5 *1 (-450 *5 *6 *7 *3)))) (-3426 (*1 *2 *3 *2) (-12 (-5 *2 (-634 (-2 (|:| |lcmfij| *3) (|:| |totdeg| (-763)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *3 (-788)) (-4 *6 (-950 *4 *3 *5)) (-4 *4 (-453)) (-4 *5 (-842)) (-5 *1 (-450 *4 *3 *5 *6)))) (-2169 (*1 *2 *2) (-12 (-5 *2 (-634 (-2 (|:| |lcmfij| *4) (|:| |totdeg| (-763)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *4 (-788)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-453)) (-4 *5 (-842)) (-5 *1 (-450 *3 *4 *5 *6)))) (-1471 (*1 *2 *3 *2) (-12 (-5 *2 (-634 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-763)) (|:| |poli| *3) (|:| |polj| *3)))) (-4 *5 (-788)) (-4 *3 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *6 (-842)) (-5 *1 (-450 *4 *5 *6 *3)))) (-3750 (*1 *2 *3 *3 *3 *3) (-12 (-4 *4 (-453)) (-4 *3 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-450 *4 *3 *5 *6)) (-4 *6 (-950 *4 *3 *5)))) (-1629 (*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *3 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-450 *4 *3 *5 *6)) (-4 *6 (-950 *4 *3 *5)))) (-2814 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-763)) (|:| |poli| *7) (|:| |polj| *7))) (-4 *5 (-788)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-450 *4 *5 *6 *7)))) (-1508 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-568)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-450 *4 *5 *6 *7)))) (-1447 (*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-450 *4 *5 *6 *2)))) (-1477 (*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-450 *4 *5 *6 *2))))) 
-(-10 -7 (-15 -1477 (|#4| |#4| (-634 |#4|))) (-15 -1447 (|#4| |#4| (-634 |#4|))) (-15 -1508 ((-634 |#4|) (-634 |#4|) (-568) (-568))) (-15 -2814 ((-121) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -1629 ((-121) |#2| |#2|)) (-15 -3750 ((-121) |#2| |#2| |#2| |#2|)) (-15 -1471 ((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#4| (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -2169 ((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -3426 ((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#2| (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -3798 ((-2 (|:| |poly| |#4|) (|:| |mult| |#1|)) |#4| (-634 |#4|))) (-15 -1423 (|#4| |#4|)) (-15 -1766 ((-634 (-2 (|:| |totdeg| (-763)) (|:| -2700 |#4|))) |#4| (-763) (-634 (-2 (|:| |totdeg| (-763)) (|:| -2700 |#4|))))) (-15 -2064 (|#4| (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -2600 ((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -2861 ((-634 |#4|) (-634 |#4|))) (-15 -2654 ((-568) |#4|)) (-15 -1499 ((-1249) |#4|)) (-15 -3217 ((-568) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-568) (-568) (-568))) (-15 -2313 ((-568) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-568) (-568) (-568) (-568))) (-15 -3242 ((-1249) (-634 |#4|))) (-15 -1282 ((-1249) (-568))) (-15 -2374 ((-121) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -4108 ((-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |totdeg| (-763)) (|:| -2700 |#4|)) |#4| (-763))) (-15 -4258 ((-763) |#4|))) 
-((-2633 ((|#4| |#4| (-634 |#4|)) 22 (|has| |#1| (-365)))) (-2715 (((-634 |#4|) (-634 |#4|) (-1143) (-1143)) 41) (((-634 |#4|) (-634 |#4|) (-1143)) 40) (((-634 |#4|) (-634 |#4|)) 35))) 
-(((-451 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2715 ((-634 |#4|) (-634 |#4|))) (-15 -2715 ((-634 |#4|) (-634 |#4|) (-1143))) (-15 -2715 ((-634 |#4|) (-634 |#4|) (-1143) (-1143))) (IF (|has| |#1| (-365)) (-15 -2633 (|#4| |#4| (-634 |#4|))) |noBranch|)) (-453) (-788) (-842) (-950 |#1| |#2| |#3|)) (T -451)) 
-((-2633 (*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *4 *5 *6)) (-4 *4 (-365)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-451 *4 *5 *6 *2)))) (-2715 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-1143)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-451 *4 *5 *6 *7)))) (-2715 (*1 *2 *2 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-1143)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-451 *4 *5 *6 *7)))) (-2715 (*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-451 *3 *4 *5 *6))))) 
-(-10 -7 (-15 -2715 ((-634 |#4|) (-634 |#4|))) (-15 -2715 ((-634 |#4|) (-634 |#4|) (-1143))) (-15 -2715 ((-634 |#4|) (-634 |#4|) (-1143) (-1143))) (IF (|has| |#1| (-365)) (-15 -2633 (|#4| |#4| (-634 |#4|))) |noBranch|)) 
-((-2495 (($ $ $) 14) (($ (-634 $)) 21)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 41)) (-2721 (($ $ $) NIL) (($ (-634 $)) 22))) 
-(((-452 |#1|) (-10 -8 (-15 -2155 ((-1157 |#1|) (-1157 |#1|) (-1157 |#1|))) (-15 -2495 (|#1| (-634 |#1|))) (-15 -2495 (|#1| |#1| |#1|)) (-15 -2721 (|#1| (-634 |#1|))) (-15 -2721 (|#1| |#1| |#1|))) (-453)) (T -452)) 
-NIL 
-(-10 -8 (-15 -2155 ((-1157 |#1|) (-1157 |#1|) (-1157 |#1|))) (-15 -2495 (|#1| (-634 |#1|))) (-15 -2495 (|#1| |#1| |#1|)) (-15 -2721 (|#1| (-634 |#1|))) (-15 -2721 (|#1| |#1| |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-2925 (((-3 $ "failed") $) 33)) (-2735 (((-121) $) 30)) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-2595 (((-3 $ "failed") $ $) 41)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42)) (-4078 (((-763)) 28)) (-1826 (((-121) $ $) 38)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
+((-1328 (((-121)) 17)) (-3774 (((-121) (-121)) 18)) (-4377 (((-121)) 13)) (-2642 (((-121) (-121)) 14)) (-2309 (((-121)) 15)) (-1905 (((-121) (-121)) 16)) (-1897 (((-917) (-917)) 21) (((-917)) 20)) (-2764 (((-763) (-634 (-2 (|:| -3850 |#1|) (|:| -1836 (-568))))) 41)) (-4493 (((-917) (-917)) 23) (((-917)) 22)) (-4307 (((-2 (|:| -1638 (-568)) (|:| -2075 (-634 |#1|))) |#1|) 61)) (-2932 (((-420 |#1|) (-2 (|:| |contp| (-568)) (|:| -2075 (-634 (-2 (|:| |irr| |#1|) (|:| -4402 (-568))))))) 125)) (-2996 (((-2 (|:| |contp| (-568)) (|:| -2075 (-634 (-2 (|:| |irr| |#1|) (|:| -4402 (-568)))))) |#1| (-121)) 151)) (-4254 (((-420 |#1|) |#1| (-763) (-763)) 164) (((-420 |#1|) |#1| (-634 (-763)) (-763)) 161) (((-420 |#1|) |#1| (-634 (-763))) 163) (((-420 |#1|) |#1| (-763)) 162) (((-420 |#1|) |#1|) 160)) (-1694 (((-3 |#1| "failed") (-917) |#1| (-634 (-763)) (-763) (-121)) 166) (((-3 |#1| "failed") (-917) |#1| (-634 (-763)) (-763)) 167) (((-3 |#1| "failed") (-917) |#1| (-634 (-763))) 169) (((-3 |#1| "failed") (-917) |#1| (-763)) 168) (((-3 |#1| "failed") (-917) |#1|) 170)) (-3850 (((-420 |#1|) |#1| (-763) (-763)) 159) (((-420 |#1|) |#1| (-634 (-763)) (-763)) 155) (((-420 |#1|) |#1| (-634 (-763))) 157) (((-420 |#1|) |#1| (-763)) 156) (((-420 |#1|) |#1|) 154)) (-3277 (((-121) |#1|) 36)) (-2604 (((-727 (-763)) (-634 (-2 (|:| -3850 |#1|) (|:| -1836 (-568))))) 66)) (-2991 (((-2 (|:| |contp| (-568)) (|:| -2075 (-634 (-2 (|:| |irr| |#1|) (|:| -4402 (-568)))))) |#1| (-121) (-1092 (-763)) (-763)) 153))) 
+(((-443 |#1|) (-10 -7 (-15 -2932 ((-420 |#1|) (-2 (|:| |contp| (-568)) (|:| -2075 (-634 (-2 (|:| |irr| |#1|) (|:| -4402 (-568)))))))) (-15 -2604 ((-727 (-763)) (-634 (-2 (|:| -3850 |#1|) (|:| -1836 (-568)))))) (-15 -4493 ((-917))) (-15 -4493 ((-917) (-917))) (-15 -1897 ((-917))) (-15 -1897 ((-917) (-917))) (-15 -2764 ((-763) (-634 (-2 (|:| -3850 |#1|) (|:| -1836 (-568)))))) (-15 -4307 ((-2 (|:| -1638 (-568)) (|:| -2075 (-634 |#1|))) |#1|)) (-15 -1328 ((-121))) (-15 -3774 ((-121) (-121))) (-15 -4377 ((-121))) (-15 -2642 ((-121) (-121))) (-15 -3277 ((-121) |#1|)) (-15 -2309 ((-121))) (-15 -1905 ((-121) (-121))) (-15 -3850 ((-420 |#1|) |#1|)) (-15 -3850 ((-420 |#1|) |#1| (-763))) (-15 -3850 ((-420 |#1|) |#1| (-634 (-763)))) (-15 -3850 ((-420 |#1|) |#1| (-634 (-763)) (-763))) (-15 -3850 ((-420 |#1|) |#1| (-763) (-763))) (-15 -4254 ((-420 |#1|) |#1|)) (-15 -4254 ((-420 |#1|) |#1| (-763))) (-15 -4254 ((-420 |#1|) |#1| (-634 (-763)))) (-15 -4254 ((-420 |#1|) |#1| (-634 (-763)) (-763))) (-15 -4254 ((-420 |#1|) |#1| (-763) (-763))) (-15 -1694 ((-3 |#1| "failed") (-917) |#1|)) (-15 -1694 ((-3 |#1| "failed") (-917) |#1| (-763))) (-15 -1694 ((-3 |#1| "failed") (-917) |#1| (-634 (-763)))) (-15 -1694 ((-3 |#1| "failed") (-917) |#1| (-634 (-763)) (-763))) (-15 -1694 ((-3 |#1| "failed") (-917) |#1| (-634 (-763)) (-763) (-121))) (-15 -2996 ((-2 (|:| |contp| (-568)) (|:| -2075 (-634 (-2 (|:| |irr| |#1|) (|:| -4402 (-568)))))) |#1| (-121))) (-15 -2991 ((-2 (|:| |contp| (-568)) (|:| -2075 (-634 (-2 (|:| |irr| |#1|) (|:| -4402 (-568)))))) |#1| (-121) (-1092 (-763)) (-763)))) (-1219 (-568))) (T -443)) 
+((-2991 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-121)) (-5 *5 (-1092 (-763))) (-5 *6 (-763)) (-5 *2 (-2 (|:| |contp| (-568)) (|:| -2075 (-634 (-2 (|:| |irr| *3) (|:| -4402 (-568))))))) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-2996 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-5 *2 (-2 (|:| |contp| (-568)) (|:| -2075 (-634 (-2 (|:| |irr| *3) (|:| -4402 (-568))))))) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-1694 (*1 *2 *3 *2 *4 *5 *6) (|partial| -12 (-5 *3 (-917)) (-5 *4 (-634 (-763))) (-5 *5 (-763)) (-5 *6 (-121)) (-5 *1 (-443 *2)) (-4 *2 (-1219 (-568))))) (-1694 (*1 *2 *3 *2 *4 *5) (|partial| -12 (-5 *3 (-917)) (-5 *4 (-634 (-763))) (-5 *5 (-763)) (-5 *1 (-443 *2)) (-4 *2 (-1219 (-568))))) (-1694 (*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-917)) (-5 *4 (-634 (-763))) (-5 *1 (-443 *2)) (-4 *2 (-1219 (-568))))) (-1694 (*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-917)) (-5 *4 (-763)) (-5 *1 (-443 *2)) (-4 *2 (-1219 (-568))))) (-1694 (*1 *2 *3 *2) (|partial| -12 (-5 *3 (-917)) (-5 *1 (-443 *2)) (-4 *2 (-1219 (-568))))) (-4254 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-4254 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-763))) (-5 *5 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-4254 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-763))) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-4254 (*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-4254 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-3850 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-3850 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-763))) (-5 *5 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-3850 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-763))) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-3850 (*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-3850 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-1905 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-2309 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-3277 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-2642 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-4377 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-3774 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-1328 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-4307 (*1 *2 *3) (-12 (-5 *2 (-2 (|:| -1638 (-568)) (|:| -2075 (-634 *3)))) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-2764 (*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3850 *4) (|:| -1836 (-568))))) (-4 *4 (-1219 (-568))) (-5 *2 (-763)) (-5 *1 (-443 *4)))) (-1897 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-1897 (*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-4493 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-4493 (*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) (-2604 (*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3850 *4) (|:| -1836 (-568))))) (-4 *4 (-1219 (-568))) (-5 *2 (-727 (-763))) (-5 *1 (-443 *4)))) (-2932 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |contp| (-568)) (|:| -2075 (-634 (-2 (|:| |irr| *4) (|:| -4402 (-568))))))) (-4 *4 (-1219 (-568))) (-5 *2 (-420 *4)) (-5 *1 (-443 *4))))) 
+(-10 -7 (-15 -2932 ((-420 |#1|) (-2 (|:| |contp| (-568)) (|:| -2075 (-634 (-2 (|:| |irr| |#1|) (|:| -4402 (-568)))))))) (-15 -2604 ((-727 (-763)) (-634 (-2 (|:| -3850 |#1|) (|:| -1836 (-568)))))) (-15 -4493 ((-917))) (-15 -4493 ((-917) (-917))) (-15 -1897 ((-917))) (-15 -1897 ((-917) (-917))) (-15 -2764 ((-763) (-634 (-2 (|:| -3850 |#1|) (|:| -1836 (-568)))))) (-15 -4307 ((-2 (|:| -1638 (-568)) (|:| -2075 (-634 |#1|))) |#1|)) (-15 -1328 ((-121))) (-15 -3774 ((-121) (-121))) (-15 -4377 ((-121))) (-15 -2642 ((-121) (-121))) (-15 -3277 ((-121) |#1|)) (-15 -2309 ((-121))) (-15 -1905 ((-121) (-121))) (-15 -3850 ((-420 |#1|) |#1|)) (-15 -3850 ((-420 |#1|) |#1| (-763))) (-15 -3850 ((-420 |#1|) |#1| (-634 (-763)))) (-15 -3850 ((-420 |#1|) |#1| (-634 (-763)) (-763))) (-15 -3850 ((-420 |#1|) |#1| (-763) (-763))) (-15 -4254 ((-420 |#1|) |#1|)) (-15 -4254 ((-420 |#1|) |#1| (-763))) (-15 -4254 ((-420 |#1|) |#1| (-634 (-763)))) (-15 -4254 ((-420 |#1|) |#1| (-634 (-763)) (-763))) (-15 -4254 ((-420 |#1|) |#1| (-763) (-763))) (-15 -1694 ((-3 |#1| "failed") (-917) |#1|)) (-15 -1694 ((-3 |#1| "failed") (-917) |#1| (-763))) (-15 -1694 ((-3 |#1| "failed") (-917) |#1| (-634 (-763)))) (-15 -1694 ((-3 |#1| "failed") (-917) |#1| (-634 (-763)) (-763))) (-15 -1694 ((-3 |#1| "failed") (-917) |#1| (-634 (-763)) (-763) (-121))) (-15 -2996 ((-2 (|:| |contp| (-568)) (|:| -2075 (-634 (-2 (|:| |irr| |#1|) (|:| -4402 (-568)))))) |#1| (-121))) (-15 -2991 ((-2 (|:| |contp| (-568)) (|:| -2075 (-634 (-2 (|:| |irr| |#1|) (|:| -4402 (-568)))))) |#1| (-121) (-1092 (-763)) (-763)))) 
+((-2183 (((-568) |#2|) 48) (((-568) |#2| (-763)) 47)) (-1815 (((-568) |#2|) 55)) (-2594 ((|#3| |#2|) 25)) (-4417 ((|#3| |#2| (-917)) 14)) (-3680 ((|#3| |#2|) 15)) (-1888 ((|#3| |#2|) 9)) (-2963 ((|#3| |#2|) 10)) (-2204 ((|#3| |#2| (-917)) 62) ((|#3| |#2|) 30)) (-4447 (((-568) |#2|) 57))) 
+(((-444 |#1| |#2| |#3|) (-10 -7 (-15 -4447 ((-568) |#2|)) (-15 -2204 (|#3| |#2|)) (-15 -2204 (|#3| |#2| (-917))) (-15 -1815 ((-568) |#2|)) (-15 -2183 ((-568) |#2| (-763))) (-15 -2183 ((-568) |#2|)) (-15 -4417 (|#3| |#2| (-917))) (-15 -2594 (|#3| |#2|)) (-15 -1888 (|#3| |#2|)) (-15 -2963 (|#3| |#2|)) (-15 -3680 (|#3| |#2|))) (-1047) (-1219 |#1|) (-13 (-406) (-1037 |#1|) (-365) (-1181) (-279))) (T -444)) 
+((-3680 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))) (-5 *1 (-444 *4 *3 *2)) (-4 *3 (-1219 *4)))) (-2963 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))) (-5 *1 (-444 *4 *3 *2)) (-4 *3 (-1219 *4)))) (-1888 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))) (-5 *1 (-444 *4 *3 *2)) (-4 *3 (-1219 *4)))) (-2594 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))) (-5 *1 (-444 *4 *3 *2)) (-4 *3 (-1219 *4)))) (-4417 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-1047)) (-4 *2 (-13 (-406) (-1037 *5) (-365) (-1181) (-279))) (-5 *1 (-444 *5 *3 *2)) (-4 *3 (-1219 *5)))) (-2183 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-568)) (-5 *1 (-444 *4 *3 *5)) (-4 *3 (-1219 *4)) (-4 *5 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))))) (-2183 (*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-1047)) (-5 *2 (-568)) (-5 *1 (-444 *5 *3 *6)) (-4 *3 (-1219 *5)) (-4 *6 (-13 (-406) (-1037 *5) (-365) (-1181) (-279))))) (-1815 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-568)) (-5 *1 (-444 *4 *3 *5)) (-4 *3 (-1219 *4)) (-4 *5 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))))) (-2204 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-1047)) (-4 *2 (-13 (-406) (-1037 *5) (-365) (-1181) (-279))) (-5 *1 (-444 *5 *3 *2)) (-4 *3 (-1219 *5)))) (-2204 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))) (-5 *1 (-444 *4 *3 *2)) (-4 *3 (-1219 *4)))) (-4447 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-568)) (-5 *1 (-444 *4 *3 *5)) (-4 *3 (-1219 *4)) (-4 *5 (-13 (-406) (-1037 *4) (-365) (-1181) (-279)))))) 
+(-10 -7 (-15 -4447 ((-568) |#2|)) (-15 -2204 (|#3| |#2|)) (-15 -2204 (|#3| |#2| (-917))) (-15 -1815 ((-568) |#2|)) (-15 -2183 ((-568) |#2| (-763))) (-15 -2183 ((-568) |#2|)) (-15 -4417 (|#3| |#2| (-917))) (-15 -2594 (|#3| |#2|)) (-15 -1888 (|#3| |#2|)) (-15 -2963 (|#3| |#2|)) (-15 -3680 (|#3| |#2|))) 
+((-3340 ((|#2| (-1244 |#1|)) 36)) (-4482 ((|#2| |#2| |#1|) 49)) (-2048 ((|#2| |#2| |#1|) 41)) (-3945 ((|#2| |#2|) 38)) (-3463 (((-121) |#2|) 30)) (-1806 (((-634 |#2|) (-917) (-420 |#2|)) 16)) (-1694 ((|#2| (-917) (-420 |#2|)) 21)) (-2604 (((-727 (-763)) (-420 |#2|)) 25))) 
+(((-445 |#1| |#2|) (-10 -7 (-15 -3463 ((-121) |#2|)) (-15 -3340 (|#2| (-1244 |#1|))) (-15 -3945 (|#2| |#2|)) (-15 -2048 (|#2| |#2| |#1|)) (-15 -4482 (|#2| |#2| |#1|)) (-15 -2604 ((-727 (-763)) (-420 |#2|))) (-15 -1694 (|#2| (-917) (-420 |#2|))) (-15 -1806 ((-634 |#2|) (-917) (-420 |#2|)))) (-1047) (-1219 |#1|)) (T -445)) 
+((-1806 (*1 *2 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-420 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-1047)) (-5 *2 (-634 *6)) (-5 *1 (-445 *5 *6)))) (-1694 (*1 *2 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-420 *2)) (-4 *2 (-1219 *5)) (-5 *1 (-445 *5 *2)) (-4 *5 (-1047)))) (-2604 (*1 *2 *3) (-12 (-5 *3 (-420 *5)) (-4 *5 (-1219 *4)) (-4 *4 (-1047)) (-5 *2 (-727 (-763))) (-5 *1 (-445 *4 *5)))) (-4482 (*1 *2 *2 *3) (-12 (-4 *3 (-1047)) (-5 *1 (-445 *3 *2)) (-4 *2 (-1219 *3)))) (-2048 (*1 *2 *2 *3) (-12 (-4 *3 (-1047)) (-5 *1 (-445 *3 *2)) (-4 *2 (-1219 *3)))) (-3945 (*1 *2 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-445 *3 *2)) (-4 *2 (-1219 *3)))) (-3340 (*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-1047)) (-4 *2 (-1219 *4)) (-5 *1 (-445 *4 *2)))) (-3463 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-121)) (-5 *1 (-445 *4 *3)) (-4 *3 (-1219 *4))))) 
+(-10 -7 (-15 -3463 ((-121) |#2|)) (-15 -3340 (|#2| (-1244 |#1|))) (-15 -3945 (|#2| |#2|)) (-15 -2048 (|#2| |#2| |#1|)) (-15 -4482 (|#2| |#2| |#1|)) (-15 -2604 ((-727 (-763)) (-420 |#2|))) (-15 -1694 (|#2| (-917) (-420 |#2|))) (-15 -1806 ((-634 |#2|) (-917) (-420 |#2|)))) 
+((-4140 (((-763)) 41)) (-1379 (((-763)) 23 (|has| |#1| (-406))) (((-763) (-763)) 22 (|has| |#1| (-406)))) (-2710 (((-568) |#1|) 18 (|has| |#1| (-406)))) (-1612 (((-568) |#1|) 20 (|has| |#1| (-406)))) (-1616 (((-763)) 40) (((-763) (-763)) 39)) (-1405 ((|#1| (-763) (-568)) 29)) (-2178 (((-1249)) 43))) 
+(((-446 |#1|) (-10 -7 (-15 -1405 (|#1| (-763) (-568))) (-15 -1616 ((-763) (-763))) (-15 -1616 ((-763))) (-15 -4140 ((-763))) (-15 -2178 ((-1249))) (IF (|has| |#1| (-406)) (PROGN (-15 -1612 ((-568) |#1|)) (-15 -2710 ((-568) |#1|)) (-15 -1379 ((-763) (-763))) (-15 -1379 ((-763)))) |noBranch|)) (-1047)) (T -446)) 
+((-1379 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-446 *3)) (-4 *3 (-406)) (-4 *3 (-1047)))) (-1379 (*1 *2 *2) (-12 (-5 *2 (-763)) (-5 *1 (-446 *3)) (-4 *3 (-406)) (-4 *3 (-1047)))) (-2710 (*1 *2 *3) (-12 (-5 *2 (-568)) (-5 *1 (-446 *3)) (-4 *3 (-406)) (-4 *3 (-1047)))) (-1612 (*1 *2 *3) (-12 (-5 *2 (-568)) (-5 *1 (-446 *3)) (-4 *3 (-406)) (-4 *3 (-1047)))) (-2178 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-446 *3)) (-4 *3 (-1047)))) (-4140 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-446 *3)) (-4 *3 (-1047)))) (-1616 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-446 *3)) (-4 *3 (-1047)))) (-1616 (*1 *2 *2) (-12 (-5 *2 (-763)) (-5 *1 (-446 *3)) (-4 *3 (-1047)))) (-1405 (*1 *2 *3 *4) (-12 (-5 *3 (-763)) (-5 *4 (-568)) (-5 *1 (-446 *2)) (-4 *2 (-1047))))) 
+(-10 -7 (-15 -1405 (|#1| (-763) (-568))) (-15 -1616 ((-763) (-763))) (-15 -1616 ((-763))) (-15 -4140 ((-763))) (-15 -2178 ((-1249))) (IF (|has| |#1| (-406)) (PROGN (-15 -1612 ((-568) |#1|)) (-15 -2710 ((-568) |#1|)) (-15 -1379 ((-763) (-763))) (-15 -1379 ((-763)))) |noBranch|)) 
+((-1307 (((-634 (-568)) (-568)) 57)) (-2197 (((-121) (-169 (-568))) 61)) (-3850 (((-420 (-169 (-568))) (-169 (-568))) 56))) 
+(((-447) (-10 -7 (-15 -3850 ((-420 (-169 (-568))) (-169 (-568)))) (-15 -1307 ((-634 (-568)) (-568))) (-15 -2197 ((-121) (-169 (-568)))))) (T -447)) 
+((-2197 (*1 *2 *3) (-12 (-5 *3 (-169 (-568))) (-5 *2 (-121)) (-5 *1 (-447)))) (-1307 (*1 *2 *3) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-447)) (-5 *3 (-568)))) (-3850 (*1 *2 *3) (-12 (-5 *2 (-420 (-169 (-568)))) (-5 *1 (-447)) (-5 *3 (-169 (-568)))))) 
+(-10 -7 (-15 -3850 ((-420 (-169 (-568))) (-169 (-568)))) (-15 -1307 ((-634 (-568)) (-568))) (-15 -2197 ((-121) (-169 (-568))))) 
+((-1351 ((|#4| |#4| (-634 |#4|)) 57)) (-3511 (((-634 |#4|) (-634 |#4|) (-1143) (-1143)) 17) (((-634 |#4|) (-634 |#4|) (-1143)) 16) (((-634 |#4|) (-634 |#4|)) 11))) 
+(((-448 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1351 (|#4| |#4| (-634 |#4|))) (-15 -3511 ((-634 |#4|) (-634 |#4|))) (-15 -3511 ((-634 |#4|) (-634 |#4|) (-1143))) (-15 -3511 ((-634 |#4|) (-634 |#4|) (-1143) (-1143)))) (-301) (-788) (-842) (-950 |#1| |#2| |#3|)) (T -448)) 
+((-3511 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-1143)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-301)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-448 *4 *5 *6 *7)))) (-3511 (*1 *2 *2 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-1143)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-301)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-448 *4 *5 *6 *7)))) (-3511 (*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-301)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-448 *3 *4 *5 *6)))) (-1351 (*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *4 *5 *6)) (-4 *4 (-301)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-448 *4 *5 *6 *2))))) 
+(-10 -7 (-15 -1351 (|#4| |#4| (-634 |#4|))) (-15 -3511 ((-634 |#4|) (-634 |#4|))) (-15 -3511 ((-634 |#4|) (-634 |#4|) (-1143))) (-15 -3511 ((-634 |#4|) (-634 |#4|) (-1143) (-1143)))) 
+((-1548 (((-634 (-634 |#4|)) (-634 |#4|) (-121)) 70) (((-634 (-634 |#4|)) (-634 |#4|)) 69) (((-634 (-634 |#4|)) (-634 |#4|) (-634 |#4|) (-121)) 63) (((-634 (-634 |#4|)) (-634 |#4|) (-634 |#4|)) 64)) (-2459 (((-634 (-634 |#4|)) (-634 |#4|) (-121)) 40) (((-634 (-634 |#4|)) (-634 |#4|)) 60))) 
+(((-449 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2459 ((-634 (-634 |#4|)) (-634 |#4|))) (-15 -2459 ((-634 (-634 |#4|)) (-634 |#4|) (-121))) (-15 -1548 ((-634 (-634 |#4|)) (-634 |#4|) (-634 |#4|))) (-15 -1548 ((-634 (-634 |#4|)) (-634 |#4|) (-634 |#4|) (-121))) (-15 -1548 ((-634 (-634 |#4|)) (-634 |#4|))) (-15 -1548 ((-634 (-634 |#4|)) (-634 |#4|) (-121)))) (-13 (-301) (-150)) (-788) (-842) (-950 |#1| |#2| |#3|)) (T -449)) 
+((-1548 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-950 *5 *6 *7)) (-5 *2 (-634 (-634 *8))) (-5 *1 (-449 *5 *6 *7 *8)) (-5 *3 (-634 *8)))) (-1548 (*1 *2 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-950 *4 *5 *6)) (-5 *2 (-634 (-634 *7))) (-5 *1 (-449 *4 *5 *6 *7)) (-5 *3 (-634 *7)))) (-1548 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-950 *5 *6 *7)) (-5 *2 (-634 (-634 *8))) (-5 *1 (-449 *5 *6 *7 *8)) (-5 *3 (-634 *8)))) (-1548 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-950 *4 *5 *6)) (-5 *2 (-634 (-634 *7))) (-5 *1 (-449 *4 *5 *6 *7)) (-5 *3 (-634 *7)))) (-2459 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-950 *5 *6 *7)) (-5 *2 (-634 (-634 *8))) (-5 *1 (-449 *5 *6 *7 *8)) (-5 *3 (-634 *8)))) (-2459 (*1 *2 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-950 *4 *5 *6)) (-5 *2 (-634 (-634 *7))) (-5 *1 (-449 *4 *5 *6 *7)) (-5 *3 (-634 *7))))) 
+(-10 -7 (-15 -2459 ((-634 (-634 |#4|)) (-634 |#4|))) (-15 -2459 ((-634 (-634 |#4|)) (-634 |#4|) (-121))) (-15 -1548 ((-634 (-634 |#4|)) (-634 |#4|) (-634 |#4|))) (-15 -1548 ((-634 (-634 |#4|)) (-634 |#4|) (-634 |#4|) (-121))) (-15 -1548 ((-634 (-634 |#4|)) (-634 |#4|))) (-15 -1548 ((-634 (-634 |#4|)) (-634 |#4|) (-121)))) 
+((-2891 (((-763) |#4|) 12)) (-3944 (((-634 (-2 (|:| |totdeg| (-763)) (|:| -1416 |#4|))) |#4| (-763) (-634 (-2 (|:| |totdeg| (-763)) (|:| -1416 |#4|)))) 31)) (-2064 (((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) 37)) (-1620 ((|#4| (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) 38)) (-2327 ((|#4| |#4| (-634 |#4|)) 39)) (-2784 (((-2 (|:| |poly| |#4|) (|:| |mult| |#1|)) |#4| (-634 |#4|)) 68)) (-2601 (((-1249) |#4|) 41)) (-1970 (((-1249) (-634 |#4|)) 50)) (-1881 (((-568) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-568) (-568) (-568)) 47)) (-3149 (((-1249) (-568)) 75)) (-4039 (((-634 |#4|) (-634 |#4|)) 73)) (-3586 (((-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |totdeg| (-763)) (|:| -1416 |#4|)) |#4| (-763)) 25)) (-4400 (((-568) |#4|) 74)) (-2198 ((|#4| |#4|) 29)) (-2652 (((-634 |#4|) (-634 |#4|) (-568) (-568)) 54)) (-3734 (((-568) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-568) (-568) (-568) (-568)) 85)) (-2144 (((-121) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) 16)) (-3735 (((-121) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) 57)) (-3382 (((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#2| (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) 56)) (-3822 (((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) 35)) (-1510 (((-121) |#2| |#2|) 55)) (-2460 (((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#4| (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) 36)) (-2611 (((-121) |#2| |#2| |#2| |#2|) 58)) (-2497 ((|#4| |#4| (-634 |#4|)) 69))) 
+(((-450 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2497 (|#4| |#4| (-634 |#4|))) (-15 -2327 (|#4| |#4| (-634 |#4|))) (-15 -2652 ((-634 |#4|) (-634 |#4|) (-568) (-568))) (-15 -3735 ((-121) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -1510 ((-121) |#2| |#2|)) (-15 -2611 ((-121) |#2| |#2| |#2| |#2|)) (-15 -2460 ((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#4| (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -3822 ((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -3382 ((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#2| (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -2784 ((-2 (|:| |poly| |#4|) (|:| |mult| |#1|)) |#4| (-634 |#4|))) (-15 -2198 (|#4| |#4|)) (-15 -3944 ((-634 (-2 (|:| |totdeg| (-763)) (|:| -1416 |#4|))) |#4| (-763) (-634 (-2 (|:| |totdeg| (-763)) (|:| -1416 |#4|))))) (-15 -1620 (|#4| (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -2064 ((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -4039 ((-634 |#4|) (-634 |#4|))) (-15 -4400 ((-568) |#4|)) (-15 -2601 ((-1249) |#4|)) (-15 -1881 ((-568) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-568) (-568) (-568))) (-15 -3734 ((-568) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-568) (-568) (-568) (-568))) (-15 -1970 ((-1249) (-634 |#4|))) (-15 -3149 ((-1249) (-568))) (-15 -2144 ((-121) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -3586 ((-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |totdeg| (-763)) (|:| -1416 |#4|)) |#4| (-763))) (-15 -2891 ((-763) |#4|))) (-453) (-788) (-842) (-950 |#1| |#2| |#3|)) (T -450)) 
+((-2891 (*1 *2 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-763)) (-5 *1 (-450 *4 *5 *6 *3)) (-4 *3 (-950 *4 *5 *6)))) (-3586 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-2 (|:| |totdeg| (-763)) (|:| -1416 *4))) (-5 *5 (-763)) (-4 *4 (-950 *6 *7 *8)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-5 *2 (-2 (|:| |lcmfij| *7) (|:| |totdeg| *5) (|:| |poli| *4) (|:| |polj| *4))) (-5 *1 (-450 *6 *7 *8 *4)))) (-2144 (*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-763)) (|:| |poli| *7) (|:| |polj| *7))) (-4 *5 (-788)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-450 *4 *5 *6 *7)))) (-3149 (*1 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1249)) (-5 *1 (-450 *4 *5 *6 *7)) (-4 *7 (-950 *4 *5 *6)))) (-1970 (*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1249)) (-5 *1 (-450 *4 *5 *6 *7)))) (-3734 (*1 *2 *3 *4 *4 *2 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *3 (-2 (|:| |lcmfij| *6) (|:| |totdeg| (-763)) (|:| |poli| *4) (|:| |polj| *4))) (-4 *6 (-788)) (-4 *4 (-950 *5 *6 *7)) (-4 *5 (-453)) (-4 *7 (-842)) (-5 *1 (-450 *5 *6 *7 *4)))) (-1881 (*1 *2 *3 *4 *4 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *3 (-2 (|:| |lcmfij| *6) (|:| |totdeg| (-763)) (|:| |poli| *4) (|:| |polj| *4))) (-4 *6 (-788)) (-4 *4 (-950 *5 *6 *7)) (-4 *5 (-453)) (-4 *7 (-842)) (-5 *1 (-450 *5 *6 *7 *4)))) (-2601 (*1 *2 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1249)) (-5 *1 (-450 *4 *5 *6 *3)) (-4 *3 (-950 *4 *5 *6)))) (-4400 (*1 *2 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-568)) (-5 *1 (-450 *4 *5 *6 *3)) (-4 *3 (-950 *4 *5 *6)))) (-4039 (*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-450 *3 *4 *5 *6)))) (-2064 (*1 *2 *2 *2) (-12 (-5 *2 (-634 (-2 (|:| |lcmfij| *4) (|:| |totdeg| (-763)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *4 (-788)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-453)) (-4 *5 (-842)) (-5 *1 (-450 *3 *4 *5 *6)))) (-1620 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-763)) (|:| |poli| *2) (|:| |polj| *2))) (-4 *5 (-788)) (-4 *2 (-950 *4 *5 *6)) (-5 *1 (-450 *4 *5 *6 *2)) (-4 *4 (-453)) (-4 *6 (-842)))) (-3944 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-634 (-2 (|:| |totdeg| (-763)) (|:| -1416 *3)))) (-5 *4 (-763)) (-4 *3 (-950 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-450 *5 *6 *7 *3)))) (-2198 (*1 *2 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-450 *3 *4 *5 *2)) (-4 *2 (-950 *3 *4 *5)))) (-2784 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-950 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-2 (|:| |poly| *3) (|:| |mult| *5))) (-5 *1 (-450 *5 *6 *7 *3)))) (-3382 (*1 *2 *3 *2) (-12 (-5 *2 (-634 (-2 (|:| |lcmfij| *3) (|:| |totdeg| (-763)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *3 (-788)) (-4 *6 (-950 *4 *3 *5)) (-4 *4 (-453)) (-4 *5 (-842)) (-5 *1 (-450 *4 *3 *5 *6)))) (-3822 (*1 *2 *2) (-12 (-5 *2 (-634 (-2 (|:| |lcmfij| *4) (|:| |totdeg| (-763)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *4 (-788)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-453)) (-4 *5 (-842)) (-5 *1 (-450 *3 *4 *5 *6)))) (-2460 (*1 *2 *3 *2) (-12 (-5 *2 (-634 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-763)) (|:| |poli| *3) (|:| |polj| *3)))) (-4 *5 (-788)) (-4 *3 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *6 (-842)) (-5 *1 (-450 *4 *5 *6 *3)))) (-2611 (*1 *2 *3 *3 *3 *3) (-12 (-4 *4 (-453)) (-4 *3 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-450 *4 *3 *5 *6)) (-4 *6 (-950 *4 *3 *5)))) (-1510 (*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *3 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-450 *4 *3 *5 *6)) (-4 *6 (-950 *4 *3 *5)))) (-3735 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-763)) (|:| |poli| *7) (|:| |polj| *7))) (-4 *5 (-788)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-450 *4 *5 *6 *7)))) (-2652 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-568)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-450 *4 *5 *6 *7)))) (-2327 (*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-450 *4 *5 *6 *2)))) (-2497 (*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-450 *4 *5 *6 *2))))) 
+(-10 -7 (-15 -2497 (|#4| |#4| (-634 |#4|))) (-15 -2327 (|#4| |#4| (-634 |#4|))) (-15 -2652 ((-634 |#4|) (-634 |#4|) (-568) (-568))) (-15 -3735 ((-121) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -1510 ((-121) |#2| |#2|)) (-15 -2611 ((-121) |#2| |#2| |#2| |#2|)) (-15 -2460 ((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#4| (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -3822 ((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -3382 ((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) |#2| (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -2784 ((-2 (|:| |poly| |#4|) (|:| |mult| |#1|)) |#4| (-634 |#4|))) (-15 -2198 (|#4| |#4|)) (-15 -3944 ((-634 (-2 (|:| |totdeg| (-763)) (|:| -1416 |#4|))) |#4| (-763) (-634 (-2 (|:| |totdeg| (-763)) (|:| -1416 |#4|))))) (-15 -1620 (|#4| (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -2064 ((-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))) (-634 (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|))))) (-15 -4039 ((-634 |#4|) (-634 |#4|))) (-15 -4400 ((-568) |#4|)) (-15 -2601 ((-1249) |#4|)) (-15 -1881 ((-568) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-568) (-568) (-568))) (-15 -3734 ((-568) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) |#4| |#4| (-568) (-568) (-568) (-568))) (-15 -1970 ((-1249) (-634 |#4|))) (-15 -3149 ((-1249) (-568))) (-15 -2144 ((-121) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)))) (-15 -3586 ((-2 (|:| |lcmfij| |#2|) (|:| |totdeg| (-763)) (|:| |poli| |#4|) (|:| |polj| |#4|)) (-2 (|:| |totdeg| (-763)) (|:| -1416 |#4|)) |#4| (-763))) (-15 -2891 ((-763) |#4|))) 
+((-4272 ((|#4| |#4| (-634 |#4|)) 22 (|has| |#1| (-365)))) (-1506 (((-634 |#4|) (-634 |#4|) (-1143) (-1143)) 41) (((-634 |#4|) (-634 |#4|) (-1143)) 40) (((-634 |#4|) (-634 |#4|)) 35))) 
+(((-451 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1506 ((-634 |#4|) (-634 |#4|))) (-15 -1506 ((-634 |#4|) (-634 |#4|) (-1143))) (-15 -1506 ((-634 |#4|) (-634 |#4|) (-1143) (-1143))) (IF (|has| |#1| (-365)) (-15 -4272 (|#4| |#4| (-634 |#4|))) |noBranch|)) (-453) (-788) (-842) (-950 |#1| |#2| |#3|)) (T -451)) 
+((-4272 (*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *4 *5 *6)) (-4 *4 (-365)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-451 *4 *5 *6 *2)))) (-1506 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-1143)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-451 *4 *5 *6 *7)))) (-1506 (*1 *2 *2 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-1143)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-451 *4 *5 *6 *7)))) (-1506 (*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-451 *3 *4 *5 *6))))) 
+(-10 -7 (-15 -1506 ((-634 |#4|) (-634 |#4|))) (-15 -1506 ((-634 |#4|) (-634 |#4|) (-1143))) (-15 -1506 ((-634 |#4|) (-634 |#4|) (-1143) (-1143))) (IF (|has| |#1| (-365)) (-15 -4272 (|#4| |#4| (-634 |#4|))) |noBranch|)) 
+((-2498 (($ $ $) 14) (($ (-634 $)) 21)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 41)) (-2723 (($ $ $) NIL) (($ (-634 $)) 22))) 
+(((-452 |#1|) (-10 -8 (-15 -3603 ((-1157 |#1|) (-1157 |#1|) (-1157 |#1|))) (-15 -2498 (|#1| (-634 |#1|))) (-15 -2498 (|#1| |#1| |#1|)) (-15 -2723 (|#1| (-634 |#1|))) (-15 -2723 (|#1| |#1| |#1|))) (-453)) (T -452)) 
+NIL 
+(-10 -8 (-15 -3603 ((-1157 |#1|) (-1157 |#1|) (-1157 |#1|))) (-15 -2498 (|#1| (-634 |#1|))) (-15 -2498 (|#1| |#1| |#1|)) (-15 -2723 (|#1| (-634 |#1|))) (-15 -2723 (|#1| |#1| |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-2902 (((-3 $ "failed") $) 33)) (-1598 (((-121) $) 30)) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-2597 (((-3 $ "failed") $ $) 41)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42)) (-3425 (((-763)) 28)) (-2273 (((-121) $ $) 38)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
 (((-453) (-1275)) (T -453)) 
-((-2721 (*1 *1 *1 *1) (-4 *1 (-453))) (-2721 (*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-453)))) (-2495 (*1 *1 *1 *1) (-4 *1 (-453))) (-2495 (*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-453)))) (-2155 (*1 *2 *2 *2) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-453))))) 
-(-13 (-558) (-10 -8 (-15 -2721 ($ $ $)) (-15 -2721 ($ (-634 $))) (-15 -2495 ($ $ $)) (-15 -2495 ($ (-634 $))) (-15 -2155 ((-1157 $) (-1157 $) (-1157 $))))) 
+((-2723 (*1 *1 *1 *1) (-4 *1 (-453))) (-2723 (*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-453)))) (-2498 (*1 *1 *1 *1) (-4 *1 (-453))) (-2498 (*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-453)))) (-3603 (*1 *2 *2 *2) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-453))))) 
+(-13 (-558) (-10 -8 (-15 -2723 ($ $ $)) (-15 -2723 ($ (-634 $))) (-15 -2498 ($ $ $)) (-15 -2498 ($ (-634 $))) (-15 -3603 ((-1157 $) (-1157 $) (-1157 $))))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-105) . T) ((-120 $ $) . T) ((-137) . T) ((-608 (-850)) . T) ((-172) . T) ((-285) . T) ((-558) . T) ((-637 $) . T) ((-707 $) . T) ((-716) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2295 (((-3 $ "failed")) NIL (|has| (-409 (-953 |#1|)) (-558)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-2776 (((-1244 (-679 (-409 (-953 |#1|)))) (-1244 $)) NIL) (((-1244 (-679 (-409 (-953 |#1|))))) NIL)) (-1741 (((-1244 $)) NIL)) (-2671 (($) NIL T CONST)) (-1309 (((-3 (-2 (|:| |particular| $) (|:| -3746 (-634 $))) "failed")) NIL)) (-2593 (((-3 $ "failed")) NIL (|has| (-409 (-953 |#1|)) (-558)))) (-1631 (((-679 (-409 (-953 |#1|))) (-1244 $)) NIL) (((-679 (-409 (-953 |#1|)))) NIL)) (-1866 (((-409 (-953 |#1|)) $) NIL)) (-3042 (((-679 (-409 (-953 |#1|))) $ (-1244 $)) NIL) (((-679 (-409 (-953 |#1|))) $) NIL)) (-3550 (((-3 $ "failed") $) NIL (|has| (-409 (-953 |#1|)) (-558)))) (-4408 (((-1157 (-953 (-409 (-953 |#1|))))) NIL (|has| (-409 (-953 |#1|)) (-365))) (((-1157 (-409 (-953 |#1|)))) 79 (|has| |#1| (-558)))) (-3551 (($ $ (-917)) NIL)) (-4409 (((-409 (-953 |#1|)) $) NIL)) (-1371 (((-1157 (-409 (-953 |#1|))) $) 77 (|has| (-409 (-953 |#1|)) (-558)))) (-3569 (((-409 (-953 |#1|)) (-1244 $)) NIL) (((-409 (-953 |#1|))) NIL)) (-2989 (((-1157 (-409 (-953 |#1|))) $) NIL)) (-3384 (((-121)) NIL)) (-3498 (($ (-1244 (-409 (-953 |#1|))) (-1244 $)) 97) (($ (-1244 (-409 (-953 |#1|)))) NIL)) (-2925 (((-3 $ "failed") $) NIL (|has| (-409 (-953 |#1|)) (-558)))) (-3700 (((-917)) NIL)) (-4370 (((-121)) NIL)) (-4373 (($ $ (-917)) NIL)) (-1537 (((-121)) NIL)) (-1580 (((-121)) NIL)) (-1695 (((-121)) NIL)) (-3116 (((-3 (-2 (|:| |particular| $) (|:| -3746 (-634 $))) "failed")) NIL)) (-2599 (((-3 $ "failed")) NIL (|has| (-409 (-953 |#1|)) (-558)))) (-4210 (((-679 (-409 (-953 |#1|))) (-1244 $)) NIL) (((-679 (-409 (-953 |#1|)))) NIL)) (-2889 (((-409 (-953 |#1|)) $) NIL)) (-4333 (((-679 (-409 (-953 |#1|))) $ (-1244 $)) NIL) (((-679 (-409 (-953 |#1|))) $) NIL)) (-3243 (((-3 $ "failed") $) NIL (|has| (-409 (-953 |#1|)) (-558)))) (-4454 (((-1157 (-953 (-409 (-953 |#1|))))) NIL (|has| (-409 (-953 |#1|)) (-365))) (((-1157 (-409 (-953 |#1|)))) 78 (|has| |#1| (-558)))) (-4222 (($ $ (-917)) NIL)) (-3329 (((-409 (-953 |#1|)) $) NIL)) (-2265 (((-1157 (-409 (-953 |#1|))) $) 72 (|has| (-409 (-953 |#1|)) (-558)))) (-3898 (((-409 (-953 |#1|)) (-1244 $)) NIL) (((-409 (-953 |#1|))) NIL)) (-3626 (((-1157 (-409 (-953 |#1|))) $) NIL)) (-2767 (((-121)) NIL)) (-4487 (((-1143) $) NIL)) (-1804 (((-121)) NIL)) (-2919 (((-121)) NIL)) (-3840 (((-121)) NIL)) (-4022 (((-1108) $) NIL)) (-3604 (((-409 (-953 |#1|)) $ $) 66 (|has| |#1| (-558)))) (-3087 (((-409 (-953 |#1|)) $) 65 (|has| |#1| (-558)))) (-4311 (((-409 (-953 |#1|)) $) 89 (|has| |#1| (-558)))) (-1686 (((-1157 (-409 (-953 |#1|))) $) 83 (|has| |#1| (-558)))) (-1942 (((-409 (-953 |#1|))) 67 (|has| |#1| (-558)))) (-3456 (((-409 (-953 |#1|)) $ $) 54 (|has| |#1| (-558)))) (-3102 (((-409 (-953 |#1|)) $) 53 (|has| |#1| (-558)))) (-1318 (((-409 (-953 |#1|)) $) 88 (|has| |#1| (-558)))) (-2726 (((-1157 (-409 (-953 |#1|))) $) 82 (|has| |#1| (-558)))) (-2267 (((-409 (-953 |#1|))) 64 (|has| |#1| (-558)))) (-1828 (($) 95) (($ (-1161)) 101) (($ (-1244 (-1161))) 100) (($ (-1244 $)) 90) (($ (-1161) (-1244 $)) 99) (($ (-1244 (-1161)) (-1244 $)) 98)) (-1346 (((-121)) NIL)) (-2779 (((-409 (-953 |#1|)) $ (-568)) NIL)) (-4073 (((-1244 (-409 (-953 |#1|))) $ (-1244 $)) 92) (((-679 (-409 (-953 |#1|))) (-1244 $) (-1244 $)) NIL) (((-1244 (-409 (-953 |#1|))) $) 37) (((-679 (-409 (-953 |#1|))) (-1244 $)) NIL)) (-4278 (((-1244 (-409 (-953 |#1|))) $) NIL) (($ (-1244 (-409 (-953 |#1|)))) 34)) (-3295 (((-634 (-953 (-409 (-953 |#1|)))) (-1244 $)) NIL) (((-634 (-953 (-409 (-953 |#1|))))) NIL) (((-634 (-953 |#1|)) (-1244 $)) 93 (|has| |#1| (-558))) (((-634 (-953 |#1|))) 94 (|has| |#1| (-558)))) (-2353 (($ $ $) NIL)) (-3433 (((-121)) NIL)) (-2745 (((-850) $) NIL) (($ (-1244 (-409 (-953 |#1|)))) NIL)) (-3746 (((-1244 $)) 56)) (-1509 (((-634 (-1244 (-409 (-953 |#1|))))) NIL (|has| (-409 (-953 |#1|)) (-558)))) (-3882 (($ $ $ $) NIL)) (-4177 (((-121)) NIL)) (-3823 (($ (-679 (-409 (-953 |#1|))) $) NIL)) (-3500 (($ $ $) NIL)) (-2433 (((-121)) NIL)) (-2189 (((-121)) NIL)) (-4107 (((-121)) NIL)) (-3056 (($) NIL T CONST)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) 91)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 52) (($ $ (-409 (-953 |#1|))) NIL) (($ (-409 (-953 |#1|)) $) NIL) (($ (-1127 |#2| (-409 (-953 |#1|))) $) NIL))) 
-(((-454 |#1| |#2| |#3| |#4|) (-13 (-419 (-409 (-953 |#1|))) (-637 (-1127 |#2| (-409 (-953 |#1|)))) (-10 -8 (-15 -2745 ($ (-1244 (-409 (-953 |#1|))))) (-15 -3116 ((-3 (-2 (|:| |particular| $) (|:| -3746 (-634 $))) "failed"))) (-15 -1309 ((-3 (-2 (|:| |particular| $) (|:| -3746 (-634 $))) "failed"))) (-15 -1828 ($)) (-15 -1828 ($ (-1161))) (-15 -1828 ($ (-1244 (-1161)))) (-15 -1828 ($ (-1244 $))) (-15 -1828 ($ (-1161) (-1244 $))) (-15 -1828 ($ (-1244 (-1161)) (-1244 $))) (IF (|has| |#1| (-558)) (PROGN (-15 -4454 ((-1157 (-409 (-953 |#1|))))) (-15 -2726 ((-1157 (-409 (-953 |#1|))) $)) (-15 -3102 ((-409 (-953 |#1|)) $)) (-15 -1318 ((-409 (-953 |#1|)) $)) (-15 -4408 ((-1157 (-409 (-953 |#1|))))) (-15 -1686 ((-1157 (-409 (-953 |#1|))) $)) (-15 -3087 ((-409 (-953 |#1|)) $)) (-15 -4311 ((-409 (-953 |#1|)) $)) (-15 -3456 ((-409 (-953 |#1|)) $ $)) (-15 -2267 ((-409 (-953 |#1|)))) (-15 -3604 ((-409 (-953 |#1|)) $ $)) (-15 -1942 ((-409 (-953 |#1|)))) (-15 -3295 ((-634 (-953 |#1|)) (-1244 $))) (-15 -3295 ((-634 (-953 |#1|))))) |noBranch|))) (-172) (-917) (-634 (-1161)) (-1244 (-679 |#1|))) (T -454)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1244 (-409 (-953 *3)))) (-4 *3 (-172)) (-14 *6 (-1244 (-679 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))))) (-3116 (*1 *2) (|partial| -12 (-5 *2 (-2 (|:| |particular| (-454 *3 *4 *5 *6)) (|:| -3746 (-634 (-454 *3 *4 *5 *6))))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-1309 (*1 *2) (|partial| -12 (-5 *2 (-2 (|:| |particular| (-454 *3 *4 *5 *6)) (|:| -3746 (-634 (-454 *3 *4 *5 *6))))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-1828 (*1 *1) (-12 (-5 *1 (-454 *2 *3 *4 *5)) (-4 *2 (-172)) (-14 *3 (-917)) (-14 *4 (-634 (-1161))) (-14 *5 (-1244 (-679 *2))))) (-1828 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 *2)) (-14 *6 (-1244 (-679 *3))))) (-1828 (*1 *1 *2) (-12 (-5 *2 (-1244 (-1161))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-1828 (*1 *1 *2) (-12 (-5 *2 (-1244 (-454 *3 *4 *5 *6))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-1828 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-454 *4 *5 *6 *7))) (-5 *1 (-454 *4 *5 *6 *7)) (-4 *4 (-172)) (-14 *5 (-917)) (-14 *6 (-634 *2)) (-14 *7 (-1244 (-679 *4))))) (-1828 (*1 *1 *2 *3) (-12 (-5 *2 (-1244 (-1161))) (-5 *3 (-1244 (-454 *4 *5 *6 *7))) (-5 *1 (-454 *4 *5 *6 *7)) (-4 *4 (-172)) (-14 *5 (-917)) (-14 *6 (-634 (-1161))) (-14 *7 (-1244 (-679 *4))))) (-4454 (*1 *2) (-12 (-5 *2 (-1157 (-409 (-953 *3)))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-2726 (*1 *2 *1) (-12 (-5 *2 (-1157 (-409 (-953 *3)))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-3102 (*1 *2 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-1318 (*1 *2 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-4408 (*1 *2) (-12 (-5 *2 (-1157 (-409 (-953 *3)))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-1686 (*1 *2 *1) (-12 (-5 *2 (-1157 (-409 (-953 *3)))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-3087 (*1 *2 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-4311 (*1 *2 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-3456 (*1 *2 *1 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-2267 (*1 *2) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-3604 (*1 *2 *1 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-1942 (*1 *2) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-3295 (*1 *2 *3) (-12 (-5 *3 (-1244 (-454 *4 *5 *6 *7))) (-5 *2 (-634 (-953 *4))) (-5 *1 (-454 *4 *5 *6 *7)) (-4 *4 (-558)) (-4 *4 (-172)) (-14 *5 (-917)) (-14 *6 (-634 (-1161))) (-14 *7 (-1244 (-679 *4))))) (-3295 (*1 *2) (-12 (-5 *2 (-634 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
-(-13 (-419 (-409 (-953 |#1|))) (-637 (-1127 |#2| (-409 (-953 |#1|)))) (-10 -8 (-15 -2745 ($ (-1244 (-409 (-953 |#1|))))) (-15 -3116 ((-3 (-2 (|:| |particular| $) (|:| -3746 (-634 $))) "failed"))) (-15 -1309 ((-3 (-2 (|:| |particular| $) (|:| -3746 (-634 $))) "failed"))) (-15 -1828 ($)) (-15 -1828 ($ (-1161))) (-15 -1828 ($ (-1244 (-1161)))) (-15 -1828 ($ (-1244 $))) (-15 -1828 ($ (-1161) (-1244 $))) (-15 -1828 ($ (-1244 (-1161)) (-1244 $))) (IF (|has| |#1| (-558)) (PROGN (-15 -4454 ((-1157 (-409 (-953 |#1|))))) (-15 -2726 ((-1157 (-409 (-953 |#1|))) $)) (-15 -3102 ((-409 (-953 |#1|)) $)) (-15 -1318 ((-409 (-953 |#1|)) $)) (-15 -4408 ((-1157 (-409 (-953 |#1|))))) (-15 -1686 ((-1157 (-409 (-953 |#1|))) $)) (-15 -3087 ((-409 (-953 |#1|)) $)) (-15 -4311 ((-409 (-953 |#1|)) $)) (-15 -3456 ((-409 (-953 |#1|)) $ $)) (-15 -2267 ((-409 (-953 |#1|)))) (-15 -3604 ((-409 (-953 |#1|)) $ $)) (-15 -1942 ((-409 (-953 |#1|)))) (-15 -3295 ((-634 (-953 |#1|)) (-1244 $))) (-15 -3295 ((-634 (-953 |#1|))))) |noBranch|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 13)) (-2055 (((-634 (-852 |#1|)) $) 73)) (-3839 (((-1157 $) $ (-852 |#1|)) 46) (((-1157 |#2|) $) 115)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#2| (-558)))) (-2227 (($ $) NIL (|has| |#2| (-558)))) (-1573 (((-121) $) NIL (|has| |#2| (-558)))) (-2773 (((-763) $) 21) (((-763) $ (-634 (-852 |#1|))) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-4305 (($ $) NIL (|has| |#2| (-453)))) (-1678 (((-420 $) $) NIL (|has| |#2| (-453)))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#2| "failed") $) 44) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#2| (-1037 (-568)))) (((-3 (-852 |#1|) "failed") $) NIL)) (-2854 ((|#2| $) 42) (((-409 (-568)) $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#2| (-1037 (-568)))) (((-852 |#1|) $) NIL)) (-4265 (($ $ $ (-852 |#1|)) NIL (|has| |#2| (-172)))) (-4425 (($ $ (-634 (-568))) 78)) (-2114 (($ $) 67)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL) (((-679 |#2|) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3250 (($ $) NIL (|has| |#2| (-453))) (($ $ (-852 |#1|)) NIL (|has| |#2| (-453)))) (-2108 (((-634 $) $) NIL)) (-3927 (((-121) $) NIL (|has| |#2| (-904)))) (-3088 (($ $ |#2| |#3| $) NIL)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-852 |#1|) (-881 (-381))) (|has| |#2| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-852 |#1|) (-881 (-568))) (|has| |#2| (-881 (-568)))))) (-2735 (((-121) $) NIL)) (-4178 (((-763) $) 58)) (-2051 (($ (-1157 |#2|) (-852 |#1|)) 120) (($ (-1157 $) (-852 |#1|)) 52)) (-2976 (((-634 $) $) NIL)) (-3921 (((-121) $) 59)) (-2047 (($ |#2| |#3|) 28) (($ $ (-852 |#1|) (-763)) 30) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-3379 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $ (-852 |#1|)) NIL)) (-2144 ((|#3| $) NIL) (((-763) $ (-852 |#1|)) 50) (((-634 (-763)) $ (-634 (-852 |#1|))) 57)) (-2521 (($ $ $) NIL (|has| |#2| (-842)))) (-3268 (($ $ $) NIL (|has| |#2| (-842)))) (-3842 (($ (-1 |#3| |#3|) $) NIL)) (-2795 (($ (-1 |#2| |#2|) $) NIL)) (-2244 (((-3 (-852 |#1|) "failed") $) 39)) (-2097 (($ $) NIL)) (-2102 ((|#2| $) 41)) (-2495 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) NIL (|has| |#2| (-453)))) (-4487 (((-1143) $) NIL)) (-3324 (((-3 (-634 $) "failed") $) NIL)) (-1794 (((-3 (-634 $) "failed") $) NIL)) (-3751 (((-3 (-2 (|:| |var| (-852 |#1|)) (|:| -3438 (-763))) "failed") $) NIL)) (-4022 (((-1108) $) NIL)) (-2086 (((-121) $) 40)) (-2091 ((|#2| $) 113)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#2| (-453)))) (-2721 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) 125 (|has| |#2| (-453)))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3848 (((-420 $) $) NIL (|has| |#2| (-904)))) (-2595 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-558)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-852 |#1|) |#2|) 85) (($ $ (-634 (-852 |#1|)) (-634 |#2|)) 88) (($ $ (-852 |#1|) $) 83) (($ $ (-634 (-852 |#1|)) (-634 $)) 104)) (-2217 (($ $ (-852 |#1|)) NIL (|has| |#2| (-172)))) (-4189 (($ $ (-852 |#1|)) 53) (($ $ (-634 (-852 |#1|))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-3206 ((|#3| $) 66) (((-763) $ (-852 |#1|)) 37) (((-634 (-763)) $ (-634 (-852 |#1|))) 56)) (-4278 (((-887 (-381)) $) NIL (-12 (|has| (-852 |#1|) (-609 (-887 (-381)))) (|has| |#2| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-852 |#1|) (-609 (-887 (-568)))) (|has| |#2| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-852 |#1|) (-609 (-541))) (|has| |#2| (-609 (-541)))))) (-3367 ((|#2| $) 122 (|has| |#2| (-453))) (($ $ (-852 |#1|)) NIL (|has| |#2| (-453)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#2| (-904))))) (-2745 (((-850) $) 141) (($ (-568)) NIL) (($ |#2|) 84) (($ (-852 |#1|)) 31) (($ (-409 (-568))) NIL (-2198 (|has| |#2| (-43 (-409 (-568)))) (|has| |#2| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#2| (-558)))) (-1302 (((-634 |#2|) $) NIL)) (-2604 ((|#2| $ |#3|) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| |#2| (-904))) (|has| |#2| (-148))))) (-4078 (((-763)) NIL)) (-4171 (($ $ $ (-763)) NIL (|has| |#2| (-172)))) (-1826 (((-121) $ $) NIL (|has| |#2| (-558)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 16 T CONST)) (-1556 (($) 25 T CONST)) (-3190 (($ $ (-852 |#1|)) NIL) (($ $ (-634 (-852 |#1|))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-1751 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1779 (($ $ |#2|) 64 (|has| |#2| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) 109)) (** (($ $ (-917)) NIL) (($ $ (-763)) 107)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 29) (($ $ (-409 (-568))) NIL (|has| |#2| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#2| (-43 (-409 (-568))))) (($ |#2| $) 63) (($ $ |#2|) NIL))) 
-(((-455 |#1| |#2| |#3|) (-13 (-950 |#2| |#3| (-852 |#1|)) (-10 -8 (-15 -4425 ($ $ (-634 (-568)))))) (-634 (-1161)) (-1047) (-230 (-1697 |#1|) (-763))) (T -455)) 
-((-4425 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-14 *3 (-634 (-1161))) (-5 *1 (-455 *3 *4 *5)) (-4 *4 (-1047)) (-4 *5 (-230 (-1697 *3) (-763)))))) 
-(-13 (-950 |#2| |#3| (-852 |#1|)) (-10 -8 (-15 -4425 ($ $ (-634 (-568)))))) 
-((-4491 (((-1249) (-310 (-381)) (-1082 (-381)) (-1082 (-381)) (-1143)) 49) (((-1249) (-310 (-381)) (-1082 (-381)) (-1082 (-381)) (-1143) (-634 (-256))) 48) (((-1249) (-310 (-381)) (-1082 (-381)) (-1143)) 42) (((-1249) (-310 (-381)) (-1082 (-381)) (-1143) (-634 (-256))) 39))) 
-(((-456) (-10 -7 (-15 -4491 ((-1249) (-310 (-381)) (-1082 (-381)) (-1143) (-634 (-256)))) (-15 -4491 ((-1249) (-310 (-381)) (-1082 (-381)) (-1143))) (-15 -4491 ((-1249) (-310 (-381)) (-1082 (-381)) (-1082 (-381)) (-1143) (-634 (-256)))) (-15 -4491 ((-1249) (-310 (-381)) (-1082 (-381)) (-1082 (-381)) (-1143))))) (T -456)) 
-((-4491 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-381))) (-5 *5 (-1143)) (-5 *2 (-1249)) (-5 *1 (-456)))) (-4491 (*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-381))) (-5 *5 (-1143)) (-5 *6 (-634 (-256))) (-5 *2 (-1249)) (-5 *1 (-456)))) (-4491 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-381))) (-5 *5 (-1143)) (-5 *2 (-1249)) (-5 *1 (-456)))) (-4491 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-381))) (-5 *5 (-1143)) (-5 *6 (-634 (-256))) (-5 *2 (-1249)) (-5 *1 (-456))))) 
-(-10 -7 (-15 -4491 ((-1249) (-310 (-381)) (-1082 (-381)) (-1143) (-634 (-256)))) (-15 -4491 ((-1249) (-310 (-381)) (-1082 (-381)) (-1143))) (-15 -4491 ((-1249) (-310 (-381)) (-1082 (-381)) (-1082 (-381)) (-1143) (-634 (-256)))) (-15 -4491 ((-1249) (-310 (-381)) (-1082 (-381)) (-1082 (-381)) (-1143)))) 
-((-1672 (((-121) |#1| (-634 |#2|)) 65)) (-3287 (((-3 (-1244 (-634 |#2|)) "failed") (-763) |#1| (-634 |#2|)) 74)) (-2894 (((-3 (-634 |#2|) "failed") |#2| |#1| (-1244 (-634 |#2|))) 76)) (-3627 ((|#2| |#2| |#1|) 28)) (-4362 (((-763) |#2| (-634 |#2|)) 20))) 
-(((-457 |#1| |#2|) (-10 -7 (-15 -3627 (|#2| |#2| |#1|)) (-15 -4362 ((-763) |#2| (-634 |#2|))) (-15 -3287 ((-3 (-1244 (-634 |#2|)) "failed") (-763) |#1| (-634 |#2|))) (-15 -2894 ((-3 (-634 |#2|) "failed") |#2| |#1| (-1244 (-634 |#2|)))) (-15 -1672 ((-121) |#1| (-634 |#2|)))) (-301) (-1219 |#1|)) (T -457)) 
-((-1672 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *5)) (-4 *5 (-1219 *3)) (-4 *3 (-301)) (-5 *2 (-121)) (-5 *1 (-457 *3 *5)))) (-2894 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1244 (-634 *3))) (-4 *4 (-301)) (-5 *2 (-634 *3)) (-5 *1 (-457 *4 *3)) (-4 *3 (-1219 *4)))) (-3287 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-763)) (-4 *4 (-301)) (-4 *6 (-1219 *4)) (-5 *2 (-1244 (-634 *6))) (-5 *1 (-457 *4 *6)) (-5 *5 (-634 *6)))) (-4362 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-301)) (-5 *2 (-763)) (-5 *1 (-457 *5 *3)))) (-3627 (*1 *2 *2 *3) (-12 (-4 *3 (-301)) (-5 *1 (-457 *3 *2)) (-4 *2 (-1219 *3))))) 
-(-10 -7 (-15 -3627 (|#2| |#2| |#1|)) (-15 -4362 ((-763) |#2| (-634 |#2|))) (-15 -3287 ((-3 (-1244 (-634 |#2|)) "failed") (-763) |#1| (-634 |#2|))) (-15 -2894 ((-3 (-634 |#2|) "failed") |#2| |#1| (-1244 (-634 |#2|)))) (-15 -1672 ((-121) |#1| (-634 |#2|)))) 
-((-3848 (((-420 |#5|) |#5|) 24))) 
-(((-458 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3848 ((-420 |#5|) |#5|))) (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $)) (-15 -1305 ((-3 $ "failed") (-1161))))) (-788) (-558) (-558) (-950 |#4| |#2| |#1|)) (T -458)) 
-((-3848 (*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $)) (-15 -1305 ((-3 $ "failed") (-1161)))))) (-4 *5 (-788)) (-4 *7 (-558)) (-5 *2 (-420 *3)) (-5 *1 (-458 *4 *5 *6 *7 *3)) (-4 *6 (-558)) (-4 *3 (-950 *7 *5 *4))))) 
-(-10 -7 (-15 -3848 ((-420 |#5|) |#5|))) 
-((-3629 ((|#3|) 36)) (-2155 (((-1157 |#4|) (-1157 |#4|) (-1157 |#4|)) 32))) 
-(((-459 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2155 ((-1157 |#4|) (-1157 |#4|) (-1157 |#4|))) (-15 -3629 (|#3|))) (-788) (-842) (-904) (-950 |#3| |#1| |#2|)) (T -459)) 
-((-3629 (*1 *2) (-12 (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-904)) (-5 *1 (-459 *3 *4 *2 *5)) (-4 *5 (-950 *2 *3 *4)))) (-2155 (*1 *2 *2 *2) (-12 (-5 *2 (-1157 *6)) (-4 *6 (-950 *5 *3 *4)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-904)) (-5 *1 (-459 *3 *4 *5 *6))))) 
-(-10 -7 (-15 -2155 ((-1157 |#4|) (-1157 |#4|) (-1157 |#4|))) (-15 -3629 (|#3|))) 
-((-3848 (((-420 (-1157 |#1|)) (-1157 |#1|)) 41))) 
-(((-460 |#1|) (-10 -7 (-15 -3848 ((-420 (-1157 |#1|)) (-1157 |#1|)))) (-301)) (T -460)) 
-((-3848 (*1 *2 *3) (-12 (-4 *4 (-301)) (-5 *2 (-420 (-1157 *4))) (-5 *1 (-460 *4)) (-5 *3 (-1157 *4))))) 
-(-10 -7 (-15 -3848 ((-420 (-1157 |#1|)) (-1157 |#1|)))) 
-((-2065 (((-57) |#2| (-1161) (-288 |#2|) (-1210 (-763))) 42) (((-57) (-1 |#2| (-568)) (-288 |#2|) (-1210 (-763))) 41) (((-57) |#2| (-1161) (-288 |#2|)) 35) (((-57) (-1 |#2| (-568)) (-288 |#2|)) 27)) (-3728 (((-57) |#2| (-1161) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568))) 80) (((-57) (-1 |#2| (-409 (-568))) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568))) 79) (((-57) |#2| (-1161) (-288 |#2|) (-1210 (-568))) 78) (((-57) (-1 |#2| (-568)) (-288 |#2|) (-1210 (-568))) 77) (((-57) |#2| (-1161) (-288 |#2|)) 72) (((-57) (-1 |#2| (-568)) (-288 |#2|)) 71)) (-2075 (((-57) |#2| (-1161) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568))) 66) (((-57) (-1 |#2| (-409 (-568))) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568))) 64)) (-2070 (((-57) |#2| (-1161) (-288 |#2|) (-1210 (-568))) 48) (((-57) (-1 |#2| (-568)) (-288 |#2|) (-1210 (-568))) 47))) 
-(((-461 |#1| |#2|) (-10 -7 (-15 -2065 ((-57) (-1 |#2| (-568)) (-288 |#2|))) (-15 -2065 ((-57) |#2| (-1161) (-288 |#2|))) (-15 -2065 ((-57) (-1 |#2| (-568)) (-288 |#2|) (-1210 (-763)))) (-15 -2065 ((-57) |#2| (-1161) (-288 |#2|) (-1210 (-763)))) (-15 -2070 ((-57) (-1 |#2| (-568)) (-288 |#2|) (-1210 (-568)))) (-15 -2070 ((-57) |#2| (-1161) (-288 |#2|) (-1210 (-568)))) (-15 -2075 ((-57) (-1 |#2| (-409 (-568))) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568)))) (-15 -2075 ((-57) |#2| (-1161) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568)))) (-15 -3728 ((-57) (-1 |#2| (-568)) (-288 |#2|))) (-15 -3728 ((-57) |#2| (-1161) (-288 |#2|))) (-15 -3728 ((-57) (-1 |#2| (-568)) (-288 |#2|) (-1210 (-568)))) (-15 -3728 ((-57) |#2| (-1161) (-288 |#2|) (-1210 (-568)))) (-15 -3728 ((-57) (-1 |#2| (-409 (-568))) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568)))) (-15 -3728 ((-57) |#2| (-1161) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568))))) (-13 (-558) (-842) (-1037 (-568)) (-630 (-568))) (-13 (-27) (-1181) (-432 |#1|))) (T -461)) 
-((-3728 (*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-5 *6 (-1210 (-409 (-568)))) (-5 *7 (-409 (-568))) (-4 *3 (-13 (-27) (-1181) (-432 *8))) (-4 *8 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *8 *3)))) (-3728 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *8 (-409 (-568)))) (-5 *4 (-288 *8)) (-5 *5 (-1210 (-409 (-568)))) (-5 *6 (-409 (-568))) (-4 *8 (-13 (-27) (-1181) (-432 *7))) (-4 *7 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *7 *8)))) (-3728 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-5 *6 (-1210 (-568))) (-4 *3 (-13 (-27) (-1181) (-432 *7))) (-4 *7 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *7 *3)))) (-3728 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *7 (-568))) (-5 *4 (-288 *7)) (-5 *5 (-1210 (-568))) (-4 *7 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *6 *7)))) (-3728 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *6 *3)))) (-3728 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 (-568))) (-5 *4 (-288 *6)) (-4 *6 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *5 *6)))) (-2075 (*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-5 *6 (-1210 (-409 (-568)))) (-5 *7 (-409 (-568))) (-4 *3 (-13 (-27) (-1181) (-432 *8))) (-4 *8 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *8 *3)))) (-2075 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *8 (-409 (-568)))) (-5 *4 (-288 *8)) (-5 *5 (-1210 (-409 (-568)))) (-5 *6 (-409 (-568))) (-4 *8 (-13 (-27) (-1181) (-432 *7))) (-4 *7 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *7 *8)))) (-2070 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-5 *6 (-1210 (-568))) (-4 *3 (-13 (-27) (-1181) (-432 *7))) (-4 *7 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *7 *3)))) (-2070 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *7 (-568))) (-5 *4 (-288 *7)) (-5 *5 (-1210 (-568))) (-4 *7 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *6 *7)))) (-2065 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-5 *6 (-1210 (-763))) (-4 *3 (-13 (-27) (-1181) (-432 *7))) (-4 *7 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *7 *3)))) (-2065 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *7 (-568))) (-5 *4 (-288 *7)) (-5 *5 (-1210 (-763))) (-4 *7 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *6 *7)))) (-2065 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *6 *3)))) (-2065 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 (-568))) (-5 *4 (-288 *6)) (-4 *6 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *5 *6))))) 
-(-10 -7 (-15 -2065 ((-57) (-1 |#2| (-568)) (-288 |#2|))) (-15 -2065 ((-57) |#2| (-1161) (-288 |#2|))) (-15 -2065 ((-57) (-1 |#2| (-568)) (-288 |#2|) (-1210 (-763)))) (-15 -2065 ((-57) |#2| (-1161) (-288 |#2|) (-1210 (-763)))) (-15 -2070 ((-57) (-1 |#2| (-568)) (-288 |#2|) (-1210 (-568)))) (-15 -2070 ((-57) |#2| (-1161) (-288 |#2|) (-1210 (-568)))) (-15 -2075 ((-57) (-1 |#2| (-409 (-568))) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568)))) (-15 -2075 ((-57) |#2| (-1161) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568)))) (-15 -3728 ((-57) (-1 |#2| (-568)) (-288 |#2|))) (-15 -3728 ((-57) |#2| (-1161) (-288 |#2|))) (-15 -3728 ((-57) (-1 |#2| (-568)) (-288 |#2|) (-1210 (-568)))) (-15 -3728 ((-57) |#2| (-1161) (-288 |#2|) (-1210 (-568)))) (-15 -3728 ((-57) (-1 |#2| (-409 (-568))) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568)))) (-15 -3728 ((-57) |#2| (-1161) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568))))) 
-((-3627 ((|#2| |#2| |#1|) 15)) (-1693 (((-634 |#2|) |#2| (-634 |#2|) |#1| (-917)) 65)) (-3782 (((-2 (|:| |plist| (-634 |#2|)) (|:| |modulo| |#1|)) |#2| (-634 |#2|) |#1| (-917)) 58))) 
-(((-462 |#1| |#2|) (-10 -7 (-15 -3782 ((-2 (|:| |plist| (-634 |#2|)) (|:| |modulo| |#1|)) |#2| (-634 |#2|) |#1| (-917))) (-15 -1693 ((-634 |#2|) |#2| (-634 |#2|) |#1| (-917))) (-15 -3627 (|#2| |#2| |#1|))) (-301) (-1219 |#1|)) (T -462)) 
-((-3627 (*1 *2 *2 *3) (-12 (-4 *3 (-301)) (-5 *1 (-462 *3 *2)) (-4 *2 (-1219 *3)))) (-1693 (*1 *2 *3 *2 *4 *5) (-12 (-5 *2 (-634 *3)) (-5 *5 (-917)) (-4 *3 (-1219 *4)) (-4 *4 (-301)) (-5 *1 (-462 *4 *3)))) (-3782 (*1 *2 *3 *4 *5 *6) (-12 (-5 *6 (-917)) (-4 *5 (-301)) (-4 *3 (-1219 *5)) (-5 *2 (-2 (|:| |plist| (-634 *3)) (|:| |modulo| *5))) (-5 *1 (-462 *5 *3)) (-5 *4 (-634 *3))))) 
-(-10 -7 (-15 -3782 ((-2 (|:| |plist| (-634 |#2|)) (|:| |modulo| |#1|)) |#2| (-634 |#2|) |#1| (-917))) (-15 -1693 ((-634 |#2|) |#2| (-634 |#2|) |#1| (-917))) (-15 -3627 (|#2| |#2| |#1|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 28)) (-1394 (($ |#3|) 25)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-2114 (($ $) 32)) (-3947 (($ |#2| |#4| $) 33)) (-2047 (($ |#2| (-703 |#3| |#4| |#5|)) 24)) (-2097 (((-703 |#3| |#4| |#5|) $) 15)) (-1445 ((|#3| $) 19)) (-3401 ((|#4| $) 17)) (-2102 ((|#2| $) 29)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-1863 (($ |#2| |#3| |#4|) 26)) (-3056 (($) 36 T CONST)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) 34)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ |#6| $) 40) (($ $ |#6|) NIL) (($ $ |#2|) NIL) (($ |#2| $) NIL))) 
-(((-463 |#1| |#2| |#3| |#4| |#5| |#6|) (-13 (-707 |#6|) (-707 |#2|) (-10 -8 (-15 -2102 (|#2| $)) (-15 -2097 ((-703 |#3| |#4| |#5|) $)) (-15 -3401 (|#4| $)) (-15 -1445 (|#3| $)) (-15 -2114 ($ $)) (-15 -2047 ($ |#2| (-703 |#3| |#4| |#5|))) (-15 -1394 ($ |#3|)) (-15 -1863 ($ |#2| |#3| |#4|)) (-15 -3947 ($ |#2| |#4| $)) (-15 * ($ |#6| $)))) (-634 (-1161)) (-172) (-842) (-230 (-1697 |#1|) (-763)) (-1 (-121) (-2 (|:| -4355 |#3|) (|:| -3438 |#4|)) (-2 (|:| -4355 |#3|) (|:| -3438 |#4|))) (-950 |#2| |#4| (-852 |#1|))) (T -463)) 
-((* (*1 *1 *2 *1) (-12 (-14 *3 (-634 (-1161))) (-4 *4 (-172)) (-4 *6 (-230 (-1697 *3) (-763))) (-14 *7 (-1 (-121) (-2 (|:| -4355 *5) (|:| -3438 *6)) (-2 (|:| -4355 *5) (|:| -3438 *6)))) (-5 *1 (-463 *3 *4 *5 *6 *7 *2)) (-4 *5 (-842)) (-4 *2 (-950 *4 *6 (-852 *3))))) (-2102 (*1 *2 *1) (-12 (-14 *3 (-634 (-1161))) (-4 *5 (-230 (-1697 *3) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4355 *4) (|:| -3438 *5)) (-2 (|:| -4355 *4) (|:| -3438 *5)))) (-4 *2 (-172)) (-5 *1 (-463 *3 *2 *4 *5 *6 *7)) (-4 *4 (-842)) (-4 *7 (-950 *2 *5 (-852 *3))))) (-2097 (*1 *2 *1) (-12 (-14 *3 (-634 (-1161))) (-4 *4 (-172)) (-4 *6 (-230 (-1697 *3) (-763))) (-14 *7 (-1 (-121) (-2 (|:| -4355 *5) (|:| -3438 *6)) (-2 (|:| -4355 *5) (|:| -3438 *6)))) (-5 *2 (-703 *5 *6 *7)) (-5 *1 (-463 *3 *4 *5 *6 *7 *8)) (-4 *5 (-842)) (-4 *8 (-950 *4 *6 (-852 *3))))) (-3401 (*1 *2 *1) (-12 (-14 *3 (-634 (-1161))) (-4 *4 (-172)) (-14 *6 (-1 (-121) (-2 (|:| -4355 *5) (|:| -3438 *2)) (-2 (|:| -4355 *5) (|:| -3438 *2)))) (-4 *2 (-230 (-1697 *3) (-763))) (-5 *1 (-463 *3 *4 *5 *2 *6 *7)) (-4 *5 (-842)) (-4 *7 (-950 *4 *2 (-852 *3))))) (-1445 (*1 *2 *1) (-12 (-14 *3 (-634 (-1161))) (-4 *4 (-172)) (-4 *5 (-230 (-1697 *3) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4355 *2) (|:| -3438 *5)) (-2 (|:| -4355 *2) (|:| -3438 *5)))) (-4 *2 (-842)) (-5 *1 (-463 *3 *4 *2 *5 *6 *7)) (-4 *7 (-950 *4 *5 (-852 *3))))) (-2114 (*1 *1 *1) (-12 (-14 *2 (-634 (-1161))) (-4 *3 (-172)) (-4 *5 (-230 (-1697 *2) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4355 *4) (|:| -3438 *5)) (-2 (|:| -4355 *4) (|:| -3438 *5)))) (-5 *1 (-463 *2 *3 *4 *5 *6 *7)) (-4 *4 (-842)) (-4 *7 (-950 *3 *5 (-852 *2))))) (-2047 (*1 *1 *2 *3) (-12 (-5 *3 (-703 *5 *6 *7)) (-4 *5 (-842)) (-4 *6 (-230 (-1697 *4) (-763))) (-14 *7 (-1 (-121) (-2 (|:| -4355 *5) (|:| -3438 *6)) (-2 (|:| -4355 *5) (|:| -3438 *6)))) (-14 *4 (-634 (-1161))) (-4 *2 (-172)) (-5 *1 (-463 *4 *2 *5 *6 *7 *8)) (-4 *8 (-950 *2 *6 (-852 *4))))) (-1394 (*1 *1 *2) (-12 (-14 *3 (-634 (-1161))) (-4 *4 (-172)) (-4 *5 (-230 (-1697 *3) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4355 *2) (|:| -3438 *5)) (-2 (|:| -4355 *2) (|:| -3438 *5)))) (-5 *1 (-463 *3 *4 *2 *5 *6 *7)) (-4 *2 (-842)) (-4 *7 (-950 *4 *5 (-852 *3))))) (-1863 (*1 *1 *2 *3 *4) (-12 (-14 *5 (-634 (-1161))) (-4 *2 (-172)) (-4 *4 (-230 (-1697 *5) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4355 *3) (|:| -3438 *4)) (-2 (|:| -4355 *3) (|:| -3438 *4)))) (-5 *1 (-463 *5 *2 *3 *4 *6 *7)) (-4 *3 (-842)) (-4 *7 (-950 *2 *4 (-852 *5))))) (-3947 (*1 *1 *2 *3 *1) (-12 (-14 *4 (-634 (-1161))) (-4 *2 (-172)) (-4 *3 (-230 (-1697 *4) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4355 *5) (|:| -3438 *3)) (-2 (|:| -4355 *5) (|:| -3438 *3)))) (-5 *1 (-463 *4 *2 *5 *3 *6 *7)) (-4 *5 (-842)) (-4 *7 (-950 *2 *3 (-852 *4)))))) 
-(-13 (-707 |#6|) (-707 |#2|) (-10 -8 (-15 -2102 (|#2| $)) (-15 -2097 ((-703 |#3| |#4| |#5|) $)) (-15 -3401 (|#4| $)) (-15 -1445 (|#3| $)) (-15 -2114 ($ $)) (-15 -2047 ($ |#2| (-703 |#3| |#4| |#5|))) (-15 -1394 ($ |#3|)) (-15 -1863 ($ |#2| |#3| |#4|)) (-15 -3947 ($ |#2| |#4| $)) (-15 * ($ |#6| $)))) 
-((-2447 (((-121) $ $) NIL)) (-1402 (((-1161) (-634 (-465))) 34)) (-1581 (((-763) (-634 (-465))) 28)) (-3189 (((-121) (-634 (-465))) 29)) (-3423 (((-568) (-634 (-465))) 20)) (-3521 (((-568) (-634 (-465))) 26)) (-3439 (((-568) (-634 (-465))) 18)) (-3765 (((-568) (-634 (-465))) 19)) (-4080 (((-568) (-634 (-465))) 21)) (-4487 (((-1143) $) NIL)) (-2836 (((-1161) (-634 (-465))) 36)) (-2884 (((-121) (-634 (-465))) 31)) (-4022 (((-1108) $) NIL)) (-3046 (((-1161) (-634 (-465))) 35)) (-3052 (((-121) (-634 (-465))) 37)) (-4019 (((-121) (-634 (-465))) 30)) (-2745 (((-850) $) NIL)) (-1706 (((-121) (-634 (-465))) 25)) (-1717 (((-121) $ $) NIL))) 
-(((-464) (-13 (-1090) (-10 -7 (-15 -3439 ((-568) (-634 (-465)))) (-15 -3521 ((-568) (-634 (-465)))) (-15 -3765 ((-568) (-634 (-465)))) (-15 -3423 ((-568) (-634 (-465)))) (-15 -4080 ((-568) (-634 (-465)))) (-15 -1706 ((-121) (-634 (-465)))) (-15 -1581 ((-763) (-634 (-465)))) (-15 -3189 ((-121) (-634 (-465)))) (-15 -2884 ((-121) (-634 (-465)))) (-15 -3046 ((-1161) (-634 (-465)))) (-15 -1402 ((-1161) (-634 (-465)))) (-15 -2836 ((-1161) (-634 (-465)))) (-15 -3052 ((-121) (-634 (-465)))) (-15 -4019 ((-121) (-634 (-465))))))) (T -464)) 
-((-3439 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-568)) (-5 *1 (-464)))) (-3521 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-568)) (-5 *1 (-464)))) (-3765 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-568)) (-5 *1 (-464)))) (-3423 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-568)) (-5 *1 (-464)))) (-4080 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-568)) (-5 *1 (-464)))) (-1706 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-121)) (-5 *1 (-464)))) (-1581 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-763)) (-5 *1 (-464)))) (-3189 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-121)) (-5 *1 (-464)))) (-2884 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-121)) (-5 *1 (-464)))) (-3046 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-1161)) (-5 *1 (-464)))) (-1402 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-1161)) (-5 *1 (-464)))) (-2836 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-1161)) (-5 *1 (-464)))) (-3052 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-121)) (-5 *1 (-464)))) (-4019 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-121)) (-5 *1 (-464))))) 
-(-13 (-1090) (-10 -7 (-15 -3439 ((-568) (-634 (-465)))) (-15 -3521 ((-568) (-634 (-465)))) (-15 -3765 ((-568) (-634 (-465)))) (-15 -3423 ((-568) (-634 (-465)))) (-15 -4080 ((-568) (-634 (-465)))) (-15 -1706 ((-121) (-634 (-465)))) (-15 -1581 ((-763) (-634 (-465)))) (-15 -3189 ((-121) (-634 (-465)))) (-15 -2884 ((-121) (-634 (-465)))) (-15 -3046 ((-1161) (-634 (-465)))) (-15 -1402 ((-1161) (-634 (-465)))) (-15 -2836 ((-1161) (-634 (-465)))) (-15 -3052 ((-121) (-634 (-465)))) (-15 -4019 ((-121) (-634 (-465)))))) 
-((-2447 (((-121) $ $) NIL)) (-1402 (($ (-1161)) 31)) (-1581 (($ (-763)) 24)) (-1507 (((-121) (-634 $) (-1161)) 42)) (-2960 (((-3 (-57) "failed") (-634 $) (-1161)) 44)) (-3189 (($ (-121)) 27)) (-3423 (($ (-568)) 16)) (-3521 (($ (-568)) 22)) (-3439 (($ (-568)) 14)) (-3765 (($ (-568)) 15)) (-4080 (($ (-568)) 17)) (-4487 (((-1143) $) NIL)) (-2836 (($ (-1161)) 32)) (-2884 (($ (-121)) 25)) (-4022 (((-1108) $) NIL)) (-3046 (($ (-1161)) 30)) (-3052 (($ (-121)) 33)) (-4019 (($ (-121)) 26)) (-2745 (((-850) $) 38)) (-2452 (((-1249) (-634 $)) 54)) (-1706 (($ (-121)) 21)) (-1717 (((-121) $ $) 40))) 
-(((-465) (-13 (-1090) (-10 -8 (-15 -3765 ($ (-568))) (-15 -3423 ($ (-568))) (-15 -3521 ($ (-568))) (-15 -2884 ($ (-121))) (-15 -3439 ($ (-568))) (-15 -4080 ($ (-568))) (-15 -1706 ($ (-121))) (-15 -1581 ($ (-763))) (-15 -3189 ($ (-121))) (-15 -4019 ($ (-121))) (-15 -3046 ($ (-1161))) (-15 -1402 ($ (-1161))) (-15 -2836 ($ (-1161))) (-15 -3052 ($ (-121))) (-15 -2960 ((-3 (-57) "failed") (-634 $) (-1161))) (-15 -1507 ((-121) (-634 $) (-1161))) (-15 -2452 ((-1249) (-634 $)))))) (T -465)) 
-((-3765 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-465)))) (-3423 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-465)))) (-3521 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-465)))) (-2884 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-465)))) (-3439 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-465)))) (-4080 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-465)))) (-1706 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-465)))) (-1581 (*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-465)))) (-3189 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-465)))) (-4019 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-465)))) (-3046 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-465)))) (-1402 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-465)))) (-2836 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-465)))) (-3052 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-465)))) (-2960 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-634 (-465))) (-5 *4 (-1161)) (-5 *2 (-57)) (-5 *1 (-465)))) (-1507 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-465))) (-5 *4 (-1161)) (-5 *2 (-121)) (-5 *1 (-465)))) (-2452 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-1249)) (-5 *1 (-465))))) 
-(-13 (-1090) (-10 -8 (-15 -3765 ($ (-568))) (-15 -3423 ($ (-568))) (-15 -3521 ($ (-568))) (-15 -2884 ($ (-121))) (-15 -3439 ($ (-568))) (-15 -4080 ($ (-568))) (-15 -1706 ($ (-121))) (-15 -1581 ($ (-763))) (-15 -3189 ($ (-121))) (-15 -4019 ($ (-121))) (-15 -3046 ($ (-1161))) (-15 -1402 ($ (-1161))) (-15 -2836 ($ (-1161))) (-15 -3052 ($ (-121))) (-15 -2960 ((-3 (-57) "failed") (-634 $) (-1161))) (-15 -1507 ((-121) (-634 $) (-1161))) (-15 -2452 ((-1249) (-634 $))))) 
-((-3103 (((-3 |#5| "failed") |#5| |#2| (-1 |#2|)) 35))) 
-(((-466 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3103 ((-3 |#5| "failed") |#5| |#2| (-1 |#2|)))) (-788) (-842) (-558) (-950 |#3| |#1| |#2|) (-13 (-1037 (-409 (-568))) (-365) (-10 -8 (-15 -2745 ($ |#4|)) (-15 -2317 (|#4| $)) (-15 -2324 (|#4| $))))) (T -466)) 
-((-3103 (*1 *2 *2 *3 *4) (|partial| -12 (-5 *4 (-1 *3)) (-4 *3 (-842)) (-4 *5 (-788)) (-4 *6 (-558)) (-4 *7 (-950 *6 *5 *3)) (-5 *1 (-466 *5 *3 *6 *7 *2)) (-4 *2 (-13 (-1037 (-409 (-568))) (-365) (-10 -8 (-15 -2745 ($ *7)) (-15 -2317 (*7 $)) (-15 -2324 (*7 $)))))))) 
-(-10 -7 (-15 -3103 ((-3 |#5| "failed") |#5| |#2| (-1 |#2|)))) 
-((-2606 ((|#3|) 43)) (-1846 (((-634 |#5|)) 47)) (-4149 (((-634 |#5|) (-634 |#5|)) 129)) (-4276 ((|#3| |#3|) 107)) (-2316 (((-1249)) 106)) (-1895 (((-634 |#5|)) 150 (|has| |#1| (-370)))) (-4397 (((-634 |#7|)) 153 (|has| |#1| (-370)))) (-1277 (((-1249) (-634 (-121))) 120)) (-1279 ((|#5| |#7|) 94)) (-1375 (((-634 |#7|) (-917)) 149 (|has| |#1| (-370)))) (-1547 (((-634 |#7|) |#5|) 92)) (-2215 ((|#6| |#3| |#7|) 97)) (-3354 (((-568) (-917)) 194 (|has| |#1| (-370)))) (-3114 (((-568) (-917) (-917)) 193 (|has| |#1| (-370)))) (-3281 (((-568) (-917)) 176 (|has| |#1| (-370)))) (-2246 (((-2 (|:| |num| (-634 |#3|)) (|:| |den| |#3|)) |#8|) 69)) (-2411 ((|#8| |#3|) 50)) (-2525 (((-634 |#3|) |#8| (-634 |#3|)) 136)) (-2664 (((-634 |#3|) |#8| (-763)) 65)) (-3039 ((|#3| |#3| (-568)) 40)) (-1801 (((-568)) 74)) (-2126 (((-763)) 73)) (-1640 (((-2 (|:| -1379 (-568)) (|:| |num| |#3|) (|:| |den| |#3|) (|:| |upTo| (-568))) |#8| (-568) (-568)) 114)) (-3781 (((-3 |#1| "failed") (-409 |#3|) |#7|) 144) (((-3 |#1| "failed") |#3| |#3| |#7|) 139) (((-3 |#1| "failed") |#3| |#7|) 104)) (-1339 ((|#1| (-409 |#3|) |#7|) 145) ((|#1| |#3| |#3| |#7|) 140) ((|#1| |#3| |#7|) 105)) (-4007 (((-634 |#10|)) 70)) (-2176 (((-634 |#10|)) 45)) (-2277 (((-568)) 204 (|has| |#1| (-370)))) (-2480 ((|#8|) 54)) (-2596 (((-1239 (-568) -3492) (-917)) 155 (|has| |#1| (-370))) (((-1239 (-568) -3492)) 156 (|has| |#1| (-370)))) (-1637 (((-1157 (-568)) (-917)) 158 (|has| |#1| (-370))) (((-1157 (-568))) 196 (|has| |#1| (-370))))) 
-(((-467 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9| |#10| |#11|) (-10 -7 (-15 -2316 ((-1249))) (-15 -4276 (|#3| |#3|)) (-15 -3039 (|#3| |#3| (-568))) (-15 -1277 ((-1249) (-634 (-121)))) (-15 -2606 (|#3|)) (-15 -2126 ((-763))) (-15 -1801 ((-568))) (-15 -2176 ((-634 |#10|))) (-15 -4007 ((-634 |#10|))) (-15 -4149 ((-634 |#5|) (-634 |#5|))) (-15 -1846 ((-634 |#5|))) (-15 -2215 (|#6| |#3| |#7|)) (-15 -2246 ((-2 (|:| |num| (-634 |#3|)) (|:| |den| |#3|)) |#8|)) (-15 -1640 ((-2 (|:| -1379 (-568)) (|:| |num| |#3|) (|:| |den| |#3|) (|:| |upTo| (-568))) |#8| (-568) (-568))) (-15 -2664 ((-634 |#3|) |#8| (-763))) (-15 -2525 ((-634 |#3|) |#8| (-634 |#3|))) (-15 -1339 (|#1| |#3| |#7|)) (-15 -1339 (|#1| |#3| |#3| |#7|)) (-15 -1339 (|#1| (-409 |#3|) |#7|)) (-15 -3781 ((-3 |#1| "failed") |#3| |#7|)) (-15 -3781 ((-3 |#1| "failed") |#3| |#3| |#7|)) (-15 -3781 ((-3 |#1| "failed") (-409 |#3|) |#7|)) (-15 -2411 (|#8| |#3|)) (-15 -2480 (|#8|)) (-15 -1547 ((-634 |#7|) |#5|)) (-15 -1279 (|#5| |#7|)) (IF (|has| |#1| (-370)) (PROGN (-15 -4397 ((-634 |#7|))) (-15 -1895 ((-634 |#5|))) (-15 -1637 ((-1157 (-568)))) (-15 -1637 ((-1157 (-568)) (-917))) (-15 -2277 ((-568))) (-15 -1375 ((-634 |#7|) (-917))) (-15 -3281 ((-568) (-917))) (-15 -3354 ((-568) (-917))) (-15 -3114 ((-568) (-917) (-917))) (-15 -2596 ((-1239 (-568) -3492))) (-15 -2596 ((-1239 (-568) -3492) (-917)))) |noBranch|)) (-365) (-634 (-1161)) (-950 |#1| |#4| (-852 |#2|)) (-230 (-1697 |#2|) (-763)) (-971 |#1|) (-641 |#1|) (-920 |#1| |#6|) (-235 |#7|) (-536 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#11|) (-258 |#9|) (-117)) (T -467)) 
-((-2596 (*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-1239 (-568) -3492)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) (-2596 (*1 *2) (-12 (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-1239 (-568) -3492)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-3114 (*1 *2 *3 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-568)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) (-3354 (*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-568)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) (-3281 (*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-568)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) (-1375 (*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-634 *10)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) (-2277 (*1 *2) (-12 (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-568)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-1637 (*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-1157 (-568))) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) (-1637 (*1 *2) (-12 (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-1157 (-568))) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-1895 (*1 *2) (-12 (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *7)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-4397 (*1 *2) (-12 (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *9)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-1279 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-641 *4)) (-4 *3 (-920 *4 *8)) (-4 *9 (-235 *3)) (-4 *10 (-536 *4 *5 *6 *7 *2 *8 *3 *9 *12)) (-4 *12 (-117)) (-4 *2 (-971 *4)) (-5 *1 (-467 *4 *5 *6 *7 *2 *8 *3 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) (-1547 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *3 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *4 *5 *6 *7 *3 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *9)) (-5 *1 (-467 *4 *5 *6 *7 *3 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-2480 (*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-536 *3 *4 *5 *6 *7 *8 *9 *2 *12)) (-4 *12 (-117)) (-4 *2 (-235 *9)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *2 *10 *11 *12)) (-4 *11 (-258 *10)))) (-2411 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *6 (-230 (-1697 *5) (-763))) (-4 *7 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-536 *4 *5 *3 *6 *7 *8 *9 *2 *12)) (-4 *12 (-117)) (-4 *2 (-235 *9)) (-5 *1 (-467 *4 *5 *3 *6 *7 *8 *9 *2 *10 *11 *12)) (-4 *11 (-258 *10)))) (-3781 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 *6)) (-4 *6 (-950 *2 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-14 *5 (-634 (-1161))) (-4 *8 (-971 *2)) (-4 *9 (-641 *2)) (-4 *4 (-920 *2 *9)) (-4 *10 (-235 *4)) (-4 *11 (-536 *2 *5 *6 *7 *8 *9 *4 *10 *13)) (-4 *13 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *6 *7 *8 *9 *4 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-3781 (*1 *2 *3 *3 *4) (|partial| -12 (-14 *5 (-634 (-1161))) (-4 *3 (-950 *2 *6 (-852 *5))) (-4 *6 (-230 (-1697 *5) (-763))) (-4 *7 (-971 *2)) (-4 *8 (-641 *2)) (-4 *4 (-920 *2 *8)) (-4 *9 (-235 *4)) (-4 *10 (-536 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) (-3781 (*1 *2 *3 *4) (|partial| -12 (-14 *5 (-634 (-1161))) (-4 *3 (-950 *2 *6 (-852 *5))) (-4 *6 (-230 (-1697 *5) (-763))) (-4 *7 (-971 *2)) (-4 *8 (-641 *2)) (-4 *4 (-920 *2 *8)) (-4 *9 (-235 *4)) (-4 *10 (-536 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) (-1339 (*1 *2 *3 *4) (-12 (-5 *3 (-409 *6)) (-4 *6 (-950 *2 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-14 *5 (-634 (-1161))) (-4 *8 (-971 *2)) (-4 *9 (-641 *2)) (-4 *4 (-920 *2 *9)) (-4 *10 (-235 *4)) (-4 *11 (-536 *2 *5 *6 *7 *8 *9 *4 *10 *13)) (-4 *13 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *6 *7 *8 *9 *4 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-1339 (*1 *2 *3 *3 *4) (-12 (-14 *5 (-634 (-1161))) (-4 *3 (-950 *2 *6 (-852 *5))) (-4 *6 (-230 (-1697 *5) (-763))) (-4 *7 (-971 *2)) (-4 *8 (-641 *2)) (-4 *4 (-920 *2 *8)) (-4 *9 (-235 *4)) (-4 *10 (-536 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) (-1339 (*1 *2 *3 *4) (-12 (-14 *5 (-634 (-1161))) (-4 *3 (-950 *2 *6 (-852 *5))) (-4 *6 (-230 (-1697 *5) (-763))) (-4 *7 (-971 *2)) (-4 *8 (-641 *2)) (-4 *4 (-920 *2 *8)) (-4 *9 (-235 *4)) (-4 *10 (-536 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) (-2525 (*1 *2 *3 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *3 (-235 *10)) (-4 *11 (-536 *4 *5 *6 *7 *8 *9 *10 *3 *13)) (-4 *13 (-117)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *3 *11 *12 *13)) (-4 *12 (-258 *11)))) (-2664 (*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1697 *6) *4)) (-4 *9 (-971 *5)) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-4 *3 (-235 *11)) (-4 *12 (-536 *5 *6 *7 *8 *9 *10 *11 *3 *14)) (-4 *14 (-117)) (-5 *2 (-634 *7)) (-5 *1 (-467 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13 *14)) (-4 *13 (-258 *12)))) (-1640 (*1 *2 *3 *4 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1697 *6) (-763))) (-4 *9 (-971 *5)) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-4 *3 (-235 *11)) (-4 *12 (-536 *5 *6 *7 *8 *9 *10 *11 *3 *14)) (-4 *14 (-117)) (-5 *2 (-2 (|:| -1379 (-568)) (|:| |num| *7) (|:| |den| *7) (|:| |upTo| (-568)))) (-5 *1 (-467 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13 *14)) (-5 *4 (-568)) (-4 *13 (-258 *12)))) (-2246 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *3 (-235 *10)) (-4 *11 (-536 *4 *5 *6 *7 *8 *9 *10 *3 *13)) (-4 *13 (-117)) (-5 *2 (-2 (|:| |num| (-634 *6)) (|:| |den| *6))) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *3 *11 *12 *13)) (-4 *12 (-258 *11)))) (-2215 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *7 (-230 (-1697 *6) (-763))) (-4 *8 (-971 *5)) (-4 *4 (-920 *5 *2)) (-4 *9 (-235 *4)) (-4 *10 (-536 *5 *6 *3 *7 *8 *2 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-641 *5)) (-5 *1 (-467 *5 *6 *3 *7 *8 *2 *4 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) (-1846 (*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *7)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-4149 (*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-971 *3)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-4007 (*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *12)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-2176 (*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *12)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-1801 (*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-568)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-2126 (*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) *2)) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-763)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-2606 (*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-230 (-1697 *4) (-763))) (-4 *6 (-971 *3)) (-4 *7 (-641 *3)) (-4 *8 (-920 *3 *7)) (-4 *9 (-235 *8)) (-4 *10 (-536 *3 *4 *2 *5 *6 *7 *8 *9 *12)) (-4 *12 (-117)) (-4 *2 (-950 *3 *5 (-852 *4))) (-5 *1 (-467 *3 *4 *2 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) (-1277 (*1 *2 *3) (-12 (-5 *3 (-634 (-121))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-1249)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) (-3039 (*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *2 (-950 *4 *6 (-852 *5))) (-4 *6 (-230 (-1697 *5) (-763))) (-4 *7 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *4 *5 *2 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *1 (-467 *4 *5 *2 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-4276 (*1 *2 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *2 (-950 *3 *5 (-852 *4))) (-4 *5 (-230 (-1697 *4) (-763))) (-4 *6 (-971 *3)) (-4 *7 (-641 *3)) (-4 *8 (-920 *3 *7)) (-4 *9 (-235 *8)) (-4 *10 (-536 *3 *4 *2 *5 *6 *7 *8 *9 *12)) (-4 *12 (-117)) (-5 *1 (-467 *3 *4 *2 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) (-2316 (*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-1249)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11))))) 
-(-10 -7 (-15 -2316 ((-1249))) (-15 -4276 (|#3| |#3|)) (-15 -3039 (|#3| |#3| (-568))) (-15 -1277 ((-1249) (-634 (-121)))) (-15 -2606 (|#3|)) (-15 -2126 ((-763))) (-15 -1801 ((-568))) (-15 -2176 ((-634 |#10|))) (-15 -4007 ((-634 |#10|))) (-15 -4149 ((-634 |#5|) (-634 |#5|))) (-15 -1846 ((-634 |#5|))) (-15 -2215 (|#6| |#3| |#7|)) (-15 -2246 ((-2 (|:| |num| (-634 |#3|)) (|:| |den| |#3|)) |#8|)) (-15 -1640 ((-2 (|:| -1379 (-568)) (|:| |num| |#3|) (|:| |den| |#3|) (|:| |upTo| (-568))) |#8| (-568) (-568))) (-15 -2664 ((-634 |#3|) |#8| (-763))) (-15 -2525 ((-634 |#3|) |#8| (-634 |#3|))) (-15 -1339 (|#1| |#3| |#7|)) (-15 -1339 (|#1| |#3| |#3| |#7|)) (-15 -1339 (|#1| (-409 |#3|) |#7|)) (-15 -3781 ((-3 |#1| "failed") |#3| |#7|)) (-15 -3781 ((-3 |#1| "failed") |#3| |#3| |#7|)) (-15 -3781 ((-3 |#1| "failed") (-409 |#3|) |#7|)) (-15 -2411 (|#8| |#3|)) (-15 -2480 (|#8|)) (-15 -1547 ((-634 |#7|) |#5|)) (-15 -1279 (|#5| |#7|)) (IF (|has| |#1| (-370)) (PROGN (-15 -4397 ((-634 |#7|))) (-15 -1895 ((-634 |#5|))) (-15 -1637 ((-1157 (-568)))) (-15 -1637 ((-1157 (-568)) (-917))) (-15 -2277 ((-568))) (-15 -1375 ((-634 |#7|) (-917))) (-15 -3281 ((-568) (-917))) (-15 -3354 ((-568) (-917))) (-15 -3114 ((-568) (-917) (-917))) (-15 -2596 ((-1239 (-568) -3492))) (-15 -2596 ((-1239 (-568) -3492) (-917)))) |noBranch|)) 
-((-2447 (((-121) $ $) NIL)) (-2055 (((-634 |#3|) $) 41)) (-4211 (((-121) $) NIL)) (-3824 (((-121) $) NIL (|has| |#1| (-558)))) (-3644 (((-2 (|:| |under| $) (|:| -1519 $) (|:| |upper| $)) $ |#3|) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-2801 (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-2671 (($) NIL T CONST)) (-1565 (((-121) $) NIL (|has| |#1| (-558)))) (-3846 (((-121) $ $) NIL (|has| |#1| (-558)))) (-3106 (((-121) $ $) NIL (|has| |#1| (-558)))) (-3695 (((-121) $) NIL (|has| |#1| (-558)))) (-2355 (((-634 |#4|) (-634 |#4|) $) NIL (|has| |#1| (-558)))) (-2492 (((-634 |#4|) (-634 |#4|) $) NIL (|has| |#1| (-558)))) (-3666 (((-3 $ "failed") (-634 |#4|)) 47)) (-2854 (($ (-634 |#4|)) NIL)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090))))) (-4328 (($ |#4| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090)))) (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-1500 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-558)))) (-3092 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) NIL (|has| $ (-6 -4519))) ((|#4| (-1 |#4| |#4| |#4|) $) NIL (|has| $ (-6 -4519)))) (-4360 (((-634 |#4|) $) 18 (|has| $ (-6 -4519)))) (-2356 ((|#3| $) 45)) (-1737 (((-121) $ (-763)) NIL)) (-1979 (((-634 |#4|) $) 14 (|has| $ (-6 -4519)))) (-3109 (((-121) |#4| $) 26 (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090))))) (-3674 (($ (-1 |#4| |#4|) $) 23 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#4| |#4|) $) 21)) (-1432 (((-634 |#3|) $) NIL)) (-3392 (((-121) |#3| $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL)) (-2705 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-558)))) (-4022 (((-1108) $) NIL)) (-3775 (((-3 |#4| "failed") (-1 (-121) |#4|) $) NIL)) (-1387 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 |#4|) (-634 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 (-288 |#4|))) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) 39)) (-3248 (($) 17)) (-4168 (((-763) |#4| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090)))) (((-763) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-3863 (($ $) 16)) (-4278 (((-541) $) NIL (|has| |#4| (-609 (-541)))) (($ (-634 |#4|)) 49)) (-4287 (($ (-634 |#4|)) 13)) (-1290 (($ $ |#3|) NIL)) (-3732 (($ $ |#3|) NIL)) (-3944 (($ $ |#3|) NIL)) (-2745 (((-850) $) 38) (((-634 |#4|) $) 48)) (-1319 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 30)) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-468 |#1| |#2| |#3| |#4|) (-13 (-977 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -4278 ($ (-634 |#4|))) (-6 -4519) (-6 -4520))) (-1047) (-788) (-842) (-1061 |#1| |#2| |#3|)) (T -468)) 
-((-4278 (*1 *1 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-468 *3 *4 *5 *6))))) 
-(-13 (-977 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -4278 ($ (-634 |#4|))) (-6 -4519) (-6 -4520))) 
-((-3056 (($) 11)) (-1556 (($) 13)) (* (($ |#2| $) 15) (($ $ |#2|) 16))) 
-(((-469 |#1| |#2| |#3|) (-10 -8 (-15 -1556 (|#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 -3056 (|#1|))) (-470 |#2| |#3|) (-172) (-23)) (T -469)) 
-NIL 
-(-10 -8 (-15 -1556 (|#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 -3056 (|#1|))) 
-((-2447 (((-121) $ $) 7)) (-3666 (((-3 |#1| "failed") $) 23)) (-2854 ((|#1| $) 22)) (-3272 (($ $ $) 20)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-3206 ((|#2| $) 18)) (-2745 (((-850) $) 11) (($ |#1|) 24)) (-3056 (($) 17 T CONST)) (-1556 (($) 21 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 14) (($ $ $) 12)) (-1767 (($ $ $) 13)) (* (($ |#1| $) 16) (($ $ |#1|) 15))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-3591 (((-3 $ "failed")) NIL (|has| (-409 (-953 |#1|)) (-558)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3542 (((-1244 (-679 (-409 (-953 |#1|)))) (-1244 $)) NIL) (((-1244 (-679 (-409 (-953 |#1|))))) NIL)) (-3818 (((-1244 $)) NIL)) (-4490 (($) NIL T CONST)) (-3354 (((-3 (-2 (|:| |particular| $) (|:| -2588 (-634 $))) "failed")) NIL)) (-2046 (((-3 $ "failed")) NIL (|has| (-409 (-953 |#1|)) (-558)))) (-1524 (((-679 (-409 (-953 |#1|))) (-1244 $)) NIL) (((-679 (-409 (-953 |#1|)))) NIL)) (-2467 (((-409 (-953 |#1|)) $) NIL)) (-2235 (((-679 (-409 (-953 |#1|))) $ (-1244 $)) NIL) (((-679 (-409 (-953 |#1|))) $) NIL)) (-2812 (((-3 $ "failed") $) NIL (|has| (-409 (-953 |#1|)) (-558)))) (-1503 (((-1157 (-953 (-409 (-953 |#1|))))) NIL (|has| (-409 (-953 |#1|)) (-365))) (((-1157 (-409 (-953 |#1|)))) 79 (|has| |#1| (-558)))) (-2815 (($ $ (-917)) NIL)) (-1509 (((-409 (-953 |#1|)) $) NIL)) (-3839 (((-1157 (-409 (-953 |#1|))) $) 77 (|has| (-409 (-953 |#1|)) (-558)))) (-2886 (((-409 (-953 |#1|)) (-1244 $)) NIL) (((-409 (-953 |#1|))) NIL)) (-3105 (((-1157 (-409 (-953 |#1|))) $) NIL)) (-1463 (((-121)) NIL)) (-3899 (($ (-1244 (-409 (-953 |#1|))) (-1244 $)) 97) (($ (-1244 (-409 (-953 |#1|)))) NIL)) (-2902 (((-3 $ "failed") $) NIL (|has| (-409 (-953 |#1|)) (-558)))) (-2371 (((-917)) NIL)) (-3375 (((-121)) NIL)) (-3402 (($ $ (-917)) NIL)) (-4221 (((-121)) NIL)) (-4463 (((-121)) NIL)) (-3582 (((-121)) NIL)) (-2587 (((-3 (-2 (|:| |particular| $) (|:| -2588 (-634 $))) "failed")) NIL)) (-2061 (((-3 $ "failed")) NIL (|has| (-409 (-953 |#1|)) (-558)))) (-4134 (((-679 (-409 (-953 |#1|))) (-1244 $)) NIL) (((-679 (-409 (-953 |#1|)))) NIL)) (-2786 (((-409 (-953 |#1|)) $) NIL)) (-3147 (((-679 (-409 (-953 |#1|))) $ (-1244 $)) NIL) (((-679 (-409 (-953 |#1|))) $) NIL)) (-1974 (((-3 $ "failed") $) NIL (|has| (-409 (-953 |#1|)) (-558)))) (-1730 (((-1157 (-953 (-409 (-953 |#1|))))) NIL (|has| (-409 (-953 |#1|)) (-365))) (((-1157 (-409 (-953 |#1|)))) 78 (|has| |#1| (-558)))) (-4202 (($ $ (-917)) NIL)) (-4390 (((-409 (-953 |#1|)) $) NIL)) (-3364 (((-1157 (-409 (-953 |#1|))) $) 72 (|has| (-409 (-953 |#1|)) (-558)))) (-2060 (((-409 (-953 |#1|)) (-1244 $)) NIL) (((-409 (-953 |#1|))) NIL)) (-3114 (((-1157 (-409 (-953 |#1|))) $) NIL)) (-3487 (((-121)) NIL)) (-1893 (((-1143) $) NIL)) (-2153 (((-121)) NIL)) (-2889 (((-121)) NIL)) (-1852 (((-121)) NIL)) (-4025 (((-1108) $) NIL)) (-3020 (((-409 (-953 |#1|)) $ $) 66 (|has| |#1| (-558)))) (-2447 (((-409 (-953 |#1|)) $) 65 (|has| |#1| (-558)))) (-3068 (((-409 (-953 |#1|)) $) 89 (|has| |#1| (-558)))) (-3540 (((-1157 (-409 (-953 |#1|))) $) 83 (|has| |#1| (-558)))) (-4235 (((-409 (-953 |#1|))) 67 (|has| |#1| (-558)))) (-3609 (((-409 (-953 |#1|)) $ $) 54 (|has| |#1| (-558)))) (-2521 (((-409 (-953 |#1|)) $) 53 (|has| |#1| (-558)))) (-3429 (((-409 (-953 |#1|)) $) 88 (|has| |#1| (-558)))) (-1556 (((-1157 (-409 (-953 |#1|))) $) 82 (|has| |#1| (-558)))) (-3377 (((-409 (-953 |#1|))) 64 (|has| |#1| (-558)))) (-2283 (($) 95) (($ (-1161)) 101) (($ (-1244 (-1161))) 100) (($ (-1244 $)) 90) (($ (-1161) (-1244 $)) 99) (($ (-1244 (-1161)) (-1244 $)) 98)) (-3636 (((-121)) NIL)) (-2781 (((-409 (-953 |#1|)) $ (-568)) NIL)) (-1656 (((-1244 (-409 (-953 |#1|))) $ (-1244 $)) 92) (((-679 (-409 (-953 |#1|))) (-1244 $) (-1244 $)) NIL) (((-1244 (-409 (-953 |#1|))) $) 37) (((-679 (-409 (-953 |#1|))) (-1244 $)) NIL)) (-4280 (((-1244 (-409 (-953 |#1|))) $) NIL) (($ (-1244 (-409 (-953 |#1|)))) 34)) (-2155 (((-634 (-953 (-409 (-953 |#1|)))) (-1244 $)) NIL) (((-634 (-953 (-409 (-953 |#1|))))) NIL) (((-634 (-953 |#1|)) (-1244 $)) 93 (|has| |#1| (-558))) (((-634 (-953 |#1|))) 94 (|has| |#1| (-558)))) (-3985 (($ $ $) NIL)) (-3441 (((-121)) NIL)) (-2747 (((-850) $) NIL) (($ (-1244 (-409 (-953 |#1|)))) NIL)) (-2588 (((-1244 $)) 56)) (-2657 (((-634 (-1244 (-409 (-953 |#1|))))) NIL (|has| (-409 (-953 |#1|)) (-558)))) (-2007 (($ $ $ $) NIL)) (-3964 (((-121)) NIL)) (-3828 (($ (-679 (-409 (-953 |#1|))) $) NIL)) (-3911 (($ $ $) NIL)) (-2435 (((-121)) NIL)) (-2984 (((-121)) NIL)) (-3579 (((-121)) NIL)) (-3058 (($) NIL T CONST)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) 91)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 52) (($ $ (-409 (-953 |#1|))) NIL) (($ (-409 (-953 |#1|)) $) NIL) (($ (-1127 |#2| (-409 (-953 |#1|))) $) NIL))) 
+(((-454 |#1| |#2| |#3| |#4|) (-13 (-419 (-409 (-953 |#1|))) (-637 (-1127 |#2| (-409 (-953 |#1|)))) (-10 -8 (-15 -2747 ($ (-1244 (-409 (-953 |#1|))))) (-15 -2587 ((-3 (-2 (|:| |particular| $) (|:| -2588 (-634 $))) "failed"))) (-15 -3354 ((-3 (-2 (|:| |particular| $) (|:| -2588 (-634 $))) "failed"))) (-15 -2283 ($)) (-15 -2283 ($ (-1161))) (-15 -2283 ($ (-1244 (-1161)))) (-15 -2283 ($ (-1244 $))) (-15 -2283 ($ (-1161) (-1244 $))) (-15 -2283 ($ (-1244 (-1161)) (-1244 $))) (IF (|has| |#1| (-558)) (PROGN (-15 -1730 ((-1157 (-409 (-953 |#1|))))) (-15 -1556 ((-1157 (-409 (-953 |#1|))) $)) (-15 -2521 ((-409 (-953 |#1|)) $)) (-15 -3429 ((-409 (-953 |#1|)) $)) (-15 -1503 ((-1157 (-409 (-953 |#1|))))) (-15 -3540 ((-1157 (-409 (-953 |#1|))) $)) (-15 -2447 ((-409 (-953 |#1|)) $)) (-15 -3068 ((-409 (-953 |#1|)) $)) (-15 -3609 ((-409 (-953 |#1|)) $ $)) (-15 -3377 ((-409 (-953 |#1|)))) (-15 -3020 ((-409 (-953 |#1|)) $ $)) (-15 -4235 ((-409 (-953 |#1|)))) (-15 -2155 ((-634 (-953 |#1|)) (-1244 $))) (-15 -2155 ((-634 (-953 |#1|))))) |noBranch|))) (-172) (-917) (-634 (-1161)) (-1244 (-679 |#1|))) (T -454)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1244 (-409 (-953 *3)))) (-4 *3 (-172)) (-14 *6 (-1244 (-679 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))))) (-2587 (*1 *2) (|partial| -12 (-5 *2 (-2 (|:| |particular| (-454 *3 *4 *5 *6)) (|:| -2588 (-634 (-454 *3 *4 *5 *6))))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-3354 (*1 *2) (|partial| -12 (-5 *2 (-2 (|:| |particular| (-454 *3 *4 *5 *6)) (|:| -2588 (-634 (-454 *3 *4 *5 *6))))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-2283 (*1 *1) (-12 (-5 *1 (-454 *2 *3 *4 *5)) (-4 *2 (-172)) (-14 *3 (-917)) (-14 *4 (-634 (-1161))) (-14 *5 (-1244 (-679 *2))))) (-2283 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 *2)) (-14 *6 (-1244 (-679 *3))))) (-2283 (*1 *1 *2) (-12 (-5 *2 (-1244 (-1161))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-2283 (*1 *1 *2) (-12 (-5 *2 (-1244 (-454 *3 *4 *5 *6))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-2283 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-454 *4 *5 *6 *7))) (-5 *1 (-454 *4 *5 *6 *7)) (-4 *4 (-172)) (-14 *5 (-917)) (-14 *6 (-634 *2)) (-14 *7 (-1244 (-679 *4))))) (-2283 (*1 *1 *2 *3) (-12 (-5 *2 (-1244 (-1161))) (-5 *3 (-1244 (-454 *4 *5 *6 *7))) (-5 *1 (-454 *4 *5 *6 *7)) (-4 *4 (-172)) (-14 *5 (-917)) (-14 *6 (-634 (-1161))) (-14 *7 (-1244 (-679 *4))))) (-1730 (*1 *2) (-12 (-5 *2 (-1157 (-409 (-953 *3)))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-1556 (*1 *2 *1) (-12 (-5 *2 (-1157 (-409 (-953 *3)))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-2521 (*1 *2 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-3429 (*1 *2 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-1503 (*1 *2) (-12 (-5 *2 (-1157 (-409 (-953 *3)))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-3540 (*1 *2 *1) (-12 (-5 *2 (-1157 (-409 (-953 *3)))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-2447 (*1 *2 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-3068 (*1 *2 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-3609 (*1 *2 *1 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-3377 (*1 *2) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-3020 (*1 *2 *1 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-4235 (*1 *2) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) (-2155 (*1 *2 *3) (-12 (-5 *3 (-1244 (-454 *4 *5 *6 *7))) (-5 *2 (-634 (-953 *4))) (-5 *1 (-454 *4 *5 *6 *7)) (-4 *4 (-558)) (-4 *4 (-172)) (-14 *5 (-917)) (-14 *6 (-634 (-1161))) (-14 *7 (-1244 (-679 *4))))) (-2155 (*1 *2) (-12 (-5 *2 (-634 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
+(-13 (-419 (-409 (-953 |#1|))) (-637 (-1127 |#2| (-409 (-953 |#1|)))) (-10 -8 (-15 -2747 ($ (-1244 (-409 (-953 |#1|))))) (-15 -2587 ((-3 (-2 (|:| |particular| $) (|:| -2588 (-634 $))) "failed"))) (-15 -3354 ((-3 (-2 (|:| |particular| $) (|:| -2588 (-634 $))) "failed"))) (-15 -2283 ($)) (-15 -2283 ($ (-1161))) (-15 -2283 ($ (-1244 (-1161)))) (-15 -2283 ($ (-1244 $))) (-15 -2283 ($ (-1161) (-1244 $))) (-15 -2283 ($ (-1244 (-1161)) (-1244 $))) (IF (|has| |#1| (-558)) (PROGN (-15 -1730 ((-1157 (-409 (-953 |#1|))))) (-15 -1556 ((-1157 (-409 (-953 |#1|))) $)) (-15 -2521 ((-409 (-953 |#1|)) $)) (-15 -3429 ((-409 (-953 |#1|)) $)) (-15 -1503 ((-1157 (-409 (-953 |#1|))))) (-15 -3540 ((-1157 (-409 (-953 |#1|))) $)) (-15 -2447 ((-409 (-953 |#1|)) $)) (-15 -3068 ((-409 (-953 |#1|)) $)) (-15 -3609 ((-409 (-953 |#1|)) $ $)) (-15 -3377 ((-409 (-953 |#1|)))) (-15 -3020 ((-409 (-953 |#1|)) $ $)) (-15 -4235 ((-409 (-953 |#1|)))) (-15 -2155 ((-634 (-953 |#1|)) (-1244 $))) (-15 -2155 ((-634 (-953 |#1|))))) |noBranch|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 13)) (-2057 (((-634 (-852 |#1|)) $) 73)) (-3840 (((-1157 $) $ (-852 |#1|)) 46) (((-1157 |#2|) $) 115)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#2| (-558)))) (-3661 (($ $) NIL (|has| |#2| (-558)))) (-4426 (((-121) $) NIL (|has| |#2| (-558)))) (-3528 (((-763) $) 21) (((-763) $ (-634 (-852 |#1|))) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3045 (($ $) NIL (|has| |#2| (-453)))) (-3498 (((-420 $) $) NIL (|has| |#2| (-453)))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#2| "failed") $) 44) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#2| (-1037 (-568)))) (((-3 (-852 |#1|) "failed") $) NIL)) (-2857 ((|#2| $) 42) (((-409 (-568)) $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#2| (-1037 (-568)))) (((-852 |#1|) $) NIL)) (-2910 (($ $ $ (-852 |#1|)) NIL (|has| |#2| (-172)))) (-1594 (($ $ (-634 (-568))) 78)) (-2116 (($ $) 67)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL) (((-679 |#2|) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1998 (($ $) NIL (|has| |#2| (-453))) (($ $ (-852 |#1|)) NIL (|has| |#2| (-453)))) (-2110 (((-634 $) $) NIL)) (-2197 (((-121) $) NIL (|has| |#2| (-904)))) (-2453 (($ $ |#2| |#3| $) NIL)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-852 |#1|) (-881 (-381))) (|has| |#2| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-852 |#1|) (-881 (-568))) (|has| |#2| (-881 (-568)))))) (-1598 (((-121) $) NIL)) (-3971 (((-763) $) 58)) (-2053 (($ (-1157 |#2|) (-852 |#1|)) 120) (($ (-1157 $) (-852 |#1|)) 52)) (-3062 (((-634 $) $) NIL)) (-2171 (((-121) $) 59)) (-2049 (($ |#2| |#3|) 28) (($ $ (-852 |#1|) (-763)) 30) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-1438 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $ (-852 |#1|)) NIL)) (-3524 ((|#3| $) NIL) (((-763) $ (-852 |#1|)) 50) (((-634 (-763)) $ (-634 (-852 |#1|))) 57)) (-1732 (($ $ $) NIL (|has| |#2| (-842)))) (-2047 (($ $ $) NIL (|has| |#2| (-842)))) (-1865 (($ (-1 |#3| |#3|) $) NIL)) (-2797 (($ (-1 |#2| |#2|) $) NIL)) (-2817 (((-3 (-852 |#1|) "failed") $) 39)) (-2099 (($ $) NIL)) (-2104 ((|#2| $) 41)) (-2498 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) NIL (|has| |#2| (-453)))) (-1893 (((-1143) $) NIL)) (-4362 (((-3 (-634 $) "failed") $) NIL)) (-2112 (((-3 (-634 $) "failed") $) NIL)) (-2617 (((-3 (-2 (|:| |var| (-852 |#1|)) (|:| -3483 (-763))) "failed") $) NIL)) (-4025 (((-1108) $) NIL)) (-2088 (((-121) $) 40)) (-2093 ((|#2| $) 113)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#2| (-453)))) (-2723 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) 125 (|has| |#2| (-453)))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3850 (((-420 $) $) NIL (|has| |#2| (-904)))) (-2597 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-558)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-852 |#1|) |#2|) 85) (($ $ (-634 (-852 |#1|)) (-634 |#2|)) 88) (($ $ (-852 |#1|) $) 83) (($ $ (-634 (-852 |#1|)) (-634 $)) 104)) (-3440 (($ $ (-852 |#1|)) NIL (|has| |#2| (-172)))) (-4191 (($ $ (-852 |#1|)) 53) (($ $ (-634 (-852 |#1|))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-1836 ((|#3| $) 66) (((-763) $ (-852 |#1|)) 37) (((-634 (-763)) $ (-634 (-852 |#1|))) 56)) (-4280 (((-887 (-381)) $) NIL (-12 (|has| (-852 |#1|) (-609 (-887 (-381)))) (|has| |#2| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-852 |#1|) (-609 (-887 (-568)))) (|has| |#2| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-852 |#1|) (-609 (-541))) (|has| |#2| (-609 (-541)))))) (-1364 ((|#2| $) 122 (|has| |#2| (-453))) (($ $ (-852 |#1|)) NIL (|has| |#2| (-453)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#2| (-904))))) (-2747 (((-850) $) 141) (($ (-568)) NIL) (($ |#2|) 84) (($ (-852 |#1|)) 31) (($ (-409 (-568))) NIL (-2199 (|has| |#2| (-43 (-409 (-568)))) (|has| |#2| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#2| (-558)))) (-3304 (((-634 |#2|) $) NIL)) (-2079 ((|#2| $ |#3|) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| |#2| (-904))) (|has| |#2| (-148))))) (-3425 (((-763)) NIL)) (-3925 (($ $ $ (-763)) NIL (|has| |#2| (-172)))) (-2273 (((-121) $ $) NIL (|has| |#2| (-558)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 16 T CONST)) (-1557 (($) 25 T CONST)) (-3192 (($ $ (-852 |#1|)) NIL) (($ $ (-634 (-852 |#1|))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-1753 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1781 (($ $ |#2|) 64 (|has| |#2| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) 109)) (** (($ $ (-917)) NIL) (($ $ (-763)) 107)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 29) (($ $ (-409 (-568))) NIL (|has| |#2| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#2| (-43 (-409 (-568))))) (($ |#2| $) 63) (($ $ |#2|) NIL))) 
+(((-455 |#1| |#2| |#3|) (-13 (-950 |#2| |#3| (-852 |#1|)) (-10 -8 (-15 -1594 ($ $ (-634 (-568)))))) (-634 (-1161)) (-1047) (-230 (-1699 |#1|) (-763))) (T -455)) 
+((-1594 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-14 *3 (-634 (-1161))) (-5 *1 (-455 *3 *4 *5)) (-4 *4 (-1047)) (-4 *5 (-230 (-1699 *3) (-763)))))) 
+(-13 (-950 |#2| |#3| (-852 |#1|)) (-10 -8 (-15 -1594 ($ $ (-634 (-568)))))) 
+((-1909 (((-1249) (-310 (-381)) (-1082 (-381)) (-1082 (-381)) (-1143)) 49) (((-1249) (-310 (-381)) (-1082 (-381)) (-1082 (-381)) (-1143) (-634 (-256))) 48) (((-1249) (-310 (-381)) (-1082 (-381)) (-1143)) 42) (((-1249) (-310 (-381)) (-1082 (-381)) (-1143) (-634 (-256))) 39))) 
+(((-456) (-10 -7 (-15 -1909 ((-1249) (-310 (-381)) (-1082 (-381)) (-1143) (-634 (-256)))) (-15 -1909 ((-1249) (-310 (-381)) (-1082 (-381)) (-1143))) (-15 -1909 ((-1249) (-310 (-381)) (-1082 (-381)) (-1082 (-381)) (-1143) (-634 (-256)))) (-15 -1909 ((-1249) (-310 (-381)) (-1082 (-381)) (-1082 (-381)) (-1143))))) (T -456)) 
+((-1909 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-381))) (-5 *5 (-1143)) (-5 *2 (-1249)) (-5 *1 (-456)))) (-1909 (*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-381))) (-5 *5 (-1143)) (-5 *6 (-634 (-256))) (-5 *2 (-1249)) (-5 *1 (-456)))) (-1909 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-381))) (-5 *5 (-1143)) (-5 *2 (-1249)) (-5 *1 (-456)))) (-1909 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-381))) (-5 *5 (-1143)) (-5 *6 (-634 (-256))) (-5 *2 (-1249)) (-5 *1 (-456))))) 
+(-10 -7 (-15 -1909 ((-1249) (-310 (-381)) (-1082 (-381)) (-1143) (-634 (-256)))) (-15 -1909 ((-1249) (-310 (-381)) (-1082 (-381)) (-1143))) (-15 -1909 ((-1249) (-310 (-381)) (-1082 (-381)) (-1082 (-381)) (-1143) (-634 (-256)))) (-15 -1909 ((-1249) (-310 (-381)) (-1082 (-381)) (-1082 (-381)) (-1143)))) 
+((-3462 (((-121) |#1| (-634 |#2|)) 65)) (-2125 (((-3 (-1244 (-634 |#2|)) "failed") (-763) |#1| (-634 |#2|)) 74)) (-2806 (((-3 (-634 |#2|) "failed") |#2| |#1| (-1244 (-634 |#2|))) 76)) (-3121 ((|#2| |#2| |#1|) 28)) (-3329 (((-763) |#2| (-634 |#2|)) 20))) 
+(((-457 |#1| |#2|) (-10 -7 (-15 -3121 (|#2| |#2| |#1|)) (-15 -3329 ((-763) |#2| (-634 |#2|))) (-15 -2125 ((-3 (-1244 (-634 |#2|)) "failed") (-763) |#1| (-634 |#2|))) (-15 -2806 ((-3 (-634 |#2|) "failed") |#2| |#1| (-1244 (-634 |#2|)))) (-15 -3462 ((-121) |#1| (-634 |#2|)))) (-301) (-1219 |#1|)) (T -457)) 
+((-3462 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *5)) (-4 *5 (-1219 *3)) (-4 *3 (-301)) (-5 *2 (-121)) (-5 *1 (-457 *3 *5)))) (-2806 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1244 (-634 *3))) (-4 *4 (-301)) (-5 *2 (-634 *3)) (-5 *1 (-457 *4 *3)) (-4 *3 (-1219 *4)))) (-2125 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-763)) (-4 *4 (-301)) (-4 *6 (-1219 *4)) (-5 *2 (-1244 (-634 *6))) (-5 *1 (-457 *4 *6)) (-5 *5 (-634 *6)))) (-3329 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-301)) (-5 *2 (-763)) (-5 *1 (-457 *5 *3)))) (-3121 (*1 *2 *2 *3) (-12 (-4 *3 (-301)) (-5 *1 (-457 *3 *2)) (-4 *2 (-1219 *3))))) 
+(-10 -7 (-15 -3121 (|#2| |#2| |#1|)) (-15 -3329 ((-763) |#2| (-634 |#2|))) (-15 -2125 ((-3 (-1244 (-634 |#2|)) "failed") (-763) |#1| (-634 |#2|))) (-15 -2806 ((-3 (-634 |#2|) "failed") |#2| |#1| (-1244 (-634 |#2|)))) (-15 -3462 ((-121) |#1| (-634 |#2|)))) 
+((-3850 (((-420 |#5|) |#5|) 24))) 
+(((-458 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3850 ((-420 |#5|) |#5|))) (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $)) (-15 -3325 ((-3 $ "failed") (-1161))))) (-788) (-558) (-558) (-950 |#4| |#2| |#1|)) (T -458)) 
+((-3850 (*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $)) (-15 -3325 ((-3 $ "failed") (-1161)))))) (-4 *5 (-788)) (-4 *7 (-558)) (-5 *2 (-420 *3)) (-5 *1 (-458 *4 *5 *6 *7 *3)) (-4 *6 (-558)) (-4 *3 (-950 *7 *5 *4))))) 
+(-10 -7 (-15 -3850 ((-420 |#5|) |#5|))) 
+((-3130 ((|#3|) 36)) (-3603 (((-1157 |#4|) (-1157 |#4|) (-1157 |#4|)) 32))) 
+(((-459 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3603 ((-1157 |#4|) (-1157 |#4|) (-1157 |#4|))) (-15 -3130 (|#3|))) (-788) (-842) (-904) (-950 |#3| |#1| |#2|)) (T -459)) 
+((-3130 (*1 *2) (-12 (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-904)) (-5 *1 (-459 *3 *4 *2 *5)) (-4 *5 (-950 *2 *3 *4)))) (-3603 (*1 *2 *2 *2) (-12 (-5 *2 (-1157 *6)) (-4 *6 (-950 *5 *3 *4)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-904)) (-5 *1 (-459 *3 *4 *5 *6))))) 
+(-10 -7 (-15 -3603 ((-1157 |#4|) (-1157 |#4|) (-1157 |#4|))) (-15 -3130 (|#3|))) 
+((-3850 (((-420 (-1157 |#1|)) (-1157 |#1|)) 41))) 
+(((-460 |#1|) (-10 -7 (-15 -3850 ((-420 (-1157 |#1|)) (-1157 |#1|)))) (-301)) (T -460)) 
+((-3850 (*1 *2 *3) (-12 (-4 *4 (-301)) (-5 *2 (-420 (-1157 *4))) (-5 *1 (-460 *4)) (-5 *3 (-1157 *4))))) 
+(-10 -7 (-15 -3850 ((-420 (-1157 |#1|)) (-1157 |#1|)))) 
+((-2067 (((-57) |#2| (-1161) (-288 |#2|) (-1210 (-763))) 42) (((-57) (-1 |#2| (-568)) (-288 |#2|) (-1210 (-763))) 41) (((-57) |#2| (-1161) (-288 |#2|)) 35) (((-57) (-1 |#2| (-568)) (-288 |#2|)) 27)) (-2512 (((-57) |#2| (-1161) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568))) 80) (((-57) (-1 |#2| (-409 (-568))) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568))) 79) (((-57) |#2| (-1161) (-288 |#2|) (-1210 (-568))) 78) (((-57) (-1 |#2| (-568)) (-288 |#2|) (-1210 (-568))) 77) (((-57) |#2| (-1161) (-288 |#2|)) 72) (((-57) (-1 |#2| (-568)) (-288 |#2|)) 71)) (-2077 (((-57) |#2| (-1161) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568))) 66) (((-57) (-1 |#2| (-409 (-568))) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568))) 64)) (-2072 (((-57) |#2| (-1161) (-288 |#2|) (-1210 (-568))) 48) (((-57) (-1 |#2| (-568)) (-288 |#2|) (-1210 (-568))) 47))) 
+(((-461 |#1| |#2|) (-10 -7 (-15 -2067 ((-57) (-1 |#2| (-568)) (-288 |#2|))) (-15 -2067 ((-57) |#2| (-1161) (-288 |#2|))) (-15 -2067 ((-57) (-1 |#2| (-568)) (-288 |#2|) (-1210 (-763)))) (-15 -2067 ((-57) |#2| (-1161) (-288 |#2|) (-1210 (-763)))) (-15 -2072 ((-57) (-1 |#2| (-568)) (-288 |#2|) (-1210 (-568)))) (-15 -2072 ((-57) |#2| (-1161) (-288 |#2|) (-1210 (-568)))) (-15 -2077 ((-57) (-1 |#2| (-409 (-568))) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568)))) (-15 -2077 ((-57) |#2| (-1161) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568)))) (-15 -2512 ((-57) (-1 |#2| (-568)) (-288 |#2|))) (-15 -2512 ((-57) |#2| (-1161) (-288 |#2|))) (-15 -2512 ((-57) (-1 |#2| (-568)) (-288 |#2|) (-1210 (-568)))) (-15 -2512 ((-57) |#2| (-1161) (-288 |#2|) (-1210 (-568)))) (-15 -2512 ((-57) (-1 |#2| (-409 (-568))) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568)))) (-15 -2512 ((-57) |#2| (-1161) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568))))) (-13 (-558) (-842) (-1037 (-568)) (-630 (-568))) (-13 (-27) (-1181) (-432 |#1|))) (T -461)) 
+((-2512 (*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-5 *6 (-1210 (-409 (-568)))) (-5 *7 (-409 (-568))) (-4 *3 (-13 (-27) (-1181) (-432 *8))) (-4 *8 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *8 *3)))) (-2512 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *8 (-409 (-568)))) (-5 *4 (-288 *8)) (-5 *5 (-1210 (-409 (-568)))) (-5 *6 (-409 (-568))) (-4 *8 (-13 (-27) (-1181) (-432 *7))) (-4 *7 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *7 *8)))) (-2512 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-5 *6 (-1210 (-568))) (-4 *3 (-13 (-27) (-1181) (-432 *7))) (-4 *7 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *7 *3)))) (-2512 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *7 (-568))) (-5 *4 (-288 *7)) (-5 *5 (-1210 (-568))) (-4 *7 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *6 *7)))) (-2512 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *6 *3)))) (-2512 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 (-568))) (-5 *4 (-288 *6)) (-4 *6 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *5 *6)))) (-2077 (*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-5 *6 (-1210 (-409 (-568)))) (-5 *7 (-409 (-568))) (-4 *3 (-13 (-27) (-1181) (-432 *8))) (-4 *8 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *8 *3)))) (-2077 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *8 (-409 (-568)))) (-5 *4 (-288 *8)) (-5 *5 (-1210 (-409 (-568)))) (-5 *6 (-409 (-568))) (-4 *8 (-13 (-27) (-1181) (-432 *7))) (-4 *7 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *7 *8)))) (-2072 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-5 *6 (-1210 (-568))) (-4 *3 (-13 (-27) (-1181) (-432 *7))) (-4 *7 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *7 *3)))) (-2072 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *7 (-568))) (-5 *4 (-288 *7)) (-5 *5 (-1210 (-568))) (-4 *7 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *6 *7)))) (-2067 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-5 *6 (-1210 (-763))) (-4 *3 (-13 (-27) (-1181) (-432 *7))) (-4 *7 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *7 *3)))) (-2067 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *7 (-568))) (-5 *4 (-288 *7)) (-5 *5 (-1210 (-763))) (-4 *7 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *6 *7)))) (-2067 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *6 *3)))) (-2067 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 (-568))) (-5 *4 (-288 *6)) (-4 *6 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *5 *6))))) 
+(-10 -7 (-15 -2067 ((-57) (-1 |#2| (-568)) (-288 |#2|))) (-15 -2067 ((-57) |#2| (-1161) (-288 |#2|))) (-15 -2067 ((-57) (-1 |#2| (-568)) (-288 |#2|) (-1210 (-763)))) (-15 -2067 ((-57) |#2| (-1161) (-288 |#2|) (-1210 (-763)))) (-15 -2072 ((-57) (-1 |#2| (-568)) (-288 |#2|) (-1210 (-568)))) (-15 -2072 ((-57) |#2| (-1161) (-288 |#2|) (-1210 (-568)))) (-15 -2077 ((-57) (-1 |#2| (-409 (-568))) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568)))) (-15 -2077 ((-57) |#2| (-1161) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568)))) (-15 -2512 ((-57) (-1 |#2| (-568)) (-288 |#2|))) (-15 -2512 ((-57) |#2| (-1161) (-288 |#2|))) (-15 -2512 ((-57) (-1 |#2| (-568)) (-288 |#2|) (-1210 (-568)))) (-15 -2512 ((-57) |#2| (-1161) (-288 |#2|) (-1210 (-568)))) (-15 -2512 ((-57) (-1 |#2| (-409 (-568))) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568)))) (-15 -2512 ((-57) |#2| (-1161) (-288 |#2|) (-1210 (-409 (-568))) (-409 (-568))))) 
+((-3121 ((|#2| |#2| |#1|) 15)) (-3568 (((-634 |#2|) |#2| (-634 |#2|) |#1| (-917)) 65)) (-2737 (((-2 (|:| |plist| (-634 |#2|)) (|:| |modulo| |#1|)) |#2| (-634 |#2|) |#1| (-917)) 58))) 
+(((-462 |#1| |#2|) (-10 -7 (-15 -2737 ((-2 (|:| |plist| (-634 |#2|)) (|:| |modulo| |#1|)) |#2| (-634 |#2|) |#1| (-917))) (-15 -3568 ((-634 |#2|) |#2| (-634 |#2|) |#1| (-917))) (-15 -3121 (|#2| |#2| |#1|))) (-301) (-1219 |#1|)) (T -462)) 
+((-3121 (*1 *2 *2 *3) (-12 (-4 *3 (-301)) (-5 *1 (-462 *3 *2)) (-4 *2 (-1219 *3)))) (-3568 (*1 *2 *3 *2 *4 *5) (-12 (-5 *2 (-634 *3)) (-5 *5 (-917)) (-4 *3 (-1219 *4)) (-4 *4 (-301)) (-5 *1 (-462 *4 *3)))) (-2737 (*1 *2 *3 *4 *5 *6) (-12 (-5 *6 (-917)) (-4 *5 (-301)) (-4 *3 (-1219 *5)) (-5 *2 (-2 (|:| |plist| (-634 *3)) (|:| |modulo| *5))) (-5 *1 (-462 *5 *3)) (-5 *4 (-634 *3))))) 
+(-10 -7 (-15 -2737 ((-2 (|:| |plist| (-634 |#2|)) (|:| |modulo| |#1|)) |#2| (-634 |#2|) |#1| (-917))) (-15 -3568 ((-634 |#2|) |#2| (-634 |#2|) |#1| (-917))) (-15 -3121 (|#2| |#2| |#1|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 28)) (-4007 (($ |#3|) 25)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-2116 (($ $) 32)) (-4350 (($ |#2| |#4| $) 33)) (-2049 (($ |#2| (-703 |#3| |#4| |#5|)) 24)) (-2099 (((-703 |#3| |#4| |#5|) $) 15)) (-2320 ((|#3| $) 19)) (-1544 ((|#4| $) 17)) (-2104 ((|#2| $) 29)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-2456 (($ |#2| |#3| |#4|) 26)) (-3058 (($) 36 T CONST)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) 34)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ |#6| $) 40) (($ $ |#6|) NIL) (($ $ |#2|) NIL) (($ |#2| $) NIL))) 
+(((-463 |#1| |#2| |#3| |#4| |#5| |#6|) (-13 (-707 |#6|) (-707 |#2|) (-10 -8 (-15 -2104 (|#2| $)) (-15 -2099 ((-703 |#3| |#4| |#5|) $)) (-15 -1544 (|#4| $)) (-15 -2320 (|#3| $)) (-15 -2116 ($ $)) (-15 -2049 ($ |#2| (-703 |#3| |#4| |#5|))) (-15 -4007 ($ |#3|)) (-15 -2456 ($ |#2| |#3| |#4|)) (-15 -4350 ($ |#2| |#4| $)) (-15 * ($ |#6| $)))) (-634 (-1161)) (-172) (-842) (-230 (-1699 |#1|) (-763)) (-1 (-121) (-2 (|:| -4357 |#3|) (|:| -3483 |#4|)) (-2 (|:| -4357 |#3|) (|:| -3483 |#4|))) (-950 |#2| |#4| (-852 |#1|))) (T -463)) 
+((* (*1 *1 *2 *1) (-12 (-14 *3 (-634 (-1161))) (-4 *4 (-172)) (-4 *6 (-230 (-1699 *3) (-763))) (-14 *7 (-1 (-121) (-2 (|:| -4357 *5) (|:| -3483 *6)) (-2 (|:| -4357 *5) (|:| -3483 *6)))) (-5 *1 (-463 *3 *4 *5 *6 *7 *2)) (-4 *5 (-842)) (-4 *2 (-950 *4 *6 (-852 *3))))) (-2104 (*1 *2 *1) (-12 (-14 *3 (-634 (-1161))) (-4 *5 (-230 (-1699 *3) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4357 *4) (|:| -3483 *5)) (-2 (|:| -4357 *4) (|:| -3483 *5)))) (-4 *2 (-172)) (-5 *1 (-463 *3 *2 *4 *5 *6 *7)) (-4 *4 (-842)) (-4 *7 (-950 *2 *5 (-852 *3))))) (-2099 (*1 *2 *1) (-12 (-14 *3 (-634 (-1161))) (-4 *4 (-172)) (-4 *6 (-230 (-1699 *3) (-763))) (-14 *7 (-1 (-121) (-2 (|:| -4357 *5) (|:| -3483 *6)) (-2 (|:| -4357 *5) (|:| -3483 *6)))) (-5 *2 (-703 *5 *6 *7)) (-5 *1 (-463 *3 *4 *5 *6 *7 *8)) (-4 *5 (-842)) (-4 *8 (-950 *4 *6 (-852 *3))))) (-1544 (*1 *2 *1) (-12 (-14 *3 (-634 (-1161))) (-4 *4 (-172)) (-14 *6 (-1 (-121) (-2 (|:| -4357 *5) (|:| -3483 *2)) (-2 (|:| -4357 *5) (|:| -3483 *2)))) (-4 *2 (-230 (-1699 *3) (-763))) (-5 *1 (-463 *3 *4 *5 *2 *6 *7)) (-4 *5 (-842)) (-4 *7 (-950 *4 *2 (-852 *3))))) (-2320 (*1 *2 *1) (-12 (-14 *3 (-634 (-1161))) (-4 *4 (-172)) (-4 *5 (-230 (-1699 *3) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4357 *2) (|:| -3483 *5)) (-2 (|:| -4357 *2) (|:| -3483 *5)))) (-4 *2 (-842)) (-5 *1 (-463 *3 *4 *2 *5 *6 *7)) (-4 *7 (-950 *4 *5 (-852 *3))))) (-2116 (*1 *1 *1) (-12 (-14 *2 (-634 (-1161))) (-4 *3 (-172)) (-4 *5 (-230 (-1699 *2) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4357 *4) (|:| -3483 *5)) (-2 (|:| -4357 *4) (|:| -3483 *5)))) (-5 *1 (-463 *2 *3 *4 *5 *6 *7)) (-4 *4 (-842)) (-4 *7 (-950 *3 *5 (-852 *2))))) (-2049 (*1 *1 *2 *3) (-12 (-5 *3 (-703 *5 *6 *7)) (-4 *5 (-842)) (-4 *6 (-230 (-1699 *4) (-763))) (-14 *7 (-1 (-121) (-2 (|:| -4357 *5) (|:| -3483 *6)) (-2 (|:| -4357 *5) (|:| -3483 *6)))) (-14 *4 (-634 (-1161))) (-4 *2 (-172)) (-5 *1 (-463 *4 *2 *5 *6 *7 *8)) (-4 *8 (-950 *2 *6 (-852 *4))))) (-4007 (*1 *1 *2) (-12 (-14 *3 (-634 (-1161))) (-4 *4 (-172)) (-4 *5 (-230 (-1699 *3) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4357 *2) (|:| -3483 *5)) (-2 (|:| -4357 *2) (|:| -3483 *5)))) (-5 *1 (-463 *3 *4 *2 *5 *6 *7)) (-4 *2 (-842)) (-4 *7 (-950 *4 *5 (-852 *3))))) (-2456 (*1 *1 *2 *3 *4) (-12 (-14 *5 (-634 (-1161))) (-4 *2 (-172)) (-4 *4 (-230 (-1699 *5) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4357 *3) (|:| -3483 *4)) (-2 (|:| -4357 *3) (|:| -3483 *4)))) (-5 *1 (-463 *5 *2 *3 *4 *6 *7)) (-4 *3 (-842)) (-4 *7 (-950 *2 *4 (-852 *5))))) (-4350 (*1 *1 *2 *3 *1) (-12 (-14 *4 (-634 (-1161))) (-4 *2 (-172)) (-4 *3 (-230 (-1699 *4) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4357 *5) (|:| -3483 *3)) (-2 (|:| -4357 *5) (|:| -3483 *3)))) (-5 *1 (-463 *4 *2 *5 *3 *6 *7)) (-4 *5 (-842)) (-4 *7 (-950 *2 *3 (-852 *4)))))) 
+(-13 (-707 |#6|) (-707 |#2|) (-10 -8 (-15 -2104 (|#2| $)) (-15 -2099 ((-703 |#3| |#4| |#5|) $)) (-15 -1544 (|#4| $)) (-15 -2320 (|#3| $)) (-15 -2116 ($ $)) (-15 -2049 ($ |#2| (-703 |#3| |#4| |#5|))) (-15 -4007 ($ |#3|)) (-15 -2456 ($ |#2| |#3| |#4|)) (-15 -4350 ($ |#2| |#4| $)) (-15 * ($ |#6| $)))) 
+((-2449 (((-121) $ $) NIL)) (-2094 (((-1161) (-634 (-465))) 34)) (-4468 (((-763) (-634 (-465))) 28)) (-3193 (((-121) (-634 (-465))) 29)) (-3366 (((-568) (-634 (-465))) 20)) (-4061 (((-568) (-634 (-465))) 26)) (-3490 (((-568) (-634 (-465))) 18)) (-2677 (((-568) (-634 (-465))) 19)) (-3442 (((-568) (-634 (-465))) 21)) (-1893 (((-1143) $) NIL)) (-3885 (((-1161) (-634 (-465))) 36)) (-2772 (((-121) (-634 (-465))) 31)) (-4025 (((-1108) $) NIL)) (-3049 (((-1161) (-634 (-465))) 35)) (-2280 (((-121) (-634 (-465))) 37)) (-4021 (((-121) (-634 (-465))) 30)) (-2747 (((-850) $) NIL)) (-3643 (((-121) (-634 (-465))) 25)) (-1719 (((-121) $ $) NIL))) 
+(((-464) (-13 (-1090) (-10 -7 (-15 -3490 ((-568) (-634 (-465)))) (-15 -4061 ((-568) (-634 (-465)))) (-15 -2677 ((-568) (-634 (-465)))) (-15 -3366 ((-568) (-634 (-465)))) (-15 -3442 ((-568) (-634 (-465)))) (-15 -3643 ((-121) (-634 (-465)))) (-15 -4468 ((-763) (-634 (-465)))) (-15 -3193 ((-121) (-634 (-465)))) (-15 -2772 ((-121) (-634 (-465)))) (-15 -3049 ((-1161) (-634 (-465)))) (-15 -2094 ((-1161) (-634 (-465)))) (-15 -3885 ((-1161) (-634 (-465)))) (-15 -2280 ((-121) (-634 (-465)))) (-15 -4021 ((-121) (-634 (-465))))))) (T -464)) 
+((-3490 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-568)) (-5 *1 (-464)))) (-4061 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-568)) (-5 *1 (-464)))) (-2677 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-568)) (-5 *1 (-464)))) (-3366 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-568)) (-5 *1 (-464)))) (-3442 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-568)) (-5 *1 (-464)))) (-3643 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-121)) (-5 *1 (-464)))) (-4468 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-763)) (-5 *1 (-464)))) (-3193 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-121)) (-5 *1 (-464)))) (-2772 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-121)) (-5 *1 (-464)))) (-3049 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-1161)) (-5 *1 (-464)))) (-2094 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-1161)) (-5 *1 (-464)))) (-3885 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-1161)) (-5 *1 (-464)))) (-2280 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-121)) (-5 *1 (-464)))) (-4021 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-121)) (-5 *1 (-464))))) 
+(-13 (-1090) (-10 -7 (-15 -3490 ((-568) (-634 (-465)))) (-15 -4061 ((-568) (-634 (-465)))) (-15 -2677 ((-568) (-634 (-465)))) (-15 -3366 ((-568) (-634 (-465)))) (-15 -3442 ((-568) (-634 (-465)))) (-15 -3643 ((-121) (-634 (-465)))) (-15 -4468 ((-763) (-634 (-465)))) (-15 -3193 ((-121) (-634 (-465)))) (-15 -2772 ((-121) (-634 (-465)))) (-15 -3049 ((-1161) (-634 (-465)))) (-15 -2094 ((-1161) (-634 (-465)))) (-15 -3885 ((-1161) (-634 (-465)))) (-15 -2280 ((-121) (-634 (-465)))) (-15 -4021 ((-121) (-634 (-465)))))) 
+((-2449 (((-121) $ $) NIL)) (-2094 (($ (-1161)) 31)) (-4468 (($ (-763)) 24)) (-2647 (((-121) (-634 $) (-1161)) 42)) (-2962 (((-3 (-57) "failed") (-634 $) (-1161)) 44)) (-3193 (($ (-121)) 27)) (-3366 (($ (-568)) 16)) (-4061 (($ (-568)) 22)) (-3490 (($ (-568)) 14)) (-2677 (($ (-568)) 15)) (-3442 (($ (-568)) 17)) (-1893 (((-1143) $) NIL)) (-3885 (($ (-1161)) 32)) (-2772 (($ (-121)) 25)) (-4025 (((-1108) $) NIL)) (-3049 (($ (-1161)) 30)) (-2280 (($ (-121)) 33)) (-4021 (($ (-121)) 26)) (-2747 (((-850) $) 38)) (-2530 (((-1249) (-634 $)) 54)) (-3643 (($ (-121)) 21)) (-1719 (((-121) $ $) 40))) 
+(((-465) (-13 (-1090) (-10 -8 (-15 -2677 ($ (-568))) (-15 -3366 ($ (-568))) (-15 -4061 ($ (-568))) (-15 -2772 ($ (-121))) (-15 -3490 ($ (-568))) (-15 -3442 ($ (-568))) (-15 -3643 ($ (-121))) (-15 -4468 ($ (-763))) (-15 -3193 ($ (-121))) (-15 -4021 ($ (-121))) (-15 -3049 ($ (-1161))) (-15 -2094 ($ (-1161))) (-15 -3885 ($ (-1161))) (-15 -2280 ($ (-121))) (-15 -2962 ((-3 (-57) "failed") (-634 $) (-1161))) (-15 -2647 ((-121) (-634 $) (-1161))) (-15 -2530 ((-1249) (-634 $)))))) (T -465)) 
+((-2677 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-465)))) (-3366 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-465)))) (-4061 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-465)))) (-2772 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-465)))) (-3490 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-465)))) (-3442 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-465)))) (-3643 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-465)))) (-4468 (*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-465)))) (-3193 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-465)))) (-4021 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-465)))) (-3049 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-465)))) (-2094 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-465)))) (-3885 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-465)))) (-2280 (*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-465)))) (-2962 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-634 (-465))) (-5 *4 (-1161)) (-5 *2 (-57)) (-5 *1 (-465)))) (-2647 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-465))) (-5 *4 (-1161)) (-5 *2 (-121)) (-5 *1 (-465)))) (-2530 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-1249)) (-5 *1 (-465))))) 
+(-13 (-1090) (-10 -8 (-15 -2677 ($ (-568))) (-15 -3366 ($ (-568))) (-15 -4061 ($ (-568))) (-15 -2772 ($ (-121))) (-15 -3490 ($ (-568))) (-15 -3442 ($ (-568))) (-15 -3643 ($ (-121))) (-15 -4468 ($ (-763))) (-15 -3193 ($ (-121))) (-15 -4021 ($ (-121))) (-15 -3049 ($ (-1161))) (-15 -2094 ($ (-1161))) (-15 -3885 ($ (-1161))) (-15 -2280 ($ (-121))) (-15 -2962 ((-3 (-57) "failed") (-634 $) (-1161))) (-15 -2647 ((-121) (-634 $) (-1161))) (-15 -2530 ((-1249) (-634 $))))) 
+((-2526 (((-3 |#5| "failed") |#5| |#2| (-1 |#2|)) 35))) 
+(((-466 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2526 ((-3 |#5| "failed") |#5| |#2| (-1 |#2|)))) (-788) (-842) (-558) (-950 |#3| |#1| |#2|) (-13 (-1037 (-409 (-568))) (-365) (-10 -8 (-15 -2747 ($ |#4|)) (-15 -2319 (|#4| $)) (-15 -2326 (|#4| $))))) (T -466)) 
+((-2526 (*1 *2 *2 *3 *4) (|partial| -12 (-5 *4 (-1 *3)) (-4 *3 (-842)) (-4 *5 (-788)) (-4 *6 (-558)) (-4 *7 (-950 *6 *5 *3)) (-5 *1 (-466 *5 *3 *6 *7 *2)) (-4 *2 (-13 (-1037 (-409 (-568))) (-365) (-10 -8 (-15 -2747 ($ *7)) (-15 -2319 (*7 $)) (-15 -2326 (*7 $)))))))) 
+(-10 -7 (-15 -2526 ((-3 |#5| "failed") |#5| |#2| (-1 |#2|)))) 
+((-2090 ((|#3|) 43)) (-2378 (((-634 |#5|)) 47)) (-3813 (((-634 |#5|) (-634 |#5|)) 129)) (-2945 ((|#3| |#3|) 107)) (-2318 (((-1249)) 106)) (-2603 (((-634 |#5|)) 150 (|has| |#1| (-370)))) (-1450 (((-634 |#7|)) 153 (|has| |#1| (-370)))) (-1277 (((-1249) (-634 (-121))) 120)) (-1345 ((|#5| |#7|) 94)) (-3869 (((-634 |#7|) (-917)) 149 (|has| |#1| (-370)))) (-4284 (((-634 |#7|) |#5|) 92)) (-3423 ((|#6| |#3| |#7|) 97)) (-1296 (((-568) (-917)) 194 (|has| |#1| (-370)))) (-2577 (((-568) (-917) (-917)) 193 (|has| |#1| (-370)))) (-2102 (((-568) (-917)) 176 (|has| |#1| (-370)))) (-2865 (((-2 (|:| |num| (-634 |#3|)) (|:| |den| |#3|)) |#8|) 69)) (-2335 ((|#8| |#3|) 50)) (-1758 (((-634 |#3|) |#8| (-634 |#3|)) 136)) (-4454 (((-634 |#3|) |#8| (-763)) 65)) (-2219 ((|#3| |#3| (-568)) 40)) (-2148 (((-568)) 74)) (-3383 (((-763)) 73)) (-3246 (((-2 (|:| -3894 (-568)) (|:| |num| |#3|) (|:| |den| |#3|) (|:| |upTo| (-568))) |#8| (-568) (-568)) 114)) (-2733 (((-3 |#1| "failed") (-409 |#3|) |#7|) 144) (((-3 |#1| "failed") |#3| |#3| |#7|) 139) (((-3 |#1| "failed") |#3| |#7|) 104)) (-1339 ((|#1| (-409 |#3|) |#7|) 145) ((|#1| |#3| |#3| |#7|) 140) ((|#1| |#3| |#7|) 105)) (-1371 (((-634 |#10|)) 70)) (-3012 (((-634 |#10|)) 45)) (-3456 (((-568)) 204 (|has| |#1| (-370)))) (-2669 ((|#8|) 54)) (-2054 (((-1239 (-568) -3494) (-917)) 155 (|has| |#1| (-370))) (((-1239 (-568) -3494)) 156 (|has| |#1| (-370)))) (-3223 (((-1157 (-568)) (-917)) 158 (|has| |#1| (-370))) (((-1157 (-568))) 196 (|has| |#1| (-370))))) 
+(((-467 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9| |#10| |#11|) (-10 -7 (-15 -2318 ((-1249))) (-15 -2945 (|#3| |#3|)) (-15 -2219 (|#3| |#3| (-568))) (-15 -1277 ((-1249) (-634 (-121)))) (-15 -2090 (|#3|)) (-15 -3383 ((-763))) (-15 -2148 ((-568))) (-15 -3012 ((-634 |#10|))) (-15 -1371 ((-634 |#10|))) (-15 -3813 ((-634 |#5|) (-634 |#5|))) (-15 -2378 ((-634 |#5|))) (-15 -3423 (|#6| |#3| |#7|)) (-15 -2865 ((-2 (|:| |num| (-634 |#3|)) (|:| |den| |#3|)) |#8|)) (-15 -3246 ((-2 (|:| -3894 (-568)) (|:| |num| |#3|) (|:| |den| |#3|) (|:| |upTo| (-568))) |#8| (-568) (-568))) (-15 -4454 ((-634 |#3|) |#8| (-763))) (-15 -1758 ((-634 |#3|) |#8| (-634 |#3|))) (-15 -1339 (|#1| |#3| |#7|)) (-15 -1339 (|#1| |#3| |#3| |#7|)) (-15 -1339 (|#1| (-409 |#3|) |#7|)) (-15 -2733 ((-3 |#1| "failed") |#3| |#7|)) (-15 -2733 ((-3 |#1| "failed") |#3| |#3| |#7|)) (-15 -2733 ((-3 |#1| "failed") (-409 |#3|) |#7|)) (-15 -2335 (|#8| |#3|)) (-15 -2669 (|#8|)) (-15 -4284 ((-634 |#7|) |#5|)) (-15 -1345 (|#5| |#7|)) (IF (|has| |#1| (-370)) (PROGN (-15 -1450 ((-634 |#7|))) (-15 -2603 ((-634 |#5|))) (-15 -3223 ((-1157 (-568)))) (-15 -3223 ((-1157 (-568)) (-917))) (-15 -3456 ((-568))) (-15 -3869 ((-634 |#7|) (-917))) (-15 -2102 ((-568) (-917))) (-15 -1296 ((-568) (-917))) (-15 -2577 ((-568) (-917) (-917))) (-15 -2054 ((-1239 (-568) -3494))) (-15 -2054 ((-1239 (-568) -3494) (-917)))) |noBranch|)) (-365) (-634 (-1161)) (-950 |#1| |#4| (-852 |#2|)) (-230 (-1699 |#2|) (-763)) (-971 |#1|) (-641 |#1|) (-920 |#1| |#6|) (-235 |#7|) (-536 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#11|) (-258 |#9|) (-117)) (T -467)) 
+((-2054 (*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-1239 (-568) -3494)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) (-2054 (*1 *2) (-12 (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-1239 (-568) -3494)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-2577 (*1 *2 *3 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-568)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) (-1296 (*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-568)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) (-2102 (*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-568)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) (-3869 (*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-634 *10)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) (-3456 (*1 *2) (-12 (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-568)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-3223 (*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-1157 (-568))) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) (-3223 (*1 *2) (-12 (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-1157 (-568))) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-2603 (*1 *2) (-12 (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *7)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-1450 (*1 *2) (-12 (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *9)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-1345 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-641 *4)) (-4 *3 (-920 *4 *8)) (-4 *9 (-235 *3)) (-4 *10 (-536 *4 *5 *6 *7 *2 *8 *3 *9 *12)) (-4 *12 (-117)) (-4 *2 (-971 *4)) (-5 *1 (-467 *4 *5 *6 *7 *2 *8 *3 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) (-4284 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *3 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *4 *5 *6 *7 *3 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *9)) (-5 *1 (-467 *4 *5 *6 *7 *3 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-2669 (*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-536 *3 *4 *5 *6 *7 *8 *9 *2 *12)) (-4 *12 (-117)) (-4 *2 (-235 *9)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *2 *10 *11 *12)) (-4 *11 (-258 *10)))) (-2335 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *6 (-230 (-1699 *5) (-763))) (-4 *7 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-536 *4 *5 *3 *6 *7 *8 *9 *2 *12)) (-4 *12 (-117)) (-4 *2 (-235 *9)) (-5 *1 (-467 *4 *5 *3 *6 *7 *8 *9 *2 *10 *11 *12)) (-4 *11 (-258 *10)))) (-2733 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 *6)) (-4 *6 (-950 *2 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-14 *5 (-634 (-1161))) (-4 *8 (-971 *2)) (-4 *9 (-641 *2)) (-4 *4 (-920 *2 *9)) (-4 *10 (-235 *4)) (-4 *11 (-536 *2 *5 *6 *7 *8 *9 *4 *10 *13)) (-4 *13 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *6 *7 *8 *9 *4 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-2733 (*1 *2 *3 *3 *4) (|partial| -12 (-14 *5 (-634 (-1161))) (-4 *3 (-950 *2 *6 (-852 *5))) (-4 *6 (-230 (-1699 *5) (-763))) (-4 *7 (-971 *2)) (-4 *8 (-641 *2)) (-4 *4 (-920 *2 *8)) (-4 *9 (-235 *4)) (-4 *10 (-536 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) (-2733 (*1 *2 *3 *4) (|partial| -12 (-14 *5 (-634 (-1161))) (-4 *3 (-950 *2 *6 (-852 *5))) (-4 *6 (-230 (-1699 *5) (-763))) (-4 *7 (-971 *2)) (-4 *8 (-641 *2)) (-4 *4 (-920 *2 *8)) (-4 *9 (-235 *4)) (-4 *10 (-536 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) (-1339 (*1 *2 *3 *4) (-12 (-5 *3 (-409 *6)) (-4 *6 (-950 *2 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-14 *5 (-634 (-1161))) (-4 *8 (-971 *2)) (-4 *9 (-641 *2)) (-4 *4 (-920 *2 *9)) (-4 *10 (-235 *4)) (-4 *11 (-536 *2 *5 *6 *7 *8 *9 *4 *10 *13)) (-4 *13 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *6 *7 *8 *9 *4 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-1339 (*1 *2 *3 *3 *4) (-12 (-14 *5 (-634 (-1161))) (-4 *3 (-950 *2 *6 (-852 *5))) (-4 *6 (-230 (-1699 *5) (-763))) (-4 *7 (-971 *2)) (-4 *8 (-641 *2)) (-4 *4 (-920 *2 *8)) (-4 *9 (-235 *4)) (-4 *10 (-536 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) (-1339 (*1 *2 *3 *4) (-12 (-14 *5 (-634 (-1161))) (-4 *3 (-950 *2 *6 (-852 *5))) (-4 *6 (-230 (-1699 *5) (-763))) (-4 *7 (-971 *2)) (-4 *8 (-641 *2)) (-4 *4 (-920 *2 *8)) (-4 *9 (-235 *4)) (-4 *10 (-536 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) (-1758 (*1 *2 *3 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *3 (-235 *10)) (-4 *11 (-536 *4 *5 *6 *7 *8 *9 *10 *3 *13)) (-4 *13 (-117)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *3 *11 *12 *13)) (-4 *12 (-258 *11)))) (-4454 (*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1699 *6) *4)) (-4 *9 (-971 *5)) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-4 *3 (-235 *11)) (-4 *12 (-536 *5 *6 *7 *8 *9 *10 *11 *3 *14)) (-4 *14 (-117)) (-5 *2 (-634 *7)) (-5 *1 (-467 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13 *14)) (-4 *13 (-258 *12)))) (-3246 (*1 *2 *3 *4 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1699 *6) (-763))) (-4 *9 (-971 *5)) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-4 *3 (-235 *11)) (-4 *12 (-536 *5 *6 *7 *8 *9 *10 *11 *3 *14)) (-4 *14 (-117)) (-5 *2 (-2 (|:| -3894 (-568)) (|:| |num| *7) (|:| |den| *7) (|:| |upTo| (-568)))) (-5 *1 (-467 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13 *14)) (-5 *4 (-568)) (-4 *13 (-258 *12)))) (-2865 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *3 (-235 *10)) (-4 *11 (-536 *4 *5 *6 *7 *8 *9 *10 *3 *13)) (-4 *13 (-117)) (-5 *2 (-2 (|:| |num| (-634 *6)) (|:| |den| *6))) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *3 *11 *12 *13)) (-4 *12 (-258 *11)))) (-3423 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *7 (-230 (-1699 *6) (-763))) (-4 *8 (-971 *5)) (-4 *4 (-920 *5 *2)) (-4 *9 (-235 *4)) (-4 *10 (-536 *5 *6 *3 *7 *8 *2 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-641 *5)) (-5 *1 (-467 *5 *6 *3 *7 *8 *2 *4 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) (-2378 (*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *7)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-3813 (*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-971 *3)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-1371 (*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *12)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-3012 (*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *12)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-2148 (*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-568)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-3383 (*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) *2)) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-763)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-2090 (*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-230 (-1699 *4) (-763))) (-4 *6 (-971 *3)) (-4 *7 (-641 *3)) (-4 *8 (-920 *3 *7)) (-4 *9 (-235 *8)) (-4 *10 (-536 *3 *4 *2 *5 *6 *7 *8 *9 *12)) (-4 *12 (-117)) (-4 *2 (-950 *3 *5 (-852 *4))) (-5 *1 (-467 *3 *4 *2 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) (-1277 (*1 *2 *3) (-12 (-5 *3 (-634 (-121))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-1249)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) (-2219 (*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *2 (-950 *4 *6 (-852 *5))) (-4 *6 (-230 (-1699 *5) (-763))) (-4 *7 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *4 *5 *2 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *1 (-467 *4 *5 *2 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) (-2945 (*1 *2 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *2 (-950 *3 *5 (-852 *4))) (-4 *5 (-230 (-1699 *4) (-763))) (-4 *6 (-971 *3)) (-4 *7 (-641 *3)) (-4 *8 (-920 *3 *7)) (-4 *9 (-235 *8)) (-4 *10 (-536 *3 *4 *2 *5 *6 *7 *8 *9 *12)) (-4 *12 (-117)) (-5 *1 (-467 *3 *4 *2 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) (-2318 (*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-1249)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11))))) 
+(-10 -7 (-15 -2318 ((-1249))) (-15 -2945 (|#3| |#3|)) (-15 -2219 (|#3| |#3| (-568))) (-15 -1277 ((-1249) (-634 (-121)))) (-15 -2090 (|#3|)) (-15 -3383 ((-763))) (-15 -2148 ((-568))) (-15 -3012 ((-634 |#10|))) (-15 -1371 ((-634 |#10|))) (-15 -3813 ((-634 |#5|) (-634 |#5|))) (-15 -2378 ((-634 |#5|))) (-15 -3423 (|#6| |#3| |#7|)) (-15 -2865 ((-2 (|:| |num| (-634 |#3|)) (|:| |den| |#3|)) |#8|)) (-15 -3246 ((-2 (|:| -3894 (-568)) (|:| |num| |#3|) (|:| |den| |#3|) (|:| |upTo| (-568))) |#8| (-568) (-568))) (-15 -4454 ((-634 |#3|) |#8| (-763))) (-15 -1758 ((-634 |#3|) |#8| (-634 |#3|))) (-15 -1339 (|#1| |#3| |#7|)) (-15 -1339 (|#1| |#3| |#3| |#7|)) (-15 -1339 (|#1| (-409 |#3|) |#7|)) (-15 -2733 ((-3 |#1| "failed") |#3| |#7|)) (-15 -2733 ((-3 |#1| "failed") |#3| |#3| |#7|)) (-15 -2733 ((-3 |#1| "failed") (-409 |#3|) |#7|)) (-15 -2335 (|#8| |#3|)) (-15 -2669 (|#8|)) (-15 -4284 ((-634 |#7|) |#5|)) (-15 -1345 (|#5| |#7|)) (IF (|has| |#1| (-370)) (PROGN (-15 -1450 ((-634 |#7|))) (-15 -2603 ((-634 |#5|))) (-15 -3223 ((-1157 (-568)))) (-15 -3223 ((-1157 (-568)) (-917))) (-15 -3456 ((-568))) (-15 -3869 ((-634 |#7|) (-917))) (-15 -2102 ((-568) (-917))) (-15 -1296 ((-568) (-917))) (-15 -2577 ((-568) (-917) (-917))) (-15 -2054 ((-1239 (-568) -3494))) (-15 -2054 ((-1239 (-568) -3494) (-917)))) |noBranch|)) 
+((-2449 (((-121) $ $) NIL)) (-2057 (((-634 |#3|) $) 41)) (-4141 (((-121) $) NIL)) (-1794 (((-121) $) NIL (|has| |#1| (-558)))) (-3647 (((-2 (|:| |under| $) (|:| -4115 $) (|:| |upper| $)) $ |#3|) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-2803 (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-4490 (($) NIL T CONST)) (-4382 (((-121) $) NIL (|has| |#1| (-558)))) (-1880 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2536 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2343 (((-121) $) NIL (|has| |#1| (-558)))) (-3993 (((-634 |#4|) (-634 |#4|) $) NIL (|has| |#1| (-558)))) (-2727 (((-634 |#4|) (-634 |#4|) $) NIL (|has| |#1| (-558)))) (-3668 (((-3 $ "failed") (-634 |#4|)) 47)) (-2857 (($ (-634 |#4|)) NIL)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090))))) (-4330 (($ |#4| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090)))) (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-2607 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-558)))) (-3094 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) NIL (|has| $ (-6 -4521))) ((|#4| (-1 |#4| |#4| |#4|) $) NIL (|has| $ (-6 -4521)))) (-3317 (((-634 |#4|) $) 18 (|has| $ (-6 -4521)))) (-4001 ((|#3| $) 45)) (-3791 (((-121) $ (-763)) NIL)) (-4406 (((-634 |#4|) $) 14 (|has| $ (-6 -4521)))) (-2551 (((-121) |#4| $) 26 (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090))))) (-2253 (($ (-1 |#4| |#4|) $) 23 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#4| |#4|) $) 21)) (-2249 (((-634 |#3|) $) NIL)) (-1495 (((-121) |#3| $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL)) (-1440 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-558)))) (-4025 (((-1108) $) NIL)) (-2712 (((-3 |#4| "failed") (-1 (-121) |#4|) $) NIL)) (-3951 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 |#4|) (-634 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 (-288 |#4|))) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) 39)) (-1990 (($) 17)) (-4170 (((-763) |#4| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090)))) (((-763) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-3865 (($ $) 16)) (-4280 (((-541) $) NIL (|has| |#4| (-609 (-541)))) (($ (-634 |#4|)) 49)) (-4289 (($ (-634 |#4|)) 13)) (-3206 (($ $ |#3|) NIL)) (-2527 (($ $ |#3|) NIL)) (-4332 (($ $ |#3|) NIL)) (-2747 (((-850) $) 38) (((-634 |#4|) $) 48)) (-3437 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 30)) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-468 |#1| |#2| |#3| |#4|) (-13 (-977 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -4280 ($ (-634 |#4|))) (-6 -4521) (-6 -4522))) (-1047) (-788) (-842) (-1061 |#1| |#2| |#3|)) (T -468)) 
+((-4280 (*1 *1 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-468 *3 *4 *5 *6))))) 
+(-13 (-977 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -4280 ($ (-634 |#4|))) (-6 -4521) (-6 -4522))) 
+((-3058 (($) 11)) (-1557 (($) 13)) (* (($ |#2| $) 15) (($ $ |#2|) 16))) 
+(((-469 |#1| |#2| |#3|) (-10 -8 (-15 -1557 (|#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 -3058 (|#1|))) (-470 |#2| |#3|) (-172) (-23)) (T -469)) 
+NIL 
+(-10 -8 (-15 -1557 (|#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 -3058 (|#1|))) 
+((-2449 (((-121) $ $) 7)) (-3668 (((-3 |#1| "failed") $) 23)) (-2857 ((|#1| $) 22)) (-2062 (($ $ $) 20)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-1836 ((|#2| $) 18)) (-2747 (((-850) $) 11) (($ |#1|) 24)) (-3058 (($) 17 T CONST)) (-1557 (($) 21 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 14) (($ $ $) 12)) (-1769 (($ $ $) 13)) (* (($ |#1| $) 16) (($ $ |#1|) 15))) 
 (((-470 |#1| |#2|) (-1275) (-172) (-23)) (T -470)) 
-((-1556 (*1 *1) (-12 (-4 *1 (-470 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) (-3272 (*1 *1 *1 *1) (-12 (-4 *1 (-470 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23))))) 
-(-13 (-475 |t#1| |t#2|) (-1037 |t#1|) (-10 -8 (-15 (-1556) ($) -3495) (-15 -3272 ($ $ $)))) 
+((-1557 (*1 *1) (-12 (-4 *1 (-470 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) (-2062 (*1 *1 *1 *1) (-12 (-4 *1 (-470 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23))))) 
+(-13 (-475 |t#1| |t#2|) (-1037 |t#1|) (-10 -8 (-15 (-1557) ($) -3497) (-15 -2062 ($ $ $)))) 
 (((-105) . T) ((-608 (-850)) . T) ((-475 |#1| |#2|) . T) ((-1037 |#1|) . T) ((-1090) . T)) 
-((-1608 (((-1244 (-1244 (-568))) (-1244 (-1244 (-568))) (-917)) 18)) (-1840 (((-1244 (-1244 (-568))) (-917)) 16))) 
-(((-471) (-10 -7 (-15 -1608 ((-1244 (-1244 (-568))) (-1244 (-1244 (-568))) (-917))) (-15 -1840 ((-1244 (-1244 (-568))) (-917))))) (T -471)) 
-((-1840 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1244 (-1244 (-568)))) (-5 *1 (-471)))) (-1608 (*1 *2 *2 *3) (-12 (-5 *2 (-1244 (-1244 (-568)))) (-5 *3 (-917)) (-5 *1 (-471))))) 
-(-10 -7 (-15 -1608 ((-1244 (-1244 (-568))) (-1244 (-1244 (-568))) (-917))) (-15 -1840 ((-1244 (-1244 (-568))) (-917)))) 
-((-3964 (((-568) (-568)) 30) (((-568)) 22)) (-4035 (((-568) (-568)) 26) (((-568)) 18)) (-3144 (((-568) (-568)) 28) (((-568)) 20)) (-3200 (((-121) (-121)) 12) (((-121)) 10)) (-4117 (((-121) (-121)) 11) (((-121)) 9)) (-3831 (((-121) (-121)) 24) (((-121)) 15))) 
-(((-472) (-10 -7 (-15 -4117 ((-121))) (-15 -3200 ((-121))) (-15 -4117 ((-121) (-121))) (-15 -3200 ((-121) (-121))) (-15 -3831 ((-121))) (-15 -3144 ((-568))) (-15 -4035 ((-568))) (-15 -3964 ((-568))) (-15 -3831 ((-121) (-121))) (-15 -3144 ((-568) (-568))) (-15 -4035 ((-568) (-568))) (-15 -3964 ((-568) (-568))))) (T -472)) 
-((-3964 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) (-4035 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) (-3144 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) (-3831 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472)))) (-3964 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) (-4035 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) (-3144 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) (-3831 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472)))) (-3200 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472)))) (-4117 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472)))) (-3200 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472)))) (-4117 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472))))) 
-(-10 -7 (-15 -4117 ((-121))) (-15 -3200 ((-121))) (-15 -4117 ((-121) (-121))) (-15 -3200 ((-121) (-121))) (-15 -3831 ((-121))) (-15 -3144 ((-568))) (-15 -4035 ((-568))) (-15 -3964 ((-568))) (-15 -3831 ((-121) (-121))) (-15 -3144 ((-568) (-568))) (-15 -4035 ((-568) (-568))) (-15 -3964 ((-568) (-568)))) 
-((-2447 (((-121) $ $) NIL)) (-2832 (((-634 (-381)) $) 27) (((-634 (-381)) $ (-634 (-381))) 90)) (-3437 (((-634 (-1084 (-381))) $) 14) (((-634 (-1084 (-381))) $ (-634 (-1084 (-381)))) 87)) (-2416 (((-634 (-634 (-944 (-215)))) (-634 (-634 (-944 (-215)))) (-634 (-869))) 42)) (-4201 (((-634 (-634 (-944 (-215)))) $) 83)) (-4203 (((-1249) $ (-944 (-215)) (-869)) 103)) (-1874 (($ $) 82) (($ (-634 (-634 (-944 (-215))))) 93) (($ (-634 (-634 (-944 (-215)))) (-634 (-869)) (-634 (-869)) (-634 (-917))) 92) (($ (-634 (-634 (-944 (-215)))) (-634 (-869)) (-634 (-869)) (-634 (-917)) (-634 (-256))) 94)) (-4487 (((-1143) $) NIL)) (-3649 (((-568) $) 65)) (-4022 (((-1108) $) NIL)) (-4129 (($) 91)) (-1511 (((-634 (-215)) (-634 (-634 (-944 (-215))))) 52)) (-4445 (((-1249) $ (-634 (-944 (-215))) (-869) (-869) (-917)) 97) (((-1249) $ (-944 (-215))) 99) (((-1249) $ (-944 (-215)) (-869) (-869) (-917)) 98)) (-2745 (((-850) $) 109) (($ (-634 (-634 (-944 (-215))))) 104)) (-3054 (((-1249) $ (-944 (-215))) 102)) (-1717 (((-121) $ $) NIL))) 
-(((-473) (-13 (-1090) (-10 -8 (-15 -4129 ($)) (-15 -1874 ($ $)) (-15 -1874 ($ (-634 (-634 (-944 (-215)))))) (-15 -1874 ($ (-634 (-634 (-944 (-215)))) (-634 (-869)) (-634 (-869)) (-634 (-917)))) (-15 -1874 ($ (-634 (-634 (-944 (-215)))) (-634 (-869)) (-634 (-869)) (-634 (-917)) (-634 (-256)))) (-15 -4201 ((-634 (-634 (-944 (-215)))) $)) (-15 -3649 ((-568) $)) (-15 -3437 ((-634 (-1084 (-381))) $)) (-15 -3437 ((-634 (-1084 (-381))) $ (-634 (-1084 (-381))))) (-15 -2832 ((-634 (-381)) $)) (-15 -2832 ((-634 (-381)) $ (-634 (-381)))) (-15 -4445 ((-1249) $ (-634 (-944 (-215))) (-869) (-869) (-917))) (-15 -4445 ((-1249) $ (-944 (-215)))) (-15 -4445 ((-1249) $ (-944 (-215)) (-869) (-869) (-917))) (-15 -3054 ((-1249) $ (-944 (-215)))) (-15 -4203 ((-1249) $ (-944 (-215)) (-869))) (-15 -2745 ($ (-634 (-634 (-944 (-215)))))) (-15 -2745 ((-850) $)) (-15 -2416 ((-634 (-634 (-944 (-215)))) (-634 (-634 (-944 (-215)))) (-634 (-869)))) (-15 -1511 ((-634 (-215)) (-634 (-634 (-944 (-215))))))))) (T -473)) 
-((-2745 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-473)))) (-4129 (*1 *1) (-5 *1 (-473))) (-1874 (*1 *1 *1) (-5 *1 (-473))) (-1874 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *1 (-473)))) (-1874 (*1 *1 *2 *3 *3 *4) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *3 (-634 (-869))) (-5 *4 (-634 (-917))) (-5 *1 (-473)))) (-1874 (*1 *1 *2 *3 *3 *4 *5) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *3 (-634 (-869))) (-5 *4 (-634 (-917))) (-5 *5 (-634 (-256))) (-5 *1 (-473)))) (-4201 (*1 *2 *1) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *1 (-473)))) (-3649 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-473)))) (-3437 (*1 *2 *1) (-12 (-5 *2 (-634 (-1084 (-381)))) (-5 *1 (-473)))) (-3437 (*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1084 (-381)))) (-5 *1 (-473)))) (-2832 (*1 *2 *1) (-12 (-5 *2 (-634 (-381))) (-5 *1 (-473)))) (-2832 (*1 *2 *1 *2) (-12 (-5 *2 (-634 (-381))) (-5 *1 (-473)))) (-4445 (*1 *2 *1 *3 *4 *4 *5) (-12 (-5 *3 (-634 (-944 (-215)))) (-5 *4 (-869)) (-5 *5 (-917)) (-5 *2 (-1249)) (-5 *1 (-473)))) (-4445 (*1 *2 *1 *3) (-12 (-5 *3 (-944 (-215))) (-5 *2 (-1249)) (-5 *1 (-473)))) (-4445 (*1 *2 *1 *3 *4 *4 *5) (-12 (-5 *3 (-944 (-215))) (-5 *4 (-869)) (-5 *5 (-917)) (-5 *2 (-1249)) (-5 *1 (-473)))) (-3054 (*1 *2 *1 *3) (-12 (-5 *3 (-944 (-215))) (-5 *2 (-1249)) (-5 *1 (-473)))) (-4203 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-944 (-215))) (-5 *4 (-869)) (-5 *2 (-1249)) (-5 *1 (-473)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *1 (-473)))) (-2416 (*1 *2 *2 *3) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *3 (-634 (-869))) (-5 *1 (-473)))) (-1511 (*1 *2 *3) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *2 (-634 (-215))) (-5 *1 (-473))))) 
-(-13 (-1090) (-10 -8 (-15 -4129 ($)) (-15 -1874 ($ $)) (-15 -1874 ($ (-634 (-634 (-944 (-215)))))) (-15 -1874 ($ (-634 (-634 (-944 (-215)))) (-634 (-869)) (-634 (-869)) (-634 (-917)))) (-15 -1874 ($ (-634 (-634 (-944 (-215)))) (-634 (-869)) (-634 (-869)) (-634 (-917)) (-634 (-256)))) (-15 -4201 ((-634 (-634 (-944 (-215)))) $)) (-15 -3649 ((-568) $)) (-15 -3437 ((-634 (-1084 (-381))) $)) (-15 -3437 ((-634 (-1084 (-381))) $ (-634 (-1084 (-381))))) (-15 -2832 ((-634 (-381)) $)) (-15 -2832 ((-634 (-381)) $ (-634 (-381)))) (-15 -4445 ((-1249) $ (-634 (-944 (-215))) (-869) (-869) (-917))) (-15 -4445 ((-1249) $ (-944 (-215)))) (-15 -4445 ((-1249) $ (-944 (-215)) (-869) (-869) (-917))) (-15 -3054 ((-1249) $ (-944 (-215)))) (-15 -4203 ((-1249) $ (-944 (-215)) (-869))) (-15 -2745 ($ (-634 (-634 (-944 (-215)))))) (-15 -2745 ((-850) $)) (-15 -2416 ((-634 (-634 (-944 (-215)))) (-634 (-634 (-944 (-215)))) (-634 (-869)))) (-15 -1511 ((-634 (-215)) (-634 (-634 (-944 (-215)))))))) 
-((-1773 (($ $) NIL) (($ $ $) 11))) 
-(((-474 |#1| |#2| |#3|) (-10 -8 (-15 -1773 (|#1| |#1| |#1|)) (-15 -1773 (|#1| |#1|))) (-475 |#2| |#3|) (-172) (-23)) (T -474)) 
-NIL 
-(-10 -8 (-15 -1773 (|#1| |#1| |#1|)) (-15 -1773 (|#1| |#1|))) 
-((-2447 (((-121) $ $) 7)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-3206 ((|#2| $) 18)) (-2745 (((-850) $) 11)) (-3056 (($) 17 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 14) (($ $ $) 12)) (-1767 (($ $ $) 13)) (* (($ |#1| $) 16) (($ $ |#1|) 15))) 
+((-1386 (((-1244 (-1244 (-568))) (-1244 (-1244 (-568))) (-917)) 18)) (-2352 (((-1244 (-1244 (-568))) (-917)) 16))) 
+(((-471) (-10 -7 (-15 -1386 ((-1244 (-1244 (-568))) (-1244 (-1244 (-568))) (-917))) (-15 -2352 ((-1244 (-1244 (-568))) (-917))))) (T -471)) 
+((-2352 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1244 (-1244 (-568)))) (-5 *1 (-471)))) (-1386 (*1 *2 *2 *3) (-12 (-5 *2 (-1244 (-1244 (-568)))) (-5 *3 (-917)) (-5 *1 (-471))))) 
+(-10 -7 (-15 -1386 ((-1244 (-1244 (-568))) (-1244 (-1244 (-568))) (-917))) (-15 -2352 ((-1244 (-1244 (-568))) (-917)))) 
+((-4420 (((-568) (-568)) 30) (((-568)) 22)) (-1502 (((-568) (-568)) 26) (((-568)) 18)) (-2728 (((-568) (-568)) 28) (((-568)) 20)) (-1820 (((-121) (-121)) 12) (((-121)) 10)) (-3641 (((-121) (-121)) 11) (((-121)) 9)) (-1825 (((-121) (-121)) 24) (((-121)) 15))) 
+(((-472) (-10 -7 (-15 -3641 ((-121))) (-15 -1820 ((-121))) (-15 -3641 ((-121) (-121))) (-15 -1820 ((-121) (-121))) (-15 -1825 ((-121))) (-15 -2728 ((-568))) (-15 -1502 ((-568))) (-15 -4420 ((-568))) (-15 -1825 ((-121) (-121))) (-15 -2728 ((-568) (-568))) (-15 -1502 ((-568) (-568))) (-15 -4420 ((-568) (-568))))) (T -472)) 
+((-4420 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) (-1502 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) (-2728 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) (-1825 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472)))) (-4420 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) (-1502 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) (-2728 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) (-1825 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472)))) (-1820 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472)))) (-3641 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472)))) (-1820 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472)))) (-3641 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472))))) 
+(-10 -7 (-15 -3641 ((-121))) (-15 -1820 ((-121))) (-15 -3641 ((-121) (-121))) (-15 -1820 ((-121) (-121))) (-15 -1825 ((-121))) (-15 -2728 ((-568))) (-15 -1502 ((-568))) (-15 -4420 ((-568))) (-15 -1825 ((-121) (-121))) (-15 -2728 ((-568) (-568))) (-15 -1502 ((-568) (-568))) (-15 -4420 ((-568) (-568)))) 
+((-2449 (((-121) $ $) NIL)) (-2833 (((-634 (-381)) $) 27) (((-634 (-381)) $ (-634 (-381))) 90)) (-3474 (((-634 (-1084 (-381))) $) 14) (((-634 (-1084 (-381))) $ (-634 (-1084 (-381)))) 87)) (-2359 (((-634 (-634 (-944 (-215)))) (-634 (-634 (-944 (-215)))) (-634 (-869))) 42)) (-4091 (((-634 (-634 (-944 (-215)))) $) 83)) (-4098 (((-1249) $ (-944 (-215)) (-869)) 103)) (-2504 (($ $) 82) (($ (-634 (-634 (-944 (-215))))) 93) (($ (-634 (-634 (-944 (-215)))) (-634 (-869)) (-634 (-869)) (-634 (-917))) 92) (($ (-634 (-634 (-944 (-215)))) (-634 (-869)) (-634 (-869)) (-634 (-917)) (-634 (-256))) 94)) (-1893 (((-1143) $) NIL)) (-3651 (((-568) $) 65)) (-4025 (((-1108) $) NIL)) (-3694 (($) 91)) (-2667 (((-634 (-215)) (-634 (-634 (-944 (-215))))) 52)) (-1675 (((-1249) $ (-634 (-944 (-215))) (-869) (-869) (-917)) 97) (((-1249) $ (-944 (-215))) 99) (((-1249) $ (-944 (-215)) (-869) (-869) (-917)) 98)) (-2747 (((-850) $) 109) (($ (-634 (-634 (-944 (-215))))) 104)) (-2290 (((-1249) $ (-944 (-215))) 102)) (-1719 (((-121) $ $) NIL))) 
+(((-473) (-13 (-1090) (-10 -8 (-15 -3694 ($)) (-15 -2504 ($ $)) (-15 -2504 ($ (-634 (-634 (-944 (-215)))))) (-15 -2504 ($ (-634 (-634 (-944 (-215)))) (-634 (-869)) (-634 (-869)) (-634 (-917)))) (-15 -2504 ($ (-634 (-634 (-944 (-215)))) (-634 (-869)) (-634 (-869)) (-634 (-917)) (-634 (-256)))) (-15 -4091 ((-634 (-634 (-944 (-215)))) $)) (-15 -3651 ((-568) $)) (-15 -3474 ((-634 (-1084 (-381))) $)) (-15 -3474 ((-634 (-1084 (-381))) $ (-634 (-1084 (-381))))) (-15 -2833 ((-634 (-381)) $)) (-15 -2833 ((-634 (-381)) $ (-634 (-381)))) (-15 -1675 ((-1249) $ (-634 (-944 (-215))) (-869) (-869) (-917))) (-15 -1675 ((-1249) $ (-944 (-215)))) (-15 -1675 ((-1249) $ (-944 (-215)) (-869) (-869) (-917))) (-15 -2290 ((-1249) $ (-944 (-215)))) (-15 -4098 ((-1249) $ (-944 (-215)) (-869))) (-15 -2747 ($ (-634 (-634 (-944 (-215)))))) (-15 -2747 ((-850) $)) (-15 -2359 ((-634 (-634 (-944 (-215)))) (-634 (-634 (-944 (-215)))) (-634 (-869)))) (-15 -2667 ((-634 (-215)) (-634 (-634 (-944 (-215))))))))) (T -473)) 
+((-2747 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-473)))) (-3694 (*1 *1) (-5 *1 (-473))) (-2504 (*1 *1 *1) (-5 *1 (-473))) (-2504 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *1 (-473)))) (-2504 (*1 *1 *2 *3 *3 *4) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *3 (-634 (-869))) (-5 *4 (-634 (-917))) (-5 *1 (-473)))) (-2504 (*1 *1 *2 *3 *3 *4 *5) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *3 (-634 (-869))) (-5 *4 (-634 (-917))) (-5 *5 (-634 (-256))) (-5 *1 (-473)))) (-4091 (*1 *2 *1) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *1 (-473)))) (-3651 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-473)))) (-3474 (*1 *2 *1) (-12 (-5 *2 (-634 (-1084 (-381)))) (-5 *1 (-473)))) (-3474 (*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1084 (-381)))) (-5 *1 (-473)))) (-2833 (*1 *2 *1) (-12 (-5 *2 (-634 (-381))) (-5 *1 (-473)))) (-2833 (*1 *2 *1 *2) (-12 (-5 *2 (-634 (-381))) (-5 *1 (-473)))) (-1675 (*1 *2 *1 *3 *4 *4 *5) (-12 (-5 *3 (-634 (-944 (-215)))) (-5 *4 (-869)) (-5 *5 (-917)) (-5 *2 (-1249)) (-5 *1 (-473)))) (-1675 (*1 *2 *1 *3) (-12 (-5 *3 (-944 (-215))) (-5 *2 (-1249)) (-5 *1 (-473)))) (-1675 (*1 *2 *1 *3 *4 *4 *5) (-12 (-5 *3 (-944 (-215))) (-5 *4 (-869)) (-5 *5 (-917)) (-5 *2 (-1249)) (-5 *1 (-473)))) (-2290 (*1 *2 *1 *3) (-12 (-5 *3 (-944 (-215))) (-5 *2 (-1249)) (-5 *1 (-473)))) (-4098 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-944 (-215))) (-5 *4 (-869)) (-5 *2 (-1249)) (-5 *1 (-473)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *1 (-473)))) (-2359 (*1 *2 *2 *3) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *3 (-634 (-869))) (-5 *1 (-473)))) (-2667 (*1 *2 *3) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *2 (-634 (-215))) (-5 *1 (-473))))) 
+(-13 (-1090) (-10 -8 (-15 -3694 ($)) (-15 -2504 ($ $)) (-15 -2504 ($ (-634 (-634 (-944 (-215)))))) (-15 -2504 ($ (-634 (-634 (-944 (-215)))) (-634 (-869)) (-634 (-869)) (-634 (-917)))) (-15 -2504 ($ (-634 (-634 (-944 (-215)))) (-634 (-869)) (-634 (-869)) (-634 (-917)) (-634 (-256)))) (-15 -4091 ((-634 (-634 (-944 (-215)))) $)) (-15 -3651 ((-568) $)) (-15 -3474 ((-634 (-1084 (-381))) $)) (-15 -3474 ((-634 (-1084 (-381))) $ (-634 (-1084 (-381))))) (-15 -2833 ((-634 (-381)) $)) (-15 -2833 ((-634 (-381)) $ (-634 (-381)))) (-15 -1675 ((-1249) $ (-634 (-944 (-215))) (-869) (-869) (-917))) (-15 -1675 ((-1249) $ (-944 (-215)))) (-15 -1675 ((-1249) $ (-944 (-215)) (-869) (-869) (-917))) (-15 -2290 ((-1249) $ (-944 (-215)))) (-15 -4098 ((-1249) $ (-944 (-215)) (-869))) (-15 -2747 ($ (-634 (-634 (-944 (-215)))))) (-15 -2747 ((-850) $)) (-15 -2359 ((-634 (-634 (-944 (-215)))) (-634 (-634 (-944 (-215)))) (-634 (-869)))) (-15 -2667 ((-634 (-215)) (-634 (-634 (-944 (-215)))))))) 
+((-1775 (($ $) NIL) (($ $ $) 11))) 
+(((-474 |#1| |#2| |#3|) (-10 -8 (-15 -1775 (|#1| |#1| |#1|)) (-15 -1775 (|#1| |#1|))) (-475 |#2| |#3|) (-172) (-23)) (T -474)) 
+NIL 
+(-10 -8 (-15 -1775 (|#1| |#1| |#1|)) (-15 -1775 (|#1| |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-1836 ((|#2| $) 18)) (-2747 (((-850) $) 11)) (-3058 (($) 17 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 14) (($ $ $) 12)) (-1769 (($ $ $) 13)) (* (($ |#1| $) 16) (($ $ |#1|) 15))) 
 (((-475 |#1| |#2|) (-1275) (-172) (-23)) (T -475)) 
-((-3206 (*1 *2 *1) (-12 (-4 *1 (-475 *3 *2)) (-4 *3 (-172)) (-4 *2 (-23)))) (-3056 (*1 *1) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) (* (*1 *1 *1 *2) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) (-1773 (*1 *1 *1) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) (-1767 (*1 *1 *1 *1) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) (-1773 (*1 *1 *1 *1) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23))))) 
-(-13 (-1090) (-10 -8 (-15 -3206 (|t#2| $)) (-15 (-3056) ($) -3495) (-15 * ($ |t#1| $)) (-15 * ($ $ |t#1|)) (-15 -1773 ($ $)) (-15 -1767 ($ $ $)) (-15 -1773 ($ $ $)))) 
+((-1836 (*1 *2 *1) (-12 (-4 *1 (-475 *3 *2)) (-4 *3 (-172)) (-4 *2 (-23)))) (-3058 (*1 *1) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) (* (*1 *1 *1 *2) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) (-1775 (*1 *1 *1) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) (-1769 (*1 *1 *1 *1) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) (-1775 (*1 *1 *1 *1) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23))))) 
+(-13 (-1090) (-10 -8 (-15 -1836 (|t#2| $)) (-15 (-3058) ($) -3497) (-15 * ($ |t#1| $)) (-15 * ($ $ |t#1|)) (-15 -1775 ($ $)) (-15 -1769 ($ $ $)) (-15 -1775 ($ $ $)))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-2371 (((-3 (-634 (-492 |#1| |#2|)) "failed") (-634 (-492 |#1| |#2|)) (-634 (-852 |#1|))) 88)) (-2220 (((-634 (-634 (-242 |#1| |#2|))) (-634 (-242 |#1| |#2|)) (-634 (-852 |#1|))) 86)) (-4318 (((-2 (|:| |dpolys| (-634 (-242 |#1| |#2|))) (|:| |coords| (-634 (-568)))) (-634 (-242 |#1| |#2|)) (-634 (-852 |#1|))) 58))) 
-(((-476 |#1| |#2| |#3|) (-10 -7 (-15 -2220 ((-634 (-634 (-242 |#1| |#2|))) (-634 (-242 |#1| |#2|)) (-634 (-852 |#1|)))) (-15 -2371 ((-3 (-634 (-492 |#1| |#2|)) "failed") (-634 (-492 |#1| |#2|)) (-634 (-852 |#1|)))) (-15 -4318 ((-2 (|:| |dpolys| (-634 (-242 |#1| |#2|))) (|:| |coords| (-634 (-568)))) (-634 (-242 |#1| |#2|)) (-634 (-852 |#1|))))) (-634 (-1161)) (-453) (-453)) (T -476)) 
-((-4318 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-852 *5))) (-14 *5 (-634 (-1161))) (-4 *6 (-453)) (-5 *2 (-2 (|:| |dpolys| (-634 (-242 *5 *6))) (|:| |coords| (-634 (-568))))) (-5 *1 (-476 *5 *6 *7)) (-5 *3 (-634 (-242 *5 *6))) (-4 *7 (-453)))) (-2371 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-492 *4 *5))) (-5 *3 (-634 (-852 *4))) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *1 (-476 *4 *5 *6)) (-4 *6 (-453)))) (-2220 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-852 *5))) (-14 *5 (-634 (-1161))) (-4 *6 (-453)) (-5 *2 (-634 (-634 (-242 *5 *6)))) (-5 *1 (-476 *5 *6 *7)) (-5 *3 (-634 (-242 *5 *6))) (-4 *7 (-453))))) 
-(-10 -7 (-15 -2220 ((-634 (-634 (-242 |#1| |#2|))) (-634 (-242 |#1| |#2|)) (-634 (-852 |#1|)))) (-15 -2371 ((-3 (-634 (-492 |#1| |#2|)) "failed") (-634 (-492 |#1| |#2|)) (-634 (-852 |#1|)))) (-15 -4318 ((-2 (|:| |dpolys| (-634 (-242 |#1| |#2|))) (|:| |coords| (-634 (-568)))) (-634 (-242 |#1| |#2|)) (-634 (-852 |#1|))))) 
-((-2925 (((-3 $ "failed") $) 11)) (-1458 (($ $ $) 20)) (-2353 (($ $ $) 21)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) 14)) (-1779 (($ $ $) 9)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) 19))) 
-(((-477 |#1|) (-10 -8 (-15 -2353 (|#1| |#1| |#1|)) (-15 -1458 (|#1| |#1| |#1|)) (-15 -1887 (|#1| |#1| (-568))) (-15 ** (|#1| |#1| (-568))) (-15 -1779 (|#1| |#1| |#1|)) (-15 -2925 ((-3 |#1| "failed") |#1|)) (-15 -1887 (|#1| |#1| (-763))) (-15 ** (|#1| |#1| (-763))) (-15 -1887 (|#1| |#1| (-917))) (-15 ** (|#1| |#1| (-917)))) (-478)) (T -477)) 
-NIL 
-(-10 -8 (-15 -2353 (|#1| |#1| |#1|)) (-15 -1458 (|#1| |#1| |#1|)) (-15 -1887 (|#1| |#1| (-568))) (-15 ** (|#1| |#1| (-568))) (-15 -1779 (|#1| |#1| |#1|)) (-15 -2925 ((-3 |#1| "failed") |#1|)) (-15 -1887 (|#1| |#1| (-763))) (-15 ** (|#1| |#1| (-763))) (-15 -1887 (|#1| |#1| (-917))) (-15 ** (|#1| |#1| (-917)))) 
-((-2447 (((-121) $ $) 7)) (-2671 (($) 19 T CONST)) (-2925 (((-3 $ "failed") $) 15)) (-2735 (((-121) $) 18)) (-4487 (((-1143) $) 9)) (-2081 (($ $) 26)) (-4022 (((-1108) $) 10)) (-1458 (($ $ $) 22)) (-2353 (($ $ $) 21)) (-2745 (((-850) $) 11)) (-1887 (($ $ (-917)) 12) (($ $ (-763)) 16) (($ $ (-568)) 23)) (-1556 (($) 20 T CONST)) (-1717 (((-121) $ $) 6)) (-1779 (($ $ $) 25)) (** (($ $ (-917)) 13) (($ $ (-763)) 17) (($ $ (-568)) 24)) (* (($ $ $) 14))) 
+((-4102 (((-3 (-634 (-492 |#1| |#2|)) "failed") (-634 (-492 |#1| |#2|)) (-634 (-852 |#1|))) 88)) (-3457 (((-634 (-634 (-242 |#1| |#2|))) (-634 (-242 |#1| |#2|)) (-634 (-852 |#1|))) 86)) (-3095 (((-2 (|:| |dpolys| (-634 (-242 |#1| |#2|))) (|:| |coords| (-634 (-568)))) (-634 (-242 |#1| |#2|)) (-634 (-852 |#1|))) 58))) 
+(((-476 |#1| |#2| |#3|) (-10 -7 (-15 -3457 ((-634 (-634 (-242 |#1| |#2|))) (-634 (-242 |#1| |#2|)) (-634 (-852 |#1|)))) (-15 -4102 ((-3 (-634 (-492 |#1| |#2|)) "failed") (-634 (-492 |#1| |#2|)) (-634 (-852 |#1|)))) (-15 -3095 ((-2 (|:| |dpolys| (-634 (-242 |#1| |#2|))) (|:| |coords| (-634 (-568)))) (-634 (-242 |#1| |#2|)) (-634 (-852 |#1|))))) (-634 (-1161)) (-453) (-453)) (T -476)) 
+((-3095 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-852 *5))) (-14 *5 (-634 (-1161))) (-4 *6 (-453)) (-5 *2 (-2 (|:| |dpolys| (-634 (-242 *5 *6))) (|:| |coords| (-634 (-568))))) (-5 *1 (-476 *5 *6 *7)) (-5 *3 (-634 (-242 *5 *6))) (-4 *7 (-453)))) (-4102 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-492 *4 *5))) (-5 *3 (-634 (-852 *4))) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *1 (-476 *4 *5 *6)) (-4 *6 (-453)))) (-3457 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-852 *5))) (-14 *5 (-634 (-1161))) (-4 *6 (-453)) (-5 *2 (-634 (-634 (-242 *5 *6)))) (-5 *1 (-476 *5 *6 *7)) (-5 *3 (-634 (-242 *5 *6))) (-4 *7 (-453))))) 
+(-10 -7 (-15 -3457 ((-634 (-634 (-242 |#1| |#2|))) (-634 (-242 |#1| |#2|)) (-634 (-852 |#1|)))) (-15 -4102 ((-3 (-634 (-492 |#1| |#2|)) "failed") (-634 (-492 |#1| |#2|)) (-634 (-852 |#1|)))) (-15 -3095 ((-2 (|:| |dpolys| (-634 (-242 |#1| |#2|))) (|:| |coords| (-634 (-568)))) (-634 (-242 |#1| |#2|)) (-634 (-852 |#1|))))) 
+((-2902 (((-3 $ "failed") $) 11)) (-2387 (($ $ $) 20)) (-3985 (($ $ $) 21)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) 14)) (-1781 (($ $ $) 9)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) 19))) 
+(((-477 |#1|) (-10 -8 (-15 -3985 (|#1| |#1| |#1|)) (-15 -2387 (|#1| |#1| |#1|)) (-15 -1889 (|#1| |#1| (-568))) (-15 ** (|#1| |#1| (-568))) (-15 -1781 (|#1| |#1| |#1|)) (-15 -2902 ((-3 |#1| "failed") |#1|)) (-15 -1889 (|#1| |#1| (-763))) (-15 ** (|#1| |#1| (-763))) (-15 -1889 (|#1| |#1| (-917))) (-15 ** (|#1| |#1| (-917)))) (-478)) (T -477)) 
+NIL 
+(-10 -8 (-15 -3985 (|#1| |#1| |#1|)) (-15 -2387 (|#1| |#1| |#1|)) (-15 -1889 (|#1| |#1| (-568))) (-15 ** (|#1| |#1| (-568))) (-15 -1781 (|#1| |#1| |#1|)) (-15 -2902 ((-3 |#1| "failed") |#1|)) (-15 -1889 (|#1| |#1| (-763))) (-15 ** (|#1| |#1| (-763))) (-15 -1889 (|#1| |#1| (-917))) (-15 ** (|#1| |#1| (-917)))) 
+((-2449 (((-121) $ $) 7)) (-4490 (($) 19 T CONST)) (-2902 (((-3 $ "failed") $) 15)) (-1598 (((-121) $) 18)) (-1893 (((-1143) $) 9)) (-2083 (($ $) 26)) (-4025 (((-1108) $) 10)) (-2387 (($ $ $) 22)) (-3985 (($ $ $) 21)) (-2747 (((-850) $) 11)) (-1889 (($ $ (-917)) 12) (($ $ (-763)) 16) (($ $ (-568)) 23)) (-1557 (($) 20 T CONST)) (-1719 (((-121) $ $) 6)) (-1781 (($ $ $) 25)) (** (($ $ (-917)) 13) (($ $ (-763)) 17) (($ $ (-568)) 24)) (* (($ $ $) 14))) 
 (((-478) (-1275)) (T -478)) 
-((-2081 (*1 *1 *1) (-4 *1 (-478))) (-1779 (*1 *1 *1 *1) (-4 *1 (-478))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-478)) (-5 *2 (-568)))) (-1887 (*1 *1 *1 *2) (-12 (-4 *1 (-478)) (-5 *2 (-568)))) (-1458 (*1 *1 *1 *1) (-4 *1 (-478))) (-2353 (*1 *1 *1 *1) (-4 *1 (-478)))) 
-(-13 (-716) (-10 -8 (-15 -2081 ($ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ (-568))) (-15 -1887 ($ $ (-568))) (-6 -4516) (-15 -1458 ($ $ $)) (-15 -2353 ($ $ $)))) 
+((-2083 (*1 *1 *1) (-4 *1 (-478))) (-1781 (*1 *1 *1 *1) (-4 *1 (-478))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-478)) (-5 *2 (-568)))) (-1889 (*1 *1 *1 *2) (-12 (-4 *1 (-478)) (-5 *2 (-568)))) (-2387 (*1 *1 *1 *1) (-4 *1 (-478))) (-3985 (*1 *1 *1 *1) (-4 *1 (-478)))) 
+(-13 (-716) (-10 -8 (-15 -2083 ($ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ (-568))) (-15 -1889 ($ $ (-568))) (-6 -4518) (-15 -2387 ($ $ $)) (-15 -3985 ($ $ $)))) 
 (((-105) . T) ((-608 (-850)) . T) ((-716) . T) ((-1102) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2055 (((-634 (-1075)) $) NIL)) (-1305 (((-1161) $) 17)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-2617 (($ $ (-409 (-568))) NIL) (($ $ (-409 (-568)) (-409 (-568))) NIL)) (-2583 (((-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|))) $) NIL)) (-1982 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1933 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL (|has| |#1| (-365)))) (-1678 (((-420 $) $) NIL (|has| |#1| (-365)))) (-1902 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1497 (((-121) $ $) NIL (|has| |#1| (-365)))) (-1974 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2786 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3728 (($ (-763) (-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|)))) NIL)) (-1990 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1941 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2671 (($) NIL T CONST)) (-2401 (($ $ $) NIL (|has| |#1| (-365)))) (-2114 (($ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-2412 (($ $ $) NIL (|has| |#1| (-365)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-3927 (((-121) $) NIL (|has| |#1| (-365)))) (-3992 (((-121) $) NIL)) (-1897 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4477 (((-409 (-568)) $) NIL) (((-409 (-568)) $ (-409 (-568))) NIL)) (-2735 (((-121) $) NIL)) (-4044 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3536 (($ $ (-917)) NIL) (($ $ (-409 (-568))) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| (-409 (-568))) NIL) (($ $ (-1075) (-409 (-568))) NIL) (($ $ (-634 (-1075)) (-634 (-409 (-568)))) NIL)) (-2795 (($ (-1 |#1| |#1|) $) 22)) (-4416 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-2495 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL (|has| |#1| (-365)))) (-3837 (($ $) 26 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) 33 (-2198 (-12 (|has| |#1| (-15 -3837 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2055 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181))))) (($ $ (-1240 |#2|)) 27 (|has| |#1| (-43 (-409 (-568)))))) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-365)))) (-2721 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-3848 (((-420 $) $) NIL (|has| |#1| (-365)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-365)))) (-1807 (($ $ (-409 (-568))) NIL)) (-2595 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1892 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))))) (-2709 (((-763) $) NIL (|has| |#1| (-365)))) (-2779 ((|#1| $ (-409 (-568))) NIL) (($ $ $) NIL (|has| (-409 (-568)) (-1102)))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-365)))) (-4189 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) 25 (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) 13 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $ (-1240 |#2|)) 15)) (-3206 (((-409 (-568)) $) NIL)) (-1994 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1945 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1986 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1937 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1978 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2790 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1811 (($ $) NIL)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL (|has| |#1| (-172))) (($ (-1240 |#2|)) NIL) (($ (-1228 |#1| |#2| |#3|)) 9) (($ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $) NIL (|has| |#1| (-558)))) (-2604 ((|#1| $ (-409 (-568))) NIL)) (-4371 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-4078 (((-763)) NIL)) (-1374 ((|#1| $) 18)) (-2006 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1958 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1998 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1949 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2014 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1966 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3996 ((|#1| $ (-409 (-568))) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))) (|has| |#1| (-15 -2745 (|#1| (-1161))))))) (-4023 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1970 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2010 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1962 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2002 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1953 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) 24)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) 23) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
-(((-479 |#1| |#2| |#3|) (-13 (-1224 |#1|) (-10 -8 (-15 -2745 ($ (-1240 |#2|))) (-15 -2745 ($ (-1228 |#1| |#2| |#3|))) (-15 -4189 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -3837 ($ $ (-1240 |#2|))) |noBranch|))) (-1047) (-1161) |#1|) (T -479)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-479 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-1228 *3 *4 *5)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3) (-5 *1 (-479 *3 *4 *5)))) (-4189 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-479 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-3837 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-479 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3)))) 
-(-13 (-1224 |#1|) (-10 -8 (-15 -2745 ($ (-1240 |#2|))) (-15 -2745 ($ (-1228 |#1| |#2| |#3|))) (-15 -4189 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -3837 ($ $ (-1240 |#2|))) |noBranch|))) 
-((-2447 (((-121) $ $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-2986 (($) NIL) (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-1868 (((-1249) $ |#1| |#1|) NIL (|has| $ (-6 -4520)))) (-2510 (((-121) $ (-763)) NIL)) (-2436 ((|#2| $ |#1| |#2|) 18)) (-3507 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-2674 (((-3 |#2| "failed") |#1| $) 19)) (-2671 (($) NIL T CONST)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-3405 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (|has| $ (-6 -4519))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-3 |#2| "failed") |#1| $) 16)) (-4328 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-3092 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (|has| $ (-6 -4519))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-3989 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#2| $ |#1|) NIL)) (-4360 (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-634 |#2|) $) NIL (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) NIL)) (-1881 ((|#1| $) NIL (|has| |#1| (-842)))) (-1979 (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-634 |#2|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-2223 ((|#1| $) NIL (|has| |#1| (-842)))) (-3674 (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4520))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-1946 (((-634 |#1|) $) NIL)) (-3548 (((-121) |#1| $) NIL)) (-1890 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-4450 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-4174 (((-634 |#1|) $) NIL)) (-3578 (((-121) |#1| $) NIL)) (-4022 (((-1108) $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-3876 ((|#2| $) NIL (|has| |#1| (-842)))) (-3775 (((-3 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) "failed") (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL)) (-3724 (($ $ |#2|) NIL (|has| $ (-6 -4520)))) (-1315 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-1387 (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-2041 (((-634 |#2|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#2| $ |#1|) 13) ((|#2| $ |#1| |#2|) NIL)) (-2085 (($) NIL) (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-4168 (((-763) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-763) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090)))) (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-609 (-541))))) (-4287 (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-2745 (((-850) $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-2367 (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-1319 (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2057 (((-634 (-1075)) $) NIL)) (-3325 (((-1161) $) 17)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-4179 (($ $ (-409 (-568))) NIL) (($ $ (-409 (-568)) (-409 (-568))) NIL)) (-2013 (((-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|))) $) NIL)) (-1984 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1935 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL (|has| |#1| (-365)))) (-3498 (((-420 $) $) NIL (|has| |#1| (-365)))) (-1904 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2589 (((-121) $ $) NIL (|has| |#1| (-365)))) (-1976 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2788 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2512 (($ (-763) (-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|)))) NIL)) (-1992 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1943 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4490 (($) NIL T CONST)) (-2403 (($ $ $) NIL (|has| |#1| (-365)))) (-2116 (($ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-2414 (($ $ $) NIL (|has| |#1| (-365)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-2197 (((-121) $) NIL (|has| |#1| (-365)))) (-1302 (((-121) $) NIL)) (-1899 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1844 (((-409 (-568)) $) NIL) (((-409 (-568)) $ (-409 (-568))) NIL)) (-1598 (((-121) $) NIL)) (-1550 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4168 (($ $ (-917)) NIL) (($ $ (-409 (-568))) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| (-409 (-568))) NIL) (($ $ (-1075) (-409 (-568))) NIL) (($ $ (-634 (-1075)) (-634 (-409 (-568)))) NIL)) (-2797 (($ (-1 |#1| |#1|) $) 22)) (-4418 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-2498 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL (|has| |#1| (-365)))) (-1845 (($ $) 26 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) 33 (-2199 (-12 (|has| |#1| (-15 -1845 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2057 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181))))) (($ $ (-1240 |#2|)) 27 (|has| |#1| (-43 (-409 (-568)))))) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-365)))) (-2723 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-3850 (((-420 $) $) NIL (|has| |#1| (-365)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-365)))) (-2168 (($ $ (-409 (-568))) NIL)) (-2597 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1894 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))))) (-1466 (((-763) $) NIL (|has| |#1| (-365)))) (-2781 ((|#1| $ (-409 (-568))) NIL) (($ $ $) NIL (|has| (-409 (-568)) (-1102)))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-365)))) (-4191 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) 25 (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) 13 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $ (-1240 |#2|)) 15)) (-1836 (((-409 (-568)) $) NIL)) (-1996 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1947 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1988 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1939 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1980 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2792 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2188 (($ $) NIL)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL (|has| |#1| (-172))) (($ (-1240 |#2|)) NIL) (($ (-1228 |#1| |#2| |#3|)) 9) (($ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $) NIL (|has| |#1| (-558)))) (-2079 ((|#1| $ (-409 (-568))) NIL)) (-3385 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-3425 (((-763)) NIL)) (-1374 ((|#1| $) 18)) (-2008 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1959 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2000 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1951 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2016 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1968 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3999 ((|#1| $ (-409 (-568))) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))) (|has| |#1| (-15 -2747 (|#1| (-1161))))))) (-1439 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1972 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2012 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1964 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2004 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1955 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) 24)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) 23) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
+(((-479 |#1| |#2| |#3|) (-13 (-1224 |#1|) (-10 -8 (-15 -2747 ($ (-1240 |#2|))) (-15 -2747 ($ (-1228 |#1| |#2| |#3|))) (-15 -4191 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -1845 ($ $ (-1240 |#2|))) |noBranch|))) (-1047) (-1161) |#1|) (T -479)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-479 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-1228 *3 *4 *5)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3) (-5 *1 (-479 *3 *4 *5)))) (-4191 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-479 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-1845 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-479 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3)))) 
+(-13 (-1224 |#1|) (-10 -8 (-15 -2747 ($ (-1240 |#2|))) (-15 -2747 ($ (-1228 |#1| |#2| |#3|))) (-15 -4191 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -1845 ($ $ (-1240 |#2|))) |noBranch|))) 
+((-2449 (((-121) $ $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-2988 (($) NIL) (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-2481 (((-1249) $ |#1| |#1|) NIL (|has| $ (-6 -4522)))) (-1667 (((-121) $ (-763)) NIL)) (-2438 ((|#2| $ |#1| |#2|) 18)) (-3963 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-2678 (((-3 |#2| "failed") |#1| $) 19)) (-4490 (($) NIL T CONST)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-1568 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (|has| $ (-6 -4521))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-3 |#2| "failed") |#1| $) 16)) (-4330 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-3094 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (|has| $ (-6 -4521))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-1292 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#2| $ |#1|) NIL)) (-3317 (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-634 |#2|) $) NIL (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) NIL)) (-2539 ((|#1| $) NIL (|has| |#1| (-842)))) (-4406 (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-634 |#2|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-3631 ((|#1| $) NIL (|has| |#1| (-842)))) (-2253 (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4522))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-4253 (((-634 |#1|) $) NIL)) (-2807 (((-121) |#1| $) NIL)) (-2580 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-1708 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-3948 (((-634 |#1|) $) NIL)) (-2916 (((-121) |#1| $) NIL)) (-4025 (((-1108) $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-3877 ((|#2| $) NIL (|has| |#1| (-842)))) (-2712 (((-3 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) "failed") (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL)) (-2490 (($ $ |#2|) NIL (|has| $ (-6 -4522)))) (-3403 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-3951 (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-1480 (((-634 |#2|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#2| $ |#1|) 13) ((|#2| $ |#1| |#2|) NIL)) (-3132 (($) NIL) (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-4170 (((-763) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-763) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090)))) (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-609 (-541))))) (-4289 (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-2747 (((-850) $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-4074 (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-3437 (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
 (((-480 |#1| |#2| |#3| |#4|) (-1172 |#1| |#2|) (-1090) (-1090) (-1172 |#1| |#2|) |#2|) (T -480)) 
 NIL 
 (-1172 |#1| |#2|) 
-((-2447 (((-121) $ $) NIL)) (-2387 (((-634 (-2 (|:| -4092 $) (|:| -1798 (-634 |#4|)))) (-634 |#4|)) NIL)) (-2415 (((-634 $) (-634 |#4|)) NIL)) (-2055 (((-634 |#3|) $) NIL)) (-4211 (((-121) $) NIL)) (-3824 (((-121) $) NIL (|has| |#1| (-558)))) (-3300 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-2819 ((|#4| |#4| $) NIL)) (-3644 (((-2 (|:| |under| $) (|:| -1519 $) (|:| |upper| $)) $ |#3|) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-2801 (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519))) (((-3 |#4| "failed") $ |#3|) NIL)) (-2671 (($) NIL T CONST)) (-1565 (((-121) $) 26 (|has| |#1| (-558)))) (-3846 (((-121) $ $) NIL (|has| |#1| (-558)))) (-3106 (((-121) $ $) NIL (|has| |#1| (-558)))) (-3695 (((-121) $) NIL (|has| |#1| (-558)))) (-4275 (((-634 |#4|) (-634 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-2355 (((-634 |#4|) (-634 |#4|) $) NIL (|has| |#1| (-558)))) (-2492 (((-634 |#4|) (-634 |#4|) $) NIL (|has| |#1| (-558)))) (-3666 (((-3 $ "failed") (-634 |#4|)) NIL)) (-2854 (($ (-634 |#4|)) NIL)) (-3935 (((-3 $ "failed") $) 39)) (-2062 ((|#4| |#4| $) NIL)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090))))) (-4328 (($ |#4| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090)))) (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-1500 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-558)))) (-1281 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) NIL)) (-4079 ((|#4| |#4| $) NIL)) (-3092 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) NIL (|has| $ (-6 -4519))) ((|#4| (-1 |#4| |#4| |#4|) $) NIL (|has| $ (-6 -4519))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-3635 (((-2 (|:| -4092 (-634 |#4|)) (|:| -1798 (-634 |#4|))) $) NIL)) (-4360 (((-634 |#4|) $) 16 (|has| $ (-6 -4519)))) (-1362 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-2356 ((|#3| $) 33)) (-1737 (((-121) $ (-763)) NIL)) (-1979 (((-634 |#4|) $) 17 (|has| $ (-6 -4519)))) (-3109 (((-121) |#4| $) 25 (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090))))) (-3674 (($ (-1 |#4| |#4|) $) 23 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#4| |#4|) $) 21)) (-1432 (((-634 |#3|) $) NIL)) (-3392 (((-121) |#3| $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL)) (-4162 (((-3 |#4| "failed") $) 37)) (-1377 (((-634 |#4|) $) NIL)) (-1415 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-2682 ((|#4| |#4| $) NIL)) (-2644 (((-121) $ $) NIL)) (-2705 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-558)))) (-4347 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-4025 ((|#4| |#4| $) NIL)) (-4022 (((-1108) $) NIL)) (-3876 (((-3 |#4| "failed") $) 35)) (-3775 (((-3 |#4| "failed") (-1 (-121) |#4|) $) NIL)) (-1665 (((-3 $ "failed") $ |#4|) 46)) (-1807 (($ $ |#4|) NIL)) (-1387 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 |#4|) (-634 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 (-288 |#4|))) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) 15)) (-3248 (($) 13)) (-3206 (((-763) $) NIL)) (-4168 (((-763) |#4| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090)))) (((-763) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-3863 (($ $) 12)) (-4278 (((-541) $) NIL (|has| |#4| (-609 (-541))))) (-4287 (($ (-634 |#4|)) 20)) (-1290 (($ $ |#3|) 42)) (-3732 (($ $ |#3|) 43)) (-1567 (($ $) NIL)) (-3944 (($ $ |#3|) NIL)) (-2745 (((-850) $) 31) (((-634 |#4|) $) 40)) (-1878 (((-763) $) NIL (|has| |#3| (-370)))) (-3556 (((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4| |#4|)) NIL) (((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-3292 (((-121) $ (-1 (-121) |#4| (-634 |#4|))) NIL)) (-1319 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-2739 (((-634 |#3|) $) NIL)) (-4390 (((-121) |#3| $) NIL)) (-1717 (((-121) $ $) NIL)) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL)) (-2213 (((-634 (-2 (|:| -4094 $) (|:| -2133 (-634 |#4|)))) (-634 |#4|)) NIL)) (-2353 (((-634 $) (-634 |#4|)) NIL)) (-2057 (((-634 |#3|) $) NIL)) (-4141 (((-121) $) NIL)) (-1794 (((-121) $) NIL (|has| |#1| (-558)))) (-4231 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-3767 ((|#4| |#4| $) NIL)) (-3647 (((-2 (|:| |under| $) (|:| -4115 $) (|:| |upper| $)) $ |#3|) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-2803 (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521))) (((-3 |#4| "failed") $ |#3|) NIL)) (-4490 (($) NIL T CONST)) (-4382 (((-121) $) 26 (|has| |#1| (-558)))) (-1880 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2536 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2343 (((-121) $) NIL (|has| |#1| (-558)))) (-2941 (((-634 |#4|) (-634 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-3993 (((-634 |#4|) (-634 |#4|) $) NIL (|has| |#1| (-558)))) (-2727 (((-634 |#4|) (-634 |#4|) $) NIL (|has| |#1| (-558)))) (-3668 (((-3 $ "failed") (-634 |#4|)) NIL)) (-2857 (($ (-634 |#4|)) NIL)) (-3936 (((-3 $ "failed") $) 39)) (-3255 ((|#4| |#4| $) NIL)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090))))) (-4330 (($ |#4| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090)))) (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-2607 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-558)))) (-1359 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) NIL)) (-3434 ((|#4| |#4| $) NIL)) (-3094 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) NIL (|has| $ (-6 -4521))) ((|#4| (-1 |#4| |#4| |#4|) $) NIL (|has| $ (-6 -4521))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-3158 (((-2 (|:| -4094 (-634 |#4|)) (|:| -2133 (-634 |#4|))) $) NIL)) (-3317 (((-634 |#4|) $) 16 (|has| $ (-6 -4521)))) (-3764 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-4001 ((|#3| $) 33)) (-3791 (((-121) $ (-763)) NIL)) (-4406 (((-634 |#4|) $) 17 (|has| $ (-6 -4521)))) (-2551 (((-121) |#4| $) 25 (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090))))) (-2253 (($ (-1 |#4| |#4|) $) 23 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#4| |#4|) $) 21)) (-2249 (((-634 |#3|) $) NIL)) (-1495 (((-121) |#3| $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL)) (-4164 (((-3 |#4| "failed") $) 37)) (-3882 (((-634 |#4|) $) NIL)) (-2157 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-1315 ((|#4| |#4| $) NIL)) (-4342 (((-121) $ $) NIL)) (-1440 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-558)))) (-3236 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-1452 ((|#4| |#4| $) NIL)) (-4025 (((-1108) $) NIL)) (-3877 (((-3 |#4| "failed") $) 35)) (-2712 (((-3 |#4| "failed") (-1 (-121) |#4|) $) NIL)) (-3413 (((-3 $ "failed") $ |#4|) 46)) (-2168 (($ $ |#4|) NIL)) (-3951 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 |#4|) (-634 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 (-288 |#4|))) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) 15)) (-1990 (($) 13)) (-1836 (((-763) $) NIL)) (-4170 (((-763) |#4| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090)))) (((-763) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-3865 (($ $) 12)) (-4280 (((-541) $) NIL (|has| |#4| (-609 (-541))))) (-4289 (($ (-634 |#4|)) 20)) (-3206 (($ $ |#3|) 42)) (-2527 (($ $ |#3|) 43)) (-4392 (($ $) NIL)) (-4332 (($ $ |#3|) NIL)) (-2747 (((-850) $) 31) (((-634 |#4|) $) 40)) (-2524 (((-763) $) NIL (|has| |#3| (-370)))) (-2835 (((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4| |#4|)) NIL) (((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-2145 (((-121) $ (-1 (-121) |#4| (-634 |#4|))) NIL)) (-3437 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-3321 (((-634 |#3|) $) NIL)) (-1413 (((-121) |#3| $) NIL)) (-1719 (((-121) $ $) NIL)) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
 (((-481 |#1| |#2| |#3| |#4|) (-1189 |#1| |#2| |#3| |#4|) (-558) (-788) (-842) (-1061 |#1| |#2| |#3|)) (T -481)) 
 NIL 
 (-1189 |#1| |#2| |#3| |#4|) 
-((-4089 (((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465))) (-1161)) NIL (|has| (-53) (-1037 (-1161)))) (((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465))) NIL)) (-4329 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) (-1161)) NIL (|has| (-53) (-1037 (-1161)))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53))) NIL)) (-1414 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) (-1161)) NIL (|has| (-53) (-1037 (-1161)))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) NIL)) (-4102 (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) NIL)) (-2788 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) (-1161)) NIL (|has| (-53) (-1037 (-1161)))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) NIL)) (-2659 (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53))) NIL)) (-1761 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465)))) NIL)) (-1829 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) (-1161)) NIL (|has| (-53) (-1037 (-1161)))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53))) NIL)) (-1961 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) (-1161)) NIL (|has| (-53) (-1037 (-1161)))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53))) NIL)) (-2017 (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53))) NIL)) (-3641 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) (-1161)) NIL (|has| (-53) (-1037 (-1161)))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53))) NIL)) (-1633 (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-634 (-1161)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-634 (-1161))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53))) NIL)) (-3430 (((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465))) (-1161)) NIL (|has| (-53) (-1037 (-1161)))) (((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465))) NIL))) 
-(((-482) (-10 -7 (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-634 (-1161)))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -1829 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)))) (-15 -1829 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -1961 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)))) (-15 -1961 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (IF (|has| (-53) (-1037 (-1161))) (IF (|has| (-53) (-1037 (-1161))) (PROGN (-15 -1829 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) (-1161))) (-15 -1961 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|) (-15 -1761 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465))))) (-15 -3641 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)))) (-15 -3641 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -2017 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)))) (-15 -2017 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -2659 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)))) (-15 -2659 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)))) (-15 -4329 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)))) (-15 -4329 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)))) (-15 -1414 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -1414 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)))) (-15 -3430 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465)))) (-15 -4089 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465)))) (IF (|has| (-53) (-1037 (-1161))) (IF (|has| (-53) (-1037 (-1161))) (PROGN (-15 -4089 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465))) (-1161))) (-15 -3430 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465))) (-1161))) (-15 -4329 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) (-1161))) (-15 -2788 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) (-1161))) (-15 -1414 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) (-1161))) (-15 -3641 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|))) (T -482)) 
-((-3641 (*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) (-1414 (*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) (-2788 (*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) (-4329 (*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) (-3430 (*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465)))) (-5 *1 (-482)))) (-4089 (*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465)))) (-5 *1 (-482)))) (-4089 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763))))) (-5 *1 (-482)))) (-3430 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763))))) (-5 *1 (-482)))) (-1414 (*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) (-1414 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) (-2788 (*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) (-2788 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) (-4329 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) (-4329 (*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) (-4102 (*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) (-4102 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) (-2659 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) (-2659 (*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) (-2017 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) (-2017 (*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) (-3641 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) (-3641 (*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) (-1761 (*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465)))) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) (-1961 (*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) (-1829 (*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) (-1961 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) (-1961 (*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) (-1829 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) (-1829 (*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) (-1633 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) (-1633 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) (-1633 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) (-1633 (*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482))))) 
-(-10 -7 (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-634 (-1161)))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -1829 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)))) (-15 -1829 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -1961 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)))) (-15 -1961 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (IF (|has| (-53) (-1037 (-1161))) (IF (|has| (-53) (-1037 (-1161))) (PROGN (-15 -1829 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) (-1161))) (-15 -1961 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|) (-15 -1761 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465))))) (-15 -3641 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)))) (-15 -3641 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -2017 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)))) (-15 -2017 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -2659 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)))) (-15 -2659 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)))) (-15 -4329 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)))) (-15 -4329 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)))) (-15 -1414 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -1414 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)))) (-15 -3430 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465)))) (-15 -4089 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465)))) (IF (|has| (-53) (-1037 (-1161))) (IF (|has| (-53) (-1037 (-1161))) (PROGN (-15 -4089 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465))) (-1161))) (-15 -3430 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465))) (-1161))) (-15 -4329 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) (-1161))) (-15 -2788 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) (-1161))) (-15 -1414 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) (-1161))) (-15 -3641 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|)) 
-((-4324 (((-310 (-568)) |#1|) 11))) 
-(((-483 |#1|) (-10 -7 (-15 -4324 ((-310 (-568)) |#1|))) (-13 (-350) (-609 (-568)))) (T -483)) 
-((-4324 (*1 *2 *3) (-12 (-5 *2 (-310 (-568))) (-5 *1 (-483 *3)) (-4 *3 (-13 (-350) (-609 (-568))))))) 
-(-10 -7 (-15 -4324 ((-310 (-568)) |#1|))) 
-((-4089 (((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465))) (-1161)) NIL (|has| |#1| (-1037 (-1161)))) (((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465))) NIL)) (-4329 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) NIL (|has| |#1| (-1037 (-1161)))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|)) NIL)) (-1414 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) NIL (|has| |#1| (-1037 (-1161)))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|)) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) NIL)) (-4102 (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|)) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) NIL)) (-2788 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) NIL (|has| |#1| (-1037 (-1161)))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|)) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) NIL)) (-2659 (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|)) NIL)) (-1761 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465)))) NIL)) (-1829 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) NIL (|has| |#1| (-1037 (-1161)))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|)) NIL)) (-1961 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) NIL (|has| |#1| (-1037 (-1161)))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|)) NIL)) (-2017 (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|)) NIL)) (-3641 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) NIL (|has| |#1| (-1037 (-1161)))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|)) NIL)) (-1633 (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|)) NIL)) (-3430 (((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465))) (-1161)) NIL (|has| |#1| (-1037 (-1161)))) (((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465))) NIL))) 
-(((-484 |#1|) (-10 -7 (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161)))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -1829 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -1829 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -1961 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -1961 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (IF (|has| |#1| (-1037 (-1161))) (IF (|has| |#1| (-1037 (-1161))) (PROGN (-15 -1829 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -1961 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|) (-15 -1761 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465))))) (-15 -3641 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -3641 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -2017 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -2017 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -2659 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -2659 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -4329 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -4329 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -1414 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -1414 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -3430 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465)))) (-15 -4089 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465)))) (IF (|has| |#1| (-1037 (-1161))) (IF (|has| |#1| (-1037 (-1161))) (PROGN (-15 -4089 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465))) (-1161))) (-15 -3430 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465))) (-1161))) (-15 -4329 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -2788 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -1414 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -3641 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|)) (-13 (-350) (-609 (-568)))) (T -484)) 
-((-3641 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) (-1414 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) (-2788 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) (-4329 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) (-3430 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 *4 (-763) (-763) (-1157 *4))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 *4) (-763)))) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) (-4089 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 *4 (-763) (-763) (-1157 *4))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 *4) (-763)))) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) (-4089 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 *4 (-763) (-763) (-1157 *4))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 *4) (-763))))) (-5 *1 (-484 *4)) (-4 *4 (-13 (-350) (-609 (-568)))))) (-3430 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 *4 (-763) (-763) (-1157 *4))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 *4) (-763))))) (-5 *1 (-484 *4)) (-4 *4 (-13 (-350) (-609 (-568)))))) (-1414 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *4)))) (-1414 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *5)))) (-2788 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *4)))) (-2788 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *5)))) (-4329 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *5)))) (-4329 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *4)))) (-4102 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *4)))) (-4102 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *5)))) (-2659 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *5)))) (-2659 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *4)))) (-2017 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *5)))) (-2017 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *4)))) (-3641 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *5)))) (-3641 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *4)))) (-1761 (*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 *4 (-763) (-763) (-1157 *4))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 *4) (-763)))) (-634 (-465)))) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)))) (-1961 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) (-1829 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) (-1961 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *5)))) (-1961 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *4)))) (-1829 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *5)))) (-1829 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *4)))) (-1633 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 *7) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 *7)) (-4 *7 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *7)))) (-1633 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 *6) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 *6)) (-4 *6 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *6)))) (-1633 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *5)))) (-1633 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *4))))) 
-(-10 -7 (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161)))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -1829 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -1829 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -1961 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -1961 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (IF (|has| |#1| (-1037 (-1161))) (IF (|has| |#1| (-1037 (-1161))) (PROGN (-15 -1829 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -1961 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|) (-15 -1761 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465))))) (-15 -3641 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -3641 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -2017 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -2017 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -2659 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -2659 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -4329 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -4329 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -1414 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -1414 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -3430 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465)))) (-15 -4089 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465)))) (IF (|has| |#1| (-1037 (-1161))) (IF (|has| |#1| (-1037 (-1161))) (PROGN (-15 -4089 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465))) (-1161))) (-15 -3430 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465))) (-1161))) (-15 -4329 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -2788 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -1414 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -3641 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|)) 
-((-4089 (((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-568)) (-1037 (-1161))) (|has| (-568) (-1037 (-1161))))) (((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465))) NIL)) (-4329 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-568)) (-1037 (-1161))) (|has| (-568) (-1037 (-1161))))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568)))) NIL)) (-1414 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-568)) (-1037 (-1161))) (|has| (-568) (-1037 (-1161))))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568)))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) NIL)) (-4102 (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568)))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) NIL)) (-2788 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-568)) (-1037 (-1161))) (|has| (-568) (-1037 (-1161))))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568)))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) NIL)) (-2659 (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568)))) NIL)) (-1761 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465)))) NIL)) (-1829 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-568)) (-1037 (-1161))) (|has| (-568) (-1037 (-1161))))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568)))) NIL)) (-1961 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-568)) (-1037 (-1161))) (|has| (-568) (-1037 (-1161))))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568)))) NIL)) (-2017 (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568)))) NIL)) (-3641 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-568)) (-1037 (-1161))) (|has| (-568) (-1037 (-1161))))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568)))) NIL)) (-1633 (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-634 (-1161)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-634 (-1161))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568)))) NIL)) (-3430 (((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-568)) (-1037 (-1161))) (|has| (-568) (-1037 (-1161))))) (((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465))) NIL))) 
-(((-485) (-10 -7 (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-634 (-1161)))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -1829 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))))) (-15 -1829 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -1961 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))))) (-15 -1961 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (IF (|has| (-409 (-568)) (-1037 (-1161))) (IF (|has| (-568) (-1037 (-1161))) (PROGN (-15 -1829 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161))) (-15 -1961 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|) (-15 -1761 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465))))) (-15 -3641 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))))) (-15 -3641 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -2017 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))))) (-15 -2017 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -2659 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))))) (-15 -2659 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))))) (-15 -4329 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))))) (-15 -4329 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))))) (-15 -1414 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -1414 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))))) (-15 -3430 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465)))) (-15 -4089 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465)))) (IF (|has| (-409 (-568)) (-1037 (-1161))) (IF (|has| (-568) (-1037 (-1161))) (PROGN (-15 -4089 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465))) (-1161))) (-15 -3430 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465))) (-1161))) (-15 -4329 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161))) (-15 -2788 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161))) (-15 -1414 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161))) (-15 -3641 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|))) (T -485)) 
-((-3641 (*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) (-1414 (*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) (-2788 (*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) (-4329 (*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) (-3430 (*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465)))) (-5 *1 (-485)))) (-4089 (*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465)))) (-5 *1 (-485)))) (-4089 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763))))) (-5 *1 (-485)))) (-3430 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763))))) (-5 *1 (-485)))) (-1414 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) (-1414 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) (-2788 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) (-2788 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) (-4329 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) (-4329 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) (-4102 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) (-4102 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) (-2659 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) (-2659 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) (-2017 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) (-2017 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) (-3641 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) (-3641 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) (-1761 (*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465)))) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) (-1961 (*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) (-1829 (*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) (-1961 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) (-1961 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) (-1829 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) (-1829 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) (-1633 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) (-1633 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) (-1633 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) (-1633 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485))))) 
-(-10 -7 (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-634 (-1161)))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -1829 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))))) (-15 -1829 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -1961 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))))) (-15 -1961 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (IF (|has| (-409 (-568)) (-1037 (-1161))) (IF (|has| (-568) (-1037 (-1161))) (PROGN (-15 -1829 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161))) (-15 -1961 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|) (-15 -1761 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465))))) (-15 -3641 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))))) (-15 -3641 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -2017 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))))) (-15 -2017 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -2659 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))))) (-15 -2659 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))))) (-15 -4329 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))))) (-15 -4329 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))))) (-15 -1414 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -1414 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))))) (-15 -3430 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465)))) (-15 -4089 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465)))) (IF (|has| (-409 (-568)) (-1037 (-1161))) (IF (|has| (-568) (-1037 (-1161))) (PROGN (-15 -4089 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465))) (-1161))) (-15 -3430 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465))) (-1161))) (-15 -4329 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161))) (-15 -2788 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161))) (-15 -1414 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161))) (-15 -3641 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|)) 
-((-4089 (((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465))) (-1161)) 357 (-12 (|has| |#1| (-1037 (-1161))) (|has| |#2| (-1037 (-1161))))) (((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465))) 351)) (-4329 (((-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) 477 (-12 (|has| |#1| (-1037 (-1161))) (|has| |#2| (-1037 (-1161))))) (((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) 470) (((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|)) 471)) (-1414 (((-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) 480 (-12 (|has| |#1| (-1037 (-1161))) (|has| |#2| (-1037 (-1161))))) (((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|)) 476) (((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) 475)) (-4102 (((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|)) 467) (((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) 466)) (-2788 (((-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) 479 (-12 (|has| |#1| (-1037 (-1161))) (|has| |#2| (-1037 (-1161))))) (((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|)) 473) (((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) 472)) (-2659 (((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) 463) (((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|)) 464)) (-1761 (((-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465)))) 454)) (-1829 (((-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) 192 (-12 (|has| |#1| (-1037 (-1161))) (|has| |#2| (-1037 (-1161))))) (((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) 190) (((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|)) 189)) (-1961 (((-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) 218 (-12 (|has| |#1| (-1037 (-1161))) (|has| |#2| (-1037 (-1161))))) (((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) 207) (((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|)) 206)) (-2017 (((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) 460) (((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|)) 461)) (-3641 (((-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) 469 (-12 (|has| |#1| (-1037 (-1161))) (|has| |#2| (-1037 (-1161))))) (((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) 457) (((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|)) 458)) (-1633 (((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161)) (-634 (-465))) 503) (((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161))) 509) (((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) 508) (((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|)) 507)) (-3430 (((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465))) (-1161)) 327 (-12 (|has| |#1| (-1037 (-1161))) (|has| |#2| (-1037 (-1161))))) (((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465))) 317))) 
-(((-486 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -1633 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -1633 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -1633 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161)))) (-15 -1633 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -1829 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -1829 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -1961 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -1961 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (IF (|has| |#1| (-1037 (-1161))) (IF (|has| |#2| (-1037 (-1161))) (PROGN (-15 -1829 ((-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -1961 ((-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|) (-15 -1761 ((-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465))))) (-15 -3641 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -3641 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -2017 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -2017 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -2659 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -2659 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -4329 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -4329 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -1414 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -1414 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -3430 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465)))) (-15 -4089 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465)))) (IF (|has| |#1| (-1037 (-1161))) (IF (|has| |#2| (-1037 (-1161))) (PROGN (-15 -4089 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465))) (-1161))) (-15 -3430 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465))) (-1161))) (-15 -4329 ((-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -2788 ((-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -1414 ((-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -3641 ((-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|)) (-365) (-453) (-13 (-432 (-568)) (-558) (-1037 |#4|) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $)))) (-13 (-842) (-558)) (-1 |#1| |#4|) (-1 |#3| |#1|)) (T -486)) 
-((-3641 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-1414 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-2788 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-4329 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-3430 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 *6) *6 *3)) (|:| A (-1 *5 (-763) (-763) (-1157 *5))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 *6 (-763) *3 *6)) (|:| C (-1 (-634 *5) (-763)))) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-4089 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 *6) *6 *3)) (|:| A (-1 *5 (-763) (-763) (-1157 *5))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 *6 (-763) *3 *6)) (|:| C (-1 (-634 *5) (-763)))) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-4089 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 *6) *6 (-1161))) (|:| A (-1 *5 (-763) (-763) (-1157 *5))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 *6 (-763) (-1161) *6)) (|:| C (-1 (-634 *5) (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-3430 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 *6) *6 (-1161))) (|:| A (-1 *5 (-763) (-763) (-1157 *5))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 *6 (-763) (-1161) *6)) (|:| C (-1 (-634 *5) (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-1414 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) (-1414 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1864 *7) (|:| -4477 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) (-2788 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) (-2788 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1864 *7) (|:| -4477 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) (-4329 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1864 *7) (|:| -4477 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) (-4329 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) (-4102 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) (-4102 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1864 *7) (|:| -4477 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) (-2659 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1864 *7) (|:| -4477 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) (-2659 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) (-2017 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1864 *7) (|:| -4477 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) (-2017 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) (-3641 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1864 *7) (|:| -4477 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) (-3641 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) (-1761 (*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 *6) *6 (-1161))) (|:| A (-1 *5 (-763) (-763) (-1157 *5))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 *6 (-763) (-1161) *6)) (|:| C (-1 (-634 *5) (-763)))) (-634 (-465)))) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-14 *9 (-1 *6 *4)) (-5 *2 (-1 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)))) (-1961 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-1829 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-1961 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1864 *7) (|:| -4477 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) (-1961 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) (-1829 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1864 *7) (|:| -4477 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) (-1829 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) (-1633 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 *9) (|:| -4477 (-763)))) (-634 *7) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 *7)) (-4 *7 (-365)) (-14 *12 (-1 *9 *7)) (-4 *10 (-13 (-842) (-558))) (-14 *11 (-1 *7 *10)) (-5 *2 (-634 (-2 (|:| -1864 *9) (|:| -4477 (-763))))) (-5 *1 (-486 *7 *8 *9 *10 *11 *12)) (-4 *8 (-453)) (-4 *9 (-13 (-432 (-568)) (-558) (-1037 *10) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) (-1633 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 *8) (|:| -4477 (-763)))) (-634 *6) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 *6)) (-4 *6 (-365)) (-14 *11 (-1 *8 *6)) (-4 *9 (-13 (-842) (-558))) (-14 *10 (-1 *6 *9)) (-5 *2 (-634 (-2 (|:| -1864 *8) (|:| -4477 (-763))))) (-5 *1 (-486 *6 *7 *8 *9 *10 *11)) (-4 *7 (-453)) (-4 *8 (-13 (-432 (-568)) (-558) (-1037 *9) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) (-1633 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1864 *7) (|:| -4477 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) (-1633 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $)))))))) 
-(-10 -7 (-15 -1633 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -1633 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -1633 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161)))) (-15 -1633 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -1829 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -1829 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -1961 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -1961 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (IF (|has| |#1| (-1037 (-1161))) (IF (|has| |#2| (-1037 (-1161))) (PROGN (-15 -1829 ((-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -1961 ((-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|) (-15 -1761 ((-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465))))) (-15 -3641 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -3641 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -2017 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -2017 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -2659 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -2659 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -4329 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -4329 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -1414 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -1414 ((-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|))) (-15 -3430 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465)))) (-15 -4089 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465)))) (IF (|has| |#1| (-1037 (-1161))) (IF (|has| |#2| (-1037 (-1161))) (PROGN (-15 -4089 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465))) (-1161))) (-15 -3430 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465))) (-1161))) (-15 -4329 ((-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -2788 ((-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -1414 ((-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -3641 ((-1 (-634 (-2 (|:| -1864 |#3|) (|:| -4477 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|)) 
-((-4089 (((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-953 (-568))) (-1037 (-1161))) (|has| (-953 (-568)) (-1037 (-1161))))) (((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465))) NIL)) (-4329 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-953 (-568))) (-1037 (-1161))) (|has| (-953 (-568)) (-1037 (-1161))))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568))))) NIL)) (-1414 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-953 (-568))) (-1037 (-1161))) (|has| (-953 (-568)) (-1037 (-1161))))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568))))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) NIL)) (-4102 (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568))))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) NIL)) (-2788 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-953 (-568))) (-1037 (-1161))) (|has| (-953 (-568)) (-1037 (-1161))))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568))))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) NIL)) (-2659 (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568))))) NIL)) (-1761 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465)))) NIL)) (-1829 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-953 (-568))) (-1037 (-1161))) (|has| (-953 (-568)) (-1037 (-1161))))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568))))) NIL)) (-1961 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-953 (-568))) (-1037 (-1161))) (|has| (-953 (-568)) (-1037 (-1161))))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568))))) NIL)) (-2017 (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568))))) NIL)) (-3641 (((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-953 (-568))) (-1037 (-1161))) (|has| (-953 (-568)) (-1037 (-1161))))) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568))))) NIL)) (-1633 (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-634 (-1161)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-634 (-1161))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568))))) NIL)) (-3430 (((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-953 (-568))) (-1037 (-1161))) (|has| (-953 (-568)) (-1037 (-1161))))) (((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465))) NIL))) 
-(((-487) (-10 -7 (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-634 (-1161)))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -1829 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -1829 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -1961 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -1961 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (IF (|has| (-409 (-953 (-568))) (-1037 (-1161))) (IF (|has| (-953 (-568)) (-1037 (-1161))) (PROGN (-15 -1829 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161))) (-15 -1961 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|) (-15 -1761 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465))))) (-15 -3641 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -3641 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -2017 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -2017 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -2659 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -2659 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -4329 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -4329 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -1414 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -1414 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -3430 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465)))) (-15 -4089 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465)))) (IF (|has| (-409 (-953 (-568))) (-1037 (-1161))) (IF (|has| (-953 (-568)) (-1037 (-1161))) (PROGN (-15 -4089 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465))) (-1161))) (-15 -3430 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465))) (-1161))) (-15 -4329 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161))) (-15 -2788 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161))) (-15 -1414 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161))) (-15 -3641 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|))) (T -487)) 
-((-3641 (*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) (-1414 (*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) (-2788 (*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) (-4329 (*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) (-3430 (*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465)))) (-5 *1 (-487)))) (-4089 (*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465)))) (-5 *1 (-487)))) (-4089 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763))))) (-5 *1 (-487)))) (-3430 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763))))) (-5 *1 (-487)))) (-1414 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) (-1414 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) (-2788 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) (-2788 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) (-4329 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) (-4329 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) (-4102 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) (-4102 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) (-2659 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) (-2659 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) (-2017 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) (-2017 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) (-3641 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) (-3641 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) (-1761 (*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465)))) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) (-1961 (*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) (-1829 (*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) (-1961 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) (-1961 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) (-1829 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) (-1829 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) (-1633 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) (-1633 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) (-1633 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) (-1633 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487))))) 
-(-10 -7 (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-634 (-1161)))) (-15 -1633 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -1829 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -1829 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -1961 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -1961 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (IF (|has| (-409 (-953 (-568))) (-1037 (-1161))) (IF (|has| (-953 (-568)) (-1037 (-1161))) (PROGN (-15 -1829 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161))) (-15 -1961 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|) (-15 -1761 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465))))) (-15 -3641 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -3641 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -2017 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -2017 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -2659 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -2659 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -4329 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -4329 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -1414 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -1414 ((-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -3430 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465)))) (-15 -4089 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465)))) (IF (|has| (-409 (-953 (-568))) (-1037 (-1161))) (IF (|has| (-953 (-568)) (-1037 (-1161))) (PROGN (-15 -4089 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465))) (-1161))) (-15 -3430 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465))) (-1161))) (-15 -4329 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161))) (-15 -2788 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161))) (-15 -1414 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161))) (-15 -3641 ((-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|)) 
-((-4089 (((-1 HPSPEC (-634 (-465))) (-1161)) NIL) ((HPSPEC (-634 (-465))) NIL)) (-4329 (((-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161)) NIL) (((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568))))) NIL)) (-1414 (((-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161)) NIL) (((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568))))) NIL) (((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) NIL)) (-4102 (((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568))))) NIL) (((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) NIL)) (-2788 (((-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161)) NIL) (((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568))))) NIL) (((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) NIL)) (-2659 (((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568))))) NIL)) (-1761 (((-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1 HPSPEC (-634 (-465)))) NIL)) (-1829 (((-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161)) NIL) (((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568))))) NIL)) (-1961 (((-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161)) NIL) (((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568))))) NIL)) (-2017 (((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568))))) NIL)) (-3641 (((-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161)) NIL) (((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568))))) NIL)) (-1633 (((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-634 (-1161)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-634 (-1161))) NIL) (((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568))))) NIL)) (-3430 (((-1 HPSPEC (-634 (-465))) (-1161)) NIL) ((HPSPEC (-634 (-465))) NIL))) 
-(((-488 |#1|) (-10 -7 (-15 -1633 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -1633 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -1633 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-634 (-1161)))) (-15 -1633 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -1829 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -1829 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -1961 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -1961 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -1829 ((-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161))) (-15 -1961 ((-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161))) (-15 -1761 ((-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1 HPSPEC (-634 (-465))))) (-15 -3641 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -3641 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -2017 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -2017 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -2659 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -2659 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -4329 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -4329 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -1414 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -1414 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -3430 (HPSPEC (-634 (-465)))) (-15 -4089 (HPSPEC (-634 (-465)))) (-15 -4089 ((-1 HPSPEC (-634 (-465))) (-1161))) (-15 -3430 ((-1 HPSPEC (-634 (-465))) (-1161))) (-15 -4329 ((-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161))) (-15 -2788 ((-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161))) (-15 -1414 ((-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161))) (-15 -3641 ((-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161)))) (-1161)) (T -488)) 
-((-3641 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3))) (-1414 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3))) (-2788 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3))) (-4329 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3))) (-3430 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 HPSPEC (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3))) (-4089 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 HPSPEC (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3))) (-4089 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 HPSPEC) (-5 *1 (-488 *4)) (-14 *4 (-1161)))) (-3430 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 HPSPEC) (-5 *1 (-488 *4)) (-14 *4 (-1161)))) (-1414 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *4)))) (-1414 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *5 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *5)))) (-2788 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *4)))) (-2788 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *5 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *5)))) (-4329 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *5 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *5)))) (-4329 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *4)))) (-4102 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *4)))) (-4102 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *5 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *5)))) (-2659 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *5 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *5)))) (-2659 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *4)))) (-2017 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *5 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *5)))) (-2017 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *4)))) (-3641 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *5 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *5)))) (-3641 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *4)))) (-1761 (*1 *2 *3) (-12 (-5 *3 (-1 HPSPEC (-634 (-465)))) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 (-1161)))) (-1961 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3))) (-1829 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3))) (-1961 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *5 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *5)))) (-1961 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *4)))) (-1829 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *5 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *5)))) (-1829 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *4)))) (-1633 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 (-733 *7 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 *7 (-568)))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 (-409 (-734 *7 (-568))))) (-14 *7 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *7 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *7)))) (-1633 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 (-733 *6 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 *6 (-568)))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 (-409 (-734 *6 (-568))))) (-14 *6 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *6 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *6)))) (-1633 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *5 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *5)))) (-1633 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *4))))) 
-(-10 -7 (-15 -1633 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -1633 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -1633 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-634 (-1161)))) (-15 -1633 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -1829 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -1829 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -1961 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -1961 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -1829 ((-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161))) (-15 -1961 ((-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161))) (-15 -1761 ((-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1 HPSPEC (-634 (-465))))) (-15 -3641 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -3641 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -2017 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -2017 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -2659 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -2659 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -4102 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -4329 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -4329 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -2788 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -1414 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -1414 ((-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -3430 (HPSPEC (-634 (-465)))) (-15 -4089 (HPSPEC (-634 (-465)))) (-15 -4089 ((-1 HPSPEC (-634 (-465))) (-1161))) (-15 -3430 ((-1 HPSPEC (-634 (-465))) (-1161))) (-15 -4329 ((-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161))) (-15 -2788 ((-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161))) (-15 -1414 ((-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161))) (-15 -3641 ((-1 (-634 (-2 (|:| -1864 (-733 |#1| (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1497 (((-121) $ $) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL)) (-2854 (((-568) $) NIL) (((-409 (-568)) $) NIL)) (-2401 (($ $ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-1897 (($) 18)) (-2735 (((-121) $) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3848 (((-420 $) $) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-4278 (((-381) $) 22) (((-215) $) 25) (((-409 (-1157 (-568))) $) 19) (((-541) $) 52)) (-2745 (((-850) $) 50) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (((-215) $) 24) (((-381) $) 21)) (-4078 (((-763)) NIL)) (-1826 (((-121) $ $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) 36 T CONST)) (-1556 (($) 11 T CONST)) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL))) 
-(((-489) (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))) (-1021) (-608 (-215)) (-608 (-381)) (-609 (-409 (-1157 (-568)))) (-609 (-541)) (-10 -8 (-15 -1897 ($))))) (T -489)) 
-((-1897 (*1 *1) (-5 *1 (-489)))) 
-(-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))) (-1021) (-608 (-215)) (-608 (-381)) (-609 (-409 (-1157 (-568)))) (-609 (-541)) (-10 -8 (-15 -1897 ($)))) 
-((-2447 (((-121) $ $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-2986 (($) NIL) (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-1868 (((-1249) $ |#1| |#1|) NIL (|has| $ (-6 -4520)))) (-2510 (((-121) $ (-763)) NIL)) (-2436 ((|#2| $ |#1| |#2|) 16)) (-3507 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-2674 (((-3 |#2| "failed") |#1| $) 20)) (-2671 (($) NIL T CONST)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-3405 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (|has| $ (-6 -4519))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-3 |#2| "failed") |#1| $) 18)) (-4328 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-3092 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (|has| $ (-6 -4519))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-3989 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#2| $ |#1|) NIL)) (-4360 (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-634 |#2|) $) NIL (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) NIL)) (-1881 ((|#1| $) NIL (|has| |#1| (-842)))) (-1979 (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-634 |#2|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-2223 ((|#1| $) NIL (|has| |#1| (-842)))) (-3674 (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4520))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-1946 (((-634 |#1|) $) 13)) (-3548 (((-121) |#1| $) NIL)) (-1890 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-4450 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-4174 (((-634 |#1|) $) NIL)) (-3578 (((-121) |#1| $) NIL)) (-4022 (((-1108) $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-3876 ((|#2| $) NIL (|has| |#1| (-842)))) (-3775 (((-3 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) "failed") (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL)) (-3724 (($ $ |#2|) NIL (|has| $ (-6 -4520)))) (-1315 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-1387 (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-2041 (((-634 |#2|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) 19)) (-2779 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL)) (-2085 (($) NIL) (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-4168 (((-763) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-763) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090)))) (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-609 (-541))))) (-4287 (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-2745 (((-850) $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-2367 (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-1319 (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 11 (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-1697 (((-763) $) 15 (|has| $ (-6 -4519))))) 
-(((-490 |#1| |#2| |#3|) (-13 (-1172 |#1| |#2|) (-10 -7 (-6 -4519))) (-1090) (-1090) (-1143)) (T -490)) 
-NIL 
-(-13 (-1172 |#1| |#2|) (-10 -7 (-6 -4519))) 
-((-3735 (((-568) (-568) (-568)) 7)) (-2701 (((-121) (-568) (-568) (-568) (-568)) 11)) (-2781 (((-1244 (-634 (-568))) (-763) (-763)) 22))) 
-(((-491) (-10 -7 (-15 -3735 ((-568) (-568) (-568))) (-15 -2701 ((-121) (-568) (-568) (-568) (-568))) (-15 -2781 ((-1244 (-634 (-568))) (-763) (-763))))) (T -491)) 
-((-2781 (*1 *2 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1244 (-634 (-568)))) (-5 *1 (-491)))) (-2701 (*1 *2 *3 *3 *3 *3) (-12 (-5 *3 (-568)) (-5 *2 (-121)) (-5 *1 (-491)))) (-3735 (*1 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-491))))) 
-(-10 -7 (-15 -3735 ((-568) (-568) (-568))) (-15 -2701 ((-121) (-568) (-568) (-568) (-568))) (-15 -2781 ((-1244 (-634 (-568))) (-763) (-763)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2055 (((-634 (-852 |#1|)) $) NIL)) (-3839 (((-1157 $) $ (-852 |#1|)) NIL) (((-1157 |#2|) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#2| (-558)))) (-2227 (($ $) NIL (|has| |#2| (-558)))) (-1573 (((-121) $) NIL (|has| |#2| (-558)))) (-2773 (((-763) $) NIL) (((-763) $ (-634 (-852 |#1|))) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-4305 (($ $) NIL (|has| |#2| (-453)))) (-1678 (((-420 $) $) NIL (|has| |#2| (-453)))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#2| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#2| (-1037 (-568)))) (((-3 (-852 |#1|) "failed") $) NIL)) (-2854 ((|#2| $) NIL) (((-409 (-568)) $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#2| (-1037 (-568)))) (((-852 |#1|) $) NIL)) (-4265 (($ $ $ (-852 |#1|)) NIL (|has| |#2| (-172)))) (-4425 (($ $ (-634 (-568))) NIL)) (-2114 (($ $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL) (((-679 |#2|) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3250 (($ $) NIL (|has| |#2| (-453))) (($ $ (-852 |#1|)) NIL (|has| |#2| (-453)))) (-2108 (((-634 $) $) NIL)) (-3927 (((-121) $) NIL (|has| |#2| (-904)))) (-3088 (($ $ |#2| (-493 (-1697 |#1|) (-763)) $) NIL)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-852 |#1|) (-881 (-381))) (|has| |#2| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-852 |#1|) (-881 (-568))) (|has| |#2| (-881 (-568)))))) (-2735 (((-121) $) NIL)) (-4178 (((-763) $) NIL)) (-2051 (($ (-1157 |#2|) (-852 |#1|)) NIL) (($ (-1157 $) (-852 |#1|)) NIL)) (-2976 (((-634 $) $) NIL)) (-3921 (((-121) $) NIL)) (-2047 (($ |#2| (-493 (-1697 |#1|) (-763))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-3379 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $ (-852 |#1|)) NIL)) (-2144 (((-493 (-1697 |#1|) (-763)) $) NIL) (((-763) $ (-852 |#1|)) NIL) (((-634 (-763)) $ (-634 (-852 |#1|))) NIL)) (-2521 (($ $ $) NIL (|has| |#2| (-842)))) (-3268 (($ $ $) NIL (|has| |#2| (-842)))) (-3842 (($ (-1 (-493 (-1697 |#1|) (-763)) (-493 (-1697 |#1|) (-763))) $) NIL)) (-2795 (($ (-1 |#2| |#2|) $) NIL)) (-2244 (((-3 (-852 |#1|) "failed") $) NIL)) (-2097 (($ $) NIL)) (-2102 ((|#2| $) NIL)) (-2495 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) NIL (|has| |#2| (-453)))) (-4487 (((-1143) $) NIL)) (-3324 (((-3 (-634 $) "failed") $) NIL)) (-1794 (((-3 (-634 $) "failed") $) NIL)) (-3751 (((-3 (-2 (|:| |var| (-852 |#1|)) (|:| -3438 (-763))) "failed") $) NIL)) (-4022 (((-1108) $) NIL)) (-2086 (((-121) $) NIL)) (-2091 ((|#2| $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#2| (-453)))) (-2721 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) NIL (|has| |#2| (-453)))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3848 (((-420 $) $) NIL (|has| |#2| (-904)))) (-2595 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-558)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-852 |#1|) |#2|) NIL) (($ $ (-634 (-852 |#1|)) (-634 |#2|)) NIL) (($ $ (-852 |#1|) $) NIL) (($ $ (-634 (-852 |#1|)) (-634 $)) NIL)) (-2217 (($ $ (-852 |#1|)) NIL (|has| |#2| (-172)))) (-4189 (($ $ (-852 |#1|)) NIL) (($ $ (-634 (-852 |#1|))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-3206 (((-493 (-1697 |#1|) (-763)) $) NIL) (((-763) $ (-852 |#1|)) NIL) (((-634 (-763)) $ (-634 (-852 |#1|))) NIL)) (-4278 (((-887 (-381)) $) NIL (-12 (|has| (-852 |#1|) (-609 (-887 (-381)))) (|has| |#2| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-852 |#1|) (-609 (-887 (-568)))) (|has| |#2| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-852 |#1|) (-609 (-541))) (|has| |#2| (-609 (-541)))))) (-3367 ((|#2| $) NIL (|has| |#2| (-453))) (($ $ (-852 |#1|)) NIL (|has| |#2| (-453)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#2| (-904))))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#2|) NIL) (($ (-852 |#1|)) NIL) (($ (-409 (-568))) NIL (-2198 (|has| |#2| (-43 (-409 (-568)))) (|has| |#2| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#2| (-558)))) (-1302 (((-634 |#2|) $) NIL)) (-2604 ((|#2| $ (-493 (-1697 |#1|) (-763))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| |#2| (-904))) (|has| |#2| (-148))))) (-4078 (((-763)) NIL)) (-4171 (($ $ $ (-763)) NIL (|has| |#2| (-172)))) (-1826 (((-121) $ $) NIL (|has| |#2| (-558)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $ (-852 |#1|)) NIL) (($ $ (-634 (-852 |#1|))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-1751 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1779 (($ $ |#2|) NIL (|has| |#2| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#2| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#2| (-43 (-409 (-568))))) (($ |#2| $) NIL) (($ $ |#2|) NIL))) 
-(((-492 |#1| |#2|) (-13 (-950 |#2| (-493 (-1697 |#1|) (-763)) (-852 |#1|)) (-10 -8 (-15 -4425 ($ $ (-634 (-568)))))) (-634 (-1161)) (-1047)) (T -492)) 
-((-4425 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-492 *3 *4)) (-14 *3 (-634 (-1161))) (-4 *4 (-1047))))) 
-(-13 (-950 |#2| (-493 (-1697 |#1|) (-763)) (-852 |#1|)) (-10 -8 (-15 -4425 ($ $ (-634 (-568)))))) 
-((-2447 (((-121) $ $) NIL (|has| |#2| (-1090)))) (-2537 (((-121) $) NIL (|has| |#2| (-137)))) (-1394 (($ (-917)) NIL (|has| |#2| (-1047)))) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-1462 (($ $ $) NIL (|has| |#2| (-788)))) (-3134 (((-3 $ "failed") $ $) NIL (|has| |#2| (-137)))) (-2510 (((-121) $ (-763)) NIL)) (-3983 (((-763)) NIL (|has| |#2| (-370)))) (-3662 (((-568) $) NIL (|has| |#2| (-840)))) (-2436 ((|#2| $ (-568) |#2|) NIL (|has| $ (-6 -4520)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) NIL (-12 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090)))) (((-3 (-409 (-568)) "failed") $) NIL (-12 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) (((-3 |#2| "failed") $) NIL (|has| |#2| (-1090)))) (-2854 (((-568) $) NIL (-12 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090)))) (((-409 (-568)) $) NIL (-12 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) ((|#2| $) NIL (|has| |#2| (-1090)))) (-3164 (((-679 (-568)) (-679 $)) NIL (-12 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (-12 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047)))) (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL (|has| |#2| (-1047))) (((-679 |#2|) (-679 $)) NIL (|has| |#2| (-1047)))) (-2925 (((-3 $ "failed") $) NIL (|has| |#2| (-716)))) (-1731 (($) NIL (|has| |#2| (-370)))) (-3989 ((|#2| $ (-568) |#2|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#2| $ (-568)) 11)) (-2033 (((-121) $) NIL (|has| |#2| (-840)))) (-4360 (((-634 |#2|) $) NIL (|has| $ (-6 -4519)))) (-2735 (((-121) $) NIL (|has| |#2| (-716)))) (-2245 (((-121) $) NIL (|has| |#2| (-840)))) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) NIL (|has| (-568) (-842)))) (-2521 (($ $ $) NIL (-2198 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1979 (((-634 |#2|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-2223 (((-568) $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (-2198 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-3674 (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#2| |#2|) $) NIL)) (-3683 (((-917) $) NIL (|has| |#2| (-370)))) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (|has| |#2| (-1090)))) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4355 (($ (-917)) NIL (|has| |#2| (-370)))) (-4022 (((-1108) $) NIL (|has| |#2| (-1090)))) (-3876 ((|#2| $) NIL (|has| (-568) (-842)))) (-3724 (($ $ |#2|) NIL (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-2041 (((-634 |#2|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#2| $ (-568) |#2|) NIL) ((|#2| $ (-568)) NIL)) (-3682 ((|#2| $ $) NIL (|has| |#2| (-1047)))) (-2039 (($ (-1244 |#2|)) NIL)) (-4321 (((-139)) NIL (|has| |#2| (-365)))) (-4189 (($ $) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1 |#2| |#2|) (-763)) NIL (|has| |#2| (-1047))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1047)))) (-4168 (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-3863 (($ $) NIL)) (-2745 (((-1244 |#2|) $) NIL) (((-850) $) NIL (|has| |#2| (-1090))) (($ (-568)) NIL (-2198 (-12 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090))) (|has| |#2| (-1047)))) (($ (-409 (-568))) NIL (-12 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) (($ |#2|) NIL (|has| |#2| (-1090)))) (-4078 (((-763)) NIL (|has| |#2| (-1047)))) (-1319 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-2897 (($ $) NIL (|has| |#2| (-840)))) (-1887 (($ $ (-763)) NIL (|has| |#2| (-716))) (($ $ (-917)) NIL (|has| |#2| (-716)))) (-3056 (($) NIL (|has| |#2| (-137)) CONST)) (-1556 (($) NIL (|has| |#2| (-716)) CONST)) (-3190 (($ $) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1 |#2| |#2|) (-763)) NIL (|has| |#2| (-1047))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1047)))) (-1751 (((-121) $ $) NIL (-2198 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1738 (((-121) $ $) NIL (-2198 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1717 (((-121) $ $) NIL (|has| |#2| (-1090)))) (-1745 (((-121) $ $) NIL (-2198 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1732 (((-121) $ $) 15 (-2198 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1779 (($ $ |#2|) NIL (|has| |#2| (-365)))) (-1773 (($ $ $) NIL (|has| |#2| (-1047))) (($ $) NIL (|has| |#2| (-1047)))) (-1767 (($ $ $) NIL (|has| |#2| (-25)))) (** (($ $ (-763)) NIL (|has| |#2| (-716))) (($ $ (-917)) NIL (|has| |#2| (-716)))) (* (($ (-568) $) NIL (|has| |#2| (-1047))) (($ $ $) NIL (|has| |#2| (-716))) (($ $ |#2|) NIL (|has| |#2| (-1047))) (($ |#2| $) NIL (|has| |#2| (-1047))) (($ (-763) $) NIL (|has| |#2| (-137))) (($ (-917) $) NIL (|has| |#2| (-25)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
+((-3492 (((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465))) (-1161)) NIL (|has| (-53) (-1037 (-1161)))) (((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465))) NIL)) (-3135 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) (-1161)) NIL (|has| (-53) (-1037 (-1161)))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53))) NIL)) (-2152 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) (-1161)) NIL (|has| (-53) (-1037 (-1161)))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) NIL)) (-3558 (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) NIL)) (-3592 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) (-1161)) NIL (|has| (-53) (-1037 (-1161)))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) NIL)) (-4428 (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53))) NIL)) (-3915 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465)))) NIL)) (-2288 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) (-1161)) NIL (|has| (-53) (-1037 (-1161)))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53))) NIL)) (-4326 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) (-1161)) NIL (|has| (-53) (-1037 (-1161)))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53))) NIL)) (-1333 (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53))) NIL)) (-3200 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) (-1161)) NIL (|has| (-53) (-1037 (-1161)))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53))) NIL)) (-1536 (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-634 (-1161)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-634 (-1161))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53))) NIL)) (-3416 (((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465))) (-1161)) NIL (|has| (-53) (-1037 (-1161)))) (((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465))) NIL))) 
+(((-482) (-10 -7 (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-634 (-1161)))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -2288 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)))) (-15 -2288 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -4326 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)))) (-15 -4326 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (IF (|has| (-53) (-1037 (-1161))) (IF (|has| (-53) (-1037 (-1161))) (PROGN (-15 -2288 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) (-1161))) (-15 -4326 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|) (-15 -3915 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465))))) (-15 -3200 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)))) (-15 -3200 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -1333 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)))) (-15 -1333 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -4428 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)))) (-15 -4428 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)))) (-15 -3135 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)))) (-15 -3135 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)))) (-15 -2152 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -2152 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)))) (-15 -3416 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465)))) (-15 -3492 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465)))) (IF (|has| (-53) (-1037 (-1161))) (IF (|has| (-53) (-1037 (-1161))) (PROGN (-15 -3492 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465))) (-1161))) (-15 -3416 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465))) (-1161))) (-15 -3135 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) (-1161))) (-15 -3592 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) (-1161))) (-15 -2152 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) (-1161))) (-15 -3200 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|))) (T -482)) 
+((-3200 (*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) (-2152 (*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) (-3592 (*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) (-3135 (*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) (-3416 (*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465)))) (-5 *1 (-482)))) (-3492 (*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465)))) (-5 *1 (-482)))) (-3492 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763))))) (-5 *1 (-482)))) (-3416 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763))))) (-5 *1 (-482)))) (-2152 (*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) (-2152 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) (-3592 (*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) (-3592 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) (-3135 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) (-3135 (*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) (-3558 (*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) (-3558 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) (-4428 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) (-4428 (*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) (-1333 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) (-1333 (*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) (-3200 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) (-3200 (*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) (-3915 (*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465)))) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) (-4326 (*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) (-2288 (*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) (-4326 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) (-4326 (*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) (-2288 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) (-2288 (*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) (-1536 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) (-1536 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) (-1536 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) (-1536 (*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482))))) 
+(-10 -7 (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-634 (-1161)))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -2288 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)))) (-15 -2288 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -4326 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)))) (-15 -4326 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (IF (|has| (-53) (-1037 (-1161))) (IF (|has| (-53) (-1037 (-1161))) (PROGN (-15 -2288 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) (-1161))) (-15 -4326 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|) (-15 -3915 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465))))) (-15 -3200 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)))) (-15 -3200 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -1333 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)))) (-15 -1333 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -4428 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)))) (-15 -4428 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)))) (-15 -3135 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)))) (-15 -3135 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)))) (-15 -2152 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-15 -2152 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)))) (-15 -3416 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465)))) (-15 -3492 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465)))) (IF (|has| (-53) (-1037 (-1161))) (IF (|has| (-53) (-1037 (-1161))) (PROGN (-15 -3492 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465))) (-1161))) (-15 -3416 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465))) (-1161))) (-15 -3135 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) (-1161))) (-15 -3592 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) (-1161))) (-15 -2152 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) (-1161))) (-15 -3200 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|)) 
+((-3119 (((-310 (-568)) |#1|) 11))) 
+(((-483 |#1|) (-10 -7 (-15 -3119 ((-310 (-568)) |#1|))) (-13 (-350) (-609 (-568)))) (T -483)) 
+((-3119 (*1 *2 *3) (-12 (-5 *2 (-310 (-568))) (-5 *1 (-483 *3)) (-4 *3 (-13 (-350) (-609 (-568))))))) 
+(-10 -7 (-15 -3119 ((-310 (-568)) |#1|))) 
+((-3492 (((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465))) (-1161)) NIL (|has| |#1| (-1037 (-1161)))) (((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465))) NIL)) (-3135 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) NIL (|has| |#1| (-1037 (-1161)))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|)) NIL)) (-2152 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) NIL (|has| |#1| (-1037 (-1161)))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|)) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) NIL)) (-3558 (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|)) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) NIL)) (-3592 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) NIL (|has| |#1| (-1037 (-1161)))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|)) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) NIL)) (-4428 (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|)) NIL)) (-3915 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465)))) NIL)) (-2288 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) NIL (|has| |#1| (-1037 (-1161)))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|)) NIL)) (-4326 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) NIL (|has| |#1| (-1037 (-1161)))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|)) NIL)) (-1333 (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|)) NIL)) (-3200 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) NIL (|has| |#1| (-1037 (-1161)))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|)) NIL)) (-1536 (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|)) NIL)) (-3416 (((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465))) (-1161)) NIL (|has| |#1| (-1037 (-1161)))) (((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465))) NIL))) 
+(((-484 |#1|) (-10 -7 (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161)))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -2288 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -2288 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -4326 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -4326 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (IF (|has| |#1| (-1037 (-1161))) (IF (|has| |#1| (-1037 (-1161))) (PROGN (-15 -2288 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -4326 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|) (-15 -3915 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465))))) (-15 -3200 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -3200 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -1333 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -1333 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -4428 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -4428 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -3135 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -3135 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -2152 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -2152 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -3416 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465)))) (-15 -3492 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465)))) (IF (|has| |#1| (-1037 (-1161))) (IF (|has| |#1| (-1037 (-1161))) (PROGN (-15 -3492 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465))) (-1161))) (-15 -3416 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465))) (-1161))) (-15 -3135 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -3592 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -2152 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -3200 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|)) (-13 (-350) (-609 (-568)))) (T -484)) 
+((-3200 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) (-2152 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) (-3592 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) (-3135 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) (-3416 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 *4 (-763) (-763) (-1157 *4))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 *4) (-763)))) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) (-3492 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 *4 (-763) (-763) (-1157 *4))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 *4) (-763)))) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) (-3492 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 *4 (-763) (-763) (-1157 *4))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 *4) (-763))))) (-5 *1 (-484 *4)) (-4 *4 (-13 (-350) (-609 (-568)))))) (-3416 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 *4 (-763) (-763) (-1157 *4))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 *4) (-763))))) (-5 *1 (-484 *4)) (-4 *4 (-13 (-350) (-609 (-568)))))) (-2152 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *4)))) (-2152 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *5)))) (-3592 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *4)))) (-3592 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *5)))) (-3135 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *5)))) (-3135 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *4)))) (-3558 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *4)))) (-3558 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *5)))) (-4428 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *5)))) (-4428 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *4)))) (-1333 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *5)))) (-1333 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *4)))) (-3200 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *5)))) (-3200 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *4)))) (-3915 (*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 *4 (-763) (-763) (-1157 *4))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 *4) (-763)))) (-634 (-465)))) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)))) (-4326 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) (-2288 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) (-4326 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *5)))) (-4326 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *4)))) (-2288 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *5)))) (-2288 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *4)))) (-1536 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 *7) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 *7)) (-4 *7 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *7)))) (-1536 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 *6) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 *6)) (-4 *6 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *6)))) (-1536 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *5)))) (-1536 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *4))))) 
+(-10 -7 (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161)))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -2288 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -2288 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -4326 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -4326 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (IF (|has| |#1| (-1037 (-1161))) (IF (|has| |#1| (-1037 (-1161))) (PROGN (-15 -2288 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -4326 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|) (-15 -3915 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465))))) (-15 -3200 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -3200 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -1333 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -1333 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -4428 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -4428 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -3135 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -3135 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -2152 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -2152 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -3416 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465)))) (-15 -3492 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465)))) (IF (|has| |#1| (-1037 (-1161))) (IF (|has| |#1| (-1037 (-1161))) (PROGN (-15 -3492 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465))) (-1161))) (-15 -3416 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 |#1| (-763) (-763) (-1157 |#1|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 |#1|) (-763)))) (-634 (-465))) (-1161))) (-15 -3135 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -3592 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -2152 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -3200 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|)) 
+((-3492 (((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-568)) (-1037 (-1161))) (|has| (-568) (-1037 (-1161))))) (((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465))) NIL)) (-3135 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-568)) (-1037 (-1161))) (|has| (-568) (-1037 (-1161))))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568)))) NIL)) (-2152 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-568)) (-1037 (-1161))) (|has| (-568) (-1037 (-1161))))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568)))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) NIL)) (-3558 (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568)))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) NIL)) (-3592 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-568)) (-1037 (-1161))) (|has| (-568) (-1037 (-1161))))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568)))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) NIL)) (-4428 (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568)))) NIL)) (-3915 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465)))) NIL)) (-2288 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-568)) (-1037 (-1161))) (|has| (-568) (-1037 (-1161))))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568)))) NIL)) (-4326 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-568)) (-1037 (-1161))) (|has| (-568) (-1037 (-1161))))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568)))) NIL)) (-1333 (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568)))) NIL)) (-3200 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-568)) (-1037 (-1161))) (|has| (-568) (-1037 (-1161))))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568)))) NIL)) (-1536 (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-634 (-1161)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-634 (-1161))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568)))) NIL)) (-3416 (((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-568)) (-1037 (-1161))) (|has| (-568) (-1037 (-1161))))) (((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465))) NIL))) 
+(((-485) (-10 -7 (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-634 (-1161)))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -2288 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))))) (-15 -2288 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -4326 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))))) (-15 -4326 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (IF (|has| (-409 (-568)) (-1037 (-1161))) (IF (|has| (-568) (-1037 (-1161))) (PROGN (-15 -2288 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161))) (-15 -4326 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|) (-15 -3915 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465))))) (-15 -3200 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))))) (-15 -3200 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -1333 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))))) (-15 -1333 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -4428 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))))) (-15 -4428 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))))) (-15 -3135 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))))) (-15 -3135 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))))) (-15 -2152 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -2152 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))))) (-15 -3416 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465)))) (-15 -3492 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465)))) (IF (|has| (-409 (-568)) (-1037 (-1161))) (IF (|has| (-568) (-1037 (-1161))) (PROGN (-15 -3492 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465))) (-1161))) (-15 -3416 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465))) (-1161))) (-15 -3135 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161))) (-15 -3592 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161))) (-15 -2152 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161))) (-15 -3200 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|))) (T -485)) 
+((-3200 (*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) (-2152 (*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) (-3592 (*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) (-3135 (*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) (-3416 (*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465)))) (-5 *1 (-485)))) (-3492 (*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465)))) (-5 *1 (-485)))) (-3492 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763))))) (-5 *1 (-485)))) (-3416 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763))))) (-5 *1 (-485)))) (-2152 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) (-2152 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) (-3592 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) (-3592 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) (-3135 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) (-3135 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) (-3558 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) (-3558 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) (-4428 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) (-4428 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) (-1333 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) (-1333 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) (-3200 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) (-3200 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) (-3915 (*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465)))) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) (-4326 (*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) (-2288 (*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) (-4326 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) (-4326 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) (-2288 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) (-2288 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) (-1536 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) (-1536 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) (-1536 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) (-1536 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485))))) 
+(-10 -7 (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-634 (-1161)))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -2288 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))))) (-15 -2288 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -4326 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))))) (-15 -4326 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (IF (|has| (-409 (-568)) (-1037 (-1161))) (IF (|has| (-568) (-1037 (-1161))) (PROGN (-15 -2288 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161))) (-15 -4326 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|) (-15 -3915 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465))))) (-15 -3200 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))))) (-15 -3200 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -1333 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))))) (-15 -1333 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -4428 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))))) (-15 -4428 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))))) (-15 -3135 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))))) (-15 -3135 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))))) (-15 -2152 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-15 -2152 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))))) (-15 -3416 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465)))) (-15 -3492 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465)))) (IF (|has| (-409 (-568)) (-1037 (-1161))) (IF (|has| (-568) (-1037 (-1161))) (PROGN (-15 -3492 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465))) (-1161))) (-15 -3416 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465))) (-1161))) (-15 -3135 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161))) (-15 -3592 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161))) (-15 -2152 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161))) (-15 -3200 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|)) 
+((-3492 (((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465))) (-1161)) 357 (-12 (|has| |#1| (-1037 (-1161))) (|has| |#2| (-1037 (-1161))))) (((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465))) 351)) (-3135 (((-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) 477 (-12 (|has| |#1| (-1037 (-1161))) (|has| |#2| (-1037 (-1161))))) (((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) 470) (((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|)) 471)) (-2152 (((-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) 480 (-12 (|has| |#1| (-1037 (-1161))) (|has| |#2| (-1037 (-1161))))) (((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|)) 476) (((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) 475)) (-3558 (((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|)) 467) (((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) 466)) (-3592 (((-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) 479 (-12 (|has| |#1| (-1037 (-1161))) (|has| |#2| (-1037 (-1161))))) (((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|)) 473) (((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) 472)) (-4428 (((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) 463) (((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|)) 464)) (-3915 (((-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465)))) 454)) (-2288 (((-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) 192 (-12 (|has| |#1| (-1037 (-1161))) (|has| |#2| (-1037 (-1161))))) (((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) 190) (((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|)) 189)) (-4326 (((-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) 218 (-12 (|has| |#1| (-1037 (-1161))) (|has| |#2| (-1037 (-1161))))) (((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) 207) (((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|)) 206)) (-1333 (((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) 460) (((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|)) 461)) (-3200 (((-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)) 469 (-12 (|has| |#1| (-1037 (-1161))) (|has| |#2| (-1037 (-1161))))) (((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) 457) (((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|)) 458)) (-1536 (((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161)) (-634 (-465))) 503) (((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161))) 509) (((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) 508) (((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|)) 507)) (-3416 (((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465))) (-1161)) 327 (-12 (|has| |#1| (-1037 (-1161))) (|has| |#2| (-1037 (-1161))))) (((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465))) 317))) 
+(((-486 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -1536 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -1536 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -1536 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161)))) (-15 -1536 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -2288 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -2288 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -4326 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -4326 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (IF (|has| |#1| (-1037 (-1161))) (IF (|has| |#2| (-1037 (-1161))) (PROGN (-15 -2288 ((-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -4326 ((-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|) (-15 -3915 ((-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465))))) (-15 -3200 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -3200 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -1333 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -1333 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -4428 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -4428 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -3135 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -3135 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -2152 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -2152 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -3416 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465)))) (-15 -3492 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465)))) (IF (|has| |#1| (-1037 (-1161))) (IF (|has| |#2| (-1037 (-1161))) (PROGN (-15 -3492 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465))) (-1161))) (-15 -3416 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465))) (-1161))) (-15 -3135 ((-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -3592 ((-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -2152 ((-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -3200 ((-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|)) (-365) (-453) (-13 (-432 (-568)) (-558) (-1037 |#4|) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $)))) (-13 (-842) (-558)) (-1 |#1| |#4|) (-1 |#3| |#1|)) (T -486)) 
+((-3200 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-2152 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-3592 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-3135 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-3416 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 *6) *6 *3)) (|:| A (-1 *5 (-763) (-763) (-1157 *5))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 *6 (-763) *3 *6)) (|:| C (-1 (-634 *5) (-763)))) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-3492 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 *6) *6 *3)) (|:| A (-1 *5 (-763) (-763) (-1157 *5))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 *6 (-763) *3 *6)) (|:| C (-1 (-634 *5) (-763)))) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-3492 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 *6) *6 (-1161))) (|:| A (-1 *5 (-763) (-763) (-1157 *5))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 *6 (-763) (-1161) *6)) (|:| C (-1 (-634 *5) (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-3416 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 *6) *6 (-1161))) (|:| A (-1 *5 (-763) (-763) (-1157 *5))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 *6 (-763) (-1161) *6)) (|:| C (-1 (-634 *5) (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-2152 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) (-2152 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1866 *7) (|:| -1844 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) (-3592 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) (-3592 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1866 *7) (|:| -1844 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) (-3135 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1866 *7) (|:| -1844 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) (-3135 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) (-3558 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) (-3558 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1866 *7) (|:| -1844 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) (-4428 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1866 *7) (|:| -1844 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) (-4428 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) (-1333 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1866 *7) (|:| -1844 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) (-1333 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) (-3200 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1866 *7) (|:| -1844 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) (-3200 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) (-3915 (*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 *6) *6 (-1161))) (|:| A (-1 *5 (-763) (-763) (-1157 *5))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 *6 (-763) (-1161) *6)) (|:| C (-1 (-634 *5) (-763)))) (-634 (-465)))) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-14 *9 (-1 *6 *4)) (-5 *2 (-1 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)))) (-4326 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-2288 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))) (-14 *9 (-1 *6 *4)))) (-4326 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1866 *7) (|:| -1844 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) (-4326 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) (-2288 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1866 *7) (|:| -1844 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) (-2288 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) (-1536 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 *9) (|:| -1844 (-763)))) (-634 *7) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 *7)) (-4 *7 (-365)) (-14 *12 (-1 *9 *7)) (-4 *10 (-13 (-842) (-558))) (-14 *11 (-1 *7 *10)) (-5 *2 (-634 (-2 (|:| -1866 *9) (|:| -1844 (-763))))) (-5 *1 (-486 *7 *8 *9 *10 *11 *12)) (-4 *8 (-453)) (-4 *9 (-13 (-432 (-568)) (-558) (-1037 *10) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) (-1536 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 *8) (|:| -1844 (-763)))) (-634 *6) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 *6)) (-4 *6 (-365)) (-14 *11 (-1 *8 *6)) (-4 *9 (-13 (-842) (-558))) (-14 *10 (-1 *6 *9)) (-5 *2 (-634 (-2 (|:| -1866 *8) (|:| -1844 (-763))))) (-5 *1 (-486 *6 *7 *8 *9 *10 *11)) (-4 *7 (-453)) (-4 *8 (-13 (-432 (-568)) (-558) (-1037 *9) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) (-1536 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1866 *7) (|:| -1844 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) (-1536 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $)))))))) 
+(-10 -7 (-15 -1536 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -1536 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -1536 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161)))) (-15 -1536 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -2288 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -2288 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -4326 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -4326 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (IF (|has| |#1| (-1037 (-1161))) (IF (|has| |#2| (-1037 (-1161))) (PROGN (-15 -2288 ((-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -4326 ((-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|) (-15 -3915 ((-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465))))) (-15 -3200 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -3200 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -1333 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -1333 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -4428 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -4428 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -3135 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -3135 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -2152 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465)))) (-15 -2152 ((-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|))) (-15 -3416 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465)))) (-15 -3492 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465)))) (IF (|has| |#1| (-1037 (-1161))) (IF (|has| |#2| (-1037 (-1161))) (PROGN (-15 -3492 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465))) (-1161))) (-15 -3416 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 |#1|)) (-1201 |#1|))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 |#1|))) (-1201 (-1157 |#1|)))) (|:| |exprStream| (-1 (-1141 |#3|) |#3| (-1161))) (|:| A (-1 |#2| (-763) (-763) (-1157 |#2|))) (|:| AF (-1 (-1157 |#1|) (-763) (-763) (-1201 (-1157 |#1|)))) (|:| AX (-1 |#3| (-763) (-1161) |#3|)) (|:| C (-1 (-634 |#2|) (-763)))) (-634 (-465))) (-1161))) (-15 -3135 ((-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -3592 ((-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -2152 ((-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161))) (-15 -3200 ((-1 (-634 (-2 (|:| -1866 |#3|) (|:| -1844 (-763)))) (-634 |#1|) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|)) 
+((-3492 (((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-953 (-568))) (-1037 (-1161))) (|has| (-953 (-568)) (-1037 (-1161))))) (((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465))) NIL)) (-3135 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-953 (-568))) (-1037 (-1161))) (|has| (-953 (-568)) (-1037 (-1161))))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568))))) NIL)) (-2152 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-953 (-568))) (-1037 (-1161))) (|has| (-953 (-568)) (-1037 (-1161))))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568))))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) NIL)) (-3558 (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568))))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) NIL)) (-3592 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-953 (-568))) (-1037 (-1161))) (|has| (-953 (-568)) (-1037 (-1161))))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568))))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) NIL)) (-4428 (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568))))) NIL)) (-3915 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465)))) NIL)) (-2288 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-953 (-568))) (-1037 (-1161))) (|has| (-953 (-568)) (-1037 (-1161))))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568))))) NIL)) (-4326 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-953 (-568))) (-1037 (-1161))) (|has| (-953 (-568)) (-1037 (-1161))))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568))))) NIL)) (-1333 (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568))))) NIL)) (-3200 (((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-953 (-568))) (-1037 (-1161))) (|has| (-953 (-568)) (-1037 (-1161))))) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568))))) NIL)) (-1536 (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-634 (-1161)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-634 (-1161))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568))))) NIL)) (-3416 (((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465))) (-1161)) NIL (-12 (|has| (-409 (-953 (-568))) (-1037 (-1161))) (|has| (-953 (-568)) (-1037 (-1161))))) (((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465))) NIL))) 
+(((-487) (-10 -7 (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-634 (-1161)))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -2288 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -2288 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -4326 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -4326 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (IF (|has| (-409 (-953 (-568))) (-1037 (-1161))) (IF (|has| (-953 (-568)) (-1037 (-1161))) (PROGN (-15 -2288 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161))) (-15 -4326 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|) (-15 -3915 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465))))) (-15 -3200 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -3200 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -1333 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -1333 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -4428 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -4428 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -3135 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -3135 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -2152 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -2152 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -3416 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465)))) (-15 -3492 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465)))) (IF (|has| (-409 (-953 (-568))) (-1037 (-1161))) (IF (|has| (-953 (-568)) (-1037 (-1161))) (PROGN (-15 -3492 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465))) (-1161))) (-15 -3416 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465))) (-1161))) (-15 -3135 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161))) (-15 -3592 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161))) (-15 -2152 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161))) (-15 -3200 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|))) (T -487)) 
+((-3200 (*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) (-2152 (*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) (-3592 (*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) (-3135 (*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) (-3416 (*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465)))) (-5 *1 (-487)))) (-3492 (*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465)))) (-5 *1 (-487)))) (-3492 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763))))) (-5 *1 (-487)))) (-3416 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763))))) (-5 *1 (-487)))) (-2152 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) (-2152 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) (-3592 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) (-3592 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) (-3135 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) (-3135 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) (-3558 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) (-3558 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) (-4428 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) (-4428 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) (-1333 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) (-1333 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) (-3200 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) (-3200 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) (-3915 (*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465)))) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) (-4326 (*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) (-2288 (*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) (-4326 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) (-4326 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) (-2288 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) (-2288 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) (-1536 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) (-1536 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) (-1536 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) (-1536 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487))))) 
+(-10 -7 (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-634 (-1161)))) (-15 -1536 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -2288 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -2288 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -4326 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -4326 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (IF (|has| (-409 (-953 (-568))) (-1037 (-1161))) (IF (|has| (-953 (-568)) (-1037 (-1161))) (PROGN (-15 -2288 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161))) (-15 -4326 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|) (-15 -3915 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465))))) (-15 -3200 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -3200 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -1333 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -1333 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -4428 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -4428 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -3135 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -3135 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -2152 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-15 -2152 ((-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))))) (-15 -3416 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465)))) (-15 -3492 ((-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465)))) (IF (|has| (-409 (-953 (-568))) (-1037 (-1161))) (IF (|has| (-953 (-568)) (-1037 (-1161))) (PROGN (-15 -3492 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465))) (-1161))) (-15 -3416 ((-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465))) (-1161))) (-15 -3135 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161))) (-15 -3592 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161))) (-15 -2152 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161))) (-15 -3200 ((-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))) (-1161)))) |noBranch|) |noBranch|)) 
+((-3492 (((-1 HPSPEC (-634 (-465))) (-1161)) NIL) ((HPSPEC (-634 (-465))) NIL)) (-3135 (((-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161)) NIL) (((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568))))) NIL)) (-2152 (((-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161)) NIL) (((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568))))) NIL) (((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) NIL)) (-3558 (((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568))))) NIL) (((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) NIL)) (-3592 (((-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161)) NIL) (((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568))))) NIL) (((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) NIL)) (-4428 (((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568))))) NIL)) (-3915 (((-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1 HPSPEC (-634 (-465)))) NIL)) (-2288 (((-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161)) NIL) (((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568))))) NIL)) (-4326 (((-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161)) NIL) (((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568))))) NIL)) (-1333 (((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568))))) NIL)) (-3200 (((-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161)) NIL) (((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568))))) NIL)) (-1536 (((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-634 (-1161)) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-634 (-1161))) NIL) (((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) NIL) (((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568))))) NIL)) (-3416 (((-1 HPSPEC (-634 (-465))) (-1161)) NIL) ((HPSPEC (-634 (-465))) NIL))) 
+(((-488 |#1|) (-10 -7 (-15 -1536 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -1536 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -1536 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-634 (-1161)))) (-15 -1536 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -2288 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -2288 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -4326 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -4326 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -2288 ((-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161))) (-15 -4326 ((-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161))) (-15 -3915 ((-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1 HPSPEC (-634 (-465))))) (-15 -3200 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -3200 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -1333 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -1333 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -4428 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -4428 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -3135 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -3135 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -2152 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -2152 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -3416 (HPSPEC (-634 (-465)))) (-15 -3492 (HPSPEC (-634 (-465)))) (-15 -3492 ((-1 HPSPEC (-634 (-465))) (-1161))) (-15 -3416 ((-1 HPSPEC (-634 (-465))) (-1161))) (-15 -3135 ((-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161))) (-15 -3592 ((-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161))) (-15 -2152 ((-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161))) (-15 -3200 ((-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161)))) (-1161)) (T -488)) 
+((-3200 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3))) (-2152 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3))) (-3592 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3))) (-3135 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3))) (-3416 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 HPSPEC (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3))) (-3492 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 HPSPEC (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3))) (-3492 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 HPSPEC) (-5 *1 (-488 *4)) (-14 *4 (-1161)))) (-3416 (*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 HPSPEC) (-5 *1 (-488 *4)) (-14 *4 (-1161)))) (-2152 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *4)))) (-2152 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *5 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *5)))) (-3592 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *4)))) (-3592 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *5 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *5)))) (-3135 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *5 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *5)))) (-3135 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *4)))) (-3558 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *4)))) (-3558 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *5 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *5)))) (-4428 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *5 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *5)))) (-4428 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *4)))) (-1333 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *5 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *5)))) (-1333 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *4)))) (-3200 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *5 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *5)))) (-3200 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *4)))) (-3915 (*1 *2 *3) (-12 (-5 *3 (-1 HPSPEC (-634 (-465)))) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 (-1161)))) (-4326 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3))) (-2288 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3))) (-4326 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *5 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *5)))) (-4326 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *4)))) (-2288 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *5 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *5)))) (-2288 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *4)))) (-1536 (*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 (-733 *7 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 *7 (-568)))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 (-409 (-734 *7 (-568))))) (-14 *7 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *7 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *7)))) (-1536 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 (-733 *6 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 *6 (-568)))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 (-409 (-734 *6 (-568))))) (-14 *6 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *6 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *6)))) (-1536 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *5 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *5)))) (-1536 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *4))))) 
+(-10 -7 (-15 -1536 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -1536 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -1536 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-634 (-1161)))) (-15 -1536 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-634 (-1161)) (-634 (-465)))) (-15 -2288 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -2288 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -4326 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -4326 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -2288 ((-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161))) (-15 -4326 ((-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161))) (-15 -3915 ((-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1 HPSPEC (-634 (-465))))) (-15 -3200 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -3200 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -1333 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -1333 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -4428 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -4428 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -3558 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -3135 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -3135 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -3592 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -2152 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465)))) (-15 -2152 ((-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))))) (-15 -3416 (HPSPEC (-634 (-465)))) (-15 -3492 (HPSPEC (-634 (-465)))) (-15 -3492 ((-1 HPSPEC (-634 (-465))) (-1161))) (-15 -3416 ((-1 HPSPEC (-634 (-465))) (-1161))) (-15 -3135 ((-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161))) (-15 -3592 ((-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161))) (-15 -2152 ((-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161))) (-15 -3200 ((-1 (-634 (-2 (|:| -1866 (-733 |#1| (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 |#1| (-568)))) (-634 (-465))) (-1161)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2589 (((-121) $ $) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL)) (-2857 (((-568) $) NIL) (((-409 (-568)) $) NIL)) (-2403 (($ $ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-1899 (($) 18)) (-1598 (((-121) $) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3850 (((-420 $) $) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-4280 (((-381) $) 22) (((-215) $) 25) (((-409 (-1157 (-568))) $) 19) (((-541) $) 52)) (-2747 (((-850) $) 50) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (((-215) $) 24) (((-381) $) 21)) (-3425 (((-763)) NIL)) (-2273 (((-121) $ $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) 36 T CONST)) (-1557 (($) 11 T CONST)) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL))) 
+(((-489) (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))) (-1021) (-608 (-215)) (-608 (-381)) (-609 (-409 (-1157 (-568)))) (-609 (-541)) (-10 -8 (-15 -1899 ($))))) (T -489)) 
+((-1899 (*1 *1) (-5 *1 (-489)))) 
+(-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))) (-1021) (-608 (-215)) (-608 (-381)) (-609 (-409 (-1157 (-568)))) (-609 (-541)) (-10 -8 (-15 -1899 ($)))) 
+((-2449 (((-121) $ $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-2988 (($) NIL) (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-2481 (((-1249) $ |#1| |#1|) NIL (|has| $ (-6 -4522)))) (-1667 (((-121) $ (-763)) NIL)) (-2438 ((|#2| $ |#1| |#2|) 16)) (-3963 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-2678 (((-3 |#2| "failed") |#1| $) 20)) (-4490 (($) NIL T CONST)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-1568 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (|has| $ (-6 -4521))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-3 |#2| "failed") |#1| $) 18)) (-4330 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-3094 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (|has| $ (-6 -4521))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-1292 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#2| $ |#1|) NIL)) (-3317 (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-634 |#2|) $) NIL (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) NIL)) (-2539 ((|#1| $) NIL (|has| |#1| (-842)))) (-4406 (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-634 |#2|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-3631 ((|#1| $) NIL (|has| |#1| (-842)))) (-2253 (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4522))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-4253 (((-634 |#1|) $) 13)) (-2807 (((-121) |#1| $) NIL)) (-2580 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-1708 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-3948 (((-634 |#1|) $) NIL)) (-2916 (((-121) |#1| $) NIL)) (-4025 (((-1108) $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-3877 ((|#2| $) NIL (|has| |#1| (-842)))) (-2712 (((-3 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) "failed") (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL)) (-2490 (($ $ |#2|) NIL (|has| $ (-6 -4522)))) (-3403 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-3951 (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-1480 (((-634 |#2|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) 19)) (-2781 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL)) (-3132 (($) NIL) (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-4170 (((-763) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-763) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090)))) (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-609 (-541))))) (-4289 (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-2747 (((-850) $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-4074 (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-3437 (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 11 (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-1699 (((-763) $) 15 (|has| $ (-6 -4521))))) 
+(((-490 |#1| |#2| |#3|) (-13 (-1172 |#1| |#2|) (-10 -7 (-6 -4521))) (-1090) (-1090) (-1143)) (T -490)) 
+NIL 
+(-13 (-1172 |#1| |#2|) (-10 -7 (-6 -4521))) 
+((-2542 (((-568) (-568) (-568)) 7)) (-1423 (((-121) (-568) (-568) (-568) (-568)) 11)) (-2783 (((-1244 (-634 (-568))) (-763) (-763)) 22))) 
+(((-491) (-10 -7 (-15 -2542 ((-568) (-568) (-568))) (-15 -1423 ((-121) (-568) (-568) (-568) (-568))) (-15 -2783 ((-1244 (-634 (-568))) (-763) (-763))))) (T -491)) 
+((-2783 (*1 *2 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1244 (-634 (-568)))) (-5 *1 (-491)))) (-1423 (*1 *2 *3 *3 *3 *3) (-12 (-5 *3 (-568)) (-5 *2 (-121)) (-5 *1 (-491)))) (-2542 (*1 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-491))))) 
+(-10 -7 (-15 -2542 ((-568) (-568) (-568))) (-15 -1423 ((-121) (-568) (-568) (-568) (-568))) (-15 -2783 ((-1244 (-634 (-568))) (-763) (-763)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2057 (((-634 (-852 |#1|)) $) NIL)) (-3840 (((-1157 $) $ (-852 |#1|)) NIL) (((-1157 |#2|) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#2| (-558)))) (-3661 (($ $) NIL (|has| |#2| (-558)))) (-4426 (((-121) $) NIL (|has| |#2| (-558)))) (-3528 (((-763) $) NIL) (((-763) $ (-634 (-852 |#1|))) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3045 (($ $) NIL (|has| |#2| (-453)))) (-3498 (((-420 $) $) NIL (|has| |#2| (-453)))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#2| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#2| (-1037 (-568)))) (((-3 (-852 |#1|) "failed") $) NIL)) (-2857 ((|#2| $) NIL) (((-409 (-568)) $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#2| (-1037 (-568)))) (((-852 |#1|) $) NIL)) (-2910 (($ $ $ (-852 |#1|)) NIL (|has| |#2| (-172)))) (-1594 (($ $ (-634 (-568))) NIL)) (-2116 (($ $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL) (((-679 |#2|) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1998 (($ $) NIL (|has| |#2| (-453))) (($ $ (-852 |#1|)) NIL (|has| |#2| (-453)))) (-2110 (((-634 $) $) NIL)) (-2197 (((-121) $) NIL (|has| |#2| (-904)))) (-2453 (($ $ |#2| (-493 (-1699 |#1|) (-763)) $) NIL)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-852 |#1|) (-881 (-381))) (|has| |#2| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-852 |#1|) (-881 (-568))) (|has| |#2| (-881 (-568)))))) (-1598 (((-121) $) NIL)) (-3971 (((-763) $) NIL)) (-2053 (($ (-1157 |#2|) (-852 |#1|)) NIL) (($ (-1157 $) (-852 |#1|)) NIL)) (-3062 (((-634 $) $) NIL)) (-2171 (((-121) $) NIL)) (-2049 (($ |#2| (-493 (-1699 |#1|) (-763))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-1438 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $ (-852 |#1|)) NIL)) (-3524 (((-493 (-1699 |#1|) (-763)) $) NIL) (((-763) $ (-852 |#1|)) NIL) (((-634 (-763)) $ (-634 (-852 |#1|))) NIL)) (-1732 (($ $ $) NIL (|has| |#2| (-842)))) (-2047 (($ $ $) NIL (|has| |#2| (-842)))) (-1865 (($ (-1 (-493 (-1699 |#1|) (-763)) (-493 (-1699 |#1|) (-763))) $) NIL)) (-2797 (($ (-1 |#2| |#2|) $) NIL)) (-2817 (((-3 (-852 |#1|) "failed") $) NIL)) (-2099 (($ $) NIL)) (-2104 ((|#2| $) NIL)) (-2498 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) NIL (|has| |#2| (-453)))) (-1893 (((-1143) $) NIL)) (-4362 (((-3 (-634 $) "failed") $) NIL)) (-2112 (((-3 (-634 $) "failed") $) NIL)) (-2617 (((-3 (-2 (|:| |var| (-852 |#1|)) (|:| -3483 (-763))) "failed") $) NIL)) (-4025 (((-1108) $) NIL)) (-2088 (((-121) $) NIL)) (-2093 ((|#2| $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#2| (-453)))) (-2723 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) NIL (|has| |#2| (-453)))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3850 (((-420 $) $) NIL (|has| |#2| (-904)))) (-2597 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-558)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-852 |#1|) |#2|) NIL) (($ $ (-634 (-852 |#1|)) (-634 |#2|)) NIL) (($ $ (-852 |#1|) $) NIL) (($ $ (-634 (-852 |#1|)) (-634 $)) NIL)) (-3440 (($ $ (-852 |#1|)) NIL (|has| |#2| (-172)))) (-4191 (($ $ (-852 |#1|)) NIL) (($ $ (-634 (-852 |#1|))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-1836 (((-493 (-1699 |#1|) (-763)) $) NIL) (((-763) $ (-852 |#1|)) NIL) (((-634 (-763)) $ (-634 (-852 |#1|))) NIL)) (-4280 (((-887 (-381)) $) NIL (-12 (|has| (-852 |#1|) (-609 (-887 (-381)))) (|has| |#2| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-852 |#1|) (-609 (-887 (-568)))) (|has| |#2| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-852 |#1|) (-609 (-541))) (|has| |#2| (-609 (-541)))))) (-1364 ((|#2| $) NIL (|has| |#2| (-453))) (($ $ (-852 |#1|)) NIL (|has| |#2| (-453)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#2| (-904))))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#2|) NIL) (($ (-852 |#1|)) NIL) (($ (-409 (-568))) NIL (-2199 (|has| |#2| (-43 (-409 (-568)))) (|has| |#2| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#2| (-558)))) (-3304 (((-634 |#2|) $) NIL)) (-2079 ((|#2| $ (-493 (-1699 |#1|) (-763))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| |#2| (-904))) (|has| |#2| (-148))))) (-3425 (((-763)) NIL)) (-3925 (($ $ $ (-763)) NIL (|has| |#2| (-172)))) (-2273 (((-121) $ $) NIL (|has| |#2| (-558)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $ (-852 |#1|)) NIL) (($ $ (-634 (-852 |#1|))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-1753 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1781 (($ $ |#2|) NIL (|has| |#2| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#2| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#2| (-43 (-409 (-568))))) (($ |#2| $) NIL) (($ $ |#2|) NIL))) 
+(((-492 |#1| |#2|) (-13 (-950 |#2| (-493 (-1699 |#1|) (-763)) (-852 |#1|)) (-10 -8 (-15 -1594 ($ $ (-634 (-568)))))) (-634 (-1161)) (-1047)) (T -492)) 
+((-1594 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-492 *3 *4)) (-14 *3 (-634 (-1161))) (-4 *4 (-1047))))) 
+(-13 (-950 |#2| (-493 (-1699 |#1|) (-763)) (-852 |#1|)) (-10 -8 (-15 -1594 ($ $ (-634 (-568)))))) 
+((-2449 (((-121) $ $) NIL (|has| |#2| (-1090)))) (-1819 (((-121) $) NIL (|has| |#2| (-137)))) (-4007 (($ (-917)) NIL (|has| |#2| (-1047)))) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-2409 (($ $ $) NIL (|has| |#2| (-788)))) (-2689 (((-3 $ "failed") $ $) NIL (|has| |#2| (-137)))) (-1667 (((-121) $ (-763)) NIL)) (-3986 (((-763)) NIL (|has| |#2| (-370)))) (-3337 (((-568) $) NIL (|has| |#2| (-840)))) (-2438 ((|#2| $ (-568) |#2|) NIL (|has| $ (-6 -4522)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) NIL (-12 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090)))) (((-3 (-409 (-568)) "failed") $) NIL (-12 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) (((-3 |#2| "failed") $) NIL (|has| |#2| (-1090)))) (-2857 (((-568) $) NIL (-12 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090)))) (((-409 (-568)) $) NIL (-12 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) ((|#2| $) NIL (|has| |#2| (-1090)))) (-1668 (((-679 (-568)) (-679 $)) NIL (-12 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (-12 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047)))) (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL (|has| |#2| (-1047))) (((-679 |#2|) (-679 $)) NIL (|has| |#2| (-1047)))) (-2902 (((-3 $ "failed") $) NIL (|has| |#2| (-716)))) (-1733 (($) NIL (|has| |#2| (-370)))) (-1292 ((|#2| $ (-568) |#2|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#2| $ (-568)) 11)) (-1436 (((-121) $) NIL (|has| |#2| (-840)))) (-3317 (((-634 |#2|) $) NIL (|has| $ (-6 -4521)))) (-1598 (((-121) $) NIL (|has| |#2| (-716)))) (-2859 (((-121) $) NIL (|has| |#2| (-840)))) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) NIL (|has| (-568) (-842)))) (-1732 (($ $ $) NIL (-2199 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-4406 (((-634 |#2|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-3631 (((-568) $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (-2199 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-2253 (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#2| |#2|) $) NIL)) (-2291 (((-917) $) NIL (|has| |#2| (-370)))) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (|has| |#2| (-1090)))) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4357 (($ (-917)) NIL (|has| |#2| (-370)))) (-4025 (((-1108) $) NIL (|has| |#2| (-1090)))) (-3877 ((|#2| $) NIL (|has| (-568) (-842)))) (-2490 (($ $ |#2|) NIL (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-1480 (((-634 |#2|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#2| $ (-568) |#2|) NIL) ((|#2| $ (-568)) NIL)) (-2286 ((|#2| $ $) NIL (|has| |#2| (-1047)))) (-2041 (($ (-1244 |#2|)) NIL)) (-3108 (((-139)) NIL (|has| |#2| (-365)))) (-4191 (($ $) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1 |#2| |#2|) (-763)) NIL (|has| |#2| (-1047))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1047)))) (-4170 (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-3865 (($ $) NIL)) (-2747 (((-1244 |#2|) $) NIL) (((-850) $) NIL (|has| |#2| (-1090))) (($ (-568)) NIL (-2199 (-12 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090))) (|has| |#2| (-1047)))) (($ (-409 (-568))) NIL (-12 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) (($ |#2|) NIL (|has| |#2| (-1090)))) (-3425 (((-763)) NIL (|has| |#2| (-1047)))) (-3437 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-2811 (($ $) NIL (|has| |#2| (-840)))) (-1889 (($ $ (-763)) NIL (|has| |#2| (-716))) (($ $ (-917)) NIL (|has| |#2| (-716)))) (-3058 (($) NIL (|has| |#2| (-137)) CONST)) (-1557 (($) NIL (|has| |#2| (-716)) CONST)) (-3192 (($ $) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1 |#2| |#2|) (-763)) NIL (|has| |#2| (-1047))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1047)))) (-1753 (((-121) $ $) NIL (-2199 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1740 (((-121) $ $) NIL (-2199 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1719 (((-121) $ $) NIL (|has| |#2| (-1090)))) (-1747 (((-121) $ $) NIL (-2199 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1734 (((-121) $ $) 15 (-2199 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1781 (($ $ |#2|) NIL (|has| |#2| (-365)))) (-1775 (($ $ $) NIL (|has| |#2| (-1047))) (($ $) NIL (|has| |#2| (-1047)))) (-1769 (($ $ $) NIL (|has| |#2| (-25)))) (** (($ $ (-763)) NIL (|has| |#2| (-716))) (($ $ (-917)) NIL (|has| |#2| (-716)))) (* (($ (-568) $) NIL (|has| |#2| (-1047))) (($ $ $) NIL (|has| |#2| (-716))) (($ $ |#2|) NIL (|has| |#2| (-1047))) (($ |#2| $) NIL (|has| |#2| (-1047))) (($ (-763) $) NIL (|has| |#2| (-137))) (($ (-917) $) NIL (|has| |#2| (-25)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
 (((-493 |#1| |#2|) (-230 |#1| |#2|) (-763) (-788)) (T -493)) 
 NIL 
 (-230 |#1| |#2|) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2510 (((-121) $ (-763)) NIL)) (-2671 (($) NIL T CONST)) (-4360 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) NIL)) (-3349 (($ $ $) 32)) (-1347 (($ $ $) 31)) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3268 ((|#1| $) 26)) (-3674 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-1890 ((|#1| $) 27)) (-4450 (($ |#1| $) 10)) (-1359 (($ (-634 |#1|)) 12)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-1315 ((|#1| $) 23)) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) 9)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) NIL)) (-2745 (((-850) $) NIL (|has| |#1| (-1090)))) (-2367 (($ (-634 |#1|)) 29)) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1697 (((-763) $) 21 (|has| $ (-6 -4519))))) 
-(((-494 |#1|) (-13 (-969 |#1|) (-10 -8 (-15 -1359 ($ (-634 |#1|))) (-15 -2367 ($ (-634 |#1|))) (-15 -3863 ($ $)) (-15 -3084 ((-121) $)) (-15 -3248 ($)) (-15 -3171 ((-121) $ $)) (-15 -1315 (|#1| $)) (-15 -4450 ($ |#1| $)) (-15 -1890 (|#1| $)) (-15 -2795 ($ (-1 |#1| |#1|) $)) (-15 -3268 (|#1| $)) (-15 -1347 ($ $ $)) (-15 -3349 ($ $ $)) (-15 -2671 ($)) (-15 -2166 ((-121) $ (-763))) (-15 -1737 ((-121) $ (-763))) (-15 -2510 ((-121) $ (-763))) (IF (|has| $ (-6 -4520)) (-15 -3674 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-15 -4487 ((-1143) $)) (-15 -4022 ((-1108) $)) (-15 -2745 ((-850) $)) (-15 -1717 ((-121) $ $)) (-15 -2447 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4519)) (PROGN (-15 -1387 ((-121) (-1 (-121) |#1|) $)) (-15 -1319 ((-121) (-1 (-121) |#1|) $)) (-15 -4168 ((-763) (-1 (-121) |#1|) $)) (-15 -1697 ((-763) $)) (-15 -4360 ((-634 |#1|) $)) (-15 -1979 ((-634 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4519)) (IF (|has| |#1| (-1090)) (PROGN (-15 -3109 ((-121) |#1| $)) (-15 -4168 ((-763) |#1| $))) |noBranch|) |noBranch|))) (-842)) (T -494)) 
-((-3171 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-494 *3)) (-4 *3 (-842)))) (-3863 (*1 *1 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) (-3248 (*1 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) (-3084 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-494 *3)) (-4 *3 (-842)))) (-2166 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-494 *4)) (-4 *4 (-842)))) (-1737 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-494 *4)) (-4 *4 (-842)))) (-2510 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-494 *4)) (-4 *4 (-842)))) (-2671 (*1 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) (-1697 (*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-763)) (-5 *1 (-494 *3)) (-4 *3 (-842)))) (-2795 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-842)) (-5 *1 (-494 *3)))) (-3674 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4520)) (-4 *3 (-842)) (-5 *1 (-494 *3)))) (-1319 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-842)) (-5 *2 (-121)) (-5 *1 (-494 *4)))) (-1387 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-842)) (-5 *2 (-121)) (-5 *1 (-494 *4)))) (-4168 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-842)) (-5 *2 (-763)) (-5 *1 (-494 *4)))) (-4360 (*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-634 *3)) (-5 *1 (-494 *3)) (-4 *3 (-842)))) (-1979 (*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-634 *3)) (-5 *1 (-494 *3)) (-4 *3 (-842)))) (-4168 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-763)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) (-3109 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-121)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) (-4487 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) (-4022 (*1 *2 *1) (-12 (-5 *2 (-1108)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) (-1717 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) (-2447 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) (-2367 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-494 *3)))) (-1315 (*1 *2 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) (-4450 (*1 *1 *2 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) (-1890 (*1 *2 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) (-3268 (*1 *2 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) (-1347 (*1 *1 *1 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) (-3349 (*1 *1 *1 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) (-1359 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-494 *3))))) 
-(-13 (-969 |#1|) (-10 -8 (-15 -1359 ($ (-634 |#1|))) (-15 -2367 ($ (-634 |#1|))) (-15 -3863 ($ $)) (-15 -3084 ((-121) $)) (-15 -3248 ($)) (-15 -3171 ((-121) $ $)) (-15 -1315 (|#1| $)) (-15 -4450 ($ |#1| $)) (-15 -1890 (|#1| $)) (-15 -2795 ($ (-1 |#1| |#1|) $)) (-15 -3268 (|#1| $)) (-15 -1347 ($ $ $)) (-15 -3349 ($ $ $)) (-15 -2671 ($)) (-15 -2166 ((-121) $ (-763))) (-15 -1737 ((-121) $ (-763))) (-15 -2510 ((-121) $ (-763))) (IF (|has| $ (-6 -4520)) (-15 -3674 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-15 -4487 ((-1143) $)) (-15 -4022 ((-1108) $)) (-15 -2745 ((-850) $)) (-15 -1717 ((-121) $ $)) (-15 -2447 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4519)) (PROGN (-15 -1387 ((-121) (-1 (-121) |#1|) $)) (-15 -1319 ((-121) (-1 (-121) |#1|) $)) (-15 -4168 ((-763) (-1 (-121) |#1|) $)) (-15 -1697 ((-763) $)) (-15 -4360 ((-634 |#1|) $)) (-15 -1979 ((-634 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4519)) (IF (|has| |#1| (-1090)) (PROGN (-15 -3109 ((-121) |#1| $)) (-15 -4168 ((-763) |#1| $))) |noBranch|) |noBranch|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-3092 (($ $) 69)) (-2886 (((-121) $) NIL)) (-4487 (((-1143) $) NIL)) (-1552 (((-415 |#2| (-409 |#2|) |#3| |#4|) $) 43)) (-4022 (((-1108) $) NIL)) (-2704 (((-3 |#4| "failed") $) 105)) (-2849 (($ (-415 |#2| (-409 |#2|) |#3| |#4|)) 76) (($ |#4|) 32) (($ |#1| |#1|) 113) (($ |#1| |#1| (-568)) NIL) (($ |#4| |#2| |#2| |#2| |#1|) 125)) (-2847 (((-2 (|:| -1713 (-415 |#2| (-409 |#2|) |#3| |#4|)) (|:| |principalPart| |#4|)) $) 45)) (-2745 (((-850) $) 100)) (-3056 (($) 33 T CONST)) (-1717 (((-121) $ $) 107)) (-1773 (($ $) 72) (($ $ $) NIL)) (-1767 (($ $ $) 70)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 73))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1667 (((-121) $ (-763)) NIL)) (-4490 (($) NIL T CONST)) (-3317 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) NIL)) (-4496 (($ $ $) 32)) (-3645 (($ $ $) 31)) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-2047 ((|#1| $) 26)) (-2253 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-2580 ((|#1| $) 27)) (-1708 (($ |#1| $) 10)) (-3739 (($ (-634 |#1|)) 12)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3403 ((|#1| $) 23)) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) 9)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) NIL)) (-2747 (((-850) $) NIL (|has| |#1| (-1090)))) (-4074 (($ (-634 |#1|)) 29)) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1699 (((-763) $) 21 (|has| $ (-6 -4521))))) 
+(((-494 |#1|) (-13 (-969 |#1|) (-10 -8 (-15 -3739 ($ (-634 |#1|))) (-15 -4074 ($ (-634 |#1|))) (-15 -3865 ($ $)) (-15 -2436 ((-121) $)) (-15 -1990 ($)) (-15 -1702 ((-121) $ $)) (-15 -3403 (|#1| $)) (-15 -1708 ($ |#1| $)) (-15 -2580 (|#1| $)) (-15 -2797 ($ (-1 |#1| |#1|) $)) (-15 -2047 (|#1| $)) (-15 -3645 ($ $ $)) (-15 -4496 ($ $ $)) (-15 -4490 ($)) (-15 -3796 ((-121) $ (-763))) (-15 -3791 ((-121) $ (-763))) (-15 -1667 ((-121) $ (-763))) (IF (|has| $ (-6 -4522)) (-15 -2253 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-15 -1893 ((-1143) $)) (-15 -4025 ((-1108) $)) (-15 -2747 ((-850) $)) (-15 -1719 ((-121) $ $)) (-15 -2449 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4521)) (PROGN (-15 -3951 ((-121) (-1 (-121) |#1|) $)) (-15 -3437 ((-121) (-1 (-121) |#1|) $)) (-15 -4170 ((-763) (-1 (-121) |#1|) $)) (-15 -1699 ((-763) $)) (-15 -3317 ((-634 |#1|) $)) (-15 -4406 ((-634 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4521)) (IF (|has| |#1| (-1090)) (PROGN (-15 -2551 ((-121) |#1| $)) (-15 -4170 ((-763) |#1| $))) |noBranch|) |noBranch|))) (-842)) (T -494)) 
+((-1702 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-494 *3)) (-4 *3 (-842)))) (-3865 (*1 *1 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) (-1990 (*1 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) (-2436 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-494 *3)) (-4 *3 (-842)))) (-3796 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-494 *4)) (-4 *4 (-842)))) (-3791 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-494 *4)) (-4 *4 (-842)))) (-1667 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-494 *4)) (-4 *4 (-842)))) (-4490 (*1 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) (-1699 (*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-763)) (-5 *1 (-494 *3)) (-4 *3 (-842)))) (-2797 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-842)) (-5 *1 (-494 *3)))) (-2253 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4522)) (-4 *3 (-842)) (-5 *1 (-494 *3)))) (-3437 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-842)) (-5 *2 (-121)) (-5 *1 (-494 *4)))) (-3951 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-842)) (-5 *2 (-121)) (-5 *1 (-494 *4)))) (-4170 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-842)) (-5 *2 (-763)) (-5 *1 (-494 *4)))) (-3317 (*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-634 *3)) (-5 *1 (-494 *3)) (-4 *3 (-842)))) (-4406 (*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-634 *3)) (-5 *1 (-494 *3)) (-4 *3 (-842)))) (-4170 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-763)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) (-2551 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-121)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) (-1893 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) (-4025 (*1 *2 *1) (-12 (-5 *2 (-1108)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) (-1719 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) (-2449 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) (-4074 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-494 *3)))) (-3403 (*1 *2 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) (-1708 (*1 *1 *2 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) (-2580 (*1 *2 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) (-2047 (*1 *2 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) (-3645 (*1 *1 *1 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) (-4496 (*1 *1 *1 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) (-3739 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-494 *3))))) 
+(-13 (-969 |#1|) (-10 -8 (-15 -3739 ($ (-634 |#1|))) (-15 -4074 ($ (-634 |#1|))) (-15 -3865 ($ $)) (-15 -2436 ((-121) $)) (-15 -1990 ($)) (-15 -1702 ((-121) $ $)) (-15 -3403 (|#1| $)) (-15 -1708 ($ |#1| $)) (-15 -2580 (|#1| $)) (-15 -2797 ($ (-1 |#1| |#1|) $)) (-15 -2047 (|#1| $)) (-15 -3645 ($ $ $)) (-15 -4496 ($ $ $)) (-15 -4490 ($)) (-15 -3796 ((-121) $ (-763))) (-15 -3791 ((-121) $ (-763))) (-15 -1667 ((-121) $ (-763))) (IF (|has| $ (-6 -4522)) (-15 -2253 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-15 -1893 ((-1143) $)) (-15 -4025 ((-1108) $)) (-15 -2747 ((-850) $)) (-15 -1719 ((-121) $ $)) (-15 -2449 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4521)) (PROGN (-15 -3951 ((-121) (-1 (-121) |#1|) $)) (-15 -3437 ((-121) (-1 (-121) |#1|) $)) (-15 -4170 ((-763) (-1 (-121) |#1|) $)) (-15 -1699 ((-763) $)) (-15 -3317 ((-634 |#1|) $)) (-15 -4406 ((-634 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4521)) (IF (|has| |#1| (-1090)) (PROGN (-15 -2551 ((-121) |#1| $)) (-15 -4170 ((-763) |#1| $))) |noBranch|) |noBranch|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-3094 (($ $) 69)) (-2776 (((-121) $) NIL)) (-1893 (((-1143) $) NIL)) (-4314 (((-415 |#2| (-409 |#2|) |#3| |#4|) $) 43)) (-4025 (((-1108) $) NIL)) (-2707 (((-3 |#4| "failed") $) 105)) (-3957 (($ (-415 |#2| (-409 |#2|) |#3| |#4|)) 76) (($ |#4|) 32) (($ |#1| |#1|) 113) (($ |#1| |#1| (-568)) NIL) (($ |#4| |#2| |#2| |#2| |#1|) 125)) (-3946 (((-2 (|:| -1716 (-415 |#2| (-409 |#2|) |#3| |#4|)) (|:| |principalPart| |#4|)) $) 45)) (-2747 (((-850) $) 100)) (-3058 (($) 33 T CONST)) (-1719 (((-121) $ $) 107)) (-1775 (($ $) 72) (($ $ $) NIL)) (-1769 (($ $ $) 70)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 73))) 
 (((-495 |#1| |#2| |#3| |#4|) (-333 |#1| |#2| |#3| |#4|) (-365) (-1219 |#1|) (-1219 (-409 |#2|)) (-340 |#1| |#2| |#3|)) (T -495)) 
 NIL 
 (-333 |#1| |#2| |#3| |#4|) 
-((-4375 (((-568) (-634 (-568))) 28)) (-4323 ((|#1| (-634 |#1|)) 56)) (-3279 (((-634 |#1|) (-634 |#1|)) 57)) (-4439 (((-634 |#1|) (-634 |#1|)) 59)) (-2721 ((|#1| (-634 |#1|)) 58)) (-3367 (((-634 (-568)) (-634 |#1|)) 31))) 
-(((-496 |#1|) (-10 -7 (-15 -2721 (|#1| (-634 |#1|))) (-15 -4323 (|#1| (-634 |#1|))) (-15 -4439 ((-634 |#1|) (-634 |#1|))) (-15 -3279 ((-634 |#1|) (-634 |#1|))) (-15 -3367 ((-634 (-568)) (-634 |#1|))) (-15 -4375 ((-568) (-634 (-568))))) (-1219 (-568))) (T -496)) 
-((-4375 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-568)) (-5 *1 (-496 *4)) (-4 *4 (-1219 *2)))) (-3367 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1219 (-568))) (-5 *2 (-634 (-568))) (-5 *1 (-496 *4)))) (-3279 (*1 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1219 (-568))) (-5 *1 (-496 *3)))) (-4439 (*1 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1219 (-568))) (-5 *1 (-496 *3)))) (-4323 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-5 *1 (-496 *2)) (-4 *2 (-1219 (-568))))) (-2721 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-5 *1 (-496 *2)) (-4 *2 (-1219 (-568)))))) 
-(-10 -7 (-15 -2721 (|#1| (-634 |#1|))) (-15 -4323 (|#1| (-634 |#1|))) (-15 -4439 ((-634 |#1|) (-634 |#1|))) (-15 -3279 ((-634 |#1|) (-634 |#1|))) (-15 -3367 ((-634 (-568)) (-634 |#1|))) (-15 -4375 ((-568) (-634 (-568))))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-1492 (((-568) $) NIL (|has| (-568) (-301)))) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-1497 (((-121) $ $) NIL)) (-3662 (((-568) $) NIL (|has| (-568) (-815)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) NIL) (((-3 (-1161) "failed") $) NIL (|has| (-568) (-1037 (-1161)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| (-568) (-1037 (-568)))) (((-3 (-568) "failed") $) NIL (|has| (-568) (-1037 (-568))))) (-2854 (((-568) $) NIL) (((-1161) $) NIL (|has| (-568) (-1037 (-1161)))) (((-409 (-568)) $) NIL (|has| (-568) (-1037 (-568)))) (((-568) $) NIL (|has| (-568) (-1037 (-568))))) (-2401 (($ $ $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| (-568) (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| (-568) (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-679 (-568)) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1731 (($) NIL (|has| (-568) (-550)))) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-2033 (((-121) $) NIL (|has| (-568) (-815)))) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| (-568) (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| (-568) (-881 (-381))))) (-2735 (((-121) $) NIL)) (-1332 (($ $) NIL)) (-2317 (((-568) $) NIL)) (-3038 (((-3 $ "failed") $) NIL (|has| (-568) (-1136)))) (-2245 (((-121) $) NIL (|has| (-568) (-815)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2521 (($ $ $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (|has| (-568) (-842)))) (-2795 (($ (-1 (-568) (-568)) $) NIL)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4434 (($) NIL (|has| (-568) (-1136)) CONST)) (-2343 (($ (-409 (-568))) 8)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3880 (($ $) NIL (|has| (-568) (-301))) (((-409 (-568)) $) NIL)) (-1519 (((-568) $) NIL (|has| (-568) (-550)))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-3848 (((-420 $) $) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1339 (($ $ (-634 (-568)) (-634 (-568))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-568) (-568)) NIL (|has| (-568) (-303 (-568)))) (($ $ (-288 (-568))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-634 (-288 (-568)))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-634 (-1161)) (-634 (-568))) NIL (|has| (-568) (-523 (-1161) (-568)))) (($ $ (-1161) (-568)) NIL (|has| (-568) (-523 (-1161) (-568))))) (-2709 (((-763) $) NIL)) (-2779 (($ $ (-568)) NIL (|has| (-568) (-281 (-568) (-568))))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-4189 (($ $) NIL (|has| (-568) (-225))) (($ $ (-763)) NIL (|has| (-568) (-225))) (($ $ (-1161)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1 (-568) (-568)) (-763)) NIL) (($ $ (-1 (-568) (-568))) NIL)) (-3013 (($ $) NIL)) (-2324 (((-568) $) NIL)) (-4278 (((-887 (-568)) $) NIL (|has| (-568) (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| (-568) (-609 (-887 (-381))))) (((-541) $) NIL (|has| (-568) (-609 (-541)))) (((-381) $) NIL (|has| (-568) (-1021))) (((-215) $) NIL (|has| (-568) (-1021)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| (-568) (-904))))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) 7) (($ (-568)) NIL) (($ (-1161)) NIL (|has| (-568) (-1037 (-1161)))) (((-409 (-568)) $) NIL) (((-1004 16) $) 9)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| (-568) (-904))) (|has| (-568) (-148))))) (-4078 (((-763)) NIL)) (-2285 (((-568) $) NIL (|has| (-568) (-550)))) (-1826 (((-121) $ $) NIL)) (-2897 (($ $) NIL (|has| (-568) (-815)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $) NIL (|has| (-568) (-225))) (($ $ (-763)) NIL (|has| (-568) (-225))) (($ $ (-1161)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1 (-568) (-568)) (-763)) NIL) (($ $ (-1 (-568) (-568))) NIL)) (-1751 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1738 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1732 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1779 (($ $ $) NIL) (($ (-568) (-568)) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ (-568) $) NIL) (($ $ (-568)) NIL))) 
-(((-497) (-13 (-993 (-568)) (-10 -8 (-15 -2745 ((-409 (-568)) $)) (-15 -2745 ((-1004 16) $)) (-15 -3880 ((-409 (-568)) $)) (-15 -2343 ($ (-409 (-568))))))) (T -497)) 
-((-2745 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-497)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-1004 16)) (-5 *1 (-497)))) (-3880 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-497)))) (-2343 (*1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-497))))) 
-(-13 (-993 (-568)) (-10 -8 (-15 -2745 ((-409 (-568)) $)) (-15 -2745 ((-1004 16) $)) (-15 -3880 ((-409 (-568)) $)) (-15 -2343 ($ (-409 (-568)))))) 
-((-1979 (((-634 |#2|) $) 22)) (-3109 (((-121) |#2| $) 27)) (-1387 (((-121) (-1 (-121) |#2|) $) 20)) (-1339 (($ $ (-634 (-288 |#2|))) 12) (($ $ (-288 |#2|)) NIL) (($ $ |#2| |#2|) NIL) (($ $ (-634 |#2|) (-634 |#2|)) NIL)) (-4168 (((-763) (-1 (-121) |#2|) $) 21) (((-763) |#2| $) 25)) (-2745 (((-850) $) 36)) (-1319 (((-121) (-1 (-121) |#2|) $) 19)) (-1717 (((-121) $ $) 30)) (-1697 (((-763) $) 16))) 
-(((-498 |#1| |#2|) (-10 -8 (-15 -1717 ((-121) |#1| |#1|)) (-15 -2745 ((-850) |#1|)) (-15 -1339 (|#1| |#1| (-634 |#2|) (-634 |#2|))) (-15 -1339 (|#1| |#1| |#2| |#2|)) (-15 -1339 (|#1| |#1| (-288 |#2|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#2|)))) (-15 -3109 ((-121) |#2| |#1|)) (-15 -4168 ((-763) |#2| |#1|)) (-15 -1979 ((-634 |#2|) |#1|)) (-15 -4168 ((-763) (-1 (-121) |#2|) |#1|)) (-15 -1387 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -1319 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -1697 ((-763) |#1|))) (-499 |#2|) (-1195)) (T -498)) 
-NIL 
-(-10 -8 (-15 -1717 ((-121) |#1| |#1|)) (-15 -2745 ((-850) |#1|)) (-15 -1339 (|#1| |#1| (-634 |#2|) (-634 |#2|))) (-15 -1339 (|#1| |#1| |#2| |#2|)) (-15 -1339 (|#1| |#1| (-288 |#2|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#2|)))) (-15 -3109 ((-121) |#2| |#1|)) (-15 -4168 ((-763) |#2| |#1|)) (-15 -1979 ((-634 |#2|) |#1|)) (-15 -4168 ((-763) (-1 (-121) |#2|) |#1|)) (-15 -1387 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -1319 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -1697 ((-763) |#1|))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2510 (((-121) $ (-763)) 8)) (-2671 (($) 7 T CONST)) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) 9)) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35)) (-2166 (((-121) $ (-763)) 10)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-1318 (((-568) (-634 (-568))) 28)) (-3116 ((|#1| (-634 |#1|)) 56)) (-2091 (((-634 |#1|) (-634 |#1|)) 57)) (-1651 (((-634 |#1|) (-634 |#1|)) 59)) (-2723 ((|#1| (-634 |#1|)) 58)) (-1364 (((-634 (-568)) (-634 |#1|)) 31))) 
+(((-496 |#1|) (-10 -7 (-15 -2723 (|#1| (-634 |#1|))) (-15 -3116 (|#1| (-634 |#1|))) (-15 -1651 ((-634 |#1|) (-634 |#1|))) (-15 -2091 ((-634 |#1|) (-634 |#1|))) (-15 -1364 ((-634 (-568)) (-634 |#1|))) (-15 -1318 ((-568) (-634 (-568))))) (-1219 (-568))) (T -496)) 
+((-1318 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-568)) (-5 *1 (-496 *4)) (-4 *4 (-1219 *2)))) (-1364 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1219 (-568))) (-5 *2 (-634 (-568))) (-5 *1 (-496 *4)))) (-2091 (*1 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1219 (-568))) (-5 *1 (-496 *3)))) (-1651 (*1 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1219 (-568))) (-5 *1 (-496 *3)))) (-3116 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-5 *1 (-496 *2)) (-4 *2 (-1219 (-568))))) (-2723 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-5 *1 (-496 *2)) (-4 *2 (-1219 (-568)))))) 
+(-10 -7 (-15 -2723 (|#1| (-634 |#1|))) (-15 -3116 (|#1| (-634 |#1|))) (-15 -1651 ((-634 |#1|) (-634 |#1|))) (-15 -2091 ((-634 |#1|) (-634 |#1|))) (-15 -1364 ((-634 (-568)) (-634 |#1|))) (-15 -1318 ((-568) (-634 (-568))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2563 (((-568) $) NIL (|has| (-568) (-301)))) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-2589 (((-121) $ $) NIL)) (-3337 (((-568) $) NIL (|has| (-568) (-815)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) NIL) (((-3 (-1161) "failed") $) NIL (|has| (-568) (-1037 (-1161)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| (-568) (-1037 (-568)))) (((-3 (-568) "failed") $) NIL (|has| (-568) (-1037 (-568))))) (-2857 (((-568) $) NIL) (((-1161) $) NIL (|has| (-568) (-1037 (-1161)))) (((-409 (-568)) $) NIL (|has| (-568) (-1037 (-568)))) (((-568) $) NIL (|has| (-568) (-1037 (-568))))) (-2403 (($ $ $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| (-568) (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| (-568) (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-679 (-568)) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1733 (($) NIL (|has| (-568) (-550)))) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-1436 (((-121) $) NIL (|has| (-568) (-815)))) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| (-568) (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| (-568) (-881 (-381))))) (-1598 (((-121) $) NIL)) (-3539 (($ $) NIL)) (-2319 (((-568) $) NIL)) (-2214 (((-3 $ "failed") $) NIL (|has| (-568) (-1136)))) (-2859 (((-121) $) NIL (|has| (-568) (-815)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1732 (($ $ $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (|has| (-568) (-842)))) (-2797 (($ (-1 (-568) (-568)) $) NIL)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4436 (($) NIL (|has| (-568) (-1136)) CONST)) (-3916 (($ (-409 (-568))) 8)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1999 (($ $) NIL (|has| (-568) (-301))) (((-409 (-568)) $) NIL)) (-4115 (((-568) $) NIL (|has| (-568) (-550)))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-3850 (((-420 $) $) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1339 (($ $ (-634 (-568)) (-634 (-568))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-568) (-568)) NIL (|has| (-568) (-303 (-568)))) (($ $ (-288 (-568))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-634 (-288 (-568)))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-634 (-1161)) (-634 (-568))) NIL (|has| (-568) (-523 (-1161) (-568)))) (($ $ (-1161) (-568)) NIL (|has| (-568) (-523 (-1161) (-568))))) (-1466 (((-763) $) NIL)) (-2781 (($ $ (-568)) NIL (|has| (-568) (-281 (-568) (-568))))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-4191 (($ $) NIL (|has| (-568) (-225))) (($ $ (-763)) NIL (|has| (-568) (-225))) (($ $ (-1161)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1 (-568) (-568)) (-763)) NIL) (($ $ (-1 (-568) (-568))) NIL)) (-3210 (($ $) NIL)) (-2326 (((-568) $) NIL)) (-4280 (((-887 (-568)) $) NIL (|has| (-568) (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| (-568) (-609 (-887 (-381))))) (((-541) $) NIL (|has| (-568) (-609 (-541)))) (((-381) $) NIL (|has| (-568) (-1021))) (((-215) $) NIL (|has| (-568) (-1021)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| (-568) (-904))))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) 7) (($ (-568)) NIL) (($ (-1161)) NIL (|has| (-568) (-1037 (-1161)))) (((-409 (-568)) $) NIL) (((-1004 16) $) 9)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| (-568) (-904))) (|has| (-568) (-148))))) (-3425 (((-763)) NIL)) (-3520 (((-568) $) NIL (|has| (-568) (-550)))) (-2273 (((-121) $ $) NIL)) (-2811 (($ $) NIL (|has| (-568) (-815)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $) NIL (|has| (-568) (-225))) (($ $ (-763)) NIL (|has| (-568) (-225))) (($ $ (-1161)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1 (-568) (-568)) (-763)) NIL) (($ $ (-1 (-568) (-568))) NIL)) (-1753 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1740 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1734 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1781 (($ $ $) NIL) (($ (-568) (-568)) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ (-568) $) NIL) (($ $ (-568)) NIL))) 
+(((-497) (-13 (-993 (-568)) (-10 -8 (-15 -2747 ((-409 (-568)) $)) (-15 -2747 ((-1004 16) $)) (-15 -1999 ((-409 (-568)) $)) (-15 -3916 ($ (-409 (-568))))))) (T -497)) 
+((-2747 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-497)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-1004 16)) (-5 *1 (-497)))) (-1999 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-497)))) (-3916 (*1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-497))))) 
+(-13 (-993 (-568)) (-10 -8 (-15 -2747 ((-409 (-568)) $)) (-15 -2747 ((-1004 16) $)) (-15 -1999 ((-409 (-568)) $)) (-15 -3916 ($ (-409 (-568)))))) 
+((-4406 (((-634 |#2|) $) 22)) (-2551 (((-121) |#2| $) 27)) (-3951 (((-121) (-1 (-121) |#2|) $) 20)) (-1339 (($ $ (-634 (-288 |#2|))) 12) (($ $ (-288 |#2|)) NIL) (($ $ |#2| |#2|) NIL) (($ $ (-634 |#2|) (-634 |#2|)) NIL)) (-4170 (((-763) (-1 (-121) |#2|) $) 21) (((-763) |#2| $) 25)) (-2747 (((-850) $) 36)) (-3437 (((-121) (-1 (-121) |#2|) $) 19)) (-1719 (((-121) $ $) 30)) (-1699 (((-763) $) 16))) 
+(((-498 |#1| |#2|) (-10 -8 (-15 -1719 ((-121) |#1| |#1|)) (-15 -2747 ((-850) |#1|)) (-15 -1339 (|#1| |#1| (-634 |#2|) (-634 |#2|))) (-15 -1339 (|#1| |#1| |#2| |#2|)) (-15 -1339 (|#1| |#1| (-288 |#2|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#2|)))) (-15 -2551 ((-121) |#2| |#1|)) (-15 -4170 ((-763) |#2| |#1|)) (-15 -4406 ((-634 |#2|) |#1|)) (-15 -4170 ((-763) (-1 (-121) |#2|) |#1|)) (-15 -3951 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3437 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -1699 ((-763) |#1|))) (-499 |#2|) (-1195)) (T -498)) 
+NIL 
+(-10 -8 (-15 -1719 ((-121) |#1| |#1|)) (-15 -2747 ((-850) |#1|)) (-15 -1339 (|#1| |#1| (-634 |#2|) (-634 |#2|))) (-15 -1339 (|#1| |#1| |#2| |#2|)) (-15 -1339 (|#1| |#1| (-288 |#2|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#2|)))) (-15 -2551 ((-121) |#2| |#1|)) (-15 -4170 ((-763) |#2| |#1|)) (-15 -4406 ((-634 |#2|) |#1|)) (-15 -4170 ((-763) (-1 (-121) |#2|) |#1|)) (-15 -3951 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3437 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -1699 ((-763) |#1|))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-1667 (((-121) $ (-763)) 8)) (-4490 (($) 7 T CONST)) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) 9)) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35)) (-3796 (((-121) $ (-763)) 10)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-499 |#1|) (-1275) (-1195)) (T -499)) 
-((-2795 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-499 *3)) (-4 *3 (-1195)))) (-3674 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| *1 (-6 -4520)) (-4 *1 (-499 *3)) (-4 *3 (-1195)))) (-1319 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| *1 (-6 -4519)) (-4 *1 (-499 *4)) (-4 *4 (-1195)) (-5 *2 (-121)))) (-1387 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| *1 (-6 -4519)) (-4 *1 (-499 *4)) (-4 *4 (-1195)) (-5 *2 (-121)))) (-4168 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| *1 (-6 -4519)) (-4 *1 (-499 *4)) (-4 *4 (-1195)) (-5 *2 (-763)))) (-4360 (*1 *2 *1) (-12 (|has| *1 (-6 -4519)) (-4 *1 (-499 *3)) (-4 *3 (-1195)) (-5 *2 (-634 *3)))) (-1979 (*1 *2 *1) (-12 (|has| *1 (-6 -4519)) (-4 *1 (-499 *3)) (-4 *3 (-1195)) (-5 *2 (-634 *3)))) (-4168 (*1 *2 *3 *1) (-12 (|has| *1 (-6 -4519)) (-4 *1 (-499 *3)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-763)))) (-3109 (*1 *2 *3 *1) (-12 (|has| *1 (-6 -4519)) (-4 *1 (-499 *3)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-121))))) 
-(-13 (-39) (-10 -8 (IF (|has| |t#1| (-1090)) (-6 (-1090)) |noBranch|) (IF (|has| |t#1| (-1090)) (IF (|has| |t#1| (-303 |t#1|)) (-6 (-303 |t#1|)) |noBranch|) |noBranch|) (-15 -2795 ($ (-1 |t#1| |t#1|) $)) (IF (|has| $ (-6 -4520)) (-15 -3674 ($ (-1 |t#1| |t#1|) $)) |noBranch|) (IF (|has| $ (-6 -4519)) (PROGN (-15 -1319 ((-121) (-1 (-121) |t#1|) $)) (-15 -1387 ((-121) (-1 (-121) |t#1|) $)) (-15 -4168 ((-763) (-1 (-121) |t#1|) $)) (-15 -4360 ((-634 |t#1|) $)) (-15 -1979 ((-634 |t#1|) $)) (IF (|has| |t#1| (-1090)) (PROGN (-15 -4168 ((-763) |t#1| $)) (-15 -3109 ((-121) |t#1| $))) |noBranch|)) |noBranch|))) 
+((-2797 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-499 *3)) (-4 *3 (-1195)))) (-2253 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| *1 (-6 -4522)) (-4 *1 (-499 *3)) (-4 *3 (-1195)))) (-3437 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| *1 (-6 -4521)) (-4 *1 (-499 *4)) (-4 *4 (-1195)) (-5 *2 (-121)))) (-3951 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| *1 (-6 -4521)) (-4 *1 (-499 *4)) (-4 *4 (-1195)) (-5 *2 (-121)))) (-4170 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| *1 (-6 -4521)) (-4 *1 (-499 *4)) (-4 *4 (-1195)) (-5 *2 (-763)))) (-3317 (*1 *2 *1) (-12 (|has| *1 (-6 -4521)) (-4 *1 (-499 *3)) (-4 *3 (-1195)) (-5 *2 (-634 *3)))) (-4406 (*1 *2 *1) (-12 (|has| *1 (-6 -4521)) (-4 *1 (-499 *3)) (-4 *3 (-1195)) (-5 *2 (-634 *3)))) (-4170 (*1 *2 *3 *1) (-12 (|has| *1 (-6 -4521)) (-4 *1 (-499 *3)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-763)))) (-2551 (*1 *2 *3 *1) (-12 (|has| *1 (-6 -4521)) (-4 *1 (-499 *3)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-121))))) 
+(-13 (-39) (-10 -8 (IF (|has| |t#1| (-1090)) (-6 (-1090)) |noBranch|) (IF (|has| |t#1| (-1090)) (IF (|has| |t#1| (-303 |t#1|)) (-6 (-303 |t#1|)) |noBranch|) |noBranch|) (-15 -2797 ($ (-1 |t#1| |t#1|) $)) (IF (|has| $ (-6 -4522)) (-15 -2253 ($ (-1 |t#1| |t#1|) $)) |noBranch|) (IF (|has| $ (-6 -4521)) (PROGN (-15 -3437 ((-121) (-1 (-121) |t#1|) $)) (-15 -3951 ((-121) (-1 (-121) |t#1|) $)) (-15 -4170 ((-763) (-1 (-121) |t#1|) $)) (-15 -3317 ((-634 |t#1|) $)) (-15 -4406 ((-634 |t#1|) $)) (IF (|has| |t#1| (-1090)) (PROGN (-15 -4170 ((-763) |t#1| $)) (-15 -2551 ((-121) |t#1| $))) |noBranch|)) |noBranch|))) 
 (((-39) . T) ((-105) |has| |#1| (-1090)) ((-608 (-850)) |has| |#1| (-1090)) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-1090) |has| |#1| (-1090)) ((-1195) . T)) 
-((-2447 (((-121) $ $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-3253 (((-1143) (-850)) 40)) (-4125 (((-1249) (-1143)) 29)) (-3346 (((-1143) (-850)) 25)) (-2857 (((-1143) (-850)) 26)) (-2745 (((-850) $) NIL) (((-1143) (-850)) 24)) (-1717 (((-121) $ $) NIL))) 
-(((-500) (-13 (-1090) (-10 -7 (-15 -2745 ((-1143) (-850))) (-15 -3346 ((-1143) (-850))) (-15 -2857 ((-1143) (-850))) (-15 -3253 ((-1143) (-850))) (-15 -4125 ((-1249) (-1143)))))) (T -500)) 
-((-2745 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-500)))) (-3346 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-500)))) (-2857 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-500)))) (-3253 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-500)))) (-4125 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-500))))) 
-(-13 (-1090) (-10 -7 (-15 -2745 ((-1143) (-850))) (-15 -3346 ((-1143) (-850))) (-15 -2857 ((-1143) (-850))) (-15 -3253 ((-1143) (-850))) (-15 -4125 ((-1249) (-1143))))) 
-((-1982 (($ $) 15)) (-1974 (($ $) 24)) (-1990 (($ $) 12)) (-1994 (($ $) 10)) (-1986 (($ $) 17)) (-1978 (($ $) 22))) 
-(((-501 |#1|) (-10 -8 (-15 -1978 (|#1| |#1|)) (-15 -1986 (|#1| |#1|)) (-15 -1994 (|#1| |#1|)) (-15 -1990 (|#1| |#1|)) (-15 -1974 (|#1| |#1|)) (-15 -1982 (|#1| |#1|))) (-502)) (T -501)) 
-NIL 
-(-10 -8 (-15 -1978 (|#1| |#1|)) (-15 -1986 (|#1| |#1|)) (-15 -1994 (|#1| |#1|)) (-15 -1990 (|#1| |#1|)) (-15 -1974 (|#1| |#1|)) (-15 -1982 (|#1| |#1|))) 
-((-1982 (($ $) 11)) (-1974 (($ $) 10)) (-1990 (($ $) 9)) (-1994 (($ $) 8)) (-1986 (($ $) 7)) (-1978 (($ $) 6))) 
+((-2449 (((-121) $ $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2002 (((-1143) (-850)) 40)) (-4127 (((-1249) (-1143)) 29)) (-4481 (((-1143) (-850)) 25)) (-4010 (((-1143) (-850)) 26)) (-2747 (((-850) $) NIL) (((-1143) (-850)) 24)) (-1719 (((-121) $ $) NIL))) 
+(((-500) (-13 (-1090) (-10 -7 (-15 -2747 ((-1143) (-850))) (-15 -4481 ((-1143) (-850))) (-15 -4010 ((-1143) (-850))) (-15 -2002 ((-1143) (-850))) (-15 -4127 ((-1249) (-1143)))))) (T -500)) 
+((-2747 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-500)))) (-4481 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-500)))) (-4010 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-500)))) (-2002 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-500)))) (-4127 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-500))))) 
+(-13 (-1090) (-10 -7 (-15 -2747 ((-1143) (-850))) (-15 -4481 ((-1143) (-850))) (-15 -4010 ((-1143) (-850))) (-15 -2002 ((-1143) (-850))) (-15 -4127 ((-1249) (-1143))))) 
+((-1984 (($ $) 15)) (-1976 (($ $) 24)) (-1992 (($ $) 12)) (-1996 (($ $) 10)) (-1988 (($ $) 17)) (-1980 (($ $) 22))) 
+(((-501 |#1|) (-10 -8 (-15 -1980 (|#1| |#1|)) (-15 -1988 (|#1| |#1|)) (-15 -1996 (|#1| |#1|)) (-15 -1992 (|#1| |#1|)) (-15 -1976 (|#1| |#1|)) (-15 -1984 (|#1| |#1|))) (-502)) (T -501)) 
+NIL 
+(-10 -8 (-15 -1980 (|#1| |#1|)) (-15 -1988 (|#1| |#1|)) (-15 -1996 (|#1| |#1|)) (-15 -1992 (|#1| |#1|)) (-15 -1976 (|#1| |#1|)) (-15 -1984 (|#1| |#1|))) 
+((-1984 (($ $) 11)) (-1976 (($ $) 10)) (-1992 (($ $) 9)) (-1996 (($ $) 8)) (-1988 (($ $) 7)) (-1980 (($ $) 6))) 
 (((-502) (-1275)) (T -502)) 
-((-1982 (*1 *1 *1) (-4 *1 (-502))) (-1974 (*1 *1 *1) (-4 *1 (-502))) (-1990 (*1 *1 *1) (-4 *1 (-502))) (-1994 (*1 *1 *1) (-4 *1 (-502))) (-1986 (*1 *1 *1) (-4 *1 (-502))) (-1978 (*1 *1 *1) (-4 *1 (-502)))) 
-(-13 (-10 -8 (-15 -1978 ($ $)) (-15 -1986 ($ $)) (-15 -1994 ($ $)) (-15 -1990 ($ $)) (-15 -1974 ($ $)) (-15 -1982 ($ $)))) 
-((-3848 (((-420 |#4|) |#4| (-1 (-420 |#2|) |#2|)) 42))) 
-(((-503 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3848 ((-420 |#4|) |#4| (-1 (-420 |#2|) |#2|)))) (-365) (-1219 |#1|) (-13 (-365) (-150) (-714 |#1| |#2|)) (-1219 |#3|)) (T -503)) 
-((-3848 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-420 *6) *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-4 *7 (-13 (-365) (-150) (-714 *5 *6))) (-5 *2 (-420 *3)) (-5 *1 (-503 *5 *6 *7 *3)) (-4 *3 (-1219 *7))))) 
-(-10 -7 (-15 -3848 ((-420 |#4|) |#4| (-1 (-420 |#2|) |#2|)))) 
-((-2447 (((-121) $ $) NIL)) (-2394 (((-634 $) (-1157 $) (-1161)) NIL) (((-634 $) (-1157 $)) NIL) (((-634 $) (-953 $)) NIL)) (-1681 (($ (-1157 $) (-1161)) NIL) (($ (-1157 $)) NIL) (($ (-953 $)) NIL)) (-2537 (((-121) $) 36)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-1836 (((-121) $ $) 62)) (-3001 (((-634 (-607 $)) $) 46)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2366 (($ $ (-288 $)) NIL) (($ $ (-634 (-288 $))) NIL) (($ $ (-634 (-607 $)) (-634 $)) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1902 (($ $) NIL)) (-1497 (((-121) $ $) NIL)) (-2671 (($) NIL T CONST)) (-3214 (((-634 $) (-1157 $) (-1161)) NIL) (((-634 $) (-1157 $)) NIL) (((-634 $) (-953 $)) NIL)) (-2932 (($ (-1157 $) (-1161)) NIL) (($ (-1157 $)) NIL) (($ (-953 $)) NIL)) (-3666 (((-3 (-607 $) "failed") $) NIL) (((-3 (-568) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL)) (-2854 (((-607 $) $) NIL) (((-568) $) NIL) (((-409 (-568)) $) 48)) (-2401 (($ $ $) NIL)) (-3164 (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-679 (-568)) (-679 $)) NIL) (((-2 (|:| -2928 (-679 (-409 (-568)))) (|:| |vec| (-1244 (-409 (-568))))) (-679 $) (-1244 $)) NIL) (((-679 (-409 (-568))) (-679 $)) NIL)) (-3092 (($ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-4499 (($ $) NIL) (($ (-634 $)) NIL)) (-3296 (((-634 (-123)) $) NIL)) (-3488 (((-123) (-123)) NIL)) (-2735 (((-121) $) 39)) (-1825 (((-121) $) NIL (|has| $ (-1037 (-568))))) (-2317 (((-1113 (-568) (-607 $)) $) 34)) (-4044 (($ $ (-568)) NIL)) (-2657 (((-1157 $) (-1157 $) (-607 $)) 77) (((-1157 $) (-1157 $) (-634 (-607 $))) 53) (($ $ (-607 $)) 66) (($ $ (-634 (-607 $))) 67)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3007 (((-1157 $) (-607 $)) 64 (|has| $ (-1047)))) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-2795 (($ (-1 $ $) (-607 $)) NIL)) (-3693 (((-3 (-607 $) "failed") $) NIL)) (-2495 (($ (-634 $)) NIL) (($ $ $) NIL)) (-4487 (((-1143) $) NIL)) (-3804 (((-634 (-607 $)) $) NIL)) (-3443 (($ (-123) $) NIL) (($ (-123) (-634 $)) NIL)) (-2841 (((-121) $ (-123)) NIL) (((-121) $ (-1161)) NIL)) (-2081 (($ $) NIL)) (-2961 (((-763) $) NIL)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ (-634 $)) NIL) (($ $ $) NIL)) (-4059 (((-121) $ $) NIL) (((-121) $ (-1161)) NIL)) (-3848 (((-420 $) $) NIL)) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3277 (((-121) $) NIL (|has| $ (-1037 (-568))))) (-1339 (($ $ (-607 $) $) NIL) (($ $ (-634 (-607 $)) (-634 $)) NIL) (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ $))) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-1161) (-1 $ (-634 $))) NIL) (($ $ (-1161) (-1 $ $)) NIL) (($ $ (-634 (-123)) (-634 (-1 $ $))) NIL) (($ $ (-634 (-123)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-123) (-1 $ (-634 $))) NIL) (($ $ (-123) (-1 $ $)) NIL)) (-2709 (((-763) $) NIL)) (-2779 (($ (-123) $) NIL) (($ (-123) $ $) NIL) (($ (-123) $ $ $) NIL) (($ (-123) $ $ $ $) NIL) (($ (-123) (-634 $)) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3502 (($ $) NIL) (($ $ $) NIL)) (-4189 (($ $ (-763)) NIL) (($ $) 33)) (-2324 (((-1113 (-568) (-607 $)) $) 17)) (-1626 (($ $) NIL (|has| $ (-1047)))) (-4278 (((-381) $) 91) (((-215) $) 99) (((-169 (-381)) $) 107)) (-2745 (((-850) $) NIL) (($ (-607 $)) NIL) (($ (-409 (-568))) NIL) (($ $) NIL) (($ (-568)) NIL) (($ (-1113 (-568) (-607 $))) 18)) (-4078 (((-763)) NIL)) (-2092 (($ $) NIL) (($ (-634 $)) NIL)) (-2887 (((-121) (-123)) 83)) (-1826 (((-121) $ $) NIL)) (-1887 (($ $ (-568)) NIL) (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (-3056 (($) 9 T CONST)) (-1556 (($) 19 T CONST)) (-3190 (($ $ (-763)) NIL) (($ $) NIL)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 21)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) NIL)) (-1779 (($ $ $) 41)) (-1773 (($ $ $) NIL) (($ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-409 (-568))) NIL) (($ $ (-568)) 44) (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (* (($ (-409 (-568)) $) NIL) (($ $ (-409 (-568))) NIL) (($ $ $) 24) (($ (-568) $) NIL) (($ (-763) $) NIL) (($ (-917) $) NIL))) 
-(((-504) (-13 (-296) (-27) (-1037 (-568)) (-1037 (-409 (-568))) (-630 (-568)) (-1021) (-630 (-409 (-568))) (-150) (-609 (-169 (-381))) (-225) (-10 -8 (-15 -2745 ($ (-1113 (-568) (-607 $)))) (-15 -2317 ((-1113 (-568) (-607 $)) $)) (-15 -2324 ((-1113 (-568) (-607 $)) $)) (-15 -3092 ($ $)) (-15 -1836 ((-121) $ $)) (-15 -2657 ((-1157 $) (-1157 $) (-607 $))) (-15 -2657 ((-1157 $) (-1157 $) (-634 (-607 $)))) (-15 -2657 ($ $ (-607 $))) (-15 -2657 ($ $ (-634 (-607 $))))))) (T -504)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1113 (-568) (-607 (-504)))) (-5 *1 (-504)))) (-2317 (*1 *2 *1) (-12 (-5 *2 (-1113 (-568) (-607 (-504)))) (-5 *1 (-504)))) (-2324 (*1 *2 *1) (-12 (-5 *2 (-1113 (-568) (-607 (-504)))) (-5 *1 (-504)))) (-3092 (*1 *1 *1) (-5 *1 (-504))) (-1836 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-504)))) (-2657 (*1 *2 *2 *3) (-12 (-5 *2 (-1157 (-504))) (-5 *3 (-607 (-504))) (-5 *1 (-504)))) (-2657 (*1 *2 *2 *3) (-12 (-5 *2 (-1157 (-504))) (-5 *3 (-634 (-607 (-504)))) (-5 *1 (-504)))) (-2657 (*1 *1 *1 *2) (-12 (-5 *2 (-607 (-504))) (-5 *1 (-504)))) (-2657 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-607 (-504)))) (-5 *1 (-504))))) 
-(-13 (-296) (-27) (-1037 (-568)) (-1037 (-409 (-568))) (-630 (-568)) (-1021) (-630 (-409 (-568))) (-150) (-609 (-169 (-381))) (-225) (-10 -8 (-15 -2745 ($ (-1113 (-568) (-607 $)))) (-15 -2317 ((-1113 (-568) (-607 $)) $)) (-15 -2324 ((-1113 (-568) (-607 $)) $)) (-15 -3092 ($ $)) (-15 -1836 ((-121) $ $)) (-15 -2657 ((-1157 $) (-1157 $) (-607 $))) (-15 -2657 ((-1157 $) (-1157 $) (-634 (-607 $)))) (-15 -2657 ($ $ (-607 $))) (-15 -2657 ($ $ (-634 (-607 $)))))) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-2016 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-842)))) (-3908 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4520))) (($ $) NIL (-12 (|has| $ (-6 -4520)) (|has| |#1| (-842))))) (-3644 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-842)))) (-2510 (((-121) $ (-763)) NIL)) (-2436 ((|#1| $ (-568) |#1|) 25 (|has| $ (-6 -4520))) ((|#1| $ (-1210 (-568)) |#1|) NIL (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-2671 (($) NIL T CONST)) (-1578 (($ $) NIL (|has| $ (-6 -4520)))) (-3943 (($ $) NIL)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-4328 (($ |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4519)))) (-3989 ((|#1| $ (-568) |#1|) 22 (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-568)) 21)) (-2764 (((-568) (-1 (-121) |#1|) $) NIL) (((-568) |#1| $) NIL (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) NIL (|has| |#1| (-1090)))) (-4360 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-1849 (($ (-763) |#1|) 14)) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) 12 (|has| (-568) (-842)))) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-1347 (($ (-1 (-121) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-842)))) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2223 (((-568) $) 23 (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-3674 (($ (-1 |#1| |#1|) $) 16 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 17) (($ (-1 |#1| |#1| |#1|) $ $) 19)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4122 (($ |#1| $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3876 ((|#1| $) NIL (|has| (-568) (-842)))) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3724 (($ $ |#1|) 10 (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) 13)) (-2779 ((|#1| $ (-568) |#1|) NIL) ((|#1| $ (-568)) 24) (($ $ (-1210 (-568))) NIL)) (-2826 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2256 (($ $ $ (-568)) NIL (|has| $ (-6 -4520)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) NIL)) (-2768 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-634 $)) NIL)) (-2745 (((-850) $) NIL (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1697 (((-763) $) 9 (|has| $ (-6 -4519))))) 
+((-1984 (*1 *1 *1) (-4 *1 (-502))) (-1976 (*1 *1 *1) (-4 *1 (-502))) (-1992 (*1 *1 *1) (-4 *1 (-502))) (-1996 (*1 *1 *1) (-4 *1 (-502))) (-1988 (*1 *1 *1) (-4 *1 (-502))) (-1980 (*1 *1 *1) (-4 *1 (-502)))) 
+(-13 (-10 -8 (-15 -1980 ($ $)) (-15 -1988 ($ $)) (-15 -1996 ($ $)) (-15 -1992 ($ $)) (-15 -1976 ($ $)) (-15 -1984 ($ $)))) 
+((-3850 (((-420 |#4|) |#4| (-1 (-420 |#2|) |#2|)) 42))) 
+(((-503 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3850 ((-420 |#4|) |#4| (-1 (-420 |#2|) |#2|)))) (-365) (-1219 |#1|) (-13 (-365) (-150) (-714 |#1| |#2|)) (-1219 |#3|)) (T -503)) 
+((-3850 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-420 *6) *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-4 *7 (-13 (-365) (-150) (-714 *5 *6))) (-5 *2 (-420 *3)) (-5 *1 (-503 *5 *6 *7 *3)) (-4 *3 (-1219 *7))))) 
+(-10 -7 (-15 -3850 ((-420 |#4|) |#4| (-1 (-420 |#2|) |#2|)))) 
+((-2449 (((-121) $ $) NIL)) (-2251 (((-634 $) (-1157 $) (-1161)) NIL) (((-634 $) (-1157 $)) NIL) (((-634 $) (-953 $)) NIL)) (-3505 (($ (-1157 $) (-1161)) NIL) (($ (-1157 $)) NIL) (($ (-953 $)) NIL)) (-1819 (((-121) $) 36)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2328 (((-121) $ $) 62)) (-3145 (((-634 (-607 $)) $) 46)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4069 (($ $ (-288 $)) NIL) (($ $ (-634 (-288 $))) NIL) (($ $ (-634 (-607 $)) (-634 $)) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-1904 (($ $) NIL)) (-2589 (((-121) $ $) NIL)) (-4490 (($) NIL T CONST)) (-1867 (((-634 $) (-1157 $) (-1161)) NIL) (((-634 $) (-1157 $)) NIL) (((-634 $) (-953 $)) NIL)) (-2919 (($ (-1157 $) (-1161)) NIL) (($ (-1157 $)) NIL) (($ (-953 $)) NIL)) (-3668 (((-3 (-607 $) "failed") $) NIL) (((-3 (-568) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL)) (-2857 (((-607 $) $) NIL) (((-568) $) NIL) (((-409 (-568)) $) 48)) (-2403 (($ $ $) NIL)) (-1668 (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-679 (-568)) (-679 $)) NIL) (((-2 (|:| -2908 (-679 (-409 (-568)))) (|:| |vec| (-1244 (-409 (-568))))) (-679 $) (-1244 $)) NIL) (((-679 (-409 (-568))) (-679 $)) NIL)) (-3094 (($ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-3855 (($ $) NIL) (($ (-634 $)) NIL)) (-2160 (((-634 (-123)) $) NIL)) (-3842 (((-123) (-123)) NIL)) (-1598 (((-121) $) 39)) (-2268 (((-121) $) NIL (|has| $ (-1037 (-568))))) (-2319 (((-1113 (-568) (-607 $)) $) 34)) (-1550 (($ $ (-568)) NIL)) (-4417 (((-1157 $) (-1157 $) (-607 $)) 77) (((-1157 $) (-1157 $) (-634 (-607 $))) 53) (($ $ (-607 $)) 66) (($ $ (-634 (-607 $))) 67)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3170 (((-1157 $) (-607 $)) 64 (|has| $ (-1047)))) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-2797 (($ (-1 $ $) (-607 $)) NIL)) (-2337 (((-3 (-607 $) "failed") $) NIL)) (-2498 (($ (-634 $)) NIL) (($ $ $) NIL)) (-1893 (((-1143) $) NIL)) (-3832 (((-634 (-607 $)) $) NIL)) (-3446 (($ (-123) $) NIL) (($ (-123) (-634 $)) NIL)) (-3910 (((-121) $ (-123)) NIL) (((-121) $ (-1161)) NIL)) (-2083 (($ $) NIL)) (-2963 (((-763) $) NIL)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ (-634 $)) NIL) (($ $ $) NIL)) (-1609 (((-121) $ $) NIL) (((-121) $ (-1161)) NIL)) (-3850 (((-420 $) $) NIL)) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2080 (((-121) $) NIL (|has| $ (-1037 (-568))))) (-1339 (($ $ (-607 $) $) NIL) (($ $ (-634 (-607 $)) (-634 $)) NIL) (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ $))) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-1161) (-1 $ (-634 $))) NIL) (($ $ (-1161) (-1 $ $)) NIL) (($ $ (-634 (-123)) (-634 (-1 $ $))) NIL) (($ $ (-634 (-123)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-123) (-1 $ (-634 $))) NIL) (($ $ (-123) (-1 $ $)) NIL)) (-1466 (((-763) $) NIL)) (-2781 (($ (-123) $) NIL) (($ (-123) $ $) NIL) (($ (-123) $ $ $) NIL) (($ (-123) $ $ $ $) NIL) (($ (-123) (-634 $)) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-3924 (($ $) NIL) (($ $ $) NIL)) (-4191 (($ $ (-763)) NIL) (($ $) 33)) (-2326 (((-1113 (-568) (-607 $)) $) 17)) (-1492 (($ $) NIL (|has| $ (-1047)))) (-4280 (((-381) $) 91) (((-215) $) 99) (((-169 (-381)) $) 107)) (-2747 (((-850) $) NIL) (($ (-607 $)) NIL) (($ (-409 (-568))) NIL) (($ $) NIL) (($ (-568)) NIL) (($ (-1113 (-568) (-607 $))) 18)) (-3425 (((-763)) NIL)) (-3159 (($ $) NIL) (($ (-634 $)) NIL)) (-2779 (((-121) (-123)) 83)) (-2273 (((-121) $ $) NIL)) (-1889 (($ $ (-568)) NIL) (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (-3058 (($) 9 T CONST)) (-1557 (($) 19 T CONST)) (-3192 (($ $ (-763)) NIL) (($ $) NIL)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 21)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) NIL)) (-1781 (($ $ $) 41)) (-1775 (($ $ $) NIL) (($ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-409 (-568))) NIL) (($ $ (-568)) 44) (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (* (($ (-409 (-568)) $) NIL) (($ $ (-409 (-568))) NIL) (($ $ $) 24) (($ (-568) $) NIL) (($ (-763) $) NIL) (($ (-917) $) NIL))) 
+(((-504) (-13 (-296) (-27) (-1037 (-568)) (-1037 (-409 (-568))) (-630 (-568)) (-1021) (-630 (-409 (-568))) (-150) (-609 (-169 (-381))) (-225) (-10 -8 (-15 -2747 ($ (-1113 (-568) (-607 $)))) (-15 -2319 ((-1113 (-568) (-607 $)) $)) (-15 -2326 ((-1113 (-568) (-607 $)) $)) (-15 -3094 ($ $)) (-15 -2328 ((-121) $ $)) (-15 -4417 ((-1157 $) (-1157 $) (-607 $))) (-15 -4417 ((-1157 $) (-1157 $) (-634 (-607 $)))) (-15 -4417 ($ $ (-607 $))) (-15 -4417 ($ $ (-634 (-607 $))))))) (T -504)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1113 (-568) (-607 (-504)))) (-5 *1 (-504)))) (-2319 (*1 *2 *1) (-12 (-5 *2 (-1113 (-568) (-607 (-504)))) (-5 *1 (-504)))) (-2326 (*1 *2 *1) (-12 (-5 *2 (-1113 (-568) (-607 (-504)))) (-5 *1 (-504)))) (-3094 (*1 *1 *1) (-5 *1 (-504))) (-2328 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-504)))) (-4417 (*1 *2 *2 *3) (-12 (-5 *2 (-1157 (-504))) (-5 *3 (-607 (-504))) (-5 *1 (-504)))) (-4417 (*1 *2 *2 *3) (-12 (-5 *2 (-1157 (-504))) (-5 *3 (-634 (-607 (-504)))) (-5 *1 (-504)))) (-4417 (*1 *1 *1 *2) (-12 (-5 *2 (-607 (-504))) (-5 *1 (-504)))) (-4417 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-607 (-504)))) (-5 *1 (-504))))) 
+(-13 (-296) (-27) (-1037 (-568)) (-1037 (-409 (-568))) (-630 (-568)) (-1021) (-630 (-409 (-568))) (-150) (-609 (-169 (-381))) (-225) (-10 -8 (-15 -2747 ($ (-1113 (-568) (-607 $)))) (-15 -2319 ((-1113 (-568) (-607 $)) $)) (-15 -2326 ((-1113 (-568) (-607 $)) $)) (-15 -3094 ($ $)) (-15 -2328 ((-121) $ $)) (-15 -4417 ((-1157 $) (-1157 $) (-607 $))) (-15 -4417 ((-1157 $) (-1157 $) (-634 (-607 $)))) (-15 -4417 ($ $ (-607 $))) (-15 -4417 ($ $ (-634 (-607 $)))))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-1324 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-842)))) (-2109 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4522))) (($ $) NIL (-12 (|has| $ (-6 -4522)) (|has| |#1| (-842))))) (-3647 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-842)))) (-1667 (((-121) $ (-763)) NIL)) (-2438 ((|#1| $ (-568) |#1|) 25 (|has| $ (-6 -4522))) ((|#1| $ (-1210 (-568)) |#1|) NIL (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-4490 (($) NIL T CONST)) (-4452 (($ $) NIL (|has| $ (-6 -4522)))) (-3945 (($ $) NIL)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-4330 (($ |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4521)))) (-1292 ((|#1| $ (-568) |#1|) 22 (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-568)) 21)) (-2766 (((-568) (-1 (-121) |#1|) $) NIL) (((-568) |#1| $) NIL (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) NIL (|has| |#1| (-1090)))) (-3317 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-1851 (($ (-763) |#1|) 14)) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) 12 (|has| (-568) (-842)))) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-3645 (($ (-1 (-121) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-842)))) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3631 (((-568) $) 23 (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-2253 (($ (-1 |#1| |#1|) $) 16 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 17) (($ (-1 |#1| |#1| |#1|) $ $) 19)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4124 (($ |#1| $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3877 ((|#1| $) NIL (|has| (-568) (-842)))) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-2490 (($ $ |#1|) 10 (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) 13)) (-2781 ((|#1| $ (-568) |#1|) NIL) ((|#1| $ (-568)) 24) (($ $ (-1210 (-568))) NIL)) (-2828 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3306 (($ $ $ (-568)) NIL (|has| $ (-6 -4522)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) NIL)) (-2770 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-634 $)) NIL)) (-2747 (((-850) $) NIL (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1699 (((-763) $) 9 (|has| $ (-6 -4521))))) 
 (((-505 |#1| |#2|) (-19 |#1|) (-1195) (-568)) (T -505)) 
 NIL 
 (-19 |#1|) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2510 (((-121) $ (-763)) NIL)) (-2436 ((|#1| $ (-568) (-568) |#1|) NIL)) (-4159 (($ $ (-568) (-505 |#1| |#3|)) NIL)) (-2451 (($ $ (-568) (-505 |#1| |#2|)) NIL)) (-2671 (($) NIL T CONST)) (-1818 (((-505 |#1| |#3|) $ (-568)) NIL)) (-3989 ((|#1| $ (-568) (-568) |#1|) NIL)) (-2602 ((|#1| $ (-568) (-568)) NIL)) (-4360 (((-634 |#1|) $) NIL)) (-3043 (((-763) $) NIL)) (-1849 (($ (-763) (-763) |#1|) NIL)) (-2555 (((-763) $) NIL)) (-1737 (((-121) $ (-763)) NIL)) (-2087 (((-568) $) NIL)) (-3364 (((-568) $) NIL)) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-1663 (((-568) $) NIL)) (-2893 (((-568) $) NIL)) (-3674 (($ (-1 |#1| |#1|) $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3724 (($ $ |#1|) NIL)) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#1| $ (-568) (-568)) NIL) ((|#1| $ (-568) (-568) |#1|) NIL)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) NIL)) (-3731 (((-505 |#1| |#2|) $ (-568)) NIL)) (-2745 (((-850) $) NIL (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1667 (((-121) $ (-763)) NIL)) (-2438 ((|#1| $ (-568) (-568) |#1|) NIL)) (-3874 (($ $ (-568) (-505 |#1| |#3|)) NIL)) (-2525 (($ $ (-568) (-505 |#1| |#2|)) NIL)) (-4490 (($) NIL T CONST)) (-2228 (((-505 |#1| |#3|) $ (-568)) NIL)) (-1292 ((|#1| $ (-568) (-568) |#1|) NIL)) (-2069 ((|#1| $ (-568) (-568)) NIL)) (-3317 (((-634 |#1|) $) NIL)) (-2241 (((-763) $) NIL)) (-1851 (($ (-763) (-763) |#1|) NIL)) (-1901 (((-763) $) NIL)) (-3791 (((-121) $ (-763)) NIL)) (-3139 (((-568) $) NIL)) (-1343 (((-568) $) NIL)) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3405 (((-568) $) NIL)) (-2801 (((-568) $) NIL)) (-2253 (($ (-1 |#1| |#1|) $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-2490 (($ $ |#1|) NIL)) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#1| $ (-568) (-568)) NIL) ((|#1| $ (-568) (-568) |#1|) NIL)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) NIL)) (-2522 (((-505 |#1| |#2|) $ (-568)) NIL)) (-2747 (((-850) $) NIL (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
 (((-506 |#1| |#2| |#3|) (-62 |#1| (-505 |#1| |#3|) (-505 |#1| |#2|)) (-1195) (-568) (-568)) (T -506)) 
 NIL 
 (-62 |#1| (-505 |#1| |#3|) (-505 |#1| |#2|)) 
-((-3387 (((-634 (-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|)))) (-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) (-763) (-763)) 27)) (-1385 (((-634 (-1157 |#1|)) |#1| (-763) (-763) (-763)) 34)) (-2769 (((-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) (-634 |#3|) (-634 (-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|)))) (-763)) 83))) 
-(((-507 |#1| |#2| |#3|) (-10 -7 (-15 -1385 ((-634 (-1157 |#1|)) |#1| (-763) (-763) (-763))) (-15 -3387 ((-634 (-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|)))) (-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) (-763) (-763))) (-15 -2769 ((-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) (-634 |#3|) (-634 (-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|)))) (-763)))) (-350) (-1219 |#1|) (-1219 |#2|)) (T -507)) 
-((-2769 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 (-2 (|:| -3746 (-679 *7)) (|:| |basisDen| *7) (|:| |basisInv| (-679 *7))))) (-5 *5 (-763)) (-4 *8 (-1219 *7)) (-4 *7 (-1219 *6)) (-4 *6 (-350)) (-5 *2 (-2 (|:| -3746 (-679 *7)) (|:| |basisDen| *7) (|:| |basisInv| (-679 *7)))) (-5 *1 (-507 *6 *7 *8)))) (-3387 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-763)) (-4 *5 (-350)) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-2 (|:| -3746 (-679 *6)) (|:| |basisDen| *6) (|:| |basisInv| (-679 *6))))) (-5 *1 (-507 *5 *6 *7)) (-5 *3 (-2 (|:| -3746 (-679 *6)) (|:| |basisDen| *6) (|:| |basisInv| (-679 *6)))) (-4 *7 (-1219 *6)))) (-1385 (*1 *2 *3 *4 *4 *4) (-12 (-5 *4 (-763)) (-4 *3 (-350)) (-4 *5 (-1219 *3)) (-5 *2 (-634 (-1157 *3))) (-5 *1 (-507 *3 *5 *6)) (-4 *6 (-1219 *5))))) 
-(-10 -7 (-15 -1385 ((-634 (-1157 |#1|)) |#1| (-763) (-763) (-763))) (-15 -3387 ((-634 (-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|)))) (-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) (-763) (-763))) (-15 -2769 ((-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) (-634 |#3|) (-634 (-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|)))) (-763)))) 
-((-1350 (((-2 (|:| -3746 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|))) (-2 (|:| -3746 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|))) (-2 (|:| -3746 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|)))) 60)) (-4096 ((|#1| (-679 |#1|) |#1| (-763)) 25)) (-2061 (((-763) (-763) (-763)) 30)) (-2180 (((-679 |#1|) (-679 |#1|) (-679 |#1|)) 42)) (-3057 (((-679 |#1|) (-679 |#1|) (-679 |#1|) |#1|) 50) (((-679 |#1|) (-679 |#1|) (-679 |#1|)) 47)) (-3463 ((|#1| (-679 |#1|) (-679 |#1|) |#1| (-568)) 29)) (-3241 ((|#1| (-679 |#1|)) 18))) 
-(((-508 |#1| |#2| |#3|) (-10 -7 (-15 -3241 (|#1| (-679 |#1|))) (-15 -4096 (|#1| (-679 |#1|) |#1| (-763))) (-15 -3463 (|#1| (-679 |#1|) (-679 |#1|) |#1| (-568))) (-15 -2061 ((-763) (-763) (-763))) (-15 -3057 ((-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -3057 ((-679 |#1|) (-679 |#1|) (-679 |#1|) |#1|)) (-15 -2180 ((-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -1350 ((-2 (|:| -3746 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|))) (-2 (|:| -3746 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|))) (-2 (|:| -3746 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|)))))) (-13 (-301) (-10 -8 (-15 -1678 ((-420 $) $)))) (-1219 |#1|) (-411 |#1| |#2|)) (T -508)) 
-((-1350 (*1 *2 *2 *2) (-12 (-5 *2 (-2 (|:| -3746 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-4 *3 (-13 (-301) (-10 -8 (-15 -1678 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *1 (-508 *3 *4 *5)) (-4 *5 (-411 *3 *4)))) (-2180 (*1 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-13 (-301) (-10 -8 (-15 -1678 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *1 (-508 *3 *4 *5)) (-4 *5 (-411 *3 *4)))) (-3057 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-679 *3)) (-4 *3 (-13 (-301) (-10 -8 (-15 -1678 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *1 (-508 *3 *4 *5)) (-4 *5 (-411 *3 *4)))) (-3057 (*1 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-13 (-301) (-10 -8 (-15 -1678 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *1 (-508 *3 *4 *5)) (-4 *5 (-411 *3 *4)))) (-2061 (*1 *2 *2 *2) (-12 (-5 *2 (-763)) (-4 *3 (-13 (-301) (-10 -8 (-15 -1678 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *1 (-508 *3 *4 *5)) (-4 *5 (-411 *3 *4)))) (-3463 (*1 *2 *3 *3 *2 *4) (-12 (-5 *3 (-679 *2)) (-5 *4 (-568)) (-4 *2 (-13 (-301) (-10 -8 (-15 -1678 ((-420 $) $))))) (-4 *5 (-1219 *2)) (-5 *1 (-508 *2 *5 *6)) (-4 *6 (-411 *2 *5)))) (-4096 (*1 *2 *3 *2 *4) (-12 (-5 *3 (-679 *2)) (-5 *4 (-763)) (-4 *2 (-13 (-301) (-10 -8 (-15 -1678 ((-420 $) $))))) (-4 *5 (-1219 *2)) (-5 *1 (-508 *2 *5 *6)) (-4 *6 (-411 *2 *5)))) (-3241 (*1 *2 *3) (-12 (-5 *3 (-679 *2)) (-4 *4 (-1219 *2)) (-4 *2 (-13 (-301) (-10 -8 (-15 -1678 ((-420 $) $))))) (-5 *1 (-508 *2 *4 *5)) (-4 *5 (-411 *2 *4))))) 
-(-10 -7 (-15 -3241 (|#1| (-679 |#1|))) (-15 -4096 (|#1| (-679 |#1|) |#1| (-763))) (-15 -3463 (|#1| (-679 |#1|) (-679 |#1|) |#1| (-568))) (-15 -2061 ((-763) (-763) (-763))) (-15 -3057 ((-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -3057 ((-679 |#1|) (-679 |#1|) (-679 |#1|) |#1|)) (-15 -2180 ((-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -1350 ((-2 (|:| -3746 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|))) (-2 (|:| -3746 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|))) (-2 (|:| -3746 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|)))))) 
-((-2447 (((-121) $ $) NIL)) (-1611 (($ $) NIL)) (-3091 (($ $ $) 35)) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-2016 (((-121) $) NIL (|has| (-121) (-842))) (((-121) (-1 (-121) (-121) (-121)) $) NIL)) (-3908 (($ $) NIL (-12 (|has| $ (-6 -4520)) (|has| (-121) (-842)))) (($ (-1 (-121) (-121) (-121)) $) NIL (|has| $ (-6 -4520)))) (-3644 (($ $) NIL (|has| (-121) (-842))) (($ (-1 (-121) (-121) (-121)) $) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-2436 (((-121) $ (-1210 (-568)) (-121)) NIL (|has| $ (-6 -4520))) (((-121) $ (-568) (-121)) 36 (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4519)))) (-2671 (($) NIL T CONST)) (-1578 (($ $) NIL (|has| $ (-6 -4520)))) (-3943 (($ $) NIL)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-121) (-1090))))) (-4328 (($ (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4519))) (($ (-121) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-121) (-1090))))) (-3092 (((-121) (-1 (-121) (-121) (-121)) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) (-121) (-121)) $ (-121)) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) (-121) (-121)) $ (-121) (-121)) NIL (-12 (|has| $ (-6 -4519)) (|has| (-121) (-1090))))) (-3989 (((-121) $ (-568) (-121)) NIL (|has| $ (-6 -4520)))) (-2602 (((-121) $ (-568)) NIL)) (-2764 (((-568) (-121) $ (-568)) NIL (|has| (-121) (-1090))) (((-568) (-121) $) NIL (|has| (-121) (-1090))) (((-568) (-1 (-121) (-121)) $) NIL)) (-4360 (((-634 (-121)) $) NIL (|has| $ (-6 -4519)))) (-3104 (($ $ $) 33)) (-3044 (($ $) NIL)) (-2460 (($ $ $) NIL)) (-1849 (($ (-763) (-121)) 23)) (-3339 (($ $ $) NIL)) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) 8 (|has| (-568) (-842)))) (-2521 (($ $ $) NIL)) (-1347 (($ $ $) NIL (|has| (-121) (-842))) (($ (-1 (-121) (-121) (-121)) $ $) NIL)) (-1979 (((-634 (-121)) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) (-121) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-121) (-1090))))) (-2223 (((-568) $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL)) (-3674 (($ (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-121) (-121) (-121)) $ $) 30) (($ (-1 (-121) (-121)) $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL)) (-4122 (($ $ $ (-568)) NIL) (($ (-121) $ (-568)) NIL)) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4022 (((-1108) $) NIL)) (-3876 (((-121) $) NIL (|has| (-568) (-842)))) (-3775 (((-3 (-121) "failed") (-1 (-121) (-121)) $) NIL)) (-3724 (($ $ (-121)) NIL (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-121)) (-634 (-121))) NIL (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090)))) (($ $ (-121) (-121)) NIL (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090)))) (($ $ (-288 (-121))) NIL (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090)))) (($ $ (-634 (-288 (-121)))) NIL (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) (-121) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-121) (-1090))))) (-2041 (((-634 (-121)) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) 24)) (-2779 (($ $ (-1210 (-568))) NIL) (((-121) $ (-568)) 18) (((-121) $ (-568) (-121)) NIL)) (-2826 (($ $ (-1210 (-568))) NIL) (($ $ (-568)) NIL)) (-4168 (((-763) (-121) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-121) (-1090)))) (((-763) (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4519)))) (-2256 (($ $ $ (-568)) NIL (|has| $ (-6 -4520)))) (-3863 (($ $) 25)) (-4278 (((-541) $) NIL (|has| (-121) (-609 (-541))))) (-4287 (($ (-634 (-121))) NIL)) (-2768 (($ (-634 $)) NIL) (($ $ $) NIL) (($ (-121) $) NIL) (($ $ (-121)) NIL)) (-2745 (((-850) $) 22)) (-1319 (((-121) (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4519)))) (-2139 (($ $ $) 31)) (-1887 (($ $) NIL)) (-2430 (($ $ $) NIL)) (-3293 (($ $ $) 39)) (-3251 (($ $) 37)) (-3005 (($ $ $) 38)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 26)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 27)) (-2424 (($ $ $) NIL)) (-1697 (((-763) $) 10 (|has| $ (-6 -4519))))) 
-(((-509 |#1|) (-13 (-132) (-10 -8 (-15 -3251 ($ $)) (-15 -3293 ($ $ $)) (-15 -3005 ($ $ $)))) (-568)) (T -509)) 
-((-3251 (*1 *1 *1) (-12 (-5 *1 (-509 *2)) (-14 *2 (-568)))) (-3293 (*1 *1 *1 *1) (-12 (-5 *1 (-509 *2)) (-14 *2 (-568)))) (-3005 (*1 *1 *1 *1) (-12 (-5 *1 (-509 *2)) (-14 *2 (-568))))) 
-(-13 (-132) (-10 -8 (-15 -3251 ($ $)) (-15 -3293 ($ $ $)) (-15 -3005 ($ $ $)))) 
-((-1891 (((-3 |#2| "failed") (-1 (-3 |#1| "failed") |#4|) (-1157 |#4|)) 34)) (-1957 (((-1157 |#4|) (-1 |#4| |#1|) |#2|) 30) ((|#2| (-1 |#1| |#4|) (-1157 |#4|)) 21)) (-3808 (((-3 (-679 |#2|) "failed") (-1 (-3 |#1| "failed") |#4|) (-679 (-1157 |#4|))) 45)) (-2569 (((-1157 (-1157 |#4|)) (-1 |#4| |#1|) |#3|) 54))) 
-(((-510 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1957 (|#2| (-1 |#1| |#4|) (-1157 |#4|))) (-15 -1957 ((-1157 |#4|) (-1 |#4| |#1|) |#2|)) (-15 -1891 ((-3 |#2| "failed") (-1 (-3 |#1| "failed") |#4|) (-1157 |#4|))) (-15 -3808 ((-3 (-679 |#2|) "failed") (-1 (-3 |#1| "failed") |#4|) (-679 (-1157 |#4|)))) (-15 -2569 ((-1157 (-1157 |#4|)) (-1 |#4| |#1|) |#3|))) (-1047) (-1219 |#1|) (-1219 |#2|) (-1047)) (T -510)) 
-((-2569 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-1047)) (-4 *7 (-1047)) (-4 *6 (-1219 *5)) (-5 *2 (-1157 (-1157 *7))) (-5 *1 (-510 *5 *6 *4 *7)) (-4 *4 (-1219 *6)))) (-3808 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *5 "failed") *8)) (-5 *4 (-679 (-1157 *8))) (-4 *5 (-1047)) (-4 *8 (-1047)) (-4 *6 (-1219 *5)) (-5 *2 (-679 *6)) (-5 *1 (-510 *5 *6 *7 *8)) (-4 *7 (-1219 *6)))) (-1891 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *5 "failed") *7)) (-5 *4 (-1157 *7)) (-4 *5 (-1047)) (-4 *7 (-1047)) (-4 *2 (-1219 *5)) (-5 *1 (-510 *5 *2 *6 *7)) (-4 *6 (-1219 *2)))) (-1957 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-1047)) (-4 *7 (-1047)) (-4 *4 (-1219 *5)) (-5 *2 (-1157 *7)) (-5 *1 (-510 *5 *4 *6 *7)) (-4 *6 (-1219 *4)))) (-1957 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *5 *7)) (-5 *4 (-1157 *7)) (-4 *5 (-1047)) (-4 *7 (-1047)) (-4 *2 (-1219 *5)) (-5 *1 (-510 *5 *2 *6 *7)) (-4 *6 (-1219 *2))))) 
-(-10 -7 (-15 -1957 (|#2| (-1 |#1| |#4|) (-1157 |#4|))) (-15 -1957 ((-1157 |#4|) (-1 |#4| |#1|) |#2|)) (-15 -1891 ((-3 |#2| "failed") (-1 (-3 |#1| "failed") |#4|) (-1157 |#4|))) (-15 -3808 ((-3 (-679 |#2|) "failed") (-1 (-3 |#1| "failed") |#4|) (-679 (-1157 |#4|)))) (-15 -2569 ((-1157 (-1157 |#4|)) (-1 |#4| |#1|) |#3|))) 
-((-2447 (((-121) $ $) NIL)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-1352 (((-1249) $) 18)) (-2779 (((-1143) $ (-1161)) 22)) (-4125 (((-1249) $) 14)) (-2745 (((-850) $) 20) (($ (-1143)) 19)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 8)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 7))) 
-(((-511) (-13 (-842) (-10 -8 (-15 -2779 ((-1143) $ (-1161))) (-15 -4125 ((-1249) $)) (-15 -1352 ((-1249) $)) (-15 -2745 ($ (-1143)))))) (T -511)) 
-((-2779 (*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1143)) (-5 *1 (-511)))) (-4125 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-511)))) (-1352 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-511)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-511))))) 
-(-13 (-842) (-10 -8 (-15 -2779 ((-1143) $ (-1161))) (-15 -4125 ((-1249) $)) (-15 -1352 ((-1249) $)) (-15 -2745 ($ (-1143))))) 
-((-4114 (((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#4|) 19)) (-3093 ((|#1| |#4|) 10)) (-2469 ((|#3| |#4|) 17))) 
-(((-512 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3093 (|#1| |#4|)) (-15 -2469 (|#3| |#4|)) (-15 -4114 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#4|))) (-558) (-993 |#1|) (-375 |#1|) (-375 |#2|)) (T -512)) 
-((-4114 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-993 *4)) (-5 *2 (-2 (|:| |num| *6) (|:| |den| *4))) (-5 *1 (-512 *4 *5 *6 *3)) (-4 *6 (-375 *4)) (-4 *3 (-375 *5)))) (-2469 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-993 *4)) (-4 *2 (-375 *4)) (-5 *1 (-512 *4 *5 *2 *3)) (-4 *3 (-375 *5)))) (-3093 (*1 *2 *3) (-12 (-4 *4 (-993 *2)) (-4 *2 (-558)) (-5 *1 (-512 *2 *4 *5 *3)) (-4 *5 (-375 *2)) (-4 *3 (-375 *4))))) 
-(-10 -7 (-15 -3093 (|#1| |#4|)) (-15 -2469 (|#3| |#4|)) (-15 -4114 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#4|))) 
-((-2447 (((-121) $ $) NIL)) (-4436 (((-1161) $) NIL)) (-1314 (((-763) $) NIL)) (-1467 (((-1161) $ (-1161)) NIL)) (-3470 (((-763) $ (-763)) NIL)) (-1600 (((-966 |#1|) $ (-966 |#1|)) NIL)) (-3393 (((-763) $ (-763)) NIL)) (-3675 (((-33 |#1|) $ (-33 |#1|)) NIL)) (-2247 (((-634 (-774 |#1|)) $ (-634 (-774 |#1|))) NIL)) (-4476 (((-236 (-921 |#1|)) $ (-236 (-921 |#1|))) NIL)) (-1398 (((-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) $ (-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|)) NIL)) (-3524 ((|#3| $ |#3|) NIL)) (-3642 (((-966 |#1|) $) NIL)) (-3807 (((-763) $) NIL)) (-3934 (((-33 |#1|) $) NIL)) (-2134 (((-634 (-774 |#1|)) $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-3936 (((-121) (-121)) NIL) (((-121)) NIL)) (-2184 (((-850) $) NIL)) (-4394 (((-236 (-921 |#1|)) $) NIL)) (-3206 (((-917) $) NIL)) (-4459 (((-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) $) NIL)) (-2373 (($ (-966 |#1|) (-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) (-33 |#1|) (-763) |#3| (-763) (-236 (-921 |#1|)) |#1| (-1161)) NIL) (($ (-966 |#1|) (-242 |#2| |#1|)) NIL)) (-2745 (((-850) $) NIL)) (-1378 ((|#3| $) NIL)) (-4248 ((|#1| $) NIL)) (-1717 (((-121) $ $) NIL))) 
-(((-513 |#1| |#2| |#3|) (-13 (-536 |#1| |#2| (-242 |#2| |#1|) (-232 (-1697 |#2|) (-763)) (-966 |#1|) (-774 |#1|) (-921 |#1|) (-236 (-921 |#1|)) |#3|) (-10 -8 (-15 -2184 ((-850) $)) (-15 -3936 ((-121) (-121))) (-15 -3936 ((-121))))) (-365) (-634 (-1161)) (-117)) (T -513)) 
-((-2184 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-513 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-3936 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-513 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-3936 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-513 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
-(-13 (-536 |#1| |#2| (-242 |#2| |#1|) (-232 (-1697 |#2|) (-763)) (-966 |#1|) (-774 |#1|) (-921 |#1|) (-236 (-921 |#1|)) |#3|) (-10 -8 (-15 -2184 ((-850) $)) (-15 -3936 ((-121) (-121))) (-15 -3936 ((-121))))) 
-((-2447 (((-121) $ $) NIL)) (-1396 (((-121) $ (-634 |#3|)) 101) (((-121) $) 102)) (-2537 (((-121) $) 144)) (-2528 (($ $ |#4|) 93) (($ $ |#4| (-634 |#3|)) 97)) (-4243 (((-1150 (-634 (-953 |#1|)) (-634 (-288 (-953 |#1|)))) (-634 |#4|)) 137 (|has| |#3| (-609 (-1161))))) (-3961 (($ $ $) 87) (($ $ |#4|) 85)) (-2735 (((-121) $) 143)) (-2750 (($ $) 105)) (-4487 (((-1143) $) NIL)) (-3212 (($ $ $) 79) (($ (-634 $)) 81)) (-4213 (((-121) |#4| $) 104)) (-1816 (((-121) $ $) 68)) (-1552 (($ (-634 |#4|)) 86)) (-4022 (((-1108) $) NIL)) (-1585 (($ (-634 |#4|)) 141)) (-1412 (((-121) $) 142)) (-2715 (($ $) 70)) (-2865 (((-634 |#4|) $) 55)) (-2321 (((-2 (|:| |mval| (-679 |#1|)) (|:| |invmval| (-679 |#1|)) (|:| |genIdeal| $)) $ (-634 |#3|)) NIL)) (-3018 (((-121) |#4| $) 73)) (-4321 (((-568) $ (-634 |#3|)) 106) (((-568) $) 107)) (-2745 (((-850) $) 140) (($ (-634 |#4|)) 82)) (-4405 (($ (-2 (|:| |mval| (-679 |#1|)) (|:| |invmval| (-679 |#1|)) (|:| |genIdeal| $))) NIL)) (-1717 (((-121) $ $) 69)) (-1767 (($ $ $) 89)) (** (($ $ (-763)) 92)) (* (($ $ $) 91))) 
-(((-514 |#1| |#2| |#3| |#4|) (-13 (-1090) (-10 -7 (-15 * ($ $ $)) (-15 ** ($ $ (-763))) (-15 -1767 ($ $ $)) (-15 -2735 ((-121) $)) (-15 -2537 ((-121) $)) (-15 -3018 ((-121) |#4| $)) (-15 -1816 ((-121) $ $)) (-15 -4213 ((-121) |#4| $)) (-15 -1396 ((-121) $ (-634 |#3|))) (-15 -1396 ((-121) $)) (-15 -3212 ($ $ $)) (-15 -3212 ($ (-634 $))) (-15 -3961 ($ $ $)) (-15 -3961 ($ $ |#4|)) (-15 -2715 ($ $)) (-15 -2321 ((-2 (|:| |mval| (-679 |#1|)) (|:| |invmval| (-679 |#1|)) (|:| |genIdeal| $)) $ (-634 |#3|))) (-15 -4405 ($ (-2 (|:| |mval| (-679 |#1|)) (|:| |invmval| (-679 |#1|)) (|:| |genIdeal| $)))) (-15 -4321 ((-568) $ (-634 |#3|))) (-15 -4321 ((-568) $)) (-15 -2750 ($ $)) (-15 -1552 ($ (-634 |#4|))) (-15 -1585 ($ (-634 |#4|))) (-15 -1412 ((-121) $)) (-15 -2865 ((-634 |#4|) $)) (-15 -2745 ($ (-634 |#4|))) (-15 -2528 ($ $ |#4|)) (-15 -2528 ($ $ |#4| (-634 |#3|))) (IF (|has| |#3| (-609 (-1161))) (-15 -4243 ((-1150 (-634 (-953 |#1|)) (-634 (-288 (-953 |#1|)))) (-634 |#4|))) |noBranch|))) (-365) (-788) (-842) (-950 |#1| |#2| |#3|)) (T -514)) 
-((* (*1 *1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) (-1767 (*1 *1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) (-2735 (*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) (-2537 (*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) (-3018 (*1 *2 *3 *1) (-12 (-4 *4 (-365)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *4 *5 *6 *3)) (-4 *3 (-950 *4 *5 *6)))) (-1816 (*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) (-4213 (*1 *2 *3 *1) (-12 (-4 *4 (-365)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *4 *5 *6 *3)) (-4 *3 (-950 *4 *5 *6)))) (-1396 (*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-842)) (-4 *4 (-365)) (-4 *5 (-788)) (-5 *2 (-121)) (-5 *1 (-514 *4 *5 *6 *7)) (-4 *7 (-950 *4 *5 *6)))) (-1396 (*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) (-3212 (*1 *1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) (-3212 (*1 *1 *2) (-12 (-5 *2 (-634 (-514 *3 *4 *5 *6))) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) (-3961 (*1 *1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) (-3961 (*1 *1 *1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *2)) (-4 *2 (-950 *3 *4 *5)))) (-2715 (*1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) (-2321 (*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-842)) (-4 *4 (-365)) (-4 *5 (-788)) (-5 *2 (-2 (|:| |mval| (-679 *4)) (|:| |invmval| (-679 *4)) (|:| |genIdeal| (-514 *4 *5 *6 *7)))) (-5 *1 (-514 *4 *5 *6 *7)) (-4 *7 (-950 *4 *5 *6)))) (-4405 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |mval| (-679 *3)) (|:| |invmval| (-679 *3)) (|:| |genIdeal| (-514 *3 *4 *5 *6)))) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) (-4321 (*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-842)) (-4 *4 (-365)) (-4 *5 (-788)) (-5 *2 (-568)) (-5 *1 (-514 *4 *5 *6 *7)) (-4 *7 (-950 *4 *5 *6)))) (-4321 (*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-568)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) (-2750 (*1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) (-1552 (*1 *1 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6)))) (-1585 (*1 *1 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6)))) (-1412 (*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) (-2865 (*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *6)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6)))) (-2528 (*1 *1 *1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *2)) (-4 *2 (-950 *3 *4 *5)))) (-2528 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-842)) (-4 *4 (-365)) (-4 *5 (-788)) (-5 *1 (-514 *4 *5 *6 *2)) (-4 *2 (-950 *4 *5 *6)))) (-4243 (*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-950 *4 *5 *6)) (-4 *6 (-609 (-1161))) (-4 *4 (-365)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1150 (-634 (-953 *4)) (-634 (-288 (-953 *4))))) (-5 *1 (-514 *4 *5 *6 *7))))) 
-(-13 (-1090) (-10 -7 (-15 * ($ $ $)) (-15 ** ($ $ (-763))) (-15 -1767 ($ $ $)) (-15 -2735 ((-121) $)) (-15 -2537 ((-121) $)) (-15 -3018 ((-121) |#4| $)) (-15 -1816 ((-121) $ $)) (-15 -4213 ((-121) |#4| $)) (-15 -1396 ((-121) $ (-634 |#3|))) (-15 -1396 ((-121) $)) (-15 -3212 ($ $ $)) (-15 -3212 ($ (-634 $))) (-15 -3961 ($ $ $)) (-15 -3961 ($ $ |#4|)) (-15 -2715 ($ $)) (-15 -2321 ((-2 (|:| |mval| (-679 |#1|)) (|:| |invmval| (-679 |#1|)) (|:| |genIdeal| $)) $ (-634 |#3|))) (-15 -4405 ($ (-2 (|:| |mval| (-679 |#1|)) (|:| |invmval| (-679 |#1|)) (|:| |genIdeal| $)))) (-15 -4321 ((-568) $ (-634 |#3|))) (-15 -4321 ((-568) $)) (-15 -2750 ($ $)) (-15 -1552 ($ (-634 |#4|))) (-15 -1585 ($ (-634 |#4|))) (-15 -1412 ((-121) $)) (-15 -2865 ((-634 |#4|) $)) (-15 -2745 ($ (-634 |#4|))) (-15 -2528 ($ $ |#4|)) (-15 -2528 ($ $ |#4| (-634 |#3|))) (IF (|has| |#3| (-609 (-1161))) (-15 -4243 ((-1150 (-634 (-953 |#1|)) (-634 (-288 (-953 |#1|)))) (-634 |#4|))) |noBranch|))) 
-((-3447 (((-121) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568))))) 144)) (-3501 (((-121) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568))))) 145)) (-4027 (((-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568))))) 103)) (-3927 (((-121) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568))))) NIL)) (-4429 (((-634 (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568))))) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568))))) 147)) (-2722 (((-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))) (-634 (-852 |#1|))) 159))) 
-(((-515 |#1| |#2|) (-10 -7 (-15 -3447 ((-121) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))))) (-15 -3501 ((-121) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))))) (-15 -3927 ((-121) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))))) (-15 -4027 ((-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))))) (-15 -4429 ((-634 (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568))))) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))))) (-15 -2722 ((-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))) (-634 (-852 |#1|))))) (-634 (-1161)) (-763)) (T -515)) 
-((-2722 (*1 *2 *2 *3) (-12 (-5 *2 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568))))) (-5 *3 (-634 (-852 *4))) (-14 *4 (-634 (-1161))) (-14 *5 (-763)) (-5 *1 (-515 *4 *5)))) (-4429 (*1 *2 *3) (-12 (-14 *4 (-634 (-1161))) (-14 *5 (-763)) (-5 *2 (-634 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568)))))) (-5 *1 (-515 *4 *5)) (-5 *3 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568))))))) (-4027 (*1 *2 *2) (-12 (-5 *2 (-514 (-409 (-568)) (-232 *4 (-763)) (-852 *3) (-242 *3 (-409 (-568))))) (-14 *3 (-634 (-1161))) (-14 *4 (-763)) (-5 *1 (-515 *3 *4)))) (-3927 (*1 *2 *3) (-12 (-5 *3 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568))))) (-14 *4 (-634 (-1161))) (-14 *5 (-763)) (-5 *2 (-121)) (-5 *1 (-515 *4 *5)))) (-3501 (*1 *2 *3) (-12 (-5 *3 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568))))) (-14 *4 (-634 (-1161))) (-14 *5 (-763)) (-5 *2 (-121)) (-5 *1 (-515 *4 *5)))) (-3447 (*1 *2 *3) (-12 (-5 *3 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568))))) (-14 *4 (-634 (-1161))) (-14 *5 (-763)) (-5 *2 (-121)) (-5 *1 (-515 *4 *5))))) 
-(-10 -7 (-15 -3447 ((-121) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))))) (-15 -3501 ((-121) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))))) (-15 -3927 ((-121) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))))) (-15 -4027 ((-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))))) (-15 -4429 ((-634 (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568))))) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))))) (-15 -2722 ((-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))) (-634 (-852 |#1|))))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-2114 (($ $) NIL)) (-2047 (($ |#1| |#2|) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-1311 ((|#2| $) NIL)) (-2102 ((|#1| $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-3056 (($) 12 T CONST)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) 11) (($ $ $) 23)) (-1767 (($ $ $) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 18))) 
+((-1475 (((-634 (-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|)))) (-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) (-763) (-763)) 27)) (-3935 (((-634 (-1157 |#1|)) |#1| (-763) (-763) (-763)) 34)) (-3500 (((-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) (-634 |#3|) (-634 (-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|)))) (-763)) 83))) 
+(((-507 |#1| |#2| |#3|) (-10 -7 (-15 -3935 ((-634 (-1157 |#1|)) |#1| (-763) (-763) (-763))) (-15 -1475 ((-634 (-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|)))) (-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) (-763) (-763))) (-15 -3500 ((-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) (-634 |#3|) (-634 (-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|)))) (-763)))) (-350) (-1219 |#1|) (-1219 |#2|)) (T -507)) 
+((-3500 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 (-2 (|:| -2588 (-679 *7)) (|:| |basisDen| *7) (|:| |basisInv| (-679 *7))))) (-5 *5 (-763)) (-4 *8 (-1219 *7)) (-4 *7 (-1219 *6)) (-4 *6 (-350)) (-5 *2 (-2 (|:| -2588 (-679 *7)) (|:| |basisDen| *7) (|:| |basisInv| (-679 *7)))) (-5 *1 (-507 *6 *7 *8)))) (-1475 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-763)) (-4 *5 (-350)) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-2 (|:| -2588 (-679 *6)) (|:| |basisDen| *6) (|:| |basisInv| (-679 *6))))) (-5 *1 (-507 *5 *6 *7)) (-5 *3 (-2 (|:| -2588 (-679 *6)) (|:| |basisDen| *6) (|:| |basisInv| (-679 *6)))) (-4 *7 (-1219 *6)))) (-3935 (*1 *2 *3 *4 *4 *4) (-12 (-5 *4 (-763)) (-4 *3 (-350)) (-4 *5 (-1219 *3)) (-5 *2 (-634 (-1157 *3))) (-5 *1 (-507 *3 *5 *6)) (-4 *6 (-1219 *5))))) 
+(-10 -7 (-15 -3935 ((-634 (-1157 |#1|)) |#1| (-763) (-763) (-763))) (-15 -1475 ((-634 (-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|)))) (-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) (-763) (-763))) (-15 -3500 ((-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) (-634 |#3|) (-634 (-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|)))) (-763)))) 
+((-3669 (((-2 (|:| -2588 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|))) (-2 (|:| -2588 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|))) (-2 (|:| -2588 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|)))) 60)) (-3530 ((|#1| (-679 |#1|) |#1| (-763)) 25)) (-1575 (((-763) (-763) (-763)) 30)) (-2485 (((-679 |#1|) (-679 |#1|) (-679 |#1|)) 42)) (-2300 (((-679 |#1|) (-679 |#1|) (-679 |#1|) |#1|) 50) (((-679 |#1|) (-679 |#1|) (-679 |#1|)) 47)) (-3666 ((|#1| (-679 |#1|) (-679 |#1|) |#1| (-568)) 29)) (-1966 ((|#1| (-679 |#1|)) 18))) 
+(((-508 |#1| |#2| |#3|) (-10 -7 (-15 -1966 (|#1| (-679 |#1|))) (-15 -3530 (|#1| (-679 |#1|) |#1| (-763))) (-15 -3666 (|#1| (-679 |#1|) (-679 |#1|) |#1| (-568))) (-15 -1575 ((-763) (-763) (-763))) (-15 -2300 ((-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -2300 ((-679 |#1|) (-679 |#1|) (-679 |#1|) |#1|)) (-15 -2485 ((-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -3669 ((-2 (|:| -2588 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|))) (-2 (|:| -2588 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|))) (-2 (|:| -2588 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|)))))) (-13 (-301) (-10 -8 (-15 -3498 ((-420 $) $)))) (-1219 |#1|) (-411 |#1| |#2|)) (T -508)) 
+((-3669 (*1 *2 *2 *2) (-12 (-5 *2 (-2 (|:| -2588 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-4 *3 (-13 (-301) (-10 -8 (-15 -3498 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *1 (-508 *3 *4 *5)) (-4 *5 (-411 *3 *4)))) (-2485 (*1 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-13 (-301) (-10 -8 (-15 -3498 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *1 (-508 *3 *4 *5)) (-4 *5 (-411 *3 *4)))) (-2300 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-679 *3)) (-4 *3 (-13 (-301) (-10 -8 (-15 -3498 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *1 (-508 *3 *4 *5)) (-4 *5 (-411 *3 *4)))) (-2300 (*1 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-13 (-301) (-10 -8 (-15 -3498 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *1 (-508 *3 *4 *5)) (-4 *5 (-411 *3 *4)))) (-1575 (*1 *2 *2 *2) (-12 (-5 *2 (-763)) (-4 *3 (-13 (-301) (-10 -8 (-15 -3498 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *1 (-508 *3 *4 *5)) (-4 *5 (-411 *3 *4)))) (-3666 (*1 *2 *3 *3 *2 *4) (-12 (-5 *3 (-679 *2)) (-5 *4 (-568)) (-4 *2 (-13 (-301) (-10 -8 (-15 -3498 ((-420 $) $))))) (-4 *5 (-1219 *2)) (-5 *1 (-508 *2 *5 *6)) (-4 *6 (-411 *2 *5)))) (-3530 (*1 *2 *3 *2 *4) (-12 (-5 *3 (-679 *2)) (-5 *4 (-763)) (-4 *2 (-13 (-301) (-10 -8 (-15 -3498 ((-420 $) $))))) (-4 *5 (-1219 *2)) (-5 *1 (-508 *2 *5 *6)) (-4 *6 (-411 *2 *5)))) (-1966 (*1 *2 *3) (-12 (-5 *3 (-679 *2)) (-4 *4 (-1219 *2)) (-4 *2 (-13 (-301) (-10 -8 (-15 -3498 ((-420 $) $))))) (-5 *1 (-508 *2 *4 *5)) (-4 *5 (-411 *2 *4))))) 
+(-10 -7 (-15 -1966 (|#1| (-679 |#1|))) (-15 -3530 (|#1| (-679 |#1|) |#1| (-763))) (-15 -3666 (|#1| (-679 |#1|) (-679 |#1|) |#1| (-568))) (-15 -1575 ((-763) (-763) (-763))) (-15 -2300 ((-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -2300 ((-679 |#1|) (-679 |#1|) (-679 |#1|) |#1|)) (-15 -2485 ((-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -3669 ((-2 (|:| -2588 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|))) (-2 (|:| -2588 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|))) (-2 (|:| -2588 (-679 |#1|)) (|:| |basisDen| |#1|) (|:| |basisInv| (-679 |#1|)))))) 
+((-2449 (((-121) $ $) NIL)) (-1613 (($ $) NIL)) (-3093 (($ $ $) 35)) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-1324 (((-121) $) NIL (|has| (-121) (-842))) (((-121) (-1 (-121) (-121) (-121)) $) NIL)) (-2109 (($ $) NIL (-12 (|has| $ (-6 -4522)) (|has| (-121) (-842)))) (($ (-1 (-121) (-121) (-121)) $) NIL (|has| $ (-6 -4522)))) (-3647 (($ $) NIL (|has| (-121) (-842))) (($ (-1 (-121) (-121) (-121)) $) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-2438 (((-121) $ (-1210 (-568)) (-121)) NIL (|has| $ (-6 -4522))) (((-121) $ (-568) (-121)) 36 (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4521)))) (-4490 (($) NIL T CONST)) (-4452 (($ $) NIL (|has| $ (-6 -4522)))) (-3945 (($ $) NIL)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-121) (-1090))))) (-4330 (($ (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4521))) (($ (-121) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-121) (-1090))))) (-3094 (((-121) (-1 (-121) (-121) (-121)) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) (-121) (-121)) $ (-121)) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) (-121) (-121)) $ (-121) (-121)) NIL (-12 (|has| $ (-6 -4521)) (|has| (-121) (-1090))))) (-1292 (((-121) $ (-568) (-121)) NIL (|has| $ (-6 -4522)))) (-2069 (((-121) $ (-568)) NIL)) (-2766 (((-568) (-121) $ (-568)) NIL (|has| (-121) (-1090))) (((-568) (-121) $) NIL (|has| (-121) (-1090))) (((-568) (-1 (-121) (-121)) $) NIL)) (-3317 (((-634 (-121)) $) NIL (|has| $ (-6 -4521)))) (-3107 (($ $ $) 33)) (-3046 (($ $) NIL)) (-2570 (($ $ $) NIL)) (-1851 (($ (-763) (-121)) 23)) (-4445 (($ $ $) NIL)) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) 8 (|has| (-568) (-842)))) (-1732 (($ $ $) NIL)) (-3645 (($ $ $) NIL (|has| (-121) (-842))) (($ (-1 (-121) (-121) (-121)) $ $) NIL)) (-4406 (((-634 (-121)) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) (-121) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-121) (-1090))))) (-3631 (((-568) $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL)) (-2253 (($ (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-121) (-121) (-121)) $ $) 30) (($ (-1 (-121) (-121)) $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL)) (-4124 (($ $ $ (-568)) NIL) (($ (-121) $ (-568)) NIL)) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4025 (((-1108) $) NIL)) (-3877 (((-121) $) NIL (|has| (-568) (-842)))) (-2712 (((-3 (-121) "failed") (-1 (-121) (-121)) $) NIL)) (-2490 (($ $ (-121)) NIL (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-121)) (-634 (-121))) NIL (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090)))) (($ $ (-121) (-121)) NIL (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090)))) (($ $ (-288 (-121))) NIL (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090)))) (($ $ (-634 (-288 (-121)))) NIL (-12 (|has| (-121) (-303 (-121))) (|has| (-121) (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) (-121) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-121) (-1090))))) (-1480 (((-634 (-121)) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) 24)) (-2781 (($ $ (-1210 (-568))) NIL) (((-121) $ (-568)) 18) (((-121) $ (-568) (-121)) NIL)) (-2828 (($ $ (-1210 (-568))) NIL) (($ $ (-568)) NIL)) (-4170 (((-763) (-121) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-121) (-1090)))) (((-763) (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4521)))) (-3306 (($ $ $ (-568)) NIL (|has| $ (-6 -4522)))) (-3865 (($ $) 25)) (-4280 (((-541) $) NIL (|has| (-121) (-609 (-541))))) (-4289 (($ (-634 (-121))) NIL)) (-2770 (($ (-634 $)) NIL) (($ $ $) NIL) (($ (-121) $) NIL) (($ $ (-121)) NIL)) (-2747 (((-850) $) 22)) (-3437 (((-121) (-1 (-121) (-121)) $) NIL (|has| $ (-6 -4521)))) (-2141 (($ $ $) 31)) (-1889 (($ $) NIL)) (-2432 (($ $ $) NIL)) (-3295 (($ $ $) 39)) (-3253 (($ $) 37)) (-3007 (($ $ $) 38)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 26)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 27)) (-2426 (($ $ $) NIL)) (-1699 (((-763) $) 10 (|has| $ (-6 -4521))))) 
+(((-509 |#1|) (-13 (-132) (-10 -8 (-15 -3253 ($ $)) (-15 -3295 ($ $ $)) (-15 -3007 ($ $ $)))) (-568)) (T -509)) 
+((-3253 (*1 *1 *1) (-12 (-5 *1 (-509 *2)) (-14 *2 (-568)))) (-3295 (*1 *1 *1 *1) (-12 (-5 *1 (-509 *2)) (-14 *2 (-568)))) (-3007 (*1 *1 *1 *1) (-12 (-5 *1 (-509 *2)) (-14 *2 (-568))))) 
+(-13 (-132) (-10 -8 (-15 -3253 ($ $)) (-15 -3295 ($ $ $)) (-15 -3007 ($ $ $)))) 
+((-2585 (((-3 |#2| "failed") (-1 (-3 |#1| "failed") |#4|) (-1157 |#4|)) 34)) (-4310 (((-1157 |#4|) (-1 |#4| |#1|) |#2|) 30) ((|#2| (-1 |#1| |#4|) (-1157 |#4|)) 21)) (-1727 (((-3 (-679 |#2|) "failed") (-1 (-3 |#1| "failed") |#4|) (-679 (-1157 |#4|))) 45)) (-1961 (((-1157 (-1157 |#4|)) (-1 |#4| |#1|) |#3|) 54))) 
+(((-510 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4310 (|#2| (-1 |#1| |#4|) (-1157 |#4|))) (-15 -4310 ((-1157 |#4|) (-1 |#4| |#1|) |#2|)) (-15 -2585 ((-3 |#2| "failed") (-1 (-3 |#1| "failed") |#4|) (-1157 |#4|))) (-15 -1727 ((-3 (-679 |#2|) "failed") (-1 (-3 |#1| "failed") |#4|) (-679 (-1157 |#4|)))) (-15 -1961 ((-1157 (-1157 |#4|)) (-1 |#4| |#1|) |#3|))) (-1047) (-1219 |#1|) (-1219 |#2|) (-1047)) (T -510)) 
+((-1961 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-1047)) (-4 *7 (-1047)) (-4 *6 (-1219 *5)) (-5 *2 (-1157 (-1157 *7))) (-5 *1 (-510 *5 *6 *4 *7)) (-4 *4 (-1219 *6)))) (-1727 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *5 "failed") *8)) (-5 *4 (-679 (-1157 *8))) (-4 *5 (-1047)) (-4 *8 (-1047)) (-4 *6 (-1219 *5)) (-5 *2 (-679 *6)) (-5 *1 (-510 *5 *6 *7 *8)) (-4 *7 (-1219 *6)))) (-2585 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *5 "failed") *7)) (-5 *4 (-1157 *7)) (-4 *5 (-1047)) (-4 *7 (-1047)) (-4 *2 (-1219 *5)) (-5 *1 (-510 *5 *2 *6 *7)) (-4 *6 (-1219 *2)))) (-4310 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-1047)) (-4 *7 (-1047)) (-4 *4 (-1219 *5)) (-5 *2 (-1157 *7)) (-5 *1 (-510 *5 *4 *6 *7)) (-4 *6 (-1219 *4)))) (-4310 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *5 *7)) (-5 *4 (-1157 *7)) (-4 *5 (-1047)) (-4 *7 (-1047)) (-4 *2 (-1219 *5)) (-5 *1 (-510 *5 *2 *6 *7)) (-4 *6 (-1219 *2))))) 
+(-10 -7 (-15 -4310 (|#2| (-1 |#1| |#4|) (-1157 |#4|))) (-15 -4310 ((-1157 |#4|) (-1 |#4| |#1|) |#2|)) (-15 -2585 ((-3 |#2| "failed") (-1 (-3 |#1| "failed") |#4|) (-1157 |#4|))) (-15 -1727 ((-3 (-679 |#2|) "failed") (-1 (-3 |#1| "failed") |#4|) (-679 (-1157 |#4|)))) (-15 -1961 ((-1157 (-1157 |#4|)) (-1 |#4| |#1|) |#3|))) 
+((-2449 (((-121) $ $) NIL)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-3687 (((-1249) $) 18)) (-2781 (((-1143) $ (-1161)) 22)) (-4127 (((-1249) $) 14)) (-2747 (((-850) $) 20) (($ (-1143)) 19)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 8)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 7))) 
+(((-511) (-13 (-842) (-10 -8 (-15 -2781 ((-1143) $ (-1161))) (-15 -4127 ((-1249) $)) (-15 -3687 ((-1249) $)) (-15 -2747 ($ (-1143)))))) (T -511)) 
+((-2781 (*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1143)) (-5 *1 (-511)))) (-4127 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-511)))) (-3687 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-511)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-511))))) 
+(-13 (-842) (-10 -8 (-15 -2781 ((-1143) $ (-1161))) (-15 -4127 ((-1249) $)) (-15 -3687 ((-1249) $)) (-15 -2747 ($ (-1143))))) 
+((-3618 (((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#4|) 19)) (-2471 ((|#1| |#4|) 10)) (-2609 ((|#3| |#4|) 17))) 
+(((-512 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2471 (|#1| |#4|)) (-15 -2609 (|#3| |#4|)) (-15 -3618 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#4|))) (-558) (-993 |#1|) (-375 |#1|) (-375 |#2|)) (T -512)) 
+((-3618 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-993 *4)) (-5 *2 (-2 (|:| |num| *6) (|:| |den| *4))) (-5 *1 (-512 *4 *5 *6 *3)) (-4 *6 (-375 *4)) (-4 *3 (-375 *5)))) (-2609 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-993 *4)) (-4 *2 (-375 *4)) (-5 *1 (-512 *4 *5 *2 *3)) (-4 *3 (-375 *5)))) (-2471 (*1 *2 *3) (-12 (-4 *4 (-993 *2)) (-4 *2 (-558)) (-5 *1 (-512 *2 *4 *5 *3)) (-4 *5 (-375 *2)) (-4 *3 (-375 *4))))) 
+(-10 -7 (-15 -2471 (|#1| |#4|)) (-15 -2609 (|#3| |#4|)) (-15 -3618 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#4|))) 
+((-2449 (((-121) $ $) NIL)) (-1636 (((-1161) $) NIL)) (-3396 (((-763) $) NIL)) (-2439 (((-1161) $ (-1161)) NIL)) (-3715 (((-763) $ (-763)) NIL)) (-1332 (((-966 |#1|) $ (-966 |#1|)) NIL)) (-1501 (((-763) $ (-763)) NIL)) (-2259 (((-33 |#1|) $ (-33 |#1|)) NIL)) (-2870 (((-634 (-774 |#1|)) $ (-634 (-774 |#1|))) NIL)) (-1840 (((-236 (-921 |#1|)) $ (-236 (-921 |#1|))) NIL)) (-2073 (((-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) $ (-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|)) NIL)) (-4082 ((|#3| $ |#3|) NIL)) (-3209 (((-966 |#1|) $) NIL)) (-1721 (((-763) $) NIL)) (-4288 (((-33 |#1|) $) NIL)) (-3452 (((-634 (-774 |#1|)) $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-4295 (((-121) (-121)) NIL) (((-121)) NIL)) (-2860 (((-850) $) NIL)) (-1435 (((-236 (-921 |#1|)) $) NIL)) (-1836 (((-917) $) NIL)) (-1764 (((-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) $) NIL)) (-4116 (($ (-966 |#1|) (-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) (-33 |#1|) (-763) |#3| (-763) (-236 (-921 |#1|)) |#1| (-1161)) NIL) (($ (-966 |#1|) (-242 |#2| |#1|)) NIL)) (-2747 (((-850) $) NIL)) (-3888 ((|#3| $) NIL)) (-2863 ((|#1| $) NIL)) (-1719 (((-121) $ $) NIL))) 
+(((-513 |#1| |#2| |#3|) (-13 (-536 |#1| |#2| (-242 |#2| |#1|) (-232 (-1699 |#2|) (-763)) (-966 |#1|) (-774 |#1|) (-921 |#1|) (-236 (-921 |#1|)) |#3|) (-10 -8 (-15 -2860 ((-850) $)) (-15 -4295 ((-121) (-121))) (-15 -4295 ((-121))))) (-365) (-634 (-1161)) (-117)) (T -513)) 
+((-2860 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-513 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-4295 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-513 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-4295 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-513 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
+(-13 (-536 |#1| |#2| (-242 |#2| |#1|) (-232 (-1699 |#2|) (-763)) (-966 |#1|) (-774 |#1|) (-921 |#1|) (-236 (-921 |#1|)) |#3|) (-10 -8 (-15 -2860 ((-850) $)) (-15 -4295 ((-121) (-121))) (-15 -4295 ((-121))))) 
+((-2449 (((-121) $ $) NIL)) (-4022 (((-121) $ (-634 |#3|)) 101) (((-121) $) 102)) (-1819 (((-121) $) 144)) (-1772 (($ $ |#4|) 93) (($ $ |#4| (-634 |#3|)) 97)) (-2846 (((-1150 (-634 (-953 |#1|)) (-634 (-288 (-953 |#1|)))) (-634 |#4|)) 137 (|has| |#3| (-609 (-1161))))) (-4409 (($ $ $) 87) (($ $ |#4|) 85)) (-1598 (((-121) $) 143)) (-3380 (($ $) 105)) (-1893 (((-1143) $) NIL)) (-1864 (($ $ $) 79) (($ (-634 $)) 81)) (-4155 (((-121) |#4| $) 104)) (-2217 (((-121) $ $) 68)) (-4314 (($ (-634 |#4|)) 86)) (-4025 (((-1108) $) NIL)) (-4483 (($ (-634 |#4|)) 141)) (-2142 (((-121) $) 142)) (-1506 (($ $) 70)) (-4057 (((-634 |#4|) $) 55)) (-3783 (((-2 (|:| |mval| (-679 |#1|)) (|:| |invmval| (-679 |#1|)) (|:| |genIdeal| $)) $ (-634 |#3|)) NIL)) (-3241 (((-121) |#4| $) 73)) (-3108 (((-568) $ (-634 |#3|)) 106) (((-568) $) 107)) (-2747 (((-850) $) 140) (($ (-634 |#4|)) 82)) (-1488 (($ (-2 (|:| |mval| (-679 |#1|)) (|:| |invmval| (-679 |#1|)) (|:| |genIdeal| $))) NIL)) (-1719 (((-121) $ $) 69)) (-1769 (($ $ $) 89)) (** (($ $ (-763)) 92)) (* (($ $ $) 91))) 
+(((-514 |#1| |#2| |#3| |#4|) (-13 (-1090) (-10 -7 (-15 * ($ $ $)) (-15 ** ($ $ (-763))) (-15 -1769 ($ $ $)) (-15 -1598 ((-121) $)) (-15 -1819 ((-121) $)) (-15 -3241 ((-121) |#4| $)) (-15 -2217 ((-121) $ $)) (-15 -4155 ((-121) |#4| $)) (-15 -4022 ((-121) $ (-634 |#3|))) (-15 -4022 ((-121) $)) (-15 -1864 ($ $ $)) (-15 -1864 ($ (-634 $))) (-15 -4409 ($ $ $)) (-15 -4409 ($ $ |#4|)) (-15 -1506 ($ $)) (-15 -3783 ((-2 (|:| |mval| (-679 |#1|)) (|:| |invmval| (-679 |#1|)) (|:| |genIdeal| $)) $ (-634 |#3|))) (-15 -1488 ($ (-2 (|:| |mval| (-679 |#1|)) (|:| |invmval| (-679 |#1|)) (|:| |genIdeal| $)))) (-15 -3108 ((-568) $ (-634 |#3|))) (-15 -3108 ((-568) $)) (-15 -3380 ($ $)) (-15 -4314 ($ (-634 |#4|))) (-15 -4483 ($ (-634 |#4|))) (-15 -2142 ((-121) $)) (-15 -4057 ((-634 |#4|) $)) (-15 -2747 ($ (-634 |#4|))) (-15 -1772 ($ $ |#4|)) (-15 -1772 ($ $ |#4| (-634 |#3|))) (IF (|has| |#3| (-609 (-1161))) (-15 -2846 ((-1150 (-634 (-953 |#1|)) (-634 (-288 (-953 |#1|)))) (-634 |#4|))) |noBranch|))) (-365) (-788) (-842) (-950 |#1| |#2| |#3|)) (T -514)) 
+((* (*1 *1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) (-1769 (*1 *1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) (-1598 (*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) (-1819 (*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) (-3241 (*1 *2 *3 *1) (-12 (-4 *4 (-365)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *4 *5 *6 *3)) (-4 *3 (-950 *4 *5 *6)))) (-2217 (*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) (-4155 (*1 *2 *3 *1) (-12 (-4 *4 (-365)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *4 *5 *6 *3)) (-4 *3 (-950 *4 *5 *6)))) (-4022 (*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-842)) (-4 *4 (-365)) (-4 *5 (-788)) (-5 *2 (-121)) (-5 *1 (-514 *4 *5 *6 *7)) (-4 *7 (-950 *4 *5 *6)))) (-4022 (*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) (-1864 (*1 *1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) (-1864 (*1 *1 *2) (-12 (-5 *2 (-634 (-514 *3 *4 *5 *6))) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) (-4409 (*1 *1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) (-4409 (*1 *1 *1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *2)) (-4 *2 (-950 *3 *4 *5)))) (-1506 (*1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) (-3783 (*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-842)) (-4 *4 (-365)) (-4 *5 (-788)) (-5 *2 (-2 (|:| |mval| (-679 *4)) (|:| |invmval| (-679 *4)) (|:| |genIdeal| (-514 *4 *5 *6 *7)))) (-5 *1 (-514 *4 *5 *6 *7)) (-4 *7 (-950 *4 *5 *6)))) (-1488 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |mval| (-679 *3)) (|:| |invmval| (-679 *3)) (|:| |genIdeal| (-514 *3 *4 *5 *6)))) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) (-3108 (*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-842)) (-4 *4 (-365)) (-4 *5 (-788)) (-5 *2 (-568)) (-5 *1 (-514 *4 *5 *6 *7)) (-4 *7 (-950 *4 *5 *6)))) (-3108 (*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-568)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) (-3380 (*1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) (-4314 (*1 *1 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6)))) (-4483 (*1 *1 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6)))) (-2142 (*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) (-4057 (*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *6)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6)))) (-1772 (*1 *1 *1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *2)) (-4 *2 (-950 *3 *4 *5)))) (-1772 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-842)) (-4 *4 (-365)) (-4 *5 (-788)) (-5 *1 (-514 *4 *5 *6 *2)) (-4 *2 (-950 *4 *5 *6)))) (-2846 (*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-950 *4 *5 *6)) (-4 *6 (-609 (-1161))) (-4 *4 (-365)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1150 (-634 (-953 *4)) (-634 (-288 (-953 *4))))) (-5 *1 (-514 *4 *5 *6 *7))))) 
+(-13 (-1090) (-10 -7 (-15 * ($ $ $)) (-15 ** ($ $ (-763))) (-15 -1769 ($ $ $)) (-15 -1598 ((-121) $)) (-15 -1819 ((-121) $)) (-15 -3241 ((-121) |#4| $)) (-15 -2217 ((-121) $ $)) (-15 -4155 ((-121) |#4| $)) (-15 -4022 ((-121) $ (-634 |#3|))) (-15 -4022 ((-121) $)) (-15 -1864 ($ $ $)) (-15 -1864 ($ (-634 $))) (-15 -4409 ($ $ $)) (-15 -4409 ($ $ |#4|)) (-15 -1506 ($ $)) (-15 -3783 ((-2 (|:| |mval| (-679 |#1|)) (|:| |invmval| (-679 |#1|)) (|:| |genIdeal| $)) $ (-634 |#3|))) (-15 -1488 ($ (-2 (|:| |mval| (-679 |#1|)) (|:| |invmval| (-679 |#1|)) (|:| |genIdeal| $)))) (-15 -3108 ((-568) $ (-634 |#3|))) (-15 -3108 ((-568) $)) (-15 -3380 ($ $)) (-15 -4314 ($ (-634 |#4|))) (-15 -4483 ($ (-634 |#4|))) (-15 -2142 ((-121) $)) (-15 -4057 ((-634 |#4|) $)) (-15 -2747 ($ (-634 |#4|))) (-15 -1772 ($ $ |#4|)) (-15 -1772 ($ $ |#4| (-634 |#3|))) (IF (|has| |#3| (-609 (-1161))) (-15 -2846 ((-1150 (-634 (-953 |#1|)) (-634 (-288 (-953 |#1|)))) (-634 |#4|))) |noBranch|))) 
+((-3543 (((-121) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568))))) 144)) (-3918 (((-121) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568))))) 145)) (-1464 (((-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568))))) 103)) (-2197 (((-121) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568))))) NIL)) (-1610 (((-634 (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568))))) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568))))) 147)) (-1543 (((-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))) (-634 (-852 |#1|))) 159))) 
+(((-515 |#1| |#2|) (-10 -7 (-15 -3543 ((-121) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))))) (-15 -3918 ((-121) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))))) (-15 -2197 ((-121) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))))) (-15 -1464 ((-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))))) (-15 -1610 ((-634 (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568))))) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))))) (-15 -1543 ((-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))) (-634 (-852 |#1|))))) (-634 (-1161)) (-763)) (T -515)) 
+((-1543 (*1 *2 *2 *3) (-12 (-5 *2 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568))))) (-5 *3 (-634 (-852 *4))) (-14 *4 (-634 (-1161))) (-14 *5 (-763)) (-5 *1 (-515 *4 *5)))) (-1610 (*1 *2 *3) (-12 (-14 *4 (-634 (-1161))) (-14 *5 (-763)) (-5 *2 (-634 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568)))))) (-5 *1 (-515 *4 *5)) (-5 *3 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568))))))) (-1464 (*1 *2 *2) (-12 (-5 *2 (-514 (-409 (-568)) (-232 *4 (-763)) (-852 *3) (-242 *3 (-409 (-568))))) (-14 *3 (-634 (-1161))) (-14 *4 (-763)) (-5 *1 (-515 *3 *4)))) (-2197 (*1 *2 *3) (-12 (-5 *3 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568))))) (-14 *4 (-634 (-1161))) (-14 *5 (-763)) (-5 *2 (-121)) (-5 *1 (-515 *4 *5)))) (-3918 (*1 *2 *3) (-12 (-5 *3 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568))))) (-14 *4 (-634 (-1161))) (-14 *5 (-763)) (-5 *2 (-121)) (-5 *1 (-515 *4 *5)))) (-3543 (*1 *2 *3) (-12 (-5 *3 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568))))) (-14 *4 (-634 (-1161))) (-14 *5 (-763)) (-5 *2 (-121)) (-5 *1 (-515 *4 *5))))) 
+(-10 -7 (-15 -3543 ((-121) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))))) (-15 -3918 ((-121) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))))) (-15 -2197 ((-121) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))))) (-15 -1464 ((-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))))) (-15 -1610 ((-634 (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568))))) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))))) (-15 -1543 ((-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))) (-514 (-409 (-568)) (-232 |#2| (-763)) (-852 |#1|) (-242 |#1| (-409 (-568)))) (-634 (-852 |#1|))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-2116 (($ $) NIL)) (-2049 (($ |#1| |#2|) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-3369 ((|#2| $) NIL)) (-2104 ((|#1| $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-3058 (($) 12 T CONST)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) 11) (($ $ $) 23)) (-1769 (($ $ $) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 18))) 
 (((-516 |#1| |#2|) (-13 (-21) (-518 |#1| |#2|)) (-21) (-842)) (T -516)) 
 NIL 
 (-13 (-21) (-518 |#1| |#2|)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 12)) (-2671 (($) NIL T CONST)) (-2114 (($ $) 26)) (-2047 (($ |#1| |#2|) 23)) (-2795 (($ (-1 |#1| |#1|) $) 25)) (-1311 ((|#2| $) NIL)) (-2102 ((|#1| $) 27)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-3056 (($) 10 T CONST)) (-1717 (((-121) $ $) NIL)) (-1767 (($ $ $) 17)) (* (($ (-917) $) NIL) (($ (-763) $) 22))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 12)) (-4490 (($) NIL T CONST)) (-2116 (($ $) 26)) (-2049 (($ |#1| |#2|) 23)) (-2797 (($ (-1 |#1| |#1|) $) 25)) (-3369 ((|#2| $) NIL)) (-2104 ((|#1| $) 27)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-3058 (($) 10 T CONST)) (-1719 (((-121) $ $) NIL)) (-1769 (($ $ $) 17)) (* (($ (-917) $) NIL) (($ (-763) $) 22))) 
 (((-517 |#1| |#2|) (-13 (-23) (-518 |#1| |#2|)) (-23) (-842)) (T -517)) 
 NIL 
 (-13 (-23) (-518 |#1| |#2|)) 
-((-2447 (((-121) $ $) 7)) (-2114 (($ $) 12)) (-2047 (($ |#1| |#2|) 15)) (-2795 (($ (-1 |#1| |#1|) $) 16)) (-1311 ((|#2| $) 13)) (-2102 ((|#1| $) 14)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-1717 (((-121) $ $) 6))) 
+((-2449 (((-121) $ $) 7)) (-2116 (($ $) 12)) (-2049 (($ |#1| |#2|) 15)) (-2797 (($ (-1 |#1| |#1|) $) 16)) (-3369 ((|#2| $) 13)) (-2104 ((|#1| $) 14)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-1719 (((-121) $ $) 6))) 
 (((-518 |#1| |#2|) (-1275) (-1090) (-842)) (T -518)) 
-((-2795 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-518 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-842)))) (-2047 (*1 *1 *2 *3) (-12 (-4 *1 (-518 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-842)))) (-2102 (*1 *2 *1) (-12 (-4 *1 (-518 *2 *3)) (-4 *3 (-842)) (-4 *2 (-1090)))) (-1311 (*1 *2 *1) (-12 (-4 *1 (-518 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-842)))) (-2114 (*1 *1 *1) (-12 (-4 *1 (-518 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-842))))) 
-(-13 (-1090) (-10 -8 (-15 -2795 ($ (-1 |t#1| |t#1|) $)) (-15 -2047 ($ |t#1| |t#2|)) (-15 -2102 (|t#1| $)) (-15 -1311 (|t#2| $)) (-15 -2114 ($ $)))) 
+((-2797 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-518 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-842)))) (-2049 (*1 *1 *2 *3) (-12 (-4 *1 (-518 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-842)))) (-2104 (*1 *2 *1) (-12 (-4 *1 (-518 *2 *3)) (-4 *3 (-842)) (-4 *2 (-1090)))) (-3369 (*1 *2 *1) (-12 (-4 *1 (-518 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-842)))) (-2116 (*1 *1 *1) (-12 (-4 *1 (-518 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-842))))) 
+(-13 (-1090) (-10 -8 (-15 -2797 ($ (-1 |t#1| |t#1|) $)) (-15 -2049 ($ |t#1| |t#2|)) (-15 -2104 (|t#1| $)) (-15 -3369 (|t#2| $)) (-15 -2116 ($ $)))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2671 (($) NIL T CONST)) (-2114 (($ $) NIL)) (-2047 (($ |#1| |#2|) NIL)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-1311 ((|#2| $) NIL)) (-2102 ((|#1| $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-3056 (($) NIL T CONST)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 13)) (-1767 (($ $ $) NIL)) (* (($ (-763) $) NIL) (($ (-917) $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-4490 (($) NIL T CONST)) (-2116 (($ $) NIL)) (-2049 (($ |#1| |#2|) NIL)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-3369 ((|#2| $) NIL)) (-2104 ((|#1| $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-3058 (($) NIL T CONST)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 13)) (-1769 (($ $ $) NIL)) (* (($ (-763) $) NIL) (($ (-917) $) NIL))) 
 (((-519 |#1| |#2|) (-13 (-787) (-518 |#1| |#2|)) (-787) (-842)) (T -519)) 
 NIL 
 (-13 (-787) (-518 |#1| |#2|)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-1462 (($ $ $) 16)) (-3134 (((-3 $ "failed") $ $) 13)) (-2671 (($) NIL T CONST)) (-2114 (($ $) NIL)) (-2047 (($ |#1| |#2|) NIL)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-1311 ((|#2| $) NIL)) (-2102 ((|#1| $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL)) (-3056 (($) NIL T CONST)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) NIL)) (-1767 (($ $ $) NIL)) (* (($ (-763) $) NIL) (($ (-917) $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2409 (($ $ $) 16)) (-2689 (((-3 $ "failed") $ $) 13)) (-4490 (($) NIL T CONST)) (-2116 (($ $) NIL)) (-2049 (($ |#1| |#2|) NIL)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-3369 ((|#2| $) NIL)) (-2104 ((|#1| $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL)) (-3058 (($) NIL T CONST)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) NIL)) (-1769 (($ $ $) NIL)) (* (($ (-763) $) NIL) (($ (-917) $) NIL))) 
 (((-520 |#1| |#2|) (-13 (-788) (-518 |#1| |#2|)) (-788) (-842)) (T -520)) 
 NIL 
 (-13 (-788) (-518 |#1| |#2|)) 
-((-2447 (((-121) $ $) NIL)) (-2114 (($ $) 24)) (-2047 (($ |#1| |#2|) 21)) (-2795 (($ (-1 |#1| |#1|) $) 23)) (-1311 ((|#2| $) 26)) (-2102 ((|#1| $) 25)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 20)) (-1717 (((-121) $ $) 13))) 
+((-2449 (((-121) $ $) NIL)) (-2116 (($ $) 24)) (-2049 (($ |#1| |#2|) 21)) (-2797 (($ (-1 |#1| |#1|) $) 23)) (-3369 ((|#2| $) 26)) (-2104 ((|#1| $) 25)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 20)) (-1719 (((-121) $ $) 13))) 
 (((-521 |#1| |#2|) (-518 |#1| |#2|) (-1090) (-842)) (T -521)) 
 NIL 
 (-518 |#1| |#2|) 
@@ -2106,3107 +2106,3107 @@ NIL
 (((-523 |#1| |#2|) (-1275) (-1090) (-1195)) (T -523)) 
 ((-1339 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *4)) (-5 *3 (-634 *5)) (-4 *1 (-523 *4 *5)) (-4 *4 (-1090)) (-4 *5 (-1195)))) (-1339 (*1 *1 *1 *2 *3) (-12 (-4 *1 (-523 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1195))))) 
 (-13 (-10 -8 (-15 -1339 ($ $ |t#1| |t#2|)) (-15 -1339 ($ $ (-634 |t#1|) (-634 |t#2|))))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 16)) (-2583 (((-634 (-2 (|:| |gen| |#1|) (|:| -1892 |#2|))) $) 18)) (-3134 (((-3 $ "failed") $ $) NIL)) (-3983 (((-763) $) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) NIL)) (-2854 ((|#1| $) NIL)) (-2882 ((|#1| $ (-568)) 23)) (-1444 ((|#2| $ (-568)) 21)) (-2096 (($ (-1 |#1| |#1|) $) 46)) (-2907 (($ (-1 |#2| |#2|) $) 43)) (-4487 (((-1143) $) NIL)) (-1764 (($ $ $) 53 (|has| |#2| (-787)))) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 42) (($ |#1|) NIL)) (-2604 ((|#2| |#1| $) 49)) (-3056 (($) 11 T CONST)) (-1717 (((-121) $ $) 29)) (-1767 (($ $ $) 27) (($ |#1| $) 25)) (* (($ (-917) $) NIL) (($ (-763) $) 36) (($ |#2| |#1|) 31))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 16)) (-2013 (((-634 (-2 (|:| |gen| |#1|) (|:| -1894 |#2|))) $) 18)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3986 (((-763) $) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) NIL)) (-2857 ((|#1| $) NIL)) (-4167 ((|#1| $ (-568)) 23)) (-2313 ((|#2| $ (-568)) 21)) (-3177 (($ (-1 |#1| |#1|) $) 46)) (-2847 (($ (-1 |#2| |#2|) $) 43)) (-1893 (((-1143) $) NIL)) (-3933 (($ $ $) 53 (|has| |#2| (-787)))) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 42) (($ |#1|) NIL)) (-2079 ((|#2| |#1| $) 49)) (-3058 (($) 11 T CONST)) (-1719 (((-121) $ $) 29)) (-1769 (($ $ $) 27) (($ |#1| $) 25)) (* (($ (-917) $) NIL) (($ (-763) $) 36) (($ |#2| |#1|) 31))) 
 (((-524 |#1| |#2| |#3|) (-320 |#1| |#2|) (-1090) (-137) |#2|) (T -524)) 
 NIL 
 (-320 |#1| |#2|) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-2016 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-842)))) (-3908 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4520))) (($ $) NIL (-12 (|has| $ (-6 -4520)) (|has| |#1| (-842))))) (-3644 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-842)))) (-2510 (((-121) $ (-763)) NIL)) (-3535 (((-121) (-121)) 24)) (-2436 ((|#1| $ (-568) |#1|) 27 (|has| $ (-6 -4520))) ((|#1| $ (-1210 (-568)) |#1|) NIL (|has| $ (-6 -4520)))) (-3507 (($ (-1 (-121) |#1|) $) 51)) (-2801 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-2671 (($) NIL T CONST)) (-1578 (($ $) NIL (|has| $ (-6 -4520)))) (-3943 (($ $) NIL)) (-3369 (($ $) 54 (|has| |#1| (-1090)))) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3405 (($ |#1| $) NIL (|has| |#1| (-1090))) (($ (-1 (-121) |#1|) $) 43)) (-4328 (($ |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4519)))) (-3989 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-568)) NIL)) (-2764 (((-568) (-1 (-121) |#1|) $) NIL) (((-568) |#1| $) NIL (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) NIL (|has| |#1| (-1090)))) (-3428 (($ $ (-568)) 13)) (-3575 (((-763) $) 11)) (-4360 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-1849 (($ (-763) |#1|) 22)) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) 20 (|has| (-568) (-842)))) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-3349 (($ $ $) NIL (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $ $) 34)) (-1347 (($ (-1 (-121) |#1| |#1|) $ $) 35) (($ $ $) NIL (|has| |#1| (-842)))) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2223 (((-568) $) 19 (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-3674 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4450 (($ $ $ (-568)) 50) (($ |#1| $ (-568)) 36)) (-4122 (($ |#1| $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3802 (($ (-634 |#1|)) 28)) (-3876 ((|#1| $) NIL (|has| (-568) (-842)))) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3724 (($ $ |#1|) 18 (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 39)) (-4467 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) 14)) (-2779 ((|#1| $ (-568) |#1|) NIL) ((|#1| $ (-568)) 32) (($ $ (-1210 (-568))) NIL)) (-1783 (($ $ (-1210 (-568))) 49) (($ $ (-568)) 44)) (-2826 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2256 (($ $ $ (-568)) 40 (|has| $ (-6 -4520)))) (-3863 (($ $) 31)) (-4278 (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) NIL)) (-3845 (($ $ $) 41) (($ $ |#1|) 38)) (-2768 (($ $ |#1|) NIL) (($ |#1| $) 37) (($ $ $) NIL) (($ (-634 $)) NIL)) (-2745 (((-850) $) NIL (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1697 (((-763) $) 15 (|has| $ (-6 -4519))))) 
-(((-525 |#1| |#2|) (-13 (-19 |#1|) (-277 |#1|) (-10 -8 (-15 -3802 ($ (-634 |#1|))) (-15 -3575 ((-763) $)) (-15 -3428 ($ $ (-568))) (-15 -3535 ((-121) (-121))))) (-1195) (-568)) (T -525)) 
-((-3802 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-525 *3 *4)) (-14 *4 (-568)))) (-3575 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-525 *3 *4)) (-4 *3 (-1195)) (-14 *4 (-568)))) (-3428 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-525 *3 *4)) (-4 *3 (-1195)) (-14 *4 *2))) (-3535 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-525 *3 *4)) (-4 *3 (-1195)) (-14 *4 (-568))))) 
-(-13 (-19 |#1|) (-277 |#1|) (-10 -8 (-15 -3802 ($ (-634 |#1|))) (-15 -3575 ((-763) $)) (-15 -3428 ($ $ (-568))) (-15 -3535 ((-121) (-121))))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-2615 (((-121) $) NIL)) (-1739 (((-763)) NIL)) (-1932 (((-581 |#1|) $) NIL) (($ $ (-917)) NIL (|has| (-581 |#1|) (-370)))) (-3211 (((-1169 (-917) (-763)) (-568)) NIL (|has| (-581 |#1|) (-370)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1497 (((-121) $ $) NIL)) (-3983 (((-763)) NIL (|has| (-581 |#1|) (-370)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-581 |#1|) "failed") $) NIL)) (-2854 (((-581 |#1|) $) NIL)) (-3498 (($ (-1244 (-581 |#1|))) NIL)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-581 |#1|) (-370)))) (-2401 (($ $ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1731 (($) NIL (|has| (-581 |#1|) (-370)))) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-4220 (($) NIL (|has| (-581 |#1|) (-370)))) (-4456 (((-121) $) NIL (|has| (-581 |#1|) (-370)))) (-3218 (($ $ (-763)) NIL (-2198 (|has| (-581 |#1|) (-148)) (|has| (-581 |#1|) (-370)))) (($ $) NIL (-2198 (|has| (-581 |#1|) (-148)) (|has| (-581 |#1|) (-370))))) (-3927 (((-121) $) NIL)) (-4477 (((-917) $) NIL (|has| (-581 |#1|) (-370))) (((-828 (-917)) $) NIL (-2198 (|has| (-581 |#1|) (-148)) (|has| (-581 |#1|) (-370))))) (-2735 (((-121) $) NIL)) (-2883 (($) NIL (|has| (-581 |#1|) (-370)))) (-3917 (((-121) $) NIL (|has| (-581 |#1|) (-370)))) (-2657 (((-581 |#1|) $) NIL) (($ $ (-917)) NIL (|has| (-581 |#1|) (-370)))) (-3038 (((-3 $ "failed") $) NIL (|has| (-581 |#1|) (-370)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2045 (((-1157 (-581 |#1|)) $) NIL) (((-1157 $) $ (-917)) NIL (|has| (-581 |#1|) (-370)))) (-3683 (((-917) $) NIL (|has| (-581 |#1|) (-370)))) (-2035 (((-1157 (-581 |#1|)) $) NIL (|has| (-581 |#1|) (-370)))) (-1422 (((-1157 (-581 |#1|)) $) NIL (|has| (-581 |#1|) (-370))) (((-3 (-1157 (-581 |#1|)) "failed") $ $) NIL (|has| (-581 |#1|) (-370)))) (-2109 (($ $ (-1157 (-581 |#1|))) NIL (|has| (-581 |#1|) (-370)))) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4434 (($) NIL (|has| (-581 |#1|) (-370)) CONST)) (-4355 (($ (-917)) NIL (|has| (-581 |#1|) (-370)))) (-2864 (((-121) $) NIL)) (-4022 (((-1108) $) NIL)) (-2704 (($) NIL (|has| (-581 |#1|) (-370)))) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) NIL (|has| (-581 |#1|) (-370)))) (-3848 (((-420 $) $) NIL)) (-1553 (((-828 (-917))) NIL) (((-917)) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3143 (((-763) $) NIL (|has| (-581 |#1|) (-370))) (((-3 (-763) "failed") $ $) NIL (-2198 (|has| (-581 |#1|) (-148)) (|has| (-581 |#1|) (-370))))) (-4321 (((-139)) NIL)) (-4189 (($ $) NIL (|has| (-581 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-581 |#1|) (-370)))) (-3206 (((-828 (-917)) $) NIL) (((-917) $) NIL)) (-1626 (((-1157 (-581 |#1|))) NIL)) (-3065 (($) NIL (|has| (-581 |#1|) (-370)))) (-2027 (($) NIL (|has| (-581 |#1|) (-370)))) (-4073 (((-1244 (-581 |#1|)) $) NIL) (((-679 (-581 |#1|)) (-1244 $)) NIL)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| (-581 |#1|) (-370)))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ (-581 |#1|)) NIL)) (-4371 (($ $) NIL (|has| (-581 |#1|) (-370))) (((-3 $ "failed") $) NIL (-2198 (|has| (-581 |#1|) (-148)) (|has| (-581 |#1|) (-370))))) (-4078 (((-763)) NIL)) (-3746 (((-1244 $)) NIL) (((-1244 $) (-917)) NIL)) (-1826 (((-121) $ $) NIL)) (-4390 (((-121) $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-1316 (($ $) NIL (|has| (-581 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-581 |#1|) (-370)))) (-3190 (($ $) NIL (|has| (-581 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-581 |#1|) (-370)))) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ $) NIL) (($ $ (-581 |#1|)) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ $ (-581 |#1|)) NIL) (($ (-581 |#1|) $) NIL))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-1324 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-842)))) (-2109 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4522))) (($ $) NIL (-12 (|has| $ (-6 -4522)) (|has| |#1| (-842))))) (-3647 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-842)))) (-1667 (((-121) $ (-763)) NIL)) (-4161 (((-121) (-121)) 24)) (-2438 ((|#1| $ (-568) |#1|) 27 (|has| $ (-6 -4522))) ((|#1| $ (-1210 (-568)) |#1|) NIL (|has| $ (-6 -4522)))) (-3963 (($ (-1 (-121) |#1|) $) 51)) (-2803 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-4490 (($) NIL T CONST)) (-4452 (($ $) NIL (|has| $ (-6 -4522)))) (-3945 (($ $) NIL)) (-1377 (($ $) 54 (|has| |#1| (-1090)))) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1568 (($ |#1| $) NIL (|has| |#1| (-1090))) (($ (-1 (-121) |#1|) $) 43)) (-4330 (($ |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4521)))) (-1292 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-568)) NIL)) (-2766 (((-568) (-1 (-121) |#1|) $) NIL) (((-568) |#1| $) NIL (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) NIL (|has| |#1| (-1090)))) (-3400 (($ $ (-568)) 13)) (-2906 (((-763) $) 11)) (-3317 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-1851 (($ (-763) |#1|) 22)) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) 20 (|has| (-568) (-842)))) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-4496 (($ $ $) NIL (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $ $) 34)) (-3645 (($ (-1 (-121) |#1| |#1|) $ $) 35) (($ $ $) NIL (|has| |#1| (-842)))) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3631 (((-568) $) 19 (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-2253 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-1708 (($ $ $ (-568)) 50) (($ |#1| $ (-568)) 36)) (-4124 (($ |#1| $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-1697 (($ (-634 |#1|)) 28)) (-3877 ((|#1| $) NIL (|has| (-568) (-842)))) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-2490 (($ $ |#1|) 18 (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 39)) (-1801 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) 14)) (-2781 ((|#1| $ (-568) |#1|) NIL) ((|#1| $ (-568)) 32) (($ $ (-1210 (-568))) NIL)) (-4031 (($ $ (-1210 (-568))) 49) (($ $ (-568)) 44)) (-2828 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3306 (($ $ $ (-568)) 40 (|has| $ (-6 -4522)))) (-3865 (($ $) 31)) (-4280 (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) NIL)) (-1876 (($ $ $) 41) (($ $ |#1|) 38)) (-2770 (($ $ |#1|) NIL) (($ |#1| $) 37) (($ $ $) NIL) (($ (-634 $)) NIL)) (-2747 (((-850) $) NIL (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1699 (((-763) $) 15 (|has| $ (-6 -4521))))) 
+(((-525 |#1| |#2|) (-13 (-19 |#1|) (-277 |#1|) (-10 -8 (-15 -1697 ($ (-634 |#1|))) (-15 -2906 ((-763) $)) (-15 -3400 ($ $ (-568))) (-15 -4161 ((-121) (-121))))) (-1195) (-568)) (T -525)) 
+((-1697 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-525 *3 *4)) (-14 *4 (-568)))) (-2906 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-525 *3 *4)) (-4 *3 (-1195)) (-14 *4 (-568)))) (-3400 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-525 *3 *4)) (-4 *3 (-1195)) (-14 *4 *2))) (-4161 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-525 *3 *4)) (-4 *3 (-1195)) (-14 *4 (-568))))) 
+(-13 (-19 |#1|) (-277 |#1|) (-10 -8 (-15 -1697 ($ (-634 |#1|))) (-15 -2906 ((-763) $)) (-15 -3400 ($ $ (-568))) (-15 -4161 ((-121) (-121))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2134 (((-121) $) NIL)) (-3800 (((-763)) NIL)) (-1934 (((-581 |#1|) $) NIL) (($ $ (-917)) NIL (|has| (-581 |#1|) (-370)))) (-1856 (((-1169 (-917) (-763)) (-568)) NIL (|has| (-581 |#1|) (-370)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2589 (((-121) $ $) NIL)) (-3986 (((-763)) NIL (|has| (-581 |#1|) (-370)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-581 |#1|) "failed") $) NIL)) (-2857 (((-581 |#1|) $) NIL)) (-3899 (($ (-1244 (-581 |#1|))) NIL)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-581 |#1|) (-370)))) (-2403 (($ $ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1733 (($) NIL (|has| (-581 |#1|) (-370)))) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-4188 (($) NIL (|has| (-581 |#1|) (-370)))) (-1748 (((-121) $) NIL (|has| (-581 |#1|) (-370)))) (-1887 (($ $ (-763)) NIL (-2199 (|has| (-581 |#1|) (-148)) (|has| (-581 |#1|) (-370)))) (($ $) NIL (-2199 (|has| (-581 |#1|) (-148)) (|has| (-581 |#1|) (-370))))) (-2197 (((-121) $) NIL)) (-1844 (((-917) $) NIL (|has| (-581 |#1|) (-370))) (((-828 (-917)) $) NIL (-2199 (|has| (-581 |#1|) (-148)) (|has| (-581 |#1|) (-370))))) (-1598 (((-121) $) NIL)) (-2769 (($) NIL (|has| (-581 |#1|) (-370)))) (-2151 (((-121) $) NIL (|has| (-581 |#1|) (-370)))) (-4417 (((-581 |#1|) $) NIL) (($ $ (-917)) NIL (|has| (-581 |#1|) (-370)))) (-2214 (((-3 $ "failed") $) NIL (|has| (-581 |#1|) (-370)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1497 (((-1157 (-581 |#1|)) $) NIL) (((-1157 $) $ (-917)) NIL (|has| (-581 |#1|) (-370)))) (-2291 (((-917) $) NIL (|has| (-581 |#1|) (-370)))) (-1447 (((-1157 (-581 |#1|)) $) NIL (|has| (-581 |#1|) (-370)))) (-2193 (((-1157 (-581 |#1|)) $) NIL (|has| (-581 |#1|) (-370))) (((-3 (-1157 (-581 |#1|)) "failed") $ $) NIL (|has| (-581 |#1|) (-370)))) (-3257 (($ $ (-1157 (-581 |#1|))) NIL (|has| (-581 |#1|) (-370)))) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4436 (($) NIL (|has| (-581 |#1|) (-370)) CONST)) (-4357 (($ (-917)) NIL (|has| (-581 |#1|) (-370)))) (-4051 (((-121) $) NIL)) (-4025 (((-1108) $) NIL)) (-2707 (($) NIL (|has| (-581 |#1|) (-370)))) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) NIL (|has| (-581 |#1|) (-370)))) (-3850 (((-420 $) $) NIL)) (-4321 (((-828 (-917))) NIL) (((-917)) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-2721 (((-763) $) NIL (|has| (-581 |#1|) (-370))) (((-3 (-763) "failed") $ $) NIL (-2199 (|has| (-581 |#1|) (-148)) (|has| (-581 |#1|) (-370))))) (-3108 (((-139)) NIL)) (-4191 (($ $) NIL (|has| (-581 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-581 |#1|) (-370)))) (-1836 (((-828 (-917)) $) NIL) (((-917) $) NIL)) (-1492 (((-1157 (-581 |#1|))) NIL)) (-2330 (($) NIL (|has| (-581 |#1|) (-370)))) (-1398 (($) NIL (|has| (-581 |#1|) (-370)))) (-1656 (((-1244 (-581 |#1|)) $) NIL) (((-679 (-581 |#1|)) (-1244 $)) NIL)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| (-581 |#1|) (-370)))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ (-581 |#1|)) NIL)) (-3385 (($ $) NIL (|has| (-581 |#1|) (-370))) (((-3 $ "failed") $) NIL (-2199 (|has| (-581 |#1|) (-148)) (|has| (-581 |#1|) (-370))))) (-3425 (((-763)) NIL)) (-2588 (((-1244 $)) NIL) (((-1244 $) (-917)) NIL)) (-2273 (((-121) $ $) NIL)) (-1413 (((-121) $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3412 (($ $) NIL (|has| (-581 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-581 |#1|) (-370)))) (-3192 (($ $) NIL (|has| (-581 |#1|) (-370))) (($ $ (-763)) NIL (|has| (-581 |#1|) (-370)))) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ $) NIL) (($ $ (-581 |#1|)) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ $ (-581 |#1|)) NIL) (($ (-581 |#1|) $) NIL))) 
 (((-526 |#1| |#2|) (-327 (-581 |#1|)) (-917) (-917)) (T -526)) 
 NIL 
 (-327 (-581 |#1|)) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2510 (((-121) $ (-763)) NIL)) (-2436 ((|#1| $ (-568) (-568) |#1|) 33)) (-4159 (($ $ (-568) |#4|) NIL)) (-2451 (($ $ (-568) |#5|) NIL)) (-2671 (($) NIL T CONST)) (-1818 ((|#4| $ (-568)) NIL)) (-3989 ((|#1| $ (-568) (-568) |#1|) 32)) (-2602 ((|#1| $ (-568) (-568)) 30)) (-4360 (((-634 |#1|) $) NIL)) (-3043 (((-763) $) 26)) (-1849 (($ (-763) (-763) |#1|) 23)) (-2555 (((-763) $) 28)) (-1737 (((-121) $ (-763)) NIL)) (-2087 (((-568) $) 24)) (-3364 (((-568) $) 25)) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-1663 (((-568) $) 27)) (-2893 (((-568) $) 29)) (-3674 (($ (-1 |#1| |#1|) $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) 36 (|has| |#1| (-1090)))) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3724 (($ $ |#1|) NIL)) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) 14)) (-3248 (($) 15)) (-2779 ((|#1| $ (-568) (-568)) 31) ((|#1| $ (-568) (-568) |#1|) NIL)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) NIL)) (-3731 ((|#5| $ (-568)) NIL)) (-2745 (((-850) $) NIL (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1667 (((-121) $ (-763)) NIL)) (-2438 ((|#1| $ (-568) (-568) |#1|) 33)) (-3874 (($ $ (-568) |#4|) NIL)) (-2525 (($ $ (-568) |#5|) NIL)) (-4490 (($) NIL T CONST)) (-2228 ((|#4| $ (-568)) NIL)) (-1292 ((|#1| $ (-568) (-568) |#1|) 32)) (-2069 ((|#1| $ (-568) (-568)) 30)) (-3317 (((-634 |#1|) $) NIL)) (-2241 (((-763) $) 26)) (-1851 (($ (-763) (-763) |#1|) 23)) (-1901 (((-763) $) 28)) (-3791 (((-121) $ (-763)) NIL)) (-3139 (((-568) $) 24)) (-1343 (((-568) $) 25)) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3405 (((-568) $) 27)) (-2801 (((-568) $) 29)) (-2253 (($ (-1 |#1| |#1|) $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) 36 (|has| |#1| (-1090)))) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-2490 (($ $ |#1|) NIL)) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) 14)) (-1990 (($) 15)) (-2781 ((|#1| $ (-568) (-568)) 31) ((|#1| $ (-568) (-568) |#1|) NIL)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) NIL)) (-2522 ((|#5| $ (-568)) NIL)) (-2747 (((-850) $) NIL (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
 (((-527 |#1| |#2| |#3| |#4| |#5|) (-62 |#1| |#4| |#5|) (-1195) (-568) (-568) (-375 |#1|) (-375 |#1|)) (T -527)) 
 NIL 
 (-62 |#1| |#4| |#5|) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2850 ((|#1| $) NIL)) (-2235 ((|#1| $) NIL)) (-2796 (($ $) NIL)) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-3910 (($ $ (-568)) 57 (|has| $ (-6 -4520)))) (-2016 (((-121) $) NIL (|has| |#1| (-842))) (((-121) (-1 (-121) |#1| |#1|) $) NIL)) (-3908 (($ $) NIL (-12 (|has| $ (-6 -4520)) (|has| |#1| (-842)))) (($ (-1 (-121) |#1| |#1|) $) 55 (|has| $ (-6 -4520)))) (-3644 (($ $) NIL (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-1659 ((|#1| $ |#1|) NIL (|has| $ (-6 -4520)))) (-3869 (($ $ $) 23 (|has| $ (-6 -4520)))) (-2395 ((|#1| $ |#1|) NIL (|has| $ (-6 -4520)))) (-2517 ((|#1| $ |#1|) 21 (|has| $ (-6 -4520)))) (-2436 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4520))) ((|#1| $ "first" |#1|) 22 (|has| $ (-6 -4520))) (($ $ "rest" $) 24 (|has| $ (-6 -4520))) ((|#1| $ "last" |#1|) NIL (|has| $ (-6 -4520))) ((|#1| $ (-1210 (-568)) |#1|) NIL (|has| $ (-6 -4520))) ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) NIL (|has| $ (-6 -4520)))) (-3507 (($ (-1 (-121) |#1|) $) NIL)) (-2801 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1679 ((|#1| $) NIL)) (-2671 (($) NIL T CONST)) (-1578 (($ $) 28 (|has| $ (-6 -4520)))) (-3943 (($ $) 29)) (-3935 (($ $) 18) (($ $ (-763)) 32)) (-3369 (($ $) 53 (|has| |#1| (-1090)))) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3405 (($ |#1| $) NIL (|has| |#1| (-1090))) (($ (-1 (-121) |#1|) $) NIL)) (-4328 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (($ |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3989 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-568)) NIL)) (-1601 (((-121) $) NIL)) (-2764 (((-568) |#1| $ (-568)) NIL (|has| |#1| (-1090))) (((-568) |#1| $) NIL (|has| |#1| (-1090))) (((-568) (-1 (-121) |#1|) $) NIL)) (-4360 (((-634 |#1|) $) 27 (|has| $ (-6 -4519)))) (-2287 (((-634 $) $) NIL)) (-1700 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1849 (($ (-763) |#1|) NIL)) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) 31 (|has| (-568) (-842)))) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-3349 (($ $ $) NIL (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $ $) 56)) (-1347 (($ $ $) NIL (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $ $) NIL)) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 51 (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2223 (((-568) $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-3674 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-3896 (($ |#1|) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-2869 (((-634 |#1|) $) NIL)) (-1651 (((-121) $) NIL)) (-4487 (((-1143) $) 50 (|has| |#1| (-1090)))) (-4162 ((|#1| $) NIL) (($ $ (-763)) NIL)) (-4450 (($ $ $ (-568)) NIL) (($ |#1| $ (-568)) NIL)) (-4122 (($ $ $ (-568)) NIL) (($ |#1| $ (-568)) NIL)) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3876 ((|#1| $) 13) (($ $ (-763)) NIL)) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3724 (($ $ |#1|) NIL (|has| $ (-6 -4520)))) (-1786 (((-121) $) NIL)) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 12)) (-4467 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) NIL)) (-3084 (((-121) $) 17)) (-3248 (($) 16)) (-2779 ((|#1| $ "value") NIL) ((|#1| $ "first") 15) (($ $ "rest") 20) ((|#1| $ "last") NIL) (($ $ (-1210 (-568))) NIL) ((|#1| $ (-568)) NIL) ((|#1| $ (-568) |#1|) NIL)) (-4075 (((-568) $ $) NIL)) (-1783 (($ $ (-1210 (-568))) NIL) (($ $ (-568)) NIL)) (-2826 (($ $ (-1210 (-568))) NIL) (($ $ (-568)) NIL)) (-3790 (((-121) $) 33)) (-2340 (($ $) NIL)) (-2714 (($ $) NIL (|has| $ (-6 -4520)))) (-2775 (((-763) $) NIL)) (-3335 (($ $) 35)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2256 (($ $ $ (-568)) NIL (|has| $ (-6 -4520)))) (-3863 (($ $) 34)) (-4278 (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) 26)) (-3845 (($ $ $) 52) (($ $ |#1|) NIL)) (-2768 (($ $ $) NIL) (($ |#1| $) 10) (($ (-634 $)) NIL) (($ $ |#1|) NIL)) (-2745 (((-850) $) 45 (|has| |#1| (-1090)))) (-4339 (((-634 $) $) NIL)) (-3491 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) 47 (|has| |#1| (-1090)))) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1697 (((-763) $) 9 (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2852 ((|#1| $) NIL)) (-2237 ((|#1| $) NIL)) (-3623 (($ $) NIL)) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-2121 (($ $ (-568)) 57 (|has| $ (-6 -4522)))) (-1324 (((-121) $) NIL (|has| |#1| (-842))) (((-121) (-1 (-121) |#1| |#1|) $) NIL)) (-2109 (($ $) NIL (-12 (|has| $ (-6 -4522)) (|has| |#1| (-842)))) (($ (-1 (-121) |#1| |#1|) $) 55 (|has| $ (-6 -4522)))) (-3647 (($ $) NIL (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-3370 ((|#1| $ |#1|) NIL (|has| $ (-6 -4522)))) (-1958 (($ $ $) 23 (|has| $ (-6 -4522)))) (-2257 ((|#1| $ |#1|) NIL (|has| $ (-6 -4522)))) (-1706 ((|#1| $ |#1|) 21 (|has| $ (-6 -4522)))) (-2438 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4522))) ((|#1| $ "first" |#1|) 22 (|has| $ (-6 -4522))) (($ $ "rest" $) 24 (|has| $ (-6 -4522))) ((|#1| $ "last" |#1|) NIL (|has| $ (-6 -4522))) ((|#1| $ (-1210 (-568)) |#1|) NIL (|has| $ (-6 -4522))) ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) NIL (|has| $ (-6 -4522)))) (-3963 (($ (-1 (-121) |#1|) $) NIL)) (-2803 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1681 ((|#1| $) NIL)) (-4490 (($) NIL T CONST)) (-4452 (($ $) 28 (|has| $ (-6 -4522)))) (-3945 (($ $) 29)) (-3936 (($ $) 18) (($ $ (-763)) 32)) (-1377 (($ $) 53 (|has| |#1| (-1090)))) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1568 (($ |#1| $) NIL (|has| |#1| (-1090))) (($ (-1 (-121) |#1|) $) NIL)) (-4330 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (($ |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1292 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-568)) NIL)) (-1340 (((-121) $) NIL)) (-2766 (((-568) |#1| $ (-568)) NIL (|has| |#1| (-1090))) (((-568) |#1| $) NIL (|has| |#1| (-1090))) (((-568) (-1 (-121) |#1|) $) NIL)) (-3317 (((-634 |#1|) $) 27 (|has| $ (-6 -4521)))) (-3534 (((-634 $) $) NIL)) (-3606 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1851 (($ (-763) |#1|) NIL)) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) 31 (|has| (-568) (-842)))) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-4496 (($ $ $) NIL (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $ $) 56)) (-3645 (($ $ $) NIL (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $ $) NIL)) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 51 (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3631 (((-568) $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-2253 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-3897 (($ |#1|) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-4081 (((-634 |#1|) $) NIL)) (-3319 (((-121) $) NIL)) (-1893 (((-1143) $) 50 (|has| |#1| (-1090)))) (-4164 ((|#1| $) NIL) (($ $ (-763)) NIL)) (-1708 (($ $ $ (-568)) NIL) (($ |#1| $ (-568)) NIL)) (-4124 (($ $ $ (-568)) NIL) (($ |#1| $ (-568)) NIL)) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3877 ((|#1| $) 13) (($ $ (-763)) NIL)) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-2490 (($ $ |#1|) NIL (|has| $ (-6 -4522)))) (-4049 (((-121) $) NIL)) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 12)) (-1801 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) NIL)) (-2436 (((-121) $) 17)) (-1990 (($) 16)) (-2781 ((|#1| $ "value") NIL) ((|#1| $ "first") 15) (($ $ "rest") 20) ((|#1| $ "last") NIL) (($ $ (-1210 (-568))) NIL) ((|#1| $ (-568)) NIL) ((|#1| $ (-568) |#1|) NIL)) (-1665 (((-568) $ $) NIL)) (-4031 (($ $ (-1210 (-568))) NIL) (($ $ (-568)) NIL)) (-2828 (($ $ (-1210 (-568))) NIL) (($ $ (-568)) NIL)) (-2763 (((-121) $) 33)) (-3903 (($ $) NIL)) (-1499 (($ $) NIL (|has| $ (-6 -4522)))) (-3535 (((-763) $) NIL)) (-4424 (($ $) 35)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3306 (($ $ $ (-568)) NIL (|has| $ (-6 -4522)))) (-3865 (($ $) 34)) (-4280 (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) 26)) (-1876 (($ $ $) 52) (($ $ |#1|) NIL)) (-2770 (($ $ $) NIL) (($ |#1| $) 10) (($ (-634 $)) NIL) (($ $ |#1|) NIL)) (-2747 (((-850) $) 45 (|has| |#1| (-1090)))) (-3180 (((-634 $) $) NIL)) (-3873 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) 47 (|has| |#1| (-1090)))) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1699 (((-763) $) 9 (|has| $ (-6 -4521))))) 
 (((-528 |#1| |#2|) (-658 |#1|) (-1195) (-568)) (T -528)) 
 NIL 
 (-658 |#1|) 
-((-4167 ((|#4| |#4|) 26)) (-3700 (((-763) |#4|) 31)) (-2121 (((-763) |#4|) 32)) (-4272 (((-634 |#3|) |#4|) 37 (|has| |#3| (-6 -4520)))) (-3140 (((-3 |#4| "failed") |#4|) 47)) (-1463 ((|#4| |#4|) 40)) (-2465 ((|#1| |#4|) 39))) 
-(((-529 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4167 (|#4| |#4|)) (-15 -3700 ((-763) |#4|)) (-15 -2121 ((-763) |#4|)) (IF (|has| |#3| (-6 -4520)) (-15 -4272 ((-634 |#3|) |#4|)) |noBranch|) (-15 -2465 (|#1| |#4|)) (-15 -1463 (|#4| |#4|)) (-15 -3140 ((-3 |#4| "failed") |#4|))) (-365) (-375 |#1|) (-375 |#1|) (-677 |#1| |#2| |#3|)) (T -529)) 
-((-3140 (*1 *2 *2) (|partial| -12 (-4 *3 (-365)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-529 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) (-1463 (*1 *2 *2) (-12 (-4 *3 (-365)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-529 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) (-2465 (*1 *2 *3) (-12 (-4 *4 (-375 *2)) (-4 *5 (-375 *2)) (-4 *2 (-365)) (-5 *1 (-529 *2 *4 *5 *3)) (-4 *3 (-677 *2 *4 *5)))) (-4272 (*1 *2 *3) (-12 (|has| *6 (-6 -4520)) (-4 *4 (-365)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-634 *6)) (-5 *1 (-529 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) (-2121 (*1 *2 *3) (-12 (-4 *4 (-365)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-763)) (-5 *1 (-529 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) (-3700 (*1 *2 *3) (-12 (-4 *4 (-365)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-763)) (-5 *1 (-529 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) (-4167 (*1 *2 *2) (-12 (-4 *3 (-365)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-529 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5))))) 
-(-10 -7 (-15 -4167 (|#4| |#4|)) (-15 -3700 ((-763) |#4|)) (-15 -2121 ((-763) |#4|)) (IF (|has| |#3| (-6 -4520)) (-15 -4272 ((-634 |#3|) |#4|)) |noBranch|) (-15 -2465 (|#1| |#4|)) (-15 -1463 (|#4| |#4|)) (-15 -3140 ((-3 |#4| "failed") |#4|))) 
-((-4167 ((|#8| |#4|) 20)) (-4272 (((-634 |#3|) |#4|) 29 (|has| |#7| (-6 -4520)))) (-3140 (((-3 |#8| "failed") |#4|) 23))) 
-(((-530 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -4167 (|#8| |#4|)) (-15 -3140 ((-3 |#8| "failed") |#4|)) (IF (|has| |#7| (-6 -4520)) (-15 -4272 ((-634 |#3|) |#4|)) |noBranch|)) (-558) (-375 |#1|) (-375 |#1|) (-677 |#1| |#2| |#3|) (-993 |#1|) (-375 |#5|) (-375 |#5|) (-677 |#5| |#6| |#7|)) (T -530)) 
-((-4272 (*1 *2 *3) (-12 (|has| *9 (-6 -4520)) (-4 *4 (-558)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-4 *7 (-993 *4)) (-4 *8 (-375 *7)) (-4 *9 (-375 *7)) (-5 *2 (-634 *6)) (-5 *1 (-530 *4 *5 *6 *3 *7 *8 *9 *10)) (-4 *3 (-677 *4 *5 *6)) (-4 *10 (-677 *7 *8 *9)))) (-3140 (*1 *2 *3) (|partial| -12 (-4 *4 (-558)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-4 *7 (-993 *4)) (-4 *2 (-677 *7 *8 *9)) (-5 *1 (-530 *4 *5 *6 *3 *7 *8 *9 *2)) (-4 *3 (-677 *4 *5 *6)) (-4 *8 (-375 *7)) (-4 *9 (-375 *7)))) (-4167 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-4 *7 (-993 *4)) (-4 *2 (-677 *7 *8 *9)) (-5 *1 (-530 *4 *5 *6 *3 *7 *8 *9 *2)) (-4 *3 (-677 *4 *5 *6)) (-4 *8 (-375 *7)) (-4 *9 (-375 *7))))) 
-(-10 -7 (-15 -4167 (|#8| |#4|)) (-15 -3140 ((-3 |#8| "failed") |#4|)) (IF (|has| |#7| (-6 -4520)) (-15 -4272 ((-634 |#3|) |#4|)) |noBranch|)) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3205 (($ (-763) (-763)) NIL)) (-3347 (($ $ $) NIL)) (-2870 (($ (-599 |#1| |#3|)) NIL) (($ $) NIL)) (-1335 (((-121) $) NIL)) (-4343 (($ $ (-568) (-568)) 12)) (-3622 (($ $ (-568) (-568)) NIL)) (-3676 (($ $ (-568) (-568) (-568) (-568)) NIL)) (-3976 (($ $) NIL)) (-2230 (((-121) $) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-1785 (($ $ (-568) (-568) $) NIL)) (-2436 ((|#1| $ (-568) (-568) |#1|) NIL) (($ $ (-634 (-568)) (-634 (-568)) $) NIL)) (-4159 (($ $ (-568) (-599 |#1| |#3|)) NIL)) (-2451 (($ $ (-568) (-599 |#1| |#2|)) NIL)) (-3422 (($ (-763) |#1|) NIL)) (-2671 (($) NIL T CONST)) (-4167 (($ $) 19 (|has| |#1| (-301)))) (-1818 (((-599 |#1| |#3|) $ (-568)) NIL)) (-3700 (((-763) $) 22 (|has| |#1| (-558)))) (-3989 ((|#1| $ (-568) (-568) |#1|) NIL)) (-2602 ((|#1| $ (-568) (-568)) NIL)) (-2076 ((|#1| $) NIL (|has| |#1| (-172)))) (-4360 (((-634 |#1|) $) NIL)) (-2121 (((-763) $) 24 (|has| |#1| (-558)))) (-4272 (((-634 (-599 |#1| |#2|)) $) 27 (|has| |#1| (-558)))) (-3043 (((-763) $) NIL)) (-1849 (($ (-763) (-763) |#1|) NIL)) (-2555 (((-763) $) NIL)) (-1737 (((-121) $ (-763)) NIL)) (-3082 ((|#1| $) 17 (|has| |#1| (-6 (-4521 "*"))))) (-2087 (((-568) $) 10)) (-3364 (((-568) $) NIL)) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-1663 (((-568) $) 11)) (-2893 (((-568) $) NIL)) (-2269 (($ (-634 (-634 |#1|))) NIL)) (-3674 (($ (-1 |#1| |#1|) $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-3208 (((-634 (-634 |#1|)) $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-3140 (((-3 $ "failed") $) 31 (|has| |#1| (-365)))) (-2858 (($ $ $) NIL)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3724 (($ $ |#1|) NIL)) (-2595 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558)))) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#1| $ (-568) (-568)) NIL) ((|#1| $ (-568) (-568) |#1|) NIL) (($ $ (-634 (-568)) (-634 (-568))) NIL)) (-2282 (($ (-634 |#1|)) NIL) (($ (-634 $)) NIL)) (-1960 (((-121) $) NIL)) (-2465 ((|#1| $) 15 (|has| |#1| (-6 (-4521 "*"))))) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) NIL)) (-2365 (((-634 (-599 |#1| |#2|)) $) NIL (|has| |#1| (-301)))) (-3731 (((-599 |#1| |#2|) $ (-568)) NIL)) (-2745 (((-850) $) NIL (|has| |#1| (-1090))) (($ (-599 |#1| |#2|)) NIL)) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1910 (((-121) $) NIL)) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1773 (($ $ $) NIL) (($ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (* (($ $ $) NIL) (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ (-568) $) NIL) (((-599 |#1| |#2|) $ (-599 |#1| |#2|)) NIL) (((-599 |#1| |#3|) (-599 |#1| |#3|) $) NIL)) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
+((-3912 ((|#4| |#4|) 26)) (-2371 (((-763) |#4|) 31)) (-3344 (((-763) |#4|) 32)) (-2934 (((-634 |#3|) |#4|) 37 (|has| |#3| (-6 -4522)))) (-2715 (((-3 |#4| "failed") |#4|) 47)) (-2415 ((|#4| |#4|) 40)) (-2591 ((|#1| |#4|) 39))) 
+(((-529 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3912 (|#4| |#4|)) (-15 -2371 ((-763) |#4|)) (-15 -3344 ((-763) |#4|)) (IF (|has| |#3| (-6 -4522)) (-15 -2934 ((-634 |#3|) |#4|)) |noBranch|) (-15 -2591 (|#1| |#4|)) (-15 -2415 (|#4| |#4|)) (-15 -2715 ((-3 |#4| "failed") |#4|))) (-365) (-375 |#1|) (-375 |#1|) (-677 |#1| |#2| |#3|)) (T -529)) 
+((-2715 (*1 *2 *2) (|partial| -12 (-4 *3 (-365)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-529 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) (-2415 (*1 *2 *2) (-12 (-4 *3 (-365)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-529 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) (-2591 (*1 *2 *3) (-12 (-4 *4 (-375 *2)) (-4 *5 (-375 *2)) (-4 *2 (-365)) (-5 *1 (-529 *2 *4 *5 *3)) (-4 *3 (-677 *2 *4 *5)))) (-2934 (*1 *2 *3) (-12 (|has| *6 (-6 -4522)) (-4 *4 (-365)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-634 *6)) (-5 *1 (-529 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) (-3344 (*1 *2 *3) (-12 (-4 *4 (-365)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-763)) (-5 *1 (-529 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) (-2371 (*1 *2 *3) (-12 (-4 *4 (-365)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-763)) (-5 *1 (-529 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) (-3912 (*1 *2 *2) (-12 (-4 *3 (-365)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-529 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5))))) 
+(-10 -7 (-15 -3912 (|#4| |#4|)) (-15 -2371 ((-763) |#4|)) (-15 -3344 ((-763) |#4|)) (IF (|has| |#3| (-6 -4522)) (-15 -2934 ((-634 |#3|) |#4|)) |noBranch|) (-15 -2591 (|#1| |#4|)) (-15 -2415 (|#4| |#4|)) (-15 -2715 ((-3 |#4| "failed") |#4|))) 
+((-3912 ((|#8| |#4|) 20)) (-2934 (((-634 |#3|) |#4|) 29 (|has| |#7| (-6 -4522)))) (-2715 (((-3 |#8| "failed") |#4|) 23))) 
+(((-530 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -3912 (|#8| |#4|)) (-15 -2715 ((-3 |#8| "failed") |#4|)) (IF (|has| |#7| (-6 -4522)) (-15 -2934 ((-634 |#3|) |#4|)) |noBranch|)) (-558) (-375 |#1|) (-375 |#1|) (-677 |#1| |#2| |#3|) (-993 |#1|) (-375 |#5|) (-375 |#5|) (-677 |#5| |#6| |#7|)) (T -530)) 
+((-2934 (*1 *2 *3) (-12 (|has| *9 (-6 -4522)) (-4 *4 (-558)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-4 *7 (-993 *4)) (-4 *8 (-375 *7)) (-4 *9 (-375 *7)) (-5 *2 (-634 *6)) (-5 *1 (-530 *4 *5 *6 *3 *7 *8 *9 *10)) (-4 *3 (-677 *4 *5 *6)) (-4 *10 (-677 *7 *8 *9)))) (-2715 (*1 *2 *3) (|partial| -12 (-4 *4 (-558)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-4 *7 (-993 *4)) (-4 *2 (-677 *7 *8 *9)) (-5 *1 (-530 *4 *5 *6 *3 *7 *8 *9 *2)) (-4 *3 (-677 *4 *5 *6)) (-4 *8 (-375 *7)) (-4 *9 (-375 *7)))) (-3912 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-4 *7 (-993 *4)) (-4 *2 (-677 *7 *8 *9)) (-5 *1 (-530 *4 *5 *6 *3 *7 *8 *9 *2)) (-4 *3 (-677 *4 *5 *6)) (-4 *8 (-375 *7)) (-4 *9 (-375 *7))))) 
+(-10 -7 (-15 -3912 (|#8| |#4|)) (-15 -2715 ((-3 |#8| "failed") |#4|)) (IF (|has| |#7| (-6 -4522)) (-15 -2934 ((-634 |#3|) |#4|)) |noBranch|)) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3207 (($ (-763) (-763)) NIL)) (-4486 (($ $ $) NIL)) (-4089 (($ (-599 |#1| |#3|)) NIL) (($ $) NIL)) (-3560 (((-121) $) NIL)) (-3211 (($ $ (-568) (-568)) 12)) (-3096 (($ $ (-568) (-568)) NIL)) (-2265 (($ $ (-568) (-568) (-568) (-568)) NIL)) (-4467 (($ $) NIL)) (-3691 (((-121) $) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-4043 (($ $ (-568) (-568) $) NIL)) (-2438 ((|#1| $ (-568) (-568) |#1|) NIL) (($ $ (-634 (-568)) (-634 (-568)) $) NIL)) (-3874 (($ $ (-568) (-599 |#1| |#3|)) NIL)) (-2525 (($ $ (-568) (-599 |#1| |#2|)) NIL)) (-1637 (($ (-763) |#1|) NIL)) (-4490 (($) NIL T CONST)) (-3912 (($ $) 19 (|has| |#1| (-301)))) (-2228 (((-599 |#1| |#3|) $ (-568)) NIL)) (-2371 (((-763) $) 22 (|has| |#1| (-558)))) (-1292 ((|#1| $ (-568) (-568) |#1|) NIL)) (-2069 ((|#1| $ (-568) (-568)) NIL)) (-3102 ((|#1| $) NIL (|has| |#1| (-172)))) (-3317 (((-634 |#1|) $) NIL)) (-3344 (((-763) $) 24 (|has| |#1| (-558)))) (-2934 (((-634 (-599 |#1| |#2|)) $) 27 (|has| |#1| (-558)))) (-2241 (((-763) $) NIL)) (-1851 (($ (-763) (-763) |#1|) NIL)) (-1901 (((-763) $) NIL)) (-3791 (((-121) $ (-763)) NIL)) (-2424 ((|#1| $) 17 (|has| |#1| (-6 (-4523 "*"))))) (-3139 (((-568) $) 10)) (-1343 (((-568) $) NIL)) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3405 (((-568) $) 11)) (-2801 (((-568) $) NIL)) (-2271 (($ (-634 (-634 |#1|))) NIL)) (-2253 (($ (-1 |#1| |#1|) $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-1843 (((-634 (-634 |#1|)) $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-2715 (((-3 $ "failed") $) 31 (|has| |#1| (-365)))) (-4018 (($ $ $) NIL)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-2490 (($ $ |#1|) NIL)) (-2597 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558)))) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#1| $ (-568) (-568)) NIL) ((|#1| $ (-568) (-568) |#1|) NIL) (($ $ (-634 (-568)) (-634 (-568))) NIL)) (-3499 (($ (-634 |#1|)) NIL) (($ (-634 $)) NIL)) (-4322 (((-121) $) NIL)) (-2591 ((|#1| $) 15 (|has| |#1| (-6 (-4523 "*"))))) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) NIL)) (-4063 (((-634 (-599 |#1| |#2|)) $) NIL (|has| |#1| (-301)))) (-2522 (((-599 |#1| |#2|) $ (-568)) NIL)) (-2747 (((-850) $) NIL (|has| |#1| (-1090))) (($ (-599 |#1| |#2|)) NIL)) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-2675 (((-121) $) NIL)) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1775 (($ $ $) NIL) (($ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (* (($ $ $) NIL) (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ (-568) $) NIL) (((-599 |#1| |#2|) $ (-599 |#1| |#2|)) NIL) (((-599 |#1| |#3|) (-599 |#1| |#3|) $) NIL)) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
 (((-531 |#1| |#2| |#3|) (-677 |#1| (-599 |#1| |#3|) (-599 |#1| |#2|)) (-1047) (-568) (-568)) (T -531)) 
 NIL 
 (-677 |#1| (-599 |#1| |#3|) (-599 |#1| |#2|)) 
-((-2376 (((-1157 |#1|) (-763)) 74)) (-1932 (((-1244 |#1|) (-1244 |#1|) (-917)) 67)) (-4464 (((-1249) (-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108))))) |#1|) 82)) (-2840 (((-1244 |#1|) (-1244 |#1|) (-763)) 36)) (-1731 (((-1244 |#1|) (-917)) 69)) (-1963 (((-1244 |#1|) (-1244 |#1|) (-568)) 24)) (-2700 (((-1157 |#1|) (-1244 |#1|)) 75)) (-2883 (((-1244 |#1|) (-917)) 93)) (-3917 (((-121) (-1244 |#1|)) 78)) (-2657 (((-1244 |#1|) (-1244 |#1|) (-917)) 59)) (-2045 (((-1157 |#1|) (-1244 |#1|)) 87)) (-3683 (((-917) (-1244 |#1|)) 56)) (-2081 (((-1244 |#1|) (-1244 |#1|)) 30)) (-4355 (((-1244 |#1|) (-917) (-917)) 95)) (-4271 (((-1244 |#1|) (-1244 |#1|) (-1108) (-1108)) 23)) (-2329 (((-1244 |#1|) (-1244 |#1|) (-763) (-1108)) 37)) (-3746 (((-1244 (-1244 |#1|)) (-917)) 92)) (-1779 (((-1244 |#1|) (-1244 |#1|) (-1244 |#1|)) 79)) (** (((-1244 |#1|) (-1244 |#1|) (-568)) 43)) (* (((-1244 |#1|) (-1244 |#1|) (-1244 |#1|)) 25))) 
-(((-532 |#1|) (-10 -7 (-15 -4464 ((-1249) (-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108))))) |#1|)) (-15 -1731 ((-1244 |#1|) (-917))) (-15 -4355 ((-1244 |#1|) (-917) (-917))) (-15 -2700 ((-1157 |#1|) (-1244 |#1|))) (-15 -2376 ((-1157 |#1|) (-763))) (-15 -2329 ((-1244 |#1|) (-1244 |#1|) (-763) (-1108))) (-15 -2840 ((-1244 |#1|) (-1244 |#1|) (-763))) (-15 -4271 ((-1244 |#1|) (-1244 |#1|) (-1108) (-1108))) (-15 -1963 ((-1244 |#1|) (-1244 |#1|) (-568))) (-15 ** ((-1244 |#1|) (-1244 |#1|) (-568))) (-15 * ((-1244 |#1|) (-1244 |#1|) (-1244 |#1|))) (-15 -1779 ((-1244 |#1|) (-1244 |#1|) (-1244 |#1|))) (-15 -2657 ((-1244 |#1|) (-1244 |#1|) (-917))) (-15 -1932 ((-1244 |#1|) (-1244 |#1|) (-917))) (-15 -2081 ((-1244 |#1|) (-1244 |#1|))) (-15 -3683 ((-917) (-1244 |#1|))) (-15 -3917 ((-121) (-1244 |#1|))) (-15 -3746 ((-1244 (-1244 |#1|)) (-917))) (-15 -2883 ((-1244 |#1|) (-917))) (-15 -2045 ((-1157 |#1|) (-1244 |#1|)))) (-350)) (T -532)) 
-((-2045 (*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-350)) (-5 *2 (-1157 *4)) (-5 *1 (-532 *4)))) (-2883 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1244 *4)) (-5 *1 (-532 *4)) (-4 *4 (-350)))) (-3746 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1244 (-1244 *4))) (-5 *1 (-532 *4)) (-4 *4 (-350)))) (-3917 (*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-350)) (-5 *2 (-121)) (-5 *1 (-532 *4)))) (-3683 (*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-350)) (-5 *2 (-917)) (-5 *1 (-532 *4)))) (-2081 (*1 *2 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-350)) (-5 *1 (-532 *3)))) (-1932 (*1 *2 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-917)) (-4 *4 (-350)) (-5 *1 (-532 *4)))) (-2657 (*1 *2 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-917)) (-4 *4 (-350)) (-5 *1 (-532 *4)))) (-1779 (*1 *2 *2 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-350)) (-5 *1 (-532 *3)))) (* (*1 *2 *2 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-350)) (-5 *1 (-532 *3)))) (** (*1 *2 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-568)) (-4 *4 (-350)) (-5 *1 (-532 *4)))) (-1963 (*1 *2 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-568)) (-4 *4 (-350)) (-5 *1 (-532 *4)))) (-4271 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-1108)) (-4 *4 (-350)) (-5 *1 (-532 *4)))) (-2840 (*1 *2 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-763)) (-4 *4 (-350)) (-5 *1 (-532 *4)))) (-2329 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-1244 *5)) (-5 *3 (-763)) (-5 *4 (-1108)) (-4 *5 (-350)) (-5 *1 (-532 *5)))) (-2376 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1157 *4)) (-5 *1 (-532 *4)) (-4 *4 (-350)))) (-2700 (*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-350)) (-5 *2 (-1157 *4)) (-5 *1 (-532 *4)))) (-4355 (*1 *2 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1244 *4)) (-5 *1 (-532 *4)) (-4 *4 (-350)))) (-1731 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1244 *4)) (-5 *1 (-532 *4)) (-4 *4 (-350)))) (-4464 (*1 *2 *3 *4) (-12 (-5 *3 (-1244 (-634 (-2 (|:| -2850 *4) (|:| -4355 (-1108)))))) (-4 *4 (-350)) (-5 *2 (-1249)) (-5 *1 (-532 *4))))) 
-(-10 -7 (-15 -4464 ((-1249) (-1244 (-634 (-2 (|:| -2850 |#1|) (|:| -4355 (-1108))))) |#1|)) (-15 -1731 ((-1244 |#1|) (-917))) (-15 -4355 ((-1244 |#1|) (-917) (-917))) (-15 -2700 ((-1157 |#1|) (-1244 |#1|))) (-15 -2376 ((-1157 |#1|) (-763))) (-15 -2329 ((-1244 |#1|) (-1244 |#1|) (-763) (-1108))) (-15 -2840 ((-1244 |#1|) (-1244 |#1|) (-763))) (-15 -4271 ((-1244 |#1|) (-1244 |#1|) (-1108) (-1108))) (-15 -1963 ((-1244 |#1|) (-1244 |#1|) (-568))) (-15 ** ((-1244 |#1|) (-1244 |#1|) (-568))) (-15 * ((-1244 |#1|) (-1244 |#1|) (-1244 |#1|))) (-15 -1779 ((-1244 |#1|) (-1244 |#1|) (-1244 |#1|))) (-15 -2657 ((-1244 |#1|) (-1244 |#1|) (-917))) (-15 -1932 ((-1244 |#1|) (-1244 |#1|) (-917))) (-15 -2081 ((-1244 |#1|) (-1244 |#1|))) (-15 -3683 ((-917) (-1244 |#1|))) (-15 -3917 ((-121) (-1244 |#1|))) (-15 -3746 ((-1244 (-1244 |#1|)) (-917))) (-15 -2883 ((-1244 |#1|) (-917))) (-15 -2045 ((-1157 |#1|) (-1244 |#1|)))) 
-((-2785 (((-1 |#1| |#1|) |#1|) 11)) (-3806 (((-1 |#1| |#1|)) 10))) 
-(((-533 |#1|) (-10 -7 (-15 -3806 ((-1 |#1| |#1|))) (-15 -2785 ((-1 |#1| |#1|) |#1|))) (-13 (-716) (-25))) (T -533)) 
-((-2785 (*1 *2 *3) (-12 (-5 *2 (-1 *3 *3)) (-5 *1 (-533 *3)) (-4 *3 (-13 (-716) (-25))))) (-3806 (*1 *2) (-12 (-5 *2 (-1 *3 *3)) (-5 *1 (-533 *3)) (-4 *3 (-13 (-716) (-25)))))) 
-(-10 -7 (-15 -3806 ((-1 |#1| |#1|))) (-15 -2785 ((-1 |#1| |#1|) |#1|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-1462 (($ $ $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-2114 (($ $) NIL)) (-2047 (($ (-763) |#1|) NIL)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-2795 (($ (-1 (-763) (-763)) $) NIL)) (-1311 ((|#1| $) NIL)) (-2102 (((-763) $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 20)) (-3056 (($) NIL T CONST)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) NIL)) (-1767 (($ $ $) NIL)) (* (($ (-763) $) NIL) (($ (-917) $) NIL))) 
+((-2154 (((-1157 |#1|) (-763)) 74)) (-1934 (((-1244 |#1|) (-1244 |#1|) (-917)) 67)) (-1785 (((-1249) (-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108))))) |#1|) 82)) (-3904 (((-1244 |#1|) (-1244 |#1|) (-763)) 36)) (-1733 (((-1244 |#1|) (-917)) 69)) (-4335 (((-1244 |#1|) (-1244 |#1|) (-568)) 24)) (-1416 (((-1157 |#1|) (-1244 |#1|)) 75)) (-2769 (((-1244 |#1|) (-917)) 93)) (-2151 (((-121) (-1244 |#1|)) 78)) (-4417 (((-1244 |#1|) (-1244 |#1|) (-917)) 59)) (-1497 (((-1157 |#1|) (-1244 |#1|)) 87)) (-2291 (((-917) (-1244 |#1|)) 56)) (-2083 (((-1244 |#1|) (-1244 |#1|)) 30)) (-4357 (((-1244 |#1|) (-917) (-917)) 95)) (-2930 (((-1244 |#1|) (-1244 |#1|) (-1108) (-1108)) 23)) (-3837 (((-1244 |#1|) (-1244 |#1|) (-763) (-1108)) 37)) (-2588 (((-1244 (-1244 |#1|)) (-917)) 92)) (-1781 (((-1244 |#1|) (-1244 |#1|) (-1244 |#1|)) 79)) (** (((-1244 |#1|) (-1244 |#1|) (-568)) 43)) (* (((-1244 |#1|) (-1244 |#1|) (-1244 |#1|)) 25))) 
+(((-532 |#1|) (-10 -7 (-15 -1785 ((-1249) (-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108))))) |#1|)) (-15 -1733 ((-1244 |#1|) (-917))) (-15 -4357 ((-1244 |#1|) (-917) (-917))) (-15 -1416 ((-1157 |#1|) (-1244 |#1|))) (-15 -2154 ((-1157 |#1|) (-763))) (-15 -3837 ((-1244 |#1|) (-1244 |#1|) (-763) (-1108))) (-15 -3904 ((-1244 |#1|) (-1244 |#1|) (-763))) (-15 -2930 ((-1244 |#1|) (-1244 |#1|) (-1108) (-1108))) (-15 -4335 ((-1244 |#1|) (-1244 |#1|) (-568))) (-15 ** ((-1244 |#1|) (-1244 |#1|) (-568))) (-15 * ((-1244 |#1|) (-1244 |#1|) (-1244 |#1|))) (-15 -1781 ((-1244 |#1|) (-1244 |#1|) (-1244 |#1|))) (-15 -4417 ((-1244 |#1|) (-1244 |#1|) (-917))) (-15 -1934 ((-1244 |#1|) (-1244 |#1|) (-917))) (-15 -2083 ((-1244 |#1|) (-1244 |#1|))) (-15 -2291 ((-917) (-1244 |#1|))) (-15 -2151 ((-121) (-1244 |#1|))) (-15 -2588 ((-1244 (-1244 |#1|)) (-917))) (-15 -2769 ((-1244 |#1|) (-917))) (-15 -1497 ((-1157 |#1|) (-1244 |#1|)))) (-350)) (T -532)) 
+((-1497 (*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-350)) (-5 *2 (-1157 *4)) (-5 *1 (-532 *4)))) (-2769 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1244 *4)) (-5 *1 (-532 *4)) (-4 *4 (-350)))) (-2588 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1244 (-1244 *4))) (-5 *1 (-532 *4)) (-4 *4 (-350)))) (-2151 (*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-350)) (-5 *2 (-121)) (-5 *1 (-532 *4)))) (-2291 (*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-350)) (-5 *2 (-917)) (-5 *1 (-532 *4)))) (-2083 (*1 *2 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-350)) (-5 *1 (-532 *3)))) (-1934 (*1 *2 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-917)) (-4 *4 (-350)) (-5 *1 (-532 *4)))) (-4417 (*1 *2 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-917)) (-4 *4 (-350)) (-5 *1 (-532 *4)))) (-1781 (*1 *2 *2 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-350)) (-5 *1 (-532 *3)))) (* (*1 *2 *2 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-350)) (-5 *1 (-532 *3)))) (** (*1 *2 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-568)) (-4 *4 (-350)) (-5 *1 (-532 *4)))) (-4335 (*1 *2 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-568)) (-4 *4 (-350)) (-5 *1 (-532 *4)))) (-2930 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-1108)) (-4 *4 (-350)) (-5 *1 (-532 *4)))) (-3904 (*1 *2 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-763)) (-4 *4 (-350)) (-5 *1 (-532 *4)))) (-3837 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-1244 *5)) (-5 *3 (-763)) (-5 *4 (-1108)) (-4 *5 (-350)) (-5 *1 (-532 *5)))) (-2154 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1157 *4)) (-5 *1 (-532 *4)) (-4 *4 (-350)))) (-1416 (*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-350)) (-5 *2 (-1157 *4)) (-5 *1 (-532 *4)))) (-4357 (*1 *2 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1244 *4)) (-5 *1 (-532 *4)) (-4 *4 (-350)))) (-1733 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1244 *4)) (-5 *1 (-532 *4)) (-4 *4 (-350)))) (-1785 (*1 *2 *3 *4) (-12 (-5 *3 (-1244 (-634 (-2 (|:| -2852 *4) (|:| -4357 (-1108)))))) (-4 *4 (-350)) (-5 *2 (-1249)) (-5 *1 (-532 *4))))) 
+(-10 -7 (-15 -1785 ((-1249) (-1244 (-634 (-2 (|:| -2852 |#1|) (|:| -4357 (-1108))))) |#1|)) (-15 -1733 ((-1244 |#1|) (-917))) (-15 -4357 ((-1244 |#1|) (-917) (-917))) (-15 -1416 ((-1157 |#1|) (-1244 |#1|))) (-15 -2154 ((-1157 |#1|) (-763))) (-15 -3837 ((-1244 |#1|) (-1244 |#1|) (-763) (-1108))) (-15 -3904 ((-1244 |#1|) (-1244 |#1|) (-763))) (-15 -2930 ((-1244 |#1|) (-1244 |#1|) (-1108) (-1108))) (-15 -4335 ((-1244 |#1|) (-1244 |#1|) (-568))) (-15 ** ((-1244 |#1|) (-1244 |#1|) (-568))) (-15 * ((-1244 |#1|) (-1244 |#1|) (-1244 |#1|))) (-15 -1781 ((-1244 |#1|) (-1244 |#1|) (-1244 |#1|))) (-15 -4417 ((-1244 |#1|) (-1244 |#1|) (-917))) (-15 -1934 ((-1244 |#1|) (-1244 |#1|) (-917))) (-15 -2083 ((-1244 |#1|) (-1244 |#1|))) (-15 -2291 ((-917) (-1244 |#1|))) (-15 -2151 ((-121) (-1244 |#1|))) (-15 -2588 ((-1244 (-1244 |#1|)) (-917))) (-15 -2769 ((-1244 |#1|) (-917))) (-15 -1497 ((-1157 |#1|) (-1244 |#1|)))) 
+((-2787 (((-1 |#1| |#1|) |#1|) 11)) (-1713 (((-1 |#1| |#1|)) 10))) 
+(((-533 |#1|) (-10 -7 (-15 -1713 ((-1 |#1| |#1|))) (-15 -2787 ((-1 |#1| |#1|) |#1|))) (-13 (-716) (-25))) (T -533)) 
+((-2787 (*1 *2 *3) (-12 (-5 *2 (-1 *3 *3)) (-5 *1 (-533 *3)) (-4 *3 (-13 (-716) (-25))))) (-1713 (*1 *2) (-12 (-5 *2 (-1 *3 *3)) (-5 *1 (-533 *3)) (-4 *3 (-13 (-716) (-25)))))) 
+(-10 -7 (-15 -1713 ((-1 |#1| |#1|))) (-15 -2787 ((-1 |#1| |#1|) |#1|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2409 (($ $ $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-2116 (($ $) NIL)) (-2049 (($ (-763) |#1|) NIL)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-2797 (($ (-1 (-763) (-763)) $) NIL)) (-3369 ((|#1| $) NIL)) (-2104 (((-763) $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 20)) (-3058 (($) NIL T CONST)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) NIL)) (-1769 (($ $ $) NIL)) (* (($ (-763) $) NIL) (($ (-917) $) NIL))) 
 (((-534 |#1|) (-13 (-788) (-518 (-763) |#1|)) (-842)) (T -534)) 
 NIL 
 (-13 (-788) (-518 (-763) |#1|)) 
-((-2580 (((-634 |#2|) (-1157 |#1|) |#3|) 83)) (-4325 (((-634 (-2 (|:| |outval| |#2|) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 |#2|))))) (-679 |#1|) |#3| (-1 (-420 (-1157 |#1|)) (-1157 |#1|))) 99)) (-2871 (((-1157 |#1|) (-679 |#1|)) 95))) 
-(((-535 |#1| |#2| |#3|) (-10 -7 (-15 -2871 ((-1157 |#1|) (-679 |#1|))) (-15 -2580 ((-634 |#2|) (-1157 |#1|) |#3|)) (-15 -4325 ((-634 (-2 (|:| |outval| |#2|) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 |#2|))))) (-679 |#1|) |#3| (-1 (-420 (-1157 |#1|)) (-1157 |#1|))))) (-365) (-365) (-13 (-365) (-840))) (T -535)) 
-((-4325 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *6)) (-5 *5 (-1 (-420 (-1157 *6)) (-1157 *6))) (-4 *6 (-365)) (-5 *2 (-634 (-2 (|:| |outval| *7) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 *7)))))) (-5 *1 (-535 *6 *7 *4)) (-4 *7 (-365)) (-4 *4 (-13 (-365) (-840))))) (-2580 (*1 *2 *3 *4) (-12 (-5 *3 (-1157 *5)) (-4 *5 (-365)) (-5 *2 (-634 *6)) (-5 *1 (-535 *5 *6 *4)) (-4 *6 (-365)) (-4 *4 (-13 (-365) (-840))))) (-2871 (*1 *2 *3) (-12 (-5 *3 (-679 *4)) (-4 *4 (-365)) (-5 *2 (-1157 *4)) (-5 *1 (-535 *4 *5 *6)) (-4 *5 (-365)) (-4 *6 (-13 (-365) (-840)))))) 
-(-10 -7 (-15 -2871 ((-1157 |#1|) (-679 |#1|))) (-15 -2580 ((-634 |#2|) (-1157 |#1|) |#3|)) (-15 -4325 ((-634 (-2 (|:| |outval| |#2|) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 |#2|))))) (-679 |#1|) |#3| (-1 (-420 (-1157 |#1|)) (-1157 |#1|))))) 
-((-2447 (((-121) $ $) 7)) (-4436 (((-1161) $) 20)) (-1314 (((-763) $) 22)) (-1467 (((-1161) $ (-1161)) 23)) (-3470 (((-763) $ (-763)) 28)) (-1600 ((|#5| $ |#5|) 31)) (-3393 (((-763) $ (-763)) 27)) (-3675 (((-33 |#1|) $ (-33 |#1|)) 29)) (-2247 (((-634 |#6|) $ (-634 |#6|)) 24)) (-4476 ((|#8| $ |#8|) 25)) (-1398 (((-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) $ (-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|)) 30)) (-3524 ((|#9| $ |#9|) 26)) (-3642 ((|#5| $) 19)) (-3807 (((-763) $) 16)) (-3934 (((-33 |#1|) $) 17)) (-2134 (((-634 |#6|) $) 21)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-4394 ((|#8| $) 14)) (-3206 (((-917) $) 12)) (-4459 (((-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) $) 18)) (-2373 (($ |#5| (-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) (-33 |#1|) (-763) |#9| (-763) |#8| |#1| (-1161)) 33) (($ |#5| |#3|) 32)) (-2745 (((-850) $) 11)) (-1378 ((|#9| $) 15)) (-4248 ((|#1| $) 13)) (-1717 (((-121) $ $) 6))) 
-(((-536 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9|) (-1275) (-365) (-634 (-1161)) (-950 |t#1| |t#4| (-852 |t#2|)) (-230 (-1697 |t#2|) (-763)) (-971 |t#1|) (-641 |t#1|) (-920 |t#1| |t#6|) (-235 |t#7|) (-117)) (T -536)) 
-((-2373 (*1 *1 *2 *3 *4 *5 *6 *5 *7 *8 *9) (-12 (-5 *3 (-242 (-4287 (QUOTE X) (QUOTE -2926)) *8)) (-5 *4 (-33 *8)) (-5 *9 (-1161)) (-4 *8 (-365)) (-5 *5 (-763)) (-4 *12 (-230 (-1697 *10) *5)) (-4 *13 (-641 *8)) (-4 *14 (-920 *8 *13)) (-4 *1 (-536 *8 *10 *11 *12 *2 *13 *14 *7 *6)) (-4 *11 (-950 *8 *12 (-852 *10))) (-4 *2 (-971 *8)) (-4 *7 (-235 *14)) (-4 *6 (-117)))) (-2373 (*1 *1 *2 *3) (-12 (-4 *4 (-365)) (-4 *6 (-230 (-1697 *5) (-763))) (-4 *7 (-641 *4)) (-4 *8 (-920 *4 *7)) (-4 *1 (-536 *4 *5 *3 *6 *2 *7 *8 *9 *10)) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *2 (-971 *4)) (-4 *9 (-235 *8)) (-4 *10 (-117)))) (-1600 (*1 *2 *1 *2) (-12 (-4 *1 (-536 *3 *4 *5 *6 *2 *7 *8 *9 *10)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *2 (-971 *3)) (-4 *7 (-641 *3)) (-4 *8 (-920 *3 *7)) (-4 *9 (-235 *8)) (-4 *10 (-117)))) (-1398 (*1 *2 *1 *2) (-12 (-5 *2 (-242 (-4287 (QUOTE X) (QUOTE -2926)) *3)) (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)))) (-3675 (*1 *2 *1 *2) (-12 (-5 *2 (-33 *3)) (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)))) (-3470 (*1 *2 *1 *2) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) *2)) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-763)))) (-3393 (*1 *2 *1 *2) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) *2)) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-763)))) (-3524 (*1 *2 *1 *2) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *2)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *2 (-117)))) (-4476 (*1 *2 *1 *2) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *2 *10)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *2 (-235 *9)) (-4 *10 (-117)))) (-2247 (*1 *2 *1 *2) (-12 (-5 *2 (-634 *8)) (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)))) (-1467 (*1 *2 *1 *2) (-12 (-5 *2 (-1161)) (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)))) (-1314 (*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) *2)) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-763)))) (-2134 (*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-634 *8)))) (-4436 (*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-1161)))) (-3642 (*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *2 *7 *8 *9 *10)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-641 *3)) (-4 *8 (-920 *3 *7)) (-4 *9 (-235 *8)) (-4 *10 (-117)) (-4 *2 (-971 *3)))) (-4459 (*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-242 (-4287 (QUOTE X) (QUOTE -2926)) *3)))) (-3934 (*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-33 *3)))) (-3807 (*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) *2)) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-763)))) (-1378 (*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *2)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *2 (-117)))) (-4394 (*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *2 *10)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-117)) (-4 *2 (-235 *9)))) (-4248 (*1 *2 *1) (-12 (-4 *1 (-536 *2 *3 *4 *5 *6 *7 *8 *9 *10)) (-4 *4 (-950 *2 *5 (-852 *3))) (-4 *5 (-230 (-1697 *3) (-763))) (-4 *6 (-971 *2)) (-4 *7 (-641 *2)) (-4 *8 (-920 *2 *7)) (-4 *9 (-235 *8)) (-4 *10 (-117)) (-4 *2 (-365))))) 
-(-13 (-1088) (-10 -8 (-15 -2373 ($ |t#5| (-242 (-4287 (QUOTE X) (QUOTE -2926)) |t#1|) (-33 |t#1|) (-763) |t#9| (-763) |t#8| |t#1| (-1161))) (-15 -2373 ($ |t#5| |t#3|)) (-15 -1600 (|t#5| $ |t#5|)) (-15 -1398 ((-242 (-4287 (QUOTE X) (QUOTE -2926)) |t#1|) $ (-242 (-4287 (QUOTE X) (QUOTE -2926)) |t#1|))) (-15 -3675 ((-33 |t#1|) $ (-33 |t#1|))) (-15 -3470 ((-763) $ (-763))) (-15 -3393 ((-763) $ (-763))) (-15 -3524 (|t#9| $ |t#9|)) (-15 -4476 (|t#8| $ |t#8|)) (-15 -2247 ((-634 |t#6|) $ (-634 |t#6|))) (-15 -1467 ((-1161) $ (-1161))) (-15 -1314 ((-763) $)) (-15 -2134 ((-634 |t#6|) $)) (-15 -4436 ((-1161) $)) (-15 -3642 (|t#5| $)) (-15 -4459 ((-242 (-4287 (QUOTE X) (QUOTE -2926)) |t#1|) $)) (-15 -3934 ((-33 |t#1|) $)) (-15 -3807 ((-763) $)) (-15 -1378 (|t#9| $)) (-15 -4394 (|t#8| $)) (-15 -4248 (|t#1| $)))) 
+((-2001 (((-634 |#2|) (-1157 |#1|) |#3|) 83)) (-3124 (((-634 (-2 (|:| |outval| |#2|) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 |#2|))))) (-679 |#1|) |#3| (-1 (-420 (-1157 |#1|)) (-1157 |#1|))) 99)) (-4096 (((-1157 |#1|) (-679 |#1|)) 95))) 
+(((-535 |#1| |#2| |#3|) (-10 -7 (-15 -4096 ((-1157 |#1|) (-679 |#1|))) (-15 -2001 ((-634 |#2|) (-1157 |#1|) |#3|)) (-15 -3124 ((-634 (-2 (|:| |outval| |#2|) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 |#2|))))) (-679 |#1|) |#3| (-1 (-420 (-1157 |#1|)) (-1157 |#1|))))) (-365) (-365) (-13 (-365) (-840))) (T -535)) 
+((-3124 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *6)) (-5 *5 (-1 (-420 (-1157 *6)) (-1157 *6))) (-4 *6 (-365)) (-5 *2 (-634 (-2 (|:| |outval| *7) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 *7)))))) (-5 *1 (-535 *6 *7 *4)) (-4 *7 (-365)) (-4 *4 (-13 (-365) (-840))))) (-2001 (*1 *2 *3 *4) (-12 (-5 *3 (-1157 *5)) (-4 *5 (-365)) (-5 *2 (-634 *6)) (-5 *1 (-535 *5 *6 *4)) (-4 *6 (-365)) (-4 *4 (-13 (-365) (-840))))) (-4096 (*1 *2 *3) (-12 (-5 *3 (-679 *4)) (-4 *4 (-365)) (-5 *2 (-1157 *4)) (-5 *1 (-535 *4 *5 *6)) (-4 *5 (-365)) (-4 *6 (-13 (-365) (-840)))))) 
+(-10 -7 (-15 -4096 ((-1157 |#1|) (-679 |#1|))) (-15 -2001 ((-634 |#2|) (-1157 |#1|) |#3|)) (-15 -3124 ((-634 (-2 (|:| |outval| |#2|) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 |#2|))))) (-679 |#1|) |#3| (-1 (-420 (-1157 |#1|)) (-1157 |#1|))))) 
+((-2449 (((-121) $ $) 7)) (-1636 (((-1161) $) 20)) (-3396 (((-763) $) 22)) (-2439 (((-1161) $ (-1161)) 23)) (-3715 (((-763) $ (-763)) 28)) (-1332 ((|#5| $ |#5|) 31)) (-1501 (((-763) $ (-763)) 27)) (-2259 (((-33 |#1|) $ (-33 |#1|)) 29)) (-2870 (((-634 |#6|) $ (-634 |#6|)) 24)) (-1840 ((|#8| $ |#8|) 25)) (-2073 (((-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) $ (-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|)) 30)) (-4082 ((|#9| $ |#9|) 26)) (-3209 ((|#5| $) 19)) (-1721 (((-763) $) 16)) (-4288 (((-33 |#1|) $) 17)) (-3452 (((-634 |#6|) $) 21)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-1435 ((|#8| $) 14)) (-1836 (((-917) $) 12)) (-1764 (((-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) $) 18)) (-4116 (($ |#5| (-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) (-33 |#1|) (-763) |#9| (-763) |#8| |#1| (-1161)) 33) (($ |#5| |#3|) 32)) (-2747 (((-850) $) 11)) (-3888 ((|#9| $) 15)) (-2863 ((|#1| $) 13)) (-1719 (((-121) $ $) 6))) 
+(((-536 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9|) (-1275) (-365) (-634 (-1161)) (-950 |t#1| |t#4| (-852 |t#2|)) (-230 (-1699 |t#2|) (-763)) (-971 |t#1|) (-641 |t#1|) (-920 |t#1| |t#6|) (-235 |t#7|) (-117)) (T -536)) 
+((-4116 (*1 *1 *2 *3 *4 *5 *6 *5 *7 *8 *9) (-12 (-5 *3 (-242 (-4289 (QUOTE X) (QUOTE -2928)) *8)) (-5 *4 (-33 *8)) (-5 *9 (-1161)) (-4 *8 (-365)) (-5 *5 (-763)) (-4 *12 (-230 (-1699 *10) *5)) (-4 *13 (-641 *8)) (-4 *14 (-920 *8 *13)) (-4 *1 (-536 *8 *10 *11 *12 *2 *13 *14 *7 *6)) (-4 *11 (-950 *8 *12 (-852 *10))) (-4 *2 (-971 *8)) (-4 *7 (-235 *14)) (-4 *6 (-117)))) (-4116 (*1 *1 *2 *3) (-12 (-4 *4 (-365)) (-4 *6 (-230 (-1699 *5) (-763))) (-4 *7 (-641 *4)) (-4 *8 (-920 *4 *7)) (-4 *1 (-536 *4 *5 *3 *6 *2 *7 *8 *9 *10)) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *2 (-971 *4)) (-4 *9 (-235 *8)) (-4 *10 (-117)))) (-1332 (*1 *2 *1 *2) (-12 (-4 *1 (-536 *3 *4 *5 *6 *2 *7 *8 *9 *10)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *2 (-971 *3)) (-4 *7 (-641 *3)) (-4 *8 (-920 *3 *7)) (-4 *9 (-235 *8)) (-4 *10 (-117)))) (-2073 (*1 *2 *1 *2) (-12 (-5 *2 (-242 (-4289 (QUOTE X) (QUOTE -2928)) *3)) (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)))) (-2259 (*1 *2 *1 *2) (-12 (-5 *2 (-33 *3)) (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)))) (-3715 (*1 *2 *1 *2) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) *2)) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-763)))) (-1501 (*1 *2 *1 *2) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) *2)) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-763)))) (-4082 (*1 *2 *1 *2) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *2)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *2 (-117)))) (-1840 (*1 *2 *1 *2) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *2 *10)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *2 (-235 *9)) (-4 *10 (-117)))) (-2870 (*1 *2 *1 *2) (-12 (-5 *2 (-634 *8)) (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)))) (-2439 (*1 *2 *1 *2) (-12 (-5 *2 (-1161)) (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)))) (-3396 (*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) *2)) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-763)))) (-3452 (*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-634 *8)))) (-1636 (*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-1161)))) (-3209 (*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *2 *7 *8 *9 *10)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-641 *3)) (-4 *8 (-920 *3 *7)) (-4 *9 (-235 *8)) (-4 *10 (-117)) (-4 *2 (-971 *3)))) (-1764 (*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-242 (-4289 (QUOTE X) (QUOTE -2928)) *3)))) (-4288 (*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-33 *3)))) (-1721 (*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) *2)) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-763)))) (-3888 (*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *2)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *2 (-117)))) (-1435 (*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *2 *10)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-117)) (-4 *2 (-235 *9)))) (-2863 (*1 *2 *1) (-12 (-4 *1 (-536 *2 *3 *4 *5 *6 *7 *8 *9 *10)) (-4 *4 (-950 *2 *5 (-852 *3))) (-4 *5 (-230 (-1699 *3) (-763))) (-4 *6 (-971 *2)) (-4 *7 (-641 *2)) (-4 *8 (-920 *2 *7)) (-4 *9 (-235 *8)) (-4 *10 (-117)) (-4 *2 (-365))))) 
+(-13 (-1088) (-10 -8 (-15 -4116 ($ |t#5| (-242 (-4289 (QUOTE X) (QUOTE -2928)) |t#1|) (-33 |t#1|) (-763) |t#9| (-763) |t#8| |t#1| (-1161))) (-15 -4116 ($ |t#5| |t#3|)) (-15 -1332 (|t#5| $ |t#5|)) (-15 -2073 ((-242 (-4289 (QUOTE X) (QUOTE -2928)) |t#1|) $ (-242 (-4289 (QUOTE X) (QUOTE -2928)) |t#1|))) (-15 -2259 ((-33 |t#1|) $ (-33 |t#1|))) (-15 -3715 ((-763) $ (-763))) (-15 -1501 ((-763) $ (-763))) (-15 -4082 (|t#9| $ |t#9|)) (-15 -1840 (|t#8| $ |t#8|)) (-15 -2870 ((-634 |t#6|) $ (-634 |t#6|))) (-15 -2439 ((-1161) $ (-1161))) (-15 -3396 ((-763) $)) (-15 -3452 ((-634 |t#6|) $)) (-15 -1636 ((-1161) $)) (-15 -3209 (|t#5| $)) (-15 -1764 ((-242 (-4289 (QUOTE X) (QUOTE -2928)) |t#1|) $)) (-15 -4288 ((-33 |t#1|) $)) (-15 -1721 ((-763) $)) (-15 -3888 (|t#9| $)) (-15 -1435 (|t#8| $)) (-15 -2863 (|t#1| $)))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T) ((-1088) . T)) 
-((-2447 (((-121) $ $) NIL)) (-4436 (((-1161) $) NIL)) (-1314 (((-763) $) NIL)) (-1467 (((-1161) $ (-1161)) NIL)) (-3470 (((-763) $ (-763)) NIL)) (-1600 (((-967 |#1|) $ (-967 |#1|)) NIL)) (-3393 (((-763) $ (-763)) NIL)) (-3675 (((-33 (-857 |#1|)) $ (-33 (-857 |#1|))) NIL)) (-2247 (((-634 (-774 (-857 |#1|))) $ (-634 (-774 (-857 |#1|)))) NIL)) (-4476 (((-236 (-922 |#1|)) $ (-236 (-922 |#1|))) NIL)) (-1398 (((-242 (-4287 (QUOTE X) (QUOTE -2926)) (-857 |#1|)) $ (-242 (-4287 (QUOTE X) (QUOTE -2926)) (-857 |#1|))) NIL)) (-3524 ((|#3| $ |#3|) NIL)) (-3642 (((-967 |#1|) $) NIL)) (-3807 (((-763) $) NIL)) (-3934 (((-33 (-857 |#1|)) $) NIL)) (-2134 (((-634 (-774 (-857 |#1|))) $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-3936 (((-121) (-121)) NIL) (((-121)) NIL)) (-2184 (((-850) $) NIL)) (-4394 (((-236 (-922 |#1|)) $) NIL)) (-3206 (((-917) $) NIL)) (-4459 (((-242 (-4287 (QUOTE X) (QUOTE -2926)) (-857 |#1|)) $) NIL)) (-2373 (($ (-967 |#1|) (-242 (-4287 (QUOTE X) (QUOTE -2926)) (-857 |#1|)) (-33 (-857 |#1|)) (-763) |#3| (-763) (-236 (-922 |#1|)) (-857 |#1|) (-1161)) NIL) (($ (-967 |#1|) (-242 |#2| (-857 |#1|))) NIL)) (-2745 (((-850) $) NIL)) (-1378 ((|#3| $) NIL)) (-4248 (((-857 |#1|) $) NIL)) (-1717 (((-121) $ $) NIL))) 
-(((-537 |#1| |#2| |#3|) (-13 (-536 (-857 |#1|) |#2| (-242 |#2| (-857 |#1|)) (-232 (-1697 |#2|) (-763)) (-967 |#1|) (-774 (-857 |#1|)) (-922 |#1|) (-236 (-922 |#1|)) |#3|) (-10 -8 (-15 -2184 ((-850) $)) (-15 -3936 ((-121) (-121))) (-15 -3936 ((-121))))) (-350) (-634 (-1161)) (-117)) (T -537)) 
-((-2184 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-537 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-3936 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-537 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-3936 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-537 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
-(-13 (-536 (-857 |#1|) |#2| (-242 |#2| (-857 |#1|)) (-232 (-1697 |#2|) (-763)) (-967 |#1|) (-774 (-857 |#1|)) (-922 |#1|) (-236 (-922 |#1|)) |#3|) (-10 -8 (-15 -2184 ((-850) $)) (-15 -3936 ((-121) (-121))) (-15 -3936 ((-121))))) 
-((-2447 (((-121) $ $) NIL)) (-4436 (((-1161) $) 42)) (-1314 (((-763) $) 48)) (-1467 (((-1161) $ (-1161)) 81)) (-3470 (((-763) $ (-763)) 71)) (-1600 ((|#5| $ |#5|) 74)) (-3393 (((-763) $ (-763)) 77)) (-3675 (((-33 |#1|) $ (-33 |#1|)) 76)) (-2247 (((-634 |#6|) $ (-634 |#6|)) 79)) (-4476 ((|#8| $ |#8|) 80)) (-1398 (((-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) $ (-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|)) 75)) (-3524 ((|#9| $ |#9|) 78)) (-3642 ((|#5| $) 40)) (-3807 (((-763) $) 43)) (-3934 (((-33 |#1|) $) 45)) (-2134 (((-634 |#6|) $) 73)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-3936 (((-121) (-121)) 52) (((-121)) 53)) (-2184 (((-850) $) 50)) (-4394 ((|#8| $) 47)) (-3206 (((-917) $) 58)) (-4459 (((-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) $) 44)) (-2373 (($ |#5| (-242 (-4287 (QUOTE X) (QUOTE -2926)) |#1|) (-33 |#1|) (-763) |#9| (-763) |#8| |#1| (-1161)) 59) (($ |#5| |#3|) 70)) (-2745 (((-850) $) 54)) (-1378 ((|#9| $) 46)) (-4248 ((|#1| $) 55)) (-1717 (((-121) $ $) NIL))) 
-(((-538 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9|) (-13 (-536 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9|) (-10 -8 (-15 -2184 ((-850) $)) (-15 -3936 ((-121) (-121))) (-15 -3936 ((-121))))) (-365) (-634 (-1161)) (-950 |#1| |#4| (-852 |#2|)) (-230 (-1697 |#2|) (-763)) (-971 |#1|) (-641 |#1|) (-920 |#1| |#6|) (-235 |#7|) (-117)) (T -538)) 
-((-2184 (*1 *2 *1) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-5 *2 (-850)) (-5 *1 (-538 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *7 (-971 *3)) (-4 *10 (-235 *9)) (-4 *11 (-117)))) (-3936 (*1 *2 *2) (-12 (-5 *2 (-121)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-5 *1 (-538 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *7 (-971 *3)) (-4 *10 (-235 *9)) (-4 *11 (-117)))) (-3936 (*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-5 *2 (-121)) (-5 *1 (-538 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *7 (-971 *3)) (-4 *10 (-235 *9)) (-4 *11 (-117))))) 
-(-13 (-536 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9|) (-10 -8 (-15 -2184 ((-850) $)) (-15 -3936 ((-121) (-121))) (-15 -3936 ((-121))))) 
-((-3602 (((-835 (-568))) 11)) (-3594 (((-835 (-568))) 13)) (-3059 (((-828 (-568))) 8))) 
-(((-539) (-10 -7 (-15 -3059 ((-828 (-568)))) (-15 -3602 ((-835 (-568)))) (-15 -3594 ((-835 (-568)))))) (T -539)) 
-((-3594 (*1 *2) (-12 (-5 *2 (-835 (-568))) (-5 *1 (-539)))) (-3602 (*1 *2) (-12 (-5 *2 (-835 (-568))) (-5 *1 (-539)))) (-3059 (*1 *2) (-12 (-5 *2 (-828 (-568))) (-5 *1 (-539))))) 
-(-10 -7 (-15 -3059 ((-828 (-568)))) (-15 -3602 ((-835 (-568)))) (-15 -3594 ((-835 (-568))))) 
-((-1656 (((-541) (-1161)) 15)) (-3643 ((|#1| (-541)) 20))) 
-(((-540 |#1|) (-10 -7 (-15 -1656 ((-541) (-1161))) (-15 -3643 (|#1| (-541)))) (-1195)) (T -540)) 
-((-3643 (*1 *2 *3) (-12 (-5 *3 (-541)) (-5 *1 (-540 *2)) (-4 *2 (-1195)))) (-1656 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-541)) (-5 *1 (-540 *4)) (-4 *4 (-1195))))) 
-(-10 -7 (-15 -1656 ((-541) (-1161))) (-15 -3643 (|#1| (-541)))) 
-((-2447 (((-121) $ $) NIL)) (-1854 (((-1143) $) 46)) (-2500 (((-121) $) 43)) (-3180 (((-1161) $) 44)) (-1620 (((-121) $) 41)) (-1742 (((-1143) $) 42)) (-2196 (($ (-1143)) 47)) (-2341 (((-121) $) NIL)) (-2491 (((-121) $) NIL)) (-1795 (((-121) $) NIL)) (-4487 (((-1143) $) NIL)) (-3472 (($ $ (-634 (-1161))) 20)) (-3643 (((-57) $) 22)) (-4469 (((-121) $) NIL)) (-1721 (((-568) $) NIL)) (-4022 (((-1108) $) NIL)) (-1864 (($ $ (-634 (-1161)) (-1161)) 59)) (-1487 (((-121) $) NIL)) (-3768 (((-215) $) NIL)) (-4284 (($ $) 38)) (-4151 (((-850) $) NIL)) (-1853 (((-121) $ $) NIL)) (-2779 (($ $ (-568)) NIL) (($ $ (-634 (-568))) NIL)) (-2043 (((-634 $) $) 28)) (-2762 (((-1161) (-634 $)) 48)) (-4278 (($ (-634 $)) 52) (($ (-1143)) NIL) (($ (-1161)) 18) (($ (-568)) 8) (($ (-215)) 25) (($ (-850)) NIL) (((-1094) $) 11) (($ (-1094)) 12)) (-1687 (((-1161) (-1161) (-634 $)) 51)) (-2745 (((-850) $) NIL)) (-1527 (($ $) 50)) (-1520 (($ $) 49)) (-2494 (($ $ (-634 $)) 56)) (-3826 (((-121) $) 27)) (-3056 (($) 9 T CONST)) (-1556 (($) 10 T CONST)) (-1717 (((-121) $ $) 60)) (-1779 (($ $ $) 65)) (-1767 (($ $ $) 61)) (** (($ $ (-763)) 64) (($ $ (-568)) 63)) (* (($ $ $) 62)) (-1697 (((-568) $) NIL))) 
-(((-541) (-13 (-1093 (-1143) (-1161) (-568) (-215) (-850)) (-609 (-1094)) (-10 -8 (-15 -3643 ((-57) $)) (-15 -4278 ($ (-1094))) (-15 -2494 ($ $ (-634 $))) (-15 -1864 ($ $ (-634 (-1161)) (-1161))) (-15 -3472 ($ $ (-634 (-1161)))) (-15 -1767 ($ $ $)) (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ (-763))) (-15 ** ($ $ (-568))) (-15 0 ($) -3495) (-15 1 ($) -3495) (-15 -4284 ($ $)) (-15 -1854 ((-1143) $)) (-15 -2196 ($ (-1143))) (-15 -2762 ((-1161) (-634 $))) (-15 -1687 ((-1161) (-1161) (-634 $)))))) (T -541)) 
-((-3643 (*1 *2 *1) (-12 (-5 *2 (-57)) (-5 *1 (-541)))) (-4278 (*1 *1 *2) (-12 (-5 *2 (-1094)) (-5 *1 (-541)))) (-2494 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-541))) (-5 *1 (-541)))) (-1864 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-1161)) (-5 *1 (-541)))) (-3472 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-541)))) (-1767 (*1 *1 *1 *1) (-5 *1 (-541))) (* (*1 *1 *1 *1) (-5 *1 (-541))) (-1779 (*1 *1 *1 *1) (-5 *1 (-541))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-541)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-541)))) (-3056 (*1 *1) (-5 *1 (-541))) (-1556 (*1 *1) (-5 *1 (-541))) (-4284 (*1 *1 *1) (-5 *1 (-541))) (-1854 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-541)))) (-2196 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-541)))) (-2762 (*1 *2 *3) (-12 (-5 *3 (-634 (-541))) (-5 *2 (-1161)) (-5 *1 (-541)))) (-1687 (*1 *2 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-541))) (-5 *1 (-541))))) 
-(-13 (-1093 (-1143) (-1161) (-568) (-215) (-850)) (-609 (-1094)) (-10 -8 (-15 -3643 ((-57) $)) (-15 -4278 ($ (-1094))) (-15 -2494 ($ $ (-634 $))) (-15 -1864 ($ $ (-634 (-1161)) (-1161))) (-15 -3472 ($ $ (-634 (-1161)))) (-15 -1767 ($ $ $)) (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ (-763))) (-15 ** ($ $ (-568))) (-15 (-3056) ($) -3495) (-15 (-1556) ($) -3495) (-15 -4284 ($ $)) (-15 -1854 ((-1143) $)) (-15 -2196 ($ (-1143))) (-15 -2762 ((-1161) (-634 $))) (-15 -1687 ((-1161) (-1161) (-634 $))))) 
-((-2049 ((|#2| |#2|) 17)) (-1975 ((|#2| |#2|) 13)) (-4216 ((|#2| |#2| (-568) (-568)) 20)) (-2710 ((|#2| |#2|) 15))) 
-(((-542 |#1| |#2|) (-10 -7 (-15 -1975 (|#2| |#2|)) (-15 -2710 (|#2| |#2|)) (-15 -2049 (|#2| |#2|)) (-15 -4216 (|#2| |#2| (-568) (-568)))) (-13 (-558) (-150)) (-1234 |#1|)) (T -542)) 
-((-4216 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-568)) (-4 *4 (-13 (-558) (-150))) (-5 *1 (-542 *4 *2)) (-4 *2 (-1234 *4)))) (-2049 (*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-150))) (-5 *1 (-542 *3 *2)) (-4 *2 (-1234 *3)))) (-2710 (*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-150))) (-5 *1 (-542 *3 *2)) (-4 *2 (-1234 *3)))) (-1975 (*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-150))) (-5 *1 (-542 *3 *2)) (-4 *2 (-1234 *3))))) 
-(-10 -7 (-15 -1975 (|#2| |#2|)) (-15 -2710 (|#2| |#2|)) (-15 -2049 (|#2| |#2|)) (-15 -4216 (|#2| |#2| (-568) (-568)))) 
-((-4406 (((-634 (-288 (-953 |#2|))) (-634 |#2|) (-634 (-1161))) 32)) (-2142 (((-634 |#2|) (-953 |#1|) |#3|) 53) (((-634 |#2|) (-1157 |#1|) |#3|) 52)) (-3953 (((-634 (-634 |#2|)) (-634 (-953 |#1|)) (-634 (-953 |#1|)) (-634 (-1161)) |#3|) 87))) 
-(((-543 |#1| |#2| |#3|) (-10 -7 (-15 -2142 ((-634 |#2|) (-1157 |#1|) |#3|)) (-15 -2142 ((-634 |#2|) (-953 |#1|) |#3|)) (-15 -3953 ((-634 (-634 |#2|)) (-634 (-953 |#1|)) (-634 (-953 |#1|)) (-634 (-1161)) |#3|)) (-15 -4406 ((-634 (-288 (-953 |#2|))) (-634 |#2|) (-634 (-1161))))) (-453) (-365) (-13 (-365) (-840))) (T -543)) 
-((-4406 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-634 (-1161))) (-4 *6 (-365)) (-5 *2 (-634 (-288 (-953 *6)))) (-5 *1 (-543 *5 *6 *7)) (-4 *5 (-453)) (-4 *7 (-13 (-365) (-840))))) (-3953 (*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-634 (-953 *6))) (-5 *4 (-634 (-1161))) (-4 *6 (-453)) (-5 *2 (-634 (-634 *7))) (-5 *1 (-543 *6 *7 *5)) (-4 *7 (-365)) (-4 *5 (-13 (-365) (-840))))) (-2142 (*1 *2 *3 *4) (-12 (-5 *3 (-953 *5)) (-4 *5 (-453)) (-5 *2 (-634 *6)) (-5 *1 (-543 *5 *6 *4)) (-4 *6 (-365)) (-4 *4 (-13 (-365) (-840))))) (-2142 (*1 *2 *3 *4) (-12 (-5 *3 (-1157 *5)) (-4 *5 (-453)) (-5 *2 (-634 *6)) (-5 *1 (-543 *5 *6 *4)) (-4 *6 (-365)) (-4 *4 (-13 (-365) (-840)))))) 
-(-10 -7 (-15 -2142 ((-634 |#2|) (-1157 |#1|) |#3|)) (-15 -2142 ((-634 |#2|) (-953 |#1|) |#3|)) (-15 -3953 ((-634 (-634 |#2|)) (-634 (-953 |#1|)) (-634 (-953 |#1|)) (-634 (-1161)) |#3|)) (-15 -4406 ((-634 (-288 (-953 |#2|))) (-634 |#2|) (-634 (-1161))))) 
-((-3627 ((|#2| |#2| |#1|) 17)) (-3048 ((|#2| (-634 |#2|)) 26)) (-1336 ((|#2| (-634 |#2|)) 45))) 
-(((-544 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3048 (|#2| (-634 |#2|))) (-15 -1336 (|#2| (-634 |#2|))) (-15 -3627 (|#2| |#2| |#1|))) (-301) (-1219 |#1|) |#1| (-1 |#1| |#1| (-763))) (T -544)) 
-((-3627 (*1 *2 *2 *3) (-12 (-4 *3 (-301)) (-14 *4 *3) (-14 *5 (-1 *3 *3 (-763))) (-5 *1 (-544 *3 *2 *4 *5)) (-4 *2 (-1219 *3)))) (-1336 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-1219 *4)) (-5 *1 (-544 *4 *2 *5 *6)) (-4 *4 (-301)) (-14 *5 *4) (-14 *6 (-1 *4 *4 (-763))))) (-3048 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-1219 *4)) (-5 *1 (-544 *4 *2 *5 *6)) (-4 *4 (-301)) (-14 *5 *4) (-14 *6 (-1 *4 *4 (-763)))))) 
-(-10 -7 (-15 -3048 (|#2| (-634 |#2|))) (-15 -1336 (|#2| (-634 |#2|))) (-15 -3627 (|#2| |#2| |#1|))) 
-((-3848 (((-420 (-1157 |#4|)) (-1157 |#4|) (-1 (-420 (-1157 |#3|)) (-1157 |#3|))) 79) (((-420 |#4|) |#4| (-1 (-420 (-1157 |#3|)) (-1157 |#3|))) 164))) 
-(((-545 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3848 ((-420 |#4|) |#4| (-1 (-420 (-1157 |#3|)) (-1157 |#3|)))) (-15 -3848 ((-420 (-1157 |#4|)) (-1157 |#4|) (-1 (-420 (-1157 |#3|)) (-1157 |#3|))))) (-842) (-788) (-13 (-301) (-150)) (-950 |#3| |#2| |#1|)) (T -545)) 
-((-3848 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-420 (-1157 *7)) (-1157 *7))) (-4 *7 (-13 (-301) (-150))) (-4 *5 (-842)) (-4 *6 (-788)) (-4 *8 (-950 *7 *6 *5)) (-5 *2 (-420 (-1157 *8))) (-5 *1 (-545 *5 *6 *7 *8)) (-5 *3 (-1157 *8)))) (-3848 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-420 (-1157 *7)) (-1157 *7))) (-4 *7 (-13 (-301) (-150))) (-4 *5 (-842)) (-4 *6 (-788)) (-5 *2 (-420 *3)) (-5 *1 (-545 *5 *6 *7 *3)) (-4 *3 (-950 *7 *6 *5))))) 
-(-10 -7 (-15 -3848 ((-420 |#4|) |#4| (-1 (-420 (-1157 |#3|)) (-1157 |#3|)))) (-15 -3848 ((-420 (-1157 |#4|)) (-1157 |#4|) (-1 (-420 (-1157 |#3|)) (-1157 |#3|))))) 
-((-2049 ((|#4| |#4|) 73)) (-1975 ((|#4| |#4|) 69)) (-4216 ((|#4| |#4| (-568) (-568)) 75)) (-2710 ((|#4| |#4|) 71))) 
-(((-546 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1975 (|#4| |#4|)) (-15 -2710 (|#4| |#4|)) (-15 -2049 (|#4| |#4|)) (-15 -4216 (|#4| |#4| (-568) (-568)))) (-13 (-365) (-370) (-609 (-568))) (-1219 |#1|) (-714 |#1| |#2|) (-1234 |#3|)) (T -546)) 
-((-4216 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-568)) (-4 *4 (-13 (-365) (-370) (-609 *3))) (-4 *5 (-1219 *4)) (-4 *6 (-714 *4 *5)) (-5 *1 (-546 *4 *5 *6 *2)) (-4 *2 (-1234 *6)))) (-2049 (*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-4 *4 (-1219 *3)) (-4 *5 (-714 *3 *4)) (-5 *1 (-546 *3 *4 *5 *2)) (-4 *2 (-1234 *5)))) (-2710 (*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-4 *4 (-1219 *3)) (-4 *5 (-714 *3 *4)) (-5 *1 (-546 *3 *4 *5 *2)) (-4 *2 (-1234 *5)))) (-1975 (*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-4 *4 (-1219 *3)) (-4 *5 (-714 *3 *4)) (-5 *1 (-546 *3 *4 *5 *2)) (-4 *2 (-1234 *5))))) 
-(-10 -7 (-15 -1975 (|#4| |#4|)) (-15 -2710 (|#4| |#4|)) (-15 -2049 (|#4| |#4|)) (-15 -4216 (|#4| |#4| (-568) (-568)))) 
-((-2049 ((|#2| |#2|) 27)) (-1975 ((|#2| |#2|) 23)) (-4216 ((|#2| |#2| (-568) (-568)) 29)) (-2710 ((|#2| |#2|) 25))) 
-(((-547 |#1| |#2|) (-10 -7 (-15 -1975 (|#2| |#2|)) (-15 -2710 (|#2| |#2|)) (-15 -2049 (|#2| |#2|)) (-15 -4216 (|#2| |#2| (-568) (-568)))) (-13 (-365) (-370) (-609 (-568))) (-1234 |#1|)) (T -547)) 
-((-4216 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-568)) (-4 *4 (-13 (-365) (-370) (-609 *3))) (-5 *1 (-547 *4 *2)) (-4 *2 (-1234 *4)))) (-2049 (*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-5 *1 (-547 *3 *2)) (-4 *2 (-1234 *3)))) (-2710 (*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-5 *1 (-547 *3 *2)) (-4 *2 (-1234 *3)))) (-1975 (*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-5 *1 (-547 *3 *2)) (-4 *2 (-1234 *3))))) 
-(-10 -7 (-15 -1975 (|#2| |#2|)) (-15 -2710 (|#2| |#2|)) (-15 -2049 (|#2| |#2|)) (-15 -4216 (|#2| |#2| (-568) (-568)))) 
-((-3112 (((-3 (-568) "failed") |#2| |#1| (-1 (-3 (-568) "failed") |#1|)) 14) (((-3 (-568) "failed") |#2| |#1| (-568) (-1 (-3 (-568) "failed") |#1|)) 13) (((-3 (-568) "failed") |#2| (-568) (-1 (-3 (-568) "failed") |#1|)) 26))) 
-(((-548 |#1| |#2|) (-10 -7 (-15 -3112 ((-3 (-568) "failed") |#2| (-568) (-1 (-3 (-568) "failed") |#1|))) (-15 -3112 ((-3 (-568) "failed") |#2| |#1| (-568) (-1 (-3 (-568) "failed") |#1|))) (-15 -3112 ((-3 (-568) "failed") |#2| |#1| (-1 (-3 (-568) "failed") |#1|)))) (-1047) (-1219 |#1|)) (T -548)) 
-((-3112 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1 (-3 (-568) "failed") *4)) (-4 *4 (-1047)) (-5 *2 (-568)) (-5 *1 (-548 *4 *3)) (-4 *3 (-1219 *4)))) (-3112 (*1 *2 *3 *4 *2 *5) (|partial| -12 (-5 *5 (-1 (-3 (-568) "failed") *4)) (-4 *4 (-1047)) (-5 *2 (-568)) (-5 *1 (-548 *4 *3)) (-4 *3 (-1219 *4)))) (-3112 (*1 *2 *3 *2 *4) (|partial| -12 (-5 *4 (-1 (-3 (-568) "failed") *5)) (-4 *5 (-1047)) (-5 *2 (-568)) (-5 *1 (-548 *5 *3)) (-4 *3 (-1219 *5))))) 
-(-10 -7 (-15 -3112 ((-3 (-568) "failed") |#2| (-568) (-1 (-3 (-568) "failed") |#1|))) (-15 -3112 ((-3 (-568) "failed") |#2| |#1| (-568) (-1 (-3 (-568) "failed") |#1|))) (-15 -3112 ((-3 (-568) "failed") |#2| |#1| (-1 (-3 (-568) "failed") |#1|)))) 
-((-1877 (($ $ $) 78)) (-1678 (((-420 $) $) 46)) (-3666 (((-3 (-568) "failed") $) 58)) (-2854 (((-568) $) 36)) (-1642 (((-3 (-409 (-568)) "failed") $) 73)) (-2688 (((-121) $) 23)) (-2425 (((-409 (-568)) $) 71)) (-3927 (((-121) $) 49)) (-1457 (($ $ $ $) 85)) (-2033 (((-121) $) 15)) (-2413 (($ $ $) 56)) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 68)) (-3038 (((-3 $ "failed") $) 63)) (-3651 (($ $) 22)) (-2110 (($ $ $) 83)) (-4434 (($) 59)) (-2427 (($ $) 52)) (-3848 (((-420 $) $) 44)) (-3277 (((-121) $) 13)) (-2709 (((-763) $) 27)) (-4189 (($ $ (-763)) NIL) (($ $) 10)) (-3863 (($ $) 16)) (-4278 (((-568) $) NIL) (((-541) $) 35) (((-887 (-568)) $) 39) (((-381) $) 30) (((-215) $) 32)) (-4078 (((-763)) 8)) (-2791 (((-121) $ $) 19)) (-2787 (($ $ $) 54))) 
-(((-549 |#1|) (-10 -8 (-15 -2110 (|#1| |#1| |#1|)) (-15 -1457 (|#1| |#1| |#1| |#1|)) (-15 -3651 (|#1| |#1|)) (-15 -3863 (|#1| |#1|)) (-15 -1642 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2425 ((-409 (-568)) |#1|)) (-15 -2688 ((-121) |#1|)) (-15 -1877 (|#1| |#1| |#1|)) (-15 -2791 ((-121) |#1| |#1|)) (-15 -3277 ((-121) |#1|)) (-15 -4434 (|#1|)) (-15 -3038 ((-3 |#1| "failed") |#1|)) (-15 -4278 ((-215) |#1|)) (-15 -4278 ((-381) |#1|)) (-15 -2413 (|#1| |#1| |#1|)) (-15 -2427 (|#1| |#1|)) (-15 -2787 (|#1| |#1| |#1|)) (-15 -4410 ((-884 (-568) |#1|) |#1| (-887 (-568)) (-884 (-568) |#1|))) (-15 -4278 ((-887 (-568)) |#1|)) (-15 -4278 ((-541) |#1|)) (-15 -2854 ((-568) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -4278 ((-568) |#1|)) (-15 -4189 (|#1| |#1|)) (-15 -4189 (|#1| |#1| (-763))) (-15 -2033 ((-121) |#1|)) (-15 -2709 ((-763) |#1|)) (-15 -3848 ((-420 |#1|) |#1|)) (-15 -1678 ((-420 |#1|) |#1|)) (-15 -3927 ((-121) |#1|)) (-15 -4078 ((-763)))) (-550)) (T -549)) 
-((-4078 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-549 *3)) (-4 *3 (-550))))) 
-(-10 -8 (-15 -2110 (|#1| |#1| |#1|)) (-15 -1457 (|#1| |#1| |#1| |#1|)) (-15 -3651 (|#1| |#1|)) (-15 -3863 (|#1| |#1|)) (-15 -1642 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2425 ((-409 (-568)) |#1|)) (-15 -2688 ((-121) |#1|)) (-15 -1877 (|#1| |#1| |#1|)) (-15 -2791 ((-121) |#1| |#1|)) (-15 -3277 ((-121) |#1|)) (-15 -4434 (|#1|)) (-15 -3038 ((-3 |#1| "failed") |#1|)) (-15 -4278 ((-215) |#1|)) (-15 -4278 ((-381) |#1|)) (-15 -2413 (|#1| |#1| |#1|)) (-15 -2427 (|#1| |#1|)) (-15 -2787 (|#1| |#1| |#1|)) (-15 -4410 ((-884 (-568) |#1|) |#1| (-887 (-568)) (-884 (-568) |#1|))) (-15 -4278 ((-887 (-568)) |#1|)) (-15 -4278 ((-541) |#1|)) (-15 -2854 ((-568) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -4278 ((-568) |#1|)) (-15 -4189 (|#1| |#1|)) (-15 -4189 (|#1| |#1| (-763))) (-15 -2033 ((-121) |#1|)) (-15 -2709 ((-763) |#1|)) (-15 -3848 ((-420 |#1|) |#1|)) (-15 -1678 ((-420 |#1|) |#1|)) (-15 -3927 ((-121) |#1|)) (-15 -4078 ((-763)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-1877 (($ $ $) 82)) (-3134 (((-3 $ "failed") $ $) 18)) (-2690 (($ $ $ $) 70)) (-4305 (($ $) 49)) (-1678 (((-420 $) $) 50)) (-1497 (((-121) $ $) 122)) (-3662 (((-568) $) 111)) (-1870 (($ $ $) 85)) (-2671 (($) 16 T CONST)) (-3666 (((-3 (-568) "failed") $) 103)) (-2854 (((-568) $) 102)) (-2401 (($ $ $) 126)) (-3164 (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 101) (((-679 (-568)) (-679 $)) 100)) (-2925 (((-3 $ "failed") $) 33)) (-1642 (((-3 (-409 (-568)) "failed") $) 79)) (-2688 (((-121) $) 81)) (-2425 (((-409 (-568)) $) 80)) (-1731 (($) 78) (($ $) 77)) (-2412 (($ $ $) 125)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 120)) (-3927 (((-121) $) 51)) (-1457 (($ $ $ $) 68)) (-1283 (($ $ $) 83)) (-2033 (((-121) $) 113)) (-2413 (($ $ $) 94)) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 97)) (-2735 (((-121) $) 30)) (-1825 (((-121) $) 89)) (-3038 (((-3 $ "failed") $) 91)) (-2245 (((-121) $) 112)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 129)) (-3326 (($ $ $ $) 69)) (-2521 (($ $ $) 114)) (-3268 (($ $ $) 115)) (-3651 (($ $) 72)) (-3678 (($ $) 86)) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-2110 (($ $ $) 67)) (-4434 (($) 90 T CONST)) (-3850 (($ $) 74)) (-4022 (((-1108) $) 10) (($ $) 76)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-2427 (($ $) 95)) (-3848 (((-420 $) $) 48)) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 128) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 127)) (-2595 (((-3 $ "failed") $ $) 41)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 121)) (-3277 (((-121) $) 88)) (-2709 (((-763) $) 123)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 124)) (-4189 (($ $ (-763)) 108) (($ $) 106)) (-2349 (($ $) 73)) (-3863 (($ $) 75)) (-4278 (((-568) $) 105) (((-541) $) 99) (((-887 (-568)) $) 98) (((-381) $) 93) (((-215) $) 92)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-568)) 104)) (-4078 (((-763)) 28)) (-2791 (((-121) $ $) 84)) (-2787 (($ $ $) 96)) (-1461 (($) 87)) (-1826 (((-121) $ $) 38)) (-4419 (($ $ $ $) 71)) (-2897 (($ $) 110)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $ (-763)) 109) (($ $) 107)) (-1751 (((-121) $ $) 117)) (-1738 (((-121) $ $) 118)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 116)) (-1732 (((-121) $ $) 119)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
+((-2449 (((-121) $ $) NIL)) (-1636 (((-1161) $) NIL)) (-3396 (((-763) $) NIL)) (-2439 (((-1161) $ (-1161)) NIL)) (-3715 (((-763) $ (-763)) NIL)) (-1332 (((-967 |#1|) $ (-967 |#1|)) NIL)) (-1501 (((-763) $ (-763)) NIL)) (-2259 (((-33 (-857 |#1|)) $ (-33 (-857 |#1|))) NIL)) (-2870 (((-634 (-774 (-857 |#1|))) $ (-634 (-774 (-857 |#1|)))) NIL)) (-1840 (((-236 (-922 |#1|)) $ (-236 (-922 |#1|))) NIL)) (-2073 (((-242 (-4289 (QUOTE X) (QUOTE -2928)) (-857 |#1|)) $ (-242 (-4289 (QUOTE X) (QUOTE -2928)) (-857 |#1|))) NIL)) (-4082 ((|#3| $ |#3|) NIL)) (-3209 (((-967 |#1|) $) NIL)) (-1721 (((-763) $) NIL)) (-4288 (((-33 (-857 |#1|)) $) NIL)) (-3452 (((-634 (-774 (-857 |#1|))) $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-4295 (((-121) (-121)) NIL) (((-121)) NIL)) (-2860 (((-850) $) NIL)) (-1435 (((-236 (-922 |#1|)) $) NIL)) (-1836 (((-917) $) NIL)) (-1764 (((-242 (-4289 (QUOTE X) (QUOTE -2928)) (-857 |#1|)) $) NIL)) (-4116 (($ (-967 |#1|) (-242 (-4289 (QUOTE X) (QUOTE -2928)) (-857 |#1|)) (-33 (-857 |#1|)) (-763) |#3| (-763) (-236 (-922 |#1|)) (-857 |#1|) (-1161)) NIL) (($ (-967 |#1|) (-242 |#2| (-857 |#1|))) NIL)) (-2747 (((-850) $) NIL)) (-3888 ((|#3| $) NIL)) (-2863 (((-857 |#1|) $) NIL)) (-1719 (((-121) $ $) NIL))) 
+(((-537 |#1| |#2| |#3|) (-13 (-536 (-857 |#1|) |#2| (-242 |#2| (-857 |#1|)) (-232 (-1699 |#2|) (-763)) (-967 |#1|) (-774 (-857 |#1|)) (-922 |#1|) (-236 (-922 |#1|)) |#3|) (-10 -8 (-15 -2860 ((-850) $)) (-15 -4295 ((-121) (-121))) (-15 -4295 ((-121))))) (-350) (-634 (-1161)) (-117)) (T -537)) 
+((-2860 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-537 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-4295 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-537 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-4295 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-537 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
+(-13 (-536 (-857 |#1|) |#2| (-242 |#2| (-857 |#1|)) (-232 (-1699 |#2|) (-763)) (-967 |#1|) (-774 (-857 |#1|)) (-922 |#1|) (-236 (-922 |#1|)) |#3|) (-10 -8 (-15 -2860 ((-850) $)) (-15 -4295 ((-121) (-121))) (-15 -4295 ((-121))))) 
+((-2449 (((-121) $ $) NIL)) (-1636 (((-1161) $) 42)) (-3396 (((-763) $) 48)) (-2439 (((-1161) $ (-1161)) 81)) (-3715 (((-763) $ (-763)) 71)) (-1332 ((|#5| $ |#5|) 74)) (-1501 (((-763) $ (-763)) 77)) (-2259 (((-33 |#1|) $ (-33 |#1|)) 76)) (-2870 (((-634 |#6|) $ (-634 |#6|)) 79)) (-1840 ((|#8| $ |#8|) 80)) (-2073 (((-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) $ (-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|)) 75)) (-4082 ((|#9| $ |#9|) 78)) (-3209 ((|#5| $) 40)) (-1721 (((-763) $) 43)) (-4288 (((-33 |#1|) $) 45)) (-3452 (((-634 |#6|) $) 73)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-4295 (((-121) (-121)) 52) (((-121)) 53)) (-2860 (((-850) $) 50)) (-1435 ((|#8| $) 47)) (-1836 (((-917) $) 58)) (-1764 (((-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) $) 44)) (-4116 (($ |#5| (-242 (-4289 (QUOTE X) (QUOTE -2928)) |#1|) (-33 |#1|) (-763) |#9| (-763) |#8| |#1| (-1161)) 59) (($ |#5| |#3|) 70)) (-2747 (((-850) $) 54)) (-3888 ((|#9| $) 46)) (-2863 ((|#1| $) 55)) (-1719 (((-121) $ $) NIL))) 
+(((-538 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9|) (-13 (-536 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9|) (-10 -8 (-15 -2860 ((-850) $)) (-15 -4295 ((-121) (-121))) (-15 -4295 ((-121))))) (-365) (-634 (-1161)) (-950 |#1| |#4| (-852 |#2|)) (-230 (-1699 |#2|) (-763)) (-971 |#1|) (-641 |#1|) (-920 |#1| |#6|) (-235 |#7|) (-117)) (T -538)) 
+((-2860 (*1 *2 *1) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-5 *2 (-850)) (-5 *1 (-538 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *7 (-971 *3)) (-4 *10 (-235 *9)) (-4 *11 (-117)))) (-4295 (*1 *2 *2) (-12 (-5 *2 (-121)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-5 *1 (-538 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *7 (-971 *3)) (-4 *10 (-235 *9)) (-4 *11 (-117)))) (-4295 (*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-5 *2 (-121)) (-5 *1 (-538 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *7 (-971 *3)) (-4 *10 (-235 *9)) (-4 *11 (-117))))) 
+(-13 (-536 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9|) (-10 -8 (-15 -2860 ((-850) $)) (-15 -4295 ((-121) (-121))) (-15 -4295 ((-121))))) 
+((-3604 (((-835 (-568))) 11)) (-3596 (((-835 (-568))) 13)) (-3061 (((-828 (-568))) 8))) 
+(((-539) (-10 -7 (-15 -3061 ((-828 (-568)))) (-15 -3604 ((-835 (-568)))) (-15 -3596 ((-835 (-568)))))) (T -539)) 
+((-3596 (*1 *2) (-12 (-5 *2 (-835 (-568))) (-5 *1 (-539)))) (-3604 (*1 *2) (-12 (-5 *2 (-835 (-568))) (-5 *1 (-539)))) (-3061 (*1 *2) (-12 (-5 *2 (-828 (-568))) (-5 *1 (-539))))) 
+(-10 -7 (-15 -3061 ((-828 (-568)))) (-15 -3604 ((-835 (-568)))) (-15 -3596 ((-835 (-568))))) 
+((-3347 (((-541) (-1161)) 15)) (-3644 ((|#1| (-541)) 20))) 
+(((-540 |#1|) (-10 -7 (-15 -3347 ((-541) (-1161))) (-15 -3644 (|#1| (-541)))) (-1195)) (T -540)) 
+((-3644 (*1 *2 *3) (-12 (-5 *3 (-541)) (-5 *1 (-540 *2)) (-4 *2 (-1195)))) (-3347 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-541)) (-5 *1 (-540 *4)) (-4 *4 (-1195))))) 
+(-10 -7 (-15 -3347 ((-541) (-1161))) (-15 -3644 (|#1| (-541)))) 
+((-2449 (((-121) $ $) NIL)) (-2416 (((-1143) $) 46)) (-1623 (((-121) $) 43)) (-3182 (((-1161) $) 44)) (-1454 (((-121) $) 41)) (-1744 (((-1143) $) 42)) (-3076 (($ (-1143)) 47)) (-3909 (((-121) $) NIL)) (-2722 (((-121) $) NIL)) (-2118 (((-121) $) NIL)) (-1893 (((-1143) $) NIL)) (-3729 (($ $ (-634 (-1161))) 20)) (-3644 (((-57) $) 22)) (-1812 (((-121) $) NIL)) (-1723 (((-568) $) NIL)) (-4025 (((-1108) $) NIL)) (-1866 (($ $ (-634 (-1161)) (-1161)) 59)) (-2538 (((-121) $) NIL)) (-3770 (((-215) $) NIL)) (-4285 (($ $) 38)) (-4153 (((-850) $) NIL)) (-2410 (((-121) $ $) NIL)) (-2781 (($ $ (-568)) NIL) (($ $ (-634 (-568))) NIL)) (-2045 (((-634 $) $) 28)) (-2765 (((-1161) (-634 $)) 48)) (-4280 (($ (-634 $)) 52) (($ (-1143)) NIL) (($ (-1161)) 18) (($ (-568)) 8) (($ (-215)) 25) (($ (-850)) NIL) (((-1094) $) 11) (($ (-1094)) 12)) (-1687 (((-1161) (-1161) (-634 $)) 51)) (-2747 (((-850) $) NIL)) (-1527 (($ $) 50)) (-1518 (($ $) 49)) (-2735 (($ $ (-634 $)) 56)) (-1803 (((-121) $) 27)) (-3058 (($) 9 T CONST)) (-1557 (($) 10 T CONST)) (-1719 (((-121) $ $) 60)) (-1781 (($ $ $) 65)) (-1769 (($ $ $) 61)) (** (($ $ (-763)) 64) (($ $ (-568)) 63)) (* (($ $ $) 62)) (-1699 (((-568) $) NIL))) 
+(((-541) (-13 (-1093 (-1143) (-1161) (-568) (-215) (-850)) (-609 (-1094)) (-10 -8 (-15 -3644 ((-57) $)) (-15 -4280 ($ (-1094))) (-15 -2735 ($ $ (-634 $))) (-15 -1866 ($ $ (-634 (-1161)) (-1161))) (-15 -3729 ($ $ (-634 (-1161)))) (-15 -1769 ($ $ $)) (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ (-763))) (-15 ** ($ $ (-568))) (-15 0 ($) -3497) (-15 1 ($) -3497) (-15 -4285 ($ $)) (-15 -2416 ((-1143) $)) (-15 -3076 ($ (-1143))) (-15 -2765 ((-1161) (-634 $))) (-15 -1687 ((-1161) (-1161) (-634 $)))))) (T -541)) 
+((-3644 (*1 *2 *1) (-12 (-5 *2 (-57)) (-5 *1 (-541)))) (-4280 (*1 *1 *2) (-12 (-5 *2 (-1094)) (-5 *1 (-541)))) (-2735 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-541))) (-5 *1 (-541)))) (-1866 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-1161)) (-5 *1 (-541)))) (-3729 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-541)))) (-1769 (*1 *1 *1 *1) (-5 *1 (-541))) (* (*1 *1 *1 *1) (-5 *1 (-541))) (-1781 (*1 *1 *1 *1) (-5 *1 (-541))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-541)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-541)))) (-3058 (*1 *1) (-5 *1 (-541))) (-1557 (*1 *1) (-5 *1 (-541))) (-4285 (*1 *1 *1) (-5 *1 (-541))) (-2416 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-541)))) (-3076 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-541)))) (-2765 (*1 *2 *3) (-12 (-5 *3 (-634 (-541))) (-5 *2 (-1161)) (-5 *1 (-541)))) (-1687 (*1 *2 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-541))) (-5 *1 (-541))))) 
+(-13 (-1093 (-1143) (-1161) (-568) (-215) (-850)) (-609 (-1094)) (-10 -8 (-15 -3644 ((-57) $)) (-15 -4280 ($ (-1094))) (-15 -2735 ($ $ (-634 $))) (-15 -1866 ($ $ (-634 (-1161)) (-1161))) (-15 -3729 ($ $ (-634 (-1161)))) (-15 -1769 ($ $ $)) (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ (-763))) (-15 ** ($ $ (-568))) (-15 (-3058) ($) -3497) (-15 (-1557) ($) -3497) (-15 -4285 ($ $)) (-15 -2416 ((-1143) $)) (-15 -3076 ($ (-1143))) (-15 -2765 ((-1161) (-634 $))) (-15 -1687 ((-1161) (-1161) (-634 $))))) 
+((-1517 ((|#2| |#2|) 17)) (-4388 ((|#2| |#2|) 13)) (-4169 ((|#2| |#2| (-568) (-568)) 20)) (-1471 ((|#2| |#2|) 15))) 
+(((-542 |#1| |#2|) (-10 -7 (-15 -4388 (|#2| |#2|)) (-15 -1471 (|#2| |#2|)) (-15 -1517 (|#2| |#2|)) (-15 -4169 (|#2| |#2| (-568) (-568)))) (-13 (-558) (-150)) (-1234 |#1|)) (T -542)) 
+((-4169 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-568)) (-4 *4 (-13 (-558) (-150))) (-5 *1 (-542 *4 *2)) (-4 *2 (-1234 *4)))) (-1517 (*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-150))) (-5 *1 (-542 *3 *2)) (-4 *2 (-1234 *3)))) (-1471 (*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-150))) (-5 *1 (-542 *3 *2)) (-4 *2 (-1234 *3)))) (-4388 (*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-150))) (-5 *1 (-542 *3 *2)) (-4 *2 (-1234 *3))))) 
+(-10 -7 (-15 -4388 (|#2| |#2|)) (-15 -1471 (|#2| |#2|)) (-15 -1517 (|#2| |#2|)) (-15 -4169 (|#2| |#2| (-568) (-568)))) 
+((-1491 (((-634 (-288 (-953 |#2|))) (-634 |#2|) (-634 (-1161))) 32)) (-3510 (((-634 |#2|) (-953 |#1|) |#3|) 53) (((-634 |#2|) (-1157 |#1|) |#3|) 52)) (-4375 (((-634 (-634 |#2|)) (-634 (-953 |#1|)) (-634 (-953 |#1|)) (-634 (-1161)) |#3|) 87))) 
+(((-543 |#1| |#2| |#3|) (-10 -7 (-15 -3510 ((-634 |#2|) (-1157 |#1|) |#3|)) (-15 -3510 ((-634 |#2|) (-953 |#1|) |#3|)) (-15 -4375 ((-634 (-634 |#2|)) (-634 (-953 |#1|)) (-634 (-953 |#1|)) (-634 (-1161)) |#3|)) (-15 -1491 ((-634 (-288 (-953 |#2|))) (-634 |#2|) (-634 (-1161))))) (-453) (-365) (-13 (-365) (-840))) (T -543)) 
+((-1491 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-634 (-1161))) (-4 *6 (-365)) (-5 *2 (-634 (-288 (-953 *6)))) (-5 *1 (-543 *5 *6 *7)) (-4 *5 (-453)) (-4 *7 (-13 (-365) (-840))))) (-4375 (*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-634 (-953 *6))) (-5 *4 (-634 (-1161))) (-4 *6 (-453)) (-5 *2 (-634 (-634 *7))) (-5 *1 (-543 *6 *7 *5)) (-4 *7 (-365)) (-4 *5 (-13 (-365) (-840))))) (-3510 (*1 *2 *3 *4) (-12 (-5 *3 (-953 *5)) (-4 *5 (-453)) (-5 *2 (-634 *6)) (-5 *1 (-543 *5 *6 *4)) (-4 *6 (-365)) (-4 *4 (-13 (-365) (-840))))) (-3510 (*1 *2 *3 *4) (-12 (-5 *3 (-1157 *5)) (-4 *5 (-453)) (-5 *2 (-634 *6)) (-5 *1 (-543 *5 *6 *4)) (-4 *6 (-365)) (-4 *4 (-13 (-365) (-840)))))) 
+(-10 -7 (-15 -3510 ((-634 |#2|) (-1157 |#1|) |#3|)) (-15 -3510 ((-634 |#2|) (-953 |#1|) |#3|)) (-15 -4375 ((-634 (-634 |#2|)) (-634 (-953 |#1|)) (-634 (-953 |#1|)) (-634 (-1161)) |#3|)) (-15 -1491 ((-634 (-288 (-953 |#2|))) (-634 |#2|) (-634 (-1161))))) 
+((-3121 ((|#2| |#2| |#1|) 17)) (-2258 ((|#2| (-634 |#2|)) 26)) (-3567 ((|#2| (-634 |#2|)) 45))) 
+(((-544 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2258 (|#2| (-634 |#2|))) (-15 -3567 (|#2| (-634 |#2|))) (-15 -3121 (|#2| |#2| |#1|))) (-301) (-1219 |#1|) |#1| (-1 |#1| |#1| (-763))) (T -544)) 
+((-3121 (*1 *2 *2 *3) (-12 (-4 *3 (-301)) (-14 *4 *3) (-14 *5 (-1 *3 *3 (-763))) (-5 *1 (-544 *3 *2 *4 *5)) (-4 *2 (-1219 *3)))) (-3567 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-1219 *4)) (-5 *1 (-544 *4 *2 *5 *6)) (-4 *4 (-301)) (-14 *5 *4) (-14 *6 (-1 *4 *4 (-763))))) (-2258 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-1219 *4)) (-5 *1 (-544 *4 *2 *5 *6)) (-4 *4 (-301)) (-14 *5 *4) (-14 *6 (-1 *4 *4 (-763)))))) 
+(-10 -7 (-15 -2258 (|#2| (-634 |#2|))) (-15 -3567 (|#2| (-634 |#2|))) (-15 -3121 (|#2| |#2| |#1|))) 
+((-3850 (((-420 (-1157 |#4|)) (-1157 |#4|) (-1 (-420 (-1157 |#3|)) (-1157 |#3|))) 79) (((-420 |#4|) |#4| (-1 (-420 (-1157 |#3|)) (-1157 |#3|))) 164))) 
+(((-545 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3850 ((-420 |#4|) |#4| (-1 (-420 (-1157 |#3|)) (-1157 |#3|)))) (-15 -3850 ((-420 (-1157 |#4|)) (-1157 |#4|) (-1 (-420 (-1157 |#3|)) (-1157 |#3|))))) (-842) (-788) (-13 (-301) (-150)) (-950 |#3| |#2| |#1|)) (T -545)) 
+((-3850 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-420 (-1157 *7)) (-1157 *7))) (-4 *7 (-13 (-301) (-150))) (-4 *5 (-842)) (-4 *6 (-788)) (-4 *8 (-950 *7 *6 *5)) (-5 *2 (-420 (-1157 *8))) (-5 *1 (-545 *5 *6 *7 *8)) (-5 *3 (-1157 *8)))) (-3850 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-420 (-1157 *7)) (-1157 *7))) (-4 *7 (-13 (-301) (-150))) (-4 *5 (-842)) (-4 *6 (-788)) (-5 *2 (-420 *3)) (-5 *1 (-545 *5 *6 *7 *3)) (-4 *3 (-950 *7 *6 *5))))) 
+(-10 -7 (-15 -3850 ((-420 |#4|) |#4| (-1 (-420 (-1157 |#3|)) (-1157 |#3|)))) (-15 -3850 ((-420 (-1157 |#4|)) (-1157 |#4|) (-1 (-420 (-1157 |#3|)) (-1157 |#3|))))) 
+((-1517 ((|#4| |#4|) 73)) (-4388 ((|#4| |#4|) 69)) (-4169 ((|#4| |#4| (-568) (-568)) 75)) (-1471 ((|#4| |#4|) 71))) 
+(((-546 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4388 (|#4| |#4|)) (-15 -1471 (|#4| |#4|)) (-15 -1517 (|#4| |#4|)) (-15 -4169 (|#4| |#4| (-568) (-568)))) (-13 (-365) (-370) (-609 (-568))) (-1219 |#1|) (-714 |#1| |#2|) (-1234 |#3|)) (T -546)) 
+((-4169 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-568)) (-4 *4 (-13 (-365) (-370) (-609 *3))) (-4 *5 (-1219 *4)) (-4 *6 (-714 *4 *5)) (-5 *1 (-546 *4 *5 *6 *2)) (-4 *2 (-1234 *6)))) (-1517 (*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-4 *4 (-1219 *3)) (-4 *5 (-714 *3 *4)) (-5 *1 (-546 *3 *4 *5 *2)) (-4 *2 (-1234 *5)))) (-1471 (*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-4 *4 (-1219 *3)) (-4 *5 (-714 *3 *4)) (-5 *1 (-546 *3 *4 *5 *2)) (-4 *2 (-1234 *5)))) (-4388 (*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-4 *4 (-1219 *3)) (-4 *5 (-714 *3 *4)) (-5 *1 (-546 *3 *4 *5 *2)) (-4 *2 (-1234 *5))))) 
+(-10 -7 (-15 -4388 (|#4| |#4|)) (-15 -1471 (|#4| |#4|)) (-15 -1517 (|#4| |#4|)) (-15 -4169 (|#4| |#4| (-568) (-568)))) 
+((-1517 ((|#2| |#2|) 27)) (-4388 ((|#2| |#2|) 23)) (-4169 ((|#2| |#2| (-568) (-568)) 29)) (-1471 ((|#2| |#2|) 25))) 
+(((-547 |#1| |#2|) (-10 -7 (-15 -4388 (|#2| |#2|)) (-15 -1471 (|#2| |#2|)) (-15 -1517 (|#2| |#2|)) (-15 -4169 (|#2| |#2| (-568) (-568)))) (-13 (-365) (-370) (-609 (-568))) (-1234 |#1|)) (T -547)) 
+((-4169 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-568)) (-4 *4 (-13 (-365) (-370) (-609 *3))) (-5 *1 (-547 *4 *2)) (-4 *2 (-1234 *4)))) (-1517 (*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-5 *1 (-547 *3 *2)) (-4 *2 (-1234 *3)))) (-1471 (*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-5 *1 (-547 *3 *2)) (-4 *2 (-1234 *3)))) (-4388 (*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-5 *1 (-547 *3 *2)) (-4 *2 (-1234 *3))))) 
+(-10 -7 (-15 -4388 (|#2| |#2|)) (-15 -1471 (|#2| |#2|)) (-15 -1517 (|#2| |#2|)) (-15 -4169 (|#2| |#2| (-568) (-568)))) 
+((-2566 (((-3 (-568) "failed") |#2| |#1| (-1 (-3 (-568) "failed") |#1|)) 14) (((-3 (-568) "failed") |#2| |#1| (-568) (-1 (-3 (-568) "failed") |#1|)) 13) (((-3 (-568) "failed") |#2| (-568) (-1 (-3 (-568) "failed") |#1|)) 26))) 
+(((-548 |#1| |#2|) (-10 -7 (-15 -2566 ((-3 (-568) "failed") |#2| (-568) (-1 (-3 (-568) "failed") |#1|))) (-15 -2566 ((-3 (-568) "failed") |#2| |#1| (-568) (-1 (-3 (-568) "failed") |#1|))) (-15 -2566 ((-3 (-568) "failed") |#2| |#1| (-1 (-3 (-568) "failed") |#1|)))) (-1047) (-1219 |#1|)) (T -548)) 
+((-2566 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1 (-3 (-568) "failed") *4)) (-4 *4 (-1047)) (-5 *2 (-568)) (-5 *1 (-548 *4 *3)) (-4 *3 (-1219 *4)))) (-2566 (*1 *2 *3 *4 *2 *5) (|partial| -12 (-5 *5 (-1 (-3 (-568) "failed") *4)) (-4 *4 (-1047)) (-5 *2 (-568)) (-5 *1 (-548 *4 *3)) (-4 *3 (-1219 *4)))) (-2566 (*1 *2 *3 *2 *4) (|partial| -12 (-5 *4 (-1 (-3 (-568) "failed") *5)) (-4 *5 (-1047)) (-5 *2 (-568)) (-5 *1 (-548 *5 *3)) (-4 *3 (-1219 *5))))) 
+(-10 -7 (-15 -2566 ((-3 (-568) "failed") |#2| (-568) (-1 (-3 (-568) "failed") |#1|))) (-15 -2566 ((-3 (-568) "failed") |#2| |#1| (-568) (-1 (-3 (-568) "failed") |#1|))) (-15 -2566 ((-3 (-568) "failed") |#2| |#1| (-1 (-3 (-568) "failed") |#1|)))) 
+((-2519 (($ $ $) 78)) (-3498 (((-420 $) $) 46)) (-3668 (((-3 (-568) "failed") $) 58)) (-2857 (((-568) $) 36)) (-3254 (((-3 (-409 (-568)) "failed") $) 73)) (-1338 (((-121) $) 23)) (-2394 (((-409 (-568)) $) 71)) (-2197 (((-121) $) 49)) (-2382 (($ $ $ $) 85)) (-1436 (((-121) $) 15)) (-2341 (($ $ $) 56)) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 68)) (-2214 (((-3 $ "failed") $) 63)) (-3248 (($ $) 22)) (-3264 (($ $ $) 83)) (-4436 (($) 59)) (-2406 (($ $) 52)) (-3850 (((-420 $) $) 44)) (-2080 (((-121) $) 13)) (-1466 (((-763) $) 27)) (-4191 (($ $ (-763)) NIL) (($ $) 10)) (-3865 (($ $) 16)) (-4280 (((-568) $) NIL) (((-541) $) 35) (((-887 (-568)) $) 39) (((-381) $) 30) (((-215) $) 32)) (-3425 (((-763)) 8)) (-3600 (((-121) $ $) 19)) (-3584 (($ $ $) 54))) 
+(((-549 |#1|) (-10 -8 (-15 -3264 (|#1| |#1| |#1|)) (-15 -2382 (|#1| |#1| |#1| |#1|)) (-15 -3248 (|#1| |#1|)) (-15 -3865 (|#1| |#1|)) (-15 -3254 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2394 ((-409 (-568)) |#1|)) (-15 -1338 ((-121) |#1|)) (-15 -2519 (|#1| |#1| |#1|)) (-15 -3600 ((-121) |#1| |#1|)) (-15 -2080 ((-121) |#1|)) (-15 -4436 (|#1|)) (-15 -2214 ((-3 |#1| "failed") |#1|)) (-15 -4280 ((-215) |#1|)) (-15 -4280 ((-381) |#1|)) (-15 -2341 (|#1| |#1| |#1|)) (-15 -2406 (|#1| |#1|)) (-15 -3584 (|#1| |#1| |#1|)) (-15 -1519 ((-884 (-568) |#1|) |#1| (-887 (-568)) (-884 (-568) |#1|))) (-15 -4280 ((-887 (-568)) |#1|)) (-15 -4280 ((-541) |#1|)) (-15 -2857 ((-568) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -4280 ((-568) |#1|)) (-15 -4191 (|#1| |#1|)) (-15 -4191 (|#1| |#1| (-763))) (-15 -1436 ((-121) |#1|)) (-15 -1466 ((-763) |#1|)) (-15 -3850 ((-420 |#1|) |#1|)) (-15 -3498 ((-420 |#1|) |#1|)) (-15 -2197 ((-121) |#1|)) (-15 -3425 ((-763)))) (-550)) (T -549)) 
+((-3425 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-549 *3)) (-4 *3 (-550))))) 
+(-10 -8 (-15 -3264 (|#1| |#1| |#1|)) (-15 -2382 (|#1| |#1| |#1| |#1|)) (-15 -3248 (|#1| |#1|)) (-15 -3865 (|#1| |#1|)) (-15 -3254 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2394 ((-409 (-568)) |#1|)) (-15 -1338 ((-121) |#1|)) (-15 -2519 (|#1| |#1| |#1|)) (-15 -3600 ((-121) |#1| |#1|)) (-15 -2080 ((-121) |#1|)) (-15 -4436 (|#1|)) (-15 -2214 ((-3 |#1| "failed") |#1|)) (-15 -4280 ((-215) |#1|)) (-15 -4280 ((-381) |#1|)) (-15 -2341 (|#1| |#1| |#1|)) (-15 -2406 (|#1| |#1|)) (-15 -3584 (|#1| |#1| |#1|)) (-15 -1519 ((-884 (-568) |#1|) |#1| (-887 (-568)) (-884 (-568) |#1|))) (-15 -4280 ((-887 (-568)) |#1|)) (-15 -4280 ((-541) |#1|)) (-15 -2857 ((-568) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -4280 ((-568) |#1|)) (-15 -4191 (|#1| |#1|)) (-15 -4191 (|#1| |#1| (-763))) (-15 -1436 ((-121) |#1|)) (-15 -1466 ((-763) |#1|)) (-15 -3850 ((-420 |#1|) |#1|)) (-15 -3498 ((-420 |#1|) |#1|)) (-15 -2197 ((-121) |#1|)) (-15 -3425 ((-763)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-2519 (($ $ $) 82)) (-2689 (((-3 $ "failed") $ $) 18)) (-1353 (($ $ $ $) 70)) (-3045 (($ $) 49)) (-3498 (((-420 $) $) 50)) (-2589 (((-121) $ $) 122)) (-3337 (((-568) $) 111)) (-1872 (($ $ $) 85)) (-4490 (($) 16 T CONST)) (-3668 (((-3 (-568) "failed") $) 103)) (-2857 (((-568) $) 102)) (-2403 (($ $ $) 126)) (-1668 (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 101) (((-679 (-568)) (-679 $)) 100)) (-2902 (((-3 $ "failed") $) 33)) (-3254 (((-3 (-409 (-568)) "failed") $) 79)) (-1338 (((-121) $) 81)) (-2394 (((-409 (-568)) $) 80)) (-1733 (($) 78) (($ $) 77)) (-2414 (($ $ $) 125)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 120)) (-2197 (((-121) $) 51)) (-2382 (($ $ $ $) 68)) (-3155 (($ $ $) 83)) (-1436 (((-121) $) 113)) (-2341 (($ $ $) 94)) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 97)) (-1598 (((-121) $) 30)) (-2268 (((-121) $) 89)) (-2214 (((-3 $ "failed") $) 91)) (-2859 (((-121) $) 112)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 129)) (-4374 (($ $ $ $) 69)) (-1732 (($ $ $) 114)) (-2047 (($ $ $) 115)) (-3248 (($ $) 72)) (-3680 (($ $) 86)) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-3264 (($ $ $) 67)) (-4436 (($) 90 T CONST)) (-1890 (($ $) 74)) (-4025 (((-1108) $) 10) (($ $) 76)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-2406 (($ $) 95)) (-3850 (((-420 $) $) 48)) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 128) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 127)) (-2597 (((-3 $ "failed") $ $) 41)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 121)) (-2080 (((-121) $) 88)) (-1466 (((-763) $) 123)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 124)) (-4191 (($ $ (-763)) 108) (($ $) 106)) (-3953 (($ $) 73)) (-3865 (($ $) 75)) (-4280 (((-568) $) 105) (((-541) $) 99) (((-887 (-568)) $) 98) (((-381) $) 93) (((-215) $) 92)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-568)) 104)) (-3425 (((-763)) 28)) (-3600 (((-121) $ $) 84)) (-3584 (($ $ $) 96)) (-2404 (($) 87)) (-2273 (((-121) $ $) 38)) (-1564 (($ $ $ $) 71)) (-2811 (($ $) 110)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $ (-763)) 109) (($ $) 107)) (-1753 (((-121) $ $) 117)) (-1740 (((-121) $ $) 118)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 116)) (-1734 (((-121) $ $) 119)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
 (((-550) (-1275)) (T -550)) 
-((-1825 (*1 *2 *1) (-12 (-4 *1 (-550)) (-5 *2 (-121)))) (-3277 (*1 *2 *1) (-12 (-4 *1 (-550)) (-5 *2 (-121)))) (-1461 (*1 *1) (-4 *1 (-550))) (-3678 (*1 *1 *1) (-4 *1 (-550))) (-1870 (*1 *1 *1 *1) (-4 *1 (-550))) (-2791 (*1 *2 *1 *1) (-12 (-4 *1 (-550)) (-5 *2 (-121)))) (-1283 (*1 *1 *1 *1) (-4 *1 (-550))) (-1877 (*1 *1 *1 *1) (-4 *1 (-550))) (-2688 (*1 *2 *1) (-12 (-4 *1 (-550)) (-5 *2 (-121)))) (-2425 (*1 *2 *1) (-12 (-4 *1 (-550)) (-5 *2 (-409 (-568))))) (-1642 (*1 *2 *1) (|partial| -12 (-4 *1 (-550)) (-5 *2 (-409 (-568))))) (-1731 (*1 *1) (-4 *1 (-550))) (-1731 (*1 *1 *1) (-4 *1 (-550))) (-4022 (*1 *1 *1) (-4 *1 (-550))) (-3863 (*1 *1 *1) (-4 *1 (-550))) (-3850 (*1 *1 *1) (-4 *1 (-550))) (-2349 (*1 *1 *1) (-4 *1 (-550))) (-3651 (*1 *1 *1) (-4 *1 (-550))) (-4419 (*1 *1 *1 *1 *1) (-4 *1 (-550))) (-2690 (*1 *1 *1 *1 *1) (-4 *1 (-550))) (-3326 (*1 *1 *1 *1 *1) (-4 *1 (-550))) (-1457 (*1 *1 *1 *1 *1) (-4 *1 (-550))) (-2110 (*1 *1 *1 *1) (-4 *1 (-550)))) 
-(-13 (-1199) (-301) (-815) (-225) (-609 (-568)) (-1037 (-568)) (-630 (-568)) (-609 (-541)) (-609 (-887 (-568))) (-881 (-568)) (-146) (-1021) (-150) (-1136) (-10 -8 (-15 -1825 ((-121) $)) (-15 -3277 ((-121) $)) (-6 -4518) (-15 -1461 ($)) (-15 -3678 ($ $)) (-15 -1870 ($ $ $)) (-15 -2791 ((-121) $ $)) (-15 -1283 ($ $ $)) (-15 -1877 ($ $ $)) (-15 -2688 ((-121) $)) (-15 -2425 ((-409 (-568)) $)) (-15 -1642 ((-3 (-409 (-568)) "failed") $)) (-15 -1731 ($)) (-15 -1731 ($ $)) (-15 -4022 ($ $)) (-15 -3863 ($ $)) (-15 -3850 ($ $)) (-15 -2349 ($ $)) (-15 -3651 ($ $)) (-15 -4419 ($ $ $ $)) (-15 -2690 ($ $ $ $)) (-15 -3326 ($ $ $ $)) (-15 -1457 ($ $ $ $)) (-15 -2110 ($ $ $)) (-6 -4517))) 
+((-2268 (*1 *2 *1) (-12 (-4 *1 (-550)) (-5 *2 (-121)))) (-2080 (*1 *2 *1) (-12 (-4 *1 (-550)) (-5 *2 (-121)))) (-2404 (*1 *1) (-4 *1 (-550))) (-3680 (*1 *1 *1) (-4 *1 (-550))) (-1872 (*1 *1 *1 *1) (-4 *1 (-550))) (-3600 (*1 *2 *1 *1) (-12 (-4 *1 (-550)) (-5 *2 (-121)))) (-3155 (*1 *1 *1 *1) (-4 *1 (-550))) (-2519 (*1 *1 *1 *1) (-4 *1 (-550))) (-1338 (*1 *2 *1) (-12 (-4 *1 (-550)) (-5 *2 (-121)))) (-2394 (*1 *2 *1) (-12 (-4 *1 (-550)) (-5 *2 (-409 (-568))))) (-3254 (*1 *2 *1) (|partial| -12 (-4 *1 (-550)) (-5 *2 (-409 (-568))))) (-1733 (*1 *1) (-4 *1 (-550))) (-1733 (*1 *1 *1) (-4 *1 (-550))) (-4025 (*1 *1 *1) (-4 *1 (-550))) (-3865 (*1 *1 *1) (-4 *1 (-550))) (-1890 (*1 *1 *1) (-4 *1 (-550))) (-3953 (*1 *1 *1) (-4 *1 (-550))) (-3248 (*1 *1 *1) (-4 *1 (-550))) (-1564 (*1 *1 *1 *1 *1) (-4 *1 (-550))) (-1353 (*1 *1 *1 *1 *1) (-4 *1 (-550))) (-4374 (*1 *1 *1 *1 *1) (-4 *1 (-550))) (-2382 (*1 *1 *1 *1 *1) (-4 *1 (-550))) (-3264 (*1 *1 *1 *1) (-4 *1 (-550)))) 
+(-13 (-1199) (-301) (-815) (-225) (-609 (-568)) (-1037 (-568)) (-630 (-568)) (-609 (-541)) (-609 (-887 (-568))) (-881 (-568)) (-146) (-1021) (-150) (-1136) (-10 -8 (-15 -2268 ((-121) $)) (-15 -2080 ((-121) $)) (-6 -4520) (-15 -2404 ($)) (-15 -3680 ($ $)) (-15 -1872 ($ $ $)) (-15 -3600 ((-121) $ $)) (-15 -3155 ($ $ $)) (-15 -2519 ($ $ $)) (-15 -1338 ((-121) $)) (-15 -2394 ((-409 (-568)) $)) (-15 -3254 ((-3 (-409 (-568)) "failed") $)) (-15 -1733 ($)) (-15 -1733 ($ $)) (-15 -4025 ($ $)) (-15 -3865 ($ $)) (-15 -1890 ($ $)) (-15 -3953 ($ $)) (-15 -3248 ($ $)) (-15 -1564 ($ $ $ $)) (-15 -1353 ($ $ $ $)) (-15 -4374 ($ $ $ $)) (-15 -2382 ($ $ $ $)) (-15 -3264 ($ $ $)) (-6 -4519))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-105) . T) ((-120 $ $) . T) ((-137) . T) ((-150) . T) ((-608 (-850)) . T) ((-146) . T) ((-172) . T) ((-609 (-215)) . T) ((-609 (-381)) . T) ((-609 (-541)) . T) ((-609 (-568)) . T) ((-609 (-887 (-568))) . T) ((-225) . T) ((-285) . T) ((-301) . T) ((-453) . T) ((-558) . T) ((-637 $) . T) ((-630 (-568)) . T) ((-707 $) . T) ((-716) . T) ((-786) . T) ((-787) . T) ((-789) . T) ((-790) . T) ((-815) . T) ((-840) . T) ((-842) . T) ((-881 (-568)) . T) ((-916) . T) ((-1021) . T) ((-1037 (-568)) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1136) . T) ((-1199) . T)) 
-((-2447 (((-121) $ $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-2986 (($) NIL) (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-1868 (((-1249) $ |#1| |#1|) NIL (|has| $ (-6 -4520)))) (-2510 (((-121) $ (-763)) NIL)) (-2436 ((|#2| $ |#1| |#2|) NIL)) (-3507 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-2674 (((-3 |#2| "failed") |#1| $) NIL)) (-2671 (($) NIL T CONST)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-3405 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (|has| $ (-6 -4519))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-3 |#2| "failed") |#1| $) NIL)) (-4328 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-3092 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (|has| $ (-6 -4519))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-3989 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#2| $ |#1|) NIL)) (-4360 (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-634 |#2|) $) NIL (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) NIL)) (-1881 ((|#1| $) NIL (|has| |#1| (-842)))) (-1979 (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-634 |#2|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-2223 ((|#1| $) NIL (|has| |#1| (-842)))) (-3674 (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4520))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-1946 (((-634 |#1|) $) NIL)) (-3548 (((-121) |#1| $) NIL)) (-1890 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-4450 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-4174 (((-634 |#1|) $) NIL)) (-3578 (((-121) |#1| $) NIL)) (-4022 (((-1108) $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-3876 ((|#2| $) NIL (|has| |#1| (-842)))) (-3775 (((-3 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) "failed") (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL)) (-3724 (($ $ |#2|) NIL (|has| $ (-6 -4520)))) (-1315 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-1387 (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-2041 (((-634 |#2|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL)) (-2085 (($) NIL) (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-4168 (((-763) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-763) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090)))) (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-609 (-541))))) (-4287 (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-2745 (((-850) $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-2367 (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-1319 (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-551 |#1| |#2| |#3|) (-13 (-1172 |#1| |#2|) (-10 -7 (-6 -4519))) (-1090) (-1090) (-13 (-1172 |#1| |#2|) (-10 -7 (-6 -4519)))) (T -551)) 
-NIL 
-(-13 (-1172 |#1| |#2|) (-10 -7 (-6 -4519))) 
-((-2994 (((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|) (-1 (-1157 |#2|) (-1157 |#2|))) 49))) 
-(((-552 |#1| |#2|) (-10 -7 (-15 -2994 ((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|) (-1 (-1157 |#2|) (-1157 |#2|))))) (-13 (-842) (-558)) (-13 (-27) (-432 |#1|))) (T -552)) 
-((-2994 (*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-607 *3)) (-5 *5 (-1 (-1157 *3) (-1157 *3))) (-4 *3 (-13 (-27) (-432 *6))) (-4 *6 (-13 (-842) (-558))) (-5 *2 (-585 *3)) (-5 *1 (-552 *6 *3))))) 
-(-10 -7 (-15 -2994 ((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|) (-1 (-1157 |#2|) (-1157 |#2|))))) 
-((-1872 (((-585 |#5|) |#5| (-1 |#3| |#3|)) 195)) (-3914 (((-3 |#5| "failed") |#5| (-1 |#3| |#3|)) 191)) (-1558 (((-585 |#5|) |#5| (-1 |#3| |#3|)) 198))) 
-(((-553 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1558 ((-585 |#5|) |#5| (-1 |#3| |#3|))) (-15 -1872 ((-585 |#5|) |#5| (-1 |#3| |#3|))) (-15 -3914 ((-3 |#5| "failed") |#5| (-1 |#3| |#3|)))) (-13 (-842) (-558) (-1037 (-568))) (-13 (-27) (-432 |#1|)) (-1219 |#2|) (-1219 (-409 |#3|)) (-340 |#2| |#3| |#4|)) (T -553)) 
-((-3914 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-27) (-432 *4))) (-4 *4 (-13 (-842) (-558) (-1037 (-568)))) (-4 *7 (-1219 (-409 *6))) (-5 *1 (-553 *4 *5 *6 *7 *2)) (-4 *2 (-340 *5 *6 *7)))) (-1872 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *7 *7)) (-4 *7 (-1219 *6)) (-4 *6 (-13 (-27) (-432 *5))) (-4 *5 (-13 (-842) (-558) (-1037 (-568)))) (-4 *8 (-1219 (-409 *7))) (-5 *2 (-585 *3)) (-5 *1 (-553 *5 *6 *7 *8 *3)) (-4 *3 (-340 *6 *7 *8)))) (-1558 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *7 *7)) (-4 *7 (-1219 *6)) (-4 *6 (-13 (-27) (-432 *5))) (-4 *5 (-13 (-842) (-558) (-1037 (-568)))) (-4 *8 (-1219 (-409 *7))) (-5 *2 (-585 *3)) (-5 *1 (-553 *5 *6 *7 *8 *3)) (-4 *3 (-340 *6 *7 *8))))) 
-(-10 -7 (-15 -1558 ((-585 |#5|) |#5| (-1 |#3| |#3|))) (-15 -1872 ((-585 |#5|) |#5| (-1 |#3| |#3|))) (-15 -3914 ((-3 |#5| "failed") |#5| (-1 |#3| |#3|)))) 
-((-3466 (((-121) (-568) (-568)) 10)) (-3572 (((-568) (-568)) 7)) (-3123 (((-568) (-568) (-568)) 8))) 
-(((-554) (-10 -7 (-15 -3572 ((-568) (-568))) (-15 -3123 ((-568) (-568) (-568))) (-15 -3466 ((-121) (-568) (-568))))) (T -554)) 
-((-3466 (*1 *2 *3 *3) (-12 (-5 *3 (-568)) (-5 *2 (-121)) (-5 *1 (-554)))) (-3123 (*1 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-554)))) (-3572 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-554))))) 
-(-10 -7 (-15 -3572 ((-568) (-568))) (-15 -3123 ((-568) (-568) (-568))) (-15 -3466 ((-121) (-568) (-568)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3877 ((|#1| $) 59)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-1982 (($ $) 89)) (-1933 (($ $) 72)) (-1462 ((|#1| $) 60)) (-3134 (((-3 $ "failed") $ $) 18)) (-1902 (($ $) 71)) (-1974 (($ $) 88)) (-2786 (($ $) 73)) (-1990 (($ $) 87)) (-1941 (($ $) 74)) (-2671 (($) 16 T CONST)) (-3666 (((-3 (-568) "failed") $) 67)) (-2854 (((-568) $) 66)) (-2925 (((-3 $ "failed") $) 33)) (-3867 (($ |#1| |#1|) 64)) (-2033 (((-121) $) 58)) (-1897 (($) 99)) (-2735 (((-121) $) 30)) (-4044 (($ $ (-568)) 70)) (-2245 (((-121) $) 57)) (-2521 (($ $ $) 105)) (-3268 (($ $ $) 104)) (-4416 (($ $) 96)) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-2668 (($ |#1| |#1|) 65) (($ |#1|) 63) (($ (-409 (-568))) 62)) (-3582 ((|#1| $) 61)) (-4022 (((-1108) $) 10)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-2595 (((-3 $ "failed") $ $) 41)) (-1892 (($ $) 97)) (-1994 (($ $) 86)) (-1945 (($ $) 75)) (-1986 (($ $) 85)) (-1937 (($ $) 76)) (-1978 (($ $) 84)) (-2790 (($ $) 77)) (-1639 (((-121) $ |#1|) 56)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-568)) 68)) (-4078 (((-763)) 28)) (-2006 (($ $) 95)) (-1958 (($ $) 83)) (-1826 (((-121) $ $) 38)) (-1998 (($ $) 94)) (-1949 (($ $) 82)) (-2014 (($ $) 93)) (-1966 (($ $) 81)) (-4023 (($ $) 92)) (-1970 (($ $) 80)) (-2010 (($ $) 91)) (-1962 (($ $) 79)) (-2002 (($ $) 90)) (-1953 (($ $) 78)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1751 (((-121) $ $) 102)) (-1738 (((-121) $ $) 101)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 103)) (-1732 (((-121) $ $) 100)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ $) 98) (($ $ (-409 (-568))) 69)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
+((-2449 (((-121) $ $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-2988 (($) NIL) (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-2481 (((-1249) $ |#1| |#1|) NIL (|has| $ (-6 -4522)))) (-1667 (((-121) $ (-763)) NIL)) (-2438 ((|#2| $ |#1| |#2|) NIL)) (-3963 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-2678 (((-3 |#2| "failed") |#1| $) NIL)) (-4490 (($) NIL T CONST)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-1568 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (|has| $ (-6 -4521))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-3 |#2| "failed") |#1| $) NIL)) (-4330 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-3094 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (|has| $ (-6 -4521))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-1292 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#2| $ |#1|) NIL)) (-3317 (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-634 |#2|) $) NIL (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) NIL)) (-2539 ((|#1| $) NIL (|has| |#1| (-842)))) (-4406 (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-634 |#2|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-3631 ((|#1| $) NIL (|has| |#1| (-842)))) (-2253 (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4522))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-4253 (((-634 |#1|) $) NIL)) (-2807 (((-121) |#1| $) NIL)) (-2580 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-1708 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-3948 (((-634 |#1|) $) NIL)) (-2916 (((-121) |#1| $) NIL)) (-4025 (((-1108) $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-3877 ((|#2| $) NIL (|has| |#1| (-842)))) (-2712 (((-3 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) "failed") (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL)) (-2490 (($ $ |#2|) NIL (|has| $ (-6 -4522)))) (-3403 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-3951 (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-1480 (((-634 |#2|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL)) (-3132 (($) NIL) (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-4170 (((-763) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-763) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090)))) (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-609 (-541))))) (-4289 (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-2747 (((-850) $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-4074 (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-3437 (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-551 |#1| |#2| |#3|) (-13 (-1172 |#1| |#2|) (-10 -7 (-6 -4521))) (-1090) (-1090) (-13 (-1172 |#1| |#2|) (-10 -7 (-6 -4521)))) (T -551)) 
+NIL 
+(-13 (-1172 |#1| |#2|) (-10 -7 (-6 -4521))) 
+((-3120 (((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|) (-1 (-1157 |#2|) (-1157 |#2|))) 49))) 
+(((-552 |#1| |#2|) (-10 -7 (-15 -3120 ((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|) (-1 (-1157 |#2|) (-1157 |#2|))))) (-13 (-842) (-558)) (-13 (-27) (-432 |#1|))) (T -552)) 
+((-3120 (*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-607 *3)) (-5 *5 (-1 (-1157 *3) (-1157 *3))) (-4 *3 (-13 (-27) (-432 *6))) (-4 *6 (-13 (-842) (-558))) (-5 *2 (-585 *3)) (-5 *1 (-552 *6 *3))))) 
+(-10 -7 (-15 -3120 ((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|) (-1 (-1157 |#2|) (-1157 |#2|))))) 
+((-2493 (((-585 |#5|) |#5| (-1 |#3| |#3|)) 195)) (-2136 (((-3 |#5| "failed") |#5| (-1 |#3| |#3|)) 191)) (-4345 (((-585 |#5|) |#5| (-1 |#3| |#3|)) 198))) 
+(((-553 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -4345 ((-585 |#5|) |#5| (-1 |#3| |#3|))) (-15 -2493 ((-585 |#5|) |#5| (-1 |#3| |#3|))) (-15 -2136 ((-3 |#5| "failed") |#5| (-1 |#3| |#3|)))) (-13 (-842) (-558) (-1037 (-568))) (-13 (-27) (-432 |#1|)) (-1219 |#2|) (-1219 (-409 |#3|)) (-340 |#2| |#3| |#4|)) (T -553)) 
+((-2136 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-27) (-432 *4))) (-4 *4 (-13 (-842) (-558) (-1037 (-568)))) (-4 *7 (-1219 (-409 *6))) (-5 *1 (-553 *4 *5 *6 *7 *2)) (-4 *2 (-340 *5 *6 *7)))) (-2493 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *7 *7)) (-4 *7 (-1219 *6)) (-4 *6 (-13 (-27) (-432 *5))) (-4 *5 (-13 (-842) (-558) (-1037 (-568)))) (-4 *8 (-1219 (-409 *7))) (-5 *2 (-585 *3)) (-5 *1 (-553 *5 *6 *7 *8 *3)) (-4 *3 (-340 *6 *7 *8)))) (-4345 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *7 *7)) (-4 *7 (-1219 *6)) (-4 *6 (-13 (-27) (-432 *5))) (-4 *5 (-13 (-842) (-558) (-1037 (-568)))) (-4 *8 (-1219 (-409 *7))) (-5 *2 (-585 *3)) (-5 *1 (-553 *5 *6 *7 *8 *3)) (-4 *3 (-340 *6 *7 *8))))) 
+(-10 -7 (-15 -4345 ((-585 |#5|) |#5| (-1 |#3| |#3|))) (-15 -2493 ((-585 |#5|) |#5| (-1 |#3| |#3|))) (-15 -2136 ((-3 |#5| "failed") |#5| (-1 |#3| |#3|)))) 
+((-3684 (((-121) (-568) (-568)) 10)) (-2896 (((-568) (-568)) 7)) (-2627 (((-568) (-568) (-568)) 8))) 
+(((-554) (-10 -7 (-15 -2896 ((-568) (-568))) (-15 -2627 ((-568) (-568) (-568))) (-15 -3684 ((-121) (-568) (-568))))) (T -554)) 
+((-3684 (*1 *2 *3 *3) (-12 (-5 *3 (-568)) (-5 *2 (-121)) (-5 *1 (-554)))) (-2627 (*1 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-554)))) (-2896 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-554))))) 
+(-10 -7 (-15 -2896 ((-568) (-568))) (-15 -2627 ((-568) (-568) (-568))) (-15 -3684 ((-121) (-568) (-568)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-1987 ((|#1| $) 59)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-1984 (($ $) 89)) (-1935 (($ $) 72)) (-2409 ((|#1| $) 60)) (-2689 (((-3 $ "failed") $ $) 18)) (-1904 (($ $) 71)) (-1976 (($ $) 88)) (-2788 (($ $) 73)) (-1992 (($ $) 87)) (-1943 (($ $) 74)) (-4490 (($) 16 T CONST)) (-3668 (((-3 (-568) "failed") $) 67)) (-2857 (((-568) $) 66)) (-2902 (((-3 $ "failed") $) 33)) (-1950 (($ |#1| |#1|) 64)) (-1436 (((-121) $) 58)) (-1899 (($) 99)) (-1598 (((-121) $) 30)) (-1550 (($ $ (-568)) 70)) (-2859 (((-121) $) 57)) (-1732 (($ $ $) 105)) (-2047 (($ $ $) 104)) (-4418 (($ $) 96)) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-4475 (($ |#1| |#1|) 65) (($ |#1|) 63) (($ (-409 (-568))) 62)) (-2933 ((|#1| $) 61)) (-4025 (((-1108) $) 10)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-2597 (((-3 $ "failed") $ $) 41)) (-1894 (($ $) 97)) (-1996 (($ $) 86)) (-1947 (($ $) 75)) (-1988 (($ $) 85)) (-1939 (($ $) 76)) (-1980 (($ $) 84)) (-2792 (($ $) 77)) (-3238 (((-121) $ |#1|) 56)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-568)) 68)) (-3425 (((-763)) 28)) (-2008 (($ $) 95)) (-1959 (($ $) 83)) (-2273 (((-121) $ $) 38)) (-2000 (($ $) 94)) (-1951 (($ $) 82)) (-2016 (($ $) 93)) (-1968 (($ $) 81)) (-1439 (($ $) 92)) (-1972 (($ $) 80)) (-2012 (($ $) 91)) (-1964 (($ $) 79)) (-2004 (($ $) 90)) (-1955 (($ $) 78)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1753 (((-121) $ $) 102)) (-1740 (((-121) $ $) 101)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 103)) (-1734 (((-121) $ $) 100)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ $) 98) (($ $ (-409 (-568))) 69)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
 (((-555 |#1|) (-1275) (-13 (-406) (-1181))) (T -555)) 
-((-2668 (*1 *1 *2 *2) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181))))) (-3867 (*1 *1 *2 *2) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181))))) (-2668 (*1 *1 *2) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181))))) (-2668 (*1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-4 *1 (-555 *3)) (-4 *3 (-13 (-406) (-1181))))) (-3582 (*1 *2 *1) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181))))) (-1462 (*1 *2 *1) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181))))) (-3877 (*1 *2 *1) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181))))) (-2033 (*1 *2 *1) (-12 (-4 *1 (-555 *3)) (-4 *3 (-13 (-406) (-1181))) (-5 *2 (-121)))) (-2245 (*1 *2 *1) (-12 (-4 *1 (-555 *3)) (-4 *3 (-13 (-406) (-1181))) (-5 *2 (-121)))) (-1639 (*1 *2 *1 *3) (-12 (-4 *1 (-555 *3)) (-4 *3 (-13 (-406) (-1181))) (-5 *2 (-121))))) 
-(-13 (-453) (-842) (-1181) (-1002) (-1037 (-568)) (-10 -8 (-6 -3996) (-15 -2668 ($ |t#1| |t#1|)) (-15 -3867 ($ |t#1| |t#1|)) (-15 -2668 ($ |t#1|)) (-15 -2668 ($ (-409 (-568)))) (-15 -3582 (|t#1| $)) (-15 -1462 (|t#1| $)) (-15 -3877 (|t#1| $)) (-15 -2033 ((-121) $)) (-15 -2245 ((-121) $)) (-15 -1639 ((-121) $ |t#1|)))) 
+((-4475 (*1 *1 *2 *2) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181))))) (-1950 (*1 *1 *2 *2) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181))))) (-4475 (*1 *1 *2) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181))))) (-4475 (*1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-4 *1 (-555 *3)) (-4 *3 (-13 (-406) (-1181))))) (-2933 (*1 *2 *1) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181))))) (-2409 (*1 *2 *1) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181))))) (-1987 (*1 *2 *1) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181))))) (-1436 (*1 *2 *1) (-12 (-4 *1 (-555 *3)) (-4 *3 (-13 (-406) (-1181))) (-5 *2 (-121)))) (-2859 (*1 *2 *1) (-12 (-4 *1 (-555 *3)) (-4 *3 (-13 (-406) (-1181))) (-5 *2 (-121)))) (-3238 (*1 *2 *1 *3) (-12 (-4 *1 (-555 *3)) (-4 *3 (-13 (-406) (-1181))) (-5 *2 (-121))))) 
+(-13 (-453) (-842) (-1181) (-1002) (-1037 (-568)) (-10 -8 (-6 -3999) (-15 -4475 ($ |t#1| |t#1|)) (-15 -1950 ($ |t#1| |t#1|)) (-15 -4475 ($ |t#1|)) (-15 -4475 ($ (-409 (-568)))) (-15 -2933 (|t#1| $)) (-15 -2409 (|t#1| $)) (-15 -1987 (|t#1| $)) (-15 -1436 ((-121) $)) (-15 -2859 ((-121) $)) (-15 -3238 ((-121) $ |t#1|)))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-40) . T) ((-98) . T) ((-105) . T) ((-120 $ $) . T) ((-137) . T) ((-608 (-850)) . T) ((-172) . T) ((-279) . T) ((-285) . T) ((-453) . T) ((-502) . T) ((-558) . T) ((-637 $) . T) ((-707 $) . T) ((-716) . T) ((-842) . T) ((-1002) . T) ((-1037 (-568)) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1181) . T) ((-1184) . T)) 
-((-1375 (((-1249) (-917) |#3| (-634 |#5|)) 55)) (-2411 ((|#8| |#3| |#3| (-634 |#10|) (-634 |#5|)) 52))) 
-(((-556 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9| |#10| |#11|) (-10 -7 (-15 -2411 (|#8| |#3| |#3| (-634 |#10|) (-634 |#5|))) (-15 -1375 ((-1249) (-917) |#3| (-634 |#5|)))) (-365) (-634 (-1161)) (-950 |#1| |#4| (-852 |#2|)) (-230 (-1697 |#2|) (-763)) (-971 |#1|) (-641 |#1|) (-920 |#1| |#6|) (-235 |#7|) (-536 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#11|) (-258 |#9|) (-117)) (T -556)) 
-((-1375 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-917)) (-5 *5 (-634 *9)) (-4 *9 (-971 *6)) (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *4 (-950 *6 *8 (-852 *7))) (-4 *8 (-230 (-1697 *7) (-763))) (-4 *10 (-641 *6)) (-4 *11 (-920 *6 *10)) (-4 *12 (-235 *11)) (-4 *13 (-536 *6 *7 *4 *8 *9 *10 *11 *12 *15)) (-4 *15 (-117)) (-5 *2 (-1249)) (-5 *1 (-556 *6 *7 *4 *8 *9 *10 *11 *12 *13 *14 *15)) (-4 *14 (-258 *13)))) (-2411 (*1 *2 *3 *3 *4 *5) (-12 (-5 *4 (-634 *13)) (-5 *5 (-634 *9)) (-4 *9 (-971 *6)) (-4 *13 (-258 *12)) (-4 *6 (-365)) (-4 *12 (-536 *6 *7 *3 *8 *9 *10 *11 *2 *14)) (-4 *14 (-117)) (-14 *7 (-634 (-1161))) (-4 *3 (-950 *6 *8 (-852 *7))) (-4 *8 (-230 (-1697 *7) (-763))) (-4 *10 (-641 *6)) (-4 *11 (-920 *6 *10)) (-4 *2 (-235 *11)) (-5 *1 (-556 *6 *7 *3 *8 *9 *10 *11 *2 *12 *13 *14))))) 
-(-10 -7 (-15 -2411 (|#8| |#3| |#3| (-634 |#10|) (-634 |#5|))) (-15 -1375 ((-1249) (-917) |#3| (-634 |#5|)))) 
-((-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 9)) (-2227 (($ $) 11)) (-1573 (((-121) $) 18)) (-2925 (((-3 $ "failed") $) 16)) (-1826 (((-121) $ $) 20))) 
-(((-557 |#1|) (-10 -8 (-15 -1573 ((-121) |#1|)) (-15 -1826 ((-121) |#1| |#1|)) (-15 -2227 (|#1| |#1|)) (-15 -3712 ((-2 (|:| -2295 |#1|) (|:| -4506 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -2925 ((-3 |#1| "failed") |#1|))) (-558)) (T -557)) 
-NIL 
-(-10 -8 (-15 -1573 ((-121) |#1|)) (-15 -1826 ((-121) |#1| |#1|)) (-15 -2227 (|#1| |#1|)) (-15 -3712 ((-2 (|:| -2295 |#1|) (|:| -4506 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -2925 ((-3 |#1| "failed") |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-2925 (((-3 $ "failed") $) 33)) (-2735 (((-121) $) 30)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2595 (((-3 $ "failed") $ $) 41)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42)) (-4078 (((-763)) 28)) (-1826 (((-121) $ $) 38)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
+((-3869 (((-1249) (-917) |#3| (-634 |#5|)) 55)) (-2335 ((|#8| |#3| |#3| (-634 |#10|) (-634 |#5|)) 52))) 
+(((-556 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9| |#10| |#11|) (-10 -7 (-15 -2335 (|#8| |#3| |#3| (-634 |#10|) (-634 |#5|))) (-15 -3869 ((-1249) (-917) |#3| (-634 |#5|)))) (-365) (-634 (-1161)) (-950 |#1| |#4| (-852 |#2|)) (-230 (-1699 |#2|) (-763)) (-971 |#1|) (-641 |#1|) (-920 |#1| |#6|) (-235 |#7|) (-536 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#11|) (-258 |#9|) (-117)) (T -556)) 
+((-3869 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-917)) (-5 *5 (-634 *9)) (-4 *9 (-971 *6)) (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *4 (-950 *6 *8 (-852 *7))) (-4 *8 (-230 (-1699 *7) (-763))) (-4 *10 (-641 *6)) (-4 *11 (-920 *6 *10)) (-4 *12 (-235 *11)) (-4 *13 (-536 *6 *7 *4 *8 *9 *10 *11 *12 *15)) (-4 *15 (-117)) (-5 *2 (-1249)) (-5 *1 (-556 *6 *7 *4 *8 *9 *10 *11 *12 *13 *14 *15)) (-4 *14 (-258 *13)))) (-2335 (*1 *2 *3 *3 *4 *5) (-12 (-5 *4 (-634 *13)) (-5 *5 (-634 *9)) (-4 *9 (-971 *6)) (-4 *13 (-258 *12)) (-4 *6 (-365)) (-4 *12 (-536 *6 *7 *3 *8 *9 *10 *11 *2 *14)) (-4 *14 (-117)) (-14 *7 (-634 (-1161))) (-4 *3 (-950 *6 *8 (-852 *7))) (-4 *8 (-230 (-1699 *7) (-763))) (-4 *10 (-641 *6)) (-4 *11 (-920 *6 *10)) (-4 *2 (-235 *11)) (-5 *1 (-556 *6 *7 *3 *8 *9 *10 *11 *2 *12 *13 *14))))) 
+(-10 -7 (-15 -2335 (|#8| |#3| |#3| (-634 |#10|) (-634 |#5|))) (-15 -3869 ((-1249) (-917) |#3| (-634 |#5|)))) 
+((-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 9)) (-3661 (($ $) 11)) (-4426 (((-121) $) 18)) (-2902 (((-3 $ "failed") $) 16)) (-2273 (((-121) $ $) 20))) 
+(((-557 |#1|) (-10 -8 (-15 -4426 ((-121) |#1|)) (-15 -2273 ((-121) |#1| |#1|)) (-15 -3661 (|#1| |#1|)) (-15 -2431 ((-2 (|:| -3591 |#1|) (|:| -4508 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -2902 ((-3 |#1| "failed") |#1|))) (-558)) (T -557)) 
+NIL 
+(-10 -8 (-15 -4426 ((-121) |#1|)) (-15 -2273 ((-121) |#1| |#1|)) (-15 -3661 (|#1| |#1|)) (-15 -2431 ((-2 (|:| -3591 |#1|) (|:| -4508 |#1|) (|:| |associate| |#1|)) |#1|)) (-15 -2902 ((-3 |#1| "failed") |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-2902 (((-3 $ "failed") $) 33)) (-1598 (((-121) $) 30)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2597 (((-3 $ "failed") $ $) 41)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42)) (-3425 (((-763)) 28)) (-2273 (((-121) $ $) 38)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
 (((-558) (-1275)) (T -558)) 
-((-2595 (*1 *1 *1 *1) (|partial| -4 *1 (-558))) (-3712 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| -2295 *1) (|:| -4506 *1) (|:| |associate| *1))) (-4 *1 (-558)))) (-2227 (*1 *1 *1) (-4 *1 (-558))) (-1826 (*1 *2 *1 *1) (-12 (-4 *1 (-558)) (-5 *2 (-121)))) (-1573 (*1 *2 *1) (-12 (-4 *1 (-558)) (-5 *2 (-121))))) 
-(-13 (-172) (-43 $) (-285) (-10 -8 (-15 -2595 ((-3 $ "failed") $ $)) (-15 -3712 ((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $)) (-15 -2227 ($ $)) (-15 -1826 ((-121) $ $)) (-15 -1573 ((-121) $)))) 
+((-2597 (*1 *1 *1 *1) (|partial| -4 *1 (-558))) (-2431 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| -3591 *1) (|:| -4508 *1) (|:| |associate| *1))) (-4 *1 (-558)))) (-3661 (*1 *1 *1) (-4 *1 (-558))) (-2273 (*1 *2 *1 *1) (-12 (-4 *1 (-558)) (-5 *2 (-121)))) (-4426 (*1 *2 *1) (-12 (-4 *1 (-558)) (-5 *2 (-121))))) 
+(-13 (-172) (-43 $) (-285) (-10 -8 (-15 -2597 ((-3 $ "failed") $ $)) (-15 -2431 ((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $)) (-15 -3661 ($ $)) (-15 -2273 ((-121) $ $)) (-15 -4426 ((-121) $)))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-105) . T) ((-120 $ $) . T) ((-137) . T) ((-608 (-850)) . T) ((-172) . T) ((-285) . T) ((-637 $) . T) ((-707 $) . T) ((-716) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-2611 (((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-1161) (-634 |#2|)) 35)) (-1908 (((-585 |#2|) |#2| (-1161)) 58)) (-2880 (((-3 |#2| "failed") |#2| (-1161)) 147)) (-1348 (((-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1161) (-607 |#2|) (-634 (-607 |#2|))) 149)) (-1913 (((-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1161) |#2|) 38))) 
-(((-559 |#1| |#2|) (-10 -7 (-15 -1913 ((-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1161) |#2|)) (-15 -2611 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-1161) (-634 |#2|))) (-15 -2880 ((-3 |#2| "failed") |#2| (-1161))) (-15 -1908 ((-585 |#2|) |#2| (-1161))) (-15 -1348 ((-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1161) (-607 |#2|) (-634 (-607 |#2|))))) (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568))) (-13 (-27) (-1181) (-432 |#1|))) (T -559)) 
-((-1348 (*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1161)) (-5 *6 (-634 (-607 *3))) (-5 *5 (-607 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *7))) (-4 *7 (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-2 (|:| -1924 *3) (|:| |coeff| *3))) (-5 *1 (-559 *7 *3)))) (-1908 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-559 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) (-2880 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-559 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4))))) (-2611 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-634 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-559 *6 *3)))) (-1913 (*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1161)) (-4 *5 (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-2 (|:| -1924 *3) (|:| |coeff| *3))) (-5 *1 (-559 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5)))))) 
-(-10 -7 (-15 -1913 ((-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1161) |#2|)) (-15 -2611 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-1161) (-634 |#2|))) (-15 -2880 ((-3 |#2| "failed") |#2| (-1161))) (-15 -1908 ((-585 |#2|) |#2| (-1161))) (-15 -1348 ((-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1161) (-607 |#2|) (-634 (-607 |#2|))))) 
-((-2715 (((-634 |#5|) (-634 |#5|)) 41))) 
-(((-560 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2715 ((-634 |#5|) (-634 |#5|)))) (-365) (-634 (-1161)) (-788) (-842) (-950 |#1| |#3| |#4|)) (T -560)) 
-((-2715 (*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-950 *3 *5 *6)) (-4 *3 (-365)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-560 *3 *4 *5 *6 *7)) (-14 *4 (-634 (-1161)))))) 
-(-10 -7 (-15 -2715 ((-634 |#5|) (-634 |#5|)))) 
-((-1678 (((-420 |#1|) |#1|) 18)) (-3848 (((-420 |#1|) |#1|) 32)) (-2760 (((-3 |#1| "failed") |#1|) 43)) (-1781 (((-420 |#1|) |#1|) 49))) 
-(((-561 |#1|) (-10 -7 (-15 -3848 ((-420 |#1|) |#1|)) (-15 -1678 ((-420 |#1|) |#1|)) (-15 -1781 ((-420 |#1|) |#1|)) (-15 -2760 ((-3 |#1| "failed") |#1|))) (-550)) (T -561)) 
-((-2760 (*1 *2 *2) (|partial| -12 (-5 *1 (-561 *2)) (-4 *2 (-550)))) (-1781 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-561 *3)) (-4 *3 (-550)))) (-1678 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-561 *3)) (-4 *3 (-550)))) (-3848 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-561 *3)) (-4 *3 (-550))))) 
-(-10 -7 (-15 -3848 ((-420 |#1|) |#1|)) (-15 -1678 ((-420 |#1|) |#1|)) (-15 -1781 ((-420 |#1|) |#1|)) (-15 -2760 ((-3 |#1| "failed") |#1|))) 
-((-2525 (((-634 |#3|) |#8| (-634 |#3|)) 45)) (-2664 (((-634 |#3|) |#8| (-763) |#3| (-634 |#3|)) 44)) (-2168 (((-634 (-1244 |#1|)) |#8| (-634 |#3|)) 26)) (-4388 (((-634 (-1244 |#1|)) |#8| (-634 |#3|)) 27))) 
-(((-562 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -4388 ((-634 (-1244 |#1|)) |#8| (-634 |#3|))) (-15 -2168 ((-634 (-1244 |#1|)) |#8| (-634 |#3|))) (-15 -2525 ((-634 |#3|) |#8| (-634 |#3|))) (-15 -2664 ((-634 |#3|) |#8| (-763) |#3| (-634 |#3|)))) (-365) (-634 (-1161)) (-950 |#1| |#4| (-852 |#2|)) (-230 (-1697 |#2|) (-763)) (-971 |#1|) (-641 |#1|) (-920 |#1| |#6|) (-235 |#7|)) (T -562)) 
-((-2664 (*1 *2 *3 *4 *5 *2) (-12 (-5 *2 (-634 *5)) (-4 *5 (-950 *6 *8 (-852 *7))) (-4 *8 (-230 (-1697 *7) *4)) (-5 *4 (-763)) (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *10 (-641 *6)) (-4 *11 (-920 *6 *10)) (-5 *1 (-562 *6 *7 *5 *8 *9 *10 *11 *3)) (-4 *9 (-971 *6)) (-4 *3 (-235 *11)))) (-2525 (*1 *2 *3 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-5 *1 (-562 *4 *5 *6 *7 *8 *9 *10 *3)) (-4 *8 (-971 *4)) (-4 *3 (-235 *10)))) (-2168 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *7)) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1697 *6) (-763))) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-5 *2 (-634 (-1244 *5))) (-5 *1 (-562 *5 *6 *7 *8 *9 *10 *11 *3)) (-4 *9 (-971 *5)) (-4 *3 (-235 *11)))) (-4388 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *7)) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1697 *6) (-763))) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-5 *2 (-634 (-1244 *5))) (-5 *1 (-562 *5 *6 *7 *8 *9 *10 *11 *3)) (-4 *9 (-971 *5)) (-4 *3 (-235 *11))))) 
-(-10 -7 (-15 -4388 ((-634 (-1244 |#1|)) |#8| (-634 |#3|))) (-15 -2168 ((-634 (-1244 |#1|)) |#8| (-634 |#3|))) (-15 -2525 ((-634 |#3|) |#8| (-634 |#3|))) (-15 -2664 ((-634 |#3|) |#8| (-763) |#3| (-634 |#3|)))) 
-((-3365 (($) 9)) (-1675 (((-3 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) "failed") (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 29)) (-1946 (((-634 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) $) 26)) (-4450 (($ (-2 (|:| -3649 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) 23)) (-2803 (($ (-634 (-2 (|:| -3649 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) 21)) (-4083 (((-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 33)) (-2041 (((-634 (-2 (|:| -3649 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) $) 31)) (-1470 (((-1249)) 12))) 
-(((-563) (-10 -8 (-15 -3365 ($)) (-15 -1470 ((-1249))) (-15 -1946 ((-634 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) $)) (-15 -2803 ($ (-634 (-2 (|:| -3649 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))))) (-15 -4450 ($ (-2 (|:| -3649 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-15 -1675 ((-3 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) "failed") (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2041 ((-634 (-2 (|:| -3649 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) $)) (-15 -4083 ((-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))))) (T -563)) 
-((-4083 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *1 (-563)))) (-2041 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| -3649 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-5 *1 (-563)))) (-1675 (*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *1 (-563)))) (-4450 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| -3649 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) (-5 *1 (-563)))) (-2803 (*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3649 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-5 *1 (-563)))) (-1946 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-5 *1 (-563)))) (-1470 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-563)))) (-3365 (*1 *1) (-5 *1 (-563)))) 
-(-10 -8 (-15 -3365 ($)) (-15 -1470 ((-1249))) (-15 -1946 ((-634 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) $)) (-15 -2803 ($ (-634 (-2 (|:| -3649 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))))) (-15 -4450 ($ (-2 (|:| -3649 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-15 -1675 ((-3 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) "failed") (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2041 ((-634 (-2 (|:| -3649 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) $)) (-15 -4083 ((-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))))) 
-((-3839 (((-1157 (-409 (-1157 |#2|))) |#2| (-607 |#2|) (-607 |#2|) (-1157 |#2|)) 28)) (-2959 (((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-607 |#2|) (-607 |#2|) (-634 |#2|) (-607 |#2|) |#2| (-409 (-1157 |#2|))) 96) (((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-607 |#2|) (-607 |#2|) (-634 |#2|) |#2| (-1157 |#2|)) 106)) (-2195 (((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|) (-607 |#2|) |#2| (-409 (-1157 |#2|))) 78) (((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|) |#2| (-1157 |#2|)) 50)) (-2968 (((-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-607 |#2|) (-607 |#2|) |#2| (-607 |#2|) |#2| (-409 (-1157 |#2|))) 85) (((-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-607 |#2|) (-607 |#2|) |#2| |#2| (-1157 |#2|)) 105)) (-2443 (((-3 |#2| "failed") |#2| |#2| (-607 |#2|) (-607 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1161)) (-607 |#2|) |#2| (-409 (-1157 |#2|))) 101) (((-3 |#2| "failed") |#2| |#2| (-607 |#2|) (-607 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1161)) |#2| (-1157 |#2|)) 107)) (-2071 (((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -3746 (-634 |#2|))) |#3| |#2| (-607 |#2|) (-607 |#2|) (-607 |#2|) |#2| (-409 (-1157 |#2|))) 124 (|has| |#3| (-646 |#2|))) (((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -3746 (-634 |#2|))) |#3| |#2| (-607 |#2|) (-607 |#2|) |#2| (-1157 |#2|)) 123 (|has| |#3| (-646 |#2|)))) (-2051 ((|#2| (-1157 (-409 (-1157 |#2|))) (-607 |#2|) |#2|) 48)) (-3085 (((-1157 (-409 (-1157 |#2|))) (-1157 |#2|) (-607 |#2|)) 27))) 
-(((-564 |#1| |#2| |#3|) (-10 -7 (-15 -2195 ((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|) |#2| (-1157 |#2|))) (-15 -2195 ((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|) (-607 |#2|) |#2| (-409 (-1157 |#2|)))) (-15 -2968 ((-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-607 |#2|) (-607 |#2|) |#2| |#2| (-1157 |#2|))) (-15 -2968 ((-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-607 |#2|) (-607 |#2|) |#2| (-607 |#2|) |#2| (-409 (-1157 |#2|)))) (-15 -2959 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-607 |#2|) (-607 |#2|) (-634 |#2|) |#2| (-1157 |#2|))) (-15 -2959 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-607 |#2|) (-607 |#2|) (-634 |#2|) (-607 |#2|) |#2| (-409 (-1157 |#2|)))) (-15 -2443 ((-3 |#2| "failed") |#2| |#2| (-607 |#2|) (-607 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1161)) |#2| (-1157 |#2|))) (-15 -2443 ((-3 |#2| "failed") |#2| |#2| (-607 |#2|) (-607 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1161)) (-607 |#2|) |#2| (-409 (-1157 |#2|)))) (-15 -3839 ((-1157 (-409 (-1157 |#2|))) |#2| (-607 |#2|) (-607 |#2|) (-1157 |#2|))) (-15 -2051 (|#2| (-1157 (-409 (-1157 |#2|))) (-607 |#2|) |#2|)) (-15 -3085 ((-1157 (-409 (-1157 |#2|))) (-1157 |#2|) (-607 |#2|))) (IF (|has| |#3| (-646 |#2|)) (PROGN (-15 -2071 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -3746 (-634 |#2|))) |#3| |#2| (-607 |#2|) (-607 |#2|) |#2| (-1157 |#2|))) (-15 -2071 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -3746 (-634 |#2|))) |#3| |#2| (-607 |#2|) (-607 |#2|) (-607 |#2|) |#2| (-409 (-1157 |#2|))))) |noBranch|)) (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568))) (-13 (-432 |#1|) (-27) (-1181)) (-1090)) (T -564)) 
-((-2071 (*1 *2 *3 *4 *5 *5 *5 *4 *6) (-12 (-5 *5 (-607 *4)) (-5 *6 (-409 (-1157 *4))) (-4 *4 (-13 (-432 *7) (-27) (-1181))) (-4 *7 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -3746 (-634 *4)))) (-5 *1 (-564 *7 *4 *3)) (-4 *3 (-646 *4)) (-4 *3 (-1090)))) (-2071 (*1 *2 *3 *4 *5 *5 *4 *6) (-12 (-5 *5 (-607 *4)) (-5 *6 (-1157 *4)) (-4 *4 (-13 (-432 *7) (-27) (-1181))) (-4 *7 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -3746 (-634 *4)))) (-5 *1 (-564 *7 *4 *3)) (-4 *3 (-646 *4)) (-4 *3 (-1090)))) (-3085 (*1 *2 *3 *4) (-12 (-5 *4 (-607 *6)) (-4 *6 (-13 (-432 *5) (-27) (-1181))) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-1157 (-409 (-1157 *6)))) (-5 *1 (-564 *5 *6 *7)) (-5 *3 (-1157 *6)) (-4 *7 (-1090)))) (-2051 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1157 (-409 (-1157 *2)))) (-5 *4 (-607 *2)) (-4 *2 (-13 (-432 *5) (-27) (-1181))) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *1 (-564 *5 *2 *6)) (-4 *6 (-1090)))) (-3839 (*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-607 *3)) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-1157 (-409 (-1157 *3)))) (-5 *1 (-564 *6 *3 *7)) (-5 *5 (-1157 *3)) (-4 *7 (-1090)))) (-2443 (*1 *2 *2 *2 *3 *3 *4 *3 *2 *5) (|partial| -12 (-5 *3 (-607 *2)) (-5 *4 (-1 (-3 *2 "failed") *2 *2 (-1161))) (-5 *5 (-409 (-1157 *2))) (-4 *2 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *1 (-564 *6 *2 *7)) (-4 *7 (-1090)))) (-2443 (*1 *2 *2 *2 *3 *3 *4 *2 *5) (|partial| -12 (-5 *3 (-607 *2)) (-5 *4 (-1 (-3 *2 "failed") *2 *2 (-1161))) (-5 *5 (-1157 *2)) (-4 *2 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *1 (-564 *6 *2 *7)) (-4 *7 (-1090)))) (-2959 (*1 *2 *3 *4 *4 *5 *4 *3 *6) (|partial| -12 (-5 *4 (-607 *3)) (-5 *5 (-634 *3)) (-5 *6 (-409 (-1157 *3))) (-4 *3 (-13 (-432 *7) (-27) (-1181))) (-4 *7 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-564 *7 *3 *8)) (-4 *8 (-1090)))) (-2959 (*1 *2 *3 *4 *4 *5 *3 *6) (|partial| -12 (-5 *4 (-607 *3)) (-5 *5 (-634 *3)) (-5 *6 (-1157 *3)) (-4 *3 (-13 (-432 *7) (-27) (-1181))) (-4 *7 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-564 *7 *3 *8)) (-4 *8 (-1090)))) (-2968 (*1 *2 *3 *4 *4 *3 *4 *3 *5) (|partial| -12 (-5 *4 (-607 *3)) (-5 *5 (-409 (-1157 *3))) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| -1924 *3) (|:| |coeff| *3))) (-5 *1 (-564 *6 *3 *7)) (-4 *7 (-1090)))) (-2968 (*1 *2 *3 *4 *4 *3 *3 *5) (|partial| -12 (-5 *4 (-607 *3)) (-5 *5 (-1157 *3)) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| -1924 *3) (|:| |coeff| *3))) (-5 *1 (-564 *6 *3 *7)) (-4 *7 (-1090)))) (-2195 (*1 *2 *3 *4 *4 *4 *3 *5) (-12 (-5 *4 (-607 *3)) (-5 *5 (-409 (-1157 *3))) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-564 *6 *3 *7)) (-4 *7 (-1090)))) (-2195 (*1 *2 *3 *4 *4 *3 *5) (-12 (-5 *4 (-607 *3)) (-5 *5 (-1157 *3)) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-564 *6 *3 *7)) (-4 *7 (-1090))))) 
-(-10 -7 (-15 -2195 ((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|) |#2| (-1157 |#2|))) (-15 -2195 ((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|) (-607 |#2|) |#2| (-409 (-1157 |#2|)))) (-15 -2968 ((-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-607 |#2|) (-607 |#2|) |#2| |#2| (-1157 |#2|))) (-15 -2968 ((-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-607 |#2|) (-607 |#2|) |#2| (-607 |#2|) |#2| (-409 (-1157 |#2|)))) (-15 -2959 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-607 |#2|) (-607 |#2|) (-634 |#2|) |#2| (-1157 |#2|))) (-15 -2959 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-607 |#2|) (-607 |#2|) (-634 |#2|) (-607 |#2|) |#2| (-409 (-1157 |#2|)))) (-15 -2443 ((-3 |#2| "failed") |#2| |#2| (-607 |#2|) (-607 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1161)) |#2| (-1157 |#2|))) (-15 -2443 ((-3 |#2| "failed") |#2| |#2| (-607 |#2|) (-607 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1161)) (-607 |#2|) |#2| (-409 (-1157 |#2|)))) (-15 -3839 ((-1157 (-409 (-1157 |#2|))) |#2| (-607 |#2|) (-607 |#2|) (-1157 |#2|))) (-15 -2051 (|#2| (-1157 (-409 (-1157 |#2|))) (-607 |#2|) |#2|)) (-15 -3085 ((-1157 (-409 (-1157 |#2|))) (-1157 |#2|) (-607 |#2|))) (IF (|has| |#3| (-646 |#2|)) (PROGN (-15 -2071 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -3746 (-634 |#2|))) |#3| |#2| (-607 |#2|) (-607 |#2|) |#2| (-1157 |#2|))) (-15 -2071 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -3746 (-634 |#2|))) |#3| |#2| (-607 |#2|) (-607 |#2|) (-607 |#2|) |#2| (-409 (-1157 |#2|))))) |noBranch|)) 
-((-1753 (((-568) (-568) (-763)) 65)) (-1624 (((-568) (-568)) 64)) (-3585 (((-568) (-568)) 63)) (-1964 (((-568) (-568)) 68)) (-1291 (((-568) (-568) (-568)) 48)) (-4479 (((-568) (-568) (-568)) 45)) (-3720 (((-409 (-568)) (-568)) 20)) (-2635 (((-568) (-568)) 21)) (-3247 (((-568) (-568)) 57)) (-3982 (((-568) (-568)) 32)) (-3526 (((-634 (-568)) (-568)) 62)) (-2769 (((-568) (-568) (-568) (-568) (-568)) 43)) (-2542 (((-409 (-568)) (-568)) 41))) 
-(((-565) (-10 -7 (-15 -2542 ((-409 (-568)) (-568))) (-15 -2769 ((-568) (-568) (-568) (-568) (-568))) (-15 -3526 ((-634 (-568)) (-568))) (-15 -3982 ((-568) (-568))) (-15 -3247 ((-568) (-568))) (-15 -2635 ((-568) (-568))) (-15 -3720 ((-409 (-568)) (-568))) (-15 -4479 ((-568) (-568) (-568))) (-15 -1291 ((-568) (-568) (-568))) (-15 -1964 ((-568) (-568))) (-15 -3585 ((-568) (-568))) (-15 -1624 ((-568) (-568))) (-15 -1753 ((-568) (-568) (-763))))) (T -565)) 
-((-1753 (*1 *2 *2 *3) (-12 (-5 *2 (-568)) (-5 *3 (-763)) (-5 *1 (-565)))) (-1624 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565)))) (-3585 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565)))) (-1964 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565)))) (-1291 (*1 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565)))) (-4479 (*1 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565)))) (-3720 (*1 *2 *3) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-565)) (-5 *3 (-568)))) (-2635 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565)))) (-3247 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565)))) (-3982 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565)))) (-3526 (*1 *2 *3) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-565)) (-5 *3 (-568)))) (-2769 (*1 *2 *2 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565)))) (-2542 (*1 *2 *3) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-565)) (-5 *3 (-568))))) 
-(-10 -7 (-15 -2542 ((-409 (-568)) (-568))) (-15 -2769 ((-568) (-568) (-568) (-568) (-568))) (-15 -3526 ((-634 (-568)) (-568))) (-15 -3982 ((-568) (-568))) (-15 -3247 ((-568) (-568))) (-15 -2635 ((-568) (-568))) (-15 -3720 ((-409 (-568)) (-568))) (-15 -4479 ((-568) (-568) (-568))) (-15 -1291 ((-568) (-568) (-568))) (-15 -1964 ((-568) (-568))) (-15 -3585 ((-568) (-568))) (-15 -1624 ((-568) (-568))) (-15 -1753 ((-568) (-568) (-763)))) 
-((-3797 (((-2 (|:| |answer| |#4|) (|:| -2577 |#4|)) |#4| (-1 |#2| |#2|)) 52))) 
-(((-566 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3797 ((-2 (|:| |answer| |#4|) (|:| -2577 |#4|)) |#4| (-1 |#2| |#2|)))) (-365) (-1219 |#1|) (-1219 (-409 |#2|)) (-340 |#1| |#2| |#3|)) (T -566)) 
-((-3797 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-4 *7 (-1219 (-409 *6))) (-5 *2 (-2 (|:| |answer| *3) (|:| -2577 *3))) (-5 *1 (-566 *5 *6 *7 *3)) (-4 *3 (-340 *5 *6 *7))))) 
-(-10 -7 (-15 -3797 ((-2 (|:| |answer| |#4|) (|:| -2577 |#4|)) |#4| (-1 |#2| |#2|)))) 
-((-3797 (((-2 (|:| |answer| (-409 |#2|)) (|:| -2577 (-409 |#2|)) (|:| |specpart| (-409 |#2|)) (|:| |polypart| |#2|)) (-409 |#2|) (-1 |#2| |#2|)) 18))) 
-(((-567 |#1| |#2|) (-10 -7 (-15 -3797 ((-2 (|:| |answer| (-409 |#2|)) (|:| -2577 (-409 |#2|)) (|:| |specpart| (-409 |#2|)) (|:| |polypart| |#2|)) (-409 |#2|) (-1 |#2| |#2|)))) (-365) (-1219 |#1|)) (T -567)) 
-((-3797 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| |answer| (-409 *6)) (|:| -2577 (-409 *6)) (|:| |specpart| (-409 *6)) (|:| |polypart| *6))) (-5 *1 (-567 *5 *6)) (-5 *3 (-409 *6))))) 
-(-10 -7 (-15 -3797 ((-2 (|:| |answer| (-409 |#2|)) (|:| -2577 (-409 |#2|)) (|:| |specpart| (-409 |#2|)) (|:| |polypart| |#2|)) (-409 |#2|) (-1 |#2| |#2|)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 25)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 86)) (-2227 (($ $) 87)) (-1573 (((-121) $) NIL)) (-1877 (($ $ $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2690 (($ $ $ $) 42)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1497 (((-121) $ $) NIL)) (-3662 (((-568) $) NIL)) (-1870 (($ $ $) 80)) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) NIL)) (-2854 (((-568) $) NIL)) (-2401 (($ $ $) 79)) (-3164 (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 60) (((-679 (-568)) (-679 $)) 57)) (-2925 (((-3 $ "failed") $) 83)) (-1642 (((-3 (-409 (-568)) "failed") $) NIL)) (-2688 (((-121) $) NIL)) (-2425 (((-409 (-568)) $) NIL)) (-1731 (($) 62) (($ $) 63)) (-2412 (($ $ $) 78)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-1457 (($ $ $ $) NIL)) (-1283 (($ $ $) 54)) (-2033 (((-121) $) NIL)) (-2413 (($ $ $) NIL)) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL)) (-2735 (((-121) $) 26)) (-1825 (((-121) $) 73)) (-3038 (((-3 $ "failed") $) NIL)) (-2245 (((-121) $) 34)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3326 (($ $ $ $) 43)) (-2521 (($ $ $) 75)) (-3268 (($ $ $) 74)) (-3651 (($ $) NIL)) (-3678 (($ $) 40)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) 53)) (-2110 (($ $ $) NIL)) (-4434 (($) NIL T CONST)) (-3850 (($ $) 31)) (-4022 (((-1108) $) NIL) (($ $) 33)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 117)) (-2721 (($ $ $) 84) (($ (-634 $)) NIL)) (-2427 (($ $) NIL)) (-3848 (((-420 $) $) 103)) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL)) (-2595 (((-3 $ "failed") $ $) 82)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3277 (((-121) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 77)) (-4189 (($ $ (-763)) NIL) (($ $) NIL)) (-2349 (($ $) 32)) (-3863 (($ $) 30)) (-4278 (((-568) $) 39) (((-541) $) 51) (((-887 (-568)) $) NIL) (((-381) $) 46) (((-215) $) 48) (((-1143) $) 52)) (-2745 (((-850) $) 37) (($ (-568)) 38) (($ $) NIL) (($ (-568)) 38)) (-4078 (((-763)) NIL)) (-2791 (((-121) $ $) NIL)) (-2787 (($ $ $) NIL)) (-1461 (($) 29)) (-1826 (((-121) $ $) NIL)) (-4419 (($ $ $ $) 41)) (-2897 (($ $) 61)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 27 T CONST)) (-1556 (($) 28 T CONST)) (-3754 (((-1143) $) 20) (((-1143) $ (-121)) 22) (((-1249) (-817) $) 23) (((-1249) (-817) $ (-121)) 24)) (-3190 (($ $ (-763)) NIL) (($ $) NIL)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 64)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 65)) (-1773 (($ $) 66) (($ $ $) 68)) (-1767 (($ $ $) 67)) (** (($ $ (-917)) NIL) (($ $ (-763)) 72)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 70) (($ $ $) 69))) 
-(((-568) (-13 (-550) (-609 (-1143)) (-823) (-10 -8 (-15 -1731 ($ $)) (-6 -4506) (-6 -4511) (-6 -4507) (-6 -4501)))) (T -568)) 
-((-1731 (*1 *1 *1) (-5 *1 (-568)))) 
-(-13 (-550) (-609 (-1143)) (-823) (-10 -8 (-15 -1731 ($ $)) (-6 -4506) (-6 -4511) (-6 -4507) (-6 -4501))) 
-((-3029 (((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035))) (-761) (-1059)) 103) (((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035))) (-761)) 105)) (-3837 (((-3 (-1035) "failed") (-310 (-381)) (-1082 (-835 (-381))) (-1161)) 168) (((-3 (-1035) "failed") (-310 (-381)) (-1082 (-835 (-381))) (-1143)) 167) (((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381)))) (-381) (-381) (-1059)) 173) (((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381)))) (-381) (-381)) 174) (((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381)))) (-381)) 175) (((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381))))) 176) (((-1035) (-310 (-381)) (-1084 (-835 (-381)))) 163) (((-1035) (-310 (-381)) (-1084 (-835 (-381))) (-381)) 162) (((-1035) (-310 (-381)) (-1084 (-835 (-381))) (-381) (-381)) 158) (((-1035) (-761)) 150) (((-1035) (-310 (-381)) (-1084 (-835 (-381))) (-381) (-381) (-1059)) 157))) 
-(((-569) (-10 -7 (-15 -3837 ((-1035) (-310 (-381)) (-1084 (-835 (-381))) (-381) (-381) (-1059))) (-15 -3837 ((-1035) (-761))) (-15 -3837 ((-1035) (-310 (-381)) (-1084 (-835 (-381))) (-381) (-381))) (-15 -3837 ((-1035) (-310 (-381)) (-1084 (-835 (-381))) (-381))) (-15 -3837 ((-1035) (-310 (-381)) (-1084 (-835 (-381))))) (-15 -3837 ((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381)))))) (-15 -3837 ((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381)))) (-381))) (-15 -3837 ((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381)))) (-381) (-381))) (-15 -3837 ((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381)))) (-381) (-381) (-1059))) (-15 -3029 ((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035))) (-761))) (-15 -3029 ((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035))) (-761) (-1059))) (-15 -3837 ((-3 (-1035) "failed") (-310 (-381)) (-1082 (-835 (-381))) (-1143))) (-15 -3837 ((-3 (-1035) "failed") (-310 (-381)) (-1082 (-835 (-381))) (-1161))))) (T -569)) 
-((-3837 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-835 (-381)))) (-5 *5 (-1161)) (-5 *2 (-1035)) (-5 *1 (-569)))) (-3837 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-835 (-381)))) (-5 *5 (-1143)) (-5 *2 (-1035)) (-5 *1 (-569)))) (-3029 (*1 *2 *3 *4) (-12 (-5 *3 (-761)) (-5 *4 (-1059)) (-5 *2 (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035)))) (-5 *1 (-569)))) (-3029 (*1 *2 *3) (-12 (-5 *3 (-761)) (-5 *2 (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035)))) (-5 *1 (-569)))) (-3837 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-634 (-1084 (-835 (-381))))) (-5 *5 (-381)) (-5 *6 (-1059)) (-5 *2 (-1035)) (-5 *1 (-569)))) (-3837 (*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-634 (-1084 (-835 (-381))))) (-5 *5 (-381)) (-5 *2 (-1035)) (-5 *1 (-569)))) (-3837 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-634 (-1084 (-835 (-381))))) (-5 *5 (-381)) (-5 *2 (-1035)) (-5 *1 (-569)))) (-3837 (*1 *2 *3 *4) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-634 (-1084 (-835 (-381))))) (-5 *2 (-1035)) (-5 *1 (-569)))) (-3837 (*1 *2 *3 *4) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1084 (-835 (-381)))) (-5 *2 (-1035)) (-5 *1 (-569)))) (-3837 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1084 (-835 (-381)))) (-5 *5 (-381)) (-5 *2 (-1035)) (-5 *1 (-569)))) (-3837 (*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1084 (-835 (-381)))) (-5 *5 (-381)) (-5 *2 (-1035)) (-5 *1 (-569)))) (-3837 (*1 *2 *3) (-12 (-5 *3 (-761)) (-5 *2 (-1035)) (-5 *1 (-569)))) (-3837 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1084 (-835 (-381)))) (-5 *5 (-381)) (-5 *6 (-1059)) (-5 *2 (-1035)) (-5 *1 (-569))))) 
-(-10 -7 (-15 -3837 ((-1035) (-310 (-381)) (-1084 (-835 (-381))) (-381) (-381) (-1059))) (-15 -3837 ((-1035) (-761))) (-15 -3837 ((-1035) (-310 (-381)) (-1084 (-835 (-381))) (-381) (-381))) (-15 -3837 ((-1035) (-310 (-381)) (-1084 (-835 (-381))) (-381))) (-15 -3837 ((-1035) (-310 (-381)) (-1084 (-835 (-381))))) (-15 -3837 ((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381)))))) (-15 -3837 ((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381)))) (-381))) (-15 -3837 ((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381)))) (-381) (-381))) (-15 -3837 ((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381)))) (-381) (-381) (-1059))) (-15 -3029 ((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035))) (-761))) (-15 -3029 ((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035))) (-761) (-1059))) (-15 -3837 ((-3 (-1035) "failed") (-310 (-381)) (-1082 (-835 (-381))) (-1143))) (-15 -3837 ((-3 (-1035) "failed") (-310 (-381)) (-1082 (-835 (-381))) (-1161)))) 
-((-1357 (((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-607 |#2|) (-607 |#2|) (-634 |#2|)) 179)) (-1448 (((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|)) 97)) (-3496 (((-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-607 |#2|) (-607 |#2|) |#2|) 175)) (-3003 (((-3 |#2| "failed") |#2| |#2| |#2| (-607 |#2|) (-607 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1161))) 184)) (-4041 (((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -3746 (-634 |#2|))) |#3| |#2| (-607 |#2|) (-607 |#2|) (-1161)) 192 (|has| |#3| (-646 |#2|))))) 
-(((-570 |#1| |#2| |#3|) (-10 -7 (-15 -1448 ((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|))) (-15 -3496 ((-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-607 |#2|) (-607 |#2|) |#2|)) (-15 -1357 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-607 |#2|) (-607 |#2|) (-634 |#2|))) (-15 -3003 ((-3 |#2| "failed") |#2| |#2| |#2| (-607 |#2|) (-607 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1161)))) (IF (|has| |#3| (-646 |#2|)) (-15 -4041 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -3746 (-634 |#2|))) |#3| |#2| (-607 |#2|) (-607 |#2|) (-1161))) |noBranch|)) (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568))) (-13 (-432 |#1|) (-27) (-1181)) (-1090)) (T -570)) 
-((-4041 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *5 (-607 *4)) (-5 *6 (-1161)) (-4 *4 (-13 (-432 *7) (-27) (-1181))) (-4 *7 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -3746 (-634 *4)))) (-5 *1 (-570 *7 *4 *3)) (-4 *3 (-646 *4)) (-4 *3 (-1090)))) (-3003 (*1 *2 *2 *2 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-607 *2)) (-5 *4 (-1 (-3 *2 "failed") *2 *2 (-1161))) (-4 *2 (-13 (-432 *5) (-27) (-1181))) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *1 (-570 *5 *2 *6)) (-4 *6 (-1090)))) (-1357 (*1 *2 *3 *4 *4 *5) (|partial| -12 (-5 *4 (-607 *3)) (-5 *5 (-634 *3)) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-570 *6 *3 *7)) (-4 *7 (-1090)))) (-3496 (*1 *2 *3 *4 *4 *3) (|partial| -12 (-5 *4 (-607 *3)) (-4 *3 (-13 (-432 *5) (-27) (-1181))) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| -1924 *3) (|:| |coeff| *3))) (-5 *1 (-570 *5 *3 *6)) (-4 *6 (-1090)))) (-1448 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-607 *3)) (-4 *3 (-13 (-432 *5) (-27) (-1181))) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-570 *5 *3 *6)) (-4 *6 (-1090))))) 
-(-10 -7 (-15 -1448 ((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|))) (-15 -3496 ((-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-607 |#2|) (-607 |#2|) |#2|)) (-15 -1357 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-607 |#2|) (-607 |#2|) (-634 |#2|))) (-15 -3003 ((-3 |#2| "failed") |#2| |#2| |#2| (-607 |#2|) (-607 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1161)))) (IF (|has| |#3| (-646 |#2|)) (-15 -4041 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -3746 (-634 |#2|))) |#3| |#2| (-607 |#2|) (-607 |#2|) (-1161))) |noBranch|)) 
-((-4393 (((-2 (|:| -1841 |#2|) (|:| |nconst| |#2|)) |#2| (-1161)) 62)) (-3191 (((-3 |#2| "failed") |#2| (-1161) (-835 |#2|) (-835 |#2|)) 159 (-12 (|has| |#2| (-1124)) (|has| |#1| (-609 (-887 (-568)))) (|has| |#1| (-881 (-568))))) (((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1161)) 133 (-12 (|has| |#2| (-620)) (|has| |#1| (-609 (-887 (-568)))) (|has| |#1| (-881 (-568)))))) (-2729 (((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1161)) 142 (-12 (|has| |#2| (-620)) (|has| |#1| (-609 (-887 (-568)))) (|has| |#1| (-881 (-568))))))) 
-(((-571 |#1| |#2|) (-10 -7 (-15 -4393 ((-2 (|:| -1841 |#2|) (|:| |nconst| |#2|)) |#2| (-1161))) (IF (|has| |#1| (-609 (-887 (-568)))) (IF (|has| |#1| (-881 (-568))) (PROGN (IF (|has| |#2| (-620)) (PROGN (-15 -2729 ((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1161))) (-15 -3191 ((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1161)))) |noBranch|) (IF (|has| |#2| (-1124)) (-15 -3191 ((-3 |#2| "failed") |#2| (-1161) (-835 |#2|) (-835 |#2|))) |noBranch|)) |noBranch|) |noBranch|)) (-13 (-842) (-1037 (-568)) (-453) (-630 (-568))) (-13 (-27) (-1181) (-432 |#1|))) (T -571)) 
-((-3191 (*1 *2 *2 *3 *4 *4) (|partial| -12 (-5 *3 (-1161)) (-5 *4 (-835 *2)) (-4 *2 (-1124)) (-4 *2 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-609 (-887 (-568)))) (-4 *5 (-881 (-568))) (-4 *5 (-13 (-842) (-1037 (-568)) (-453) (-630 (-568)))) (-5 *1 (-571 *5 *2)))) (-3191 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1161)) (-4 *5 (-609 (-887 (-568)))) (-4 *5 (-881 (-568))) (-4 *5 (-13 (-842) (-1037 (-568)) (-453) (-630 (-568)))) (-5 *2 (-2 (|:| |special| *3) (|:| |integrand| *3))) (-5 *1 (-571 *5 *3)) (-4 *3 (-620)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) (-2729 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1161)) (-4 *5 (-609 (-887 (-568)))) (-4 *5 (-881 (-568))) (-4 *5 (-13 (-842) (-1037 (-568)) (-453) (-630 (-568)))) (-5 *2 (-2 (|:| |special| *3) (|:| |integrand| *3))) (-5 *1 (-571 *5 *3)) (-4 *3 (-620)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) (-4393 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-842) (-1037 (-568)) (-453) (-630 (-568)))) (-5 *2 (-2 (|:| -1841 *3) (|:| |nconst| *3))) (-5 *1 (-571 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5)))))) 
-(-10 -7 (-15 -4393 ((-2 (|:| -1841 |#2|) (|:| |nconst| |#2|)) |#2| (-1161))) (IF (|has| |#1| (-609 (-887 (-568)))) (IF (|has| |#1| (-881 (-568))) (PROGN (IF (|has| |#2| (-620)) (PROGN (-15 -2729 ((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1161))) (-15 -3191 ((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1161)))) |noBranch|) (IF (|has| |#2| (-1124)) (-15 -3191 ((-3 |#2| "failed") |#2| (-1161) (-835 |#2|) (-835 |#2|))) |noBranch|)) |noBranch|) |noBranch|)) 
-((-4474 (((-3 (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|)))))) "failed") (-409 |#2|) (-634 (-409 |#2|))) 39)) (-3837 (((-585 (-409 |#2|)) (-409 |#2|)) 27)) (-2706 (((-3 (-409 |#2|) "failed") (-409 |#2|)) 16)) (-2150 (((-3 (-2 (|:| -1924 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-409 |#2|)) 46))) 
-(((-572 |#1| |#2|) (-10 -7 (-15 -3837 ((-585 (-409 |#2|)) (-409 |#2|))) (-15 -2706 ((-3 (-409 |#2|) "failed") (-409 |#2|))) (-15 -2150 ((-3 (-2 (|:| -1924 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-409 |#2|))) (-15 -4474 ((-3 (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|)))))) "failed") (-409 |#2|) (-634 (-409 |#2|))))) (-13 (-365) (-150) (-1037 (-568))) (-1219 |#1|)) (T -572)) 
-((-4474 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-634 (-409 *6))) (-5 *3 (-409 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-572 *5 *6)))) (-2150 (*1 *2 *3 *3) (|partial| -12 (-4 *4 (-13 (-365) (-150) (-1037 (-568)))) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| -1924 (-409 *5)) (|:| |coeff| (-409 *5)))) (-5 *1 (-572 *4 *5)) (-5 *3 (-409 *5)))) (-2706 (*1 *2 *2) (|partial| -12 (-5 *2 (-409 *4)) (-4 *4 (-1219 *3)) (-4 *3 (-13 (-365) (-150) (-1037 (-568)))) (-5 *1 (-572 *3 *4)))) (-3837 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-568)))) (-4 *5 (-1219 *4)) (-5 *2 (-585 (-409 *5))) (-5 *1 (-572 *4 *5)) (-5 *3 (-409 *5))))) 
-(-10 -7 (-15 -3837 ((-585 (-409 |#2|)) (-409 |#2|))) (-15 -2706 ((-3 (-409 |#2|) "failed") (-409 |#2|))) (-15 -2150 ((-3 (-2 (|:| -1924 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-409 |#2|))) (-15 -4474 ((-3 (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|)))))) "failed") (-409 |#2|) (-634 (-409 |#2|))))) 
-((-3981 (((-3 (-568) "failed") |#1|) 14)) (-4469 (((-121) |#1|) 13)) (-1721 (((-568) |#1|) 9))) 
-(((-573 |#1|) (-10 -7 (-15 -1721 ((-568) |#1|)) (-15 -4469 ((-121) |#1|)) (-15 -3981 ((-3 (-568) "failed") |#1|))) (-1037 (-568))) (T -573)) 
-((-3981 (*1 *2 *3) (|partial| -12 (-5 *2 (-568)) (-5 *1 (-573 *3)) (-4 *3 (-1037 *2)))) (-4469 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-573 *3)) (-4 *3 (-1037 (-568))))) (-1721 (*1 *2 *3) (-12 (-5 *2 (-568)) (-5 *1 (-573 *3)) (-4 *3 (-1037 *2))))) 
-(-10 -7 (-15 -1721 ((-568) |#1|)) (-15 -4469 ((-121) |#1|)) (-15 -3981 ((-3 (-568) "failed") |#1|))) 
-((-3561 (((-3 (-2 (|:| |mainpart| (-409 (-953 |#1|))) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 (-953 |#1|))) (|:| |logand| (-409 (-953 |#1|))))))) "failed") (-409 (-953 |#1|)) (-1161) (-634 (-409 (-953 |#1|)))) 43)) (-2005 (((-585 (-409 (-953 |#1|))) (-409 (-953 |#1|)) (-1161)) 25)) (-2439 (((-3 (-409 (-953 |#1|)) "failed") (-409 (-953 |#1|)) (-1161)) 20)) (-3684 (((-3 (-2 (|:| -1924 (-409 (-953 |#1|))) (|:| |coeff| (-409 (-953 |#1|)))) "failed") (-409 (-953 |#1|)) (-1161) (-409 (-953 |#1|))) 32))) 
-(((-574 |#1|) (-10 -7 (-15 -2005 ((-585 (-409 (-953 |#1|))) (-409 (-953 |#1|)) (-1161))) (-15 -2439 ((-3 (-409 (-953 |#1|)) "failed") (-409 (-953 |#1|)) (-1161))) (-15 -3561 ((-3 (-2 (|:| |mainpart| (-409 (-953 |#1|))) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 (-953 |#1|))) (|:| |logand| (-409 (-953 |#1|))))))) "failed") (-409 (-953 |#1|)) (-1161) (-634 (-409 (-953 |#1|))))) (-15 -3684 ((-3 (-2 (|:| -1924 (-409 (-953 |#1|))) (|:| |coeff| (-409 (-953 |#1|)))) "failed") (-409 (-953 |#1|)) (-1161) (-409 (-953 |#1|))))) (-13 (-558) (-1037 (-568)) (-150))) (T -574)) 
-((-3684 (*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1161)) (-4 *5 (-13 (-558) (-1037 (-568)) (-150))) (-5 *2 (-2 (|:| -1924 (-409 (-953 *5))) (|:| |coeff| (-409 (-953 *5))))) (-5 *1 (-574 *5)) (-5 *3 (-409 (-953 *5))))) (-3561 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-634 (-409 (-953 *6)))) (-5 *3 (-409 (-953 *6))) (-4 *6 (-13 (-558) (-1037 (-568)) (-150))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-574 *6)))) (-2439 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-409 (-953 *4))) (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-1037 (-568)) (-150))) (-5 *1 (-574 *4)))) (-2005 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-558) (-1037 (-568)) (-150))) (-5 *2 (-585 (-409 (-953 *5)))) (-5 *1 (-574 *5)) (-5 *3 (-409 (-953 *5)))))) 
-(-10 -7 (-15 -2005 ((-585 (-409 (-953 |#1|))) (-409 (-953 |#1|)) (-1161))) (-15 -2439 ((-3 (-409 (-953 |#1|)) "failed") (-409 (-953 |#1|)) (-1161))) (-15 -3561 ((-3 (-2 (|:| |mainpart| (-409 (-953 |#1|))) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 (-953 |#1|))) (|:| |logand| (-409 (-953 |#1|))))))) "failed") (-409 (-953 |#1|)) (-1161) (-634 (-409 (-953 |#1|))))) (-15 -3684 ((-3 (-2 (|:| -1924 (-409 (-953 |#1|))) (|:| |coeff| (-409 (-953 |#1|)))) "failed") (-409 (-953 |#1|)) (-1161) (-409 (-953 |#1|))))) 
-((-2447 (((-121) $ $) 59)) (-2537 (((-121) $) 36)) (-3877 ((|#1| $) 30)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) 63)) (-1982 (($ $) 123)) (-1933 (($ $) 103)) (-1462 ((|#1| $) 28)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1902 (($ $) NIL)) (-1974 (($ $) 125)) (-2786 (($ $) 99)) (-1990 (($ $) 127)) (-1941 (($ $) 107)) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) 78)) (-2854 (((-568) $) 80)) (-2925 (((-3 $ "failed") $) 62)) (-3867 (($ |#1| |#1|) 26)) (-2033 (((-121) $) 33)) (-1897 (($) 89)) (-2735 (((-121) $) 43)) (-4044 (($ $ (-568)) NIL)) (-2245 (((-121) $) 34)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-4416 (($ $) 91)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2668 (($ |#1| |#1|) 20) (($ |#1|) 25) (($ (-409 (-568))) 77)) (-3582 ((|#1| $) 27)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) 65) (($ (-634 $)) NIL)) (-2595 (((-3 $ "failed") $ $) 64)) (-1892 (($ $) 93)) (-1994 (($ $) 131)) (-1945 (($ $) 105)) (-1986 (($ $) 133)) (-1937 (($ $) 109)) (-1978 (($ $) 129)) (-2790 (($ $) 101)) (-1639 (((-121) $ |#1|) 31)) (-2745 (((-850) $) 85) (($ (-568)) 67) (($ $) NIL) (($ (-568)) 67)) (-4078 (((-763)) 87)) (-2006 (($ $) 145)) (-1958 (($ $) 115)) (-1826 (((-121) $ $) NIL)) (-1998 (($ $) 143)) (-1949 (($ $) 111)) (-2014 (($ $) 141)) (-1966 (($ $) 121)) (-4023 (($ $) 139)) (-1970 (($ $) 119)) (-2010 (($ $) 137)) (-1962 (($ $) 117)) (-2002 (($ $) 135)) (-1953 (($ $) 113)) (-1887 (($ $ (-917)) 55) (($ $ (-763)) NIL)) (-3056 (($) 21 T CONST)) (-1556 (($) 10 T CONST)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 37)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 35)) (-1773 (($ $) 41) (($ $ $) 42)) (-1767 (($ $ $) 40)) (** (($ $ (-917)) 54) (($ $ (-763)) NIL) (($ $ $) 95) (($ $ (-409 (-568))) 147)) (* (($ (-917) $) 51) (($ (-763) $) NIL) (($ (-568) $) 50) (($ $ $) 48))) 
+((-2119 (((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-1161) (-634 |#2|)) 35)) (-2663 (((-585 |#2|) |#2| (-1161)) 58)) (-4152 (((-3 |#2| "failed") |#2| (-1161)) 147)) (-3654 (((-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1161) (-607 |#2|) (-634 (-607 |#2|))) 149)) (-2686 (((-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1161) |#2|) 38))) 
+(((-559 |#1| |#2|) (-10 -7 (-15 -2686 ((-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1161) |#2|)) (-15 -2119 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-1161) (-634 |#2|))) (-15 -4152 ((-3 |#2| "failed") |#2| (-1161))) (-15 -2663 ((-585 |#2|) |#2| (-1161))) (-15 -3654 ((-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1161) (-607 |#2|) (-634 (-607 |#2|))))) (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568))) (-13 (-27) (-1181) (-432 |#1|))) (T -559)) 
+((-3654 (*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1161)) (-5 *6 (-634 (-607 *3))) (-5 *5 (-607 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *7))) (-4 *7 (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-2 (|:| -4151 *3) (|:| |coeff| *3))) (-5 *1 (-559 *7 *3)))) (-2663 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-559 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) (-4152 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-559 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4))))) (-2119 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-634 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-559 *6 *3)))) (-2686 (*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1161)) (-4 *5 (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-2 (|:| -4151 *3) (|:| |coeff| *3))) (-5 *1 (-559 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5)))))) 
+(-10 -7 (-15 -2686 ((-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1161) |#2|)) (-15 -2119 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-1161) (-634 |#2|))) (-15 -4152 ((-3 |#2| "failed") |#2| (-1161))) (-15 -2663 ((-585 |#2|) |#2| (-1161))) (-15 -3654 ((-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-1161) (-607 |#2|) (-634 (-607 |#2|))))) 
+((-1506 (((-634 |#5|) (-634 |#5|)) 41))) 
+(((-560 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1506 ((-634 |#5|) (-634 |#5|)))) (-365) (-634 (-1161)) (-788) (-842) (-950 |#1| |#3| |#4|)) (T -560)) 
+((-1506 (*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-950 *3 *5 *6)) (-4 *3 (-365)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-560 *3 *4 *5 *6 *7)) (-14 *4 (-634 (-1161)))))) 
+(-10 -7 (-15 -1506 ((-634 |#5|) (-634 |#5|)))) 
+((-3498 (((-420 |#1|) |#1|) 18)) (-3850 (((-420 |#1|) |#1|) 32)) (-3449 (((-3 |#1| "failed") |#1|) 43)) (-4024 (((-420 |#1|) |#1|) 49))) 
+(((-561 |#1|) (-10 -7 (-15 -3850 ((-420 |#1|) |#1|)) (-15 -3498 ((-420 |#1|) |#1|)) (-15 -4024 ((-420 |#1|) |#1|)) (-15 -3449 ((-3 |#1| "failed") |#1|))) (-550)) (T -561)) 
+((-3449 (*1 *2 *2) (|partial| -12 (-5 *1 (-561 *2)) (-4 *2 (-550)))) (-4024 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-561 *3)) (-4 *3 (-550)))) (-3498 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-561 *3)) (-4 *3 (-550)))) (-3850 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-561 *3)) (-4 *3 (-550))))) 
+(-10 -7 (-15 -3850 ((-420 |#1|) |#1|)) (-15 -3498 ((-420 |#1|) |#1|)) (-15 -4024 ((-420 |#1|) |#1|)) (-15 -3449 ((-3 |#1| "failed") |#1|))) 
+((-1758 (((-634 |#3|) |#8| (-634 |#3|)) 45)) (-4454 (((-634 |#3|) |#8| (-763) |#3| (-634 |#3|)) 44)) (-3814 (((-634 (-1244 |#1|)) |#8| (-634 |#3|)) 26)) (-1399 (((-634 (-1244 |#1|)) |#8| (-634 |#3|)) 27))) 
+(((-562 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -1399 ((-634 (-1244 |#1|)) |#8| (-634 |#3|))) (-15 -3814 ((-634 (-1244 |#1|)) |#8| (-634 |#3|))) (-15 -1758 ((-634 |#3|) |#8| (-634 |#3|))) (-15 -4454 ((-634 |#3|) |#8| (-763) |#3| (-634 |#3|)))) (-365) (-634 (-1161)) (-950 |#1| |#4| (-852 |#2|)) (-230 (-1699 |#2|) (-763)) (-971 |#1|) (-641 |#1|) (-920 |#1| |#6|) (-235 |#7|)) (T -562)) 
+((-4454 (*1 *2 *3 *4 *5 *2) (-12 (-5 *2 (-634 *5)) (-4 *5 (-950 *6 *8 (-852 *7))) (-4 *8 (-230 (-1699 *7) *4)) (-5 *4 (-763)) (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *10 (-641 *6)) (-4 *11 (-920 *6 *10)) (-5 *1 (-562 *6 *7 *5 *8 *9 *10 *11 *3)) (-4 *9 (-971 *6)) (-4 *3 (-235 *11)))) (-1758 (*1 *2 *3 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-5 *1 (-562 *4 *5 *6 *7 *8 *9 *10 *3)) (-4 *8 (-971 *4)) (-4 *3 (-235 *10)))) (-3814 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *7)) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1699 *6) (-763))) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-5 *2 (-634 (-1244 *5))) (-5 *1 (-562 *5 *6 *7 *8 *9 *10 *11 *3)) (-4 *9 (-971 *5)) (-4 *3 (-235 *11)))) (-1399 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *7)) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1699 *6) (-763))) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-5 *2 (-634 (-1244 *5))) (-5 *1 (-562 *5 *6 *7 *8 *9 *10 *11 *3)) (-4 *9 (-971 *5)) (-4 *3 (-235 *11))))) 
+(-10 -7 (-15 -1399 ((-634 (-1244 |#1|)) |#8| (-634 |#3|))) (-15 -3814 ((-634 (-1244 |#1|)) |#8| (-634 |#3|))) (-15 -1758 ((-634 |#3|) |#8| (-634 |#3|))) (-15 -4454 ((-634 |#3|) |#8| (-763) |#3| (-634 |#3|)))) 
+((-1350 (($) 9)) (-1677 (((-3 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) "failed") (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 29)) (-4253 (((-634 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) $) 26)) (-1708 (($ (-2 (|:| -3651 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) 23)) (-3656 (($ (-634 (-2 (|:| -3651 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) 21)) (-4085 (((-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 33)) (-1480 (((-634 (-2 (|:| -3651 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) $) 31)) (-2455 (((-1249)) 12))) 
+(((-563) (-10 -8 (-15 -1350 ($)) (-15 -2455 ((-1249))) (-15 -4253 ((-634 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) $)) (-15 -3656 ($ (-634 (-2 (|:| -3651 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))))) (-15 -1708 ($ (-2 (|:| -3651 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-15 -1677 ((-3 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) "failed") (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -1480 ((-634 (-2 (|:| -3651 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) $)) (-15 -4085 ((-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))))) (T -563)) 
+((-4085 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *1 (-563)))) (-1480 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| -3651 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-5 *1 (-563)))) (-1677 (*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *1 (-563)))) (-1708 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| -3651 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) (-5 *1 (-563)))) (-3656 (*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3651 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-5 *1 (-563)))) (-4253 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-5 *1 (-563)))) (-2455 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-563)))) (-1350 (*1 *1) (-5 *1 (-563)))) 
+(-10 -8 (-15 -1350 ($)) (-15 -2455 ((-1249))) (-15 -4253 ((-634 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) $)) (-15 -3656 ($ (-634 (-2 (|:| -3651 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))))) (-15 -1708 ($ (-2 (|:| -3651 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-15 -1677 ((-3 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) "failed") (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -1480 ((-634 (-2 (|:| -3651 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) $)) (-15 -4085 ((-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))))) 
+((-3840 (((-1157 (-409 (-1157 |#2|))) |#2| (-607 |#2|) (-607 |#2|) (-1157 |#2|)) 28)) (-3014 (((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-607 |#2|) (-607 |#2|) (-634 |#2|) (-607 |#2|) |#2| (-409 (-1157 |#2|))) 96) (((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-607 |#2|) (-607 |#2|) (-634 |#2|) |#2| (-1157 |#2|)) 106)) (-3069 (((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|) (-607 |#2|) |#2| (-409 (-1157 |#2|))) 78) (((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|) |#2| (-1157 |#2|)) 50)) (-3032 (((-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-607 |#2|) (-607 |#2|) |#2| (-607 |#2|) |#2| (-409 (-1157 |#2|))) 85) (((-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-607 |#2|) (-607 |#2|) |#2| |#2| (-1157 |#2|)) 105)) (-2488 (((-3 |#2| "failed") |#2| |#2| (-607 |#2|) (-607 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1161)) (-607 |#2|) |#2| (-409 (-1157 |#2|))) 101) (((-3 |#2| "failed") |#2| |#2| (-607 |#2|) (-607 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1161)) |#2| (-1157 |#2|)) 107)) (-3077 (((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2588 (-634 |#2|))) |#3| |#2| (-607 |#2|) (-607 |#2|) (-607 |#2|) |#2| (-409 (-1157 |#2|))) 124 (|has| |#3| (-646 |#2|))) (((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2588 (-634 |#2|))) |#3| |#2| (-607 |#2|) (-607 |#2|) |#2| (-1157 |#2|)) 123 (|has| |#3| (-646 |#2|)))) (-2053 ((|#2| (-1157 (-409 (-1157 |#2|))) (-607 |#2|) |#2|) 48)) (-3087 (((-1157 (-409 (-1157 |#2|))) (-1157 |#2|) (-607 |#2|)) 27))) 
+(((-564 |#1| |#2| |#3|) (-10 -7 (-15 -3069 ((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|) |#2| (-1157 |#2|))) (-15 -3069 ((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|) (-607 |#2|) |#2| (-409 (-1157 |#2|)))) (-15 -3032 ((-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-607 |#2|) (-607 |#2|) |#2| |#2| (-1157 |#2|))) (-15 -3032 ((-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-607 |#2|) (-607 |#2|) |#2| (-607 |#2|) |#2| (-409 (-1157 |#2|)))) (-15 -3014 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-607 |#2|) (-607 |#2|) (-634 |#2|) |#2| (-1157 |#2|))) (-15 -3014 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-607 |#2|) (-607 |#2|) (-634 |#2|) (-607 |#2|) |#2| (-409 (-1157 |#2|)))) (-15 -2488 ((-3 |#2| "failed") |#2| |#2| (-607 |#2|) (-607 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1161)) |#2| (-1157 |#2|))) (-15 -2488 ((-3 |#2| "failed") |#2| |#2| (-607 |#2|) (-607 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1161)) (-607 |#2|) |#2| (-409 (-1157 |#2|)))) (-15 -3840 ((-1157 (-409 (-1157 |#2|))) |#2| (-607 |#2|) (-607 |#2|) (-1157 |#2|))) (-15 -2053 (|#2| (-1157 (-409 (-1157 |#2|))) (-607 |#2|) |#2|)) (-15 -3087 ((-1157 (-409 (-1157 |#2|))) (-1157 |#2|) (-607 |#2|))) (IF (|has| |#3| (-646 |#2|)) (PROGN (-15 -3077 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2588 (-634 |#2|))) |#3| |#2| (-607 |#2|) (-607 |#2|) |#2| (-1157 |#2|))) (-15 -3077 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2588 (-634 |#2|))) |#3| |#2| (-607 |#2|) (-607 |#2|) (-607 |#2|) |#2| (-409 (-1157 |#2|))))) |noBranch|)) (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568))) (-13 (-432 |#1|) (-27) (-1181)) (-1090)) (T -564)) 
+((-3077 (*1 *2 *3 *4 *5 *5 *5 *4 *6) (-12 (-5 *5 (-607 *4)) (-5 *6 (-409 (-1157 *4))) (-4 *4 (-13 (-432 *7) (-27) (-1181))) (-4 *7 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2588 (-634 *4)))) (-5 *1 (-564 *7 *4 *3)) (-4 *3 (-646 *4)) (-4 *3 (-1090)))) (-3077 (*1 *2 *3 *4 *5 *5 *4 *6) (-12 (-5 *5 (-607 *4)) (-5 *6 (-1157 *4)) (-4 *4 (-13 (-432 *7) (-27) (-1181))) (-4 *7 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2588 (-634 *4)))) (-5 *1 (-564 *7 *4 *3)) (-4 *3 (-646 *4)) (-4 *3 (-1090)))) (-3087 (*1 *2 *3 *4) (-12 (-5 *4 (-607 *6)) (-4 *6 (-13 (-432 *5) (-27) (-1181))) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-1157 (-409 (-1157 *6)))) (-5 *1 (-564 *5 *6 *7)) (-5 *3 (-1157 *6)) (-4 *7 (-1090)))) (-2053 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1157 (-409 (-1157 *2)))) (-5 *4 (-607 *2)) (-4 *2 (-13 (-432 *5) (-27) (-1181))) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *1 (-564 *5 *2 *6)) (-4 *6 (-1090)))) (-3840 (*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-607 *3)) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-1157 (-409 (-1157 *3)))) (-5 *1 (-564 *6 *3 *7)) (-5 *5 (-1157 *3)) (-4 *7 (-1090)))) (-2488 (*1 *2 *2 *2 *3 *3 *4 *3 *2 *5) (|partial| -12 (-5 *3 (-607 *2)) (-5 *4 (-1 (-3 *2 "failed") *2 *2 (-1161))) (-5 *5 (-409 (-1157 *2))) (-4 *2 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *1 (-564 *6 *2 *7)) (-4 *7 (-1090)))) (-2488 (*1 *2 *2 *2 *3 *3 *4 *2 *5) (|partial| -12 (-5 *3 (-607 *2)) (-5 *4 (-1 (-3 *2 "failed") *2 *2 (-1161))) (-5 *5 (-1157 *2)) (-4 *2 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *1 (-564 *6 *2 *7)) (-4 *7 (-1090)))) (-3014 (*1 *2 *3 *4 *4 *5 *4 *3 *6) (|partial| -12 (-5 *4 (-607 *3)) (-5 *5 (-634 *3)) (-5 *6 (-409 (-1157 *3))) (-4 *3 (-13 (-432 *7) (-27) (-1181))) (-4 *7 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-564 *7 *3 *8)) (-4 *8 (-1090)))) (-3014 (*1 *2 *3 *4 *4 *5 *3 *6) (|partial| -12 (-5 *4 (-607 *3)) (-5 *5 (-634 *3)) (-5 *6 (-1157 *3)) (-4 *3 (-13 (-432 *7) (-27) (-1181))) (-4 *7 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-564 *7 *3 *8)) (-4 *8 (-1090)))) (-3032 (*1 *2 *3 *4 *4 *3 *4 *3 *5) (|partial| -12 (-5 *4 (-607 *3)) (-5 *5 (-409 (-1157 *3))) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| -4151 *3) (|:| |coeff| *3))) (-5 *1 (-564 *6 *3 *7)) (-4 *7 (-1090)))) (-3032 (*1 *2 *3 *4 *4 *3 *3 *5) (|partial| -12 (-5 *4 (-607 *3)) (-5 *5 (-1157 *3)) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| -4151 *3) (|:| |coeff| *3))) (-5 *1 (-564 *6 *3 *7)) (-4 *7 (-1090)))) (-3069 (*1 *2 *3 *4 *4 *4 *3 *5) (-12 (-5 *4 (-607 *3)) (-5 *5 (-409 (-1157 *3))) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-564 *6 *3 *7)) (-4 *7 (-1090)))) (-3069 (*1 *2 *3 *4 *4 *3 *5) (-12 (-5 *4 (-607 *3)) (-5 *5 (-1157 *3)) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-564 *6 *3 *7)) (-4 *7 (-1090))))) 
+(-10 -7 (-15 -3069 ((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|) |#2| (-1157 |#2|))) (-15 -3069 ((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|) (-607 |#2|) |#2| (-409 (-1157 |#2|)))) (-15 -3032 ((-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-607 |#2|) (-607 |#2|) |#2| |#2| (-1157 |#2|))) (-15 -3032 ((-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-607 |#2|) (-607 |#2|) |#2| (-607 |#2|) |#2| (-409 (-1157 |#2|)))) (-15 -3014 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-607 |#2|) (-607 |#2|) (-634 |#2|) |#2| (-1157 |#2|))) (-15 -3014 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-607 |#2|) (-607 |#2|) (-634 |#2|) (-607 |#2|) |#2| (-409 (-1157 |#2|)))) (-15 -2488 ((-3 |#2| "failed") |#2| |#2| (-607 |#2|) (-607 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1161)) |#2| (-1157 |#2|))) (-15 -2488 ((-3 |#2| "failed") |#2| |#2| (-607 |#2|) (-607 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1161)) (-607 |#2|) |#2| (-409 (-1157 |#2|)))) (-15 -3840 ((-1157 (-409 (-1157 |#2|))) |#2| (-607 |#2|) (-607 |#2|) (-1157 |#2|))) (-15 -2053 (|#2| (-1157 (-409 (-1157 |#2|))) (-607 |#2|) |#2|)) (-15 -3087 ((-1157 (-409 (-1157 |#2|))) (-1157 |#2|) (-607 |#2|))) (IF (|has| |#3| (-646 |#2|)) (PROGN (-15 -3077 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2588 (-634 |#2|))) |#3| |#2| (-607 |#2|) (-607 |#2|) |#2| (-1157 |#2|))) (-15 -3077 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2588 (-634 |#2|))) |#3| |#2| (-607 |#2|) (-607 |#2|) (-607 |#2|) |#2| (-409 (-1157 |#2|))))) |noBranch|)) 
+((-3875 (((-568) (-568) (-763)) 65)) (-1479 (((-568) (-568)) 64)) (-2944 (((-568) (-568)) 63)) (-4341 (((-568) (-568)) 68)) (-3214 (((-568) (-568) (-568)) 48)) (-1855 (((-568) (-568) (-568)) 45)) (-2472 (((-409 (-568)) (-568)) 20)) (-4286 (((-568) (-568)) 21)) (-1986 (((-568) (-568)) 57)) (-4492 (((-568) (-568)) 32)) (-4097 (((-634 (-568)) (-568)) 62)) (-3500 (((-568) (-568) (-568) (-568) (-568)) 43)) (-1839 (((-409 (-568)) (-568)) 41))) 
+(((-565) (-10 -7 (-15 -1839 ((-409 (-568)) (-568))) (-15 -3500 ((-568) (-568) (-568) (-568) (-568))) (-15 -4097 ((-634 (-568)) (-568))) (-15 -4492 ((-568) (-568))) (-15 -1986 ((-568) (-568))) (-15 -4286 ((-568) (-568))) (-15 -2472 ((-409 (-568)) (-568))) (-15 -1855 ((-568) (-568) (-568))) (-15 -3214 ((-568) (-568) (-568))) (-15 -4341 ((-568) (-568))) (-15 -2944 ((-568) (-568))) (-15 -1479 ((-568) (-568))) (-15 -3875 ((-568) (-568) (-763))))) (T -565)) 
+((-3875 (*1 *2 *2 *3) (-12 (-5 *2 (-568)) (-5 *3 (-763)) (-5 *1 (-565)))) (-1479 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565)))) (-2944 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565)))) (-4341 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565)))) (-3214 (*1 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565)))) (-1855 (*1 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565)))) (-2472 (*1 *2 *3) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-565)) (-5 *3 (-568)))) (-4286 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565)))) (-1986 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565)))) (-4492 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565)))) (-4097 (*1 *2 *3) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-565)) (-5 *3 (-568)))) (-3500 (*1 *2 *2 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565)))) (-1839 (*1 *2 *3) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-565)) (-5 *3 (-568))))) 
+(-10 -7 (-15 -1839 ((-409 (-568)) (-568))) (-15 -3500 ((-568) (-568) (-568) (-568) (-568))) (-15 -4097 ((-634 (-568)) (-568))) (-15 -4492 ((-568) (-568))) (-15 -1986 ((-568) (-568))) (-15 -4286 ((-568) (-568))) (-15 -2472 ((-409 (-568)) (-568))) (-15 -1855 ((-568) (-568) (-568))) (-15 -3214 ((-568) (-568) (-568))) (-15 -4341 ((-568) (-568))) (-15 -2944 ((-568) (-568))) (-15 -1479 ((-568) (-568))) (-15 -3875 ((-568) (-568) (-763)))) 
+((-2780 (((-2 (|:| |answer| |#4|) (|:| -1989 |#4|)) |#4| (-1 |#2| |#2|)) 52))) 
+(((-566 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2780 ((-2 (|:| |answer| |#4|) (|:| -1989 |#4|)) |#4| (-1 |#2| |#2|)))) (-365) (-1219 |#1|) (-1219 (-409 |#2|)) (-340 |#1| |#2| |#3|)) (T -566)) 
+((-2780 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-4 *7 (-1219 (-409 *6))) (-5 *2 (-2 (|:| |answer| *3) (|:| -1989 *3))) (-5 *1 (-566 *5 *6 *7 *3)) (-4 *3 (-340 *5 *6 *7))))) 
+(-10 -7 (-15 -2780 ((-2 (|:| |answer| |#4|) (|:| -1989 |#4|)) |#4| (-1 |#2| |#2|)))) 
+((-2780 (((-2 (|:| |answer| (-409 |#2|)) (|:| -1989 (-409 |#2|)) (|:| |specpart| (-409 |#2|)) (|:| |polypart| |#2|)) (-409 |#2|) (-1 |#2| |#2|)) 18))) 
+(((-567 |#1| |#2|) (-10 -7 (-15 -2780 ((-2 (|:| |answer| (-409 |#2|)) (|:| -1989 (-409 |#2|)) (|:| |specpart| (-409 |#2|)) (|:| |polypart| |#2|)) (-409 |#2|) (-1 |#2| |#2|)))) (-365) (-1219 |#1|)) (T -567)) 
+((-2780 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| |answer| (-409 *6)) (|:| -1989 (-409 *6)) (|:| |specpart| (-409 *6)) (|:| |polypart| *6))) (-5 *1 (-567 *5 *6)) (-5 *3 (-409 *6))))) 
+(-10 -7 (-15 -2780 ((-2 (|:| |answer| (-409 |#2|)) (|:| -1989 (-409 |#2|)) (|:| |specpart| (-409 |#2|)) (|:| |polypart| |#2|)) (-409 |#2|) (-1 |#2| |#2|)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 25)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 86)) (-3661 (($ $) 87)) (-4426 (((-121) $) NIL)) (-2519 (($ $ $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-1353 (($ $ $ $) 42)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2589 (((-121) $ $) NIL)) (-3337 (((-568) $) NIL)) (-1872 (($ $ $) 80)) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) NIL)) (-2857 (((-568) $) NIL)) (-2403 (($ $ $) 79)) (-1668 (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 60) (((-679 (-568)) (-679 $)) 57)) (-2902 (((-3 $ "failed") $) 83)) (-3254 (((-3 (-409 (-568)) "failed") $) NIL)) (-1338 (((-121) $) NIL)) (-2394 (((-409 (-568)) $) NIL)) (-1733 (($) 62) (($ $) 63)) (-2414 (($ $ $) 78)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-2382 (($ $ $ $) NIL)) (-3155 (($ $ $) 54)) (-1436 (((-121) $) NIL)) (-2341 (($ $ $) NIL)) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL)) (-1598 (((-121) $) 26)) (-2268 (((-121) $) 73)) (-2214 (((-3 $ "failed") $) NIL)) (-2859 (((-121) $) 34)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-4374 (($ $ $ $) 43)) (-1732 (($ $ $) 75)) (-2047 (($ $ $) 74)) (-3248 (($ $) NIL)) (-3680 (($ $) 40)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) 53)) (-3264 (($ $ $) NIL)) (-4436 (($) NIL T CONST)) (-1890 (($ $) 31)) (-4025 (((-1108) $) NIL) (($ $) 33)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 117)) (-2723 (($ $ $) 84) (($ (-634 $)) NIL)) (-2406 (($ $) NIL)) (-3850 (((-420 $) $) 103)) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL)) (-2597 (((-3 $ "failed") $ $) 82)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2080 (((-121) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 77)) (-4191 (($ $ (-763)) NIL) (($ $) NIL)) (-3953 (($ $) 32)) (-3865 (($ $) 30)) (-4280 (((-568) $) 39) (((-541) $) 51) (((-887 (-568)) $) NIL) (((-381) $) 46) (((-215) $) 48) (((-1143) $) 52)) (-2747 (((-850) $) 37) (($ (-568)) 38) (($ $) NIL) (($ (-568)) 38)) (-3425 (((-763)) NIL)) (-3600 (((-121) $ $) NIL)) (-3584 (($ $ $) NIL)) (-2404 (($) 29)) (-2273 (((-121) $ $) NIL)) (-1564 (($ $ $ $) 41)) (-2811 (($ $) 61)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 27 T CONST)) (-1557 (($) 28 T CONST)) (-2628 (((-1143) $) 20) (((-1143) $ (-121)) 22) (((-1249) (-817) $) 23) (((-1249) (-817) $ (-121)) 24)) (-3192 (($ $ (-763)) NIL) (($ $) NIL)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 64)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 65)) (-1775 (($ $) 66) (($ $ $) 68)) (-1769 (($ $ $) 67)) (** (($ $ (-917)) NIL) (($ $ (-763)) 72)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 70) (($ $ $) 69))) 
+(((-568) (-13 (-550) (-609 (-1143)) (-823) (-10 -8 (-15 -1733 ($ $)) (-6 -4508) (-6 -4513) (-6 -4509) (-6 -4503)))) (T -568)) 
+((-1733 (*1 *1 *1) (-5 *1 (-568)))) 
+(-13 (-550) (-609 (-1143)) (-823) (-10 -8 (-15 -1733 ($ $)) (-6 -4508) (-6 -4513) (-6 -4509) (-6 -4503))) 
+((-3031 (((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035))) (-761) (-1059)) 103) (((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035))) (-761)) 105)) (-1845 (((-3 (-1035) "failed") (-310 (-381)) (-1082 (-835 (-381))) (-1161)) 168) (((-3 (-1035) "failed") (-310 (-381)) (-1082 (-835 (-381))) (-1143)) 167) (((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381)))) (-381) (-381) (-1059)) 173) (((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381)))) (-381) (-381)) 174) (((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381)))) (-381)) 175) (((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381))))) 176) (((-1035) (-310 (-381)) (-1084 (-835 (-381)))) 163) (((-1035) (-310 (-381)) (-1084 (-835 (-381))) (-381)) 162) (((-1035) (-310 (-381)) (-1084 (-835 (-381))) (-381) (-381)) 158) (((-1035) (-761)) 150) (((-1035) (-310 (-381)) (-1084 (-835 (-381))) (-381) (-381) (-1059)) 157))) 
+(((-569) (-10 -7 (-15 -1845 ((-1035) (-310 (-381)) (-1084 (-835 (-381))) (-381) (-381) (-1059))) (-15 -1845 ((-1035) (-761))) (-15 -1845 ((-1035) (-310 (-381)) (-1084 (-835 (-381))) (-381) (-381))) (-15 -1845 ((-1035) (-310 (-381)) (-1084 (-835 (-381))) (-381))) (-15 -1845 ((-1035) (-310 (-381)) (-1084 (-835 (-381))))) (-15 -1845 ((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381)))))) (-15 -1845 ((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381)))) (-381))) (-15 -1845 ((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381)))) (-381) (-381))) (-15 -1845 ((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381)))) (-381) (-381) (-1059))) (-15 -3031 ((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035))) (-761))) (-15 -3031 ((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035))) (-761) (-1059))) (-15 -1845 ((-3 (-1035) "failed") (-310 (-381)) (-1082 (-835 (-381))) (-1143))) (-15 -1845 ((-3 (-1035) "failed") (-310 (-381)) (-1082 (-835 (-381))) (-1161))))) (T -569)) 
+((-1845 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-835 (-381)))) (-5 *5 (-1161)) (-5 *2 (-1035)) (-5 *1 (-569)))) (-1845 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-835 (-381)))) (-5 *5 (-1143)) (-5 *2 (-1035)) (-5 *1 (-569)))) (-3031 (*1 *2 *3 *4) (-12 (-5 *3 (-761)) (-5 *4 (-1059)) (-5 *2 (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035)))) (-5 *1 (-569)))) (-3031 (*1 *2 *3) (-12 (-5 *3 (-761)) (-5 *2 (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035)))) (-5 *1 (-569)))) (-1845 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-634 (-1084 (-835 (-381))))) (-5 *5 (-381)) (-5 *6 (-1059)) (-5 *2 (-1035)) (-5 *1 (-569)))) (-1845 (*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-634 (-1084 (-835 (-381))))) (-5 *5 (-381)) (-5 *2 (-1035)) (-5 *1 (-569)))) (-1845 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-634 (-1084 (-835 (-381))))) (-5 *5 (-381)) (-5 *2 (-1035)) (-5 *1 (-569)))) (-1845 (*1 *2 *3 *4) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-634 (-1084 (-835 (-381))))) (-5 *2 (-1035)) (-5 *1 (-569)))) (-1845 (*1 *2 *3 *4) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1084 (-835 (-381)))) (-5 *2 (-1035)) (-5 *1 (-569)))) (-1845 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1084 (-835 (-381)))) (-5 *5 (-381)) (-5 *2 (-1035)) (-5 *1 (-569)))) (-1845 (*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1084 (-835 (-381)))) (-5 *5 (-381)) (-5 *2 (-1035)) (-5 *1 (-569)))) (-1845 (*1 *2 *3) (-12 (-5 *3 (-761)) (-5 *2 (-1035)) (-5 *1 (-569)))) (-1845 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1084 (-835 (-381)))) (-5 *5 (-381)) (-5 *6 (-1059)) (-5 *2 (-1035)) (-5 *1 (-569))))) 
+(-10 -7 (-15 -1845 ((-1035) (-310 (-381)) (-1084 (-835 (-381))) (-381) (-381) (-1059))) (-15 -1845 ((-1035) (-761))) (-15 -1845 ((-1035) (-310 (-381)) (-1084 (-835 (-381))) (-381) (-381))) (-15 -1845 ((-1035) (-310 (-381)) (-1084 (-835 (-381))) (-381))) (-15 -1845 ((-1035) (-310 (-381)) (-1084 (-835 (-381))))) (-15 -1845 ((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381)))))) (-15 -1845 ((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381)))) (-381))) (-15 -1845 ((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381)))) (-381) (-381))) (-15 -1845 ((-1035) (-310 (-381)) (-634 (-1084 (-835 (-381)))) (-381) (-381) (-1059))) (-15 -3031 ((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035))) (-761))) (-15 -3031 ((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035))) (-761) (-1059))) (-15 -1845 ((-3 (-1035) "failed") (-310 (-381)) (-1082 (-835 (-381))) (-1143))) (-15 -1845 ((-3 (-1035) "failed") (-310 (-381)) (-1082 (-835 (-381))) (-1161)))) 
+((-3725 (((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-607 |#2|) (-607 |#2|) (-634 |#2|)) 179)) (-2333 (((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|)) 97)) (-3886 (((-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-607 |#2|) (-607 |#2|) |#2|) 175)) (-3157 (((-3 |#2| "failed") |#2| |#2| |#2| (-607 |#2|) (-607 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1161))) 184)) (-1534 (((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2588 (-634 |#2|))) |#3| |#2| (-607 |#2|) (-607 |#2|) (-1161)) 192 (|has| |#3| (-646 |#2|))))) 
+(((-570 |#1| |#2| |#3|) (-10 -7 (-15 -2333 ((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|))) (-15 -3886 ((-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-607 |#2|) (-607 |#2|) |#2|)) (-15 -3725 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-607 |#2|) (-607 |#2|) (-634 |#2|))) (-15 -3157 ((-3 |#2| "failed") |#2| |#2| |#2| (-607 |#2|) (-607 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1161)))) (IF (|has| |#3| (-646 |#2|)) (-15 -1534 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2588 (-634 |#2|))) |#3| |#2| (-607 |#2|) (-607 |#2|) (-1161))) |noBranch|)) (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568))) (-13 (-432 |#1|) (-27) (-1181)) (-1090)) (T -570)) 
+((-1534 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *5 (-607 *4)) (-5 *6 (-1161)) (-4 *4 (-13 (-432 *7) (-27) (-1181))) (-4 *7 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2588 (-634 *4)))) (-5 *1 (-570 *7 *4 *3)) (-4 *3 (-646 *4)) (-4 *3 (-1090)))) (-3157 (*1 *2 *2 *2 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-607 *2)) (-5 *4 (-1 (-3 *2 "failed") *2 *2 (-1161))) (-4 *2 (-13 (-432 *5) (-27) (-1181))) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *1 (-570 *5 *2 *6)) (-4 *6 (-1090)))) (-3725 (*1 *2 *3 *4 *4 *5) (|partial| -12 (-5 *4 (-607 *3)) (-5 *5 (-634 *3)) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-570 *6 *3 *7)) (-4 *7 (-1090)))) (-3886 (*1 *2 *3 *4 *4 *3) (|partial| -12 (-5 *4 (-607 *3)) (-4 *3 (-13 (-432 *5) (-27) (-1181))) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| -4151 *3) (|:| |coeff| *3))) (-5 *1 (-570 *5 *3 *6)) (-4 *6 (-1090)))) (-2333 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-607 *3)) (-4 *3 (-13 (-432 *5) (-27) (-1181))) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-570 *5 *3 *6)) (-4 *6 (-1090))))) 
+(-10 -7 (-15 -2333 ((-585 |#2|) |#2| (-607 |#2|) (-607 |#2|))) (-15 -3886 ((-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") |#2| (-607 |#2|) (-607 |#2|) |#2|)) (-15 -3725 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-607 |#2|) (-607 |#2|) (-634 |#2|))) (-15 -3157 ((-3 |#2| "failed") |#2| |#2| |#2| (-607 |#2|) (-607 |#2|) (-1 (-3 |#2| "failed") |#2| |#2| (-1161)))) (IF (|has| |#3| (-646 |#2|)) (-15 -1534 ((-2 (|:| |particular| (-3 |#2| "failed")) (|:| -2588 (-634 |#2|))) |#3| |#2| (-607 |#2|) (-607 |#2|) (-1161))) |noBranch|)) 
+((-1431 (((-2 (|:| -2358 |#2|) (|:| |nconst| |#2|)) |#2| (-1161)) 62)) (-1780 (((-3 |#2| "failed") |#2| (-1161) (-835 |#2|) (-835 |#2|)) 159 (-12 (|has| |#2| (-1124)) (|has| |#1| (-609 (-887 (-568)))) (|has| |#1| (-881 (-568))))) (((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1161)) 133 (-12 (|has| |#2| (-620)) (|has| |#1| (-609 (-887 (-568)))) (|has| |#1| (-881 (-568)))))) (-1576 (((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1161)) 142 (-12 (|has| |#2| (-620)) (|has| |#1| (-609 (-887 (-568)))) (|has| |#1| (-881 (-568))))))) 
+(((-571 |#1| |#2|) (-10 -7 (-15 -1431 ((-2 (|:| -2358 |#2|) (|:| |nconst| |#2|)) |#2| (-1161))) (IF (|has| |#1| (-609 (-887 (-568)))) (IF (|has| |#1| (-881 (-568))) (PROGN (IF (|has| |#2| (-620)) (PROGN (-15 -1576 ((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1161))) (-15 -1780 ((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1161)))) |noBranch|) (IF (|has| |#2| (-1124)) (-15 -1780 ((-3 |#2| "failed") |#2| (-1161) (-835 |#2|) (-835 |#2|))) |noBranch|)) |noBranch|) |noBranch|)) (-13 (-842) (-1037 (-568)) (-453) (-630 (-568))) (-13 (-27) (-1181) (-432 |#1|))) (T -571)) 
+((-1780 (*1 *2 *2 *3 *4 *4) (|partial| -12 (-5 *3 (-1161)) (-5 *4 (-835 *2)) (-4 *2 (-1124)) (-4 *2 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-609 (-887 (-568)))) (-4 *5 (-881 (-568))) (-4 *5 (-13 (-842) (-1037 (-568)) (-453) (-630 (-568)))) (-5 *1 (-571 *5 *2)))) (-1780 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1161)) (-4 *5 (-609 (-887 (-568)))) (-4 *5 (-881 (-568))) (-4 *5 (-13 (-842) (-1037 (-568)) (-453) (-630 (-568)))) (-5 *2 (-2 (|:| |special| *3) (|:| |integrand| *3))) (-5 *1 (-571 *5 *3)) (-4 *3 (-620)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) (-1576 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1161)) (-4 *5 (-609 (-887 (-568)))) (-4 *5 (-881 (-568))) (-4 *5 (-13 (-842) (-1037 (-568)) (-453) (-630 (-568)))) (-5 *2 (-2 (|:| |special| *3) (|:| |integrand| *3))) (-5 *1 (-571 *5 *3)) (-4 *3 (-620)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) (-1431 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-842) (-1037 (-568)) (-453) (-630 (-568)))) (-5 *2 (-2 (|:| -2358 *3) (|:| |nconst| *3))) (-5 *1 (-571 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5)))))) 
+(-10 -7 (-15 -1431 ((-2 (|:| -2358 |#2|) (|:| |nconst| |#2|)) |#2| (-1161))) (IF (|has| |#1| (-609 (-887 (-568)))) (IF (|has| |#1| (-881 (-568))) (PROGN (IF (|has| |#2| (-620)) (PROGN (-15 -1576 ((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1161))) (-15 -1780 ((-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1161)))) |noBranch|) (IF (|has| |#2| (-1124)) (-15 -1780 ((-3 |#2| "failed") |#2| (-1161) (-835 |#2|) (-835 |#2|))) |noBranch|)) |noBranch|) |noBranch|)) 
+((-1830 (((-3 (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|)))))) "failed") (-409 |#2|) (-634 (-409 |#2|))) 39)) (-1845 (((-585 (-409 |#2|)) (-409 |#2|)) 27)) (-1449 (((-3 (-409 |#2|) "failed") (-409 |#2|)) 16)) (-3566 (((-3 (-2 (|:| -4151 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-409 |#2|)) 46))) 
+(((-572 |#1| |#2|) (-10 -7 (-15 -1845 ((-585 (-409 |#2|)) (-409 |#2|))) (-15 -1449 ((-3 (-409 |#2|) "failed") (-409 |#2|))) (-15 -3566 ((-3 (-2 (|:| -4151 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-409 |#2|))) (-15 -1830 ((-3 (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|)))))) "failed") (-409 |#2|) (-634 (-409 |#2|))))) (-13 (-365) (-150) (-1037 (-568))) (-1219 |#1|)) (T -572)) 
+((-1830 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-634 (-409 *6))) (-5 *3 (-409 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-572 *5 *6)))) (-3566 (*1 *2 *3 *3) (|partial| -12 (-4 *4 (-13 (-365) (-150) (-1037 (-568)))) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| -4151 (-409 *5)) (|:| |coeff| (-409 *5)))) (-5 *1 (-572 *4 *5)) (-5 *3 (-409 *5)))) (-1449 (*1 *2 *2) (|partial| -12 (-5 *2 (-409 *4)) (-4 *4 (-1219 *3)) (-4 *3 (-13 (-365) (-150) (-1037 (-568)))) (-5 *1 (-572 *3 *4)))) (-1845 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-568)))) (-4 *5 (-1219 *4)) (-5 *2 (-585 (-409 *5))) (-5 *1 (-572 *4 *5)) (-5 *3 (-409 *5))))) 
+(-10 -7 (-15 -1845 ((-585 (-409 |#2|)) (-409 |#2|))) (-15 -1449 ((-3 (-409 |#2|) "failed") (-409 |#2|))) (-15 -3566 ((-3 (-2 (|:| -4151 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-409 |#2|))) (-15 -1830 ((-3 (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|)))))) "failed") (-409 |#2|) (-634 (-409 |#2|))))) 
+((-4487 (((-3 (-568) "failed") |#1|) 14)) (-1812 (((-121) |#1|) 13)) (-1723 (((-568) |#1|) 9))) 
+(((-573 |#1|) (-10 -7 (-15 -1723 ((-568) |#1|)) (-15 -1812 ((-121) |#1|)) (-15 -4487 ((-3 (-568) "failed") |#1|))) (-1037 (-568))) (T -573)) 
+((-4487 (*1 *2 *3) (|partial| -12 (-5 *2 (-568)) (-5 *1 (-573 *3)) (-4 *3 (-1037 *2)))) (-1812 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-573 *3)) (-4 *3 (-1037 (-568))))) (-1723 (*1 *2 *3) (-12 (-5 *2 (-568)) (-5 *1 (-573 *3)) (-4 *3 (-1037 *2))))) 
+(-10 -7 (-15 -1723 ((-568) |#1|)) (-15 -1812 ((-121) |#1|)) (-15 -4487 ((-3 (-568) "failed") |#1|))) 
+((-2853 (((-3 (-2 (|:| |mainpart| (-409 (-953 |#1|))) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 (-953 |#1|))) (|:| |logand| (-409 (-953 |#1|))))))) "failed") (-409 (-953 |#1|)) (-1161) (-634 (-409 (-953 |#1|)))) 43)) (-1284 (((-585 (-409 (-953 |#1|))) (-409 (-953 |#1|)) (-1161)) 25)) (-2462 (((-3 (-409 (-953 |#1|)) "failed") (-409 (-953 |#1|)) (-1161)) 20)) (-2296 (((-3 (-2 (|:| -4151 (-409 (-953 |#1|))) (|:| |coeff| (-409 (-953 |#1|)))) "failed") (-409 (-953 |#1|)) (-1161) (-409 (-953 |#1|))) 32))) 
+(((-574 |#1|) (-10 -7 (-15 -1284 ((-585 (-409 (-953 |#1|))) (-409 (-953 |#1|)) (-1161))) (-15 -2462 ((-3 (-409 (-953 |#1|)) "failed") (-409 (-953 |#1|)) (-1161))) (-15 -2853 ((-3 (-2 (|:| |mainpart| (-409 (-953 |#1|))) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 (-953 |#1|))) (|:| |logand| (-409 (-953 |#1|))))))) "failed") (-409 (-953 |#1|)) (-1161) (-634 (-409 (-953 |#1|))))) (-15 -2296 ((-3 (-2 (|:| -4151 (-409 (-953 |#1|))) (|:| |coeff| (-409 (-953 |#1|)))) "failed") (-409 (-953 |#1|)) (-1161) (-409 (-953 |#1|))))) (-13 (-558) (-1037 (-568)) (-150))) (T -574)) 
+((-2296 (*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1161)) (-4 *5 (-13 (-558) (-1037 (-568)) (-150))) (-5 *2 (-2 (|:| -4151 (-409 (-953 *5))) (|:| |coeff| (-409 (-953 *5))))) (-5 *1 (-574 *5)) (-5 *3 (-409 (-953 *5))))) (-2853 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-634 (-409 (-953 *6)))) (-5 *3 (-409 (-953 *6))) (-4 *6 (-13 (-558) (-1037 (-568)) (-150))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-574 *6)))) (-2462 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-409 (-953 *4))) (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-1037 (-568)) (-150))) (-5 *1 (-574 *4)))) (-1284 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-558) (-1037 (-568)) (-150))) (-5 *2 (-585 (-409 (-953 *5)))) (-5 *1 (-574 *5)) (-5 *3 (-409 (-953 *5)))))) 
+(-10 -7 (-15 -1284 ((-585 (-409 (-953 |#1|))) (-409 (-953 |#1|)) (-1161))) (-15 -2462 ((-3 (-409 (-953 |#1|)) "failed") (-409 (-953 |#1|)) (-1161))) (-15 -2853 ((-3 (-2 (|:| |mainpart| (-409 (-953 |#1|))) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 (-953 |#1|))) (|:| |logand| (-409 (-953 |#1|))))))) "failed") (-409 (-953 |#1|)) (-1161) (-634 (-409 (-953 |#1|))))) (-15 -2296 ((-3 (-2 (|:| -4151 (-409 (-953 |#1|))) (|:| |coeff| (-409 (-953 |#1|)))) "failed") (-409 (-953 |#1|)) (-1161) (-409 (-953 |#1|))))) 
+((-2449 (((-121) $ $) 59)) (-1819 (((-121) $) 36)) (-1987 ((|#1| $) 30)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) 63)) (-1984 (($ $) 123)) (-1935 (($ $) 103)) (-2409 ((|#1| $) 28)) (-2689 (((-3 $ "failed") $ $) NIL)) (-1904 (($ $) NIL)) (-1976 (($ $) 125)) (-2788 (($ $) 99)) (-1992 (($ $) 127)) (-1943 (($ $) 107)) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) 78)) (-2857 (((-568) $) 80)) (-2902 (((-3 $ "failed") $) 62)) (-1950 (($ |#1| |#1|) 26)) (-1436 (((-121) $) 33)) (-1899 (($) 89)) (-1598 (((-121) $) 43)) (-1550 (($ $ (-568)) NIL)) (-2859 (((-121) $) 34)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-4418 (($ $) 91)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-4475 (($ |#1| |#1|) 20) (($ |#1|) 25) (($ (-409 (-568))) 77)) (-2933 ((|#1| $) 27)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) 65) (($ (-634 $)) NIL)) (-2597 (((-3 $ "failed") $ $) 64)) (-1894 (($ $) 93)) (-1996 (($ $) 131)) (-1947 (($ $) 105)) (-1988 (($ $) 133)) (-1939 (($ $) 109)) (-1980 (($ $) 129)) (-2792 (($ $) 101)) (-3238 (((-121) $ |#1|) 31)) (-2747 (((-850) $) 85) (($ (-568)) 67) (($ $) NIL) (($ (-568)) 67)) (-3425 (((-763)) 87)) (-2008 (($ $) 145)) (-1959 (($ $) 115)) (-2273 (((-121) $ $) NIL)) (-2000 (($ $) 143)) (-1951 (($ $) 111)) (-2016 (($ $) 141)) (-1968 (($ $) 121)) (-1439 (($ $) 139)) (-1972 (($ $) 119)) (-2012 (($ $) 137)) (-1964 (($ $) 117)) (-2004 (($ $) 135)) (-1955 (($ $) 113)) (-1889 (($ $ (-917)) 55) (($ $ (-763)) NIL)) (-3058 (($) 21 T CONST)) (-1557 (($) 10 T CONST)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 37)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 35)) (-1775 (($ $) 41) (($ $ $) 42)) (-1769 (($ $ $) 40)) (** (($ $ (-917)) 54) (($ $ (-763)) NIL) (($ $ $) 95) (($ $ (-409 (-568))) 147)) (* (($ (-917) $) 51) (($ (-763) $) NIL) (($ (-568) $) 50) (($ $ $) 48))) 
 (((-575 |#1|) (-555 |#1|) (-13 (-406) (-1181))) (T -575)) 
 NIL 
 (-555 |#1|) 
-((-1858 (((-3 (-634 (-1157 (-568))) "failed") (-634 (-1157 (-568))) (-1157 (-568))) 24))) 
-(((-576) (-10 -7 (-15 -1858 ((-3 (-634 (-1157 (-568))) "failed") (-634 (-1157 (-568))) (-1157 (-568)))))) (T -576)) 
-((-1858 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 (-568)))) (-5 *3 (-1157 (-568))) (-5 *1 (-576))))) 
-(-10 -7 (-15 -1858 ((-3 (-634 (-1157 (-568))) "failed") (-634 (-1157 (-568))) (-1157 (-568))))) 
-((-3030 (((-634 (-607 |#2|)) (-634 (-607 |#2|)) (-1161)) 18)) (-1909 (((-634 (-607 |#2|)) (-634 |#2|) (-1161)) 23)) (-1791 (((-634 (-607 |#2|)) (-634 (-607 |#2|)) (-634 (-607 |#2|))) 10)) (-3791 ((|#2| |#2| (-1161)) 51 (|has| |#1| (-558)))) (-2046 ((|#2| |#2| (-1161)) 76 (-12 (|has| |#2| (-279)) (|has| |#1| (-453))))) (-4356 (((-607 |#2|) (-607 |#2|) (-634 (-607 |#2|)) (-1161)) 25)) (-3647 (((-607 |#2|) (-634 (-607 |#2|))) 24)) (-1575 (((-585 |#2|) |#2| (-1161) (-1 (-585 |#2|) |#2| (-1161)) (-1 (-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1161))) 100 (-12 (|has| |#2| (-279)) (|has| |#2| (-620)) (|has| |#2| (-1037 (-1161))) (|has| |#1| (-609 (-887 (-568)))) (|has| |#1| (-453)) (|has| |#1| (-881 (-568))))))) 
-(((-577 |#1| |#2|) (-10 -7 (-15 -3030 ((-634 (-607 |#2|)) (-634 (-607 |#2|)) (-1161))) (-15 -3647 ((-607 |#2|) (-634 (-607 |#2|)))) (-15 -4356 ((-607 |#2|) (-607 |#2|) (-634 (-607 |#2|)) (-1161))) (-15 -1791 ((-634 (-607 |#2|)) (-634 (-607 |#2|)) (-634 (-607 |#2|)))) (-15 -1909 ((-634 (-607 |#2|)) (-634 |#2|) (-1161))) (IF (|has| |#1| (-558)) (-15 -3791 (|#2| |#2| (-1161))) |noBranch|) (IF (|has| |#1| (-453)) (IF (|has| |#2| (-279)) (PROGN (-15 -2046 (|#2| |#2| (-1161))) (IF (|has| |#1| (-609 (-887 (-568)))) (IF (|has| |#1| (-881 (-568))) (IF (|has| |#2| (-620)) (IF (|has| |#2| (-1037 (-1161))) (-15 -1575 ((-585 |#2|) |#2| (-1161) (-1 (-585 |#2|) |#2| (-1161)) (-1 (-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1161)))) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) |noBranch|) |noBranch|)) (-842) (-432 |#1|)) (T -577)) 
-((-1575 (*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-1 (-585 *3) *3 (-1161))) (-5 *6 (-1 (-3 (-2 (|:| |special| *3) (|:| |integrand| *3)) "failed") *3 (-1161))) (-4 *3 (-279)) (-4 *3 (-620)) (-4 *3 (-1037 *4)) (-4 *3 (-432 *7)) (-5 *4 (-1161)) (-4 *7 (-609 (-887 (-568)))) (-4 *7 (-453)) (-4 *7 (-881 (-568))) (-4 *7 (-842)) (-5 *2 (-585 *3)) (-5 *1 (-577 *7 *3)))) (-2046 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-453)) (-4 *4 (-842)) (-5 *1 (-577 *4 *2)) (-4 *2 (-279)) (-4 *2 (-432 *4)))) (-3791 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-558)) (-4 *4 (-842)) (-5 *1 (-577 *4 *2)) (-4 *2 (-432 *4)))) (-1909 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-1161)) (-4 *6 (-432 *5)) (-4 *5 (-842)) (-5 *2 (-634 (-607 *6))) (-5 *1 (-577 *5 *6)))) (-1791 (*1 *2 *2 *2) (-12 (-5 *2 (-634 (-607 *4))) (-4 *4 (-432 *3)) (-4 *3 (-842)) (-5 *1 (-577 *3 *4)))) (-4356 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-634 (-607 *6))) (-5 *4 (-1161)) (-5 *2 (-607 *6)) (-4 *6 (-432 *5)) (-4 *5 (-842)) (-5 *1 (-577 *5 *6)))) (-3647 (*1 *2 *3) (-12 (-5 *3 (-634 (-607 *5))) (-4 *4 (-842)) (-5 *2 (-607 *5)) (-5 *1 (-577 *4 *5)) (-4 *5 (-432 *4)))) (-3030 (*1 *2 *2 *3) (-12 (-5 *2 (-634 (-607 *5))) (-5 *3 (-1161)) (-4 *5 (-432 *4)) (-4 *4 (-842)) (-5 *1 (-577 *4 *5))))) 
-(-10 -7 (-15 -3030 ((-634 (-607 |#2|)) (-634 (-607 |#2|)) (-1161))) (-15 -3647 ((-607 |#2|) (-634 (-607 |#2|)))) (-15 -4356 ((-607 |#2|) (-607 |#2|) (-634 (-607 |#2|)) (-1161))) (-15 -1791 ((-634 (-607 |#2|)) (-634 (-607 |#2|)) (-634 (-607 |#2|)))) (-15 -1909 ((-634 (-607 |#2|)) (-634 |#2|) (-1161))) (IF (|has| |#1| (-558)) (-15 -3791 (|#2| |#2| (-1161))) |noBranch|) (IF (|has| |#1| (-453)) (IF (|has| |#2| (-279)) (PROGN (-15 -2046 (|#2| |#2| (-1161))) (IF (|has| |#1| (-609 (-887 (-568)))) (IF (|has| |#1| (-881 (-568))) (IF (|has| |#2| (-620)) (IF (|has| |#2| (-1037 (-1161))) (-15 -1575 ((-585 |#2|) |#2| (-1161) (-1 (-585 |#2|) |#2| (-1161)) (-1 (-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1161)))) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) |noBranch|) |noBranch|)) 
-((-1569 (((-2 (|:| |answer| (-585 (-409 |#2|))) (|:| |a0| |#1|)) (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-634 |#1|) "failed") (-568) |#1| |#1|)) 167)) (-3187 (((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|))))))) (|:| |a0| |#1|)) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -1924 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-634 (-409 |#2|))) 143)) (-4158 (((-3 (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|)))))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-634 (-409 |#2|))) 140)) (-3705 (((-3 |#2| "failed") |#2| (-1 (-3 (-2 (|:| -1924 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) |#1|) 129)) (-1997 (((-2 (|:| |answer| (-585 (-409 |#2|))) (|:| |a0| |#1|)) (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -1924 |#1|) (|:| |coeff| |#1|)) "failed") |#1|)) 153)) (-4116 (((-3 (-2 (|:| -1924 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-409 |#2|)) 170)) (-1354 (((-3 (-2 (|:| |answer| (-409 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -1924 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -1924 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-409 |#2|)) 173)) (-2250 (((-2 (|:| |ir| (-585 (-409 |#2|))) (|:| |specpart| (-409 |#2|)) (|:| |polypart| |#2|)) (-409 |#2|) (-1 |#2| |#2|)) 81)) (-3311 (((-2 (|:| |answer| |#2|) (|:| |polypart| |#2|)) |#2| (-1 |#2| |#2|)) 88)) (-3027 (((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|))))))) (|:| |a0| |#1|)) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3284 |#1|) (|:| |sol?| (-121))) (-568) |#1|) (-634 (-409 |#2|))) 147)) (-3168 (((-3 (-615 |#1| |#2|) "failed") (-615 |#1| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3284 |#1|) (|:| |sol?| (-121))) (-568) |#1|)) 133)) (-2159 (((-2 (|:| |answer| (-585 (-409 |#2|))) (|:| |a0| |#1|)) (-409 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3284 |#1|) (|:| |sol?| (-121))) (-568) |#1|)) 157)) (-3999 (((-3 (-2 (|:| |answer| (-409 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -1924 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3284 |#1|) (|:| |sol?| (-121))) (-568) |#1|) (-409 |#2|)) 178))) 
-(((-578 |#1| |#2|) (-10 -7 (-15 -1997 ((-2 (|:| |answer| (-585 (-409 |#2|))) (|:| |a0| |#1|)) (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -1924 |#1|) (|:| |coeff| |#1|)) "failed") |#1|))) (-15 -2159 ((-2 (|:| |answer| (-585 (-409 |#2|))) (|:| |a0| |#1|)) (-409 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3284 |#1|) (|:| |sol?| (-121))) (-568) |#1|))) (-15 -1569 ((-2 (|:| |answer| (-585 (-409 |#2|))) (|:| |a0| |#1|)) (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-634 |#1|) "failed") (-568) |#1| |#1|))) (-15 -1354 ((-3 (-2 (|:| |answer| (-409 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -1924 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -1924 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-409 |#2|))) (-15 -3999 ((-3 (-2 (|:| |answer| (-409 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -1924 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3284 |#1|) (|:| |sol?| (-121))) (-568) |#1|) (-409 |#2|))) (-15 -3187 ((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|))))))) (|:| |a0| |#1|)) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -1924 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-634 (-409 |#2|)))) (-15 -3027 ((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|))))))) (|:| |a0| |#1|)) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3284 |#1|) (|:| |sol?| (-121))) (-568) |#1|) (-634 (-409 |#2|)))) (-15 -4116 ((-3 (-2 (|:| -1924 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-409 |#2|))) (-15 -4158 ((-3 (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|)))))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-634 (-409 |#2|)))) (-15 -3705 ((-3 |#2| "failed") |#2| (-1 (-3 (-2 (|:| -1924 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) |#1|)) (-15 -3168 ((-3 (-615 |#1| |#2|) "failed") (-615 |#1| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3284 |#1|) (|:| |sol?| (-121))) (-568) |#1|))) (-15 -2250 ((-2 (|:| |ir| (-585 (-409 |#2|))) (|:| |specpart| (-409 |#2|)) (|:| |polypart| |#2|)) (-409 |#2|) (-1 |#2| |#2|))) (-15 -3311 ((-2 (|:| |answer| |#2|) (|:| |polypart| |#2|)) |#2| (-1 |#2| |#2|)))) (-365) (-1219 |#1|)) (T -578)) 
-((-3311 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| |answer| *3) (|:| |polypart| *3))) (-5 *1 (-578 *5 *3)))) (-2250 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| |ir| (-585 (-409 *6))) (|:| |specpart| (-409 *6)) (|:| |polypart| *6))) (-5 *1 (-578 *5 *6)) (-5 *3 (-409 *6)))) (-3168 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-615 *4 *5)) (-5 *3 (-1 (-2 (|:| |ans| *4) (|:| -3284 *4) (|:| |sol?| (-121))) (-568) *4)) (-4 *4 (-365)) (-4 *5 (-1219 *4)) (-5 *1 (-578 *4 *5)))) (-3705 (*1 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 (-2 (|:| -1924 *4) (|:| |coeff| *4)) "failed") *4)) (-4 *4 (-365)) (-5 *1 (-578 *4 *2)) (-4 *2 (-1219 *4)))) (-4158 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1 *7 *7)) (-5 *5 (-634 (-409 *7))) (-4 *7 (-1219 *6)) (-5 *3 (-409 *7)) (-4 *6 (-365)) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-578 *6 *7)))) (-4116 (*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| -1924 (-409 *6)) (|:| |coeff| (-409 *6)))) (-5 *1 (-578 *5 *6)) (-5 *3 (-409 *6)))) (-3027 (*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1 *8 *8)) (-5 *5 (-1 (-2 (|:| |ans| *7) (|:| -3284 *7) (|:| |sol?| (-121))) (-568) *7)) (-5 *6 (-634 (-409 *8))) (-4 *7 (-365)) (-4 *8 (-1219 *7)) (-5 *3 (-409 *8)) (-5 *2 (-2 (|:| |answer| (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (|:| |a0| *7))) (-5 *1 (-578 *7 *8)))) (-3187 (*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1 *8 *8)) (-5 *5 (-1 (-3 (-2 (|:| -1924 *7) (|:| |coeff| *7)) "failed") *7)) (-5 *6 (-634 (-409 *8))) (-4 *7 (-365)) (-4 *8 (-1219 *7)) (-5 *3 (-409 *8)) (-5 *2 (-2 (|:| |answer| (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (|:| |a0| *7))) (-5 *1 (-578 *7 *8)))) (-3999 (*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-2 (|:| |ans| *6) (|:| -3284 *6) (|:| |sol?| (-121))) (-568) *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-5 *2 (-3 (-2 (|:| |answer| (-409 *7)) (|:| |a0| *6)) (-2 (|:| -1924 (-409 *7)) (|:| |coeff| (-409 *7))) "failed")) (-5 *1 (-578 *6 *7)) (-5 *3 (-409 *7)))) (-1354 (*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-2 (|:| -1924 *6) (|:| |coeff| *6)) "failed") *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-5 *2 (-3 (-2 (|:| |answer| (-409 *7)) (|:| |a0| *6)) (-2 (|:| -1924 (-409 *7)) (|:| |coeff| (-409 *7))) "failed")) (-5 *1 (-578 *6 *7)) (-5 *3 (-409 *7)))) (-1569 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-634 *6) "failed") (-568) *6 *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-5 *2 (-2 (|:| |answer| (-585 (-409 *7))) (|:| |a0| *6))) (-5 *1 (-578 *6 *7)) (-5 *3 (-409 *7)))) (-2159 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-2 (|:| |ans| *6) (|:| -3284 *6) (|:| |sol?| (-121))) (-568) *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-5 *2 (-2 (|:| |answer| (-585 (-409 *7))) (|:| |a0| *6))) (-5 *1 (-578 *6 *7)) (-5 *3 (-409 *7)))) (-1997 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-2 (|:| -1924 *6) (|:| |coeff| *6)) "failed") *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-5 *2 (-2 (|:| |answer| (-585 (-409 *7))) (|:| |a0| *6))) (-5 *1 (-578 *6 *7)) (-5 *3 (-409 *7))))) 
-(-10 -7 (-15 -1997 ((-2 (|:| |answer| (-585 (-409 |#2|))) (|:| |a0| |#1|)) (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -1924 |#1|) (|:| |coeff| |#1|)) "failed") |#1|))) (-15 -2159 ((-2 (|:| |answer| (-585 (-409 |#2|))) (|:| |a0| |#1|)) (-409 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3284 |#1|) (|:| |sol?| (-121))) (-568) |#1|))) (-15 -1569 ((-2 (|:| |answer| (-585 (-409 |#2|))) (|:| |a0| |#1|)) (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-634 |#1|) "failed") (-568) |#1| |#1|))) (-15 -1354 ((-3 (-2 (|:| |answer| (-409 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -1924 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -1924 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-409 |#2|))) (-15 -3999 ((-3 (-2 (|:| |answer| (-409 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -1924 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3284 |#1|) (|:| |sol?| (-121))) (-568) |#1|) (-409 |#2|))) (-15 -3187 ((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|))))))) (|:| |a0| |#1|)) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -1924 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-634 (-409 |#2|)))) (-15 -3027 ((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|))))))) (|:| |a0| |#1|)) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3284 |#1|) (|:| |sol?| (-121))) (-568) |#1|) (-634 (-409 |#2|)))) (-15 -4116 ((-3 (-2 (|:| -1924 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-409 |#2|))) (-15 -4158 ((-3 (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|)))))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-634 (-409 |#2|)))) (-15 -3705 ((-3 |#2| "failed") |#2| (-1 (-3 (-2 (|:| -1924 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) |#1|)) (-15 -3168 ((-3 (-615 |#1| |#2|) "failed") (-615 |#1| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3284 |#1|) (|:| |sol?| (-121))) (-568) |#1|))) (-15 -2250 ((-2 (|:| |ir| (-585 (-409 |#2|))) (|:| |specpart| (-409 |#2|)) (|:| |polypart| |#2|)) (-409 |#2|) (-1 |#2| |#2|))) (-15 -3311 ((-2 (|:| |answer| |#2|) (|:| |polypart| |#2|)) |#2| (-1 |#2| |#2|)))) 
-((-2484 (((-3 |#2| "failed") |#2| (-1161) (-1161)) 10))) 
-(((-579 |#1| |#2|) (-10 -7 (-15 -2484 ((-3 |#2| "failed") |#2| (-1161) (-1161)))) (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568))) (-13 (-1181) (-959) (-1124) (-29 |#1|))) (T -579)) 
-((-2484 (*1 *2 *2 *3 *3) (|partial| -12 (-5 *3 (-1161)) (-4 *4 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-579 *4 *2)) (-4 *2 (-13 (-1181) (-959) (-1124) (-29 *4)))))) 
-(-10 -7 (-15 -2484 ((-3 |#2| "failed") |#2| (-1161) (-1161)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1902 (($ $ (-568)) 65)) (-1497 (((-121) $ $) NIL)) (-2671 (($) NIL T CONST)) (-2143 (($ (-1157 (-568)) (-568)) 71)) (-2401 (($ $ $) NIL)) (-2925 (((-3 $ "failed") $) 57)) (-3974 (($ $) 33)) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-4477 (((-763) $) 15)) (-2735 (((-121) $) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3094 (((-568)) 27)) (-1914 (((-568) $) 31)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1807 (($ $ (-568)) 21)) (-2595 (((-3 $ "failed") $ $) 58)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2709 (((-763) $) 16)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 60)) (-3396 (((-1141 (-568)) $) 18)) (-1811 (($ $) 23)) (-2745 (((-850) $) 85) (($ (-568)) 51) (($ $) NIL)) (-4078 (((-763)) 14)) (-1826 (((-121) $ $) NIL)) (-3996 (((-568) $ (-568)) 35)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 34 T CONST)) (-1556 (($) 19 T CONST)) (-1717 (((-121) $ $) 38)) (-1773 (($ $) 50) (($ $ $) 36)) (-1767 (($ $ $) 49)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 53) (($ $ $) 54))) 
+((-2434 (((-3 (-634 (-1157 (-568))) "failed") (-634 (-1157 (-568))) (-1157 (-568))) 24))) 
+(((-576) (-10 -7 (-15 -2434 ((-3 (-634 (-1157 (-568))) "failed") (-634 (-1157 (-568))) (-1157 (-568)))))) (T -576)) 
+((-2434 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 (-568)))) (-5 *3 (-1157 (-568))) (-5 *1 (-576))))) 
+(-10 -7 (-15 -2434 ((-3 (-634 (-1157 (-568))) "failed") (-634 (-1157 (-568))) (-1157 (-568))))) 
+((-2179 (((-634 (-607 |#2|)) (-634 (-607 |#2|)) (-1161)) 18)) (-2668 (((-634 (-607 |#2|)) (-634 |#2|) (-1161)) 23)) (-1793 (((-634 (-607 |#2|)) (-634 (-607 |#2|)) (-634 (-607 |#2|))) 10)) (-2767 ((|#2| |#2| (-1161)) 51 (|has| |#1| (-558)))) (-1505 ((|#2| |#2| (-1161)) 76 (-12 (|has| |#2| (-279)) (|has| |#1| (-453))))) (-3291 (((-607 |#2|) (-607 |#2|) (-634 (-607 |#2|)) (-1161)) 25)) (-3234 (((-607 |#2|) (-634 (-607 |#2|))) 24)) (-4437 (((-585 |#2|) |#2| (-1161) (-1 (-585 |#2|) |#2| (-1161)) (-1 (-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1161))) 100 (-12 (|has| |#2| (-279)) (|has| |#2| (-620)) (|has| |#2| (-1037 (-1161))) (|has| |#1| (-609 (-887 (-568)))) (|has| |#1| (-453)) (|has| |#1| (-881 (-568))))))) 
+(((-577 |#1| |#2|) (-10 -7 (-15 -2179 ((-634 (-607 |#2|)) (-634 (-607 |#2|)) (-1161))) (-15 -3234 ((-607 |#2|) (-634 (-607 |#2|)))) (-15 -3291 ((-607 |#2|) (-607 |#2|) (-634 (-607 |#2|)) (-1161))) (-15 -1793 ((-634 (-607 |#2|)) (-634 (-607 |#2|)) (-634 (-607 |#2|)))) (-15 -2668 ((-634 (-607 |#2|)) (-634 |#2|) (-1161))) (IF (|has| |#1| (-558)) (-15 -2767 (|#2| |#2| (-1161))) |noBranch|) (IF (|has| |#1| (-453)) (IF (|has| |#2| (-279)) (PROGN (-15 -1505 (|#2| |#2| (-1161))) (IF (|has| |#1| (-609 (-887 (-568)))) (IF (|has| |#1| (-881 (-568))) (IF (|has| |#2| (-620)) (IF (|has| |#2| (-1037 (-1161))) (-15 -4437 ((-585 |#2|) |#2| (-1161) (-1 (-585 |#2|) |#2| (-1161)) (-1 (-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1161)))) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) |noBranch|) |noBranch|)) (-842) (-432 |#1|)) (T -577)) 
+((-4437 (*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-1 (-585 *3) *3 (-1161))) (-5 *6 (-1 (-3 (-2 (|:| |special| *3) (|:| |integrand| *3)) "failed") *3 (-1161))) (-4 *3 (-279)) (-4 *3 (-620)) (-4 *3 (-1037 *4)) (-4 *3 (-432 *7)) (-5 *4 (-1161)) (-4 *7 (-609 (-887 (-568)))) (-4 *7 (-453)) (-4 *7 (-881 (-568))) (-4 *7 (-842)) (-5 *2 (-585 *3)) (-5 *1 (-577 *7 *3)))) (-1505 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-453)) (-4 *4 (-842)) (-5 *1 (-577 *4 *2)) (-4 *2 (-279)) (-4 *2 (-432 *4)))) (-2767 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-558)) (-4 *4 (-842)) (-5 *1 (-577 *4 *2)) (-4 *2 (-432 *4)))) (-2668 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-1161)) (-4 *6 (-432 *5)) (-4 *5 (-842)) (-5 *2 (-634 (-607 *6))) (-5 *1 (-577 *5 *6)))) (-1793 (*1 *2 *2 *2) (-12 (-5 *2 (-634 (-607 *4))) (-4 *4 (-432 *3)) (-4 *3 (-842)) (-5 *1 (-577 *3 *4)))) (-3291 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-634 (-607 *6))) (-5 *4 (-1161)) (-5 *2 (-607 *6)) (-4 *6 (-432 *5)) (-4 *5 (-842)) (-5 *1 (-577 *5 *6)))) (-3234 (*1 *2 *3) (-12 (-5 *3 (-634 (-607 *5))) (-4 *4 (-842)) (-5 *2 (-607 *5)) (-5 *1 (-577 *4 *5)) (-4 *5 (-432 *4)))) (-2179 (*1 *2 *2 *3) (-12 (-5 *2 (-634 (-607 *5))) (-5 *3 (-1161)) (-4 *5 (-432 *4)) (-4 *4 (-842)) (-5 *1 (-577 *4 *5))))) 
+(-10 -7 (-15 -2179 ((-634 (-607 |#2|)) (-634 (-607 |#2|)) (-1161))) (-15 -3234 ((-607 |#2|) (-634 (-607 |#2|)))) (-15 -3291 ((-607 |#2|) (-607 |#2|) (-634 (-607 |#2|)) (-1161))) (-15 -1793 ((-634 (-607 |#2|)) (-634 (-607 |#2|)) (-634 (-607 |#2|)))) (-15 -2668 ((-634 (-607 |#2|)) (-634 |#2|) (-1161))) (IF (|has| |#1| (-558)) (-15 -2767 (|#2| |#2| (-1161))) |noBranch|) (IF (|has| |#1| (-453)) (IF (|has| |#2| (-279)) (PROGN (-15 -1505 (|#2| |#2| (-1161))) (IF (|has| |#1| (-609 (-887 (-568)))) (IF (|has| |#1| (-881 (-568))) (IF (|has| |#2| (-620)) (IF (|has| |#2| (-1037 (-1161))) (-15 -4437 ((-585 |#2|) |#2| (-1161) (-1 (-585 |#2|) |#2| (-1161)) (-1 (-3 (-2 (|:| |special| |#2|) (|:| |integrand| |#2|)) "failed") |#2| (-1161)))) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) |noBranch|) |noBranch|)) 
+((-4405 (((-2 (|:| |answer| (-585 (-409 |#2|))) (|:| |a0| |#1|)) (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-634 |#1|) "failed") (-568) |#1| |#1|)) 167)) (-1774 (((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|))))))) (|:| |a0| |#1|)) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -4151 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-634 (-409 |#2|))) 143)) (-3861 (((-3 (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|)))))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-634 (-409 |#2|))) 140)) (-2391 (((-3 |#2| "failed") |#2| (-1 (-3 (-2 (|:| -4151 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) |#1|) 129)) (-4479 (((-2 (|:| |answer| (-585 (-409 |#2|))) (|:| |a0| |#1|)) (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -4151 |#1|) (|:| |coeff| |#1|)) "failed") |#1|)) 153)) (-3633 (((-3 (-2 (|:| -4151 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-409 |#2|)) 170)) (-3704 (((-3 (-2 (|:| |answer| (-409 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -4151 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -4151 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-409 |#2|)) 173)) (-1641 (((-2 (|:| |ir| (-585 (-409 |#2|))) (|:| |specpart| (-409 |#2|)) (|:| |polypart| |#2|)) (-409 |#2|) (-1 |#2| |#2|)) 81)) (-4276 (((-2 (|:| |answer| |#2|) (|:| |polypart| |#2|)) |#2| (-1 |#2| |#2|)) 88)) (-3300 (((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|))))))) (|:| |a0| |#1|)) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3286 |#1|) (|:| |sol?| (-121))) (-568) |#1|) (-634 (-409 |#2|))) 147)) (-1683 (((-3 (-615 |#1| |#2|) "failed") (-615 |#1| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3286 |#1|) (|:| |sol?| (-121))) (-568) |#1|)) 133)) (-3634 (((-2 (|:| |answer| (-585 (-409 |#2|))) (|:| |a0| |#1|)) (-409 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3286 |#1|) (|:| |sol?| (-121))) (-568) |#1|)) 157)) (-1329 (((-3 (-2 (|:| |answer| (-409 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -4151 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3286 |#1|) (|:| |sol?| (-121))) (-568) |#1|) (-409 |#2|)) 178))) 
+(((-578 |#1| |#2|) (-10 -7 (-15 -4479 ((-2 (|:| |answer| (-585 (-409 |#2|))) (|:| |a0| |#1|)) (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -4151 |#1|) (|:| |coeff| |#1|)) "failed") |#1|))) (-15 -3634 ((-2 (|:| |answer| (-585 (-409 |#2|))) (|:| |a0| |#1|)) (-409 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3286 |#1|) (|:| |sol?| (-121))) (-568) |#1|))) (-15 -4405 ((-2 (|:| |answer| (-585 (-409 |#2|))) (|:| |a0| |#1|)) (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-634 |#1|) "failed") (-568) |#1| |#1|))) (-15 -3704 ((-3 (-2 (|:| |answer| (-409 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -4151 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -4151 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-409 |#2|))) (-15 -1329 ((-3 (-2 (|:| |answer| (-409 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -4151 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3286 |#1|) (|:| |sol?| (-121))) (-568) |#1|) (-409 |#2|))) (-15 -1774 ((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|))))))) (|:| |a0| |#1|)) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -4151 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-634 (-409 |#2|)))) (-15 -3300 ((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|))))))) (|:| |a0| |#1|)) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3286 |#1|) (|:| |sol?| (-121))) (-568) |#1|) (-634 (-409 |#2|)))) (-15 -3633 ((-3 (-2 (|:| -4151 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-409 |#2|))) (-15 -3861 ((-3 (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|)))))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-634 (-409 |#2|)))) (-15 -2391 ((-3 |#2| "failed") |#2| (-1 (-3 (-2 (|:| -4151 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) |#1|)) (-15 -1683 ((-3 (-615 |#1| |#2|) "failed") (-615 |#1| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3286 |#1|) (|:| |sol?| (-121))) (-568) |#1|))) (-15 -1641 ((-2 (|:| |ir| (-585 (-409 |#2|))) (|:| |specpart| (-409 |#2|)) (|:| |polypart| |#2|)) (-409 |#2|) (-1 |#2| |#2|))) (-15 -4276 ((-2 (|:| |answer| |#2|) (|:| |polypart| |#2|)) |#2| (-1 |#2| |#2|)))) (-365) (-1219 |#1|)) (T -578)) 
+((-4276 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| |answer| *3) (|:| |polypart| *3))) (-5 *1 (-578 *5 *3)))) (-1641 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| |ir| (-585 (-409 *6))) (|:| |specpart| (-409 *6)) (|:| |polypart| *6))) (-5 *1 (-578 *5 *6)) (-5 *3 (-409 *6)))) (-1683 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-615 *4 *5)) (-5 *3 (-1 (-2 (|:| |ans| *4) (|:| -3286 *4) (|:| |sol?| (-121))) (-568) *4)) (-4 *4 (-365)) (-4 *5 (-1219 *4)) (-5 *1 (-578 *4 *5)))) (-2391 (*1 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 (-2 (|:| -4151 *4) (|:| |coeff| *4)) "failed") *4)) (-4 *4 (-365)) (-5 *1 (-578 *4 *2)) (-4 *2 (-1219 *4)))) (-3861 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1 *7 *7)) (-5 *5 (-634 (-409 *7))) (-4 *7 (-1219 *6)) (-5 *3 (-409 *7)) (-4 *6 (-365)) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-578 *6 *7)))) (-3633 (*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| -4151 (-409 *6)) (|:| |coeff| (-409 *6)))) (-5 *1 (-578 *5 *6)) (-5 *3 (-409 *6)))) (-3300 (*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1 *8 *8)) (-5 *5 (-1 (-2 (|:| |ans| *7) (|:| -3286 *7) (|:| |sol?| (-121))) (-568) *7)) (-5 *6 (-634 (-409 *8))) (-4 *7 (-365)) (-4 *8 (-1219 *7)) (-5 *3 (-409 *8)) (-5 *2 (-2 (|:| |answer| (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (|:| |a0| *7))) (-5 *1 (-578 *7 *8)))) (-1774 (*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1 *8 *8)) (-5 *5 (-1 (-3 (-2 (|:| -4151 *7) (|:| |coeff| *7)) "failed") *7)) (-5 *6 (-634 (-409 *8))) (-4 *7 (-365)) (-4 *8 (-1219 *7)) (-5 *3 (-409 *8)) (-5 *2 (-2 (|:| |answer| (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (|:| |a0| *7))) (-5 *1 (-578 *7 *8)))) (-1329 (*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-2 (|:| |ans| *6) (|:| -3286 *6) (|:| |sol?| (-121))) (-568) *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-5 *2 (-3 (-2 (|:| |answer| (-409 *7)) (|:| |a0| *6)) (-2 (|:| -4151 (-409 *7)) (|:| |coeff| (-409 *7))) "failed")) (-5 *1 (-578 *6 *7)) (-5 *3 (-409 *7)))) (-3704 (*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-2 (|:| -4151 *6) (|:| |coeff| *6)) "failed") *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-5 *2 (-3 (-2 (|:| |answer| (-409 *7)) (|:| |a0| *6)) (-2 (|:| -4151 (-409 *7)) (|:| |coeff| (-409 *7))) "failed")) (-5 *1 (-578 *6 *7)) (-5 *3 (-409 *7)))) (-4405 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-634 *6) "failed") (-568) *6 *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-5 *2 (-2 (|:| |answer| (-585 (-409 *7))) (|:| |a0| *6))) (-5 *1 (-578 *6 *7)) (-5 *3 (-409 *7)))) (-3634 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-2 (|:| |ans| *6) (|:| -3286 *6) (|:| |sol?| (-121))) (-568) *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-5 *2 (-2 (|:| |answer| (-585 (-409 *7))) (|:| |a0| *6))) (-5 *1 (-578 *6 *7)) (-5 *3 (-409 *7)))) (-4479 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-2 (|:| -4151 *6) (|:| |coeff| *6)) "failed") *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-5 *2 (-2 (|:| |answer| (-585 (-409 *7))) (|:| |a0| *6))) (-5 *1 (-578 *6 *7)) (-5 *3 (-409 *7))))) 
+(-10 -7 (-15 -4479 ((-2 (|:| |answer| (-585 (-409 |#2|))) (|:| |a0| |#1|)) (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -4151 |#1|) (|:| |coeff| |#1|)) "failed") |#1|))) (-15 -3634 ((-2 (|:| |answer| (-585 (-409 |#2|))) (|:| |a0| |#1|)) (-409 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3286 |#1|) (|:| |sol?| (-121))) (-568) |#1|))) (-15 -4405 ((-2 (|:| |answer| (-585 (-409 |#2|))) (|:| |a0| |#1|)) (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-634 |#1|) "failed") (-568) |#1| |#1|))) (-15 -3704 ((-3 (-2 (|:| |answer| (-409 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -4151 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -4151 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-409 |#2|))) (-15 -1329 ((-3 (-2 (|:| |answer| (-409 |#2|)) (|:| |a0| |#1|)) (-2 (|:| -4151 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3286 |#1|) (|:| |sol?| (-121))) (-568) |#1|) (-409 |#2|))) (-15 -1774 ((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|))))))) (|:| |a0| |#1|)) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-3 (-2 (|:| -4151 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) (-634 (-409 |#2|)))) (-15 -3300 ((-3 (-2 (|:| |answer| (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|))))))) (|:| |a0| |#1|)) "failed") (-409 |#2|) (-1 |#2| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3286 |#1|) (|:| |sol?| (-121))) (-568) |#1|) (-634 (-409 |#2|)))) (-15 -3633 ((-3 (-2 (|:| -4151 (-409 |#2|)) (|:| |coeff| (-409 |#2|))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-409 |#2|))) (-15 -3861 ((-3 (-2 (|:| |mainpart| (-409 |#2|)) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| (-409 |#2|)) (|:| |logand| (-409 |#2|)))))) "failed") (-409 |#2|) (-1 |#2| |#2|) (-634 (-409 |#2|)))) (-15 -2391 ((-3 |#2| "failed") |#2| (-1 (-3 (-2 (|:| -4151 |#1|) (|:| |coeff| |#1|)) "failed") |#1|) |#1|)) (-15 -1683 ((-3 (-615 |#1| |#2|) "failed") (-615 |#1| |#2|) (-1 (-2 (|:| |ans| |#1|) (|:| -3286 |#1|) (|:| |sol?| (-121))) (-568) |#1|))) (-15 -1641 ((-2 (|:| |ir| (-585 (-409 |#2|))) (|:| |specpart| (-409 |#2|)) (|:| |polypart| |#2|)) (-409 |#2|) (-1 |#2| |#2|))) (-15 -4276 ((-2 (|:| |answer| |#2|) (|:| |polypart| |#2|)) |#2| (-1 |#2| |#2|)))) 
+((-2692 (((-3 |#2| "failed") |#2| (-1161) (-1161)) 10))) 
+(((-579 |#1| |#2|) (-10 -7 (-15 -2692 ((-3 |#2| "failed") |#2| (-1161) (-1161)))) (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568))) (-13 (-1181) (-959) (-1124) (-29 |#1|))) (T -579)) 
+((-2692 (*1 *2 *2 *3 *3) (|partial| -12 (-5 *3 (-1161)) (-4 *4 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-579 *4 *2)) (-4 *2 (-13 (-1181) (-959) (-1124) (-29 *4)))))) 
+(-10 -7 (-15 -2692 ((-3 |#2| "failed") |#2| (-1161) (-1161)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-1904 (($ $ (-568)) 65)) (-2589 (((-121) $ $) NIL)) (-4490 (($) NIL T CONST)) (-3517 (($ (-1157 (-568)) (-568)) 71)) (-2403 (($ $ $) NIL)) (-2902 (((-3 $ "failed") $) 57)) (-4456 (($ $) 33)) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-1844 (((-763) $) 15)) (-1598 (((-121) $) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2477 (((-568)) 27)) (-2691 (((-568) $) 31)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2168 (($ $ (-568)) 21)) (-2597 (((-3 $ "failed") $ $) 58)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1466 (((-763) $) 16)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 60)) (-1513 (((-1141 (-568)) $) 18)) (-2188 (($ $) 23)) (-2747 (((-850) $) 85) (($ (-568)) 51) (($ $) NIL)) (-3425 (((-763)) 14)) (-2273 (((-121) $ $) NIL)) (-3999 (((-568) $ (-568)) 35)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 34 T CONST)) (-1557 (($) 19 T CONST)) (-1719 (((-121) $ $) 38)) (-1775 (($ $) 50) (($ $ $) 36)) (-1769 (($ $ $) 49)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 53) (($ $ $) 54))) 
 (((-580 |#1| |#2|) (-863 |#1|) (-568) (-121)) (T -580)) 
 NIL 
 (-863 |#1|) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 18)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-2615 (((-121) $) NIL)) (-1739 (((-763)) NIL)) (-1932 (($ $ (-917)) NIL (|has| $ (-370))) (($ $) NIL)) (-3211 (((-1169 (-917) (-763)) (-568)) 47)) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1497 (((-121) $ $) NIL)) (-3983 (((-763)) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 $ "failed") $) 75)) (-2854 (($ $) 74)) (-3498 (($ (-1244 $)) 73)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) 42)) (-2401 (($ $ $) NIL)) (-2925 (((-3 $ "failed") $) 30)) (-1731 (($) NIL)) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-4220 (($) 49)) (-4456 (((-121) $) NIL)) (-3218 (($ $) NIL) (($ $ (-763)) NIL)) (-3927 (((-121) $) NIL)) (-4477 (((-828 (-917)) $) NIL) (((-917) $) NIL)) (-2735 (((-121) $) NIL)) (-2883 (($) 35 (|has| $ (-370)))) (-3917 (((-121) $) NIL (|has| $ (-370)))) (-2657 (($ $ (-917)) NIL (|has| $ (-370))) (($ $) NIL)) (-3038 (((-3 $ "failed") $) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2045 (((-1157 $) $ (-917)) NIL (|has| $ (-370))) (((-1157 $) $) 83)) (-3683 (((-917) $) 55)) (-2035 (((-1157 $) $) NIL (|has| $ (-370)))) (-1422 (((-3 (-1157 $) "failed") $ $) NIL (|has| $ (-370))) (((-1157 $) $) NIL (|has| $ (-370)))) (-2109 (($ $ (-1157 $)) NIL (|has| $ (-370)))) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4434 (($) NIL T CONST)) (-4355 (($ (-917)) 48)) (-2864 (((-121) $) 67)) (-4022 (((-1108) $) NIL)) (-2704 (($) 16 (|has| $ (-370)))) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) 40)) (-3848 (((-420 $) $) NIL)) (-1553 (((-917)) 66) (((-828 (-917))) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3143 (((-3 (-763) "failed") $ $) NIL) (((-763) $) NIL)) (-4321 (((-139)) NIL)) (-4189 (($ $ (-763)) NIL) (($ $) NIL)) (-3206 (((-917) $) 65) (((-828 (-917)) $) NIL)) (-1626 (((-1157 $)) 82)) (-3065 (($) 54)) (-2027 (($) 36 (|has| $ (-370)))) (-4073 (((-679 $) (-1244 $)) NIL) (((-1244 $) $) 71)) (-4278 (((-568) $) 26)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL)) (-2745 (((-850) $) NIL) (($ (-568)) 28) (($ $) NIL) (($ (-409 (-568))) NIL)) (-4371 (((-3 $ "failed") $) NIL) (($ $) 84)) (-4078 (((-763)) 37)) (-3746 (((-1244 $) (-917)) 77) (((-1244 $)) 76)) (-1826 (((-121) $ $) NIL)) (-4390 (((-121) $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) 19 T CONST)) (-1556 (($) 15 T CONST)) (-1316 (($ $ (-763)) NIL (|has| $ (-370))) (($ $) NIL (|has| $ (-370)))) (-3190 (($ $ (-763)) NIL) (($ $) NIL)) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) 24)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 61) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 18)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2134 (((-121) $) NIL)) (-3800 (((-763)) NIL)) (-1934 (($ $ (-917)) NIL (|has| $ (-370))) (($ $) NIL)) (-1856 (((-1169 (-917) (-763)) (-568)) 47)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2589 (((-121) $ $) NIL)) (-3986 (((-763)) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 $ "failed") $) 75)) (-2857 (($ $) 74)) (-3899 (($ (-1244 $)) 73)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) 42)) (-2403 (($ $ $) NIL)) (-2902 (((-3 $ "failed") $) 30)) (-1733 (($) NIL)) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-4188 (($) 49)) (-1748 (((-121) $) NIL)) (-1887 (($ $) NIL) (($ $ (-763)) NIL)) (-2197 (((-121) $) NIL)) (-1844 (((-828 (-917)) $) NIL) (((-917) $) NIL)) (-1598 (((-121) $) NIL)) (-2769 (($) 35 (|has| $ (-370)))) (-2151 (((-121) $) NIL (|has| $ (-370)))) (-4417 (($ $ (-917)) NIL (|has| $ (-370))) (($ $) NIL)) (-2214 (((-3 $ "failed") $) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1497 (((-1157 $) $ (-917)) NIL (|has| $ (-370))) (((-1157 $) $) 83)) (-2291 (((-917) $) 55)) (-1447 (((-1157 $) $) NIL (|has| $ (-370)))) (-2193 (((-3 (-1157 $) "failed") $ $) NIL (|has| $ (-370))) (((-1157 $) $) NIL (|has| $ (-370)))) (-3257 (($ $ (-1157 $)) NIL (|has| $ (-370)))) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4436 (($) NIL T CONST)) (-4357 (($ (-917)) 48)) (-4051 (((-121) $) 67)) (-4025 (((-1108) $) NIL)) (-2707 (($) 16 (|has| $ (-370)))) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) 40)) (-3850 (((-420 $) $) NIL)) (-4321 (((-917)) 66) (((-828 (-917))) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-2721 (((-3 (-763) "failed") $ $) NIL) (((-763) $) NIL)) (-3108 (((-139)) NIL)) (-4191 (($ $ (-763)) NIL) (($ $) NIL)) (-1836 (((-917) $) 65) (((-828 (-917)) $) NIL)) (-1492 (((-1157 $)) 82)) (-2330 (($) 54)) (-1398 (($) 36 (|has| $ (-370)))) (-1656 (((-679 $) (-1244 $)) NIL) (((-1244 $) $) 71)) (-4280 (((-568) $) 26)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL)) (-2747 (((-850) $) NIL) (($ (-568)) 28) (($ $) NIL) (($ (-409 (-568))) NIL)) (-3385 (((-3 $ "failed") $) NIL) (($ $) 84)) (-3425 (((-763)) 37)) (-2588 (((-1244 $) (-917)) 77) (((-1244 $)) 76)) (-2273 (((-121) $ $) NIL)) (-1413 (((-121) $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) 19 T CONST)) (-1557 (($) 15 T CONST)) (-3412 (($ $ (-763)) NIL (|has| $ (-370))) (($ $) NIL (|has| $ (-370)))) (-3192 (($ $ (-763)) NIL) (($ $) NIL)) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) 24)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 61) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL))) 
 (((-581 |#1|) (-13 (-350) (-327 $) (-609 (-568))) (-917)) (T -581)) 
 NIL 
 (-13 (-350) (-327 $) (-609 (-568))) 
-((-1592 (((-1249) (-1143)) 10))) 
-(((-582) (-10 -7 (-15 -1592 ((-1249) (-1143))))) (T -582)) 
-((-1592 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-582))))) 
-(-10 -7 (-15 -1592 ((-1249) (-1143)))) 
-((-3969 (((-585 |#2|) (-585 |#2|)) 37)) (-2789 (((-634 |#2|) (-585 |#2|)) 39)) (-1988 ((|#2| (-585 |#2|)) 46))) 
-(((-583 |#1| |#2|) (-10 -7 (-15 -3969 ((-585 |#2|) (-585 |#2|))) (-15 -2789 ((-634 |#2|) (-585 |#2|))) (-15 -1988 (|#2| (-585 |#2|)))) (-13 (-453) (-1037 (-568)) (-842) (-630 (-568))) (-13 (-29 |#1|) (-1181))) (T -583)) 
-((-1988 (*1 *2 *3) (-12 (-5 *3 (-585 *2)) (-4 *2 (-13 (-29 *4) (-1181))) (-5 *1 (-583 *4 *2)) (-4 *4 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))))) (-2789 (*1 *2 *3) (-12 (-5 *3 (-585 *5)) (-4 *5 (-13 (-29 *4) (-1181))) (-4 *4 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *2 (-634 *5)) (-5 *1 (-583 *4 *5)))) (-3969 (*1 *2 *2) (-12 (-5 *2 (-585 *4)) (-4 *4 (-13 (-29 *3) (-1181))) (-4 *3 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *1 (-583 *3 *4))))) 
-(-10 -7 (-15 -3969 ((-585 |#2|) (-585 |#2|))) (-15 -2789 ((-634 |#2|) (-585 |#2|))) (-15 -1988 (|#2| (-585 |#2|)))) 
-((-2795 (((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| |mainpart| |#1|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#1|) (|:| |logand| |#1|))))) "failed")) 38) (((-3 |#2| "failed") (-1 |#2| |#1|) (-3 |#1| "failed")) 11) (((-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| -1924 |#1|) (|:| |coeff| |#1|)) "failed")) 31) (((-585 |#2|) (-1 |#2| |#1|) (-585 |#1|)) 26))) 
-(((-584 |#1| |#2|) (-10 -7 (-15 -2795 ((-585 |#2|) (-1 |#2| |#1|) (-585 |#1|))) (-15 -2795 ((-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| -1924 |#1|) (|:| |coeff| |#1|)) "failed"))) (-15 -2795 ((-3 |#2| "failed") (-1 |#2| |#1|) (-3 |#1| "failed"))) (-15 -2795 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| |mainpart| |#1|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#1|) (|:| |logand| |#1|))))) "failed")))) (-365) (-365)) (T -584)) 
-((-2795 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *6 *5)) (-5 *4 (-3 (-2 (|:| |mainpart| *5) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *5) (|:| |logand| *5))))) "failed")) (-4 *5 (-365)) (-4 *6 (-365)) (-5 *2 (-2 (|:| |mainpart| *6) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *6) (|:| |logand| *6)))))) (-5 *1 (-584 *5 *6)))) (-2795 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *2 *5)) (-5 *4 (-3 *5 "failed")) (-4 *5 (-365)) (-4 *2 (-365)) (-5 *1 (-584 *5 *2)))) (-2795 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *6 *5)) (-5 *4 (-3 (-2 (|:| -1924 *5) (|:| |coeff| *5)) "failed")) (-4 *5 (-365)) (-4 *6 (-365)) (-5 *2 (-2 (|:| -1924 *6) (|:| |coeff| *6))) (-5 *1 (-584 *5 *6)))) (-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-585 *5)) (-4 *5 (-365)) (-4 *6 (-365)) (-5 *2 (-585 *6)) (-5 *1 (-584 *5 *6))))) 
-(-10 -7 (-15 -2795 ((-585 |#2|) (-1 |#2| |#1|) (-585 |#1|))) (-15 -2795 ((-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| -1924 |#1|) (|:| |coeff| |#1|)) "failed"))) (-15 -2795 ((-3 |#2| "failed") (-1 |#2| |#1|) (-3 |#1| "failed"))) (-15 -2795 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| |mainpart| |#1|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#1|) (|:| |logand| |#1|))))) "failed")))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) 68)) (-2854 ((|#1| $) NIL)) (-1924 ((|#1| $) 24)) (-2293 (((-634 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|))) $) 26)) (-3893 (($ |#1| (-634 (-2 (|:| |scalar| (-409 (-568))) (|:| |coeff| (-1157 |#1|)) (|:| |logand| (-1157 |#1|)))) (-634 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|)))) 22)) (-2577 (((-634 (-2 (|:| |scalar| (-409 (-568))) (|:| |coeff| (-1157 |#1|)) (|:| |logand| (-1157 |#1|)))) $) 25)) (-4487 (((-1143) $) NIL)) (-3690 (($ |#1| |#1|) 32) (($ |#1| (-1161)) 43 (|has| |#1| (-1037 (-1161))))) (-4022 (((-1108) $) NIL)) (-3446 (((-121) $) 28)) (-4189 ((|#1| $ (-1 |#1| |#1|)) 80) ((|#1| $ (-1161)) 81 (|has| |#1| (-895 (-1161))))) (-2745 (((-850) $) 95) (($ |#1|) 23)) (-3056 (($) 16 T CONST)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) 15) (($ $ $) NIL)) (-1767 (($ $ $) 77)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 14) (($ (-409 (-568)) $) 35) (($ $ (-409 (-568))) NIL))) 
-(((-585 |#1|) (-13 (-707 (-409 (-568))) (-1037 |#1|) (-10 -8 (-15 -3893 ($ |#1| (-634 (-2 (|:| |scalar| (-409 (-568))) (|:| |coeff| (-1157 |#1|)) (|:| |logand| (-1157 |#1|)))) (-634 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|))))) (-15 -1924 (|#1| $)) (-15 -2577 ((-634 (-2 (|:| |scalar| (-409 (-568))) (|:| |coeff| (-1157 |#1|)) (|:| |logand| (-1157 |#1|)))) $)) (-15 -2293 ((-634 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|))) $)) (-15 -3446 ((-121) $)) (-15 -3690 ($ |#1| |#1|)) (-15 -4189 (|#1| $ (-1 |#1| |#1|))) (IF (|has| |#1| (-895 (-1161))) (-15 -4189 (|#1| $ (-1161))) |noBranch|) (IF (|has| |#1| (-1037 (-1161))) (-15 -3690 ($ |#1| (-1161))) |noBranch|))) (-365)) (T -585)) 
-((-3893 (*1 *1 *2 *3 *4) (-12 (-5 *3 (-634 (-2 (|:| |scalar| (-409 (-568))) (|:| |coeff| (-1157 *2)) (|:| |logand| (-1157 *2))))) (-5 *4 (-634 (-2 (|:| |integrand| *2) (|:| |intvar| *2)))) (-4 *2 (-365)) (-5 *1 (-585 *2)))) (-1924 (*1 *2 *1) (-12 (-5 *1 (-585 *2)) (-4 *2 (-365)))) (-2577 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |scalar| (-409 (-568))) (|:| |coeff| (-1157 *3)) (|:| |logand| (-1157 *3))))) (-5 *1 (-585 *3)) (-4 *3 (-365)))) (-2293 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |integrand| *3) (|:| |intvar| *3)))) (-5 *1 (-585 *3)) (-4 *3 (-365)))) (-3446 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-585 *3)) (-4 *3 (-365)))) (-3690 (*1 *1 *2 *2) (-12 (-5 *1 (-585 *2)) (-4 *2 (-365)))) (-4189 (*1 *2 *1 *3) (-12 (-5 *3 (-1 *2 *2)) (-5 *1 (-585 *2)) (-4 *2 (-365)))) (-4189 (*1 *2 *1 *3) (-12 (-4 *2 (-365)) (-4 *2 (-895 *3)) (-5 *1 (-585 *2)) (-5 *3 (-1161)))) (-3690 (*1 *1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *1 (-585 *2)) (-4 *2 (-1037 *3)) (-4 *2 (-365))))) 
-(-13 (-707 (-409 (-568))) (-1037 |#1|) (-10 -8 (-15 -3893 ($ |#1| (-634 (-2 (|:| |scalar| (-409 (-568))) (|:| |coeff| (-1157 |#1|)) (|:| |logand| (-1157 |#1|)))) (-634 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|))))) (-15 -1924 (|#1| $)) (-15 -2577 ((-634 (-2 (|:| |scalar| (-409 (-568))) (|:| |coeff| (-1157 |#1|)) (|:| |logand| (-1157 |#1|)))) $)) (-15 -2293 ((-634 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|))) $)) (-15 -3446 ((-121) $)) (-15 -3690 ($ |#1| |#1|)) (-15 -4189 (|#1| $ (-1 |#1| |#1|))) (IF (|has| |#1| (-895 (-1161))) (-15 -4189 (|#1| $ (-1161))) |noBranch|) (IF (|has| |#1| (-1037 (-1161))) (-15 -3690 ($ |#1| (-1161))) |noBranch|))) 
-((-4443 (((-121) |#1|) 16)) (-2742 (((-3 |#1| "failed") |#1|) 14)) (-1789 (((-2 (|:| -1461 |#1|) (|:| -3438 (-763))) |#1|) 30) (((-3 |#1| "failed") |#1| (-763)) 18)) (-3407 (((-121) |#1| (-763)) 19)) (-2558 ((|#1| |#1|) 31)) (-4304 ((|#1| |#1| (-763)) 33))) 
-(((-586 |#1|) (-10 -7 (-15 -3407 ((-121) |#1| (-763))) (-15 -1789 ((-3 |#1| "failed") |#1| (-763))) (-15 -1789 ((-2 (|:| -1461 |#1|) (|:| -3438 (-763))) |#1|)) (-15 -4304 (|#1| |#1| (-763))) (-15 -4443 ((-121) |#1|)) (-15 -2742 ((-3 |#1| "failed") |#1|)) (-15 -2558 (|#1| |#1|))) (-550)) (T -586)) 
-((-2558 (*1 *2 *2) (-12 (-5 *1 (-586 *2)) (-4 *2 (-550)))) (-2742 (*1 *2 *2) (|partial| -12 (-5 *1 (-586 *2)) (-4 *2 (-550)))) (-4443 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-586 *3)) (-4 *3 (-550)))) (-4304 (*1 *2 *2 *3) (-12 (-5 *3 (-763)) (-5 *1 (-586 *2)) (-4 *2 (-550)))) (-1789 (*1 *2 *3) (-12 (-5 *2 (-2 (|:| -1461 *3) (|:| -3438 (-763)))) (-5 *1 (-586 *3)) (-4 *3 (-550)))) (-1789 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-763)) (-5 *1 (-586 *2)) (-4 *2 (-550)))) (-3407 (*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-5 *2 (-121)) (-5 *1 (-586 *3)) (-4 *3 (-550))))) 
-(-10 -7 (-15 -3407 ((-121) |#1| (-763))) (-15 -1789 ((-3 |#1| "failed") |#1| (-763))) (-15 -1789 ((-2 (|:| -1461 |#1|) (|:| -3438 (-763))) |#1|)) (-15 -4304 (|#1| |#1| (-763))) (-15 -4443 ((-121) |#1|)) (-15 -2742 ((-3 |#1| "failed") |#1|)) (-15 -2558 (|#1| |#1|))) 
-((-1344 (((-1157 |#1|) (-917)) 26))) 
-(((-587 |#1|) (-10 -7 (-15 -1344 ((-1157 |#1|) (-917)))) (-350)) (T -587)) 
-((-1344 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-587 *4)) (-4 *4 (-350))))) 
-(-10 -7 (-15 -1344 ((-1157 |#1|) (-917)))) 
-((-3969 (((-585 (-409 (-953 |#1|))) (-585 (-409 (-953 |#1|)))) 26)) (-3837 (((-3 (-310 |#1|) (-634 (-310 |#1|))) (-409 (-953 |#1|)) (-1161)) 32 (|has| |#1| (-150)))) (-2789 (((-634 (-310 |#1|)) (-585 (-409 (-953 |#1|)))) 18)) (-2890 (((-310 |#1|) (-409 (-953 |#1|)) (-1161)) 30 (|has| |#1| (-150)))) (-1988 (((-310 |#1|) (-585 (-409 (-953 |#1|)))) 20))) 
-(((-588 |#1|) (-10 -7 (-15 -3969 ((-585 (-409 (-953 |#1|))) (-585 (-409 (-953 |#1|))))) (-15 -2789 ((-634 (-310 |#1|)) (-585 (-409 (-953 |#1|))))) (-15 -1988 ((-310 |#1|) (-585 (-409 (-953 |#1|))))) (IF (|has| |#1| (-150)) (PROGN (-15 -3837 ((-3 (-310 |#1|) (-634 (-310 |#1|))) (-409 (-953 |#1|)) (-1161))) (-15 -2890 ((-310 |#1|) (-409 (-953 |#1|)) (-1161)))) |noBranch|)) (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (T -588)) 
-((-2890 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-150)) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *2 (-310 *5)) (-5 *1 (-588 *5)))) (-3837 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-150)) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *2 (-3 (-310 *5) (-634 (-310 *5)))) (-5 *1 (-588 *5)))) (-1988 (*1 *2 *3) (-12 (-5 *3 (-585 (-409 (-953 *4)))) (-4 *4 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *2 (-310 *4)) (-5 *1 (-588 *4)))) (-2789 (*1 *2 *3) (-12 (-5 *3 (-585 (-409 (-953 *4)))) (-4 *4 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *2 (-634 (-310 *4))) (-5 *1 (-588 *4)))) (-3969 (*1 *2 *2) (-12 (-5 *2 (-585 (-409 (-953 *3)))) (-4 *3 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *1 (-588 *3))))) 
-(-10 -7 (-15 -3969 ((-585 (-409 (-953 |#1|))) (-585 (-409 (-953 |#1|))))) (-15 -2789 ((-634 (-310 |#1|)) (-585 (-409 (-953 |#1|))))) (-15 -1988 ((-310 |#1|) (-585 (-409 (-953 |#1|))))) (IF (|has| |#1| (-150)) (PROGN (-15 -3837 ((-3 (-310 |#1|) (-634 (-310 |#1|))) (-409 (-953 |#1|)) (-1161))) (-15 -2890 ((-310 |#1|) (-409 (-953 |#1|)) (-1161)))) |noBranch|)) 
-((-2187 (((-634 (-679 (-568))) (-634 (-568)) (-634 (-900 (-568)))) 45) (((-634 (-679 (-568))) (-634 (-568))) 46) (((-679 (-568)) (-634 (-568)) (-900 (-568))) 41)) (-1320 (((-763) (-634 (-568))) 39))) 
-(((-589) (-10 -7 (-15 -1320 ((-763) (-634 (-568)))) (-15 -2187 ((-679 (-568)) (-634 (-568)) (-900 (-568)))) (-15 -2187 ((-634 (-679 (-568))) (-634 (-568)))) (-15 -2187 ((-634 (-679 (-568))) (-634 (-568)) (-634 (-900 (-568))))))) (T -589)) 
-((-2187 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-568))) (-5 *4 (-634 (-900 (-568)))) (-5 *2 (-634 (-679 (-568)))) (-5 *1 (-589)))) (-2187 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-634 (-679 (-568)))) (-5 *1 (-589)))) (-2187 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-568))) (-5 *4 (-900 (-568))) (-5 *2 (-679 (-568))) (-5 *1 (-589)))) (-1320 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-763)) (-5 *1 (-589))))) 
-(-10 -7 (-15 -1320 ((-763) (-634 (-568)))) (-15 -2187 ((-679 (-568)) (-634 (-568)) (-900 (-568)))) (-15 -2187 ((-634 (-679 (-568))) (-634 (-568)))) (-15 -2187 ((-634 (-679 (-568))) (-634 (-568)) (-634 (-900 (-568)))))) 
-((-2067 (((-634 |#5|) |#5| (-121)) 72)) (-1768 (((-121) |#5| (-634 |#5|)) 30))) 
-(((-590 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2067 ((-634 |#5|) |#5| (-121))) (-15 -1768 ((-121) |#5| (-634 |#5|)))) (-13 (-301) (-150)) (-788) (-842) (-1061 |#1| |#2| |#3|) (-1099 |#1| |#2| |#3| |#4|)) (T -590)) 
-((-1768 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-1099 *5 *6 *7 *8)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-590 *5 *6 *7 *8 *3)))) (-2067 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-634 *3)) (-5 *1 (-590 *5 *6 *7 *8 *3)) (-4 *3 (-1099 *5 *6 *7 *8))))) 
-(-10 -7 (-15 -2067 ((-634 |#5|) |#5| (-121))) (-15 -1768 ((-121) |#5| (-634 |#5|)))) 
-((-2447 (((-121) $ $) NIL (|has| (-147) (-1090)))) (-1873 (($ $) 34)) (-2072 (($ $) NIL)) (-4403 (($ $ (-147)) NIL) (($ $ (-142)) NIL)) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-3673 (((-121) $ $) 51)) (-3760 (((-121) $ $ (-568)) 46)) (-3969 (((-634 $) $ (-147)) 59) (((-634 $) $ (-142)) 60)) (-2016 (((-121) (-1 (-121) (-147) (-147)) $) NIL) (((-121) $) NIL (|has| (-147) (-842)))) (-3908 (($ (-1 (-121) (-147) (-147)) $) NIL (|has| $ (-6 -4520))) (($ $) NIL (-12 (|has| $ (-6 -4520)) (|has| (-147) (-842))))) (-3644 (($ (-1 (-121) (-147) (-147)) $) NIL) (($ $) NIL (|has| (-147) (-842)))) (-2510 (((-121) $ (-763)) NIL)) (-2436 (((-147) $ (-568) (-147)) 45 (|has| $ (-6 -4520))) (((-147) $ (-1210 (-568)) (-147)) NIL (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4519)))) (-2671 (($) NIL T CONST)) (-1869 (($ $ (-147)) 63) (($ $ (-142)) 64)) (-1578 (($ $) NIL (|has| $ (-6 -4520)))) (-3943 (($ $) NIL)) (-1386 (($ $ (-1210 (-568)) $) 44)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-147) (-1090))))) (-4328 (($ (-147) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-147) (-1090)))) (($ (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4519)))) (-3092 (((-147) (-1 (-147) (-147) (-147)) $ (-147) (-147)) NIL (-12 (|has| $ (-6 -4519)) (|has| (-147) (-1090)))) (((-147) (-1 (-147) (-147) (-147)) $ (-147)) NIL (|has| $ (-6 -4519))) (((-147) (-1 (-147) (-147) (-147)) $) NIL (|has| $ (-6 -4519)))) (-3989 (((-147) $ (-568) (-147)) NIL (|has| $ (-6 -4520)))) (-2602 (((-147) $ (-568)) NIL)) (-3766 (((-121) $ $) 70)) (-2764 (((-568) (-1 (-121) (-147)) $) NIL) (((-568) (-147) $) NIL (|has| (-147) (-1090))) (((-568) (-147) $ (-568)) 48 (|has| (-147) (-1090))) (((-568) $ $ (-568)) 47) (((-568) (-142) $ (-568)) 50)) (-4360 (((-634 (-147)) $) NIL (|has| $ (-6 -4519)))) (-1849 (($ (-763) (-147)) 9)) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) 28 (|has| (-568) (-842)))) (-2521 (($ $ $) NIL (|has| (-147) (-842)))) (-1347 (($ (-1 (-121) (-147) (-147)) $ $) NIL) (($ $ $) NIL (|has| (-147) (-842)))) (-1979 (((-634 (-147)) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) (-147) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-147) (-1090))))) (-2223 (((-568) $) 42 (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (|has| (-147) (-842)))) (-4062 (((-121) $ $ (-147)) 71)) (-2661 (((-763) $ $ (-147)) 69)) (-3674 (($ (-1 (-147) (-147)) $) 33 (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-147) (-147)) $) NIL) (($ (-1 (-147) (-147) (-147)) $ $) NIL)) (-2496 (($ $) 37)) (-2003 (($ $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-3382 (($ $ (-147)) 61) (($ $ (-142)) 62)) (-4487 (((-1143) $) 38 (|has| (-147) (-1090)))) (-4122 (($ (-147) $ (-568)) NIL) (($ $ $ (-568)) 23)) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4022 (((-568) $) 68) (((-1108) $) NIL (|has| (-147) (-1090)))) (-3876 (((-147) $) NIL (|has| (-568) (-842)))) (-3775 (((-3 (-147) "failed") (-1 (-121) (-147)) $) NIL)) (-3724 (($ $ (-147)) NIL (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-147)))) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-288 (-147))) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-147) (-147)) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-634 (-147)) (-634 (-147))) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) (-147) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-147) (-1090))))) (-2041 (((-634 (-147)) $) NIL)) (-3084 (((-121) $) 12)) (-3248 (($) 10)) (-2779 (((-147) $ (-568) (-147)) NIL) (((-147) $ (-568)) 52) (($ $ (-1210 (-568))) 21) (($ $ $) NIL)) (-2826 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-4168 (((-763) (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4519))) (((-763) (-147) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-147) (-1090))))) (-2256 (($ $ $ (-568)) 65 (|has| $ (-6 -4520)))) (-3863 (($ $) 17)) (-4278 (((-541) $) NIL (|has| (-147) (-609 (-541))))) (-4287 (($ (-634 (-147))) NIL)) (-2768 (($ $ (-147)) NIL) (($ (-147) $) NIL) (($ $ $) 16) (($ (-634 $)) 66)) (-2745 (($ (-147)) NIL) (((-850) $) 27 (|has| (-147) (-1090)))) (-1319 (((-121) (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4519)))) (-1751 (((-121) $ $) NIL (|has| (-147) (-842)))) (-1738 (((-121) $ $) NIL (|has| (-147) (-842)))) (-1717 (((-121) $ $) 14 (|has| (-147) (-1090)))) (-1745 (((-121) $ $) NIL (|has| (-147) (-842)))) (-1732 (((-121) $ $) 15 (|has| (-147) (-842)))) (-1697 (((-763) $) 13 (|has| $ (-6 -4519))))) 
-(((-591 |#1|) (-13 (-1129) (-10 -8 (-15 -4022 ((-568) $)))) (-568)) (T -591)) 
-((-4022 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-591 *3)) (-14 *3 *2)))) 
-(-13 (-1129) (-10 -8 (-15 -4022 ((-568) $)))) 
-((-2627 (((-2 (|:| |num| |#4|) (|:| |den| (-568))) |#4| |#2|) 23) (((-2 (|:| |num| |#4|) (|:| |den| (-568))) |#4| |#2| (-1084 |#4|)) 32))) 
-(((-592 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2627 ((-2 (|:| |num| |#4|) (|:| |den| (-568))) |#4| |#2| (-1084 |#4|))) (-15 -2627 ((-2 (|:| |num| |#4|) (|:| |den| (-568))) |#4| |#2|))) (-788) (-842) (-558) (-950 |#3| |#1| |#2|)) (T -592)) 
-((-2627 (*1 *2 *3 *4) (-12 (-4 *5 (-788)) (-4 *4 (-842)) (-4 *6 (-558)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| (-568)))) (-5 *1 (-592 *5 *4 *6 *3)) (-4 *3 (-950 *6 *5 *4)))) (-2627 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-1084 *3)) (-4 *3 (-950 *7 *6 *4)) (-4 *6 (-788)) (-4 *4 (-842)) (-4 *7 (-558)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| (-568)))) (-5 *1 (-592 *6 *4 *7 *3))))) 
-(-10 -7 (-15 -2627 ((-2 (|:| |num| |#4|) (|:| |den| (-568))) |#4| |#2| (-1084 |#4|))) (-15 -2627 ((-2 (|:| |num| |#4|) (|:| |den| (-568))) |#4| |#2|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 63)) (-2055 (((-634 (-1075)) $) NIL)) (-1305 (((-1161) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-2617 (($ $ (-568)) 54) (($ $ (-568) (-568)) 55)) (-2583 (((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) 60)) (-3414 (($ $) 99)) (-3134 (((-3 $ "failed") $ $) NIL)) (-3529 (((-850) (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) (-1026 (-835 (-568))) (-1161) |#1| (-409 (-568))) 214)) (-3728 (($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) 34)) (-2671 (($) NIL T CONST)) (-2114 (($ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3992 (((-121) $) NIL)) (-4477 (((-568) $) 58) (((-568) $ (-568)) 59)) (-2735 (((-121) $) NIL)) (-3536 (($ $ (-917)) 76)) (-1716 (($ (-1 |#1| (-568)) $) 73)) (-3921 (((-121) $) 25)) (-2047 (($ |#1| (-568)) 22) (($ $ (-1075) (-568)) NIL) (($ $ (-634 (-1075)) (-634 (-568))) NIL)) (-2795 (($ (-1 |#1| |#1|) $) 67)) (-2866 (($ (-1026 (-835 (-568))) (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) 11)) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-4487 (((-1143) $) NIL)) (-3837 (($ $) 111 (|has| |#1| (-43 (-409 (-568)))))) (-3696 (((-3 $ "failed") $ $ (-121)) 98)) (-2483 (($ $ $) 107)) (-4022 (((-1108) $) NIL)) (-1898 (((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) 13)) (-3689 (((-1026 (-835 (-568))) $) 12)) (-1807 (($ $ (-568)) 45)) (-2595 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-1339 (((-1141 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-568)))))) (-2779 ((|#1| $ (-568)) 57) (($ $ $) NIL (|has| (-568) (-1102)))) (-4189 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $) 70 (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (-3206 (((-568) $) NIL)) (-1811 (($ $) 46)) (-2745 (((-850) $) NIL) (($ (-568)) 28) (($ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $) NIL (|has| |#1| (-558))) (($ |#1|) 27 (|has| |#1| (-172)))) (-2604 ((|#1| $ (-568)) 56)) (-4371 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-4078 (((-763)) 37)) (-1374 ((|#1| $) NIL)) (-1951 (($ $) 179 (|has| |#1| (-43 (-409 (-568)))))) (-4187 (($ $) 155 (|has| |#1| (-43 (-409 (-568)))))) (-3464 (($ $) 176 (|has| |#1| (-43 (-409 (-568)))))) (-1893 (($ $) 152 (|has| |#1| (-43 (-409 (-568)))))) (-3353 (($ $) 181 (|has| |#1| (-43 (-409 (-568)))))) (-2029 (($ $) 158 (|has| |#1| (-43 (-409 (-568)))))) (-3077 (($ $ (-409 (-568))) 145 (|has| |#1| (-43 (-409 (-568)))))) (-4240 (($ $ |#1|) 120 (|has| |#1| (-43 (-409 (-568)))))) (-1391 (($ $) 149 (|has| |#1| (-43 (-409 (-568)))))) (-1284 (($ $) 147 (|has| |#1| (-43 (-409 (-568)))))) (-3468 (($ $) 182 (|has| |#1| (-43 (-409 (-568)))))) (-3852 (($ $) 159 (|has| |#1| (-43 (-409 (-568)))))) (-2485 (($ $) 180 (|has| |#1| (-43 (-409 (-568)))))) (-2322 (($ $) 157 (|has| |#1| (-43 (-409 (-568)))))) (-1625 (($ $) 177 (|has| |#1| (-43 (-409 (-568)))))) (-4490 (($ $) 153 (|has| |#1| (-43 (-409 (-568)))))) (-2410 (($ $) 187 (|has| |#1| (-43 (-409 (-568)))))) (-2188 (($ $) 167 (|has| |#1| (-43 (-409 (-568)))))) (-4463 (($ $) 184 (|has| |#1| (-43 (-409 (-568)))))) (-3100 (($ $) 162 (|has| |#1| (-43 (-409 (-568)))))) (-2268 (($ $) 191 (|has| |#1| (-43 (-409 (-568)))))) (-3124 (($ $) 171 (|has| |#1| (-43 (-409 (-568)))))) (-2083 (($ $) 193 (|has| |#1| (-43 (-409 (-568)))))) (-3235 (($ $) 173 (|has| |#1| (-43 (-409 (-568)))))) (-2957 (($ $) 189 (|has| |#1| (-43 (-409 (-568)))))) (-3654 (($ $) 169 (|has| |#1| (-43 (-409 (-568)))))) (-2524 (($ $) 186 (|has| |#1| (-43 (-409 (-568)))))) (-3810 (($ $) 165 (|has| |#1| (-43 (-409 (-568)))))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-3996 ((|#1| $ (-568)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-568)))) (|has| |#1| (-15 -2745 (|#1| (-1161))))))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 29 T CONST)) (-1556 (($) 38 T CONST)) (-3190 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (-1717 (((-121) $ $) 65)) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1773 (($ $) 84) (($ $ $) 64)) (-1767 (($ $ $) 81)) (** (($ $ (-917)) NIL) (($ $ (-763)) 102)) (* (($ (-917) $) 89) (($ (-763) $) 87) (($ (-568) $) 85) (($ $ $) 95) (($ $ |#1|) NIL) (($ |#1| $) 114) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
-(((-593 |#1|) (-13 (-1221 |#1| (-568)) (-10 -8 (-15 -2866 ($ (-1026 (-835 (-568))) (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))))) (-15 -3689 ((-1026 (-835 (-568))) $)) (-15 -1898 ((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $)) (-15 -3728 ($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))))) (-15 -3921 ((-121) $)) (-15 -1716 ($ (-1 |#1| (-568)) $)) (-15 -3696 ((-3 $ "failed") $ $ (-121))) (-15 -3414 ($ $)) (-15 -2483 ($ $ $)) (-15 -3529 ((-850) (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) (-1026 (-835 (-568))) (-1161) |#1| (-409 (-568)))) (IF (|has| |#1| (-43 (-409 (-568)))) (PROGN (-15 -3837 ($ $)) (-15 -4240 ($ $ |#1|)) (-15 -3077 ($ $ (-409 (-568)))) (-15 -1284 ($ $)) (-15 -1391 ($ $)) (-15 -1893 ($ $)) (-15 -4490 ($ $)) (-15 -4187 ($ $)) (-15 -2322 ($ $)) (-15 -2029 ($ $)) (-15 -3852 ($ $)) (-15 -3100 ($ $)) (-15 -3810 ($ $)) (-15 -2188 ($ $)) (-15 -3654 ($ $)) (-15 -3124 ($ $)) (-15 -3235 ($ $)) (-15 -3464 ($ $)) (-15 -1625 ($ $)) (-15 -1951 ($ $)) (-15 -2485 ($ $)) (-15 -3353 ($ $)) (-15 -3468 ($ $)) (-15 -4463 ($ $)) (-15 -2524 ($ $)) (-15 -2410 ($ $)) (-15 -2957 ($ $)) (-15 -2268 ($ $)) (-15 -2083 ($ $))) |noBranch|))) (-1047)) (T -593)) 
-((-3921 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-593 *3)) (-4 *3 (-1047)))) (-2866 (*1 *1 *2 *3) (-12 (-5 *2 (-1026 (-835 (-568)))) (-5 *3 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *4)))) (-4 *4 (-1047)) (-5 *1 (-593 *4)))) (-3689 (*1 *2 *1) (-12 (-5 *2 (-1026 (-835 (-568)))) (-5 *1 (-593 *3)) (-4 *3 (-1047)))) (-1898 (*1 *2 *1) (-12 (-5 *2 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *3)))) (-5 *1 (-593 *3)) (-4 *3 (-1047)))) (-3728 (*1 *1 *2) (-12 (-5 *2 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *3)))) (-4 *3 (-1047)) (-5 *1 (-593 *3)))) (-1716 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-568))) (-4 *3 (-1047)) (-5 *1 (-593 *3)))) (-3696 (*1 *1 *1 *1 *2) (|partial| -12 (-5 *2 (-121)) (-5 *1 (-593 *3)) (-4 *3 (-1047)))) (-3414 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-1047)))) (-2483 (*1 *1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-1047)))) (-3529 (*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *3 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *6)))) (-5 *4 (-1026 (-835 (-568)))) (-5 *5 (-1161)) (-5 *7 (-409 (-568))) (-4 *6 (-1047)) (-5 *2 (-850)) (-5 *1 (-593 *6)))) (-3837 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-4240 (*1 *1 *1 *2) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-3077 (*1 *1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-593 *3)) (-4 *3 (-43 *2)) (-4 *3 (-1047)))) (-1284 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-1391 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-1893 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-4490 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-4187 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-2322 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-2029 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-3852 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-3100 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-3810 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-2188 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-3654 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-3124 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-3235 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-3464 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-1625 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-1951 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-2485 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-3353 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-3468 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-4463 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-2524 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-2410 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-2957 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-2268 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-2083 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(-13 (-1221 |#1| (-568)) (-10 -8 (-15 -2866 ($ (-1026 (-835 (-568))) (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))))) (-15 -3689 ((-1026 (-835 (-568))) $)) (-15 -1898 ((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $)) (-15 -3728 ($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))))) (-15 -3921 ((-121) $)) (-15 -1716 ($ (-1 |#1| (-568)) $)) (-15 -3696 ((-3 $ "failed") $ $ (-121))) (-15 -3414 ($ $)) (-15 -2483 ($ $ $)) (-15 -3529 ((-850) (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) (-1026 (-835 (-568))) (-1161) |#1| (-409 (-568)))) (IF (|has| |#1| (-43 (-409 (-568)))) (PROGN (-15 -3837 ($ $)) (-15 -4240 ($ $ |#1|)) (-15 -3077 ($ $ (-409 (-568)))) (-15 -1284 ($ $)) (-15 -1391 ($ $)) (-15 -1893 ($ $)) (-15 -4490 ($ $)) (-15 -4187 ($ $)) (-15 -2322 ($ $)) (-15 -2029 ($ $)) (-15 -3852 ($ $)) (-15 -3100 ($ $)) (-15 -3810 ($ $)) (-15 -2188 ($ $)) (-15 -3654 ($ $)) (-15 -3124 ($ $)) (-15 -3235 ($ $)) (-15 -3464 ($ $)) (-15 -1625 ($ $)) (-15 -1951 ($ $)) (-15 -2485 ($ $)) (-15 -3353 ($ $)) (-15 -3468 ($ $)) (-15 -4463 ($ $)) (-15 -2524 ($ $)) (-15 -2410 ($ $)) (-15 -2957 ($ $)) (-15 -2268 ($ $)) (-15 -2083 ($ $))) |noBranch|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-3728 (($ (-1141 |#1|)) 9)) (-2671 (($) NIL T CONST)) (-2925 (((-3 $ "failed") $) 42)) (-3992 (((-121) $) 52)) (-4477 (((-763) $) 55) (((-763) $ (-763)) 54)) (-2735 (((-121) $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2595 (((-3 $ "failed") $ $) 44 (|has| |#1| (-558)))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL (|has| |#1| (-558)))) (-1302 (((-1141 |#1|) $) 23)) (-4078 (((-763)) 51)) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 10 T CONST)) (-1556 (($) 14 T CONST)) (-1717 (((-121) $ $) 22)) (-1773 (($ $) 30) (($ $ $) 16)) (-1767 (($ $ $) 25)) (** (($ $ (-917)) NIL) (($ $ (-763)) 49)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 34) (($ $ $) 28) (($ |#1| $) 37) (($ $ |#1|) 38) (($ $ (-568)) 36))) 
-(((-594 |#1|) (-13 (-1047) (-10 -8 (-15 -1302 ((-1141 |#1|) $)) (-15 -3728 ($ (-1141 |#1|))) (-15 -3992 ((-121) $)) (-15 -4477 ((-763) $)) (-15 -4477 ((-763) $ (-763))) (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 * ($ $ (-568))) (IF (|has| |#1| (-558)) (-6 (-558)) |noBranch|))) (-1047)) (T -594)) 
-((-1302 (*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-594 *3)) (-4 *3 (-1047)))) (-3728 (*1 *1 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-594 *3)))) (-3992 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-594 *3)) (-4 *3 (-1047)))) (-4477 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-594 *3)) (-4 *3 (-1047)))) (-4477 (*1 *2 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-594 *3)) (-4 *3 (-1047)))) (* (*1 *1 *2 *1) (-12 (-5 *1 (-594 *2)) (-4 *2 (-1047)))) (* (*1 *1 *1 *2) (-12 (-5 *1 (-594 *2)) (-4 *2 (-1047)))) (* (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-594 *3)) (-4 *3 (-1047))))) 
-(-13 (-1047) (-10 -8 (-15 -1302 ((-1141 |#1|) $)) (-15 -3728 ($ (-1141 |#1|))) (-15 -3992 ((-121) $)) (-15 -4477 ((-763) $)) (-15 -4477 ((-763) $ (-763))) (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 * ($ $ (-568))) (IF (|has| |#1| (-558)) (-6 (-558)) |noBranch|))) 
-((-2795 (((-598 |#2|) (-1 |#2| |#1|) (-598 |#1|)) 15))) 
-(((-595 |#1| |#2|) (-10 -7 (-15 -2795 ((-598 |#2|) (-1 |#2| |#1|) (-598 |#1|)))) (-1195) (-1195)) (T -595)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-598 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-598 *6)) (-5 *1 (-595 *5 *6))))) 
-(-10 -7 (-15 -2795 ((-598 |#2|) (-1 |#2| |#1|) (-598 |#1|)))) 
-((-2795 (((-1141 |#3|) (-1 |#3| |#1| |#2|) (-598 |#1|) (-1141 |#2|)) 20) (((-1141 |#3|) (-1 |#3| |#1| |#2|) (-1141 |#1|) (-598 |#2|)) 19) (((-598 |#3|) (-1 |#3| |#1| |#2|) (-598 |#1|) (-598 |#2|)) 18))) 
-(((-596 |#1| |#2| |#3|) (-10 -7 (-15 -2795 ((-598 |#3|) (-1 |#3| |#1| |#2|) (-598 |#1|) (-598 |#2|))) (-15 -2795 ((-1141 |#3|) (-1 |#3| |#1| |#2|) (-1141 |#1|) (-598 |#2|))) (-15 -2795 ((-1141 |#3|) (-1 |#3| |#1| |#2|) (-598 |#1|) (-1141 |#2|)))) (-1195) (-1195) (-1195)) (T -596)) 
-((-2795 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-598 *6)) (-5 *5 (-1141 *7)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-4 *8 (-1195)) (-5 *2 (-1141 *8)) (-5 *1 (-596 *6 *7 *8)))) (-2795 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-1141 *6)) (-5 *5 (-598 *7)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-4 *8 (-1195)) (-5 *2 (-1141 *8)) (-5 *1 (-596 *6 *7 *8)))) (-2795 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-598 *6)) (-5 *5 (-598 *7)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-4 *8 (-1195)) (-5 *2 (-598 *8)) (-5 *1 (-596 *6 *7 *8))))) 
-(-10 -7 (-15 -2795 ((-598 |#3|) (-1 |#3| |#1| |#2|) (-598 |#1|) (-598 |#2|))) (-15 -2795 ((-1141 |#3|) (-1 |#3| |#1| |#2|) (-1141 |#1|) (-598 |#2|))) (-15 -2795 ((-1141 |#3|) (-1 |#3| |#1| |#2|) (-598 |#1|) (-1141 |#2|)))) 
-((-3201 ((|#3| |#3| (-634 (-607 |#3|)) (-634 (-1161))) 55)) (-4173 (((-169 |#2|) |#3|) 116)) (-1683 ((|#3| (-169 |#2|)) 43)) (-2980 ((|#2| |#3|) 19)) (-4217 ((|#3| |#2|) 32))) 
-(((-597 |#1| |#2| |#3|) (-10 -7 (-15 -1683 (|#3| (-169 |#2|))) (-15 -2980 (|#2| |#3|)) (-15 -4217 (|#3| |#2|)) (-15 -4173 ((-169 |#2|) |#3|)) (-15 -3201 (|#3| |#3| (-634 (-607 |#3|)) (-634 (-1161))))) (-13 (-558) (-842)) (-13 (-432 |#1|) (-1002) (-1181)) (-13 (-432 (-169 |#1|)) (-1002) (-1181))) (T -597)) 
-((-3201 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-634 (-607 *2))) (-5 *4 (-634 (-1161))) (-4 *2 (-13 (-432 (-169 *5)) (-1002) (-1181))) (-4 *5 (-13 (-558) (-842))) (-5 *1 (-597 *5 *6 *2)) (-4 *6 (-13 (-432 *5) (-1002) (-1181))))) (-4173 (*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842))) (-5 *2 (-169 *5)) (-5 *1 (-597 *4 *5 *3)) (-4 *5 (-13 (-432 *4) (-1002) (-1181))) (-4 *3 (-13 (-432 (-169 *4)) (-1002) (-1181))))) (-4217 (*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842))) (-4 *2 (-13 (-432 (-169 *4)) (-1002) (-1181))) (-5 *1 (-597 *4 *3 *2)) (-4 *3 (-13 (-432 *4) (-1002) (-1181))))) (-2980 (*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842))) (-4 *2 (-13 (-432 *4) (-1002) (-1181))) (-5 *1 (-597 *4 *2 *3)) (-4 *3 (-13 (-432 (-169 *4)) (-1002) (-1181))))) (-1683 (*1 *2 *3) (-12 (-5 *3 (-169 *5)) (-4 *5 (-13 (-432 *4) (-1002) (-1181))) (-4 *4 (-13 (-558) (-842))) (-4 *2 (-13 (-432 (-169 *4)) (-1002) (-1181))) (-5 *1 (-597 *4 *5 *2))))) 
-(-10 -7 (-15 -1683 (|#3| (-169 |#2|))) (-15 -2980 (|#2| |#3|)) (-15 -4217 (|#3| |#2|)) (-15 -4173 ((-169 |#2|) |#3|)) (-15 -3201 (|#3| |#3| (-634 (-607 |#3|)) (-634 (-1161))))) 
-((-2801 (($ (-1 (-121) |#1|) $) 16)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-2781 (($ (-1 |#1| |#1|) |#1|) 9)) (-2794 (($ (-1 (-121) |#1|) $) 12)) (-2798 (($ (-1 (-121) |#1|) $) 14)) (-4287 (((-1141 |#1|) $) 17)) (-2745 (((-850) $) NIL))) 
-(((-598 |#1|) (-13 (-608 (-850)) (-10 -8 (-15 -2795 ($ (-1 |#1| |#1|) $)) (-15 -2794 ($ (-1 (-121) |#1|) $)) (-15 -2798 ($ (-1 (-121) |#1|) $)) (-15 -2801 ($ (-1 (-121) |#1|) $)) (-15 -2781 ($ (-1 |#1| |#1|) |#1|)) (-15 -4287 ((-1141 |#1|) $)))) (-1195)) (T -598)) 
-((-2795 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1195)) (-5 *1 (-598 *3)))) (-2794 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1195)) (-5 *1 (-598 *3)))) (-2798 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1195)) (-5 *1 (-598 *3)))) (-2801 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1195)) (-5 *1 (-598 *3)))) (-2781 (*1 *1 *2 *3) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1195)) (-5 *1 (-598 *3)))) (-4287 (*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-598 *3)) (-4 *3 (-1195))))) 
-(-13 (-608 (-850)) (-10 -8 (-15 -2795 ($ (-1 |#1| |#1|) $)) (-15 -2794 ($ (-1 (-121) |#1|) $)) (-15 -2798 ($ (-1 (-121) |#1|) $)) (-15 -2801 ($ (-1 (-121) |#1|) $)) (-15 -2781 ($ (-1 |#1| |#1|) |#1|)) (-15 -4287 ((-1141 |#1|) $)))) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3205 (($ (-763)) NIL (|has| |#1| (-23)))) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-2016 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-842)))) (-3908 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4520))) (($ $) NIL (-12 (|has| $ (-6 -4520)) (|has| |#1| (-842))))) (-3644 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-842)))) (-2510 (((-121) $ (-763)) NIL)) (-2436 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4520))) ((|#1| $ (-1210 (-568)) |#1|) NIL (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-2671 (($) NIL T CONST)) (-1578 (($ $) NIL (|has| $ (-6 -4520)))) (-3943 (($ $) NIL)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-4328 (($ |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4519)))) (-3989 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-568)) NIL)) (-2764 (((-568) (-1 (-121) |#1|) $) NIL) (((-568) |#1| $) NIL (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) NIL (|has| |#1| (-1090)))) (-4360 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-1802 (((-679 |#1|) $ $) NIL (|has| |#1| (-1047)))) (-1849 (($ (-763) |#1|) NIL)) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) NIL (|has| (-568) (-842)))) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-1347 (($ (-1 (-121) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-842)))) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2223 (((-568) $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-3674 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-1550 ((|#1| $) NIL (-12 (|has| |#1| (-1002)) (|has| |#1| (-1047))))) (-2166 (((-121) $ (-763)) NIL)) (-3678 ((|#1| $) NIL (-12 (|has| |#1| (-1002)) (|has| |#1| (-1047))))) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4122 (($ |#1| $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3876 ((|#1| $) NIL (|has| (-568) (-842)))) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3724 (($ $ |#1|) NIL (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#1| $ (-568) |#1|) NIL) ((|#1| $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-3682 ((|#1| $ $) NIL (|has| |#1| (-1047)))) (-2826 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-2748 (($ $ $) NIL (|has| |#1| (-1047)))) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2256 (($ $ $ (-568)) NIL (|has| $ (-6 -4520)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) NIL)) (-2768 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-634 $)) NIL)) (-2745 (((-850) $) NIL (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1773 (($ $) NIL (|has| |#1| (-21))) (($ $ $) NIL (|has| |#1| (-21)))) (-1767 (($ $ $) NIL (|has| |#1| (-25)))) (* (($ (-568) $) NIL (|has| |#1| (-21))) (($ |#1| $) NIL (|has| |#1| (-716))) (($ $ |#1|) NIL (|has| |#1| (-716)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
+((-1288 (((-1249) (-1143)) 10))) 
+(((-582) (-10 -7 (-15 -1288 ((-1249) (-1143))))) (T -582)) 
+((-1288 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-582))))) 
+(-10 -7 (-15 -1288 ((-1249) (-1143)))) 
+((-4446 (((-585 |#2|) (-585 |#2|)) 37)) (-2791 (((-634 |#2|) (-585 |#2|)) 39)) (-4443 ((|#2| (-585 |#2|)) 46))) 
+(((-583 |#1| |#2|) (-10 -7 (-15 -4446 ((-585 |#2|) (-585 |#2|))) (-15 -2791 ((-634 |#2|) (-585 |#2|))) (-15 -4443 (|#2| (-585 |#2|)))) (-13 (-453) (-1037 (-568)) (-842) (-630 (-568))) (-13 (-29 |#1|) (-1181))) (T -583)) 
+((-4443 (*1 *2 *3) (-12 (-5 *3 (-585 *2)) (-4 *2 (-13 (-29 *4) (-1181))) (-5 *1 (-583 *4 *2)) (-4 *4 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))))) (-2791 (*1 *2 *3) (-12 (-5 *3 (-585 *5)) (-4 *5 (-13 (-29 *4) (-1181))) (-4 *4 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *2 (-634 *5)) (-5 *1 (-583 *4 *5)))) (-4446 (*1 *2 *2) (-12 (-5 *2 (-585 *4)) (-4 *4 (-13 (-29 *3) (-1181))) (-4 *3 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *1 (-583 *3 *4))))) 
+(-10 -7 (-15 -4446 ((-585 |#2|) (-585 |#2|))) (-15 -2791 ((-634 |#2|) (-585 |#2|))) (-15 -4443 (|#2| (-585 |#2|)))) 
+((-2797 (((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| |mainpart| |#1|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#1|) (|:| |logand| |#1|))))) "failed")) 38) (((-3 |#2| "failed") (-1 |#2| |#1|) (-3 |#1| "failed")) 11) (((-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| -4151 |#1|) (|:| |coeff| |#1|)) "failed")) 31) (((-585 |#2|) (-1 |#2| |#1|) (-585 |#1|)) 26))) 
+(((-584 |#1| |#2|) (-10 -7 (-15 -2797 ((-585 |#2|) (-1 |#2| |#1|) (-585 |#1|))) (-15 -2797 ((-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| -4151 |#1|) (|:| |coeff| |#1|)) "failed"))) (-15 -2797 ((-3 |#2| "failed") (-1 |#2| |#1|) (-3 |#1| "failed"))) (-15 -2797 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| |mainpart| |#1|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#1|) (|:| |logand| |#1|))))) "failed")))) (-365) (-365)) (T -584)) 
+((-2797 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *6 *5)) (-5 *4 (-3 (-2 (|:| |mainpart| *5) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *5) (|:| |logand| *5))))) "failed")) (-4 *5 (-365)) (-4 *6 (-365)) (-5 *2 (-2 (|:| |mainpart| *6) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *6) (|:| |logand| *6)))))) (-5 *1 (-584 *5 *6)))) (-2797 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *2 *5)) (-5 *4 (-3 *5 "failed")) (-4 *5 (-365)) (-4 *2 (-365)) (-5 *1 (-584 *5 *2)))) (-2797 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *6 *5)) (-5 *4 (-3 (-2 (|:| -4151 *5) (|:| |coeff| *5)) "failed")) (-4 *5 (-365)) (-4 *6 (-365)) (-5 *2 (-2 (|:| -4151 *6) (|:| |coeff| *6))) (-5 *1 (-584 *5 *6)))) (-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-585 *5)) (-4 *5 (-365)) (-4 *6 (-365)) (-5 *2 (-585 *6)) (-5 *1 (-584 *5 *6))))) 
+(-10 -7 (-15 -2797 ((-585 |#2|) (-1 |#2| |#1|) (-585 |#1|))) (-15 -2797 ((-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| -4151 |#1|) (|:| |coeff| |#1|)) "failed"))) (-15 -2797 ((-3 |#2| "failed") (-1 |#2| |#1|) (-3 |#1| "failed"))) (-15 -2797 ((-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") (-1 |#2| |#1|) (-3 (-2 (|:| |mainpart| |#1|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#1|) (|:| |logand| |#1|))))) "failed")))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) 68)) (-2857 ((|#1| $) NIL)) (-4151 ((|#1| $) 24)) (-3576 (((-634 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|))) $) 26)) (-2044 (($ |#1| (-634 (-2 (|:| |scalar| (-409 (-568))) (|:| |coeff| (-1157 |#1|)) (|:| |logand| (-1157 |#1|)))) (-634 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|)))) 22)) (-1989 (((-634 (-2 (|:| |scalar| (-409 (-568))) (|:| |coeff| (-1157 |#1|)) (|:| |logand| (-1157 |#1|)))) $) 25)) (-1893 (((-1143) $) NIL)) (-2317 (($ |#1| |#1|) 32) (($ |#1| (-1161)) 43 (|has| |#1| (-1037 (-1161))))) (-4025 (((-1108) $) NIL)) (-3536 (((-121) $) 28)) (-4191 ((|#1| $ (-1 |#1| |#1|)) 80) ((|#1| $ (-1161)) 81 (|has| |#1| (-895 (-1161))))) (-2747 (((-850) $) 95) (($ |#1|) 23)) (-3058 (($) 16 T CONST)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) 15) (($ $ $) NIL)) (-1769 (($ $ $) 77)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 14) (($ (-409 (-568)) $) 35) (($ $ (-409 (-568))) NIL))) 
+(((-585 |#1|) (-13 (-707 (-409 (-568))) (-1037 |#1|) (-10 -8 (-15 -2044 ($ |#1| (-634 (-2 (|:| |scalar| (-409 (-568))) (|:| |coeff| (-1157 |#1|)) (|:| |logand| (-1157 |#1|)))) (-634 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|))))) (-15 -4151 (|#1| $)) (-15 -1989 ((-634 (-2 (|:| |scalar| (-409 (-568))) (|:| |coeff| (-1157 |#1|)) (|:| |logand| (-1157 |#1|)))) $)) (-15 -3576 ((-634 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|))) $)) (-15 -3536 ((-121) $)) (-15 -2317 ($ |#1| |#1|)) (-15 -4191 (|#1| $ (-1 |#1| |#1|))) (IF (|has| |#1| (-895 (-1161))) (-15 -4191 (|#1| $ (-1161))) |noBranch|) (IF (|has| |#1| (-1037 (-1161))) (-15 -2317 ($ |#1| (-1161))) |noBranch|))) (-365)) (T -585)) 
+((-2044 (*1 *1 *2 *3 *4) (-12 (-5 *3 (-634 (-2 (|:| |scalar| (-409 (-568))) (|:| |coeff| (-1157 *2)) (|:| |logand| (-1157 *2))))) (-5 *4 (-634 (-2 (|:| |integrand| *2) (|:| |intvar| *2)))) (-4 *2 (-365)) (-5 *1 (-585 *2)))) (-4151 (*1 *2 *1) (-12 (-5 *1 (-585 *2)) (-4 *2 (-365)))) (-1989 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |scalar| (-409 (-568))) (|:| |coeff| (-1157 *3)) (|:| |logand| (-1157 *3))))) (-5 *1 (-585 *3)) (-4 *3 (-365)))) (-3576 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |integrand| *3) (|:| |intvar| *3)))) (-5 *1 (-585 *3)) (-4 *3 (-365)))) (-3536 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-585 *3)) (-4 *3 (-365)))) (-2317 (*1 *1 *2 *2) (-12 (-5 *1 (-585 *2)) (-4 *2 (-365)))) (-4191 (*1 *2 *1 *3) (-12 (-5 *3 (-1 *2 *2)) (-5 *1 (-585 *2)) (-4 *2 (-365)))) (-4191 (*1 *2 *1 *3) (-12 (-4 *2 (-365)) (-4 *2 (-895 *3)) (-5 *1 (-585 *2)) (-5 *3 (-1161)))) (-2317 (*1 *1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *1 (-585 *2)) (-4 *2 (-1037 *3)) (-4 *2 (-365))))) 
+(-13 (-707 (-409 (-568))) (-1037 |#1|) (-10 -8 (-15 -2044 ($ |#1| (-634 (-2 (|:| |scalar| (-409 (-568))) (|:| |coeff| (-1157 |#1|)) (|:| |logand| (-1157 |#1|)))) (-634 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|))))) (-15 -4151 (|#1| $)) (-15 -1989 ((-634 (-2 (|:| |scalar| (-409 (-568))) (|:| |coeff| (-1157 |#1|)) (|:| |logand| (-1157 |#1|)))) $)) (-15 -3576 ((-634 (-2 (|:| |integrand| |#1|) (|:| |intvar| |#1|))) $)) (-15 -3536 ((-121) $)) (-15 -2317 ($ |#1| |#1|)) (-15 -4191 (|#1| $ (-1 |#1| |#1|))) (IF (|has| |#1| (-895 (-1161))) (-15 -4191 (|#1| $ (-1161))) |noBranch|) (IF (|has| |#1| (-1037 (-1161))) (-15 -2317 ($ |#1| (-1161))) |noBranch|))) 
+((-1669 (((-121) |#1|) 16)) (-3342 (((-3 |#1| "failed") |#1|) 14)) (-4062 (((-2 (|:| -2404 |#1|) (|:| -3483 (-763))) |#1|) 30) (((-3 |#1| "failed") |#1| (-763)) 18)) (-1578 (((-121) |#1| (-763)) 19)) (-1915 ((|#1| |#1|) 31)) (-3042 ((|#1| |#1| (-763)) 33))) 
+(((-586 |#1|) (-10 -7 (-15 -1578 ((-121) |#1| (-763))) (-15 -4062 ((-3 |#1| "failed") |#1| (-763))) (-15 -4062 ((-2 (|:| -2404 |#1|) (|:| -3483 (-763))) |#1|)) (-15 -3042 (|#1| |#1| (-763))) (-15 -1669 ((-121) |#1|)) (-15 -3342 ((-3 |#1| "failed") |#1|)) (-15 -1915 (|#1| |#1|))) (-550)) (T -586)) 
+((-1915 (*1 *2 *2) (-12 (-5 *1 (-586 *2)) (-4 *2 (-550)))) (-3342 (*1 *2 *2) (|partial| -12 (-5 *1 (-586 *2)) (-4 *2 (-550)))) (-1669 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-586 *3)) (-4 *3 (-550)))) (-3042 (*1 *2 *2 *3) (-12 (-5 *3 (-763)) (-5 *1 (-586 *2)) (-4 *2 (-550)))) (-4062 (*1 *2 *3) (-12 (-5 *2 (-2 (|:| -2404 *3) (|:| -3483 (-763)))) (-5 *1 (-586 *3)) (-4 *3 (-550)))) (-4062 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-763)) (-5 *1 (-586 *2)) (-4 *2 (-550)))) (-1578 (*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-5 *2 (-121)) (-5 *1 (-586 *3)) (-4 *3 (-550))))) 
+(-10 -7 (-15 -1578 ((-121) |#1| (-763))) (-15 -4062 ((-3 |#1| "failed") |#1| (-763))) (-15 -4062 ((-2 (|:| -2404 |#1|) (|:| -3483 (-763))) |#1|)) (-15 -3042 (|#1| |#1| (-763))) (-15 -1669 ((-121) |#1|)) (-15 -3342 ((-3 |#1| "failed") |#1|)) (-15 -1915 (|#1| |#1|))) 
+((-3620 (((-1157 |#1|) (-917)) 26))) 
+(((-587 |#1|) (-10 -7 (-15 -3620 ((-1157 |#1|) (-917)))) (-350)) (T -587)) 
+((-3620 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-587 *4)) (-4 *4 (-350))))) 
+(-10 -7 (-15 -3620 ((-1157 |#1|) (-917)))) 
+((-4446 (((-585 (-409 (-953 |#1|))) (-585 (-409 (-953 |#1|)))) 26)) (-1845 (((-3 (-310 |#1|) (-634 (-310 |#1|))) (-409 (-953 |#1|)) (-1161)) 32 (|has| |#1| (-150)))) (-2791 (((-634 (-310 |#1|)) (-585 (-409 (-953 |#1|)))) 18)) (-2789 (((-310 |#1|) (-409 (-953 |#1|)) (-1161)) 30 (|has| |#1| (-150)))) (-4443 (((-310 |#1|) (-585 (-409 (-953 |#1|)))) 20))) 
+(((-588 |#1|) (-10 -7 (-15 -4446 ((-585 (-409 (-953 |#1|))) (-585 (-409 (-953 |#1|))))) (-15 -2791 ((-634 (-310 |#1|)) (-585 (-409 (-953 |#1|))))) (-15 -4443 ((-310 |#1|) (-585 (-409 (-953 |#1|))))) (IF (|has| |#1| (-150)) (PROGN (-15 -1845 ((-3 (-310 |#1|) (-634 (-310 |#1|))) (-409 (-953 |#1|)) (-1161))) (-15 -2789 ((-310 |#1|) (-409 (-953 |#1|)) (-1161)))) |noBranch|)) (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (T -588)) 
+((-2789 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-150)) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *2 (-310 *5)) (-5 *1 (-588 *5)))) (-1845 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-150)) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *2 (-3 (-310 *5) (-634 (-310 *5)))) (-5 *1 (-588 *5)))) (-4443 (*1 *2 *3) (-12 (-5 *3 (-585 (-409 (-953 *4)))) (-4 *4 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *2 (-310 *4)) (-5 *1 (-588 *4)))) (-2791 (*1 *2 *3) (-12 (-5 *3 (-585 (-409 (-953 *4)))) (-4 *4 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *2 (-634 (-310 *4))) (-5 *1 (-588 *4)))) (-4446 (*1 *2 *2) (-12 (-5 *2 (-585 (-409 (-953 *3)))) (-4 *3 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *1 (-588 *3))))) 
+(-10 -7 (-15 -4446 ((-585 (-409 (-953 |#1|))) (-585 (-409 (-953 |#1|))))) (-15 -2791 ((-634 (-310 |#1|)) (-585 (-409 (-953 |#1|))))) (-15 -4443 ((-310 |#1|) (-585 (-409 (-953 |#1|))))) (IF (|has| |#1| (-150)) (PROGN (-15 -1845 ((-3 (-310 |#1|) (-634 (-310 |#1|))) (-409 (-953 |#1|)) (-1161))) (-15 -2789 ((-310 |#1|) (-409 (-953 |#1|)) (-1161)))) |noBranch|)) 
+((-2970 (((-634 (-679 (-568))) (-634 (-568)) (-634 (-900 (-568)))) 45) (((-634 (-679 (-568))) (-634 (-568))) 46) (((-679 (-568)) (-634 (-568)) (-900 (-568))) 41)) (-3445 (((-763) (-634 (-568))) 39))) 
+(((-589) (-10 -7 (-15 -3445 ((-763) (-634 (-568)))) (-15 -2970 ((-679 (-568)) (-634 (-568)) (-900 (-568)))) (-15 -2970 ((-634 (-679 (-568))) (-634 (-568)))) (-15 -2970 ((-634 (-679 (-568))) (-634 (-568)) (-634 (-900 (-568))))))) (T -589)) 
+((-2970 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-568))) (-5 *4 (-634 (-900 (-568)))) (-5 *2 (-634 (-679 (-568)))) (-5 *1 (-589)))) (-2970 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-634 (-679 (-568)))) (-5 *1 (-589)))) (-2970 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-568))) (-5 *4 (-900 (-568))) (-5 *2 (-679 (-568))) (-5 *1 (-589)))) (-3445 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-763)) (-5 *1 (-589))))) 
+(-10 -7 (-15 -3445 ((-763) (-634 (-568)))) (-15 -2970 ((-679 (-568)) (-634 (-568)) (-900 (-568)))) (-15 -2970 ((-634 (-679 (-568))) (-634 (-568)))) (-15 -2970 ((-634 (-679 (-568))) (-634 (-568)) (-634 (-900 (-568)))))) 
+((-2805 (((-634 |#5|) |#5| (-121)) 72)) (-3952 (((-121) |#5| (-634 |#5|)) 30))) 
+(((-590 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2805 ((-634 |#5|) |#5| (-121))) (-15 -3952 ((-121) |#5| (-634 |#5|)))) (-13 (-301) (-150)) (-788) (-842) (-1061 |#1| |#2| |#3|) (-1099 |#1| |#2| |#3| |#4|)) (T -590)) 
+((-3952 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-1099 *5 *6 *7 *8)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-590 *5 *6 *7 *8 *3)))) (-2805 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-634 *3)) (-5 *1 (-590 *5 *6 *7 *8 *3)) (-4 *3 (-1099 *5 *6 *7 *8))))) 
+(-10 -7 (-15 -2805 ((-634 |#5|) |#5| (-121))) (-15 -3952 ((-121) |#5| (-634 |#5|)))) 
+((-2449 (((-121) $ $) NIL (|has| (-147) (-1090)))) (-2499 (($ $) 34)) (-3083 (($ $) NIL)) (-1474 (($ $ (-147)) NIL) (($ $ (-142)) NIL)) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-3675 (((-121) $ $) 51)) (-3762 (((-121) $ $ (-568)) 46)) (-4446 (((-634 $) $ (-147)) 59) (((-634 $) $ (-142)) 60)) (-1324 (((-121) (-1 (-121) (-147) (-147)) $) NIL) (((-121) $) NIL (|has| (-147) (-842)))) (-2109 (($ (-1 (-121) (-147) (-147)) $) NIL (|has| $ (-6 -4522))) (($ $) NIL (-12 (|has| $ (-6 -4522)) (|has| (-147) (-842))))) (-3647 (($ (-1 (-121) (-147) (-147)) $) NIL) (($ $) NIL (|has| (-147) (-842)))) (-1667 (((-121) $ (-763)) NIL)) (-2438 (((-147) $ (-568) (-147)) 45 (|has| $ (-6 -4522))) (((-147) $ (-1210 (-568)) (-147)) NIL (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4521)))) (-4490 (($) NIL T CONST)) (-1871 (($ $ (-147)) 63) (($ $ (-142)) 64)) (-4452 (($ $) NIL (|has| $ (-6 -4522)))) (-3945 (($ $) NIL)) (-3943 (($ $ (-1210 (-568)) $) 44)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-147) (-1090))))) (-4330 (($ (-147) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-147) (-1090)))) (($ (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4521)))) (-3094 (((-147) (-1 (-147) (-147) (-147)) $ (-147) (-147)) NIL (-12 (|has| $ (-6 -4521)) (|has| (-147) (-1090)))) (((-147) (-1 (-147) (-147) (-147)) $ (-147)) NIL (|has| $ (-6 -4521))) (((-147) (-1 (-147) (-147) (-147)) $) NIL (|has| $ (-6 -4521)))) (-1292 (((-147) $ (-568) (-147)) NIL (|has| $ (-6 -4522)))) (-2069 (((-147) $ (-568)) NIL)) (-3768 (((-121) $ $) 70)) (-2766 (((-568) (-1 (-121) (-147)) $) NIL) (((-568) (-147) $) NIL (|has| (-147) (-1090))) (((-568) (-147) $ (-568)) 48 (|has| (-147) (-1090))) (((-568) $ $ (-568)) 47) (((-568) (-142) $ (-568)) 50)) (-3317 (((-634 (-147)) $) NIL (|has| $ (-6 -4521)))) (-1851 (($ (-763) (-147)) 9)) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) 28 (|has| (-568) (-842)))) (-1732 (($ $ $) NIL (|has| (-147) (-842)))) (-3645 (($ (-1 (-121) (-147) (-147)) $ $) NIL) (($ $ $) NIL (|has| (-147) (-842)))) (-4406 (((-634 (-147)) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) (-147) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-147) (-1090))))) (-3631 (((-568) $) 42 (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (|has| (-147) (-842)))) (-4065 (((-121) $ $ (-147)) 71)) (-4439 (((-763) $ $ (-147)) 69)) (-2253 (($ (-1 (-147) (-147)) $) 33 (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-147) (-147)) $) NIL) (($ (-1 (-147) (-147) (-147)) $ $) NIL)) (-2739 (($ $) 37)) (-4499 (($ $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-3384 (($ $ (-147)) 61) (($ $ (-142)) 62)) (-1893 (((-1143) $) 38 (|has| (-147) (-1090)))) (-4124 (($ (-147) $ (-568)) NIL) (($ $ $ (-568)) 23)) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4025 (((-568) $) 68) (((-1108) $) NIL (|has| (-147) (-1090)))) (-3877 (((-147) $) NIL (|has| (-568) (-842)))) (-2712 (((-3 (-147) "failed") (-1 (-121) (-147)) $) NIL)) (-2490 (($ $ (-147)) NIL (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-147)))) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-288 (-147))) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-147) (-147)) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-634 (-147)) (-634 (-147))) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) (-147) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-147) (-1090))))) (-1480 (((-634 (-147)) $) NIL)) (-2436 (((-121) $) 12)) (-1990 (($) 10)) (-2781 (((-147) $ (-568) (-147)) NIL) (((-147) $ (-568)) 52) (($ $ (-1210 (-568))) 21) (($ $ $) NIL)) (-2828 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-4170 (((-763) (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4521))) (((-763) (-147) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-147) (-1090))))) (-3306 (($ $ $ (-568)) 65 (|has| $ (-6 -4522)))) (-3865 (($ $) 17)) (-4280 (((-541) $) NIL (|has| (-147) (-609 (-541))))) (-4289 (($ (-634 (-147))) NIL)) (-2770 (($ $ (-147)) NIL) (($ (-147) $) NIL) (($ $ $) 16) (($ (-634 $)) 66)) (-2747 (($ (-147)) NIL) (((-850) $) 27 (|has| (-147) (-1090)))) (-3437 (((-121) (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4521)))) (-1753 (((-121) $ $) NIL (|has| (-147) (-842)))) (-1740 (((-121) $ $) NIL (|has| (-147) (-842)))) (-1719 (((-121) $ $) 14 (|has| (-147) (-1090)))) (-1747 (((-121) $ $) NIL (|has| (-147) (-842)))) (-1734 (((-121) $ $) 15 (|has| (-147) (-842)))) (-1699 (((-763) $) 13 (|has| $ (-6 -4521))))) 
+(((-591 |#1|) (-13 (-1129) (-10 -8 (-15 -4025 ((-568) $)))) (-568)) (T -591)) 
+((-4025 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-591 *3)) (-14 *3 *2)))) 
+(-13 (-1129) (-10 -8 (-15 -4025 ((-568) $)))) 
+((-2630 (((-2 (|:| |num| |#4|) (|:| |den| (-568))) |#4| |#2|) 23) (((-2 (|:| |num| |#4|) (|:| |den| (-568))) |#4| |#2| (-1084 |#4|)) 32))) 
+(((-592 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2630 ((-2 (|:| |num| |#4|) (|:| |den| (-568))) |#4| |#2| (-1084 |#4|))) (-15 -2630 ((-2 (|:| |num| |#4|) (|:| |den| (-568))) |#4| |#2|))) (-788) (-842) (-558) (-950 |#3| |#1| |#2|)) (T -592)) 
+((-2630 (*1 *2 *3 *4) (-12 (-4 *5 (-788)) (-4 *4 (-842)) (-4 *6 (-558)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| (-568)))) (-5 *1 (-592 *5 *4 *6 *3)) (-4 *3 (-950 *6 *5 *4)))) (-2630 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-1084 *3)) (-4 *3 (-950 *7 *6 *4)) (-4 *6 (-788)) (-4 *4 (-842)) (-4 *7 (-558)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| (-568)))) (-5 *1 (-592 *6 *4 *7 *3))))) 
+(-10 -7 (-15 -2630 ((-2 (|:| |num| |#4|) (|:| |den| (-568))) |#4| |#2| (-1084 |#4|))) (-15 -2630 ((-2 (|:| |num| |#4|) (|:| |den| (-568))) |#4| |#2|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 63)) (-2057 (((-634 (-1075)) $) NIL)) (-3325 (((-1161) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-4179 (($ $ (-568)) 54) (($ $ (-568) (-568)) 55)) (-2013 (((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) 60)) (-1608 (($ $) 99)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4118 (((-850) (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) (-1026 (-835 (-568))) (-1161) |#1| (-409 (-568))) 214)) (-2512 (($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) 34)) (-4490 (($) NIL T CONST)) (-2116 (($ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1302 (((-121) $) NIL)) (-1844 (((-568) $) 58) (((-568) $ (-568)) 59)) (-1598 (((-121) $) NIL)) (-4168 (($ $ (-917)) 76)) (-3698 (($ (-1 |#1| (-568)) $) 73)) (-2171 (((-121) $) 25)) (-2049 (($ |#1| (-568)) 22) (($ $ (-1075) (-568)) NIL) (($ $ (-634 (-1075)) (-634 (-568))) NIL)) (-2797 (($ (-1 |#1| |#1|) $) 67)) (-4064 (($ (-1026 (-835 (-568))) (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) 11)) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-1893 (((-1143) $) NIL)) (-1845 (($ $) 111 (|has| |#1| (-43 (-409 (-568)))))) (-2349 (((-3 $ "failed") $ $ (-121)) 98)) (-2688 (($ $ $) 107)) (-4025 (((-1108) $) NIL)) (-2612 (((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) 13)) (-2312 (((-1026 (-835 (-568))) $) 12)) (-2168 (($ $ (-568)) 45)) (-2597 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-1339 (((-1141 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-568)))))) (-2781 ((|#1| $ (-568)) 57) (($ $ $) NIL (|has| (-568) (-1102)))) (-4191 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $) 70 (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (-1836 (((-568) $) NIL)) (-2188 (($ $) 46)) (-2747 (((-850) $) NIL) (($ (-568)) 28) (($ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $) NIL (|has| |#1| (-558))) (($ |#1|) 27 (|has| |#1| (-172)))) (-2079 ((|#1| $ (-568)) 56)) (-3385 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-3425 (((-763)) 37)) (-1374 ((|#1| $) NIL)) (-4278 (($ $) 179 (|has| |#1| (-43 (-409 (-568)))))) (-4029 (($ $) 155 (|has| |#1| (-43 (-409 (-568)))))) (-3671 (($ $) 176 (|has| |#1| (-43 (-409 (-568)))))) (-2590 (($ $) 152 (|has| |#1| (-43 (-409 (-568)))))) (-1291 (($ $) 181 (|has| |#1| (-43 (-409 (-568)))))) (-1411 (($ $) 158 (|has| |#1| (-43 (-409 (-568)))))) (-2395 (($ $ (-409 (-568))) 145 (|has| |#1| (-43 (-409 (-568)))))) (-2836 (($ $ |#1|) 120 (|has| |#1| (-43 (-409 (-568)))))) (-3981 (($ $) 149 (|has| |#1| (-43 (-409 (-568)))))) (-3161 (($ $) 147 (|has| |#1| (-43 (-409 (-568)))))) (-3701 (($ $) 182 (|has| |#1| (-43 (-409 (-568)))))) (-1902 (($ $) 159 (|has| |#1| (-43 (-409 (-568)))))) (-2697 (($ $) 180 (|has| |#1| (-43 (-409 (-568)))))) (-3792 (($ $) 157 (|has| |#1| (-43 (-409 (-568)))))) (-1486 (($ $) 177 (|has| |#1| (-43 (-409 (-568)))))) (-1906 (($ $) 153 (|has| |#1| (-43 (-409 (-568)))))) (-2329 (($ $) 187 (|has| |#1| (-43 (-409 (-568)))))) (-2975 (($ $) 167 (|has| |#1| (-43 (-409 (-568)))))) (-1782 (($ $) 184 (|has| |#1| (-43 (-409 (-568)))))) (-2511 (($ $) 162 (|has| |#1| (-43 (-409 (-568)))))) (-3389 (($ $) 191 (|has| |#1| (-43 (-409 (-568)))))) (-2633 (($ $) 171 (|has| |#1| (-43 (-409 (-568)))))) (-3127 (($ $) 193 (|has| |#1| (-43 (-409 (-568)))))) (-1945 (($ $) 173 (|has| |#1| (-43 (-409 (-568)))))) (-3003 (($ $) 189 (|has| |#1| (-43 (-409 (-568)))))) (-3272 (($ $) 169 (|has| |#1| (-43 (-409 (-568)))))) (-1752 (($ $) 186 (|has| |#1| (-43 (-409 (-568)))))) (-1742 (($ $) 165 (|has| |#1| (-43 (-409 (-568)))))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-3999 ((|#1| $ (-568)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-568)))) (|has| |#1| (-15 -2747 (|#1| (-1161))))))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 29 T CONST)) (-1557 (($) 38 T CONST)) (-3192 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (-1719 (((-121) $ $) 65)) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1775 (($ $) 84) (($ $ $) 64)) (-1769 (($ $ $) 81)) (** (($ $ (-917)) NIL) (($ $ (-763)) 102)) (* (($ (-917) $) 89) (($ (-763) $) 87) (($ (-568) $) 85) (($ $ $) 95) (($ $ |#1|) NIL) (($ |#1| $) 114) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
+(((-593 |#1|) (-13 (-1221 |#1| (-568)) (-10 -8 (-15 -4064 ($ (-1026 (-835 (-568))) (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))))) (-15 -2312 ((-1026 (-835 (-568))) $)) (-15 -2612 ((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $)) (-15 -2512 ($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))))) (-15 -2171 ((-121) $)) (-15 -3698 ($ (-1 |#1| (-568)) $)) (-15 -2349 ((-3 $ "failed") $ $ (-121))) (-15 -1608 ($ $)) (-15 -2688 ($ $ $)) (-15 -4118 ((-850) (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) (-1026 (-835 (-568))) (-1161) |#1| (-409 (-568)))) (IF (|has| |#1| (-43 (-409 (-568)))) (PROGN (-15 -1845 ($ $)) (-15 -2836 ($ $ |#1|)) (-15 -2395 ($ $ (-409 (-568)))) (-15 -3161 ($ $)) (-15 -3981 ($ $)) (-15 -2590 ($ $)) (-15 -1906 ($ $)) (-15 -4029 ($ $)) (-15 -3792 ($ $)) (-15 -1411 ($ $)) (-15 -1902 ($ $)) (-15 -2511 ($ $)) (-15 -1742 ($ $)) (-15 -2975 ($ $)) (-15 -3272 ($ $)) (-15 -2633 ($ $)) (-15 -1945 ($ $)) (-15 -3671 ($ $)) (-15 -1486 ($ $)) (-15 -4278 ($ $)) (-15 -2697 ($ $)) (-15 -1291 ($ $)) (-15 -3701 ($ $)) (-15 -1782 ($ $)) (-15 -1752 ($ $)) (-15 -2329 ($ $)) (-15 -3003 ($ $)) (-15 -3389 ($ $)) (-15 -3127 ($ $))) |noBranch|))) (-1047)) (T -593)) 
+((-2171 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-593 *3)) (-4 *3 (-1047)))) (-4064 (*1 *1 *2 *3) (-12 (-5 *2 (-1026 (-835 (-568)))) (-5 *3 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *4)))) (-4 *4 (-1047)) (-5 *1 (-593 *4)))) (-2312 (*1 *2 *1) (-12 (-5 *2 (-1026 (-835 (-568)))) (-5 *1 (-593 *3)) (-4 *3 (-1047)))) (-2612 (*1 *2 *1) (-12 (-5 *2 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *3)))) (-5 *1 (-593 *3)) (-4 *3 (-1047)))) (-2512 (*1 *1 *2) (-12 (-5 *2 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *3)))) (-4 *3 (-1047)) (-5 *1 (-593 *3)))) (-3698 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-568))) (-4 *3 (-1047)) (-5 *1 (-593 *3)))) (-2349 (*1 *1 *1 *1 *2) (|partial| -12 (-5 *2 (-121)) (-5 *1 (-593 *3)) (-4 *3 (-1047)))) (-1608 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-1047)))) (-2688 (*1 *1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-1047)))) (-4118 (*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *3 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *6)))) (-5 *4 (-1026 (-835 (-568)))) (-5 *5 (-1161)) (-5 *7 (-409 (-568))) (-4 *6 (-1047)) (-5 *2 (-850)) (-5 *1 (-593 *6)))) (-1845 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-2836 (*1 *1 *1 *2) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-2395 (*1 *1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-593 *3)) (-4 *3 (-43 *2)) (-4 *3 (-1047)))) (-3161 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-3981 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-2590 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-1906 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-4029 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-3792 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-1411 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-1902 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-2511 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-1742 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-2975 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-3272 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-2633 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-1945 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-3671 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-1486 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-4278 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-2697 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-1291 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-3701 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-1782 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-1752 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-2329 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-3003 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-3389 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) (-3127 (*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
+(-13 (-1221 |#1| (-568)) (-10 -8 (-15 -4064 ($ (-1026 (-835 (-568))) (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))))) (-15 -2312 ((-1026 (-835 (-568))) $)) (-15 -2612 ((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $)) (-15 -2512 ($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))))) (-15 -2171 ((-121) $)) (-15 -3698 ($ (-1 |#1| (-568)) $)) (-15 -2349 ((-3 $ "failed") $ $ (-121))) (-15 -1608 ($ $)) (-15 -2688 ($ $ $)) (-15 -4118 ((-850) (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) (-1026 (-835 (-568))) (-1161) |#1| (-409 (-568)))) (IF (|has| |#1| (-43 (-409 (-568)))) (PROGN (-15 -1845 ($ $)) (-15 -2836 ($ $ |#1|)) (-15 -2395 ($ $ (-409 (-568)))) (-15 -3161 ($ $)) (-15 -3981 ($ $)) (-15 -2590 ($ $)) (-15 -1906 ($ $)) (-15 -4029 ($ $)) (-15 -3792 ($ $)) (-15 -1411 ($ $)) (-15 -1902 ($ $)) (-15 -2511 ($ $)) (-15 -1742 ($ $)) (-15 -2975 ($ $)) (-15 -3272 ($ $)) (-15 -2633 ($ $)) (-15 -1945 ($ $)) (-15 -3671 ($ $)) (-15 -1486 ($ $)) (-15 -4278 ($ $)) (-15 -2697 ($ $)) (-15 -1291 ($ $)) (-15 -3701 ($ $)) (-15 -1782 ($ $)) (-15 -1752 ($ $)) (-15 -2329 ($ $)) (-15 -3003 ($ $)) (-15 -3389 ($ $)) (-15 -3127 ($ $))) |noBranch|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-2512 (($ (-1141 |#1|)) 9)) (-4490 (($) NIL T CONST)) (-2902 (((-3 $ "failed") $) 42)) (-1302 (((-121) $) 52)) (-1844 (((-763) $) 55) (((-763) $ (-763)) 54)) (-1598 (((-121) $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2597 (((-3 $ "failed") $ $) 44 (|has| |#1| (-558)))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL (|has| |#1| (-558)))) (-3304 (((-1141 |#1|) $) 23)) (-3425 (((-763)) 51)) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 10 T CONST)) (-1557 (($) 14 T CONST)) (-1719 (((-121) $ $) 22)) (-1775 (($ $) 30) (($ $ $) 16)) (-1769 (($ $ $) 25)) (** (($ $ (-917)) NIL) (($ $ (-763)) 49)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 34) (($ $ $) 28) (($ |#1| $) 37) (($ $ |#1|) 38) (($ $ (-568)) 36))) 
+(((-594 |#1|) (-13 (-1047) (-10 -8 (-15 -3304 ((-1141 |#1|) $)) (-15 -2512 ($ (-1141 |#1|))) (-15 -1302 ((-121) $)) (-15 -1844 ((-763) $)) (-15 -1844 ((-763) $ (-763))) (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 * ($ $ (-568))) (IF (|has| |#1| (-558)) (-6 (-558)) |noBranch|))) (-1047)) (T -594)) 
+((-3304 (*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-594 *3)) (-4 *3 (-1047)))) (-2512 (*1 *1 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-594 *3)))) (-1302 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-594 *3)) (-4 *3 (-1047)))) (-1844 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-594 *3)) (-4 *3 (-1047)))) (-1844 (*1 *2 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-594 *3)) (-4 *3 (-1047)))) (* (*1 *1 *2 *1) (-12 (-5 *1 (-594 *2)) (-4 *2 (-1047)))) (* (*1 *1 *1 *2) (-12 (-5 *1 (-594 *2)) (-4 *2 (-1047)))) (* (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-594 *3)) (-4 *3 (-1047))))) 
+(-13 (-1047) (-10 -8 (-15 -3304 ((-1141 |#1|) $)) (-15 -2512 ($ (-1141 |#1|))) (-15 -1302 ((-121) $)) (-15 -1844 ((-763) $)) (-15 -1844 ((-763) $ (-763))) (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 * ($ $ (-568))) (IF (|has| |#1| (-558)) (-6 (-558)) |noBranch|))) 
+((-2797 (((-598 |#2|) (-1 |#2| |#1|) (-598 |#1|)) 15))) 
+(((-595 |#1| |#2|) (-10 -7 (-15 -2797 ((-598 |#2|) (-1 |#2| |#1|) (-598 |#1|)))) (-1195) (-1195)) (T -595)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-598 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-598 *6)) (-5 *1 (-595 *5 *6))))) 
+(-10 -7 (-15 -2797 ((-598 |#2|) (-1 |#2| |#1|) (-598 |#1|)))) 
+((-2797 (((-1141 |#3|) (-1 |#3| |#1| |#2|) (-598 |#1|) (-1141 |#2|)) 20) (((-1141 |#3|) (-1 |#3| |#1| |#2|) (-1141 |#1|) (-598 |#2|)) 19) (((-598 |#3|) (-1 |#3| |#1| |#2|) (-598 |#1|) (-598 |#2|)) 18))) 
+(((-596 |#1| |#2| |#3|) (-10 -7 (-15 -2797 ((-598 |#3|) (-1 |#3| |#1| |#2|) (-598 |#1|) (-598 |#2|))) (-15 -2797 ((-1141 |#3|) (-1 |#3| |#1| |#2|) (-1141 |#1|) (-598 |#2|))) (-15 -2797 ((-1141 |#3|) (-1 |#3| |#1| |#2|) (-598 |#1|) (-1141 |#2|)))) (-1195) (-1195) (-1195)) (T -596)) 
+((-2797 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-598 *6)) (-5 *5 (-1141 *7)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-4 *8 (-1195)) (-5 *2 (-1141 *8)) (-5 *1 (-596 *6 *7 *8)))) (-2797 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-1141 *6)) (-5 *5 (-598 *7)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-4 *8 (-1195)) (-5 *2 (-1141 *8)) (-5 *1 (-596 *6 *7 *8)))) (-2797 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-598 *6)) (-5 *5 (-598 *7)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-4 *8 (-1195)) (-5 *2 (-598 *8)) (-5 *1 (-596 *6 *7 *8))))) 
+(-10 -7 (-15 -2797 ((-598 |#3|) (-1 |#3| |#1| |#2|) (-598 |#1|) (-598 |#2|))) (-15 -2797 ((-1141 |#3|) (-1 |#3| |#1| |#2|) (-1141 |#1|) (-598 |#2|))) (-15 -2797 ((-1141 |#3|) (-1 |#3| |#1| |#2|) (-598 |#1|) (-1141 |#2|)))) 
+((-1824 ((|#3| |#3| (-634 (-607 |#3|)) (-634 (-1161))) 55)) (-3940 (((-169 |#2|) |#3|) 116)) (-3519 ((|#3| (-169 |#2|)) 43)) (-3073 ((|#2| |#3|) 19)) (-4175 ((|#3| |#2|) 32))) 
+(((-597 |#1| |#2| |#3|) (-10 -7 (-15 -3519 (|#3| (-169 |#2|))) (-15 -3073 (|#2| |#3|)) (-15 -4175 (|#3| |#2|)) (-15 -3940 ((-169 |#2|) |#3|)) (-15 -1824 (|#3| |#3| (-634 (-607 |#3|)) (-634 (-1161))))) (-13 (-558) (-842)) (-13 (-432 |#1|) (-1002) (-1181)) (-13 (-432 (-169 |#1|)) (-1002) (-1181))) (T -597)) 
+((-1824 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-634 (-607 *2))) (-5 *4 (-634 (-1161))) (-4 *2 (-13 (-432 (-169 *5)) (-1002) (-1181))) (-4 *5 (-13 (-558) (-842))) (-5 *1 (-597 *5 *6 *2)) (-4 *6 (-13 (-432 *5) (-1002) (-1181))))) (-3940 (*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842))) (-5 *2 (-169 *5)) (-5 *1 (-597 *4 *5 *3)) (-4 *5 (-13 (-432 *4) (-1002) (-1181))) (-4 *3 (-13 (-432 (-169 *4)) (-1002) (-1181))))) (-4175 (*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842))) (-4 *2 (-13 (-432 (-169 *4)) (-1002) (-1181))) (-5 *1 (-597 *4 *3 *2)) (-4 *3 (-13 (-432 *4) (-1002) (-1181))))) (-3073 (*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842))) (-4 *2 (-13 (-432 *4) (-1002) (-1181))) (-5 *1 (-597 *4 *2 *3)) (-4 *3 (-13 (-432 (-169 *4)) (-1002) (-1181))))) (-3519 (*1 *2 *3) (-12 (-5 *3 (-169 *5)) (-4 *5 (-13 (-432 *4) (-1002) (-1181))) (-4 *4 (-13 (-558) (-842))) (-4 *2 (-13 (-432 (-169 *4)) (-1002) (-1181))) (-5 *1 (-597 *4 *5 *2))))) 
+(-10 -7 (-15 -3519 (|#3| (-169 |#2|))) (-15 -3073 (|#2| |#3|)) (-15 -4175 (|#3| |#2|)) (-15 -3940 ((-169 |#2|) |#3|)) (-15 -1824 (|#3| |#3| (-634 (-607 |#3|)) (-634 (-1161))))) 
+((-2803 (($ (-1 (-121) |#1|) $) 16)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-2783 (($ (-1 |#1| |#1|) |#1|) 9)) (-2796 (($ (-1 (-121) |#1|) $) 12)) (-2800 (($ (-1 (-121) |#1|) $) 14)) (-4289 (((-1141 |#1|) $) 17)) (-2747 (((-850) $) NIL))) 
+(((-598 |#1|) (-13 (-608 (-850)) (-10 -8 (-15 -2797 ($ (-1 |#1| |#1|) $)) (-15 -2796 ($ (-1 (-121) |#1|) $)) (-15 -2800 ($ (-1 (-121) |#1|) $)) (-15 -2803 ($ (-1 (-121) |#1|) $)) (-15 -2783 ($ (-1 |#1| |#1|) |#1|)) (-15 -4289 ((-1141 |#1|) $)))) (-1195)) (T -598)) 
+((-2797 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1195)) (-5 *1 (-598 *3)))) (-2796 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1195)) (-5 *1 (-598 *3)))) (-2800 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1195)) (-5 *1 (-598 *3)))) (-2803 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1195)) (-5 *1 (-598 *3)))) (-2783 (*1 *1 *2 *3) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1195)) (-5 *1 (-598 *3)))) (-4289 (*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-598 *3)) (-4 *3 (-1195))))) 
+(-13 (-608 (-850)) (-10 -8 (-15 -2797 ($ (-1 |#1| |#1|) $)) (-15 -2796 ($ (-1 (-121) |#1|) $)) (-15 -2800 ($ (-1 (-121) |#1|) $)) (-15 -2803 ($ (-1 (-121) |#1|) $)) (-15 -2783 ($ (-1 |#1| |#1|) |#1|)) (-15 -4289 ((-1141 |#1|) $)))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3207 (($ (-763)) NIL (|has| |#1| (-23)))) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-1324 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-842)))) (-2109 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4522))) (($ $) NIL (-12 (|has| $ (-6 -4522)) (|has| |#1| (-842))))) (-3647 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-842)))) (-1667 (((-121) $ (-763)) NIL)) (-2438 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4522))) ((|#1| $ (-1210 (-568)) |#1|) NIL (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-4490 (($) NIL T CONST)) (-4452 (($ $) NIL (|has| $ (-6 -4522)))) (-3945 (($ $) NIL)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-4330 (($ |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4521)))) (-1292 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-568)) NIL)) (-2766 (((-568) (-1 (-121) |#1|) $) NIL) (((-568) |#1| $) NIL (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) NIL (|has| |#1| (-1090)))) (-3317 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-1804 (((-679 |#1|) $ $) NIL (|has| |#1| (-1047)))) (-1851 (($ (-763) |#1|) NIL)) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) NIL (|has| (-568) (-842)))) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-3645 (($ (-1 (-121) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-842)))) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3631 (((-568) $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-2253 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-4303 ((|#1| $) NIL (-12 (|has| |#1| (-1002)) (|has| |#1| (-1047))))) (-3796 (((-121) $ (-763)) NIL)) (-3680 ((|#1| $) NIL (-12 (|has| |#1| (-1002)) (|has| |#1| (-1047))))) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4124 (($ |#1| $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3877 ((|#1| $) NIL (|has| (-568) (-842)))) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-2490 (($ $ |#1|) NIL (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#1| $ (-568) |#1|) NIL) ((|#1| $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-2286 ((|#1| $ $) NIL (|has| |#1| (-1047)))) (-2828 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-3372 (($ $ $) NIL (|has| |#1| (-1047)))) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3306 (($ $ $ (-568)) NIL (|has| $ (-6 -4522)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) NIL)) (-2770 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-634 $)) NIL)) (-2747 (((-850) $) NIL (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1775 (($ $) NIL (|has| |#1| (-21))) (($ $ $) NIL (|has| |#1| (-21)))) (-1769 (($ $ $) NIL (|has| |#1| (-25)))) (* (($ (-568) $) NIL (|has| |#1| (-21))) (($ |#1| $) NIL (|has| |#1| (-716))) (($ $ |#1|) NIL (|has| |#1| (-716)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
 (((-599 |#1| |#2|) (-1242 |#1|) (-1195) (-568)) (T -599)) 
 NIL 
 (-1242 |#1|) 
-((-1868 (((-1249) $ |#2| |#2|) 36)) (-1881 ((|#2| $) 23)) (-2223 ((|#2| $) 21)) (-3674 (($ (-1 |#3| |#3|) $) 32)) (-2795 (($ (-1 |#3| |#3|) $) 30)) (-3876 ((|#3| $) 26)) (-3724 (($ $ |#3|) 33)) (-4467 (((-121) |#3| $) 17)) (-2041 (((-634 |#3|) $) 15)) (-2779 ((|#3| $ |#2| |#3|) 12) ((|#3| $ |#2|) NIL))) 
-(((-600 |#1| |#2| |#3|) (-10 -8 (-15 -1868 ((-1249) |#1| |#2| |#2|)) (-15 -3724 (|#1| |#1| |#3|)) (-15 -3876 (|#3| |#1|)) (-15 -1881 (|#2| |#1|)) (-15 -2223 (|#2| |#1|)) (-15 -4467 ((-121) |#3| |#1|)) (-15 -2041 ((-634 |#3|) |#1|)) (-15 -2779 (|#3| |#1| |#2|)) (-15 -2779 (|#3| |#1| |#2| |#3|)) (-15 -3674 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -2795 (|#1| (-1 |#3| |#3|) |#1|))) (-601 |#2| |#3|) (-1090) (-1195)) (T -600)) 
+((-2481 (((-1249) $ |#2| |#2|) 36)) (-2539 ((|#2| $) 23)) (-3631 ((|#2| $) 21)) (-2253 (($ (-1 |#3| |#3|) $) 32)) (-2797 (($ (-1 |#3| |#3|) $) 30)) (-3877 ((|#3| $) 26)) (-2490 (($ $ |#3|) 33)) (-1801 (((-121) |#3| $) 17)) (-1480 (((-634 |#3|) $) 15)) (-2781 ((|#3| $ |#2| |#3|) 12) ((|#3| $ |#2|) NIL))) 
+(((-600 |#1| |#2| |#3|) (-10 -8 (-15 -2481 ((-1249) |#1| |#2| |#2|)) (-15 -2490 (|#1| |#1| |#3|)) (-15 -3877 (|#3| |#1|)) (-15 -2539 (|#2| |#1|)) (-15 -3631 (|#2| |#1|)) (-15 -1801 ((-121) |#3| |#1|)) (-15 -1480 ((-634 |#3|) |#1|)) (-15 -2781 (|#3| |#1| |#2|)) (-15 -2781 (|#3| |#1| |#2| |#3|)) (-15 -2253 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -2797 (|#1| (-1 |#3| |#3|) |#1|))) (-601 |#2| |#3|) (-1090) (-1195)) (T -600)) 
 NIL 
-(-10 -8 (-15 -1868 ((-1249) |#1| |#2| |#2|)) (-15 -3724 (|#1| |#1| |#3|)) (-15 -3876 (|#3| |#1|)) (-15 -1881 (|#2| |#1|)) (-15 -2223 (|#2| |#1|)) (-15 -4467 ((-121) |#3| |#1|)) (-15 -2041 ((-634 |#3|) |#1|)) (-15 -2779 (|#3| |#1| |#2|)) (-15 -2779 (|#3| |#1| |#2| |#3|)) (-15 -3674 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -2795 (|#1| (-1 |#3| |#3|) |#1|))) 
-((-2447 (((-121) $ $) 18 (|has| |#2| (-1090)))) (-1868 (((-1249) $ |#1| |#1|) 37 (|has| $ (-6 -4520)))) (-2510 (((-121) $ (-763)) 8)) (-2436 ((|#2| $ |#1| |#2|) 49 (|has| $ (-6 -4520)))) (-2671 (($) 7 T CONST)) (-3989 ((|#2| $ |#1| |#2|) 50 (|has| $ (-6 -4520)))) (-2602 ((|#2| $ |#1|) 48)) (-4360 (((-634 |#2|) $) 30 (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) 9)) (-1881 ((|#1| $) 40 (|has| |#1| (-842)))) (-1979 (((-634 |#2|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#2| $) 27 (-12 (|has| |#2| (-1090)) (|has| $ (-6 -4519))))) (-2223 ((|#1| $) 41 (|has| |#1| (-842)))) (-3674 (($ (-1 |#2| |#2|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#2| |#2|) $) 35)) (-2166 (((-121) $ (-763)) 10)) (-4487 (((-1143) $) 22 (|has| |#2| (-1090)))) (-4174 (((-634 |#1|) $) 43)) (-3578 (((-121) |#1| $) 44)) (-4022 (((-1108) $) 21 (|has| |#2| (-1090)))) (-3876 ((|#2| $) 39 (|has| |#1| (-842)))) (-3724 (($ $ |#2|) 38 (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) |#2|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#2|))) 26 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) 25 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) 24 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) 23 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-3171 (((-121) $ $) 14)) (-4467 (((-121) |#2| $) 42 (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-2041 (((-634 |#2|) $) 45)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 ((|#2| $ |#1| |#2|) 47) ((|#2| $ |#1|) 46)) (-4168 (((-763) (-1 (-121) |#2|) $) 31 (|has| $ (-6 -4519))) (((-763) |#2| $) 28 (-12 (|has| |#2| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-2745 (((-850) $) 20 (|has| |#2| (-1090)))) (-1319 (((-121) (-1 (-121) |#2|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| |#2| (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+(-10 -8 (-15 -2481 ((-1249) |#1| |#2| |#2|)) (-15 -2490 (|#1| |#1| |#3|)) (-15 -3877 (|#3| |#1|)) (-15 -2539 (|#2| |#1|)) (-15 -3631 (|#2| |#1|)) (-15 -1801 ((-121) |#3| |#1|)) (-15 -1480 ((-634 |#3|) |#1|)) (-15 -2781 (|#3| |#1| |#2|)) (-15 -2781 (|#3| |#1| |#2| |#3|)) (-15 -2253 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -2797 (|#1| (-1 |#3| |#3|) |#1|))) 
+((-2449 (((-121) $ $) 18 (|has| |#2| (-1090)))) (-2481 (((-1249) $ |#1| |#1|) 37 (|has| $ (-6 -4522)))) (-1667 (((-121) $ (-763)) 8)) (-2438 ((|#2| $ |#1| |#2|) 49 (|has| $ (-6 -4522)))) (-4490 (($) 7 T CONST)) (-1292 ((|#2| $ |#1| |#2|) 50 (|has| $ (-6 -4522)))) (-2069 ((|#2| $ |#1|) 48)) (-3317 (((-634 |#2|) $) 30 (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) 9)) (-2539 ((|#1| $) 40 (|has| |#1| (-842)))) (-4406 (((-634 |#2|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#2| $) 27 (-12 (|has| |#2| (-1090)) (|has| $ (-6 -4521))))) (-3631 ((|#1| $) 41 (|has| |#1| (-842)))) (-2253 (($ (-1 |#2| |#2|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#2| |#2|) $) 35)) (-3796 (((-121) $ (-763)) 10)) (-1893 (((-1143) $) 22 (|has| |#2| (-1090)))) (-3948 (((-634 |#1|) $) 43)) (-2916 (((-121) |#1| $) 44)) (-4025 (((-1108) $) 21 (|has| |#2| (-1090)))) (-3877 ((|#2| $) 39 (|has| |#1| (-842)))) (-2490 (($ $ |#2|) 38 (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) |#2|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#2|))) 26 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) 25 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) 24 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) 23 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-1702 (((-121) $ $) 14)) (-1801 (((-121) |#2| $) 42 (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-1480 (((-634 |#2|) $) 45)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 ((|#2| $ |#1| |#2|) 47) ((|#2| $ |#1|) 46)) (-4170 (((-763) (-1 (-121) |#2|) $) 31 (|has| $ (-6 -4521))) (((-763) |#2| $) 28 (-12 (|has| |#2| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-2747 (((-850) $) 20 (|has| |#2| (-1090)))) (-3437 (((-121) (-1 (-121) |#2|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| |#2| (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-601 |#1| |#2|) (-1275) (-1090) (-1195)) (T -601)) 
-((-2041 (*1 *2 *1) (-12 (-4 *1 (-601 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1195)) (-5 *2 (-634 *4)))) (-3578 (*1 *2 *3 *1) (-12 (-4 *1 (-601 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1195)) (-5 *2 (-121)))) (-4174 (*1 *2 *1) (-12 (-4 *1 (-601 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1195)) (-5 *2 (-634 *3)))) (-4467 (*1 *2 *3 *1) (-12 (|has| *1 (-6 -4519)) (-4 *1 (-601 *4 *3)) (-4 *4 (-1090)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-121)))) (-2223 (*1 *2 *1) (-12 (-4 *1 (-601 *2 *3)) (-4 *3 (-1195)) (-4 *2 (-1090)) (-4 *2 (-842)))) (-1881 (*1 *2 *1) (-12 (-4 *1 (-601 *2 *3)) (-4 *3 (-1195)) (-4 *2 (-1090)) (-4 *2 (-842)))) (-3876 (*1 *2 *1) (-12 (-4 *1 (-601 *3 *2)) (-4 *3 (-1090)) (-4 *3 (-842)) (-4 *2 (-1195)))) (-3724 (*1 *1 *1 *2) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-601 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195)))) (-1868 (*1 *2 *1 *3 *3) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-601 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1195)) (-5 *2 (-1249))))) 
-(-13 (-499 |t#2|) (-283 |t#1| |t#2|) (-10 -8 (-15 -2041 ((-634 |t#2|) $)) (-15 -3578 ((-121) |t#1| $)) (-15 -4174 ((-634 |t#1|) $)) (IF (|has| |t#2| (-1090)) (IF (|has| $ (-6 -4519)) (-15 -4467 ((-121) |t#2| $)) |noBranch|) |noBranch|) (IF (|has| |t#1| (-842)) (PROGN (-15 -2223 (|t#1| $)) (-15 -1881 (|t#1| $)) (-15 -3876 (|t#2| $))) |noBranch|) (IF (|has| $ (-6 -4520)) (PROGN (-15 -3724 ($ $ |t#2|)) (-15 -1868 ((-1249) $ |t#1| |t#1|))) |noBranch|))) 
+((-1480 (*1 *2 *1) (-12 (-4 *1 (-601 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1195)) (-5 *2 (-634 *4)))) (-2916 (*1 *2 *3 *1) (-12 (-4 *1 (-601 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1195)) (-5 *2 (-121)))) (-3948 (*1 *2 *1) (-12 (-4 *1 (-601 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1195)) (-5 *2 (-634 *3)))) (-1801 (*1 *2 *3 *1) (-12 (|has| *1 (-6 -4521)) (-4 *1 (-601 *4 *3)) (-4 *4 (-1090)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-121)))) (-3631 (*1 *2 *1) (-12 (-4 *1 (-601 *2 *3)) (-4 *3 (-1195)) (-4 *2 (-1090)) (-4 *2 (-842)))) (-2539 (*1 *2 *1) (-12 (-4 *1 (-601 *2 *3)) (-4 *3 (-1195)) (-4 *2 (-1090)) (-4 *2 (-842)))) (-3877 (*1 *2 *1) (-12 (-4 *1 (-601 *3 *2)) (-4 *3 (-1090)) (-4 *3 (-842)) (-4 *2 (-1195)))) (-2490 (*1 *1 *1 *2) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-601 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195)))) (-2481 (*1 *2 *1 *3 *3) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-601 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1195)) (-5 *2 (-1249))))) 
+(-13 (-499 |t#2|) (-283 |t#1| |t#2|) (-10 -8 (-15 -1480 ((-634 |t#2|) $)) (-15 -2916 ((-121) |t#1| $)) (-15 -3948 ((-634 |t#1|) $)) (IF (|has| |t#2| (-1090)) (IF (|has| $ (-6 -4521)) (-15 -1801 ((-121) |t#2| $)) |noBranch|) |noBranch|) (IF (|has| |t#1| (-842)) (PROGN (-15 -3631 (|t#1| $)) (-15 -2539 (|t#1| $)) (-15 -3877 (|t#2| $))) |noBranch|) (IF (|has| $ (-6 -4522)) (PROGN (-15 -2490 ($ $ |t#2|)) (-15 -2481 ((-1249) $ |t#1| |t#1|))) |noBranch|))) 
 (((-39) . T) ((-105) |has| |#2| (-1090)) ((-608 (-850)) |has| |#2| (-1090)) ((-281 |#1| |#2|) . T) ((-283 |#1| |#2|) . T) ((-303 |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) ((-499 |#2|) . T) ((-523 |#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) ((-1090) |has| |#2| (-1090)) ((-1195) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2295 (((-3 $ "failed")) NIL (-2198 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-3134 (((-3 $ "failed") $ $) NIL)) (-2776 (((-1244 (-679 |#1|))) NIL (|has| |#2| (-419 |#1|))) (((-1244 (-679 |#1|)) (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-1741 (((-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-2671 (($) NIL T CONST)) (-1309 (((-3 (-2 (|:| |particular| $) (|:| -3746 (-634 $))) "failed")) NIL (-2198 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-2593 (((-3 $ "failed")) NIL (-2198 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-1631 (((-679 |#1|)) NIL (|has| |#2| (-419 |#1|))) (((-679 |#1|) (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-1866 ((|#1| $) NIL (|has| |#2| (-369 |#1|)))) (-3042 (((-679 |#1|) $) NIL (|has| |#2| (-419 |#1|))) (((-679 |#1|) $ (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-3550 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-4408 (((-1157 (-953 |#1|))) NIL (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-365))))) (-3551 (($ $ (-917)) NIL)) (-4409 ((|#1| $) NIL (|has| |#2| (-369 |#1|)))) (-1371 (((-1157 |#1|) $) NIL (-2198 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-3569 ((|#1|) NIL (|has| |#2| (-419 |#1|))) ((|#1| (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-2989 (((-1157 |#1|) $) NIL (|has| |#2| (-369 |#1|)))) (-3384 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-3498 (($ (-1244 |#1|)) NIL (|has| |#2| (-419 |#1|))) (($ (-1244 |#1|) (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-2925 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-3700 (((-917)) NIL (|has| |#2| (-369 |#1|)))) (-4370 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-4373 (($ $ (-917)) NIL)) (-1537 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-1580 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-1695 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-3116 (((-3 (-2 (|:| |particular| $) (|:| -3746 (-634 $))) "failed")) NIL (-2198 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-2599 (((-3 $ "failed")) NIL (-2198 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-4210 (((-679 |#1|)) NIL (|has| |#2| (-419 |#1|))) (((-679 |#1|) (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-2889 ((|#1| $) NIL (|has| |#2| (-369 |#1|)))) (-4333 (((-679 |#1|) $) NIL (|has| |#2| (-419 |#1|))) (((-679 |#1|) $ (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-3243 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-4454 (((-1157 (-953 |#1|))) NIL (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-365))))) (-4222 (($ $ (-917)) NIL)) (-3329 ((|#1| $) NIL (|has| |#2| (-369 |#1|)))) (-2265 (((-1157 |#1|) $) NIL (-2198 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-3898 ((|#1|) NIL (|has| |#2| (-419 |#1|))) ((|#1| (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-3626 (((-1157 |#1|) $) NIL (|has| |#2| (-369 |#1|)))) (-2767 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-4487 (((-1143) $) NIL)) (-1804 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-2919 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-3840 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-4022 (((-1108) $) NIL)) (-1346 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-2779 ((|#1| $ (-568)) NIL (|has| |#2| (-419 |#1|)))) (-4073 (((-679 |#1|) (-1244 $)) NIL (|has| |#2| (-419 |#1|))) (((-1244 |#1|) $) NIL (|has| |#2| (-419 |#1|))) (((-679 |#1|) (-1244 $) (-1244 $)) NIL (|has| |#2| (-369 |#1|))) (((-1244 |#1|) $ (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-4278 (($ (-1244 |#1|)) NIL (|has| |#2| (-419 |#1|))) (((-1244 |#1|) $) NIL (|has| |#2| (-419 |#1|)))) (-3295 (((-634 (-953 |#1|))) NIL (|has| |#2| (-419 |#1|))) (((-634 (-953 |#1|)) (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-2353 (($ $ $) NIL)) (-3433 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-2745 (((-850) $) NIL) ((|#2| $) 21) (($ |#2|) 22)) (-3746 (((-1244 $)) NIL (|has| |#2| (-419 |#1|)))) (-1509 (((-634 (-1244 |#1|))) NIL (-2198 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-3882 (($ $ $ $) NIL)) (-4177 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-3823 (($ (-679 |#1|) $) NIL (|has| |#2| (-419 |#1|)))) (-3500 (($ $ $) NIL)) (-2433 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-2189 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-4107 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-3056 (($) NIL T CONST)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) 24)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 20) (($ $ |#1|) 19) (($ |#1| $) NIL))) 
-(((-602 |#1| |#2|) (-13 (-736 |#1|) (-608 |#2|) (-10 -8 (-15 -2745 ($ |#2|)) (IF (|has| |#2| (-419 |#1|)) (-6 (-419 |#1|)) |noBranch|) (IF (|has| |#2| (-369 |#1|)) (-6 (-369 |#1|)) |noBranch|))) (-172) (-736 |#1|)) (T -602)) 
-((-2745 (*1 *1 *2) (-12 (-4 *3 (-172)) (-5 *1 (-602 *3 *2)) (-4 *2 (-736 *3))))) 
-(-13 (-736 |#1|) (-608 |#2|) (-10 -8 (-15 -2745 ($ |#2|)) (IF (|has| |#2| (-419 |#1|)) (-6 (-419 |#1|)) |noBranch|) (IF (|has| |#2| (-369 |#1|)) (-6 (-369 |#1|)) |noBranch|))) 
-((-2447 (((-121) $ $) NIL)) (-1705 (((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) $ (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) 33)) (-2986 (($ (-634 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)))) NIL) (($) NIL)) (-1868 (((-1249) $ (-1143) (-1143)) NIL (|has| $ (-6 -4520)))) (-2510 (((-121) $ (-763)) NIL)) (-2436 ((|#1| $ (-1143) |#1|) 43)) (-3507 (($ (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL (|has| $ (-6 -4519)))) (-2674 (((-3 |#1| "failed") (-1143) $) 46)) (-2671 (($) NIL T CONST)) (-2511 (($ $ (-1143)) 25)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090))))) (-3405 (((-3 |#1| "failed") (-1143) $) 47) (($ (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL (|has| $ (-6 -4519))) (($ (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) $) NIL (|has| $ (-6 -4519)))) (-4328 (($ (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL (|has| $ (-6 -4519))) (($ (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090))))) (-3092 (((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL (|has| $ (-6 -4519))) (((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $ (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) NIL (|has| $ (-6 -4519))) (((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $ (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090))))) (-3327 (((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) $) 32)) (-3989 ((|#1| $ (-1143) |#1|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-1143)) NIL)) (-4360 (((-634 |#1|) $) NIL (|has| $ (-6 -4519))) (((-634 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL (|has| $ (-6 -4519)))) (-3380 (($ $) 48)) (-1798 (($ (-390)) 23) (($ (-390) (-1143)) 22)) (-3391 (((-390) $) 34)) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-1143) $) NIL (|has| (-1143) (-842)))) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519))) (((-634 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) (((-121) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090))))) (-2223 (((-1143) $) NIL (|has| (-1143) (-842)))) (-3674 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4520))) (($ (-1 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1|) $) NIL) (($ (-1 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL)) (-1946 (((-634 (-1143)) $) 39)) (-3548 (((-121) (-1143) $) NIL)) (-3305 (((-1143) $) 35)) (-1890 (((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) $) NIL)) (-4450 (($ (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) $) NIL)) (-4174 (((-634 (-1143)) $) NIL)) (-3578 (((-121) (-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-4169 (((-1249) $) NIL)) (-3876 ((|#1| $) NIL (|has| (-1143) (-842)))) (-3775 (((-3 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) "failed") (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL)) (-3724 (($ $ |#1|) NIL (|has| $ (-6 -4520)))) (-1315 (((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) $) NIL)) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) (-634 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)))) NIL (-12 (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-303 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)))) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090)))) (($ $ (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) NIL (-12 (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-303 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)))) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090)))) (($ $ (-288 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)))) NIL (-12 (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-303 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)))) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090)))) (($ $ (-634 (-288 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))))) NIL (-12 (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-303 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)))) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) 37)) (-2779 ((|#1| $ (-1143) |#1|) NIL) ((|#1| $ (-1143)) 42)) (-2085 (($ (-634 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)))) NIL) (($) NIL)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) (((-763) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090)))) (((-763) (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL (|has| $ (-6 -4519)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-609 (-541))))) (-4287 (($ (-634 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)))) NIL)) (-2745 (((-850) $) 21)) (-3637 (($ $) 26)) (-2367 (($ (-634 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)))) NIL)) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 20)) (-1697 (((-763) $) 41 (|has| $ (-6 -4519))))) 
-(((-603 |#1|) (-13 (-366 (-390) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) (-1172 (-1143) |#1|) (-10 -8 (-6 -4519) (-15 -3380 ($ $)))) (-1090)) (T -603)) 
-((-3380 (*1 *1 *1) (-12 (-5 *1 (-603 *2)) (-4 *2 (-1090))))) 
-(-13 (-366 (-390) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) (-1172 (-1143) |#1|) (-10 -8 (-6 -4519) (-15 -3380 ($ $)))) 
-((-3109 (((-121) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) $) 15)) (-1946 (((-634 |#2|) $) 19)) (-3548 (((-121) |#2| $) 12))) 
-(((-604 |#1| |#2| |#3|) (-10 -8 (-15 -1946 ((-634 |#2|) |#1|)) (-15 -3548 ((-121) |#2| |#1|)) (-15 -3109 ((-121) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) |#1|))) (-605 |#2| |#3|) (-1090) (-1090)) (T -604)) 
-NIL 
-(-10 -8 (-15 -1946 ((-634 |#2|) |#1|)) (-15 -3548 ((-121) |#2| |#1|)) (-15 -3109 ((-121) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) |#1|))) 
-((-2447 (((-121) $ $) 18 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (-2510 (((-121) $ (-763)) 8)) (-3507 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 42 (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 52 (|has| $ (-6 -4519)))) (-2674 (((-3 |#2| "failed") |#1| $) 57)) (-2671 (($) 7 T CONST)) (-3924 (($ $) 55 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| $ (-6 -4519))))) (-3405 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 44 (|has| $ (-6 -4519))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 43 (|has| $ (-6 -4519))) (((-3 |#2| "failed") |#1| $) 58)) (-4328 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 54 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 51 (|has| $ (-6 -4519)))) (-3092 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 53 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| $ (-6 -4519)))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 50 (|has| $ (-6 -4519))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 49 (|has| $ (-6 -4519)))) (-4360 (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 30 (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) 9)) (-1979 (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 27 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 35)) (-2166 (((-121) $ (-763)) 10)) (-4487 (((-1143) $) 22 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (-1946 (((-634 |#1|) $) 59)) (-3548 (((-121) |#1| $) 60)) (-1890 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 36)) (-4450 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 37)) (-4022 (((-1108) $) 21 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (-3775 (((-3 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) "failed") (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 48)) (-1315 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 38)) (-1387 (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) 26 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) 25 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 24 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) 23 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-3171 (((-121) $ $) 14)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2085 (($) 46) (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) 45)) (-4168 (((-763) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 31 (|has| $ (-6 -4519))) (((-763) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 28 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-4278 (((-541) $) 56 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-609 (-541))))) (-4287 (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) 47)) (-2745 (((-850) $) 20 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (-2367 (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) 39)) (-1319 (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-3591 (((-3 $ "failed")) NIL (-2199 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3542 (((-1244 (-679 |#1|))) NIL (|has| |#2| (-419 |#1|))) (((-1244 (-679 |#1|)) (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-3818 (((-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-4490 (($) NIL T CONST)) (-3354 (((-3 (-2 (|:| |particular| $) (|:| -2588 (-634 $))) "failed")) NIL (-2199 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-2046 (((-3 $ "failed")) NIL (-2199 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-1524 (((-679 |#1|)) NIL (|has| |#2| (-419 |#1|))) (((-679 |#1|) (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-2467 ((|#1| $) NIL (|has| |#2| (-369 |#1|)))) (-2235 (((-679 |#1|) $) NIL (|has| |#2| (-419 |#1|))) (((-679 |#1|) $ (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-2812 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-1503 (((-1157 (-953 |#1|))) NIL (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-365))))) (-2815 (($ $ (-917)) NIL)) (-1509 ((|#1| $) NIL (|has| |#2| (-369 |#1|)))) (-3839 (((-1157 |#1|) $) NIL (-2199 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-2886 ((|#1|) NIL (|has| |#2| (-419 |#1|))) ((|#1| (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-3105 (((-1157 |#1|) $) NIL (|has| |#2| (-369 |#1|)))) (-1463 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-3899 (($ (-1244 |#1|)) NIL (|has| |#2| (-419 |#1|))) (($ (-1244 |#1|) (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-2902 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-2371 (((-917)) NIL (|has| |#2| (-369 |#1|)))) (-3375 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-3402 (($ $ (-917)) NIL)) (-4221 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-4463 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-3582 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-2587 (((-3 (-2 (|:| |particular| $) (|:| -2588 (-634 $))) "failed")) NIL (-2199 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-2061 (((-3 $ "failed")) NIL (-2199 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-4134 (((-679 |#1|)) NIL (|has| |#2| (-419 |#1|))) (((-679 |#1|) (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-2786 ((|#1| $) NIL (|has| |#2| (-369 |#1|)))) (-3147 (((-679 |#1|) $) NIL (|has| |#2| (-419 |#1|))) (((-679 |#1|) $ (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-1974 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-1730 (((-1157 (-953 |#1|))) NIL (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-365))))) (-4202 (($ $ (-917)) NIL)) (-4390 ((|#1| $) NIL (|has| |#2| (-369 |#1|)))) (-3364 (((-1157 |#1|) $) NIL (-2199 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-2060 ((|#1|) NIL (|has| |#2| (-419 |#1|))) ((|#1| (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-3114 (((-1157 |#1|) $) NIL (|has| |#2| (-369 |#1|)))) (-3487 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-1893 (((-1143) $) NIL)) (-2153 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-2889 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-1852 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-4025 (((-1108) $) NIL)) (-3636 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-2781 ((|#1| $ (-568)) NIL (|has| |#2| (-419 |#1|)))) (-1656 (((-679 |#1|) (-1244 $)) NIL (|has| |#2| (-419 |#1|))) (((-1244 |#1|) $) NIL (|has| |#2| (-419 |#1|))) (((-679 |#1|) (-1244 $) (-1244 $)) NIL (|has| |#2| (-369 |#1|))) (((-1244 |#1|) $ (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-4280 (($ (-1244 |#1|)) NIL (|has| |#2| (-419 |#1|))) (((-1244 |#1|) $) NIL (|has| |#2| (-419 |#1|)))) (-2155 (((-634 (-953 |#1|))) NIL (|has| |#2| (-419 |#1|))) (((-634 (-953 |#1|)) (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-3985 (($ $ $) NIL)) (-3441 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-2747 (((-850) $) NIL) ((|#2| $) 21) (($ |#2|) 22)) (-2588 (((-1244 $)) NIL (|has| |#2| (-419 |#1|)))) (-2657 (((-634 (-1244 |#1|))) NIL (-2199 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-2007 (($ $ $ $) NIL)) (-3964 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-3828 (($ (-679 |#1|) $) NIL (|has| |#2| (-419 |#1|)))) (-3911 (($ $ $) NIL)) (-2435 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-2984 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-3579 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-3058 (($) NIL T CONST)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) 24)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 20) (($ $ |#1|) 19) (($ |#1| $) NIL))) 
+(((-602 |#1| |#2|) (-13 (-736 |#1|) (-608 |#2|) (-10 -8 (-15 -2747 ($ |#2|)) (IF (|has| |#2| (-419 |#1|)) (-6 (-419 |#1|)) |noBranch|) (IF (|has| |#2| (-369 |#1|)) (-6 (-369 |#1|)) |noBranch|))) (-172) (-736 |#1|)) (T -602)) 
+((-2747 (*1 *1 *2) (-12 (-4 *3 (-172)) (-5 *1 (-602 *3 *2)) (-4 *2 (-736 *3))))) 
+(-13 (-736 |#1|) (-608 |#2|) (-10 -8 (-15 -2747 ($ |#2|)) (IF (|has| |#2| (-419 |#1|)) (-6 (-419 |#1|)) |noBranch|) (IF (|has| |#2| (-369 |#1|)) (-6 (-369 |#1|)) |noBranch|))) 
+((-2449 (((-121) $ $) NIL)) (-3637 (((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) $ (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) 33)) (-2988 (($ (-634 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)))) NIL) (($) NIL)) (-2481 (((-1249) $ (-1143) (-1143)) NIL (|has| $ (-6 -4522)))) (-1667 (((-121) $ (-763)) NIL)) (-2438 ((|#1| $ (-1143) |#1|) 43)) (-3963 (($ (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL (|has| $ (-6 -4521)))) (-2678 (((-3 |#1| "failed") (-1143) $) 46)) (-4490 (($) NIL T CONST)) (-1672 (($ $ (-1143)) 25)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090))))) (-1568 (((-3 |#1| "failed") (-1143) $) 47) (($ (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL (|has| $ (-6 -4521))) (($ (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) $) NIL (|has| $ (-6 -4521)))) (-4330 (($ (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL (|has| $ (-6 -4521))) (($ (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090))))) (-3094 (((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL (|has| $ (-6 -4521))) (((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $ (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) NIL (|has| $ (-6 -4521))) (((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $ (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090))))) (-4379 (((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) $) 32)) (-1292 ((|#1| $ (-1143) |#1|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-1143)) NIL)) (-3317 (((-634 |#1|) $) NIL (|has| $ (-6 -4521))) (((-634 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL (|has| $ (-6 -4521)))) (-1444 (($ $) 48)) (-2133 (($ (-390)) 23) (($ (-390) (-1143)) 22)) (-3393 (((-390) $) 34)) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-1143) $) NIL (|has| (-1143) (-842)))) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521))) (((-634 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) (((-121) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090))))) (-3631 (((-1143) $) NIL (|has| (-1143) (-842)))) (-2253 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4522))) (($ (-1 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1|) $) NIL) (($ (-1 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL)) (-4253 (((-634 (-1143)) $) 39)) (-2807 (((-121) (-1143) $) NIL)) (-4249 (((-1143) $) 35)) (-2580 (((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) $) NIL)) (-1708 (($ (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) $) NIL)) (-3948 (((-634 (-1143)) $) NIL)) (-2916 (((-121) (-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-3919 (((-1249) $) NIL)) (-3877 ((|#1| $) NIL (|has| (-1143) (-842)))) (-2712 (((-3 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) "failed") (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL)) (-2490 (($ $ |#1|) NIL (|has| $ (-6 -4522)))) (-3403 (((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) $) NIL)) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) (-634 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)))) NIL (-12 (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-303 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)))) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090)))) (($ $ (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) NIL (-12 (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-303 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)))) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090)))) (($ $ (-288 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)))) NIL (-12 (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-303 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)))) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090)))) (($ $ (-634 (-288 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))))) NIL (-12 (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-303 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)))) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) 37)) (-2781 ((|#1| $ (-1143) |#1|) NIL) ((|#1| $ (-1143)) 42)) (-3132 (($ (-634 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)))) NIL) (($) NIL)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) (((-763) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090)))) (((-763) (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL (|has| $ (-6 -4521)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-609 (-541))))) (-4289 (($ (-634 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)))) NIL)) (-2747 (((-850) $) 21)) (-3171 (($ $) 26)) (-4074 (($ (-634 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)))) NIL)) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 20)) (-1699 (((-763) $) 41 (|has| $ (-6 -4521))))) 
+(((-603 |#1|) (-13 (-366 (-390) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) (-1172 (-1143) |#1|) (-10 -8 (-6 -4521) (-15 -1444 ($ $)))) (-1090)) (T -603)) 
+((-1444 (*1 *1 *1) (-12 (-5 *1 (-603 *2)) (-4 *2 (-1090))))) 
+(-13 (-366 (-390) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) (-1172 (-1143) |#1|) (-10 -8 (-6 -4521) (-15 -1444 ($ $)))) 
+((-2551 (((-121) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) $) 15)) (-4253 (((-634 |#2|) $) 19)) (-2807 (((-121) |#2| $) 12))) 
+(((-604 |#1| |#2| |#3|) (-10 -8 (-15 -4253 ((-634 |#2|) |#1|)) (-15 -2807 ((-121) |#2| |#1|)) (-15 -2551 ((-121) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) |#1|))) (-605 |#2| |#3|) (-1090) (-1090)) (T -604)) 
+NIL 
+(-10 -8 (-15 -4253 ((-634 |#2|) |#1|)) (-15 -2807 ((-121) |#2| |#1|)) (-15 -2551 ((-121) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) |#1|))) 
+((-2449 (((-121) $ $) 18 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (-1667 (((-121) $ (-763)) 8)) (-3963 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 42 (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 52 (|has| $ (-6 -4521)))) (-2678 (((-3 |#2| "failed") |#1| $) 57)) (-4490 (($) 7 T CONST)) (-3926 (($ $) 55 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| $ (-6 -4521))))) (-1568 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 44 (|has| $ (-6 -4521))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 43 (|has| $ (-6 -4521))) (((-3 |#2| "failed") |#1| $) 58)) (-4330 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 54 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 51 (|has| $ (-6 -4521)))) (-3094 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 53 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| $ (-6 -4521)))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 50 (|has| $ (-6 -4521))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 49 (|has| $ (-6 -4521)))) (-3317 (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 30 (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) 9)) (-4406 (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 27 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 35)) (-3796 (((-121) $ (-763)) 10)) (-1893 (((-1143) $) 22 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (-4253 (((-634 |#1|) $) 59)) (-2807 (((-121) |#1| $) 60)) (-2580 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 36)) (-1708 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 37)) (-4025 (((-1108) $) 21 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (-2712 (((-3 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) "failed") (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 48)) (-3403 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 38)) (-3951 (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) 26 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) 25 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 24 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) 23 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-1702 (((-121) $ $) 14)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-3132 (($) 46) (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) 45)) (-4170 (((-763) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 31 (|has| $ (-6 -4521))) (((-763) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 28 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-4280 (((-541) $) 56 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-609 (-541))))) (-4289 (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) 47)) (-2747 (((-850) $) 20 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (-4074 (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) 39)) (-3437 (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-605 |#1| |#2|) (-1275) (-1090) (-1090)) (T -605)) 
-((-3548 (*1 *2 *3 *1) (-12 (-4 *1 (-605 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-5 *2 (-121)))) (-1946 (*1 *2 *1) (-12 (-4 *1 (-605 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-5 *2 (-634 *3)))) (-3405 (*1 *2 *3 *1) (|partial| -12 (-4 *1 (-605 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090)))) (-2674 (*1 *2 *3 *1) (|partial| -12 (-4 *1 (-605 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090))))) 
-(-13 (-221 (-2 (|:| -3649 |t#1|) (|:| -4083 |t#2|))) (-10 -8 (-15 -3548 ((-121) |t#1| $)) (-15 -1946 ((-634 |t#1|) $)) (-15 -3405 ((-3 |t#2| "failed") |t#1| $)) (-15 -2674 ((-3 |t#2| "failed") |t#1| $)))) 
-(((-39) . T) ((-111 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-105) |has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) ((-608 (-850)) |has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) ((-154 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-609 (-541)) |has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-609 (-541))) ((-221 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-227 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) -12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))) ((-499 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-523 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) -12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))) ((-1090) |has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) ((-1195) . T)) 
-((-2384 (((-607 |#2|) |#1|) 15)) (-3564 (((-3 |#1| "failed") (-607 |#2|)) 19))) 
-(((-606 |#1| |#2|) (-10 -7 (-15 -2384 ((-607 |#2|) |#1|)) (-15 -3564 ((-3 |#1| "failed") (-607 |#2|)))) (-842) (-842)) (T -606)) 
-((-3564 (*1 *2 *3) (|partial| -12 (-5 *3 (-607 *4)) (-4 *4 (-842)) (-4 *2 (-842)) (-5 *1 (-606 *2 *4)))) (-2384 (*1 *2 *3) (-12 (-5 *2 (-607 *4)) (-5 *1 (-606 *3 *4)) (-4 *3 (-842)) (-4 *4 (-842))))) 
-(-10 -7 (-15 -2384 ((-607 |#2|) |#1|)) (-15 -3564 ((-3 |#1| "failed") (-607 |#2|)))) 
-((-2447 (((-121) $ $) NIL)) (-3801 (((-3 (-1161) "failed") $) 36)) (-3138 (((-1249) $ (-763)) 26)) (-2764 (((-763) $) 25)) (-3488 (((-123) $) 12)) (-3391 (((-1161) $) 20)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-4487 (((-1143) $) NIL)) (-3443 (($ (-123) (-634 |#1|) (-763)) 30) (($ (-1161)) 31)) (-2841 (((-121) $ (-123)) 18) (((-121) $ (-1161)) 16)) (-2961 (((-763) $) 22)) (-4022 (((-1108) $) NIL)) (-4278 (((-887 (-568)) $) 69 (|has| |#1| (-609 (-887 (-568))))) (((-887 (-381)) $) 75 (|has| |#1| (-609 (-887 (-381))))) (((-541) $) 62 (|has| |#1| (-609 (-541))))) (-2745 (((-850) $) 51)) (-3256 (((-634 |#1|) $) 24)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 39)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 40))) 
-(((-607 |#1|) (-13 (-138) (-879 |#1|) (-10 -8 (-15 -3391 ((-1161) $)) (-15 -3488 ((-123) $)) (-15 -3256 ((-634 |#1|) $)) (-15 -2961 ((-763) $)) (-15 -3443 ($ (-123) (-634 |#1|) (-763))) (-15 -3443 ($ (-1161))) (-15 -3801 ((-3 (-1161) "failed") $)) (-15 -2841 ((-121) $ (-123))) (-15 -2841 ((-121) $ (-1161))) (IF (|has| |#1| (-609 (-541))) (-6 (-609 (-541))) |noBranch|))) (-842)) (T -607)) 
-((-3391 (*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-607 *3)) (-4 *3 (-842)))) (-3488 (*1 *2 *1) (-12 (-5 *2 (-123)) (-5 *1 (-607 *3)) (-4 *3 (-842)))) (-3256 (*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-607 *3)) (-4 *3 (-842)))) (-2961 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-607 *3)) (-4 *3 (-842)))) (-3443 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-123)) (-5 *3 (-634 *5)) (-5 *4 (-763)) (-4 *5 (-842)) (-5 *1 (-607 *5)))) (-3443 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-607 *3)) (-4 *3 (-842)))) (-3801 (*1 *2 *1) (|partial| -12 (-5 *2 (-1161)) (-5 *1 (-607 *3)) (-4 *3 (-842)))) (-2841 (*1 *2 *1 *3) (-12 (-5 *3 (-123)) (-5 *2 (-121)) (-5 *1 (-607 *4)) (-4 *4 (-842)))) (-2841 (*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-121)) (-5 *1 (-607 *4)) (-4 *4 (-842))))) 
-(-13 (-138) (-879 |#1|) (-10 -8 (-15 -3391 ((-1161) $)) (-15 -3488 ((-123) $)) (-15 -3256 ((-634 |#1|) $)) (-15 -2961 ((-763) $)) (-15 -3443 ($ (-123) (-634 |#1|) (-763))) (-15 -3443 ($ (-1161))) (-15 -3801 ((-3 (-1161) "failed") $)) (-15 -2841 ((-121) $ (-123))) (-15 -2841 ((-121) $ (-1161))) (IF (|has| |#1| (-609 (-541))) (-6 (-609 (-541))) |noBranch|))) 
-((-2745 ((|#1| $) 6))) 
+((-2807 (*1 *2 *3 *1) (-12 (-4 *1 (-605 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-5 *2 (-121)))) (-4253 (*1 *2 *1) (-12 (-4 *1 (-605 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-5 *2 (-634 *3)))) (-1568 (*1 *2 *3 *1) (|partial| -12 (-4 *1 (-605 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090)))) (-2678 (*1 *2 *3 *1) (|partial| -12 (-4 *1 (-605 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090))))) 
+(-13 (-221 (-2 (|:| -3651 |t#1|) (|:| -4085 |t#2|))) (-10 -8 (-15 -2807 ((-121) |t#1| $)) (-15 -4253 ((-634 |t#1|) $)) (-15 -1568 ((-3 |t#2| "failed") |t#1| $)) (-15 -2678 ((-3 |t#2| "failed") |t#1| $)))) 
+(((-39) . T) ((-111 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-105) |has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) ((-608 (-850)) |has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) ((-154 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-609 (-541)) |has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-609 (-541))) ((-221 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-227 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) -12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))) ((-499 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-523 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) -12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))) ((-1090) |has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) ((-1195) . T)) 
+((-2195 (((-607 |#2|) |#1|) 15)) (-2868 (((-3 |#1| "failed") (-607 |#2|)) 19))) 
+(((-606 |#1| |#2|) (-10 -7 (-15 -2195 ((-607 |#2|) |#1|)) (-15 -2868 ((-3 |#1| "failed") (-607 |#2|)))) (-842) (-842)) (T -606)) 
+((-2868 (*1 *2 *3) (|partial| -12 (-5 *3 (-607 *4)) (-4 *4 (-842)) (-4 *2 (-842)) (-5 *1 (-606 *2 *4)))) (-2195 (*1 *2 *3) (-12 (-5 *2 (-607 *4)) (-5 *1 (-606 *3 *4)) (-4 *3 (-842)) (-4 *4 (-842))))) 
+(-10 -7 (-15 -2195 ((-607 |#2|) |#1|)) (-15 -2868 ((-3 |#1| "failed") (-607 |#2|)))) 
+((-2449 (((-121) $ $) NIL)) (-1688 (((-3 (-1161) "failed") $) 36)) (-2704 (((-1249) $ (-763)) 26)) (-2766 (((-763) $) 25)) (-3842 (((-123) $) 12)) (-3393 (((-1161) $) 20)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-1893 (((-1143) $) NIL)) (-3446 (($ (-123) (-634 |#1|) (-763)) 30) (($ (-1161)) 31)) (-3910 (((-121) $ (-123)) 18) (((-121) $ (-1161)) 16)) (-2963 (((-763) $) 22)) (-4025 (((-1108) $) NIL)) (-4280 (((-887 (-568)) $) 69 (|has| |#1| (-609 (-887 (-568))))) (((-887 (-381)) $) 75 (|has| |#1| (-609 (-887 (-381))))) (((-541) $) 62 (|has| |#1| (-609 (-541))))) (-2747 (((-850) $) 51)) (-2014 (((-634 |#1|) $) 24)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 39)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 40))) 
+(((-607 |#1|) (-13 (-138) (-879 |#1|) (-10 -8 (-15 -3393 ((-1161) $)) (-15 -3842 ((-123) $)) (-15 -2014 ((-634 |#1|) $)) (-15 -2963 ((-763) $)) (-15 -3446 ($ (-123) (-634 |#1|) (-763))) (-15 -3446 ($ (-1161))) (-15 -1688 ((-3 (-1161) "failed") $)) (-15 -3910 ((-121) $ (-123))) (-15 -3910 ((-121) $ (-1161))) (IF (|has| |#1| (-609 (-541))) (-6 (-609 (-541))) |noBranch|))) (-842)) (T -607)) 
+((-3393 (*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-607 *3)) (-4 *3 (-842)))) (-3842 (*1 *2 *1) (-12 (-5 *2 (-123)) (-5 *1 (-607 *3)) (-4 *3 (-842)))) (-2014 (*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-607 *3)) (-4 *3 (-842)))) (-2963 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-607 *3)) (-4 *3 (-842)))) (-3446 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-123)) (-5 *3 (-634 *5)) (-5 *4 (-763)) (-4 *5 (-842)) (-5 *1 (-607 *5)))) (-3446 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-607 *3)) (-4 *3 (-842)))) (-1688 (*1 *2 *1) (|partial| -12 (-5 *2 (-1161)) (-5 *1 (-607 *3)) (-4 *3 (-842)))) (-3910 (*1 *2 *1 *3) (-12 (-5 *3 (-123)) (-5 *2 (-121)) (-5 *1 (-607 *4)) (-4 *4 (-842)))) (-3910 (*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-121)) (-5 *1 (-607 *4)) (-4 *4 (-842))))) 
+(-13 (-138) (-879 |#1|) (-10 -8 (-15 -3393 ((-1161) $)) (-15 -3842 ((-123) $)) (-15 -2014 ((-634 |#1|) $)) (-15 -2963 ((-763) $)) (-15 -3446 ($ (-123) (-634 |#1|) (-763))) (-15 -3446 ($ (-1161))) (-15 -1688 ((-3 (-1161) "failed") $)) (-15 -3910 ((-121) $ (-123))) (-15 -3910 ((-121) $ (-1161))) (IF (|has| |#1| (-609 (-541))) (-6 (-609 (-541))) |noBranch|))) 
+((-2747 ((|#1| $) 6))) 
 (((-608 |#1|) (-1275) (-1195)) (T -608)) 
-((-2745 (*1 *2 *1) (-12 (-4 *1 (-608 *2)) (-4 *2 (-1195))))) 
-(-13 (-10 -8 (-15 -2745 (|t#1| $)))) 
-((-4278 ((|#1| $) 6))) 
+((-2747 (*1 *2 *1) (-12 (-4 *1 (-608 *2)) (-4 *2 (-1195))))) 
+(-13 (-10 -8 (-15 -2747 (|t#1| $)))) 
+((-4280 ((|#1| $) 6))) 
 (((-609 |#1|) (-1275) (-1195)) (T -609)) 
-((-4278 (*1 *2 *1) (-12 (-4 *1 (-609 *2)) (-4 *2 (-1195))))) 
-(-13 (-10 -8 (-15 -4278 (|t#1| $)))) 
-((-3156 (((-3 (-1157 (-409 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|) (-1 (-420 |#2|) |#2|)) 13) (((-3 (-1157 (-409 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|)) 14))) 
-(((-610 |#1| |#2|) (-10 -7 (-15 -3156 ((-3 (-1157 (-409 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|))) (-15 -3156 ((-3 (-1157 (-409 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|) (-1 (-420 |#2|) |#2|)))) (-13 (-150) (-27) (-1037 (-568)) (-1037 (-409 (-568)))) (-1219 |#1|)) (T -610)) 
-((-3156 (*1 *2 *3 *3 *3 *4) (|partial| -12 (-5 *4 (-1 (-420 *6) *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-150) (-27) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-1157 (-409 *6))) (-5 *1 (-610 *5 *6)) (-5 *3 (-409 *6)))) (-3156 (*1 *2 *3 *3 *3) (|partial| -12 (-4 *4 (-13 (-150) (-27) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-1157 (-409 *5))) (-5 *1 (-610 *4 *5)) (-5 *3 (-409 *5))))) 
-(-10 -7 (-15 -3156 ((-3 (-1157 (-409 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|))) (-15 -3156 ((-3 (-1157 (-409 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|) (-1 (-420 |#2|) |#2|)))) 
-((-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#2|) 10))) 
-(((-611 |#1| |#2|) (-10 -8 (-15 -2745 (|#1| |#2|)) (-15 -2745 (|#1| (-568))) (-15 -2745 ((-850) |#1|))) (-612 |#2|) (-1047)) (T -611)) 
-NIL 
-(-10 -8 (-15 -2745 (|#1| |#2|)) (-15 -2745 (|#1| (-568))) (-15 -2745 ((-850) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-2925 (((-3 $ "failed") $) 33)) (-2735 (((-121) $) 30)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 35)) (-4078 (((-763)) 28)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ |#1| $) 36))) 
+((-4280 (*1 *2 *1) (-12 (-4 *1 (-609 *2)) (-4 *2 (-1195))))) 
+(-13 (-10 -8 (-15 -4280 (|t#1| $)))) 
+((-2762 (((-3 (-1157 (-409 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|) (-1 (-420 |#2|) |#2|)) 13) (((-3 (-1157 (-409 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|)) 14))) 
+(((-610 |#1| |#2|) (-10 -7 (-15 -2762 ((-3 (-1157 (-409 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|))) (-15 -2762 ((-3 (-1157 (-409 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|) (-1 (-420 |#2|) |#2|)))) (-13 (-150) (-27) (-1037 (-568)) (-1037 (-409 (-568)))) (-1219 |#1|)) (T -610)) 
+((-2762 (*1 *2 *3 *3 *3 *4) (|partial| -12 (-5 *4 (-1 (-420 *6) *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-150) (-27) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-1157 (-409 *6))) (-5 *1 (-610 *5 *6)) (-5 *3 (-409 *6)))) (-2762 (*1 *2 *3 *3 *3) (|partial| -12 (-4 *4 (-13 (-150) (-27) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-1157 (-409 *5))) (-5 *1 (-610 *4 *5)) (-5 *3 (-409 *5))))) 
+(-10 -7 (-15 -2762 ((-3 (-1157 (-409 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|))) (-15 -2762 ((-3 (-1157 (-409 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|) (-1 (-420 |#2|) |#2|)))) 
+((-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#2|) 10))) 
+(((-611 |#1| |#2|) (-10 -8 (-15 -2747 (|#1| |#2|)) (-15 -2747 (|#1| (-568))) (-15 -2747 ((-850) |#1|))) (-612 |#2|) (-1047)) (T -611)) 
+NIL 
+(-10 -8 (-15 -2747 (|#1| |#2|)) (-15 -2747 (|#1| (-568))) (-15 -2747 ((-850) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-2902 (((-3 $ "failed") $) 33)) (-1598 (((-121) $) 30)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 35)) (-3425 (((-763)) 28)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ |#1| $) 36))) 
 (((-612 |#1|) (-1275) (-1047)) (T -612)) 
-((-2745 (*1 *1 *2) (-12 (-4 *1 (-612 *2)) (-4 *2 (-1047))))) 
-(-13 (-1047) (-637 |t#1|) (-10 -8 (-15 -2745 ($ |t#1|)))) 
+((-2747 (*1 *1 *2) (-12 (-4 *1 (-612 *2)) (-4 *2 (-1047))))) 
+(-13 (-1047) (-637 |t#1|) (-10 -8 (-15 -2747 ($ |t#1|)))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 |#1|) . T) ((-637 $) . T) ((-716) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-3662 (((-568) $) NIL (|has| |#1| (-840)))) (-2671 (($) NIL T CONST)) (-2925 (((-3 $ "failed") $) NIL)) (-2033 (((-121) $) NIL (|has| |#1| (-840)))) (-2735 (((-121) $) NIL)) (-2317 ((|#1| $) 13)) (-2245 (((-121) $) NIL (|has| |#1| (-840)))) (-2521 (($ $ $) NIL (|has| |#1| (-840)))) (-3268 (($ $ $) NIL (|has| |#1| (-840)))) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2324 ((|#3| $) 15)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#2|) NIL)) (-4078 (((-763)) 20)) (-2897 (($ $) NIL (|has| |#1| (-840)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) 12 T CONST)) (-1751 (((-121) $ $) NIL (|has| |#1| (-840)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-840)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| |#1| (-840)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-840)))) (-1779 (($ $ |#3|) NIL) (($ |#1| |#3|) 11)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 17) (($ $ |#2|) NIL) (($ |#2| $) NIL))) 
-(((-613 |#1| |#2| |#3|) (-13 (-43 |#2|) (-10 -8 (IF (|has| |#1| (-840)) (-6 (-840)) |noBranch|) (-15 -1779 ($ $ |#3|)) (-15 -1779 ($ |#1| |#3|)) (-15 -2317 (|#1| $)) (-15 -2324 (|#3| $)))) (-43 |#2|) (-172) (|SubsetCategory| (-716) |#2|)) (T -613)) 
-((-1779 (*1 *1 *1 *2) (-12 (-4 *4 (-172)) (-5 *1 (-613 *3 *4 *2)) (-4 *3 (-43 *4)) (-4 *2 (|SubsetCategory| (-716) *4)))) (-1779 (*1 *1 *2 *3) (-12 (-4 *4 (-172)) (-5 *1 (-613 *2 *4 *3)) (-4 *2 (-43 *4)) (-4 *3 (|SubsetCategory| (-716) *4)))) (-2317 (*1 *2 *1) (-12 (-4 *3 (-172)) (-4 *2 (-43 *3)) (-5 *1 (-613 *2 *3 *4)) (-4 *4 (|SubsetCategory| (-716) *3)))) (-2324 (*1 *2 *1) (-12 (-4 *4 (-172)) (-4 *2 (|SubsetCategory| (-716) *4)) (-5 *1 (-613 *3 *4 *2)) (-4 *3 (-43 *4))))) 
-(-13 (-43 |#2|) (-10 -8 (IF (|has| |#1| (-840)) (-6 (-840)) |noBranch|) (-15 -1779 ($ $ |#3|)) (-15 -1779 ($ |#1| |#3|)) (-15 -2317 (|#1| $)) (-15 -2324 (|#3| $)))) 
-((-3607 ((|#2| |#2| (-1161) (-1161)) 18))) 
-(((-614 |#1| |#2|) (-10 -7 (-15 -3607 (|#2| |#2| (-1161) (-1161)))) (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568))) (-13 (-1181) (-959) (-29 |#1|))) (T -614)) 
-((-3607 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-614 *4 *2)) (-4 *2 (-13 (-1181) (-959) (-29 *4)))))) 
-(-10 -7 (-15 -3607 (|#2| |#2| (-1161) (-1161)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 52)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-2462 ((|#1| $) 49)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1497 (((-121) $ $) NIL (|has| |#1| (-365)))) (-1619 (((-2 (|:| -2848 $) (|:| -4367 (-409 |#2|))) (-409 |#2|)) 95 (|has| |#1| (-365)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 83) (((-3 |#2| "failed") $) 80)) (-2854 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) NIL) ((|#2| $) NIL)) (-2401 (($ $ $) NIL (|has| |#1| (-365)))) (-2114 (($ $) 24)) (-2925 (((-3 $ "failed") $) 74)) (-2412 (($ $ $) NIL (|has| |#1| (-365)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-4477 (((-568) $) 19)) (-2735 (((-121) $) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-3921 (((-121) $) 36)) (-2047 (($ |#1| (-568)) 21)) (-2102 ((|#1| $) 51)) (-2495 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-365)))) (-2721 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) 85 (|has| |#1| (-365)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 98 (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-365)))) (-2595 (((-3 $ "failed") $ $) 78)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-2709 (((-763) $) 97 (|has| |#1| (-365)))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 96 (|has| |#1| (-365)))) (-4189 (($ $ (-1 |#2| |#2|)) 65) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-763)) NIL (|has| |#2| (-225))) (($ $) NIL (|has| |#2| (-225)))) (-3206 (((-568) $) 34)) (-4278 (((-409 |#2|) $) 42)) (-2745 (((-850) $) 61) (($ (-568)) 32) (($ $) NIL) (($ (-409 (-568))) NIL (|has| |#1| (-1037 (-409 (-568))))) (($ |#1|) 31) (($ |#2|) 22)) (-2604 ((|#1| $ (-568)) 62)) (-4371 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-4078 (((-763)) 29)) (-1826 (((-121) $ $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 9 T CONST)) (-1556 (($) 12 T CONST)) (-3190 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-763)) NIL (|has| |#2| (-225))) (($ $) NIL (|has| |#2| (-225)))) (-1717 (((-121) $ $) 17)) (-1773 (($ $) 46) (($ $ $) NIL)) (-1767 (($ $ $) 75)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 26) (($ $ $) 44))) 
-(((-615 |#1| |#2|) (-13 (-223 |#2|) (-558) (-609 (-409 |#2|)) (-413 |#1|) (-1037 |#2|) (-10 -8 (-15 -3921 ((-121) $)) (-15 -3206 ((-568) $)) (-15 -4477 ((-568) $)) (-15 -2114 ($ $)) (-15 -2102 (|#1| $)) (-15 -2462 (|#1| $)) (-15 -2604 (|#1| $ (-568))) (-15 -2047 ($ |#1| (-568))) (IF (|has| |#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |#1| (-365)) (PROGN (-6 (-301)) (-15 -1619 ((-2 (|:| -2848 $) (|:| -4367 (-409 |#2|))) (-409 |#2|)))) |noBranch|))) (-558) (-1219 |#1|)) (T -615)) 
-((-3921 (*1 *2 *1) (-12 (-4 *3 (-558)) (-5 *2 (-121)) (-5 *1 (-615 *3 *4)) (-4 *4 (-1219 *3)))) (-3206 (*1 *2 *1) (-12 (-4 *3 (-558)) (-5 *2 (-568)) (-5 *1 (-615 *3 *4)) (-4 *4 (-1219 *3)))) (-4477 (*1 *2 *1) (-12 (-4 *3 (-558)) (-5 *2 (-568)) (-5 *1 (-615 *3 *4)) (-4 *4 (-1219 *3)))) (-2114 (*1 *1 *1) (-12 (-4 *2 (-558)) (-5 *1 (-615 *2 *3)) (-4 *3 (-1219 *2)))) (-2102 (*1 *2 *1) (-12 (-4 *2 (-558)) (-5 *1 (-615 *2 *3)) (-4 *3 (-1219 *2)))) (-2462 (*1 *2 *1) (-12 (-4 *2 (-558)) (-5 *1 (-615 *2 *3)) (-4 *3 (-1219 *2)))) (-2604 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *2 (-558)) (-5 *1 (-615 *2 *4)) (-4 *4 (-1219 *2)))) (-2047 (*1 *1 *2 *3) (-12 (-5 *3 (-568)) (-4 *2 (-558)) (-5 *1 (-615 *2 *4)) (-4 *4 (-1219 *2)))) (-1619 (*1 *2 *3) (-12 (-4 *4 (-365)) (-4 *4 (-558)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| -2848 (-615 *4 *5)) (|:| -4367 (-409 *5)))) (-5 *1 (-615 *4 *5)) (-5 *3 (-409 *5))))) 
-(-13 (-223 |#2|) (-558) (-609 (-409 |#2|)) (-413 |#1|) (-1037 |#2|) (-10 -8 (-15 -3921 ((-121) $)) (-15 -3206 ((-568) $)) (-15 -4477 ((-568) $)) (-15 -2114 ($ $)) (-15 -2102 (|#1| $)) (-15 -2462 (|#1| $)) (-15 -2604 (|#1| $ (-568))) (-15 -2047 ($ |#1| (-568))) (IF (|has| |#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |#1| (-365)) (PROGN (-6 (-301)) (-15 -1619 ((-2 (|:| -2848 $) (|:| -4367 (-409 |#2|))) (-409 |#2|)))) |noBranch|))) 
-((-2415 (((-634 |#6|) (-634 |#4|) (-121)) 46)) (-1918 ((|#6| |#6|) 39))) 
-(((-616 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -1918 (|#6| |#6|)) (-15 -2415 ((-634 |#6|) (-634 |#4|) (-121)))) (-453) (-788) (-842) (-1061 |#1| |#2| |#3|) (-1066 |#1| |#2| |#3| |#4|) (-1099 |#1| |#2| |#3| |#4|)) (T -616)) 
-((-2415 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 *10)) (-5 *1 (-616 *5 *6 *7 *8 *9 *10)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *10 (-1099 *5 *6 *7 *8)))) (-1918 (*1 *2 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *1 (-616 *3 *4 *5 *6 *7 *2)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *2 (-1099 *3 *4 *5 *6))))) 
-(-10 -7 (-15 -1918 (|#6| |#6|)) (-15 -2415 ((-634 |#6|) (-634 |#4|) (-121)))) 
-((-2756 (((-121) |#3| (-763) (-634 |#3|)) 22)) (-3875 (((-3 (-2 (|:| |polfac| (-634 |#4|)) (|:| |correct| |#3|) (|:| |corrfact| (-634 (-1157 |#3|)))) "failed") |#3| (-634 (-1157 |#3|)) (-2 (|:| |contp| |#3|) (|:| -3276 (-634 (-2 (|:| |irr| |#4|) (|:| -3959 (-568)))))) (-634 |#3|) (-634 |#1|) (-634 |#3|)) 51))) 
-(((-617 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2756 ((-121) |#3| (-763) (-634 |#3|))) (-15 -3875 ((-3 (-2 (|:| |polfac| (-634 |#4|)) (|:| |correct| |#3|) (|:| |corrfact| (-634 (-1157 |#3|)))) "failed") |#3| (-634 (-1157 |#3|)) (-2 (|:| |contp| |#3|) (|:| -3276 (-634 (-2 (|:| |irr| |#4|) (|:| -3959 (-568)))))) (-634 |#3|) (-634 |#1|) (-634 |#3|)))) (-842) (-788) (-301) (-950 |#3| |#2| |#1|)) (T -617)) 
-((-3875 (*1 *2 *3 *4 *5 *6 *7 *6) (|partial| -12 (-5 *5 (-2 (|:| |contp| *3) (|:| -3276 (-634 (-2 (|:| |irr| *10) (|:| -3959 (-568))))))) (-5 *6 (-634 *3)) (-5 *7 (-634 *8)) (-4 *8 (-842)) (-4 *3 (-301)) (-4 *10 (-950 *3 *9 *8)) (-4 *9 (-788)) (-5 *2 (-2 (|:| |polfac| (-634 *10)) (|:| |correct| *3) (|:| |corrfact| (-634 (-1157 *3))))) (-5 *1 (-617 *8 *9 *3 *10)) (-5 *4 (-634 (-1157 *3))))) (-2756 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-763)) (-5 *5 (-634 *3)) (-4 *3 (-301)) (-4 *6 (-842)) (-4 *7 (-788)) (-5 *2 (-121)) (-5 *1 (-617 *6 *7 *3 *8)) (-4 *8 (-950 *3 *7 *6))))) 
-(-10 -7 (-15 -2756 ((-121) |#3| (-763) (-634 |#3|))) (-15 -3875 ((-3 (-2 (|:| |polfac| (-634 |#4|)) (|:| |correct| |#3|) (|:| |corrfact| (-634 (-1157 |#3|)))) "failed") |#3| (-634 (-1157 |#3|)) (-2 (|:| |contp| |#3|) (|:| -3276 (-634 (-2 (|:| |irr| |#4|) (|:| -3959 (-568)))))) (-634 |#3|) (-634 |#1|) (-634 |#3|)))) 
-((-2447 (((-121) $ $) NIL)) (-3595 (((-634 |#1|) $) NIL)) (-2671 (($) NIL T CONST)) (-2925 (((-3 $ "failed") $) NIL)) (-2735 (((-121) $) NIL)) (-2407 (($ $) 67)) (-4416 (((-656 |#1| |#2|) $) 52)) (-4297 (((-634 (-2 (|:| |k| (-888 |#1|)) (|:| |c| |#2|))) $) 36)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) 70)) (-2831 (((-634 (-288 |#2|)) $ $) 33)) (-4022 (((-1108) $) NIL)) (-1892 (($ (-656 |#1| |#2|)) 48)) (-1458 (($ $ $) NIL)) (-2353 (($ $ $) NIL)) (-2745 (((-850) $) 58) (((-1257 |#1| |#2|) $) NIL) (((-1262 |#1| |#2|) $) 66)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-1556 (($) 53 T CONST)) (-2088 (((-634 (-2 (|:| |k| (-663 |#1|)) (|:| |c| |#2|))) $) 31)) (-2759 (((-634 (-656 |#1| |#2|)) (-634 |#1|)) 65)) (-1717 (((-121) $ $) 54)) (-1779 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ $ $) 44))) 
-(((-618 |#1| |#2| |#3|) (-13 (-478) (-10 -8 (-15 -1892 ($ (-656 |#1| |#2|))) (-15 -4416 ((-656 |#1| |#2|) $)) (-15 -4297 ((-634 (-2 (|:| |k| (-888 |#1|)) (|:| |c| |#2|))) $)) (-15 -2745 ((-1257 |#1| |#2|) $)) (-15 -2745 ((-1262 |#1| |#2|) $)) (-15 -2407 ($ $)) (-15 -3595 ((-634 |#1|) $)) (-15 -2759 ((-634 (-656 |#1| |#2|)) (-634 |#1|))) (-15 -2088 ((-634 (-2 (|:| |k| (-663 |#1|)) (|:| |c| |#2|))) $)) (-15 -2831 ((-634 (-288 |#2|)) $ $)))) (-842) (-13 (-172) (-707 (-409 (-568)))) (-917)) (T -618)) 
-((-1892 (*1 *1 *2) (-12 (-5 *2 (-656 *3 *4)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-5 *1 (-618 *3 *4 *5)) (-14 *5 (-917)))) (-4416 (*1 *2 *1) (-12 (-5 *2 (-656 *3 *4)) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917)))) (-4297 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |k| (-888 *3)) (|:| |c| *4)))) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-1257 *3 *4)) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-1262 *3 *4)) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917)))) (-2407 (*1 *1 *1) (-12 (-5 *1 (-618 *2 *3 *4)) (-4 *2 (-842)) (-4 *3 (-13 (-172) (-707 (-409 (-568))))) (-14 *4 (-917)))) (-3595 (*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917)))) (-2759 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-842)) (-5 *2 (-634 (-656 *4 *5))) (-5 *1 (-618 *4 *5 *6)) (-4 *5 (-13 (-172) (-707 (-409 (-568))))) (-14 *6 (-917)))) (-2088 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |k| (-663 *3)) (|:| |c| *4)))) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917)))) (-2831 (*1 *2 *1 *1) (-12 (-5 *2 (-634 (-288 *4))) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917))))) 
-(-13 (-478) (-10 -8 (-15 -1892 ($ (-656 |#1| |#2|))) (-15 -4416 ((-656 |#1| |#2|) $)) (-15 -4297 ((-634 (-2 (|:| |k| (-888 |#1|)) (|:| |c| |#2|))) $)) (-15 -2745 ((-1257 |#1| |#2|) $)) (-15 -2745 ((-1262 |#1| |#2|) $)) (-15 -2407 ($ $)) (-15 -3595 ((-634 |#1|) $)) (-15 -2759 ((-634 (-656 |#1| |#2|)) (-634 |#1|))) (-15 -2088 ((-634 (-2 (|:| |k| (-663 |#1|)) (|:| |c| |#2|))) $)) (-15 -2831 ((-634 (-288 |#2|)) $ $)))) 
-((-2415 (((-634 (-1131 |#1| (-534 (-852 |#2|)) (-852 |#2|) (-775 |#1| (-852 |#2|)))) (-634 (-775 |#1| (-852 |#2|))) (-121)) 70) (((-634 (-1044 |#1| |#2|)) (-634 (-775 |#1| (-852 |#2|))) (-121)) 56)) (-3624 (((-121) (-634 (-775 |#1| (-852 |#2|)))) 22)) (-3419 (((-634 (-1131 |#1| (-534 (-852 |#2|)) (-852 |#2|) (-775 |#1| (-852 |#2|)))) (-634 (-775 |#1| (-852 |#2|))) (-121)) 69)) (-2406 (((-634 (-1044 |#1| |#2|)) (-634 (-775 |#1| (-852 |#2|))) (-121)) 55)) (-2715 (((-634 (-775 |#1| (-852 |#2|))) (-634 (-775 |#1| (-852 |#2|)))) 26)) (-1560 (((-3 (-634 (-775 |#1| (-852 |#2|))) "failed") (-634 (-775 |#1| (-852 |#2|)))) 25))) 
-(((-619 |#1| |#2|) (-10 -7 (-15 -3624 ((-121) (-634 (-775 |#1| (-852 |#2|))))) (-15 -1560 ((-3 (-634 (-775 |#1| (-852 |#2|))) "failed") (-634 (-775 |#1| (-852 |#2|))))) (-15 -2715 ((-634 (-775 |#1| (-852 |#2|))) (-634 (-775 |#1| (-852 |#2|))))) (-15 -2406 ((-634 (-1044 |#1| |#2|)) (-634 (-775 |#1| (-852 |#2|))) (-121))) (-15 -3419 ((-634 (-1131 |#1| (-534 (-852 |#2|)) (-852 |#2|) (-775 |#1| (-852 |#2|)))) (-634 (-775 |#1| (-852 |#2|))) (-121))) (-15 -2415 ((-634 (-1044 |#1| |#2|)) (-634 (-775 |#1| (-852 |#2|))) (-121))) (-15 -2415 ((-634 (-1131 |#1| (-534 (-852 |#2|)) (-852 |#2|) (-775 |#1| (-852 |#2|)))) (-634 (-775 |#1| (-852 |#2|))) (-121)))) (-453) (-634 (-1161))) (T -619)) 
-((-2415 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-775 *5 (-852 *6)))) (-5 *4 (-121)) (-4 *5 (-453)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-1131 *5 (-534 (-852 *6)) (-852 *6) (-775 *5 (-852 *6))))) (-5 *1 (-619 *5 *6)))) (-2415 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-775 *5 (-852 *6)))) (-5 *4 (-121)) (-4 *5 (-453)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-1044 *5 *6))) (-5 *1 (-619 *5 *6)))) (-3419 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-775 *5 (-852 *6)))) (-5 *4 (-121)) (-4 *5 (-453)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-1131 *5 (-534 (-852 *6)) (-852 *6) (-775 *5 (-852 *6))))) (-5 *1 (-619 *5 *6)))) (-2406 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-775 *5 (-852 *6)))) (-5 *4 (-121)) (-4 *5 (-453)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-1044 *5 *6))) (-5 *1 (-619 *5 *6)))) (-2715 (*1 *2 *2) (-12 (-5 *2 (-634 (-775 *3 (-852 *4)))) (-4 *3 (-453)) (-14 *4 (-634 (-1161))) (-5 *1 (-619 *3 *4)))) (-1560 (*1 *2 *2) (|partial| -12 (-5 *2 (-634 (-775 *3 (-852 *4)))) (-4 *3 (-453)) (-14 *4 (-634 (-1161))) (-5 *1 (-619 *3 *4)))) (-3624 (*1 *2 *3) (-12 (-5 *3 (-634 (-775 *4 (-852 *5)))) (-4 *4 (-453)) (-14 *5 (-634 (-1161))) (-5 *2 (-121)) (-5 *1 (-619 *4 *5))))) 
-(-10 -7 (-15 -3624 ((-121) (-634 (-775 |#1| (-852 |#2|))))) (-15 -1560 ((-3 (-634 (-775 |#1| (-852 |#2|))) "failed") (-634 (-775 |#1| (-852 |#2|))))) (-15 -2715 ((-634 (-775 |#1| (-852 |#2|))) (-634 (-775 |#1| (-852 |#2|))))) (-15 -2406 ((-634 (-1044 |#1| |#2|)) (-634 (-775 |#1| (-852 |#2|))) (-121))) (-15 -3419 ((-634 (-1131 |#1| (-534 (-852 |#2|)) (-852 |#2|) (-775 |#1| (-852 |#2|)))) (-634 (-775 |#1| (-852 |#2|))) (-121))) (-15 -2415 ((-634 (-1044 |#1| |#2|)) (-634 (-775 |#1| (-852 |#2|))) (-121))) (-15 -2415 ((-634 (-1131 |#1| (-534 (-852 |#2|)) (-852 |#2|) (-775 |#1| (-852 |#2|)))) (-634 (-775 |#1| (-852 |#2|))) (-121)))) 
-((-1982 (($ $) 36)) (-1933 (($ $) 19)) (-1974 (($ $) 35)) (-2786 (($ $) 20)) (-1990 (($ $) 34)) (-1941 (($ $) 21)) (-1897 (($) 46)) (-4416 (($ $) 43)) (-1911 (($ $) 15)) (-3690 (($ $ (-1082 $)) 7) (($ $ (-1161)) 6)) (-1892 (($ $) 44)) (-1916 (($ $) 13)) (-1928 (($ $) 14)) (-1994 (($ $) 33)) (-1945 (($ $) 22)) (-1986 (($ $) 32)) (-1937 (($ $) 23)) (-1978 (($ $) 31)) (-2790 (($ $) 24)) (-2006 (($ $) 42)) (-1958 (($ $) 30)) (-1998 (($ $) 41)) (-1949 (($ $) 29)) (-2014 (($ $) 40)) (-1966 (($ $) 28)) (-4023 (($ $) 39)) (-1970 (($ $) 27)) (-2010 (($ $) 38)) (-1962 (($ $) 26)) (-2002 (($ $) 37)) (-1953 (($ $) 25)) (-3833 (($ $) 17)) (-1969 (($ $) 18)) (-2902 (($ $) 16)) (** (($ $ $) 45))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3337 (((-568) $) NIL (|has| |#1| (-840)))) (-4490 (($) NIL T CONST)) (-2902 (((-3 $ "failed") $) NIL)) (-1436 (((-121) $) NIL (|has| |#1| (-840)))) (-1598 (((-121) $) NIL)) (-2319 ((|#1| $) 13)) (-2859 (((-121) $) NIL (|has| |#1| (-840)))) (-1732 (($ $ $) NIL (|has| |#1| (-840)))) (-2047 (($ $ $) NIL (|has| |#1| (-840)))) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2326 ((|#3| $) 15)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#2|) NIL)) (-3425 (((-763)) 20)) (-2811 (($ $) NIL (|has| |#1| (-840)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) 12 T CONST)) (-1753 (((-121) $ $) NIL (|has| |#1| (-840)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-840)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| |#1| (-840)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-840)))) (-1781 (($ $ |#3|) NIL) (($ |#1| |#3|) 11)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 17) (($ $ |#2|) NIL) (($ |#2| $) NIL))) 
+(((-613 |#1| |#2| |#3|) (-13 (-43 |#2|) (-10 -8 (IF (|has| |#1| (-840)) (-6 (-840)) |noBranch|) (-15 -1781 ($ $ |#3|)) (-15 -1781 ($ |#1| |#3|)) (-15 -2319 (|#1| $)) (-15 -2326 (|#3| $)))) (-43 |#2|) (-172) (|SubsetCategory| (-716) |#2|)) (T -613)) 
+((-1781 (*1 *1 *1 *2) (-12 (-4 *4 (-172)) (-5 *1 (-613 *3 *4 *2)) (-4 *3 (-43 *4)) (-4 *2 (|SubsetCategory| (-716) *4)))) (-1781 (*1 *1 *2 *3) (-12 (-4 *4 (-172)) (-5 *1 (-613 *2 *4 *3)) (-4 *2 (-43 *4)) (-4 *3 (|SubsetCategory| (-716) *4)))) (-2319 (*1 *2 *1) (-12 (-4 *3 (-172)) (-4 *2 (-43 *3)) (-5 *1 (-613 *2 *3 *4)) (-4 *4 (|SubsetCategory| (-716) *3)))) (-2326 (*1 *2 *1) (-12 (-4 *4 (-172)) (-4 *2 (|SubsetCategory| (-716) *4)) (-5 *1 (-613 *3 *4 *2)) (-4 *3 (-43 *4))))) 
+(-13 (-43 |#2|) (-10 -8 (IF (|has| |#1| (-840)) (-6 (-840)) |noBranch|) (-15 -1781 ($ $ |#3|)) (-15 -1781 ($ |#1| |#3|)) (-15 -2319 (|#1| $)) (-15 -2326 (|#3| $)))) 
+((-3033 ((|#2| |#2| (-1161) (-1161)) 18))) 
+(((-614 |#1| |#2|) (-10 -7 (-15 -3033 (|#2| |#2| (-1161) (-1161)))) (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568))) (-13 (-1181) (-959) (-29 |#1|))) (T -614)) 
+((-3033 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-614 *4 *2)) (-4 *2 (-13 (-1181) (-959) (-29 *4)))))) 
+(-10 -7 (-15 -3033 (|#2| |#2| (-1161) (-1161)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 52)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2581 ((|#1| $) 49)) (-2689 (((-3 $ "failed") $ $) NIL)) (-2589 (((-121) $ $) NIL (|has| |#1| (-365)))) (-1448 (((-2 (|:| -3949 $) (|:| -3358 (-409 |#2|))) (-409 |#2|)) 95 (|has| |#1| (-365)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 83) (((-3 |#2| "failed") $) 80)) (-2857 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) NIL) ((|#2| $) NIL)) (-2403 (($ $ $) NIL (|has| |#1| (-365)))) (-2116 (($ $) 24)) (-2902 (((-3 $ "failed") $) 74)) (-2414 (($ $ $) NIL (|has| |#1| (-365)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-1844 (((-568) $) 19)) (-1598 (((-121) $) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-2171 (((-121) $) 36)) (-2049 (($ |#1| (-568)) 21)) (-2104 ((|#1| $) 51)) (-2498 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-365)))) (-2723 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) 85 (|has| |#1| (-365)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 98 (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-365)))) (-2597 (((-3 $ "failed") $ $) 78)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1466 (((-763) $) 97 (|has| |#1| (-365)))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 96 (|has| |#1| (-365)))) (-4191 (($ $ (-1 |#2| |#2|)) 65) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-763)) NIL (|has| |#2| (-225))) (($ $) NIL (|has| |#2| (-225)))) (-1836 (((-568) $) 34)) (-4280 (((-409 |#2|) $) 42)) (-2747 (((-850) $) 61) (($ (-568)) 32) (($ $) NIL) (($ (-409 (-568))) NIL (|has| |#1| (-1037 (-409 (-568))))) (($ |#1|) 31) (($ |#2|) 22)) (-2079 ((|#1| $ (-568)) 62)) (-3385 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-3425 (((-763)) 29)) (-2273 (((-121) $ $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 9 T CONST)) (-1557 (($) 12 T CONST)) (-3192 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-763)) NIL (|has| |#2| (-225))) (($ $) NIL (|has| |#2| (-225)))) (-1719 (((-121) $ $) 17)) (-1775 (($ $) 46) (($ $ $) NIL)) (-1769 (($ $ $) 75)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 26) (($ $ $) 44))) 
+(((-615 |#1| |#2|) (-13 (-223 |#2|) (-558) (-609 (-409 |#2|)) (-413 |#1|) (-1037 |#2|) (-10 -8 (-15 -2171 ((-121) $)) (-15 -1836 ((-568) $)) (-15 -1844 ((-568) $)) (-15 -2116 ($ $)) (-15 -2104 (|#1| $)) (-15 -2581 (|#1| $)) (-15 -2079 (|#1| $ (-568))) (-15 -2049 ($ |#1| (-568))) (IF (|has| |#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |#1| (-365)) (PROGN (-6 (-301)) (-15 -1448 ((-2 (|:| -3949 $) (|:| -3358 (-409 |#2|))) (-409 |#2|)))) |noBranch|))) (-558) (-1219 |#1|)) (T -615)) 
+((-2171 (*1 *2 *1) (-12 (-4 *3 (-558)) (-5 *2 (-121)) (-5 *1 (-615 *3 *4)) (-4 *4 (-1219 *3)))) (-1836 (*1 *2 *1) (-12 (-4 *3 (-558)) (-5 *2 (-568)) (-5 *1 (-615 *3 *4)) (-4 *4 (-1219 *3)))) (-1844 (*1 *2 *1) (-12 (-4 *3 (-558)) (-5 *2 (-568)) (-5 *1 (-615 *3 *4)) (-4 *4 (-1219 *3)))) (-2116 (*1 *1 *1) (-12 (-4 *2 (-558)) (-5 *1 (-615 *2 *3)) (-4 *3 (-1219 *2)))) (-2104 (*1 *2 *1) (-12 (-4 *2 (-558)) (-5 *1 (-615 *2 *3)) (-4 *3 (-1219 *2)))) (-2581 (*1 *2 *1) (-12 (-4 *2 (-558)) (-5 *1 (-615 *2 *3)) (-4 *3 (-1219 *2)))) (-2079 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *2 (-558)) (-5 *1 (-615 *2 *4)) (-4 *4 (-1219 *2)))) (-2049 (*1 *1 *2 *3) (-12 (-5 *3 (-568)) (-4 *2 (-558)) (-5 *1 (-615 *2 *4)) (-4 *4 (-1219 *2)))) (-1448 (*1 *2 *3) (-12 (-4 *4 (-365)) (-4 *4 (-558)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| -3949 (-615 *4 *5)) (|:| -3358 (-409 *5)))) (-5 *1 (-615 *4 *5)) (-5 *3 (-409 *5))))) 
+(-13 (-223 |#2|) (-558) (-609 (-409 |#2|)) (-413 |#1|) (-1037 |#2|) (-10 -8 (-15 -2171 ((-121) $)) (-15 -1836 ((-568) $)) (-15 -1844 ((-568) $)) (-15 -2116 ($ $)) (-15 -2104 (|#1| $)) (-15 -2581 (|#1| $)) (-15 -2079 (|#1| $ (-568))) (-15 -2049 ($ |#1| (-568))) (IF (|has| |#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |#1| (-365)) (PROGN (-6 (-301)) (-15 -1448 ((-2 (|:| -3949 $) (|:| -3358 (-409 |#2|))) (-409 |#2|)))) |noBranch|))) 
+((-2353 (((-634 |#6|) (-634 |#4|) (-121)) 46)) (-2705 ((|#6| |#6|) 39))) 
+(((-616 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -2705 (|#6| |#6|)) (-15 -2353 ((-634 |#6|) (-634 |#4|) (-121)))) (-453) (-788) (-842) (-1061 |#1| |#2| |#3|) (-1066 |#1| |#2| |#3| |#4|) (-1099 |#1| |#2| |#3| |#4|)) (T -616)) 
+((-2353 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 *10)) (-5 *1 (-616 *5 *6 *7 *8 *9 *10)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *10 (-1099 *5 *6 *7 *8)))) (-2705 (*1 *2 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *1 (-616 *3 *4 *5 *6 *7 *2)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *2 (-1099 *3 *4 *5 *6))))) 
+(-10 -7 (-15 -2705 (|#6| |#6|)) (-15 -2353 ((-634 |#6|) (-634 |#4|) (-121)))) 
+((-3415 (((-121) |#3| (-763) (-634 |#3|)) 22)) (-1983 (((-3 (-2 (|:| |polfac| (-634 |#4|)) (|:| |correct| |#3|) (|:| |corrfact| (-634 (-1157 |#3|)))) "failed") |#3| (-634 (-1157 |#3|)) (-2 (|:| |contp| |#3|) (|:| -2075 (-634 (-2 (|:| |irr| |#4|) (|:| -4402 (-568)))))) (-634 |#3|) (-634 |#1|) (-634 |#3|)) 51))) 
+(((-617 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3415 ((-121) |#3| (-763) (-634 |#3|))) (-15 -1983 ((-3 (-2 (|:| |polfac| (-634 |#4|)) (|:| |correct| |#3|) (|:| |corrfact| (-634 (-1157 |#3|)))) "failed") |#3| (-634 (-1157 |#3|)) (-2 (|:| |contp| |#3|) (|:| -2075 (-634 (-2 (|:| |irr| |#4|) (|:| -4402 (-568)))))) (-634 |#3|) (-634 |#1|) (-634 |#3|)))) (-842) (-788) (-301) (-950 |#3| |#2| |#1|)) (T -617)) 
+((-1983 (*1 *2 *3 *4 *5 *6 *7 *6) (|partial| -12 (-5 *5 (-2 (|:| |contp| *3) (|:| -2075 (-634 (-2 (|:| |irr| *10) (|:| -4402 (-568))))))) (-5 *6 (-634 *3)) (-5 *7 (-634 *8)) (-4 *8 (-842)) (-4 *3 (-301)) (-4 *10 (-950 *3 *9 *8)) (-4 *9 (-788)) (-5 *2 (-2 (|:| |polfac| (-634 *10)) (|:| |correct| *3) (|:| |corrfact| (-634 (-1157 *3))))) (-5 *1 (-617 *8 *9 *3 *10)) (-5 *4 (-634 (-1157 *3))))) (-3415 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-763)) (-5 *5 (-634 *3)) (-4 *3 (-301)) (-4 *6 (-842)) (-4 *7 (-788)) (-5 *2 (-121)) (-5 *1 (-617 *6 *7 *3 *8)) (-4 *8 (-950 *3 *7 *6))))) 
+(-10 -7 (-15 -3415 ((-121) |#3| (-763) (-634 |#3|))) (-15 -1983 ((-3 (-2 (|:| |polfac| (-634 |#4|)) (|:| |correct| |#3|) (|:| |corrfact| (-634 (-1157 |#3|)))) "failed") |#3| (-634 (-1157 |#3|)) (-2 (|:| |contp| |#3|) (|:| -2075 (-634 (-2 (|:| |irr| |#4|) (|:| -4402 (-568)))))) (-634 |#3|) (-634 |#1|) (-634 |#3|)))) 
+((-2449 (((-121) $ $) NIL)) (-2981 (((-634 |#1|) $) NIL)) (-4490 (($) NIL T CONST)) (-2902 (((-3 $ "failed") $) NIL)) (-1598 (((-121) $) NIL)) (-2310 (($ $) 67)) (-4418 (((-656 |#1| |#2|) $) 52)) (-3016 (((-634 (-2 (|:| |k| (-888 |#1|)) (|:| |c| |#2|))) $) 36)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) 70)) (-3852 (((-634 (-288 |#2|)) $ $) 33)) (-4025 (((-1108) $) NIL)) (-1894 (($ (-656 |#1| |#2|)) 48)) (-2387 (($ $ $) NIL)) (-3985 (($ $ $) NIL)) (-2747 (((-850) $) 58) (((-1257 |#1| |#2|) $) NIL) (((-1262 |#1| |#2|) $) 66)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-1557 (($) 53 T CONST)) (-3142 (((-634 (-2 (|:| |k| (-663 |#1|)) (|:| |c| |#2|))) $) 31)) (-3436 (((-634 (-656 |#1| |#2|)) (-634 |#1|)) 65)) (-1719 (((-121) $ $) 54)) (-1781 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ $ $) 44))) 
+(((-618 |#1| |#2| |#3|) (-13 (-478) (-10 -8 (-15 -1894 ($ (-656 |#1| |#2|))) (-15 -4418 ((-656 |#1| |#2|) $)) (-15 -3016 ((-634 (-2 (|:| |k| (-888 |#1|)) (|:| |c| |#2|))) $)) (-15 -2747 ((-1257 |#1| |#2|) $)) (-15 -2747 ((-1262 |#1| |#2|) $)) (-15 -2310 ($ $)) (-15 -2981 ((-634 |#1|) $)) (-15 -3436 ((-634 (-656 |#1| |#2|)) (-634 |#1|))) (-15 -3142 ((-634 (-2 (|:| |k| (-663 |#1|)) (|:| |c| |#2|))) $)) (-15 -3852 ((-634 (-288 |#2|)) $ $)))) (-842) (-13 (-172) (-707 (-409 (-568)))) (-917)) (T -618)) 
+((-1894 (*1 *1 *2) (-12 (-5 *2 (-656 *3 *4)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-5 *1 (-618 *3 *4 *5)) (-14 *5 (-917)))) (-4418 (*1 *2 *1) (-12 (-5 *2 (-656 *3 *4)) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917)))) (-3016 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |k| (-888 *3)) (|:| |c| *4)))) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-1257 *3 *4)) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-1262 *3 *4)) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917)))) (-2310 (*1 *1 *1) (-12 (-5 *1 (-618 *2 *3 *4)) (-4 *2 (-842)) (-4 *3 (-13 (-172) (-707 (-409 (-568))))) (-14 *4 (-917)))) (-2981 (*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917)))) (-3436 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-842)) (-5 *2 (-634 (-656 *4 *5))) (-5 *1 (-618 *4 *5 *6)) (-4 *5 (-13 (-172) (-707 (-409 (-568))))) (-14 *6 (-917)))) (-3142 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |k| (-663 *3)) (|:| |c| *4)))) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917)))) (-3852 (*1 *2 *1 *1) (-12 (-5 *2 (-634 (-288 *4))) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917))))) 
+(-13 (-478) (-10 -8 (-15 -1894 ($ (-656 |#1| |#2|))) (-15 -4418 ((-656 |#1| |#2|) $)) (-15 -3016 ((-634 (-2 (|:| |k| (-888 |#1|)) (|:| |c| |#2|))) $)) (-15 -2747 ((-1257 |#1| |#2|) $)) (-15 -2747 ((-1262 |#1| |#2|) $)) (-15 -2310 ($ $)) (-15 -2981 ((-634 |#1|) $)) (-15 -3436 ((-634 (-656 |#1| |#2|)) (-634 |#1|))) (-15 -3142 ((-634 (-2 (|:| |k| (-663 |#1|)) (|:| |c| |#2|))) $)) (-15 -3852 ((-634 (-288 |#2|)) $ $)))) 
+((-2353 (((-634 (-1131 |#1| (-534 (-852 |#2|)) (-852 |#2|) (-775 |#1| (-852 |#2|)))) (-634 (-775 |#1| (-852 |#2|))) (-121)) 70) (((-634 (-1044 |#1| |#2|)) (-634 (-775 |#1| (-852 |#2|))) (-121)) 56)) (-3106 (((-121) (-634 (-775 |#1| (-852 |#2|)))) 22)) (-1625 (((-634 (-1131 |#1| (-534 (-852 |#2|)) (-852 |#2|) (-775 |#1| (-852 |#2|)))) (-634 (-775 |#1| (-852 |#2|))) (-121)) 69)) (-2305 (((-634 (-1044 |#1| |#2|)) (-634 (-775 |#1| (-852 |#2|))) (-121)) 55)) (-1506 (((-634 (-775 |#1| (-852 |#2|))) (-634 (-775 |#1| (-852 |#2|)))) 26)) (-4358 (((-3 (-634 (-775 |#1| (-852 |#2|))) "failed") (-634 (-775 |#1| (-852 |#2|)))) 25))) 
+(((-619 |#1| |#2|) (-10 -7 (-15 -3106 ((-121) (-634 (-775 |#1| (-852 |#2|))))) (-15 -4358 ((-3 (-634 (-775 |#1| (-852 |#2|))) "failed") (-634 (-775 |#1| (-852 |#2|))))) (-15 -1506 ((-634 (-775 |#1| (-852 |#2|))) (-634 (-775 |#1| (-852 |#2|))))) (-15 -2305 ((-634 (-1044 |#1| |#2|)) (-634 (-775 |#1| (-852 |#2|))) (-121))) (-15 -1625 ((-634 (-1131 |#1| (-534 (-852 |#2|)) (-852 |#2|) (-775 |#1| (-852 |#2|)))) (-634 (-775 |#1| (-852 |#2|))) (-121))) (-15 -2353 ((-634 (-1044 |#1| |#2|)) (-634 (-775 |#1| (-852 |#2|))) (-121))) (-15 -2353 ((-634 (-1131 |#1| (-534 (-852 |#2|)) (-852 |#2|) (-775 |#1| (-852 |#2|)))) (-634 (-775 |#1| (-852 |#2|))) (-121)))) (-453) (-634 (-1161))) (T -619)) 
+((-2353 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-775 *5 (-852 *6)))) (-5 *4 (-121)) (-4 *5 (-453)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-1131 *5 (-534 (-852 *6)) (-852 *6) (-775 *5 (-852 *6))))) (-5 *1 (-619 *5 *6)))) (-2353 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-775 *5 (-852 *6)))) (-5 *4 (-121)) (-4 *5 (-453)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-1044 *5 *6))) (-5 *1 (-619 *5 *6)))) (-1625 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-775 *5 (-852 *6)))) (-5 *4 (-121)) (-4 *5 (-453)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-1131 *5 (-534 (-852 *6)) (-852 *6) (-775 *5 (-852 *6))))) (-5 *1 (-619 *5 *6)))) (-2305 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-775 *5 (-852 *6)))) (-5 *4 (-121)) (-4 *5 (-453)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-1044 *5 *6))) (-5 *1 (-619 *5 *6)))) (-1506 (*1 *2 *2) (-12 (-5 *2 (-634 (-775 *3 (-852 *4)))) (-4 *3 (-453)) (-14 *4 (-634 (-1161))) (-5 *1 (-619 *3 *4)))) (-4358 (*1 *2 *2) (|partial| -12 (-5 *2 (-634 (-775 *3 (-852 *4)))) (-4 *3 (-453)) (-14 *4 (-634 (-1161))) (-5 *1 (-619 *3 *4)))) (-3106 (*1 *2 *3) (-12 (-5 *3 (-634 (-775 *4 (-852 *5)))) (-4 *4 (-453)) (-14 *5 (-634 (-1161))) (-5 *2 (-121)) (-5 *1 (-619 *4 *5))))) 
+(-10 -7 (-15 -3106 ((-121) (-634 (-775 |#1| (-852 |#2|))))) (-15 -4358 ((-3 (-634 (-775 |#1| (-852 |#2|))) "failed") (-634 (-775 |#1| (-852 |#2|))))) (-15 -1506 ((-634 (-775 |#1| (-852 |#2|))) (-634 (-775 |#1| (-852 |#2|))))) (-15 -2305 ((-634 (-1044 |#1| |#2|)) (-634 (-775 |#1| (-852 |#2|))) (-121))) (-15 -1625 ((-634 (-1131 |#1| (-534 (-852 |#2|)) (-852 |#2|) (-775 |#1| (-852 |#2|)))) (-634 (-775 |#1| (-852 |#2|))) (-121))) (-15 -2353 ((-634 (-1044 |#1| |#2|)) (-634 (-775 |#1| (-852 |#2|))) (-121))) (-15 -2353 ((-634 (-1131 |#1| (-534 (-852 |#2|)) (-852 |#2|) (-775 |#1| (-852 |#2|)))) (-634 (-775 |#1| (-852 |#2|))) (-121)))) 
+((-1984 (($ $) 38)) (-1935 (($ $) 21)) (-1976 (($ $) 37)) (-2788 (($ $) 22)) (-1992 (($ $) 36)) (-1943 (($ $) 23)) (-1899 (($) 48)) (-4418 (($ $) 45)) (-1913 (($ $) 17)) (-2317 (($ $ (-1082 $)) 7) (($ $ (-1161)) 6)) (-1558 (($ $) 14)) (-1565 (($ $) 13)) (-1894 (($ $) 46)) (-1918 (($ $) 15)) (-1930 (($ $) 16)) (-1996 (($ $) 35)) (-1947 (($ $) 24)) (-1988 (($ $) 34)) (-1939 (($ $) 25)) (-1980 (($ $) 33)) (-2792 (($ $) 26)) (-2008 (($ $) 44)) (-1959 (($ $) 32)) (-2000 (($ $) 43)) (-1951 (($ $) 31)) (-2016 (($ $) 42)) (-1968 (($ $) 30)) (-1439 (($ $) 41)) (-1972 (($ $) 29)) (-2012 (($ $) 40)) (-1964 (($ $) 28)) (-2004 (($ $) 39)) (-1955 (($ $) 27)) (-1826 (($ $) 19)) (-4366 (($ $) 20)) (-2830 (($ $) 18)) (** (($ $ $) 47))) 
 (((-620) (-1275)) (T -620)) 
-((-1969 (*1 *1 *1) (-4 *1 (-620))) (-3833 (*1 *1 *1) (-4 *1 (-620))) (-2902 (*1 *1 *1) (-4 *1 (-620))) (-1911 (*1 *1 *1) (-4 *1 (-620))) (-1928 (*1 *1 *1) (-4 *1 (-620))) (-1916 (*1 *1 *1) (-4 *1 (-620)))) 
-(-13 (-959) (-1181) (-10 -8 (-15 -1969 ($ $)) (-15 -3833 ($ $)) (-15 -2902 ($ $)) (-15 -1911 ($ $)) (-15 -1928 ($ $)) (-15 -1916 ($ $)))) 
+((-4366 (*1 *1 *1) (-4 *1 (-620))) (-1826 (*1 *1 *1) (-4 *1 (-620))) (-2830 (*1 *1 *1) (-4 *1 (-620))) (-1913 (*1 *1 *1) (-4 *1 (-620))) (-1930 (*1 *1 *1) (-4 *1 (-620))) (-1918 (*1 *1 *1) (-4 *1 (-620))) (-1558 (*1 *1 *1) (-4 *1 (-620))) (-1565 (*1 *1 *1) (-4 *1 (-620)))) 
+(-13 (-959) (-1181) (-10 -8 (-15 -4366 ($ $)) (-15 -1826 ($ $)) (-15 -2830 ($ $)) (-15 -1913 ($ $)) (-15 -1930 ($ $)) (-15 -1918 ($ $)) (-15 -1558 ($ $)) (-15 -1565 ($ $)))) 
 (((-40) . T) ((-98) . T) ((-279) . T) ((-502) . T) ((-959) . T) ((-1181) . T) ((-1184) . T)) 
-((-3488 (((-123) (-123)) 83)) (-1911 ((|#2| |#2|) 30)) (-3690 ((|#2| |#2| (-1082 |#2|)) 79) ((|#2| |#2| (-1161)) 52)) (-1916 ((|#2| |#2|) 29)) (-1928 ((|#2| |#2|) 31)) (-2887 (((-121) (-123)) 34)) (-3833 ((|#2| |#2|) 26)) (-1969 ((|#2| |#2|) 28)) (-2902 ((|#2| |#2|) 27))) 
-(((-621 |#1| |#2|) (-10 -7 (-15 -2887 ((-121) (-123))) (-15 -3488 ((-123) (-123))) (-15 -1969 (|#2| |#2|)) (-15 -3833 (|#2| |#2|)) (-15 -2902 (|#2| |#2|)) (-15 -1911 (|#2| |#2|)) (-15 -1916 (|#2| |#2|)) (-15 -1928 (|#2| |#2|)) (-15 -3690 (|#2| |#2| (-1161))) (-15 -3690 (|#2| |#2| (-1082 |#2|)))) (-13 (-842) (-558)) (-13 (-432 |#1|) (-1002) (-1181))) (T -621)) 
-((-3690 (*1 *2 *2 *3) (-12 (-5 *3 (-1082 *2)) (-4 *2 (-13 (-432 *4) (-1002) (-1181))) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-621 *4 *2)))) (-3690 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-621 *4 *2)) (-4 *2 (-13 (-432 *4) (-1002) (-1181))))) (-1928 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181))))) (-1916 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181))))) (-1911 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181))))) (-2902 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181))))) (-3833 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181))))) (-1969 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181))))) (-3488 (*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *4)) (-4 *4 (-13 (-432 *3) (-1002) (-1181))))) (-2887 (*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-621 *4 *5)) (-4 *5 (-13 (-432 *4) (-1002) (-1181)))))) 
-(-10 -7 (-15 -2887 ((-121) (-123))) (-15 -3488 ((-123) (-123))) (-15 -1969 (|#2| |#2|)) (-15 -3833 (|#2| |#2|)) (-15 -2902 (|#2| |#2|)) (-15 -1911 (|#2| |#2|)) (-15 -1916 (|#2| |#2|)) (-15 -1928 (|#2| |#2|)) (-15 -3690 (|#2| |#2| (-1161))) (-15 -3690 (|#2| |#2| (-1082 |#2|)))) 
-((-2030 (((-492 |#1| |#2|) (-242 |#1| |#2|)) 52)) (-2197 (((-634 (-242 |#1| |#2|)) (-634 (-492 |#1| |#2|))) 67)) (-2990 (((-492 |#1| |#2|) (-634 (-492 |#1| |#2|)) (-852 |#1|)) 69) (((-492 |#1| |#2|) (-634 (-492 |#1| |#2|)) (-634 (-492 |#1| |#2|)) (-852 |#1|)) 68)) (-2482 (((-2 (|:| |gblist| (-634 (-242 |#1| |#2|))) (|:| |gvlist| (-634 (-568)))) (-634 (-492 |#1| |#2|))) 105)) (-3591 (((-634 (-492 |#1| |#2|)) (-852 |#1|) (-634 (-492 |#1| |#2|)) (-634 (-492 |#1| |#2|))) 82)) (-4056 (((-2 (|:| |glbase| (-634 (-242 |#1| |#2|))) (|:| |glval| (-634 (-568)))) (-634 (-242 |#1| |#2|))) 116)) (-4061 (((-1244 |#2|) (-492 |#1| |#2|) (-634 (-492 |#1| |#2|))) 57)) (-1586 (((-634 (-492 |#1| |#2|)) (-634 (-492 |#1| |#2|))) 39)) (-3158 (((-242 |#1| |#2|) (-242 |#1| |#2|) (-634 (-242 |#1| |#2|))) 49)) (-2853 (((-242 |#1| |#2|) (-634 |#2|) (-242 |#1| |#2|) (-634 (-242 |#1| |#2|))) 89))) 
-(((-622 |#1| |#2|) (-10 -7 (-15 -2482 ((-2 (|:| |gblist| (-634 (-242 |#1| |#2|))) (|:| |gvlist| (-634 (-568)))) (-634 (-492 |#1| |#2|)))) (-15 -4056 ((-2 (|:| |glbase| (-634 (-242 |#1| |#2|))) (|:| |glval| (-634 (-568)))) (-634 (-242 |#1| |#2|)))) (-15 -2197 ((-634 (-242 |#1| |#2|)) (-634 (-492 |#1| |#2|)))) (-15 -2990 ((-492 |#1| |#2|) (-634 (-492 |#1| |#2|)) (-634 (-492 |#1| |#2|)) (-852 |#1|))) (-15 -2990 ((-492 |#1| |#2|) (-634 (-492 |#1| |#2|)) (-852 |#1|))) (-15 -1586 ((-634 (-492 |#1| |#2|)) (-634 (-492 |#1| |#2|)))) (-15 -4061 ((-1244 |#2|) (-492 |#1| |#2|) (-634 (-492 |#1| |#2|)))) (-15 -2853 ((-242 |#1| |#2|) (-634 |#2|) (-242 |#1| |#2|) (-634 (-242 |#1| |#2|)))) (-15 -3591 ((-634 (-492 |#1| |#2|)) (-852 |#1|) (-634 (-492 |#1| |#2|)) (-634 (-492 |#1| |#2|)))) (-15 -3158 ((-242 |#1| |#2|) (-242 |#1| |#2|) (-634 (-242 |#1| |#2|)))) (-15 -2030 ((-492 |#1| |#2|) (-242 |#1| |#2|)))) (-634 (-1161)) (-453)) (T -622)) 
-((-2030 (*1 *2 *3) (-12 (-5 *3 (-242 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *2 (-492 *4 *5)) (-5 *1 (-622 *4 *5)))) (-3158 (*1 *2 *2 *3) (-12 (-5 *3 (-634 (-242 *4 *5))) (-5 *2 (-242 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *1 (-622 *4 *5)))) (-3591 (*1 *2 *3 *2 *2) (-12 (-5 *2 (-634 (-492 *4 *5))) (-5 *3 (-852 *4)) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *1 (-622 *4 *5)))) (-2853 (*1 *2 *3 *2 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-634 (-242 *5 *6))) (-4 *6 (-453)) (-5 *2 (-242 *5 *6)) (-14 *5 (-634 (-1161))) (-5 *1 (-622 *5 *6)))) (-4061 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-492 *5 *6))) (-5 *3 (-492 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-453)) (-5 *2 (-1244 *6)) (-5 *1 (-622 *5 *6)))) (-1586 (*1 *2 *2) (-12 (-5 *2 (-634 (-492 *3 *4))) (-14 *3 (-634 (-1161))) (-4 *4 (-453)) (-5 *1 (-622 *3 *4)))) (-2990 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-492 *5 *6))) (-5 *4 (-852 *5)) (-14 *5 (-634 (-1161))) (-5 *2 (-492 *5 *6)) (-5 *1 (-622 *5 *6)) (-4 *6 (-453)))) (-2990 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-634 (-492 *5 *6))) (-5 *4 (-852 *5)) (-14 *5 (-634 (-1161))) (-5 *2 (-492 *5 *6)) (-5 *1 (-622 *5 *6)) (-4 *6 (-453)))) (-2197 (*1 *2 *3) (-12 (-5 *3 (-634 (-492 *4 *5))) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *2 (-634 (-242 *4 *5))) (-5 *1 (-622 *4 *5)))) (-4056 (*1 *2 *3) (-12 (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *2 (-2 (|:| |glbase| (-634 (-242 *4 *5))) (|:| |glval| (-634 (-568))))) (-5 *1 (-622 *4 *5)) (-5 *3 (-634 (-242 *4 *5))))) (-2482 (*1 *2 *3) (-12 (-5 *3 (-634 (-492 *4 *5))) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *2 (-2 (|:| |gblist| (-634 (-242 *4 *5))) (|:| |gvlist| (-634 (-568))))) (-5 *1 (-622 *4 *5))))) 
-(-10 -7 (-15 -2482 ((-2 (|:| |gblist| (-634 (-242 |#1| |#2|))) (|:| |gvlist| (-634 (-568)))) (-634 (-492 |#1| |#2|)))) (-15 -4056 ((-2 (|:| |glbase| (-634 (-242 |#1| |#2|))) (|:| |glval| (-634 (-568)))) (-634 (-242 |#1| |#2|)))) (-15 -2197 ((-634 (-242 |#1| |#2|)) (-634 (-492 |#1| |#2|)))) (-15 -2990 ((-492 |#1| |#2|) (-634 (-492 |#1| |#2|)) (-634 (-492 |#1| |#2|)) (-852 |#1|))) (-15 -2990 ((-492 |#1| |#2|) (-634 (-492 |#1| |#2|)) (-852 |#1|))) (-15 -1586 ((-634 (-492 |#1| |#2|)) (-634 (-492 |#1| |#2|)))) (-15 -4061 ((-1244 |#2|) (-492 |#1| |#2|) (-634 (-492 |#1| |#2|)))) (-15 -2853 ((-242 |#1| |#2|) (-634 |#2|) (-242 |#1| |#2|) (-634 (-242 |#1| |#2|)))) (-15 -3591 ((-634 (-492 |#1| |#2|)) (-852 |#1|) (-634 (-492 |#1| |#2|)) (-634 (-492 |#1| |#2|)))) (-15 -3158 ((-242 |#1| |#2|) (-242 |#1| |#2|) (-634 (-242 |#1| |#2|)))) (-15 -2030 ((-492 |#1| |#2|) (-242 |#1| |#2|)))) 
-((-2447 (((-121) $ $) NIL (-2198 (|has| (-57) (-1090)) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-1090))))) (-2986 (($) NIL) (($ (-634 (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))))) NIL)) (-1868 (((-1249) $ (-1143) (-1143)) NIL (|has| $ (-6 -4520)))) (-2510 (((-121) $ (-763)) NIL)) (-2436 (((-57) $ (-1143) (-57)) 16) (((-57) $ (-1161) (-57)) 17)) (-3507 (($ (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519)))) (-2674 (((-3 (-57) "failed") (-1143) $) NIL)) (-2671 (($) NIL T CONST)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-1090))))) (-3405 (($ (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) $) NIL (|has| $ (-6 -4519))) (($ (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519))) (((-3 (-57) "failed") (-1143) $) NIL)) (-4328 (($ (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-1090)))) (($ (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519)))) (-3092 (((-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-1 (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) $ (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-1090)))) (((-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-1 (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) $ (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) NIL (|has| $ (-6 -4519))) (((-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-1 (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519)))) (-3989 (((-57) $ (-1143) (-57)) NIL (|has| $ (-6 -4520)))) (-2602 (((-57) $ (-1143)) NIL)) (-4360 (((-634 (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519))) (((-634 (-57)) $) NIL (|has| $ (-6 -4519)))) (-3380 (($ $) NIL)) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-1143) $) NIL (|has| (-1143) (-842)))) (-1979 (((-634 (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519))) (((-634 (-57)) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-1090)))) (((-121) (-57) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-57) (-1090))))) (-2223 (((-1143) $) NIL (|has| (-1143) (-842)))) (-3674 (($ (-1 (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4520))) (($ (-1 (-57) (-57)) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) $) NIL) (($ (-1 (-57) (-57)) $) NIL) (($ (-1 (-57) (-57) (-57)) $ $) NIL)) (-2418 (($ (-390)) 9)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (-2198 (|has| (-57) (-1090)) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-1090))))) (-1946 (((-634 (-1143)) $) NIL)) (-3548 (((-121) (-1143) $) NIL)) (-1890 (((-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) $) NIL)) (-4450 (($ (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) $) NIL)) (-4174 (((-634 (-1143)) $) NIL)) (-3578 (((-121) (-1143) $) NIL)) (-4022 (((-1108) $) NIL (-2198 (|has| (-57) (-1090)) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-1090))))) (-3876 (((-57) $) NIL (|has| (-1143) (-842)))) (-3775 (((-3 (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) "failed") (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) $) NIL)) (-3724 (($ $ (-57)) NIL (|has| $ (-6 -4520)))) (-1315 (((-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) $) NIL)) (-1387 (((-121) (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))))) NIL (-12 (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-303 (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))))) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-1090)))) (($ $ (-288 (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))))) NIL (-12 (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-303 (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))))) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-1090)))) (($ $ (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) NIL (-12 (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-303 (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))))) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-1090)))) (($ $ (-634 (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) (-634 (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))))) NIL (-12 (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-303 (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))))) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-1090)))) (($ $ (-634 (-57)) (-634 (-57))) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090)))) (($ $ (-57) (-57)) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090)))) (($ $ (-288 (-57))) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090)))) (($ $ (-634 (-288 (-57)))) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) (-57) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-57) (-1090))))) (-2041 (((-634 (-57)) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 (((-57) $ (-1143)) 14) (((-57) $ (-1143) (-57)) NIL) (((-57) $ (-1161)) 15)) (-2085 (($) NIL) (($ (-634 (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))))) NIL)) (-4168 (((-763) (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519))) (((-763) (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-1090)))) (((-763) (-57) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-57) (-1090)))) (((-763) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4519)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-609 (-541))))) (-4287 (($ (-634 (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))))) NIL)) (-2745 (((-850) $) NIL (-2198 (|has| (-57) (-1090)) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-1090))))) (-3637 (($ $) NIL)) (-2367 (($ (-634 (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))))) NIL)) (-1319 (((-121) (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) NIL (-2198 (|has| (-57) (-1090)) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 (-57))) (-1090))))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-623) (-13 (-1172 (-1143) (-57)) (-10 -8 (-15 -2418 ($ (-390))) (-15 -3380 ($ $)) (-15 -2779 ((-57) $ (-1161))) (-15 -2436 ((-57) $ (-1161) (-57))) (-15 -3637 ($ $))))) (T -623)) 
-((-2418 (*1 *1 *2) (-12 (-5 *2 (-390)) (-5 *1 (-623)))) (-3380 (*1 *1 *1) (-5 *1 (-623))) (-2779 (*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-57)) (-5 *1 (-623)))) (-2436 (*1 *2 *1 *3 *2) (-12 (-5 *2 (-57)) (-5 *3 (-1161)) (-5 *1 (-623)))) (-3637 (*1 *1 *1) (-5 *1 (-623)))) 
-(-13 (-1172 (-1143) (-57)) (-10 -8 (-15 -2418 ($ (-390))) (-15 -3380 ($ $)) (-15 -2779 ((-57) $ (-1161))) (-15 -2436 ((-57) $ (-1161) (-57))) (-15 -3637 ($ $)))) 
-((-1779 (($ $ |#2|) 10))) 
-(((-624 |#1| |#2|) (-10 -8 (-15 -1779 (|#1| |#1| |#2|))) (-625 |#2|) (-172)) (T -624)) 
-NIL 
-(-10 -8 (-15 -1779 (|#1| |#1| |#2|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-4287 (($ $ $) 26)) (-2745 (((-850) $) 11)) (-3056 (($) 17 T CONST)) (-1717 (((-121) $ $) 6)) (-1779 (($ $ |#1|) 25 (|has| |#1| (-365)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ |#1| $) 22) (($ $ |#1|) 24))) 
+((-3842 (((-123) (-123)) 87)) (-1913 ((|#2| |#2|) 32)) (-2317 ((|#2| |#2| (-1082 |#2|)) 83) ((|#2| |#2| (-1161)) 56)) (-1558 ((|#2| |#2|) 34)) (-1565 ((|#2| |#2|) 35)) (-1918 ((|#2| |#2|) 31)) (-1930 ((|#2| |#2|) 33)) (-2779 (((-121) (-123)) 38)) (-1826 ((|#2| |#2|) 28)) (-4366 ((|#2| |#2|) 30)) (-2830 ((|#2| |#2|) 29))) 
+(((-621 |#1| |#2|) (-10 -7 (-15 -2779 ((-121) (-123))) (-15 -3842 ((-123) (-123))) (-15 -4366 (|#2| |#2|)) (-15 -1826 (|#2| |#2|)) (-15 -2830 (|#2| |#2|)) (-15 -1913 (|#2| |#2|)) (-15 -1918 (|#2| |#2|)) (-15 -1930 (|#2| |#2|)) (-15 -1558 (|#2| |#2|)) (-15 -1565 (|#2| |#2|)) (-15 -2317 (|#2| |#2| (-1161))) (-15 -2317 (|#2| |#2| (-1082 |#2|)))) (-13 (-842) (-558)) (-13 (-432 |#1|) (-1002) (-1181))) (T -621)) 
+((-2317 (*1 *2 *2 *3) (-12 (-5 *3 (-1082 *2)) (-4 *2 (-13 (-432 *4) (-1002) (-1181))) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-621 *4 *2)))) (-2317 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-621 *4 *2)) (-4 *2 (-13 (-432 *4) (-1002) (-1181))))) (-1565 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181))))) (-1558 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181))))) (-1930 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181))))) (-1918 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181))))) (-1913 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181))))) (-2830 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181))))) (-1826 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181))))) (-4366 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181))))) (-3842 (*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *4)) (-4 *4 (-13 (-432 *3) (-1002) (-1181))))) (-2779 (*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-621 *4 *5)) (-4 *5 (-13 (-432 *4) (-1002) (-1181)))))) 
+(-10 -7 (-15 -2779 ((-121) (-123))) (-15 -3842 ((-123) (-123))) (-15 -4366 (|#2| |#2|)) (-15 -1826 (|#2| |#2|)) (-15 -2830 (|#2| |#2|)) (-15 -1913 (|#2| |#2|)) (-15 -1918 (|#2| |#2|)) (-15 -1930 (|#2| |#2|)) (-15 -1558 (|#2| |#2|)) (-15 -1565 (|#2| |#2|)) (-15 -2317 (|#2| |#2| (-1161))) (-15 -2317 (|#2| |#2| (-1082 |#2|)))) 
+((-1418 (((-492 |#1| |#2|) (-242 |#1| |#2|)) 52)) (-3092 (((-634 (-242 |#1| |#2|)) (-634 (-492 |#1| |#2|))) 67)) (-3110 (((-492 |#1| |#2|) (-634 (-492 |#1| |#2|)) (-852 |#1|)) 69) (((-492 |#1| |#2|) (-634 (-492 |#1| |#2|)) (-634 (-492 |#1| |#2|)) (-852 |#1|)) 68)) (-2682 (((-2 (|:| |gblist| (-634 (-242 |#1| |#2|))) (|:| |gvlist| (-634 (-568)))) (-634 (-492 |#1| |#2|))) 105)) (-2966 (((-634 (-492 |#1| |#2|)) (-852 |#1|) (-634 (-492 |#1| |#2|)) (-634 (-492 |#1| |#2|))) 82)) (-1601 (((-2 (|:| |glbase| (-634 (-242 |#1| |#2|))) (|:| |glval| (-634 (-568)))) (-634 (-242 |#1| |#2|))) 116)) (-1617 (((-1244 |#2|) (-492 |#1| |#2|) (-634 (-492 |#1| |#2|))) 57)) (-4488 (((-634 (-492 |#1| |#2|)) (-634 (-492 |#1| |#2|))) 39)) (-1645 (((-242 |#1| |#2|) (-242 |#1| |#2|) (-634 (-242 |#1| |#2|))) 49)) (-3983 (((-242 |#1| |#2|) (-634 |#2|) (-242 |#1| |#2|) (-634 (-242 |#1| |#2|))) 89))) 
+(((-622 |#1| |#2|) (-10 -7 (-15 -2682 ((-2 (|:| |gblist| (-634 (-242 |#1| |#2|))) (|:| |gvlist| (-634 (-568)))) (-634 (-492 |#1| |#2|)))) (-15 -1601 ((-2 (|:| |glbase| (-634 (-242 |#1| |#2|))) (|:| |glval| (-634 (-568)))) (-634 (-242 |#1| |#2|)))) (-15 -3092 ((-634 (-242 |#1| |#2|)) (-634 (-492 |#1| |#2|)))) (-15 -3110 ((-492 |#1| |#2|) (-634 (-492 |#1| |#2|)) (-634 (-492 |#1| |#2|)) (-852 |#1|))) (-15 -3110 ((-492 |#1| |#2|) (-634 (-492 |#1| |#2|)) (-852 |#1|))) (-15 -4488 ((-634 (-492 |#1| |#2|)) (-634 (-492 |#1| |#2|)))) (-15 -1617 ((-1244 |#2|) (-492 |#1| |#2|) (-634 (-492 |#1| |#2|)))) (-15 -3983 ((-242 |#1| |#2|) (-634 |#2|) (-242 |#1| |#2|) (-634 (-242 |#1| |#2|)))) (-15 -2966 ((-634 (-492 |#1| |#2|)) (-852 |#1|) (-634 (-492 |#1| |#2|)) (-634 (-492 |#1| |#2|)))) (-15 -1645 ((-242 |#1| |#2|) (-242 |#1| |#2|) (-634 (-242 |#1| |#2|)))) (-15 -1418 ((-492 |#1| |#2|) (-242 |#1| |#2|)))) (-634 (-1161)) (-453)) (T -622)) 
+((-1418 (*1 *2 *3) (-12 (-5 *3 (-242 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *2 (-492 *4 *5)) (-5 *1 (-622 *4 *5)))) (-1645 (*1 *2 *2 *3) (-12 (-5 *3 (-634 (-242 *4 *5))) (-5 *2 (-242 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *1 (-622 *4 *5)))) (-2966 (*1 *2 *3 *2 *2) (-12 (-5 *2 (-634 (-492 *4 *5))) (-5 *3 (-852 *4)) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *1 (-622 *4 *5)))) (-3983 (*1 *2 *3 *2 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-634 (-242 *5 *6))) (-4 *6 (-453)) (-5 *2 (-242 *5 *6)) (-14 *5 (-634 (-1161))) (-5 *1 (-622 *5 *6)))) (-1617 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-492 *5 *6))) (-5 *3 (-492 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-453)) (-5 *2 (-1244 *6)) (-5 *1 (-622 *5 *6)))) (-4488 (*1 *2 *2) (-12 (-5 *2 (-634 (-492 *3 *4))) (-14 *3 (-634 (-1161))) (-4 *4 (-453)) (-5 *1 (-622 *3 *4)))) (-3110 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-492 *5 *6))) (-5 *4 (-852 *5)) (-14 *5 (-634 (-1161))) (-5 *2 (-492 *5 *6)) (-5 *1 (-622 *5 *6)) (-4 *6 (-453)))) (-3110 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-634 (-492 *5 *6))) (-5 *4 (-852 *5)) (-14 *5 (-634 (-1161))) (-5 *2 (-492 *5 *6)) (-5 *1 (-622 *5 *6)) (-4 *6 (-453)))) (-3092 (*1 *2 *3) (-12 (-5 *3 (-634 (-492 *4 *5))) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *2 (-634 (-242 *4 *5))) (-5 *1 (-622 *4 *5)))) (-1601 (*1 *2 *3) (-12 (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *2 (-2 (|:| |glbase| (-634 (-242 *4 *5))) (|:| |glval| (-634 (-568))))) (-5 *1 (-622 *4 *5)) (-5 *3 (-634 (-242 *4 *5))))) (-2682 (*1 *2 *3) (-12 (-5 *3 (-634 (-492 *4 *5))) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *2 (-2 (|:| |gblist| (-634 (-242 *4 *5))) (|:| |gvlist| (-634 (-568))))) (-5 *1 (-622 *4 *5))))) 
+(-10 -7 (-15 -2682 ((-2 (|:| |gblist| (-634 (-242 |#1| |#2|))) (|:| |gvlist| (-634 (-568)))) (-634 (-492 |#1| |#2|)))) (-15 -1601 ((-2 (|:| |glbase| (-634 (-242 |#1| |#2|))) (|:| |glval| (-634 (-568)))) (-634 (-242 |#1| |#2|)))) (-15 -3092 ((-634 (-242 |#1| |#2|)) (-634 (-492 |#1| |#2|)))) (-15 -3110 ((-492 |#1| |#2|) (-634 (-492 |#1| |#2|)) (-634 (-492 |#1| |#2|)) (-852 |#1|))) (-15 -3110 ((-492 |#1| |#2|) (-634 (-492 |#1| |#2|)) (-852 |#1|))) (-15 -4488 ((-634 (-492 |#1| |#2|)) (-634 (-492 |#1| |#2|)))) (-15 -1617 ((-1244 |#2|) (-492 |#1| |#2|) (-634 (-492 |#1| |#2|)))) (-15 -3983 ((-242 |#1| |#2|) (-634 |#2|) (-242 |#1| |#2|) (-634 (-242 |#1| |#2|)))) (-15 -2966 ((-634 (-492 |#1| |#2|)) (-852 |#1|) (-634 (-492 |#1| |#2|)) (-634 (-492 |#1| |#2|)))) (-15 -1645 ((-242 |#1| |#2|) (-242 |#1| |#2|) (-634 (-242 |#1| |#2|)))) (-15 -1418 ((-492 |#1| |#2|) (-242 |#1| |#2|)))) 
+((-2449 (((-121) $ $) NIL (-2199 (|has| (-57) (-1090)) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-1090))))) (-2988 (($) NIL) (($ (-634 (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))))) NIL)) (-2481 (((-1249) $ (-1143) (-1143)) NIL (|has| $ (-6 -4522)))) (-1667 (((-121) $ (-763)) NIL)) (-2438 (((-57) $ (-1143) (-57)) 16) (((-57) $ (-1161) (-57)) 17)) (-3963 (($ (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521)))) (-2678 (((-3 (-57) "failed") (-1143) $) NIL)) (-4490 (($) NIL T CONST)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-1090))))) (-1568 (($ (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) $) NIL (|has| $ (-6 -4521))) (($ (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521))) (((-3 (-57) "failed") (-1143) $) NIL)) (-4330 (($ (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-1090)))) (($ (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521)))) (-3094 (((-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-1 (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) $ (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-1090)))) (((-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-1 (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) $ (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) NIL (|has| $ (-6 -4521))) (((-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-1 (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521)))) (-1292 (((-57) $ (-1143) (-57)) NIL (|has| $ (-6 -4522)))) (-2069 (((-57) $ (-1143)) NIL)) (-3317 (((-634 (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521))) (((-634 (-57)) $) NIL (|has| $ (-6 -4521)))) (-1444 (($ $) NIL)) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-1143) $) NIL (|has| (-1143) (-842)))) (-4406 (((-634 (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521))) (((-634 (-57)) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-1090)))) (((-121) (-57) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-57) (-1090))))) (-3631 (((-1143) $) NIL (|has| (-1143) (-842)))) (-2253 (($ (-1 (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4522))) (($ (-1 (-57) (-57)) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) $) NIL) (($ (-1 (-57) (-57)) $) NIL) (($ (-1 (-57) (-57) (-57)) $ $) NIL)) (-2420 (($ (-390)) 9)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (-2199 (|has| (-57) (-1090)) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-1090))))) (-4253 (((-634 (-1143)) $) NIL)) (-2807 (((-121) (-1143) $) NIL)) (-2580 (((-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) $) NIL)) (-1708 (($ (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) $) NIL)) (-3948 (((-634 (-1143)) $) NIL)) (-2916 (((-121) (-1143) $) NIL)) (-4025 (((-1108) $) NIL (-2199 (|has| (-57) (-1090)) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-1090))))) (-3877 (((-57) $) NIL (|has| (-1143) (-842)))) (-2712 (((-3 (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) "failed") (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) $) NIL)) (-2490 (($ $ (-57)) NIL (|has| $ (-6 -4522)))) (-3403 (((-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) $) NIL)) (-3951 (((-121) (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))))) NIL (-12 (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-303 (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))))) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-1090)))) (($ $ (-288 (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))))) NIL (-12 (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-303 (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))))) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-1090)))) (($ $ (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) NIL (-12 (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-303 (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))))) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-1090)))) (($ $ (-634 (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) (-634 (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))))) NIL (-12 (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-303 (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))))) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-1090)))) (($ $ (-634 (-57)) (-634 (-57))) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090)))) (($ $ (-57) (-57)) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090)))) (($ $ (-288 (-57))) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090)))) (($ $ (-634 (-288 (-57)))) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) (-57) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-57) (-1090))))) (-1480 (((-634 (-57)) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 (((-57) $ (-1143)) 14) (((-57) $ (-1143) (-57)) NIL) (((-57) $ (-1161)) 15)) (-3132 (($) NIL) (($ (-634 (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))))) NIL)) (-4170 (((-763) (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521))) (((-763) (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-1090)))) (((-763) (-57) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-57) (-1090)))) (((-763) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4521)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-609 (-541))))) (-4289 (($ (-634 (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))))) NIL)) (-2747 (((-850) $) NIL (-2199 (|has| (-57) (-1090)) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-1090))))) (-3171 (($ $) NIL)) (-4074 (($ (-634 (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))))) NIL)) (-3437 (((-121) (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) NIL (-2199 (|has| (-57) (-1090)) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 (-57))) (-1090))))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-623) (-13 (-1172 (-1143) (-57)) (-10 -8 (-15 -2420 ($ (-390))) (-15 -1444 ($ $)) (-15 -2781 ((-57) $ (-1161))) (-15 -2438 ((-57) $ (-1161) (-57))) (-15 -3171 ($ $))))) (T -623)) 
+((-2420 (*1 *1 *2) (-12 (-5 *2 (-390)) (-5 *1 (-623)))) (-1444 (*1 *1 *1) (-5 *1 (-623))) (-2781 (*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-57)) (-5 *1 (-623)))) (-2438 (*1 *2 *1 *3 *2) (-12 (-5 *2 (-57)) (-5 *3 (-1161)) (-5 *1 (-623)))) (-3171 (*1 *1 *1) (-5 *1 (-623)))) 
+(-13 (-1172 (-1143) (-57)) (-10 -8 (-15 -2420 ($ (-390))) (-15 -1444 ($ $)) (-15 -2781 ((-57) $ (-1161))) (-15 -2438 ((-57) $ (-1161) (-57))) (-15 -3171 ($ $)))) 
+((-1781 (($ $ |#2|) 10))) 
+(((-624 |#1| |#2|) (-10 -8 (-15 -1781 (|#1| |#1| |#2|))) (-625 |#2|) (-172)) (T -624)) 
+NIL 
+(-10 -8 (-15 -1781 (|#1| |#1| |#2|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-4289 (($ $ $) 26)) (-2747 (((-850) $) 11)) (-3058 (($) 17 T CONST)) (-1719 (((-121) $ $) 6)) (-1781 (($ $ |#1|) 25 (|has| |#1| (-365)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ |#1| $) 22) (($ $ |#1|) 24))) 
 (((-625 |#1|) (-1275) (-172)) (T -625)) 
-((-4287 (*1 *1 *1 *1) (-12 (-4 *1 (-625 *2)) (-4 *2 (-172)))) (-1779 (*1 *1 *1 *2) (-12 (-4 *1 (-625 *2)) (-4 *2 (-172)) (-4 *2 (-365))))) 
-(-13 (-707 |t#1|) (-10 -8 (-15 -4287 ($ $ $)) (-6 |NullSquare|) (-6 |JacobiIdentity|) (IF (|has| |t#1| (-365)) (-15 -1779 ($ $ |t#1|)) |noBranch|))) 
+((-4289 (*1 *1 *1 *1) (-12 (-4 *1 (-625 *2)) (-4 *2 (-172)))) (-1781 (*1 *1 *1 *2) (-12 (-4 *1 (-625 *2)) (-4 *2 (-172)) (-4 *2 (-365))))) 
+(-13 (-707 |t#1|) (-10 -8 (-15 -4289 ($ $ $)) (-6 |NullSquare|) (-6 |JacobiIdentity|) (IF (|has| |t#1| (-365)) (-15 -1781 ($ $ |t#1|)) |noBranch|))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 |#1| |#1|) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 |#1|) . T) ((-707 |#1|) . T) ((-1053 |#1|) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2295 (((-3 $ "failed")) NIL (-2198 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-3134 (((-3 $ "failed") $ $) NIL)) (-2776 (((-1244 (-679 |#1|))) NIL (|has| |#2| (-419 |#1|))) (((-1244 (-679 |#1|)) (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-1741 (((-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-2671 (($) NIL T CONST)) (-1309 (((-3 (-2 (|:| |particular| $) (|:| -3746 (-634 $))) "failed")) NIL (-2198 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-2593 (((-3 $ "failed")) NIL (-2198 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-1631 (((-679 |#1|)) NIL (|has| |#2| (-419 |#1|))) (((-679 |#1|) (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-1866 ((|#1| $) NIL (|has| |#2| (-369 |#1|)))) (-3042 (((-679 |#1|) $) NIL (|has| |#2| (-419 |#1|))) (((-679 |#1|) $ (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-3550 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-4408 (((-1157 (-953 |#1|))) NIL (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-365))))) (-3551 (($ $ (-917)) NIL)) (-4409 ((|#1| $) NIL (|has| |#2| (-369 |#1|)))) (-1371 (((-1157 |#1|) $) NIL (-2198 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-3569 ((|#1|) NIL (|has| |#2| (-419 |#1|))) ((|#1| (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-2989 (((-1157 |#1|) $) NIL (|has| |#2| (-369 |#1|)))) (-3384 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-3498 (($ (-1244 |#1|)) NIL (|has| |#2| (-419 |#1|))) (($ (-1244 |#1|) (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-2925 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-3700 (((-917)) NIL (|has| |#2| (-369 |#1|)))) (-4370 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-4373 (($ $ (-917)) NIL)) (-1537 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-1580 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-1695 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-3116 (((-3 (-2 (|:| |particular| $) (|:| -3746 (-634 $))) "failed")) NIL (-2198 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-2599 (((-3 $ "failed")) NIL (-2198 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-4210 (((-679 |#1|)) NIL (|has| |#2| (-419 |#1|))) (((-679 |#1|) (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-2889 ((|#1| $) NIL (|has| |#2| (-369 |#1|)))) (-4333 (((-679 |#1|) $) NIL (|has| |#2| (-419 |#1|))) (((-679 |#1|) $ (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-3243 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-4454 (((-1157 (-953 |#1|))) NIL (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-365))))) (-4222 (($ $ (-917)) NIL)) (-3329 ((|#1| $) NIL (|has| |#2| (-369 |#1|)))) (-2265 (((-1157 |#1|) $) NIL (-2198 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-3898 ((|#1|) NIL (|has| |#2| (-419 |#1|))) ((|#1| (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-3626 (((-1157 |#1|) $) NIL (|has| |#2| (-369 |#1|)))) (-2767 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-4487 (((-1143) $) NIL)) (-1804 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-2919 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-3840 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-4022 (((-1108) $) NIL)) (-1346 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-2779 ((|#1| $ (-568)) NIL (|has| |#2| (-419 |#1|)))) (-4073 (((-679 |#1|) (-1244 $)) NIL (|has| |#2| (-419 |#1|))) (((-1244 |#1|) $) NIL (|has| |#2| (-419 |#1|))) (((-679 |#1|) (-1244 $) (-1244 $)) NIL (|has| |#2| (-369 |#1|))) (((-1244 |#1|) $ (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-4278 (($ (-1244 |#1|)) NIL (|has| |#2| (-419 |#1|))) (((-1244 |#1|) $) NIL (|has| |#2| (-419 |#1|)))) (-3295 (((-634 (-953 |#1|))) NIL (|has| |#2| (-419 |#1|))) (((-634 (-953 |#1|)) (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-2353 (($ $ $) NIL)) (-3433 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-2745 (((-850) $) NIL) ((|#2| $) 12) (($ |#2|) 13)) (-3746 (((-1244 $)) NIL (|has| |#2| (-419 |#1|)))) (-1509 (((-634 (-1244 |#1|))) NIL (-2198 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-3882 (($ $ $ $) NIL)) (-4177 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-3823 (($ (-679 |#1|) $) NIL (|has| |#2| (-419 |#1|)))) (-3500 (($ $ $) NIL)) (-2433 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-2189 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-4107 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-3056 (($) 15 T CONST)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) 17)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 11) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
-(((-626 |#1| |#2|) (-13 (-736 |#1|) (-608 |#2|) (-10 -8 (-15 -2745 ($ |#2|)) (IF (|has| |#2| (-419 |#1|)) (-6 (-419 |#1|)) |noBranch|) (IF (|has| |#2| (-369 |#1|)) (-6 (-369 |#1|)) |noBranch|))) (-172) (-736 |#1|)) (T -626)) 
-((-2745 (*1 *1 *2) (-12 (-4 *3 (-172)) (-5 *1 (-626 *3 *2)) (-4 *2 (-736 *3))))) 
-(-13 (-736 |#1|) (-608 |#2|) (-10 -8 (-15 -2745 ($ |#2|)) (IF (|has| |#2| (-419 |#1|)) (-6 (-419 |#1|)) |noBranch|) (IF (|has| |#2| (-369 |#1|)) (-6 (-369 |#1|)) |noBranch|))) 
-((-2763 (((-3 (-835 |#2|) "failed") |#2| (-288 |#2|) (-1143)) 77) (((-3 (-835 |#2|) (-2 (|:| |leftHandLimit| (-3 (-835 |#2|) "failed")) (|:| |rightHandLimit| (-3 (-835 |#2|) "failed"))) "failed") |#2| (-288 (-835 |#2|))) 99)) (-2471 (((-3 (-828 |#2|) "failed") |#2| (-288 (-828 |#2|))) 104))) 
-(((-627 |#1| |#2|) (-10 -7 (-15 -2763 ((-3 (-835 |#2|) (-2 (|:| |leftHandLimit| (-3 (-835 |#2|) "failed")) (|:| |rightHandLimit| (-3 (-835 |#2|) "failed"))) "failed") |#2| (-288 (-835 |#2|)))) (-15 -2471 ((-3 (-828 |#2|) "failed") |#2| (-288 (-828 |#2|)))) (-15 -2763 ((-3 (-835 |#2|) "failed") |#2| (-288 |#2|) (-1143)))) (-13 (-453) (-842) (-1037 (-568)) (-630 (-568))) (-13 (-27) (-1181) (-432 |#1|))) (T -627)) 
-((-2763 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-288 *3)) (-5 *5 (-1143)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-835 *3)) (-5 *1 (-627 *6 *3)))) (-2471 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-288 (-828 *3))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-828 *3)) (-5 *1 (-627 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) (-2763 (*1 *2 *3 *4) (-12 (-5 *4 (-288 (-835 *3))) (-4 *3 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (-835 *3) (-2 (|:| |leftHandLimit| (-3 (-835 *3) "failed")) (|:| |rightHandLimit| (-3 (-835 *3) "failed"))) "failed")) (-5 *1 (-627 *5 *3))))) 
-(-10 -7 (-15 -2763 ((-3 (-835 |#2|) (-2 (|:| |leftHandLimit| (-3 (-835 |#2|) "failed")) (|:| |rightHandLimit| (-3 (-835 |#2|) "failed"))) "failed") |#2| (-288 (-835 |#2|)))) (-15 -2471 ((-3 (-828 |#2|) "failed") |#2| (-288 (-828 |#2|)))) (-15 -2763 ((-3 (-835 |#2|) "failed") |#2| (-288 |#2|) (-1143)))) 
-((-2763 (((-3 (-835 (-409 (-953 |#1|))) "failed") (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|))) (-1143)) 79) (((-3 (-835 (-409 (-953 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed"))) "failed") (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|)))) 18) (((-3 (-835 (-409 (-953 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed"))) "failed") (-409 (-953 |#1|)) (-288 (-835 (-953 |#1|)))) 34)) (-2471 (((-828 (-409 (-953 |#1|))) (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|)))) 21) (((-828 (-409 (-953 |#1|))) (-409 (-953 |#1|)) (-288 (-828 (-953 |#1|)))) 42))) 
-(((-628 |#1|) (-10 -7 (-15 -2763 ((-3 (-835 (-409 (-953 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed"))) "failed") (-409 (-953 |#1|)) (-288 (-835 (-953 |#1|))))) (-15 -2763 ((-3 (-835 (-409 (-953 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed"))) "failed") (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|))))) (-15 -2471 ((-828 (-409 (-953 |#1|))) (-409 (-953 |#1|)) (-288 (-828 (-953 |#1|))))) (-15 -2471 ((-828 (-409 (-953 |#1|))) (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|))))) (-15 -2763 ((-3 (-835 (-409 (-953 |#1|))) "failed") (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|))) (-1143)))) (-453)) (T -628)) 
-((-2763 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-288 (-409 (-953 *6)))) (-5 *5 (-1143)) (-5 *3 (-409 (-953 *6))) (-4 *6 (-453)) (-5 *2 (-835 *3)) (-5 *1 (-628 *6)))) (-2471 (*1 *2 *3 *4) (-12 (-5 *4 (-288 (-409 (-953 *5)))) (-5 *3 (-409 (-953 *5))) (-4 *5 (-453)) (-5 *2 (-828 *3)) (-5 *1 (-628 *5)))) (-2471 (*1 *2 *3 *4) (-12 (-5 *4 (-288 (-828 (-953 *5)))) (-4 *5 (-453)) (-5 *2 (-828 (-409 (-953 *5)))) (-5 *1 (-628 *5)) (-5 *3 (-409 (-953 *5))))) (-2763 (*1 *2 *3 *4) (-12 (-5 *4 (-288 (-409 (-953 *5)))) (-5 *3 (-409 (-953 *5))) (-4 *5 (-453)) (-5 *2 (-3 (-835 *3) (-2 (|:| |leftHandLimit| (-3 (-835 *3) "failed")) (|:| |rightHandLimit| (-3 (-835 *3) "failed"))) "failed")) (-5 *1 (-628 *5)))) (-2763 (*1 *2 *3 *4) (-12 (-5 *4 (-288 (-835 (-953 *5)))) (-4 *5 (-453)) (-5 *2 (-3 (-835 (-409 (-953 *5))) (-2 (|:| |leftHandLimit| (-3 (-835 (-409 (-953 *5))) "failed")) (|:| |rightHandLimit| (-3 (-835 (-409 (-953 *5))) "failed"))) "failed")) (-5 *1 (-628 *5)) (-5 *3 (-409 (-953 *5)))))) 
-(-10 -7 (-15 -2763 ((-3 (-835 (-409 (-953 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed"))) "failed") (-409 (-953 |#1|)) (-288 (-835 (-953 |#1|))))) (-15 -2763 ((-3 (-835 (-409 (-953 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed"))) "failed") (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|))))) (-15 -2471 ((-828 (-409 (-953 |#1|))) (-409 (-953 |#1|)) (-288 (-828 (-953 |#1|))))) (-15 -2471 ((-828 (-409 (-953 |#1|))) (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|))))) (-15 -2763 ((-3 (-835 (-409 (-953 |#1|))) "failed") (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|))) (-1143)))) 
-((-2947 (((-3 (-1244 (-409 |#1|)) "failed") (-1244 |#2|) |#2|) 57 (-3044 (|has| |#1| (-365)))) (((-3 (-1244 |#1|) "failed") (-1244 |#2|) |#2|) 42 (|has| |#1| (-365)))) (-2279 (((-121) (-1244 |#2|)) 30)) (-4085 (((-3 (-1244 |#1|) "failed") (-1244 |#2|)) 33))) 
-(((-629 |#1| |#2|) (-10 -7 (-15 -2279 ((-121) (-1244 |#2|))) (-15 -4085 ((-3 (-1244 |#1|) "failed") (-1244 |#2|))) (IF (|has| |#1| (-365)) (-15 -2947 ((-3 (-1244 |#1|) "failed") (-1244 |#2|) |#2|)) (-15 -2947 ((-3 (-1244 (-409 |#1|)) "failed") (-1244 |#2|) |#2|)))) (-558) (-630 |#1|)) (T -629)) 
-((-2947 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1244 *4)) (-4 *4 (-630 *5)) (-3044 (-4 *5 (-365))) (-4 *5 (-558)) (-5 *2 (-1244 (-409 *5))) (-5 *1 (-629 *5 *4)))) (-2947 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1244 *4)) (-4 *4 (-630 *5)) (-4 *5 (-365)) (-4 *5 (-558)) (-5 *2 (-1244 *5)) (-5 *1 (-629 *5 *4)))) (-4085 (*1 *2 *3) (|partial| -12 (-5 *3 (-1244 *5)) (-4 *5 (-630 *4)) (-4 *4 (-558)) (-5 *2 (-1244 *4)) (-5 *1 (-629 *4 *5)))) (-2279 (*1 *2 *3) (-12 (-5 *3 (-1244 *5)) (-4 *5 (-630 *4)) (-4 *4 (-558)) (-5 *2 (-121)) (-5 *1 (-629 *4 *5))))) 
-(-10 -7 (-15 -2279 ((-121) (-1244 |#2|))) (-15 -4085 ((-3 (-1244 |#1|) "failed") (-1244 |#2|))) (IF (|has| |#1| (-365)) (-15 -2947 ((-3 (-1244 |#1|) "failed") (-1244 |#2|) |#2|)) (-15 -2947 ((-3 (-1244 (-409 |#1|)) "failed") (-1244 |#2|) |#2|)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-3164 (((-679 |#1|) (-679 $)) 35) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 34)) (-2925 (((-3 $ "failed") $) 33)) (-2735 (((-121) $) 30)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11) (($ (-568)) 27)) (-4078 (((-763)) 28)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-3591 (((-3 $ "failed")) NIL (-2199 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3542 (((-1244 (-679 |#1|))) NIL (|has| |#2| (-419 |#1|))) (((-1244 (-679 |#1|)) (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-3818 (((-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-4490 (($) NIL T CONST)) (-3354 (((-3 (-2 (|:| |particular| $) (|:| -2588 (-634 $))) "failed")) NIL (-2199 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-2046 (((-3 $ "failed")) NIL (-2199 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-1524 (((-679 |#1|)) NIL (|has| |#2| (-419 |#1|))) (((-679 |#1|) (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-2467 ((|#1| $) NIL (|has| |#2| (-369 |#1|)))) (-2235 (((-679 |#1|) $) NIL (|has| |#2| (-419 |#1|))) (((-679 |#1|) $ (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-2812 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-1503 (((-1157 (-953 |#1|))) NIL (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-365))))) (-2815 (($ $ (-917)) NIL)) (-1509 ((|#1| $) NIL (|has| |#2| (-369 |#1|)))) (-3839 (((-1157 |#1|) $) NIL (-2199 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-2886 ((|#1|) NIL (|has| |#2| (-419 |#1|))) ((|#1| (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-3105 (((-1157 |#1|) $) NIL (|has| |#2| (-369 |#1|)))) (-1463 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-3899 (($ (-1244 |#1|)) NIL (|has| |#2| (-419 |#1|))) (($ (-1244 |#1|) (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-2902 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-2371 (((-917)) NIL (|has| |#2| (-369 |#1|)))) (-3375 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-3402 (($ $ (-917)) NIL)) (-4221 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-4463 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-3582 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-2587 (((-3 (-2 (|:| |particular| $) (|:| -2588 (-634 $))) "failed")) NIL (-2199 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-2061 (((-3 $ "failed")) NIL (-2199 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-4134 (((-679 |#1|)) NIL (|has| |#2| (-419 |#1|))) (((-679 |#1|) (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-2786 ((|#1| $) NIL (|has| |#2| (-369 |#1|)))) (-3147 (((-679 |#1|) $) NIL (|has| |#2| (-419 |#1|))) (((-679 |#1|) $ (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-1974 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-1730 (((-1157 (-953 |#1|))) NIL (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-365))))) (-4202 (($ $ (-917)) NIL)) (-4390 ((|#1| $) NIL (|has| |#2| (-369 |#1|)))) (-3364 (((-1157 |#1|) $) NIL (-2199 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-2060 ((|#1|) NIL (|has| |#2| (-419 |#1|))) ((|#1| (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-3114 (((-1157 |#1|) $) NIL (|has| |#2| (-369 |#1|)))) (-3487 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-1893 (((-1143) $) NIL)) (-2153 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-2889 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-1852 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-4025 (((-1108) $) NIL)) (-3636 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-2781 ((|#1| $ (-568)) NIL (|has| |#2| (-419 |#1|)))) (-1656 (((-679 |#1|) (-1244 $)) NIL (|has| |#2| (-419 |#1|))) (((-1244 |#1|) $) NIL (|has| |#2| (-419 |#1|))) (((-679 |#1|) (-1244 $) (-1244 $)) NIL (|has| |#2| (-369 |#1|))) (((-1244 |#1|) $ (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-4280 (($ (-1244 |#1|)) NIL (|has| |#2| (-419 |#1|))) (((-1244 |#1|) $) NIL (|has| |#2| (-419 |#1|)))) (-2155 (((-634 (-953 |#1|))) NIL (|has| |#2| (-419 |#1|))) (((-634 (-953 |#1|)) (-1244 $)) NIL (|has| |#2| (-369 |#1|)))) (-3985 (($ $ $) NIL)) (-3441 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-2747 (((-850) $) NIL) ((|#2| $) 12) (($ |#2|) 13)) (-2588 (((-1244 $)) NIL (|has| |#2| (-419 |#1|)))) (-2657 (((-634 (-1244 |#1|))) NIL (-2199 (-12 (|has| |#2| (-369 |#1|)) (|has| |#1| (-558))) (-12 (|has| |#2| (-419 |#1|)) (|has| |#1| (-558)))))) (-2007 (($ $ $ $) NIL)) (-3964 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-3828 (($ (-679 |#1|) $) NIL (|has| |#2| (-419 |#1|)))) (-3911 (($ $ $) NIL)) (-2435 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-2984 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-3579 (((-121)) NIL (|has| |#2| (-369 |#1|)))) (-3058 (($) 15 T CONST)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) 17)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 11) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
+(((-626 |#1| |#2|) (-13 (-736 |#1|) (-608 |#2|) (-10 -8 (-15 -2747 ($ |#2|)) (IF (|has| |#2| (-419 |#1|)) (-6 (-419 |#1|)) |noBranch|) (IF (|has| |#2| (-369 |#1|)) (-6 (-369 |#1|)) |noBranch|))) (-172) (-736 |#1|)) (T -626)) 
+((-2747 (*1 *1 *2) (-12 (-4 *3 (-172)) (-5 *1 (-626 *3 *2)) (-4 *2 (-736 *3))))) 
+(-13 (-736 |#1|) (-608 |#2|) (-10 -8 (-15 -2747 ($ |#2|)) (IF (|has| |#2| (-419 |#1|)) (-6 (-419 |#1|)) |noBranch|) (IF (|has| |#2| (-369 |#1|)) (-6 (-369 |#1|)) |noBranch|))) 
+((-3464 (((-3 (-835 |#2|) "failed") |#2| (-288 |#2|) (-1143)) 78) (((-3 (-835 |#2|) (-2 (|:| |leftHandLimit| (-3 (-835 |#2|) "failed")) (|:| |rightHandLimit| (-3 (-835 |#2|) "failed"))) "failed") |#2| (-288 (-835 |#2|))) 100)) (-2621 (((-3 (-828 |#2|) "failed") |#2| (-288 (-828 |#2|))) 105))) 
+(((-627 |#1| |#2|) (-10 -7 (-15 -3464 ((-3 (-835 |#2|) (-2 (|:| |leftHandLimit| (-3 (-835 |#2|) "failed")) (|:| |rightHandLimit| (-3 (-835 |#2|) "failed"))) "failed") |#2| (-288 (-835 |#2|)))) (-15 -2621 ((-3 (-828 |#2|) "failed") |#2| (-288 (-828 |#2|)))) (-15 -3464 ((-3 (-835 |#2|) "failed") |#2| (-288 |#2|) (-1143)))) (-13 (-453) (-842) (-1037 (-568)) (-630 (-568))) (-13 (-27) (-1181) (-432 |#1|))) (T -627)) 
+((-3464 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-288 *3)) (-5 *5 (-1143)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-835 *3)) (-5 *1 (-627 *6 *3)))) (-2621 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-288 (-828 *3))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-828 *3)) (-5 *1 (-627 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) (-3464 (*1 *2 *3 *4) (-12 (-5 *4 (-288 (-835 *3))) (-4 *3 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (-835 *3) (-2 (|:| |leftHandLimit| (-3 (-835 *3) "failed")) (|:| |rightHandLimit| (-3 (-835 *3) "failed"))) "failed")) (-5 *1 (-627 *5 *3))))) 
+(-10 -7 (-15 -3464 ((-3 (-835 |#2|) (-2 (|:| |leftHandLimit| (-3 (-835 |#2|) "failed")) (|:| |rightHandLimit| (-3 (-835 |#2|) "failed"))) "failed") |#2| (-288 (-835 |#2|)))) (-15 -2621 ((-3 (-828 |#2|) "failed") |#2| (-288 (-828 |#2|)))) (-15 -3464 ((-3 (-835 |#2|) "failed") |#2| (-288 |#2|) (-1143)))) 
+((-3464 (((-3 (-835 (-409 (-953 |#1|))) "failed") (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|))) (-1143)) 79) (((-3 (-835 (-409 (-953 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed"))) "failed") (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|)))) 18) (((-3 (-835 (-409 (-953 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed"))) "failed") (-409 (-953 |#1|)) (-288 (-835 (-953 |#1|)))) 34)) (-2621 (((-828 (-409 (-953 |#1|))) (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|)))) 21) (((-828 (-409 (-953 |#1|))) (-409 (-953 |#1|)) (-288 (-828 (-953 |#1|)))) 42))) 
+(((-628 |#1|) (-10 -7 (-15 -3464 ((-3 (-835 (-409 (-953 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed"))) "failed") (-409 (-953 |#1|)) (-288 (-835 (-953 |#1|))))) (-15 -3464 ((-3 (-835 (-409 (-953 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed"))) "failed") (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|))))) (-15 -2621 ((-828 (-409 (-953 |#1|))) (-409 (-953 |#1|)) (-288 (-828 (-953 |#1|))))) (-15 -2621 ((-828 (-409 (-953 |#1|))) (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|))))) (-15 -3464 ((-3 (-835 (-409 (-953 |#1|))) "failed") (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|))) (-1143)))) (-453)) (T -628)) 
+((-3464 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-288 (-409 (-953 *6)))) (-5 *5 (-1143)) (-5 *3 (-409 (-953 *6))) (-4 *6 (-453)) (-5 *2 (-835 *3)) (-5 *1 (-628 *6)))) (-2621 (*1 *2 *3 *4) (-12 (-5 *4 (-288 (-409 (-953 *5)))) (-5 *3 (-409 (-953 *5))) (-4 *5 (-453)) (-5 *2 (-828 *3)) (-5 *1 (-628 *5)))) (-2621 (*1 *2 *3 *4) (-12 (-5 *4 (-288 (-828 (-953 *5)))) (-4 *5 (-453)) (-5 *2 (-828 (-409 (-953 *5)))) (-5 *1 (-628 *5)) (-5 *3 (-409 (-953 *5))))) (-3464 (*1 *2 *3 *4) (-12 (-5 *4 (-288 (-409 (-953 *5)))) (-5 *3 (-409 (-953 *5))) (-4 *5 (-453)) (-5 *2 (-3 (-835 *3) (-2 (|:| |leftHandLimit| (-3 (-835 *3) "failed")) (|:| |rightHandLimit| (-3 (-835 *3) "failed"))) "failed")) (-5 *1 (-628 *5)))) (-3464 (*1 *2 *3 *4) (-12 (-5 *4 (-288 (-835 (-953 *5)))) (-4 *5 (-453)) (-5 *2 (-3 (-835 (-409 (-953 *5))) (-2 (|:| |leftHandLimit| (-3 (-835 (-409 (-953 *5))) "failed")) (|:| |rightHandLimit| (-3 (-835 (-409 (-953 *5))) "failed"))) "failed")) (-5 *1 (-628 *5)) (-5 *3 (-409 (-953 *5)))))) 
+(-10 -7 (-15 -3464 ((-3 (-835 (-409 (-953 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed"))) "failed") (-409 (-953 |#1|)) (-288 (-835 (-953 |#1|))))) (-15 -3464 ((-3 (-835 (-409 (-953 |#1|))) (-2 (|:| |leftHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed")) (|:| |rightHandLimit| (-3 (-835 (-409 (-953 |#1|))) "failed"))) "failed") (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|))))) (-15 -2621 ((-828 (-409 (-953 |#1|))) (-409 (-953 |#1|)) (-288 (-828 (-953 |#1|))))) (-15 -2621 ((-828 (-409 (-953 |#1|))) (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|))))) (-15 -3464 ((-3 (-835 (-409 (-953 |#1|))) "failed") (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|))) (-1143)))) 
+((-2971 (((-3 (-1244 (-409 |#1|)) "failed") (-1244 |#2|) |#2|) 57 (-3046 (|has| |#1| (-365)))) (((-3 (-1244 |#1|) "failed") (-1244 |#2|) |#2|) 42 (|has| |#1| (-365)))) (-3472 (((-121) (-1244 |#2|)) 30)) (-3466 (((-3 (-1244 |#1|) "failed") (-1244 |#2|)) 33))) 
+(((-629 |#1| |#2|) (-10 -7 (-15 -3472 ((-121) (-1244 |#2|))) (-15 -3466 ((-3 (-1244 |#1|) "failed") (-1244 |#2|))) (IF (|has| |#1| (-365)) (-15 -2971 ((-3 (-1244 |#1|) "failed") (-1244 |#2|) |#2|)) (-15 -2971 ((-3 (-1244 (-409 |#1|)) "failed") (-1244 |#2|) |#2|)))) (-558) (-630 |#1|)) (T -629)) 
+((-2971 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1244 *4)) (-4 *4 (-630 *5)) (-3046 (-4 *5 (-365))) (-4 *5 (-558)) (-5 *2 (-1244 (-409 *5))) (-5 *1 (-629 *5 *4)))) (-2971 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1244 *4)) (-4 *4 (-630 *5)) (-4 *5 (-365)) (-4 *5 (-558)) (-5 *2 (-1244 *5)) (-5 *1 (-629 *5 *4)))) (-3466 (*1 *2 *3) (|partial| -12 (-5 *3 (-1244 *5)) (-4 *5 (-630 *4)) (-4 *4 (-558)) (-5 *2 (-1244 *4)) (-5 *1 (-629 *4 *5)))) (-3472 (*1 *2 *3) (-12 (-5 *3 (-1244 *5)) (-4 *5 (-630 *4)) (-4 *4 (-558)) (-5 *2 (-121)) (-5 *1 (-629 *4 *5))))) 
+(-10 -7 (-15 -3472 ((-121) (-1244 |#2|))) (-15 -3466 ((-3 (-1244 |#1|) "failed") (-1244 |#2|))) (IF (|has| |#1| (-365)) (-15 -2971 ((-3 (-1244 |#1|) "failed") (-1244 |#2|) |#2|)) (-15 -2971 ((-3 (-1244 (-409 |#1|)) "failed") (-1244 |#2|) |#2|)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-1668 (((-679 |#1|) (-679 $)) 35) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 34)) (-2902 (((-3 $ "failed") $) 33)) (-1598 (((-121) $) 30)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11) (($ (-568)) 27)) (-3425 (((-763)) 28)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
 (((-630 |#1|) (-1275) (-1047)) (T -630)) 
-((-3164 (*1 *2 *3) (-12 (-5 *3 (-679 *1)) (-4 *1 (-630 *4)) (-4 *4 (-1047)) (-5 *2 (-679 *4)))) (-3164 (*1 *2 *3 *4) (-12 (-5 *3 (-679 *1)) (-5 *4 (-1244 *1)) (-4 *1 (-630 *5)) (-4 *5 (-1047)) (-5 *2 (-2 (|:| -2928 (-679 *5)) (|:| |vec| (-1244 *5))))))) 
-(-13 (-1047) (-10 -8 (-15 -3164 ((-679 |t#1|) (-679 $))) (-15 -3164 ((-2 (|:| -2928 (-679 |t#1|)) (|:| |vec| (-1244 |t#1|))) (-679 $) (-1244 $))))) 
+((-1668 (*1 *2 *3) (-12 (-5 *3 (-679 *1)) (-4 *1 (-630 *4)) (-4 *4 (-1047)) (-5 *2 (-679 *4)))) (-1668 (*1 *2 *3 *4) (-12 (-5 *3 (-679 *1)) (-5 *4 (-1244 *1)) (-4 *1 (-630 *5)) (-4 *5 (-1047)) (-5 *2 (-2 (|:| -2908 (-679 *5)) (|:| |vec| (-1244 *5))))))) 
+(-13 (-1047) (-10 -8 (-15 -1668 ((-679 |t#1|) (-679 $))) (-15 -1668 ((-2 (|:| -2908 (-679 |t#1|)) (|:| |vec| (-1244 |t#1|))) (-679 $) (-1244 $))))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 $) . T) ((-716) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-2661 ((|#2| (-634 |#1|) (-634 |#2|) |#1| (-1 |#2| |#1|)) 18) (((-1 |#2| |#1|) (-634 |#1|) (-634 |#2|) (-1 |#2| |#1|)) 19) ((|#2| (-634 |#1|) (-634 |#2|) |#1| |#2|) 16) (((-1 |#2| |#1|) (-634 |#1|) (-634 |#2|) |#2|) 17) ((|#2| (-634 |#1|) (-634 |#2|) |#1|) 10) (((-1 |#2| |#1|) (-634 |#1|) (-634 |#2|)) 12))) 
-(((-631 |#1| |#2|) (-10 -7 (-15 -2661 ((-1 |#2| |#1|) (-634 |#1|) (-634 |#2|))) (-15 -2661 (|#2| (-634 |#1|) (-634 |#2|) |#1|)) (-15 -2661 ((-1 |#2| |#1|) (-634 |#1|) (-634 |#2|) |#2|)) (-15 -2661 (|#2| (-634 |#1|) (-634 |#2|) |#1| |#2|)) (-15 -2661 ((-1 |#2| |#1|) (-634 |#1|) (-634 |#2|) (-1 |#2| |#1|))) (-15 -2661 (|#2| (-634 |#1|) (-634 |#2|) |#1| (-1 |#2| |#1|)))) (-1090) (-1195)) (T -631)) 
-((-2661 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 *2)) (-5 *6 (-1 *2 *5)) (-4 *5 (-1090)) (-4 *2 (-1195)) (-5 *1 (-631 *5 *2)))) (-2661 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-1 *6 *5)) (-5 *3 (-634 *5)) (-5 *4 (-634 *6)) (-4 *5 (-1090)) (-4 *6 (-1195)) (-5 *1 (-631 *5 *6)))) (-2661 (*1 *2 *3 *4 *5 *2) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 *2)) (-4 *5 (-1090)) (-4 *2 (-1195)) (-5 *1 (-631 *5 *2)))) (-2661 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 *6)) (-5 *4 (-634 *5)) (-4 *6 (-1090)) (-4 *5 (-1195)) (-5 *2 (-1 *5 *6)) (-5 *1 (-631 *6 *5)))) (-2661 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 *2)) (-4 *5 (-1090)) (-4 *2 (-1195)) (-5 *1 (-631 *5 *2)))) (-2661 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 *6)) (-4 *5 (-1090)) (-4 *6 (-1195)) (-5 *2 (-1 *6 *5)) (-5 *1 (-631 *5 *6))))) 
-(-10 -7 (-15 -2661 ((-1 |#2| |#1|) (-634 |#1|) (-634 |#2|))) (-15 -2661 (|#2| (-634 |#1|) (-634 |#2|) |#1|)) (-15 -2661 ((-1 |#2| |#1|) (-634 |#1|) (-634 |#2|) |#2|)) (-15 -2661 (|#2| (-634 |#1|) (-634 |#2|) |#1| |#2|)) (-15 -2661 ((-1 |#2| |#1|) (-634 |#1|) (-634 |#2|) (-1 |#2| |#1|))) (-15 -2661 (|#2| (-634 |#1|) (-634 |#2|) |#1| (-1 |#2| |#1|)))) 
-((-2512 (((-634 |#2|) (-1 |#2| |#1| |#2|) (-634 |#1|) |#2|) 16)) (-3092 ((|#2| (-1 |#2| |#1| |#2|) (-634 |#1|) |#2|) 18)) (-2795 (((-634 |#2|) (-1 |#2| |#1|) (-634 |#1|)) 13))) 
-(((-632 |#1| |#2|) (-10 -7 (-15 -2512 ((-634 |#2|) (-1 |#2| |#1| |#2|) (-634 |#1|) |#2|)) (-15 -3092 (|#2| (-1 |#2| |#1| |#2|) (-634 |#1|) |#2|)) (-15 -2795 ((-634 |#2|) (-1 |#2| |#1|) (-634 |#1|)))) (-1195) (-1195)) (T -632)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-634 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-634 *6)) (-5 *1 (-632 *5 *6)))) (-3092 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-634 *5)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-632 *5 *2)))) (-2512 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-634 *6)) (-4 *6 (-1195)) (-4 *5 (-1195)) (-5 *2 (-634 *5)) (-5 *1 (-632 *6 *5))))) 
-(-10 -7 (-15 -2512 ((-634 |#2|) (-1 |#2| |#1| |#2|) (-634 |#1|) |#2|)) (-15 -3092 (|#2| (-1 |#2| |#1| |#2|) (-634 |#1|) |#2|)) (-15 -2795 ((-634 |#2|) (-1 |#2| |#1|) (-634 |#1|)))) 
-((-2795 (((-634 |#3|) (-1 |#3| |#1| |#2|) (-634 |#1|) (-634 |#2|)) 13))) 
-(((-633 |#1| |#2| |#3|) (-10 -7 (-15 -2795 ((-634 |#3|) (-1 |#3| |#1| |#2|) (-634 |#1|) (-634 |#2|)))) (-1195) (-1195) (-1195)) (T -633)) 
-((-2795 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-634 *6)) (-5 *5 (-634 *7)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-4 *8 (-1195)) (-5 *2 (-634 *8)) (-5 *1 (-633 *6 *7 *8))))) 
-(-10 -7 (-15 -2795 ((-634 |#3|) (-1 |#3| |#1| |#2|) (-634 |#1|) (-634 |#2|)))) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2850 ((|#1| $) NIL)) (-2235 ((|#1| $) NIL)) (-2796 (($ $) NIL)) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-3910 (($ $ (-568)) NIL (|has| $ (-6 -4520)))) (-2016 (((-121) $) NIL (|has| |#1| (-842))) (((-121) (-1 (-121) |#1| |#1|) $) NIL)) (-3908 (($ $) NIL (-12 (|has| $ (-6 -4520)) (|has| |#1| (-842)))) (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-3644 (($ $) NIL (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-1659 ((|#1| $ |#1|) NIL (|has| $ (-6 -4520)))) (-3869 (($ $ $) NIL (|has| $ (-6 -4520)))) (-2395 ((|#1| $ |#1|) NIL (|has| $ (-6 -4520)))) (-2517 ((|#1| $ |#1|) NIL (|has| $ (-6 -4520)))) (-2436 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4520))) ((|#1| $ "first" |#1|) NIL (|has| $ (-6 -4520))) (($ $ "rest" $) NIL (|has| $ (-6 -4520))) ((|#1| $ "last" |#1|) NIL (|has| $ (-6 -4520))) ((|#1| $ (-1210 (-568)) |#1|) NIL (|has| $ (-6 -4520))) ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) NIL (|has| $ (-6 -4520)))) (-3971 (($ $ $) 31 (|has| |#1| (-1090)))) (-3960 (($ $ $) 33 (|has| |#1| (-1090)))) (-3951 (($ $ $) 36 (|has| |#1| (-1090)))) (-3507 (($ (-1 (-121) |#1|) $) NIL)) (-2801 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1679 ((|#1| $) NIL)) (-2671 (($) NIL T CONST)) (-1578 (($ $) NIL (|has| $ (-6 -4520)))) (-3943 (($ $) NIL)) (-3935 (($ $) NIL) (($ $ (-763)) NIL)) (-3369 (($ $) NIL (|has| |#1| (-1090)))) (-3924 (($ $) 30 (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3405 (($ |#1| $) NIL (|has| |#1| (-1090))) (($ (-1 (-121) |#1|) $) NIL)) (-4328 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (($ |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3989 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-568)) NIL)) (-1601 (((-121) $) NIL)) (-2764 (((-568) |#1| $ (-568)) NIL (|has| |#1| (-1090))) (((-568) |#1| $) NIL (|has| |#1| (-1090))) (((-568) (-1 (-121) |#1|) $) NIL)) (-4360 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-2597 (((-121) $) 9)) (-2287 (((-634 $) $) NIL)) (-1700 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3973 (($) 7)) (-1849 (($ (-763) |#1|) NIL)) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) NIL (|has| (-568) (-842)))) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-3349 (($ $ $) NIL (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $ $) NIL)) (-1347 (($ $ $) NIL (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $ $) NIL)) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 32 (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2223 (((-568) $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-3674 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-3896 (($ |#1|) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-2869 (((-634 |#1|) $) NIL)) (-1651 (((-121) $) NIL)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4162 ((|#1| $) NIL) (($ $ (-763)) NIL)) (-4450 (($ $ $ (-568)) NIL) (($ |#1| $ (-568)) NIL)) (-4122 (($ $ $ (-568)) NIL) (($ |#1| $ (-568)) NIL)) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3876 ((|#1| $) NIL) (($ $ (-763)) NIL)) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3724 (($ $ |#1|) NIL (|has| $ (-6 -4520)))) (-1786 (((-121) $) NIL)) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#1| $ "value") NIL) ((|#1| $ "first") NIL) (($ $ "rest") NIL) ((|#1| $ "last") NIL) (($ $ (-1210 (-568))) NIL) ((|#1| $ (-568)) 35) ((|#1| $ (-568) |#1|) NIL)) (-4075 (((-568) $ $) NIL)) (-1783 (($ $ (-1210 (-568))) NIL) (($ $ (-568)) NIL)) (-2826 (($ $ (-1210 (-568))) NIL) (($ $ (-568)) NIL)) (-3790 (((-121) $) NIL)) (-2340 (($ $) NIL)) (-2714 (($ $) NIL (|has| $ (-6 -4520)))) (-2775 (((-763) $) NIL)) (-3335 (($ $) NIL)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2256 (($ $ $ (-568)) NIL (|has| $ (-6 -4520)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) 44 (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) NIL)) (-3853 (($ |#1| $) 10)) (-3845 (($ $ $) NIL) (($ $ |#1|) NIL)) (-2768 (($ $ $) 29) (($ |#1| $) NIL) (($ (-634 $)) NIL) (($ $ |#1|) NIL)) (-2745 (((-850) $) NIL (|has| |#1| (-1090)))) (-4339 (((-634 $) $) NIL)) (-3491 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1855 (($ $ $) 11)) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-3754 (((-1143) $) 25 (|has| |#1| (-823))) (((-1143) $ (-121)) 26 (|has| |#1| (-823))) (((-1249) (-817) $) 27 (|has| |#1| (-823))) (((-1249) (-817) $ (-121)) 28 (|has| |#1| (-823)))) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-634 |#1|) (-13 (-658 |#1|) (-10 -8 (-15 -3973 ($)) (-15 -2597 ((-121) $)) (-15 -3853 ($ |#1| $)) (-15 -1855 ($ $ $)) (IF (|has| |#1| (-1090)) (PROGN (-15 -3971 ($ $ $)) (-15 -3960 ($ $ $)) (-15 -3951 ($ $ $))) |noBranch|) (IF (|has| |#1| (-823)) (-6 (-823)) |noBranch|))) (-1195)) (T -634)) 
-((-3973 (*1 *1) (-12 (-5 *1 (-634 *2)) (-4 *2 (-1195)))) (-2597 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-634 *3)) (-4 *3 (-1195)))) (-3853 (*1 *1 *2 *1) (-12 (-5 *1 (-634 *2)) (-4 *2 (-1195)))) (-1855 (*1 *1 *1 *1) (-12 (-5 *1 (-634 *2)) (-4 *2 (-1195)))) (-3971 (*1 *1 *1 *1) (-12 (-5 *1 (-634 *2)) (-4 *2 (-1090)) (-4 *2 (-1195)))) (-3960 (*1 *1 *1 *1) (-12 (-5 *1 (-634 *2)) (-4 *2 (-1090)) (-4 *2 (-1195)))) (-3951 (*1 *1 *1 *1) (-12 (-5 *1 (-634 *2)) (-4 *2 (-1090)) (-4 *2 (-1195))))) 
-(-13 (-658 |#1|) (-10 -8 (-15 -3973 ($)) (-15 -2597 ((-121) $)) (-15 -3853 ($ |#1| $)) (-15 -1855 ($ $ $)) (IF (|has| |#1| (-1090)) (PROGN (-15 -3971 ($ $ $)) (-15 -3960 ($ $ $)) (-15 -3951 ($ $ $))) |noBranch|) (IF (|has| |#1| (-823)) (-6 (-823)) |noBranch|))) 
-((-3232 (((-634 |#1|) |#2| (-568)) 21)) (-3905 (((-679 |#1|) (-634 |#2|) (-568)) 30)) (-2145 (((-679 |#1|) (-634 |#2|) (-568)) 28))) 
-(((-635 |#1| |#2|) (-10 -7 (-15 -3905 ((-679 |#1|) (-634 |#2|) (-568))) (-15 -2145 ((-679 |#1|) (-634 |#2|) (-568))) (-15 -3232 ((-634 |#1|) |#2| (-568)))) (-365) (-641 |#1|)) (T -635)) 
-((-3232 (*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-365)) (-5 *2 (-634 *5)) (-5 *1 (-635 *5 *3)) (-4 *3 (-641 *5)))) (-2145 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-568)) (-4 *6 (-641 *5)) (-4 *5 (-365)) (-5 *2 (-679 *5)) (-5 *1 (-635 *5 *6)))) (-3905 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-568)) (-4 *6 (-641 *5)) (-4 *5 (-365)) (-5 *2 (-679 *5)) (-5 *1 (-635 *5 *6))))) 
-(-10 -7 (-15 -3905 ((-679 |#1|) (-634 |#2|) (-568))) (-15 -2145 ((-679 |#1|) (-634 |#2|) (-568))) (-15 -3232 ((-634 |#1|) |#2| (-568)))) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3991 (($ |#1| |#1| $) 43)) (-2510 (((-121) $ (-763)) NIL)) (-3507 (($ (-1 (-121) |#1|) $) 56 (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-2671 (($) NIL T CONST)) (-3369 (($ $) 45)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3405 (($ |#1| $) 51 (|has| $ (-6 -4519))) (($ (-1 (-121) |#1|) $) 53 (|has| $ (-6 -4519)))) (-4328 (($ |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4519)))) (-4360 (((-634 |#1|) $) 9 (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) NIL)) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3674 (($ (-1 |#1| |#1|) $) 39 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 37)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-1890 ((|#1| $) 46)) (-4450 (($ |#1| $) 26) (($ |#1| $ (-763)) 42)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-1315 ((|#1| $) 48)) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) 21)) (-3248 (($) 25)) (-4020 (((-121) $) 49)) (-1799 (((-634 (-2 (|:| -4083 |#1|) (|:| -4168 (-763)))) $) 60)) (-2085 (($) 23) (($ (-634 |#1|)) 18)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) 57 (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) 19)) (-4278 (((-541) $) 34 (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) NIL)) (-2745 (((-850) $) 14 (|has| |#1| (-1090)))) (-2367 (($ (-634 |#1|)) 22)) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 62 (|has| |#1| (-1090)))) (-1697 (((-763) $) 16 (|has| $ (-6 -4519))))) 
-(((-636 |#1|) (-13 (-684 |#1|) (-10 -8 (-6 -4519) (-15 -4020 ((-121) $)) (-15 -3991 ($ |#1| |#1| $)))) (-1090)) (T -636)) 
-((-4020 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-636 *3)) (-4 *3 (-1090)))) (-3991 (*1 *1 *2 *2 *1) (-12 (-5 *1 (-636 *2)) (-4 *2 (-1090))))) 
-(-13 (-684 |#1|) (-10 -8 (-6 -4519) (-15 -4020 ((-121) $)) (-15 -3991 ($ |#1| |#1| $)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-3056 (($) 17 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ |#1| $) 22))) 
+((-4439 ((|#2| (-634 |#1|) (-634 |#2|) |#1| (-1 |#2| |#1|)) 18) (((-1 |#2| |#1|) (-634 |#1|) (-634 |#2|) (-1 |#2| |#1|)) 19) ((|#2| (-634 |#1|) (-634 |#2|) |#1| |#2|) 16) (((-1 |#2| |#1|) (-634 |#1|) (-634 |#2|) |#2|) 17) ((|#2| (-634 |#1|) (-634 |#2|) |#1|) 10) (((-1 |#2| |#1|) (-634 |#1|) (-634 |#2|)) 12))) 
+(((-631 |#1| |#2|) (-10 -7 (-15 -4439 ((-1 |#2| |#1|) (-634 |#1|) (-634 |#2|))) (-15 -4439 (|#2| (-634 |#1|) (-634 |#2|) |#1|)) (-15 -4439 ((-1 |#2| |#1|) (-634 |#1|) (-634 |#2|) |#2|)) (-15 -4439 (|#2| (-634 |#1|) (-634 |#2|) |#1| |#2|)) (-15 -4439 ((-1 |#2| |#1|) (-634 |#1|) (-634 |#2|) (-1 |#2| |#1|))) (-15 -4439 (|#2| (-634 |#1|) (-634 |#2|) |#1| (-1 |#2| |#1|)))) (-1090) (-1195)) (T -631)) 
+((-4439 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 *2)) (-5 *6 (-1 *2 *5)) (-4 *5 (-1090)) (-4 *2 (-1195)) (-5 *1 (-631 *5 *2)))) (-4439 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-1 *6 *5)) (-5 *3 (-634 *5)) (-5 *4 (-634 *6)) (-4 *5 (-1090)) (-4 *6 (-1195)) (-5 *1 (-631 *5 *6)))) (-4439 (*1 *2 *3 *4 *5 *2) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 *2)) (-4 *5 (-1090)) (-4 *2 (-1195)) (-5 *1 (-631 *5 *2)))) (-4439 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 *6)) (-5 *4 (-634 *5)) (-4 *6 (-1090)) (-4 *5 (-1195)) (-5 *2 (-1 *5 *6)) (-5 *1 (-631 *6 *5)))) (-4439 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 *2)) (-4 *5 (-1090)) (-4 *2 (-1195)) (-5 *1 (-631 *5 *2)))) (-4439 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 *6)) (-4 *5 (-1090)) (-4 *6 (-1195)) (-5 *2 (-1 *6 *5)) (-5 *1 (-631 *5 *6))))) 
+(-10 -7 (-15 -4439 ((-1 |#2| |#1|) (-634 |#1|) (-634 |#2|))) (-15 -4439 (|#2| (-634 |#1|) (-634 |#2|) |#1|)) (-15 -4439 ((-1 |#2| |#1|) (-634 |#1|) (-634 |#2|) |#2|)) (-15 -4439 (|#2| (-634 |#1|) (-634 |#2|) |#1| |#2|)) (-15 -4439 ((-1 |#2| |#1|) (-634 |#1|) (-634 |#2|) (-1 |#2| |#1|))) (-15 -4439 (|#2| (-634 |#1|) (-634 |#2|) |#1| (-1 |#2| |#1|)))) 
+((-1678 (((-634 |#2|) (-1 |#2| |#1| |#2|) (-634 |#1|) |#2|) 16)) (-3094 ((|#2| (-1 |#2| |#1| |#2|) (-634 |#1|) |#2|) 18)) (-2797 (((-634 |#2|) (-1 |#2| |#1|) (-634 |#1|)) 13))) 
+(((-632 |#1| |#2|) (-10 -7 (-15 -1678 ((-634 |#2|) (-1 |#2| |#1| |#2|) (-634 |#1|) |#2|)) (-15 -3094 (|#2| (-1 |#2| |#1| |#2|) (-634 |#1|) |#2|)) (-15 -2797 ((-634 |#2|) (-1 |#2| |#1|) (-634 |#1|)))) (-1195) (-1195)) (T -632)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-634 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-634 *6)) (-5 *1 (-632 *5 *6)))) (-3094 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-634 *5)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-632 *5 *2)))) (-1678 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-634 *6)) (-4 *6 (-1195)) (-4 *5 (-1195)) (-5 *2 (-634 *5)) (-5 *1 (-632 *6 *5))))) 
+(-10 -7 (-15 -1678 ((-634 |#2|) (-1 |#2| |#1| |#2|) (-634 |#1|) |#2|)) (-15 -3094 (|#2| (-1 |#2| |#1| |#2|) (-634 |#1|) |#2|)) (-15 -2797 ((-634 |#2|) (-1 |#2| |#1|) (-634 |#1|)))) 
+((-2797 (((-634 |#3|) (-1 |#3| |#1| |#2|) (-634 |#1|) (-634 |#2|)) 13))) 
+(((-633 |#1| |#2| |#3|) (-10 -7 (-15 -2797 ((-634 |#3|) (-1 |#3| |#1| |#2|) (-634 |#1|) (-634 |#2|)))) (-1195) (-1195) (-1195)) (T -633)) 
+((-2797 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-634 *6)) (-5 *5 (-634 *7)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-4 *8 (-1195)) (-5 *2 (-634 *8)) (-5 *1 (-633 *6 *7 *8))))) 
+(-10 -7 (-15 -2797 ((-634 |#3|) (-1 |#3| |#1| |#2|) (-634 |#1|) (-634 |#2|)))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2852 ((|#1| $) NIL)) (-2237 ((|#1| $) NIL)) (-3623 (($ $) NIL)) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-2121 (($ $ (-568)) NIL (|has| $ (-6 -4522)))) (-1324 (((-121) $) NIL (|has| |#1| (-842))) (((-121) (-1 (-121) |#1| |#1|) $) NIL)) (-2109 (($ $) NIL (-12 (|has| $ (-6 -4522)) (|has| |#1| (-842)))) (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-3647 (($ $) NIL (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-3370 ((|#1| $ |#1|) NIL (|has| $ (-6 -4522)))) (-1958 (($ $ $) NIL (|has| $ (-6 -4522)))) (-2257 ((|#1| $ |#1|) NIL (|has| $ (-6 -4522)))) (-1706 ((|#1| $ |#1|) NIL (|has| $ (-6 -4522)))) (-2438 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4522))) ((|#1| $ "first" |#1|) NIL (|has| $ (-6 -4522))) (($ $ "rest" $) NIL (|has| $ (-6 -4522))) ((|#1| $ "last" |#1|) NIL (|has| $ (-6 -4522))) ((|#1| $ (-1210 (-568)) |#1|) NIL (|has| $ (-6 -4522))) ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) NIL (|has| $ (-6 -4522)))) (-3977 (($ $ $) 31 (|has| |#1| (-1090)))) (-3962 (($ $ $) 33 (|has| |#1| (-1090)))) (-3954 (($ $ $) 36 (|has| |#1| (-1090)))) (-3963 (($ (-1 (-121) |#1|) $) NIL)) (-2803 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1681 ((|#1| $) NIL)) (-4490 (($) NIL T CONST)) (-4452 (($ $) NIL (|has| $ (-6 -4522)))) (-3945 (($ $) NIL)) (-3936 (($ $) NIL) (($ $ (-763)) NIL)) (-1377 (($ $) NIL (|has| |#1| (-1090)))) (-3926 (($ $) 30 (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1568 (($ |#1| $) NIL (|has| |#1| (-1090))) (($ (-1 (-121) |#1|) $) NIL)) (-4330 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (($ |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1292 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-568)) NIL)) (-1340 (((-121) $) NIL)) (-2766 (((-568) |#1| $ (-568)) NIL (|has| |#1| (-1090))) (((-568) |#1| $) NIL (|has| |#1| (-1090))) (((-568) (-1 (-121) |#1|) $) NIL)) (-3317 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2595 (((-121) $) 9)) (-3534 (((-634 $) $) NIL)) (-3606 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3973 (($) 7)) (-1851 (($ (-763) |#1|) NIL)) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) NIL (|has| (-568) (-842)))) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-4496 (($ $ $) NIL (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $ $) NIL)) (-3645 (($ $ $) NIL (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $ $) NIL)) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 32 (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3631 (((-568) $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-2253 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-3897 (($ |#1|) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-4081 (((-634 |#1|) $) NIL)) (-3319 (((-121) $) NIL)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4164 ((|#1| $) NIL) (($ $ (-763)) NIL)) (-1708 (($ $ $ (-568)) NIL) (($ |#1| $ (-568)) NIL)) (-4124 (($ $ $ (-568)) NIL) (($ |#1| $ (-568)) NIL)) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3877 ((|#1| $) NIL) (($ $ (-763)) NIL)) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-2490 (($ $ |#1|) NIL (|has| $ (-6 -4522)))) (-4049 (((-121) $) NIL)) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#1| $ "value") NIL) ((|#1| $ "first") NIL) (($ $ "rest") NIL) ((|#1| $ "last") NIL) (($ $ (-1210 (-568))) NIL) ((|#1| $ (-568)) 35) ((|#1| $ (-568) |#1|) NIL)) (-1665 (((-568) $ $) NIL)) (-4031 (($ $ (-1210 (-568))) NIL) (($ $ (-568)) NIL)) (-2828 (($ $ (-1210 (-568))) NIL) (($ $ (-568)) NIL)) (-2763 (((-121) $) NIL)) (-3903 (($ $) NIL)) (-1499 (($ $) NIL (|has| $ (-6 -4522)))) (-3535 (((-763) $) NIL)) (-4424 (($ $) NIL)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3306 (($ $ $ (-568)) NIL (|has| $ (-6 -4522)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) 44 (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) NIL)) (-3856 (($ |#1| $) 10)) (-1876 (($ $ $) NIL) (($ $ |#1|) NIL)) (-2770 (($ $ $) 29) (($ |#1| $) NIL) (($ (-634 $)) NIL) (($ $ |#1|) NIL)) (-2747 (((-850) $) NIL (|has| |#1| (-1090)))) (-3180 (((-634 $) $) NIL)) (-3873 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1857 (($ $ $) 11)) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-2628 (((-1143) $) 25 (|has| |#1| (-823))) (((-1143) $ (-121)) 26 (|has| |#1| (-823))) (((-1249) (-817) $) 27 (|has| |#1| (-823))) (((-1249) (-817) $ (-121)) 28 (|has| |#1| (-823)))) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-634 |#1|) (-13 (-658 |#1|) (-10 -8 (-15 -3973 ($)) (-15 -2595 ((-121) $)) (-15 -3856 ($ |#1| $)) (-15 -1857 ($ $ $)) (IF (|has| |#1| (-1090)) (PROGN (-15 -3977 ($ $ $)) (-15 -3962 ($ $ $)) (-15 -3954 ($ $ $))) |noBranch|) (IF (|has| |#1| (-823)) (-6 (-823)) |noBranch|))) (-1195)) (T -634)) 
+((-3973 (*1 *1) (-12 (-5 *1 (-634 *2)) (-4 *2 (-1195)))) (-2595 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-634 *3)) (-4 *3 (-1195)))) (-3856 (*1 *1 *2 *1) (-12 (-5 *1 (-634 *2)) (-4 *2 (-1195)))) (-1857 (*1 *1 *1 *1) (-12 (-5 *1 (-634 *2)) (-4 *2 (-1195)))) (-3977 (*1 *1 *1 *1) (-12 (-5 *1 (-634 *2)) (-4 *2 (-1090)) (-4 *2 (-1195)))) (-3962 (*1 *1 *1 *1) (-12 (-5 *1 (-634 *2)) (-4 *2 (-1090)) (-4 *2 (-1195)))) (-3954 (*1 *1 *1 *1) (-12 (-5 *1 (-634 *2)) (-4 *2 (-1090)) (-4 *2 (-1195))))) 
+(-13 (-658 |#1|) (-10 -8 (-15 -3973 ($)) (-15 -2595 ((-121) $)) (-15 -3856 ($ |#1| $)) (-15 -1857 ($ $ $)) (IF (|has| |#1| (-1090)) (PROGN (-15 -3977 ($ $ $)) (-15 -3962 ($ $ $)) (-15 -3954 ($ $ $))) |noBranch|) (IF (|has| |#1| (-823)) (-6 (-823)) |noBranch|))) 
+((-1932 (((-634 |#1|) |#2| (-568)) 21)) (-2092 (((-679 |#1|) (-634 |#2|) (-568)) 30)) (-3531 (((-679 |#1|) (-634 |#2|) (-568)) 28))) 
+(((-635 |#1| |#2|) (-10 -7 (-15 -2092 ((-679 |#1|) (-634 |#2|) (-568))) (-15 -3531 ((-679 |#1|) (-634 |#2|) (-568))) (-15 -1932 ((-634 |#1|) |#2| (-568)))) (-365) (-641 |#1|)) (T -635)) 
+((-1932 (*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-365)) (-5 *2 (-634 *5)) (-5 *1 (-635 *5 *3)) (-4 *3 (-641 *5)))) (-3531 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-568)) (-4 *6 (-641 *5)) (-4 *5 (-365)) (-5 *2 (-679 *5)) (-5 *1 (-635 *5 *6)))) (-2092 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-568)) (-4 *6 (-641 *5)) (-4 *5 (-365)) (-5 *2 (-679 *5)) (-5 *1 (-635 *5 *6))))) 
+(-10 -7 (-15 -2092 ((-679 |#1|) (-634 |#2|) (-568))) (-15 -3531 ((-679 |#1|) (-634 |#2|) (-568))) (-15 -1932 ((-634 |#1|) |#2| (-568)))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3989 (($ |#1| |#1| $) 43)) (-1667 (((-121) $ (-763)) NIL)) (-3963 (($ (-1 (-121) |#1|) $) 56 (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-4490 (($) NIL T CONST)) (-1377 (($ $) 45)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1568 (($ |#1| $) 51 (|has| $ (-6 -4521))) (($ (-1 (-121) |#1|) $) 53 (|has| $ (-6 -4521)))) (-4330 (($ |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4521)))) (-3317 (((-634 |#1|) $) 9 (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) NIL)) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-2253 (($ (-1 |#1| |#1|) $) 39 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 37)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-2580 ((|#1| $) 46)) (-1708 (($ |#1| $) 26) (($ |#1| $ (-763)) 42)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3403 ((|#1| $) 48)) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) 21)) (-1990 (($) 25)) (-1433 (((-121) $) 49)) (-2138 (((-634 (-2 (|:| -4085 |#1|) (|:| -4170 (-763)))) $) 60)) (-3132 (($) 23) (($ (-634 |#1|)) 18)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) 57 (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) 19)) (-4280 (((-541) $) 34 (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) NIL)) (-2747 (((-850) $) 14 (|has| |#1| (-1090)))) (-4074 (($ (-634 |#1|)) 22)) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 62 (|has| |#1| (-1090)))) (-1699 (((-763) $) 16 (|has| $ (-6 -4521))))) 
+(((-636 |#1|) (-13 (-684 |#1|) (-10 -8 (-6 -4521) (-15 -1433 ((-121) $)) (-15 -3989 ($ |#1| |#1| $)))) (-1090)) (T -636)) 
+((-1433 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-636 *3)) (-4 *3 (-1090)))) (-3989 (*1 *1 *2 *2 *1) (-12 (-5 *1 (-636 *2)) (-4 *2 (-1090))))) 
+(-13 (-684 |#1|) (-10 -8 (-6 -4521) (-15 -1433 ((-121) $)) (-15 -3989 ($ |#1| |#1| $)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-3058 (($) 17 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ |#1| $) 22))) 
 (((-637 |#1|) (-1275) (-1054)) (T -637)) 
 ((* (*1 *1 *2 *1) (-12 (-4 *1 (-637 *2)) (-4 *2 (-1054))))) 
 (-13 (-21) (-10 -8 (-15 * ($ |t#1| $)))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-137) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-3983 (((-763) $) 15)) (-2543 (($ $ |#1|) 55)) (-1578 (($ $) 32)) (-3943 (($ $) 31)) (-3666 (((-3 |#1| "failed") $) 47)) (-2854 ((|#1| $) NIL)) (-1548 (($ |#1| |#2| $) 60) (($ $ $) 61)) (-3680 (((-850) $ (-1 (-850) (-850) (-850)) (-1 (-850) (-850) (-850)) (-568)) 45)) (-2882 ((|#1| $ (-568)) 30)) (-2408 ((|#2| $ (-568)) 29)) (-2096 (($ (-1 |#1| |#1|) $) 34)) (-2505 (($ (-1 |#2| |#2|) $) 38)) (-2640 (($) 10)) (-2955 (($ |#1| |#2|) 22)) (-2552 (($ (-634 (-2 (|:| |gen| |#1|) (|:| -1892 |#2|)))) 23)) (-2513 (((-634 (-2 (|:| |gen| |#1|) (|:| -1892 |#2|))) $) 13)) (-4094 (($ |#1| $) 56)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-4246 (((-121) $ $) 58)) (-2745 (((-850) $) 19) (($ |#1|) 16)) (-1717 (((-121) $ $) 25))) 
-(((-638 |#1| |#2| |#3|) (-13 (-1090) (-1037 |#1|) (-10 -8 (-15 -3680 ((-850) $ (-1 (-850) (-850) (-850)) (-1 (-850) (-850) (-850)) (-568))) (-15 -2513 ((-634 (-2 (|:| |gen| |#1|) (|:| -1892 |#2|))) $)) (-15 -2955 ($ |#1| |#2|)) (-15 -2552 ($ (-634 (-2 (|:| |gen| |#1|) (|:| -1892 |#2|))))) (-15 -2408 (|#2| $ (-568))) (-15 -2882 (|#1| $ (-568))) (-15 -3943 ($ $)) (-15 -1578 ($ $)) (-15 -3983 ((-763) $)) (-15 -2640 ($)) (-15 -2543 ($ $ |#1|)) (-15 -4094 ($ |#1| $)) (-15 -1548 ($ |#1| |#2| $)) (-15 -1548 ($ $ $)) (-15 -4246 ((-121) $ $)) (-15 -2505 ($ (-1 |#2| |#2|) $)) (-15 -2096 ($ (-1 |#1| |#1|) $)))) (-1090) (-23) |#2|) (T -638)) 
-((-3680 (*1 *2 *1 *3 *3 *4) (-12 (-5 *3 (-1 (-850) (-850) (-850))) (-5 *4 (-568)) (-5 *2 (-850)) (-5 *1 (-638 *5 *6 *7)) (-4 *5 (-1090)) (-4 *6 (-23)) (-14 *7 *6))) (-2513 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1892 *4)))) (-5 *1 (-638 *3 *4 *5)) (-4 *3 (-1090)) (-4 *4 (-23)) (-14 *5 *4))) (-2955 (*1 *1 *2 *3) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3))) (-2552 (*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1892 *4)))) (-4 *3 (-1090)) (-4 *4 (-23)) (-14 *5 *4) (-5 *1 (-638 *3 *4 *5)))) (-2408 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *2 (-23)) (-5 *1 (-638 *4 *2 *5)) (-4 *4 (-1090)) (-14 *5 *2))) (-2882 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *2 (-1090)) (-5 *1 (-638 *2 *4 *5)) (-4 *4 (-23)) (-14 *5 *4))) (-3943 (*1 *1 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3))) (-1578 (*1 *1 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3))) (-3983 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-638 *3 *4 *5)) (-4 *3 (-1090)) (-4 *4 (-23)) (-14 *5 *4))) (-2640 (*1 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3))) (-2543 (*1 *1 *1 *2) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3))) (-4094 (*1 *1 *2 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3))) (-1548 (*1 *1 *2 *3 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3))) (-1548 (*1 *1 *1 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3))) (-4246 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-638 *3 *4 *5)) (-4 *3 (-1090)) (-4 *4 (-23)) (-14 *5 *4))) (-2505 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-23)) (-14 *5 *4) (-5 *1 (-638 *3 *4 *5)) (-4 *3 (-1090)))) (-2096 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-638 *3 *4 *5)) (-4 *4 (-23)) (-14 *5 *4)))) 
-(-13 (-1090) (-1037 |#1|) (-10 -8 (-15 -3680 ((-850) $ (-1 (-850) (-850) (-850)) (-1 (-850) (-850) (-850)) (-568))) (-15 -2513 ((-634 (-2 (|:| |gen| |#1|) (|:| -1892 |#2|))) $)) (-15 -2955 ($ |#1| |#2|)) (-15 -2552 ($ (-634 (-2 (|:| |gen| |#1|) (|:| -1892 |#2|))))) (-15 -2408 (|#2| $ (-568))) (-15 -2882 (|#1| $ (-568))) (-15 -3943 ($ $)) (-15 -1578 ($ $)) (-15 -3983 ((-763) $)) (-15 -2640 ($)) (-15 -2543 ($ $ |#1|)) (-15 -4094 ($ |#1| $)) (-15 -1548 ($ |#1| |#2| $)) (-15 -1548 ($ $ $)) (-15 -4246 ((-121) $ $)) (-15 -2505 ($ (-1 |#2| |#2|) $)) (-15 -2096 ($ (-1 |#1| |#1|) $)))) 
-((-2223 (((-568) $) 23)) (-4122 (($ |#2| $ (-568)) 21) (($ $ $ (-568)) NIL)) (-4174 (((-634 (-568)) $) 12)) (-3578 (((-121) (-568) $) 14)) (-2768 (($ $ |#2|) 18) (($ |#2| $) 19) (($ $ $) NIL) (($ (-634 $)) NIL))) 
-(((-639 |#1| |#2|) (-10 -8 (-15 -4122 (|#1| |#1| |#1| (-568))) (-15 -4122 (|#1| |#2| |#1| (-568))) (-15 -2768 (|#1| (-634 |#1|))) (-15 -2768 (|#1| |#1| |#1|)) (-15 -2768 (|#1| |#2| |#1|)) (-15 -2768 (|#1| |#1| |#2|)) (-15 -2223 ((-568) |#1|)) (-15 -4174 ((-634 (-568)) |#1|)) (-15 -3578 ((-121) (-568) |#1|))) (-640 |#2|) (-1195)) (T -639)) 
-NIL 
-(-10 -8 (-15 -4122 (|#1| |#1| |#1| (-568))) (-15 -4122 (|#1| |#2| |#1| (-568))) (-15 -2768 (|#1| (-634 |#1|))) (-15 -2768 (|#1| |#1| |#1|)) (-15 -2768 (|#1| |#2| |#1|)) (-15 -2768 (|#1| |#1| |#2|)) (-15 -2223 ((-568) |#1|)) (-15 -4174 ((-634 (-568)) |#1|)) (-15 -3578 ((-121) (-568) |#1|))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-1868 (((-1249) $ (-568) (-568)) 37 (|has| $ (-6 -4520)))) (-2510 (((-121) $ (-763)) 8)) (-2436 ((|#1| $ (-568) |#1|) 49 (|has| $ (-6 -4520))) ((|#1| $ (-1210 (-568)) |#1|) 53 (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) |#1|) $) 70 (|has| $ (-6 -4519)))) (-2671 (($) 7 T CONST)) (-3924 (($ $) 73 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-4328 (($ |#1| $) 72 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) |#1|) $) 69 (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4519)))) (-3989 ((|#1| $ (-568) |#1|) 50 (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-568)) 48)) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-1849 (($ (-763) |#1|) 64)) (-1737 (((-121) $ (-763)) 9)) (-1881 (((-568) $) 40 (|has| (-568) (-842)))) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-2223 (((-568) $) 41 (|has| (-568) (-842)))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-2166 (((-121) $ (-763)) 10)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4122 (($ |#1| $ (-568)) 55) (($ $ $ (-568)) 54)) (-4174 (((-634 (-568)) $) 43)) (-3578 (((-121) (-568) $) 44)) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3876 ((|#1| $) 39 (|has| (-568) (-842)))) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 66)) (-3724 (($ $ |#1|) 38 (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-4467 (((-121) |#1| $) 42 (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) 45)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 ((|#1| $ (-568) |#1|) 47) ((|#1| $ (-568)) 46) (($ $ (-1210 (-568))) 58)) (-2826 (($ $ (-568)) 57) (($ $ (-1210 (-568))) 56)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-4278 (((-541) $) 74 (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) 65)) (-2768 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-634 $)) 60)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL)) (-3986 (((-763) $) 15)) (-1842 (($ $ |#1|) 55)) (-4452 (($ $) 32)) (-3945 (($ $) 31)) (-3668 (((-3 |#1| "failed") $) 47)) (-2857 ((|#1| $) NIL)) (-4290 (($ |#1| |#2| $) 60) (($ $ $) 61)) (-2276 (((-850) $ (-1 (-850) (-850) (-850)) (-1 (-850) (-850) (-850)) (-568)) 45)) (-4167 ((|#1| $ (-568)) 30)) (-2315 ((|#2| $ (-568)) 29)) (-3177 (($ (-1 |#1| |#1|) $) 34)) (-1644 (($ (-1 |#2| |#2|) $) 38)) (-4317 (($) 10)) (-3000 (($ |#1| |#2|) 22)) (-1886 (($ (-634 (-2 (|:| |gen| |#1|) (|:| -1894 |#2|)))) 23)) (-1684 (((-634 (-2 (|:| |gen| |#1|) (|:| -1894 |#2|))) $) 13)) (-3516 (($ |#1| $) 56)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2854 (((-121) $ $) 58)) (-2747 (((-850) $) 19) (($ |#1|) 16)) (-1719 (((-121) $ $) 25))) 
+(((-638 |#1| |#2| |#3|) (-13 (-1090) (-1037 |#1|) (-10 -8 (-15 -2276 ((-850) $ (-1 (-850) (-850) (-850)) (-1 (-850) (-850) (-850)) (-568))) (-15 -1684 ((-634 (-2 (|:| |gen| |#1|) (|:| -1894 |#2|))) $)) (-15 -3000 ($ |#1| |#2|)) (-15 -1886 ($ (-634 (-2 (|:| |gen| |#1|) (|:| -1894 |#2|))))) (-15 -2315 (|#2| $ (-568))) (-15 -4167 (|#1| $ (-568))) (-15 -3945 ($ $)) (-15 -4452 ($ $)) (-15 -3986 ((-763) $)) (-15 -4317 ($)) (-15 -1842 ($ $ |#1|)) (-15 -3516 ($ |#1| $)) (-15 -4290 ($ |#1| |#2| $)) (-15 -4290 ($ $ $)) (-15 -2854 ((-121) $ $)) (-15 -1644 ($ (-1 |#2| |#2|) $)) (-15 -3177 ($ (-1 |#1| |#1|) $)))) (-1090) (-23) |#2|) (T -638)) 
+((-2276 (*1 *2 *1 *3 *3 *4) (-12 (-5 *3 (-1 (-850) (-850) (-850))) (-5 *4 (-568)) (-5 *2 (-850)) (-5 *1 (-638 *5 *6 *7)) (-4 *5 (-1090)) (-4 *6 (-23)) (-14 *7 *6))) (-1684 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1894 *4)))) (-5 *1 (-638 *3 *4 *5)) (-4 *3 (-1090)) (-4 *4 (-23)) (-14 *5 *4))) (-3000 (*1 *1 *2 *3) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3))) (-1886 (*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1894 *4)))) (-4 *3 (-1090)) (-4 *4 (-23)) (-14 *5 *4) (-5 *1 (-638 *3 *4 *5)))) (-2315 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *2 (-23)) (-5 *1 (-638 *4 *2 *5)) (-4 *4 (-1090)) (-14 *5 *2))) (-4167 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *2 (-1090)) (-5 *1 (-638 *2 *4 *5)) (-4 *4 (-23)) (-14 *5 *4))) (-3945 (*1 *1 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3))) (-4452 (*1 *1 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3))) (-3986 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-638 *3 *4 *5)) (-4 *3 (-1090)) (-4 *4 (-23)) (-14 *5 *4))) (-4317 (*1 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3))) (-1842 (*1 *1 *1 *2) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3))) (-3516 (*1 *1 *2 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3))) (-4290 (*1 *1 *2 *3 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3))) (-4290 (*1 *1 *1 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3))) (-2854 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-638 *3 *4 *5)) (-4 *3 (-1090)) (-4 *4 (-23)) (-14 *5 *4))) (-1644 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-23)) (-14 *5 *4) (-5 *1 (-638 *3 *4 *5)) (-4 *3 (-1090)))) (-3177 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-638 *3 *4 *5)) (-4 *4 (-23)) (-14 *5 *4)))) 
+(-13 (-1090) (-1037 |#1|) (-10 -8 (-15 -2276 ((-850) $ (-1 (-850) (-850) (-850)) (-1 (-850) (-850) (-850)) (-568))) (-15 -1684 ((-634 (-2 (|:| |gen| |#1|) (|:| -1894 |#2|))) $)) (-15 -3000 ($ |#1| |#2|)) (-15 -1886 ($ (-634 (-2 (|:| |gen| |#1|) (|:| -1894 |#2|))))) (-15 -2315 (|#2| $ (-568))) (-15 -4167 (|#1| $ (-568))) (-15 -3945 ($ $)) (-15 -4452 ($ $)) (-15 -3986 ((-763) $)) (-15 -4317 ($)) (-15 -1842 ($ $ |#1|)) (-15 -3516 ($ |#1| $)) (-15 -4290 ($ |#1| |#2| $)) (-15 -4290 ($ $ $)) (-15 -2854 ((-121) $ $)) (-15 -1644 ($ (-1 |#2| |#2|) $)) (-15 -3177 ($ (-1 |#1| |#1|) $)))) 
+((-3631 (((-568) $) 23)) (-4124 (($ |#2| $ (-568)) 21) (($ $ $ (-568)) NIL)) (-3948 (((-634 (-568)) $) 12)) (-2916 (((-121) (-568) $) 14)) (-2770 (($ $ |#2|) 18) (($ |#2| $) 19) (($ $ $) NIL) (($ (-634 $)) NIL))) 
+(((-639 |#1| |#2|) (-10 -8 (-15 -4124 (|#1| |#1| |#1| (-568))) (-15 -4124 (|#1| |#2| |#1| (-568))) (-15 -2770 (|#1| (-634 |#1|))) (-15 -2770 (|#1| |#1| |#1|)) (-15 -2770 (|#1| |#2| |#1|)) (-15 -2770 (|#1| |#1| |#2|)) (-15 -3631 ((-568) |#1|)) (-15 -3948 ((-634 (-568)) |#1|)) (-15 -2916 ((-121) (-568) |#1|))) (-640 |#2|) (-1195)) (T -639)) 
+NIL 
+(-10 -8 (-15 -4124 (|#1| |#1| |#1| (-568))) (-15 -4124 (|#1| |#2| |#1| (-568))) (-15 -2770 (|#1| (-634 |#1|))) (-15 -2770 (|#1| |#1| |#1|)) (-15 -2770 (|#1| |#2| |#1|)) (-15 -2770 (|#1| |#1| |#2|)) (-15 -3631 ((-568) |#1|)) (-15 -3948 ((-634 (-568)) |#1|)) (-15 -2916 ((-121) (-568) |#1|))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2481 (((-1249) $ (-568) (-568)) 37 (|has| $ (-6 -4522)))) (-1667 (((-121) $ (-763)) 8)) (-2438 ((|#1| $ (-568) |#1|) 49 (|has| $ (-6 -4522))) ((|#1| $ (-1210 (-568)) |#1|) 53 (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) |#1|) $) 70 (|has| $ (-6 -4521)))) (-4490 (($) 7 T CONST)) (-3926 (($ $) 73 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-4330 (($ |#1| $) 72 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) |#1|) $) 69 (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4521)))) (-1292 ((|#1| $ (-568) |#1|) 50 (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-568)) 48)) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-1851 (($ (-763) |#1|) 64)) (-3791 (((-121) $ (-763)) 9)) (-2539 (((-568) $) 40 (|has| (-568) (-842)))) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3631 (((-568) $) 41 (|has| (-568) (-842)))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-3796 (((-121) $ (-763)) 10)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4124 (($ |#1| $ (-568)) 55) (($ $ $ (-568)) 54)) (-3948 (((-634 (-568)) $) 43)) (-2916 (((-121) (-568) $) 44)) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3877 ((|#1| $) 39 (|has| (-568) (-842)))) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 66)) (-2490 (($ $ |#1|) 38 (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-1801 (((-121) |#1| $) 42 (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) 45)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 ((|#1| $ (-568) |#1|) 47) ((|#1| $ (-568)) 46) (($ $ (-1210 (-568))) 58)) (-2828 (($ $ (-568)) 57) (($ $ (-1210 (-568))) 56)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-4280 (((-541) $) 74 (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) 65)) (-2770 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-634 $)) 60)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-640 |#1|) (-1275) (-1195)) (T -640)) 
-((-1849 (*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) (-2768 (*1 *1 *1 *2) (-12 (-4 *1 (-640 *2)) (-4 *2 (-1195)))) (-2768 (*1 *1 *2 *1) (-12 (-4 *1 (-640 *2)) (-4 *2 (-1195)))) (-2768 (*1 *1 *1 *1) (-12 (-4 *1 (-640 *2)) (-4 *2 (-1195)))) (-2768 (*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) (-2795 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) (-2779 (*1 *1 *1 *2) (-12 (-5 *2 (-1210 (-568))) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) (-2826 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) (-2826 (*1 *1 *1 *2) (-12 (-5 *2 (-1210 (-568))) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) (-4122 (*1 *1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-640 *2)) (-4 *2 (-1195)))) (-4122 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) (-2436 (*1 *2 *1 *3 *2) (-12 (-5 *3 (-1210 (-568))) (|has| *1 (-6 -4520)) (-4 *1 (-640 *2)) (-4 *2 (-1195))))) 
-(-13 (-601 (-568) |t#1|) (-154 |t#1|) (-10 -8 (-15 -1849 ($ (-763) |t#1|)) (-15 -2768 ($ $ |t#1|)) (-15 -2768 ($ |t#1| $)) (-15 -2768 ($ $ $)) (-15 -2768 ($ (-634 $))) (-15 -2795 ($ (-1 |t#1| |t#1| |t#1|) $ $)) (-15 -2779 ($ $ (-1210 (-568)))) (-15 -2826 ($ $ (-568))) (-15 -2826 ($ $ (-1210 (-568)))) (-15 -4122 ($ |t#1| $ (-568))) (-15 -4122 ($ $ $ (-568))) (IF (|has| $ (-6 -4520)) (-15 -2436 (|t#1| $ (-1210 (-568)) |t#1|)) |noBranch|))) 
+((-1851 (*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) (-2770 (*1 *1 *1 *2) (-12 (-4 *1 (-640 *2)) (-4 *2 (-1195)))) (-2770 (*1 *1 *2 *1) (-12 (-4 *1 (-640 *2)) (-4 *2 (-1195)))) (-2770 (*1 *1 *1 *1) (-12 (-4 *1 (-640 *2)) (-4 *2 (-1195)))) (-2770 (*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) (-2797 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) (-2781 (*1 *1 *1 *2) (-12 (-5 *2 (-1210 (-568))) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) (-2828 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) (-2828 (*1 *1 *1 *2) (-12 (-5 *2 (-1210 (-568))) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) (-4124 (*1 *1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-640 *2)) (-4 *2 (-1195)))) (-4124 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) (-2438 (*1 *2 *1 *3 *2) (-12 (-5 *3 (-1210 (-568))) (|has| *1 (-6 -4522)) (-4 *1 (-640 *2)) (-4 *2 (-1195))))) 
+(-13 (-601 (-568) |t#1|) (-154 |t#1|) (-10 -8 (-15 -1851 ($ (-763) |t#1|)) (-15 -2770 ($ $ |t#1|)) (-15 -2770 ($ |t#1| $)) (-15 -2770 ($ $ $)) (-15 -2770 ($ (-634 $))) (-15 -2797 ($ (-1 |t#1| |t#1| |t#1|) $ $)) (-15 -2781 ($ $ (-1210 (-568)))) (-15 -2828 ($ $ (-568))) (-15 -2828 ($ $ (-1210 (-568)))) (-15 -4124 ($ |t#1| $ (-568))) (-15 -4124 ($ $ $ (-568))) (IF (|has| $ (-6 -4522)) (-15 -2438 (|t#1| $ (-1210 (-568)) |t#1|)) |noBranch|))) 
 (((-39) . T) ((-105) |has| |#1| (-1090)) ((-608 (-850)) |has| |#1| (-1090)) ((-154 |#1|) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-281 (-568) |#1|) . T) ((-283 (-568) |#1|) . T) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-601 (-568) |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-1090) |has| |#1| (-1090)) ((-1195) . T)) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-2055 (((-634 (-1075)) $) 115)) (-1305 (((-1161) $) 120)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-2617 (($ $ (-568) (-568)) 126) (($ $ (-568)) 125)) (-2583 (((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) 118)) (-3134 (((-3 $ "failed") $ $) 18)) (-4305 (($ $) 71)) (-1678 (((-420 $) $) 70)) (-1497 (((-121) $ $) 57)) (-1870 (($ $ (-568)) 86)) (-3728 (($ (-568) |#1| $) 87)) (-3975 (($ $ $) 92)) (-2671 (($) 16 T CONST)) (-1429 (($ (-568) $) 89) (($ $) 88)) (-2255 (($ $) 93)) (-2401 (($ $ $) 53)) (-2114 (($ $) 108)) (-2925 (((-3 $ "failed") $) 33)) (-2412 (($ $ $) 54)) (-1277 (((-121) (-121)) 83) (((-121)) 82)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 49)) (-3927 (((-121) $) 69)) (-2421 (($ $) 95)) (-3992 (((-121) $) 116)) (-2455 (((-3 (-568) "failed") $) 94)) (-4477 (((-568) $ (-568)) 124) (((-568) $) 123) (((-568) $) 99)) (-2735 (((-121) $) 30)) (-3536 (($ $ (-917)) 122)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-3921 (((-121) $) 106)) (-2662 (($ (-634 $) (-634 (-763)) (-568)) 90)) (-2047 (($ $ (-634 (-1075)) (-634 (-568))) 114) (($ $ (-1075) (-568)) 113) (($ |#1| (-568)) 107)) (-2795 (($ (-1 |#1| |#1|) $) 105)) (-2097 (($ $) 103)) (-2102 ((|#1| $) 102)) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-2081 (($ $) 68)) (-4022 (((-1108) $) 10)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-1987 ((|#1| $ (-568)) 98)) (-4273 (($ $ (-568)) 85)) (-3848 (((-420 $) $) 72)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-1807 (($ $ (-568)) 128)) (-2595 (((-3 $ "failed") $ $) 41)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-1339 (((-1141 |#1|) $ |#1|) 129 (|has| |#1| (-15 ** (|#1| |#1| (-568)))))) (-2709 (((-763) $) 56)) (-2779 (($ $ $) 142 (|has| (-568) (-1102))) ((|#1| $ (-568)) 119)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 55)) (-4189 (($ $) 141 (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $ (-763)) 139 (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $ (-1161)) 137 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161))) 136 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-1161) (-763)) 135 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161)) (-634 (-763))) 134 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|)))))) (-4493 (($ (-1 $)) 91)) (-3206 (((-568) $) 104)) (-1811 (($ $) 117)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63) (($ |#1|) 112 (|has| |#1| (-172))) (($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) 97) (((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) 96)) (-2604 ((|#1| $ (-568)) 109)) (-4447 ((|#1| $) 84)) (-4371 (((-3 $ "failed") $) 111 (|has| |#1| (-148)))) (-4078 (((-763)) 28)) (-1374 ((|#1| $) 121)) (-1826 (((-121) $ $) 38)) (-3996 ((|#1| $ (-568)) 127 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-568)))) (|has| |#1| (-15 -2745 (|#1| (-1161))))))) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $) 140 (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $ (-763)) 138 (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $ (-1161)) 133 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161))) 132 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-1161) (-763)) 131 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161)) (-634 (-763))) 130 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|)))))) (-1717 (((-121) $ $) 6)) (-1779 (($ $ $) 62) (($ $ |#1|) 110 (|has| |#1| (-365)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64) (($ |#1| $) 101) (($ $ |#1|) 100))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2057 (((-634 (-1075)) $) 115)) (-3325 (((-1161) $) 120)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-4179 (($ $ (-568) (-568)) 126) (($ $ (-568)) 125)) (-2013 (((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) 118)) (-2689 (((-3 $ "failed") $ $) 18)) (-3045 (($ $) 71)) (-3498 (((-420 $) $) 70)) (-2589 (((-121) $ $) 57)) (-1872 (($ $ (-568)) 86)) (-2512 (($ (-568) |#1| $) 87)) (-4461 (($ $ $) 92)) (-4490 (($) 16 T CONST)) (-2232 (($ (-568) $) 89) (($ $) 88)) (-3297 (($ $) 93)) (-2403 (($ $ $) 53)) (-2116 (($ $) 108)) (-2902 (((-3 $ "failed") $) 33)) (-2414 (($ $ $) 54)) (-1277 (((-121) (-121)) 83) (((-121)) 82)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 49)) (-2197 (((-121) $) 69)) (-2379 (($ $) 95)) (-1302 (((-121) $) 116)) (-2545 (((-3 (-568) "failed") $) 94)) (-1844 (((-568) $ (-568)) 124) (((-568) $) 123) (((-568) $) 99)) (-1598 (((-121) $) 30)) (-4168 (($ $ (-917)) 122)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-2171 (((-121) $) 106)) (-4444 (($ (-634 $) (-634 (-763)) (-568)) 90)) (-2049 (($ $ (-634 (-1075)) (-634 (-568))) 114) (($ $ (-1075) (-568)) 113) (($ |#1| (-568)) 107)) (-2797 (($ (-1 |#1| |#1|) $) 105)) (-2099 (($ $) 103)) (-2104 ((|#1| $) 102)) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-2083 (($ $) 68)) (-4025 (((-1108) $) 10)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-4438 ((|#1| $ (-568)) 98)) (-2938 (($ $ (-568)) 85)) (-3850 (((-420 $) $) 72)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2168 (($ $ (-568)) 128)) (-2597 (((-3 $ "failed") $ $) 41)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-1339 (((-1141 |#1|) $ |#1|) 129 (|has| |#1| (-15 ** (|#1| |#1| (-568)))))) (-1466 (((-763) $) 56)) (-2781 (($ $ $) 142 (|has| (-568) (-1102))) ((|#1| $ (-568)) 119)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 55)) (-4191 (($ $) 141 (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $ (-763)) 139 (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $ (-1161)) 137 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161))) 136 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-1161) (-763)) 135 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161)) (-634 (-763))) 134 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|)))))) (-1922 (($ (-1 $)) 91)) (-1836 (((-568) $) 104)) (-2188 (($ $) 117)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63) (($ |#1|) 112 (|has| |#1| (-172))) (($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) 97) (((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) 96)) (-2079 ((|#1| $ (-568)) 109)) (-1691 ((|#1| $) 84)) (-3385 (((-3 $ "failed") $) 111 (|has| |#1| (-148)))) (-3425 (((-763)) 28)) (-1374 ((|#1| $) 121)) (-2273 (((-121) $ $) 38)) (-3999 ((|#1| $ (-568)) 127 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-568)))) (|has| |#1| (-15 -2747 (|#1| (-1161))))))) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $) 140 (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $ (-763)) 138 (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $ (-1161)) 133 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161))) 132 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-1161) (-763)) 131 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161)) (-634 (-763))) 130 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|)))))) (-1719 (((-121) $ $) 6)) (-1781 (($ $ $) 62) (($ $ |#1|) 110 (|has| |#1| (-365)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64) (($ |#1| $) 101) (($ $ |#1|) 100))) 
 (((-641 |#1|) (-1275) (-365)) (T -641)) 
-((-4477 (*1 *2 *1) (-12 (-4 *1 (-641 *3)) (-4 *3 (-365)) (-5 *2 (-568)))) (-4477 (*1 *2 *1) (-12 (-4 *1 (-641 *3)) (-4 *3 (-365)) (-5 *2 (-568)))) (-1987 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-641 *2)) (-4 *2 (-365)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *3)))) (-4 *3 (-365)) (-4 *1 (-641 *3)))) (-2745 (*1 *2 *1) (-12 (-4 *1 (-641 *3)) (-4 *3 (-365)) (-5 *2 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *3)))))) (-2421 (*1 *1 *1) (-12 (-4 *1 (-641 *2)) (-4 *2 (-365)))) (-2455 (*1 *2 *1) (|partial| -12 (-4 *1 (-641 *3)) (-4 *3 (-365)) (-5 *2 (-568)))) (-2255 (*1 *1 *1) (-12 (-4 *1 (-641 *2)) (-4 *2 (-365)))) (-3975 (*1 *1 *1 *1) (-12 (-4 *1 (-641 *2)) (-4 *2 (-365)))) (-4493 (*1 *1 *2) (-12 (-5 *2 (-1 *1)) (-4 *1 (-641 *3)) (-4 *3 (-365)))) (-2662 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-634 *1)) (-5 *3 (-634 (-763))) (-5 *4 (-568)) (-4 *1 (-641 *5)) (-4 *5 (-365)))) (-1429 (*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-4 *1 (-641 *3)) (-4 *3 (-365)))) (-1429 (*1 *1 *1) (-12 (-4 *1 (-641 *2)) (-4 *2 (-365)))) (-3728 (*1 *1 *2 *3 *1) (-12 (-5 *2 (-568)) (-4 *1 (-641 *3)) (-4 *3 (-365)))) (-1870 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-641 *3)) (-4 *3 (-365)))) (-4273 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-641 *3)) (-4 *3 (-365)))) (-4447 (*1 *2 *1) (-12 (-4 *1 (-641 *2)) (-4 *2 (-365)))) (-1277 (*1 *2 *2) (-12 (-5 *2 (-121)) (-4 *1 (-641 *3)) (-4 *3 (-365)))) (-1277 (*1 *2) (-12 (-4 *1 (-641 *3)) (-4 *3 (-365)) (-5 *2 (-121))))) 
-(-13 (-365) (-1221 |t#1| (-568)) (-10 -8 (-15 -4477 ((-568) $)) (-15 -1987 (|t#1| $ (-568))) (-15 -2745 ($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |t#1|))))) (-15 -2745 ((-1141 (-2 (|:| |k| (-568)) (|:| |c| |t#1|))) $)) (-15 -2421 ($ $)) (-15 -2455 ((-3 (-568) "failed") $)) (-15 -2255 ($ $)) (-15 -3975 ($ $ $)) (-15 -4493 ($ (-1 $))) (-15 -2662 ($ (-634 $) (-634 (-763)) (-568))) (-15 -1429 ($ (-568) $)) (-15 -1429 ($ $)) (-15 -3728 ($ (-568) |t#1| $)) (-15 -1870 ($ $ (-568))) (-15 -4273 ($ $ (-568))) (-15 -4447 (|t#1| $)) (-15 -1277 ((-121) (-121))) (-15 -1277 ((-121))))) 
+((-1844 (*1 *2 *1) (-12 (-4 *1 (-641 *3)) (-4 *3 (-365)) (-5 *2 (-568)))) (-1844 (*1 *2 *1) (-12 (-4 *1 (-641 *3)) (-4 *3 (-365)) (-5 *2 (-568)))) (-4438 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-641 *2)) (-4 *2 (-365)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *3)))) (-4 *3 (-365)) (-4 *1 (-641 *3)))) (-2747 (*1 *2 *1) (-12 (-4 *1 (-641 *3)) (-4 *3 (-365)) (-5 *2 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *3)))))) (-2379 (*1 *1 *1) (-12 (-4 *1 (-641 *2)) (-4 *2 (-365)))) (-2545 (*1 *2 *1) (|partial| -12 (-4 *1 (-641 *3)) (-4 *3 (-365)) (-5 *2 (-568)))) (-3297 (*1 *1 *1) (-12 (-4 *1 (-641 *2)) (-4 *2 (-365)))) (-4461 (*1 *1 *1 *1) (-12 (-4 *1 (-641 *2)) (-4 *2 (-365)))) (-1922 (*1 *1 *2) (-12 (-5 *2 (-1 *1)) (-4 *1 (-641 *3)) (-4 *3 (-365)))) (-4444 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-634 *1)) (-5 *3 (-634 (-763))) (-5 *4 (-568)) (-4 *1 (-641 *5)) (-4 *5 (-365)))) (-2232 (*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-4 *1 (-641 *3)) (-4 *3 (-365)))) (-2232 (*1 *1 *1) (-12 (-4 *1 (-641 *2)) (-4 *2 (-365)))) (-2512 (*1 *1 *2 *3 *1) (-12 (-5 *2 (-568)) (-4 *1 (-641 *3)) (-4 *3 (-365)))) (-1872 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-641 *3)) (-4 *3 (-365)))) (-2938 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-641 *3)) (-4 *3 (-365)))) (-1691 (*1 *2 *1) (-12 (-4 *1 (-641 *2)) (-4 *2 (-365)))) (-1277 (*1 *2 *2) (-12 (-5 *2 (-121)) (-4 *1 (-641 *3)) (-4 *3 (-365)))) (-1277 (*1 *2) (-12 (-4 *1 (-641 *3)) (-4 *3 (-365)) (-5 *2 (-121))))) 
+(-13 (-365) (-1221 |t#1| (-568)) (-10 -8 (-15 -1844 ((-568) $)) (-15 -4438 (|t#1| $ (-568))) (-15 -2747 ($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |t#1|))))) (-15 -2747 ((-1141 (-2 (|:| |k| (-568)) (|:| |c| |t#1|))) $)) (-15 -2379 ($ $)) (-15 -2545 ((-3 (-568) "failed") $)) (-15 -3297 ($ $)) (-15 -4461 ($ $ $)) (-15 -1922 ($ (-1 $))) (-15 -4444 ($ (-634 $) (-634 (-763)) (-568))) (-15 -2232 ($ (-568) $)) (-15 -2232 ($ $)) (-15 -2512 ($ (-568) |t#1| $)) (-15 -1872 ($ $ (-568))) (-15 -2938 ($ $ (-568))) (-15 -1691 (|t#1| $)) (-15 -1277 ((-121) (-121))) (-15 -1277 ((-121))))) 
 (((-21) . T) ((-23) . T) ((-52 |#1| (-568)) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 |#1| |#1|) . T) ((-120 $ $) . T) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) . T) ((-225) |has| |#1| (-15 * (|#1| (-568) |#1|))) ((-238) . T) ((-281 $ $) |has| (-568) (-1102)) ((-285) . T) ((-301) . T) ((-365) . T) ((-453) . T) ((-558) . T) ((-637 (-409 (-568))) . T) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) . T) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) . T) ((-716) . T) ((-895 (-1161)) -12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))) ((-974 |#1| (-568) (-1075)) . T) ((-916) . T) ((-1053 (-409 (-568))) . T) ((-1053 |#1|) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1199) . T) ((-1221 |#1| (-568)) . T)) 
-((-4351 (((-3 |#2| "failed") |#3| |#2| (-1161) |#2| (-634 |#2|)) 159) (((-3 (-2 (|:| |particular| |#2|) (|:| -3746 (-634 |#2|))) "failed") |#3| |#2| (-1161)) 43))) 
-(((-642 |#1| |#2| |#3|) (-10 -7 (-15 -4351 ((-3 (-2 (|:| |particular| |#2|) (|:| -3746 (-634 |#2|))) "failed") |#3| |#2| (-1161))) (-15 -4351 ((-3 |#2| "failed") |#3| |#2| (-1161) |#2| (-634 |#2|)))) (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150)) (-13 (-29 |#1|) (-1181) (-959)) (-646 |#2|)) (T -642)) 
-((-4351 (*1 *2 *3 *2 *4 *2 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-634 *2)) (-4 *2 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *1 (-642 *6 *2 *3)) (-4 *3 (-646 *2)))) (-4351 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1161)) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-4 *4 (-13 (-29 *6) (-1181) (-959))) (-5 *2 (-2 (|:| |particular| *4) (|:| -3746 (-634 *4)))) (-5 *1 (-642 *6 *4 *3)) (-4 *3 (-646 *4))))) 
-(-10 -7 (-15 -4351 ((-3 (-2 (|:| |particular| |#2|) (|:| -3746 (-634 |#2|))) "failed") |#3| |#2| (-1161))) (-15 -4351 ((-3 |#2| "failed") |#3| |#2| (-1161) |#2| (-634 |#2|)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-1591 (($ $) NIL (|has| |#1| (-365)))) (-1834 (($ $ $) NIL (|has| |#1| (-365)))) (-2699 (($ $ (-763)) NIL (|has| |#1| (-365)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-2012 (($ $ $) NIL (|has| |#1| (-365)))) (-2607 (($ $ $) NIL (|has| |#1| (-365)))) (-2420 (($ $ $) NIL (|has| |#1| (-365)))) (-2681 (($ $ $) NIL (|has| |#1| (-365)))) (-1523 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-365)))) (-1884 (((-3 $ "failed") $ $) NIL (|has| |#1| (-365)))) (-1653 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-365)))) (-3666 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) NIL)) (-2854 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) NIL)) (-2114 (($ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3250 (($ $) NIL (|has| |#1| (-453)))) (-2735 (((-121) $) NIL)) (-2047 (($ |#1| (-763)) NIL)) (-4123 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-558)))) (-3937 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-558)))) (-2144 (((-763) $) NIL)) (-3748 (($ $ $) NIL (|has| |#1| (-365)))) (-1382 (($ $ $) NIL (|has| |#1| (-365)))) (-1525 (($ $ $) NIL (|has| |#1| (-365)))) (-2450 (($ $ $) NIL (|has| |#1| (-365)))) (-3758 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-365)))) (-2260 (((-3 $ "failed") $ $) NIL (|has| |#1| (-365)))) (-1293 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-365)))) (-2102 ((|#1| $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2595 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558)))) (-2779 ((|#1| $ |#1|) NIL)) (-3357 (($ $ $) NIL (|has| |#1| (-365)))) (-3206 (((-763) $) NIL)) (-3367 ((|#1| $) NIL (|has| |#1| (-453)))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ (-409 (-568))) NIL (|has| |#1| (-1037 (-409 (-568))))) (($ |#1|) NIL)) (-1302 (((-634 |#1|) $) NIL)) (-2604 ((|#1| $ (-763)) NIL)) (-4078 (((-763)) NIL)) (-3823 ((|#1| $ |#1| |#1|) NIL)) (-4391 (($ $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($) NIL)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
+((-3259 (((-3 |#2| "failed") |#3| |#2| (-1161) |#2| (-634 |#2|)) 159) (((-3 (-2 (|:| |particular| |#2|) (|:| -2588 (-634 |#2|))) "failed") |#3| |#2| (-1161)) 43))) 
+(((-642 |#1| |#2| |#3|) (-10 -7 (-15 -3259 ((-3 (-2 (|:| |particular| |#2|) (|:| -2588 (-634 |#2|))) "failed") |#3| |#2| (-1161))) (-15 -3259 ((-3 |#2| "failed") |#3| |#2| (-1161) |#2| (-634 |#2|)))) (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150)) (-13 (-29 |#1|) (-1181) (-959)) (-646 |#2|)) (T -642)) 
+((-3259 (*1 *2 *3 *2 *4 *2 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-634 *2)) (-4 *2 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *1 (-642 *6 *2 *3)) (-4 *3 (-646 *2)))) (-3259 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1161)) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-4 *4 (-13 (-29 *6) (-1181) (-959))) (-5 *2 (-2 (|:| |particular| *4) (|:| -2588 (-634 *4)))) (-5 *1 (-642 *6 *4 *3)) (-4 *3 (-646 *4))))) 
+(-10 -7 (-15 -3259 ((-3 (-2 (|:| |particular| |#2|) (|:| -2588 (-634 |#2|))) "failed") |#3| |#2| (-1161))) (-15 -3259 ((-3 |#2| "failed") |#3| |#2| (-1161) |#2| (-634 |#2|)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-1283 (($ $) NIL (|has| |#1| (-365)))) (-2314 (($ $ $) NIL (|has| |#1| (-365)))) (-1412 (($ $ (-763)) NIL (|has| |#1| (-365)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-1309 (($ $ $) NIL (|has| |#1| (-365)))) (-2096 (($ $ $) NIL (|has| |#1| (-365)))) (-2374 (($ $ $) NIL (|has| |#1| (-365)))) (-1310 (($ $ $) NIL (|has| |#1| (-365)))) (-4137 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-365)))) (-2554 (((-3 $ "failed") $ $) NIL (|has| |#1| (-365)))) (-3333 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-365)))) (-3668 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) NIL)) (-2857 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) NIL)) (-2116 (($ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1998 (($ $) NIL (|has| |#1| (-453)))) (-1598 (((-121) $) NIL)) (-2049 (($ |#1| (-763)) NIL)) (-3667 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-558)))) (-4301 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-558)))) (-3524 (((-763) $) NIL)) (-2600 (($ $ $) NIL (|has| |#1| (-365)))) (-3914 (($ $ $) NIL (|has| |#1| (-365)))) (-4150 (($ $ $) NIL (|has| |#1| (-365)))) (-2520 (($ $ $) NIL (|has| |#1| (-365)))) (-2651 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-365)))) (-3327 (((-3 $ "failed") $ $) NIL (|has| |#1| (-365)))) (-3229 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-365)))) (-2104 ((|#1| $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2597 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558)))) (-2781 ((|#1| $ |#1|) NIL)) (-1311 (($ $ $) NIL (|has| |#1| (-365)))) (-1836 (((-763) $) NIL)) (-1364 ((|#1| $) NIL (|has| |#1| (-453)))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ (-409 (-568))) NIL (|has| |#1| (-1037 (-409 (-568))))) (($ |#1|) NIL)) (-3304 (((-634 |#1|) $) NIL)) (-2079 ((|#1| $ (-763)) NIL)) (-3425 (((-763)) NIL)) (-3828 ((|#1| $ |#1| |#1|) NIL)) (-1419 (($ $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($) NIL)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
 (((-643 |#1|) (-646 |#1|) (-225)) (T -643)) 
 NIL 
 (-646 |#1|) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-1591 (($ $) NIL (|has| |#1| (-365)))) (-1834 (($ $ $) NIL (|has| |#1| (-365)))) (-2699 (($ $ (-763)) NIL (|has| |#1| (-365)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-2012 (($ $ $) NIL (|has| |#1| (-365)))) (-2607 (($ $ $) NIL (|has| |#1| (-365)))) (-2420 (($ $ $) NIL (|has| |#1| (-365)))) (-2681 (($ $ $) NIL (|has| |#1| (-365)))) (-1523 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-365)))) (-1884 (((-3 $ "failed") $ $) NIL (|has| |#1| (-365)))) (-1653 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-365)))) (-3666 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) NIL)) (-2854 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) NIL)) (-2114 (($ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3250 (($ $) NIL (|has| |#1| (-453)))) (-2735 (((-121) $) NIL)) (-2047 (($ |#1| (-763)) NIL)) (-4123 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-558)))) (-3937 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-558)))) (-2144 (((-763) $) NIL)) (-3748 (($ $ $) NIL (|has| |#1| (-365)))) (-1382 (($ $ $) NIL (|has| |#1| (-365)))) (-1525 (($ $ $) NIL (|has| |#1| (-365)))) (-2450 (($ $ $) NIL (|has| |#1| (-365)))) (-3758 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-365)))) (-2260 (((-3 $ "failed") $ $) NIL (|has| |#1| (-365)))) (-1293 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-365)))) (-2102 ((|#1| $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2595 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558)))) (-2779 ((|#1| $ |#1|) NIL) ((|#2| $ |#2|) 13)) (-3357 (($ $ $) NIL (|has| |#1| (-365)))) (-3206 (((-763) $) NIL)) (-3367 ((|#1| $) NIL (|has| |#1| (-453)))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ (-409 (-568))) NIL (|has| |#1| (-1037 (-409 (-568))))) (($ |#1|) NIL)) (-1302 (((-634 |#1|) $) NIL)) (-2604 ((|#1| $ (-763)) NIL)) (-4078 (((-763)) NIL)) (-3823 ((|#1| $ |#1| |#1|) NIL)) (-4391 (($ $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($) NIL)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
-(((-644 |#1| |#2|) (-13 (-646 |#1|) (-281 |#2| |#2|)) (-225) (-13 (-637 |#1|) (-10 -8 (-15 -4189 ($ $))))) (T -644)) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-1283 (($ $) NIL (|has| |#1| (-365)))) (-2314 (($ $ $) NIL (|has| |#1| (-365)))) (-1412 (($ $ (-763)) NIL (|has| |#1| (-365)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-1309 (($ $ $) NIL (|has| |#1| (-365)))) (-2096 (($ $ $) NIL (|has| |#1| (-365)))) (-2374 (($ $ $) NIL (|has| |#1| (-365)))) (-1310 (($ $ $) NIL (|has| |#1| (-365)))) (-4137 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-365)))) (-2554 (((-3 $ "failed") $ $) NIL (|has| |#1| (-365)))) (-3333 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-365)))) (-3668 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) NIL)) (-2857 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) NIL)) (-2116 (($ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1998 (($ $) NIL (|has| |#1| (-453)))) (-1598 (((-121) $) NIL)) (-2049 (($ |#1| (-763)) NIL)) (-3667 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-558)))) (-4301 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-558)))) (-3524 (((-763) $) NIL)) (-2600 (($ $ $) NIL (|has| |#1| (-365)))) (-3914 (($ $ $) NIL (|has| |#1| (-365)))) (-4150 (($ $ $) NIL (|has| |#1| (-365)))) (-2520 (($ $ $) NIL (|has| |#1| (-365)))) (-2651 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-365)))) (-3327 (((-3 $ "failed") $ $) NIL (|has| |#1| (-365)))) (-3229 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-365)))) (-2104 ((|#1| $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2597 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558)))) (-2781 ((|#1| $ |#1|) NIL) ((|#2| $ |#2|) 13)) (-1311 (($ $ $) NIL (|has| |#1| (-365)))) (-1836 (((-763) $) NIL)) (-1364 ((|#1| $) NIL (|has| |#1| (-453)))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ (-409 (-568))) NIL (|has| |#1| (-1037 (-409 (-568))))) (($ |#1|) NIL)) (-3304 (((-634 |#1|) $) NIL)) (-2079 ((|#1| $ (-763)) NIL)) (-3425 (((-763)) NIL)) (-3828 ((|#1| $ |#1| |#1|) NIL)) (-1419 (($ $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($) NIL)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
+(((-644 |#1| |#2|) (-13 (-646 |#1|) (-281 |#2| |#2|)) (-225) (-13 (-637 |#1|) (-10 -8 (-15 -4191 ($ $))))) (T -644)) 
 NIL 
 (-13 (-646 |#1|) (-281 |#2| |#2|)) 
-((-1591 (($ $) 26)) (-4391 (($ $) 24)) (-3190 (($) 12))) 
-(((-645 |#1| |#2|) (-10 -8 (-15 -1591 (|#1| |#1|)) (-15 -4391 (|#1| |#1|)) (-15 -3190 (|#1|))) (-646 |#2|) (-1047)) (T -645)) 
+((-1283 (($ $) 26)) (-1419 (($ $) 24)) (-3192 (($) 12))) 
+(((-645 |#1| |#2|) (-10 -8 (-15 -1283 (|#1| |#1|)) (-15 -1419 (|#1| |#1|)) (-15 -3192 (|#1|))) (-646 |#2|) (-1047)) (T -645)) 
 NIL 
-(-10 -8 (-15 -1591 (|#1| |#1|)) (-15 -4391 (|#1| |#1|)) (-15 -3190 (|#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-1591 (($ $) 79 (|has| |#1| (-365)))) (-1834 (($ $ $) 81 (|has| |#1| (-365)))) (-2699 (($ $ (-763)) 80 (|has| |#1| (-365)))) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-2012 (($ $ $) 44 (|has| |#1| (-365)))) (-2607 (($ $ $) 45 (|has| |#1| (-365)))) (-2420 (($ $ $) 47 (|has| |#1| (-365)))) (-2681 (($ $ $) 42 (|has| |#1| (-365)))) (-1523 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 41 (|has| |#1| (-365)))) (-1884 (((-3 $ "failed") $ $) 43 (|has| |#1| (-365)))) (-1653 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 46 (|has| |#1| (-365)))) (-3666 (((-3 (-568) "failed") $) 73 (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) 71 (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 68)) (-2854 (((-568) $) 74 (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) 72 (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) 67)) (-2114 (($ $) 63)) (-2925 (((-3 $ "failed") $) 33)) (-3250 (($ $) 54 (|has| |#1| (-453)))) (-2735 (((-121) $) 30)) (-2047 (($ |#1| (-763)) 61)) (-4123 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 56 (|has| |#1| (-558)))) (-3937 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 57 (|has| |#1| (-558)))) (-2144 (((-763) $) 65)) (-3748 (($ $ $) 51 (|has| |#1| (-365)))) (-1382 (($ $ $) 52 (|has| |#1| (-365)))) (-1525 (($ $ $) 40 (|has| |#1| (-365)))) (-2450 (($ $ $) 49 (|has| |#1| (-365)))) (-3758 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 48 (|has| |#1| (-365)))) (-2260 (((-3 $ "failed") $ $) 50 (|has| |#1| (-365)))) (-1293 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 53 (|has| |#1| (-365)))) (-2102 ((|#1| $) 64)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2595 (((-3 $ "failed") $ |#1|) 58 (|has| |#1| (-558)))) (-2779 ((|#1| $ |#1|) 84)) (-3357 (($ $ $) 78 (|has| |#1| (-365)))) (-3206 (((-763) $) 66)) (-3367 ((|#1| $) 55 (|has| |#1| (-453)))) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ (-409 (-568))) 70 (|has| |#1| (-1037 (-409 (-568))))) (($ |#1|) 69)) (-1302 (((-634 |#1|) $) 60)) (-2604 ((|#1| $ (-763)) 62)) (-4078 (((-763)) 28)) (-3823 ((|#1| $ |#1| |#1|) 59)) (-4391 (($ $) 82)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($) 83)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 76) (($ |#1| $) 75))) 
+(-10 -8 (-15 -1283 (|#1| |#1|)) (-15 -1419 (|#1| |#1|)) (-15 -3192 (|#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-1283 (($ $) 79 (|has| |#1| (-365)))) (-2314 (($ $ $) 81 (|has| |#1| (-365)))) (-1412 (($ $ (-763)) 80 (|has| |#1| (-365)))) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-1309 (($ $ $) 44 (|has| |#1| (-365)))) (-2096 (($ $ $) 45 (|has| |#1| (-365)))) (-2374 (($ $ $) 47 (|has| |#1| (-365)))) (-1310 (($ $ $) 42 (|has| |#1| (-365)))) (-4137 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 41 (|has| |#1| (-365)))) (-2554 (((-3 $ "failed") $ $) 43 (|has| |#1| (-365)))) (-3333 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 46 (|has| |#1| (-365)))) (-3668 (((-3 (-568) "failed") $) 73 (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) 71 (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 68)) (-2857 (((-568) $) 74 (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) 72 (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) 67)) (-2116 (($ $) 63)) (-2902 (((-3 $ "failed") $) 33)) (-1998 (($ $) 54 (|has| |#1| (-453)))) (-1598 (((-121) $) 30)) (-2049 (($ |#1| (-763)) 61)) (-3667 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 56 (|has| |#1| (-558)))) (-4301 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 57 (|has| |#1| (-558)))) (-3524 (((-763) $) 65)) (-2600 (($ $ $) 51 (|has| |#1| (-365)))) (-3914 (($ $ $) 52 (|has| |#1| (-365)))) (-4150 (($ $ $) 40 (|has| |#1| (-365)))) (-2520 (($ $ $) 49 (|has| |#1| (-365)))) (-2651 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 48 (|has| |#1| (-365)))) (-3327 (((-3 $ "failed") $ $) 50 (|has| |#1| (-365)))) (-3229 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 53 (|has| |#1| (-365)))) (-2104 ((|#1| $) 64)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2597 (((-3 $ "failed") $ |#1|) 58 (|has| |#1| (-558)))) (-2781 ((|#1| $ |#1|) 84)) (-1311 (($ $ $) 78 (|has| |#1| (-365)))) (-1836 (((-763) $) 66)) (-1364 ((|#1| $) 55 (|has| |#1| (-453)))) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ (-409 (-568))) 70 (|has| |#1| (-1037 (-409 (-568))))) (($ |#1|) 69)) (-3304 (((-634 |#1|) $) 60)) (-2079 ((|#1| $ (-763)) 62)) (-3425 (((-763)) 28)) (-3828 ((|#1| $ |#1| |#1|) 59)) (-1419 (($ $) 82)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($) 83)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 76) (($ |#1| $) 75))) 
 (((-646 |#1|) (-1275) (-1047)) (T -646)) 
-((-3190 (*1 *1) (-12 (-4 *1 (-646 *2)) (-4 *2 (-1047)))) (-4391 (*1 *1 *1) (-12 (-4 *1 (-646 *2)) (-4 *2 (-1047)))) (-1834 (*1 *1 *1 *1) (-12 (-4 *1 (-646 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-2699 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-646 *3)) (-4 *3 (-1047)) (-4 *3 (-365)))) (-1591 (*1 *1 *1) (-12 (-4 *1 (-646 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-3357 (*1 *1 *1 *1) (-12 (-4 *1 (-646 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
-(-13 (-844 |t#1|) (-281 |t#1| |t#1|) (-10 -8 (-15 -3190 ($)) (-15 -4391 ($ $)) (IF (|has| |t#1| (-365)) (PROGN (-15 -1834 ($ $ $)) (-15 -2699 ($ $ (-763))) (-15 -1591 ($ $)) (-15 -3357 ($ $ $))) |noBranch|))) 
+((-3192 (*1 *1) (-12 (-4 *1 (-646 *2)) (-4 *2 (-1047)))) (-1419 (*1 *1 *1) (-12 (-4 *1 (-646 *2)) (-4 *2 (-1047)))) (-2314 (*1 *1 *1 *1) (-12 (-4 *1 (-646 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-1412 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-646 *3)) (-4 *3 (-1047)) (-4 *3 (-365)))) (-1283 (*1 *1 *1) (-12 (-4 *1 (-646 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-1311 (*1 *1 *1 *1) (-12 (-4 *1 (-646 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
+(-13 (-844 |t#1|) (-281 |t#1| |t#1|) (-10 -8 (-15 -3192 ($)) (-15 -1419 ($ $)) (IF (|has| |t#1| (-365)) (PROGN (-15 -2314 ($ $ $)) (-15 -1412 ($ $ (-763))) (-15 -1283 ($ $)) (-15 -1311 ($ $ $))) |noBranch|))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#1|) |has| |#1| (-172)) ((-105) . T) ((-120 |#1| |#1|) . T) ((-137) . T) ((-608 (-850)) . T) ((-281 |#1| |#1|) . T) ((-413 |#1|) . T) ((-637 |#1|) . T) ((-637 $) . T) ((-707 |#1|) |has| |#1| (-172)) ((-716) . T) ((-1037 (-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 |#1|) . T) ((-1053 |#1|) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-844 |#1|) . T)) 
-((-2519 (((-634 (-643 (-409 |#2|))) (-643 (-409 |#2|))) 72 (|has| |#1| (-27)))) (-3848 (((-634 (-643 (-409 |#2|))) (-643 (-409 |#2|))) 71 (|has| |#1| (-27))) (((-634 (-643 (-409 |#2|))) (-643 (-409 |#2|)) (-1 (-634 |#1|) |#2|)) 15))) 
-(((-647 |#1| |#2|) (-10 -7 (-15 -3848 ((-634 (-643 (-409 |#2|))) (-643 (-409 |#2|)) (-1 (-634 |#1|) |#2|))) (IF (|has| |#1| (-27)) (PROGN (-15 -3848 ((-634 (-643 (-409 |#2|))) (-643 (-409 |#2|)))) (-15 -2519 ((-634 (-643 (-409 |#2|))) (-643 (-409 |#2|))))) |noBranch|)) (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568)))) (-1219 |#1|)) (T -647)) 
-((-2519 (*1 *2 *3) (-12 (-4 *4 (-27)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-643 (-409 *5)))) (-5 *1 (-647 *4 *5)) (-5 *3 (-643 (-409 *5))))) (-3848 (*1 *2 *3) (-12 (-4 *4 (-27)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-643 (-409 *5)))) (-5 *1 (-647 *4 *5)) (-5 *3 (-643 (-409 *5))))) (-3848 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-643 (-409 *6)))) (-5 *1 (-647 *5 *6)) (-5 *3 (-643 (-409 *6)))))) 
-(-10 -7 (-15 -3848 ((-634 (-643 (-409 |#2|))) (-643 (-409 |#2|)) (-1 (-634 |#1|) |#2|))) (IF (|has| |#1| (-27)) (PROGN (-15 -3848 ((-634 (-643 (-409 |#2|))) (-643 (-409 |#2|)))) (-15 -2519 ((-634 (-643 (-409 |#2|))) (-643 (-409 |#2|))))) |noBranch|)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-1591 (($ $) NIL (|has| |#1| (-365)))) (-1834 (($ $ $) 28 (|has| |#1| (-365)))) (-2699 (($ $ (-763)) 31 (|has| |#1| (-365)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-2012 (($ $ $) NIL (|has| |#1| (-365)))) (-2607 (($ $ $) NIL (|has| |#1| (-365)))) (-2420 (($ $ $) NIL (|has| |#1| (-365)))) (-2681 (($ $ $) NIL (|has| |#1| (-365)))) (-1523 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-365)))) (-1884 (((-3 $ "failed") $ $) NIL (|has| |#1| (-365)))) (-1653 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-365)))) (-3666 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) NIL)) (-2854 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) NIL)) (-2114 (($ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3250 (($ $) NIL (|has| |#1| (-453)))) (-2735 (((-121) $) NIL)) (-2047 (($ |#1| (-763)) NIL)) (-4123 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-558)))) (-3937 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-558)))) (-2144 (((-763) $) NIL)) (-3748 (($ $ $) NIL (|has| |#1| (-365)))) (-1382 (($ $ $) NIL (|has| |#1| (-365)))) (-1525 (($ $ $) NIL (|has| |#1| (-365)))) (-2450 (($ $ $) NIL (|has| |#1| (-365)))) (-3758 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-365)))) (-2260 (((-3 $ "failed") $ $) NIL (|has| |#1| (-365)))) (-1293 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-365)))) (-2102 ((|#1| $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2595 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558)))) (-2779 ((|#1| $ |#1|) 24)) (-3357 (($ $ $) 33 (|has| |#1| (-365)))) (-3206 (((-763) $) NIL)) (-3367 ((|#1| $) NIL (|has| |#1| (-453)))) (-2745 (((-850) $) 20) (($ (-568)) NIL) (($ (-409 (-568))) NIL (|has| |#1| (-1037 (-409 (-568))))) (($ |#1|) NIL)) (-1302 (((-634 |#1|) $) NIL)) (-2604 ((|#1| $ (-763)) NIL)) (-4078 (((-763)) NIL)) (-3823 ((|#1| $ |#1| |#1|) 23)) (-4391 (($ $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 21 T CONST)) (-1556 (($) 8 T CONST)) (-3190 (($) NIL)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
+((-1718 (((-634 (-643 (-409 |#2|))) (-643 (-409 |#2|))) 72 (|has| |#1| (-27)))) (-3850 (((-634 (-643 (-409 |#2|))) (-643 (-409 |#2|))) 71 (|has| |#1| (-27))) (((-634 (-643 (-409 |#2|))) (-643 (-409 |#2|)) (-1 (-634 |#1|) |#2|)) 15))) 
+(((-647 |#1| |#2|) (-10 -7 (-15 -3850 ((-634 (-643 (-409 |#2|))) (-643 (-409 |#2|)) (-1 (-634 |#1|) |#2|))) (IF (|has| |#1| (-27)) (PROGN (-15 -3850 ((-634 (-643 (-409 |#2|))) (-643 (-409 |#2|)))) (-15 -1718 ((-634 (-643 (-409 |#2|))) (-643 (-409 |#2|))))) |noBranch|)) (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568)))) (-1219 |#1|)) (T -647)) 
+((-1718 (*1 *2 *3) (-12 (-4 *4 (-27)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-643 (-409 *5)))) (-5 *1 (-647 *4 *5)) (-5 *3 (-643 (-409 *5))))) (-3850 (*1 *2 *3) (-12 (-4 *4 (-27)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-643 (-409 *5)))) (-5 *1 (-647 *4 *5)) (-5 *3 (-643 (-409 *5))))) (-3850 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-643 (-409 *6)))) (-5 *1 (-647 *5 *6)) (-5 *3 (-643 (-409 *6)))))) 
+(-10 -7 (-15 -3850 ((-634 (-643 (-409 |#2|))) (-643 (-409 |#2|)) (-1 (-634 |#1|) |#2|))) (IF (|has| |#1| (-27)) (PROGN (-15 -3850 ((-634 (-643 (-409 |#2|))) (-643 (-409 |#2|)))) (-15 -1718 ((-634 (-643 (-409 |#2|))) (-643 (-409 |#2|))))) |noBranch|)) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-1283 (($ $) NIL (|has| |#1| (-365)))) (-2314 (($ $ $) 28 (|has| |#1| (-365)))) (-1412 (($ $ (-763)) 31 (|has| |#1| (-365)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-1309 (($ $ $) NIL (|has| |#1| (-365)))) (-2096 (($ $ $) NIL (|has| |#1| (-365)))) (-2374 (($ $ $) NIL (|has| |#1| (-365)))) (-1310 (($ $ $) NIL (|has| |#1| (-365)))) (-4137 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-365)))) (-2554 (((-3 $ "failed") $ $) NIL (|has| |#1| (-365)))) (-3333 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-365)))) (-3668 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) NIL)) (-2857 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) NIL)) (-2116 (($ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1998 (($ $) NIL (|has| |#1| (-453)))) (-1598 (((-121) $) NIL)) (-2049 (($ |#1| (-763)) NIL)) (-3667 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-558)))) (-4301 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-558)))) (-3524 (((-763) $) NIL)) (-2600 (($ $ $) NIL (|has| |#1| (-365)))) (-3914 (($ $ $) NIL (|has| |#1| (-365)))) (-4150 (($ $ $) NIL (|has| |#1| (-365)))) (-2520 (($ $ $) NIL (|has| |#1| (-365)))) (-2651 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-365)))) (-3327 (((-3 $ "failed") $ $) NIL (|has| |#1| (-365)))) (-3229 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-365)))) (-2104 ((|#1| $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2597 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558)))) (-2781 ((|#1| $ |#1|) 24)) (-1311 (($ $ $) 33 (|has| |#1| (-365)))) (-1836 (((-763) $) NIL)) (-1364 ((|#1| $) NIL (|has| |#1| (-453)))) (-2747 (((-850) $) 20) (($ (-568)) NIL) (($ (-409 (-568))) NIL (|has| |#1| (-1037 (-409 (-568))))) (($ |#1|) NIL)) (-3304 (((-634 |#1|) $) NIL)) (-2079 ((|#1| $ (-763)) NIL)) (-3425 (((-763)) NIL)) (-3828 ((|#1| $ |#1| |#1|) 23)) (-1419 (($ $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 21 T CONST)) (-1557 (($) 8 T CONST)) (-3192 (($) NIL)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
 (((-648 |#1| |#2|) (-646 |#1|) (-1047) (-1 |#1| |#1|)) (T -648)) 
 NIL 
 (-646 |#1|) 
-((-1834 ((|#2| |#2| |#2| (-1 |#1| |#1|)) 61)) (-2699 ((|#2| |#2| (-763) (-1 |#1| |#1|)) 42)) (-3357 ((|#2| |#2| |#2| (-1 |#1| |#1|)) 63))) 
-(((-649 |#1| |#2|) (-10 -7 (-15 -1834 (|#2| |#2| |#2| (-1 |#1| |#1|))) (-15 -2699 (|#2| |#2| (-763) (-1 |#1| |#1|))) (-15 -3357 (|#2| |#2| |#2| (-1 |#1| |#1|)))) (-365) (-646 |#1|)) (T -649)) 
-((-3357 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 *4 *4)) (-4 *4 (-365)) (-5 *1 (-649 *4 *2)) (-4 *2 (-646 *4)))) (-2699 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-763)) (-5 *4 (-1 *5 *5)) (-4 *5 (-365)) (-5 *1 (-649 *5 *2)) (-4 *2 (-646 *5)))) (-1834 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 *4 *4)) (-4 *4 (-365)) (-5 *1 (-649 *4 *2)) (-4 *2 (-646 *4))))) 
-(-10 -7 (-15 -1834 (|#2| |#2| |#2| (-1 |#1| |#1|))) (-15 -2699 (|#2| |#2| (-763) (-1 |#1| |#1|))) (-15 -3357 (|#2| |#2| |#2| (-1 |#1| |#1|)))) 
-((-2430 (($ $ $) 9))) 
-(((-650 |#1|) (-10 -8 (-15 -2430 (|#1| |#1| |#1|))) (-651)) (T -650)) 
-NIL 
-(-10 -8 (-15 -2430 (|#1| |#1| |#1|))) 
-((-2447 (((-121) $ $) 7)) (-1611 (($ $) 10)) (-2430 (($ $ $) 8)) (-1717 (((-121) $ $) 6)) (-2424 (($ $ $) 9))) 
+((-2314 ((|#2| |#2| |#2| (-1 |#1| |#1|)) 61)) (-1412 ((|#2| |#2| (-763) (-1 |#1| |#1|)) 42)) (-1311 ((|#2| |#2| |#2| (-1 |#1| |#1|)) 63))) 
+(((-649 |#1| |#2|) (-10 -7 (-15 -2314 (|#2| |#2| |#2| (-1 |#1| |#1|))) (-15 -1412 (|#2| |#2| (-763) (-1 |#1| |#1|))) (-15 -1311 (|#2| |#2| |#2| (-1 |#1| |#1|)))) (-365) (-646 |#1|)) (T -649)) 
+((-1311 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 *4 *4)) (-4 *4 (-365)) (-5 *1 (-649 *4 *2)) (-4 *2 (-646 *4)))) (-1412 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-763)) (-5 *4 (-1 *5 *5)) (-4 *5 (-365)) (-5 *1 (-649 *5 *2)) (-4 *2 (-646 *5)))) (-2314 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 *4 *4)) (-4 *4 (-365)) (-5 *1 (-649 *4 *2)) (-4 *2 (-646 *4))))) 
+(-10 -7 (-15 -2314 (|#2| |#2| |#2| (-1 |#1| |#1|))) (-15 -1412 (|#2| |#2| (-763) (-1 |#1| |#1|))) (-15 -1311 (|#2| |#2| |#2| (-1 |#1| |#1|)))) 
+((-2432 (($ $ $) 9))) 
+(((-650 |#1|) (-10 -8 (-15 -2432 (|#1| |#1| |#1|))) (-651)) (T -650)) 
+NIL 
+(-10 -8 (-15 -2432 (|#1| |#1| |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1613 (($ $) 10)) (-2432 (($ $ $) 8)) (-1719 (((-121) $ $) 6)) (-2426 (($ $ $) 9))) 
 (((-651) (-1275)) (T -651)) 
-((-1611 (*1 *1 *1) (-4 *1 (-651))) (-2424 (*1 *1 *1 *1) (-4 *1 (-651))) (-2430 (*1 *1 *1 *1) (-4 *1 (-651)))) 
-(-13 (-105) (-10 -8 (-15 -1611 ($ $)) (-15 -2424 ($ $ $)) (-15 -2430 ($ $ $)))) 
+((-1613 (*1 *1 *1) (-4 *1 (-651))) (-2426 (*1 *1 *1 *1) (-4 *1 (-651))) (-2432 (*1 *1 *1 *1) (-4 *1 (-651)))) 
+(-13 (-105) (-10 -8 (-15 -1613 ($ $)) (-15 -2426 ($ $ $)) (-15 -2432 ($ $ $)))) 
 (((-105) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-2317 ((|#1| $) 21)) (-2521 (($ $ $) NIL (|has| |#1| (-786)))) (-3268 (($ $ $) NIL (|has| |#1| (-786)))) (-4487 (((-1143) $) 46)) (-4022 (((-1108) $) NIL)) (-2324 ((|#3| $) 22)) (-2745 (((-850) $) 42)) (-3056 (($) 10 T CONST)) (-1751 (((-121) $ $) NIL (|has| |#1| (-786)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-786)))) (-1717 (((-121) $ $) 20)) (-1745 (((-121) $ $) NIL (|has| |#1| (-786)))) (-1732 (((-121) $ $) 24 (|has| |#1| (-786)))) (-1779 (($ $ |#3|) 34) (($ |#1| |#3|) 35)) (-1773 (($ $) 17) (($ $ $) NIL)) (-1767 (($ $ $) 27)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 30) (($ |#2| $) 32) (($ $ |#2|) NIL))) 
-(((-652 |#1| |#2| |#3|) (-13 (-707 |#2|) (-10 -8 (IF (|has| |#1| (-786)) (-6 (-786)) |noBranch|) (-15 -1779 ($ $ |#3|)) (-15 -1779 ($ |#1| |#3|)) (-15 -2317 (|#1| $)) (-15 -2324 (|#3| $)))) (-707 |#2|) (-172) (|SubsetCategory| (-716) |#2|)) (T -652)) 
-((-1779 (*1 *1 *1 *2) (-12 (-4 *4 (-172)) (-5 *1 (-652 *3 *4 *2)) (-4 *3 (-707 *4)) (-4 *2 (|SubsetCategory| (-716) *4)))) (-1779 (*1 *1 *2 *3) (-12 (-4 *4 (-172)) (-5 *1 (-652 *2 *4 *3)) (-4 *2 (-707 *4)) (-4 *3 (|SubsetCategory| (-716) *4)))) (-2317 (*1 *2 *1) (-12 (-4 *3 (-172)) (-4 *2 (-707 *3)) (-5 *1 (-652 *2 *3 *4)) (-4 *4 (|SubsetCategory| (-716) *3)))) (-2324 (*1 *2 *1) (-12 (-4 *4 (-172)) (-4 *2 (|SubsetCategory| (-716) *4)) (-5 *1 (-652 *3 *4 *2)) (-4 *3 (-707 *4))))) 
-(-13 (-707 |#2|) (-10 -8 (IF (|has| |#1| (-786)) (-6 (-786)) |noBranch|) (-15 -1779 ($ $ |#3|)) (-15 -1779 ($ |#1| |#3|)) (-15 -2317 (|#1| $)) (-15 -2324 (|#3| $)))) 
-((-1393 (((-679 |#1|) (-679 |#1|)) 27)) (-1582 (((-679 |#1|) (-679 |#1|)) 26)) (-3726 (((-634 (-634 |#1|)) (-634 |#1|) (-634 (-634 |#1|))) 44)) (-2910 (((-634 (-634 |#1|)) (-634 (-634 |#1|))) 29)) (-3108 (((-634 |#1|) (-634 |#1|) (-634 |#1|) |#1|) 43)) (-2228 (((-634 (-634 |#1|)) (-634 (-634 |#1|)) (-634 (-634 |#1|))) 34))) 
-(((-653 |#1|) (-10 -7 (-15 -1393 ((-679 |#1|) (-679 |#1|))) (-15 -1582 ((-679 |#1|) (-679 |#1|))) (-15 -2910 ((-634 (-634 |#1|)) (-634 (-634 |#1|)))) (-15 -2228 ((-634 (-634 |#1|)) (-634 (-634 |#1|)) (-634 (-634 |#1|)))) (-15 -3108 ((-634 |#1|) (-634 |#1|) (-634 |#1|) |#1|)) (-15 -3726 ((-634 (-634 |#1|)) (-634 |#1|) (-634 (-634 |#1|))))) (-365)) (T -653)) 
-((-3726 (*1 *2 *3 *2) (-12 (-5 *2 (-634 (-634 *4))) (-5 *3 (-634 *4)) (-4 *4 (-365)) (-5 *1 (-653 *4)))) (-3108 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-5 *1 (-653 *3)))) (-2228 (*1 *2 *2 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-365)) (-5 *1 (-653 *3)))) (-2910 (*1 *2 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-365)) (-5 *1 (-653 *3)))) (-1582 (*1 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-365)) (-5 *1 (-653 *3)))) (-1393 (*1 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-365)) (-5 *1 (-653 *3))))) 
-(-10 -7 (-15 -1393 ((-679 |#1|) (-679 |#1|))) (-15 -1582 ((-679 |#1|) (-679 |#1|))) (-15 -2910 ((-634 (-634 |#1|)) (-634 (-634 |#1|)))) (-15 -2228 ((-634 (-634 |#1|)) (-634 (-634 |#1|)) (-634 (-634 |#1|)))) (-15 -3108 ((-634 |#1|) (-634 |#1|) (-634 |#1|) |#1|)) (-15 -3726 ((-634 (-634 |#1|)) (-634 |#1|) (-634 (-634 |#1|))))) 
-((-1277 (((-121)) 46) (((-121) (-121)) 47)) (-3427 ((|#7| |#5| |#3|) 44)) (-1279 ((|#5| |#7|) 29)) (-4026 (((-2 (|:| |fnc| |#3|) (|:| |crv| |#3|) (|:| |chart| (-634 (-568)))) |#3| |#5| |#3| (-568)) 99)) (-4252 (((-634 |#6|) |#5| |#3| (-568)) 35))) 
-(((-654 |#1| |#2| |#3| |#4| |#5| |#6| |#7|) (-10 -7 (-15 -1277 ((-121) (-121))) (-15 -1277 ((-121))) (-15 -3427 (|#7| |#5| |#3|)) (-15 -4252 ((-634 |#6|) |#5| |#3| (-568))) (-15 -1279 (|#5| |#7|)) (-15 -4026 ((-2 (|:| |fnc| |#3|) (|:| |crv| |#3|) (|:| |chart| (-634 (-568)))) |#3| |#5| |#3| (-568)))) (-365) (-634 (-1161)) (-950 |#1| |#4| (-852 |#2|)) (-230 (-1697 |#2|) (-763)) (-971 |#1|) (-641 |#1|) (-920 |#1| |#6|)) (T -654)) 
-((-4026 (*1 *2 *3 *4 *3 *5) (-12 (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *8 (-230 (-1697 *7) (-763))) (-4 *9 (-641 *6)) (-5 *2 (-2 (|:| |fnc| *3) (|:| |crv| *3) (|:| |chart| (-634 (-568))))) (-5 *1 (-654 *6 *7 *3 *8 *4 *9 *10)) (-5 *5 (-568)) (-4 *3 (-950 *6 *8 (-852 *7))) (-4 *4 (-971 *6)) (-4 *10 (-920 *6 *9)))) (-1279 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-641 *4)) (-4 *2 (-971 *4)) (-5 *1 (-654 *4 *5 *6 *7 *2 *8 *3)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *3 (-920 *4 *8)))) (-4252 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-568)) (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *8 (-230 (-1697 *7) (-763))) (-4 *9 (-641 *6)) (-5 *2 (-634 *9)) (-5 *1 (-654 *6 *7 *4 *8 *3 *9 *10)) (-4 *4 (-950 *6 *8 (-852 *7))) (-4 *3 (-971 *6)) (-4 *10 (-920 *6 *9)))) (-3427 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1697 *6) (-763))) (-4 *2 (-920 *5 *8)) (-5 *1 (-654 *5 *6 *4 *7 *3 *8 *2)) (-4 *4 (-950 *5 *7 (-852 *6))) (-4 *3 (-971 *5)) (-4 *8 (-641 *5)))) (-1277 (*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *8 (-641 *3)) (-5 *2 (-121)) (-5 *1 (-654 *3 *4 *5 *6 *7 *8 *9)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *7 (-971 *3)) (-4 *9 (-920 *3 *8)))) (-1277 (*1 *2 *2) (-12 (-5 *2 (-121)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *8 (-641 *3)) (-5 *1 (-654 *3 *4 *5 *6 *7 *8 *9)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *7 (-971 *3)) (-4 *9 (-920 *3 *8))))) 
-(-10 -7 (-15 -1277 ((-121) (-121))) (-15 -1277 ((-121))) (-15 -3427 (|#7| |#5| |#3|)) (-15 -4252 ((-634 |#6|) |#5| |#3| (-568))) (-15 -1279 (|#5| |#7|)) (-15 -4026 ((-2 (|:| |fnc| |#3|) (|:| |crv| |#3|) (|:| |chart| (-634 (-568)))) |#3| |#5| |#3| (-568)))) 
-((-3588 (((-3 (-634 (-1157 |#1|)) "failed") (-634 (-1157 |#1|)) (-1157 |#1|)) 33))) 
-(((-655 |#1|) (-10 -7 (-15 -3588 ((-3 (-634 (-1157 |#1|)) "failed") (-634 (-1157 |#1|)) (-1157 |#1|)))) (-904)) (T -655)) 
-((-3588 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 *4))) (-5 *3 (-1157 *4)) (-4 *4 (-904)) (-5 *1 (-655 *4))))) 
-(-10 -7 (-15 -3588 ((-3 (-634 (-1157 |#1|)) "failed") (-634 (-1157 |#1|)) (-1157 |#1|)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3595 (((-634 |#1|) $) 82)) (-2821 (($ $ (-763)) 90)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-2628 (((-1266 |#1| |#2|) (-1266 |#1| |#2|) $) 48)) (-3666 (((-3 (-663 |#1|) "failed") $) NIL)) (-2854 (((-663 |#1|) $) NIL)) (-2114 (($ $) 89)) (-4178 (((-763) $) NIL)) (-2976 (((-634 $) $) NIL)) (-3921 (((-121) $) NIL)) (-2354 (($ (-663 |#1|) |#2|) 68)) (-2407 (($ $) 86)) (-2795 (($ (-1 |#2| |#2|) $) NIL)) (-2532 (((-1266 |#1| |#2|) (-1266 |#1| |#2|) $) 47)) (-4297 (((-634 (-2 (|:| |k| (-663 |#1|)) (|:| |c| |#2|))) $) NIL)) (-2315 (((-2 (|:| |k| (-663 |#1|)) (|:| |c| |#2|)) $) NIL)) (-2097 (((-663 |#1|) $) NIL)) (-2102 ((|#2| $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-1339 (($ $ |#1| $) 30) (($ $ (-634 |#1|) (-634 $)) 32)) (-3206 (((-763) $) 88)) (-4287 (($ $ $) 20) (($ (-663 |#1|) (-663 |#1|)) 77) (($ (-663 |#1|) $) 75) (($ $ (-663 |#1|)) 76)) (-2745 (((-850) $) NIL) (($ |#1|) 74) (((-1257 |#1| |#2|) $) 58) (((-1266 |#1| |#2|) $) 41) (($ (-663 |#1|)) 25)) (-1302 (((-634 |#2|) $) NIL)) (-2604 ((|#2| $ (-663 |#1|)) NIL)) (-2348 ((|#2| (-1266 |#1| |#2|) $) 43)) (-3056 (($) 23 T CONST)) (-2253 (((-3 $ "failed") (-1257 |#1| |#2|)) 60)) (-3903 (($ (-663 |#1|)) 14)) (-1717 (((-121) $ $) 44)) (-1779 (($ $ |#2|) NIL (|has| |#2| (-365)))) (-1773 (($ $) 66) (($ $ $) NIL)) (-1767 (($ $ $) 29)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ |#2| $) 28) (($ $ |#2|) NIL) (($ |#2| (-663 |#1|)) NIL))) 
-(((-656 |#1| |#2|) (-13 (-376 |#1| |#2|) (-384 |#2| (-663 |#1|)) (-10 -8 (-15 -2253 ((-3 $ "failed") (-1257 |#1| |#2|))) (-15 -4287 ($ (-663 |#1|) (-663 |#1|))) (-15 -4287 ($ (-663 |#1|) $)) (-15 -4287 ($ $ (-663 |#1|))))) (-842) (-172)) (T -656)) 
-((-2253 (*1 *1 *2) (|partial| -12 (-5 *2 (-1257 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *1 (-656 *3 *4)))) (-4287 (*1 *1 *2 *2) (-12 (-5 *2 (-663 *3)) (-4 *3 (-842)) (-5 *1 (-656 *3 *4)) (-4 *4 (-172)))) (-4287 (*1 *1 *2 *1) (-12 (-5 *2 (-663 *3)) (-4 *3 (-842)) (-5 *1 (-656 *3 *4)) (-4 *4 (-172)))) (-4287 (*1 *1 *1 *2) (-12 (-5 *2 (-663 *3)) (-4 *3 (-842)) (-5 *1 (-656 *3 *4)) (-4 *4 (-172))))) 
-(-13 (-376 |#1| |#2|) (-384 |#2| (-663 |#1|)) (-10 -8 (-15 -2253 ((-3 $ "failed") (-1257 |#1| |#2|))) (-15 -4287 ($ (-663 |#1|) (-663 |#1|))) (-15 -4287 ($ (-663 |#1|) $)) (-15 -4287 ($ $ (-663 |#1|))))) 
-((-2016 (((-121) $) NIL) (((-121) (-1 (-121) |#2| |#2|) $) 49)) (-3908 (($ $) NIL) (($ (-1 (-121) |#2| |#2|) $) 11)) (-3507 (($ (-1 (-121) |#2|) $) 27)) (-1578 (($ $) 55)) (-3369 (($ $) 62)) (-3405 (($ |#2| $) NIL) (($ (-1 (-121) |#2|) $) 36)) (-3092 ((|#2| (-1 |#2| |#2| |#2|) $) 21) ((|#2| (-1 |#2| |#2| |#2|) $ |#2|) 50) ((|#2| (-1 |#2| |#2| |#2|) $ |#2| |#2|) 52)) (-2764 (((-568) |#2| $ (-568)) 60) (((-568) |#2| $) NIL) (((-568) (-1 (-121) |#2|) $) 46)) (-1849 (($ (-763) |#2|) 53)) (-3349 (($ $ $) NIL) (($ (-1 (-121) |#2| |#2|) $ $) 29)) (-1347 (($ $ $) NIL) (($ (-1 (-121) |#2| |#2|) $ $) 24)) (-2795 (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) 54)) (-3896 (($ |#2|) 14)) (-4450 (($ $ $ (-568)) 35) (($ |#2| $ (-568)) 33)) (-3775 (((-3 |#2| "failed") (-1 (-121) |#2|) $) 45)) (-1783 (($ $ (-1210 (-568))) 43) (($ $ (-568)) 37)) (-2256 (($ $ $ (-568)) 59)) (-3863 (($ $) 57)) (-1732 (((-121) $ $) 64))) 
-(((-657 |#1| |#2|) (-10 -8 (-15 -3896 (|#1| |#2|)) (-15 -1783 (|#1| |#1| (-568))) (-15 -1783 (|#1| |#1| (-1210 (-568)))) (-15 -3405 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -4450 (|#1| |#2| |#1| (-568))) (-15 -4450 (|#1| |#1| |#1| (-568))) (-15 -3349 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -3507 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -3405 (|#1| |#2| |#1|)) (-15 -3369 (|#1| |#1|)) (-15 -3349 (|#1| |#1| |#1|)) (-15 -1347 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -2016 ((-121) (-1 (-121) |#2| |#2|) |#1|)) (-15 -2764 ((-568) (-1 (-121) |#2|) |#1|)) (-15 -2764 ((-568) |#2| |#1|)) (-15 -2764 ((-568) |#2| |#1| (-568))) (-15 -1347 (|#1| |#1| |#1|)) (-15 -2016 ((-121) |#1|)) (-15 -2256 (|#1| |#1| |#1| (-568))) (-15 -1578 (|#1| |#1|)) (-15 -3908 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -3908 (|#1| |#1|)) (-15 -1732 ((-121) |#1| |#1|)) (-15 -3092 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -3092 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3092 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -3775 ((-3 |#2| "failed") (-1 (-121) |#2|) |#1|)) (-15 -1849 (|#1| (-763) |#2|)) (-15 -2795 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -2795 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -3863 (|#1| |#1|))) (-658 |#2|) (-1195)) (T -657)) 
-NIL 
-(-10 -8 (-15 -3896 (|#1| |#2|)) (-15 -1783 (|#1| |#1| (-568))) (-15 -1783 (|#1| |#1| (-1210 (-568)))) (-15 -3405 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -4450 (|#1| |#2| |#1| (-568))) (-15 -4450 (|#1| |#1| |#1| (-568))) (-15 -3349 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -3507 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -3405 (|#1| |#2| |#1|)) (-15 -3369 (|#1| |#1|)) (-15 -3349 (|#1| |#1| |#1|)) (-15 -1347 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -2016 ((-121) (-1 (-121) |#2| |#2|) |#1|)) (-15 -2764 ((-568) (-1 (-121) |#2|) |#1|)) (-15 -2764 ((-568) |#2| |#1|)) (-15 -2764 ((-568) |#2| |#1| (-568))) (-15 -1347 (|#1| |#1| |#1|)) (-15 -2016 ((-121) |#1|)) (-15 -2256 (|#1| |#1| |#1| (-568))) (-15 -1578 (|#1| |#1|)) (-15 -3908 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -3908 (|#1| |#1|)) (-15 -1732 ((-121) |#1| |#1|)) (-15 -3092 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -3092 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3092 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -3775 ((-3 |#2| "failed") (-1 (-121) |#2|) |#1|)) (-15 -1849 (|#1| (-763) |#2|)) (-15 -2795 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -2795 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -3863 (|#1| |#1|))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2850 ((|#1| $) 45)) (-2235 ((|#1| $) 62)) (-2796 (($ $) 64)) (-1868 (((-1249) $ (-568) (-568)) 94 (|has| $ (-6 -4520)))) (-3910 (($ $ (-568)) 49 (|has| $ (-6 -4520)))) (-2016 (((-121) $) 136 (|has| |#1| (-842))) (((-121) (-1 (-121) |#1| |#1|) $) 130)) (-3908 (($ $) 140 (-12 (|has| |#1| (-842)) (|has| $ (-6 -4520)))) (($ (-1 (-121) |#1| |#1|) $) 139 (|has| $ (-6 -4520)))) (-3644 (($ $) 135 (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $) 129)) (-2510 (((-121) $ (-763)) 8)) (-1659 ((|#1| $ |#1|) 36 (|has| $ (-6 -4520)))) (-3869 (($ $ $) 53 (|has| $ (-6 -4520)))) (-2395 ((|#1| $ |#1|) 51 (|has| $ (-6 -4520)))) (-2517 ((|#1| $ |#1|) 55 (|has| $ (-6 -4520)))) (-2436 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4520))) ((|#1| $ "first" |#1|) 54 (|has| $ (-6 -4520))) (($ $ "rest" $) 52 (|has| $ (-6 -4520))) ((|#1| $ "last" |#1|) 50 (|has| $ (-6 -4520))) ((|#1| $ (-1210 (-568)) |#1|) 114 (|has| $ (-6 -4520))) ((|#1| $ (-568) |#1|) 83 (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) 38 (|has| $ (-6 -4520)))) (-3507 (($ (-1 (-121) |#1|) $) 123)) (-2801 (($ (-1 (-121) |#1|) $) 99 (|has| $ (-6 -4519)))) (-1679 ((|#1| $) 63)) (-2671 (($) 7 T CONST)) (-1578 (($ $) 138 (|has| $ (-6 -4520)))) (-3943 (($ $) 128)) (-3935 (($ $) 70) (($ $ (-763)) 68)) (-3369 (($ $) 125 (|has| |#1| (-1090)))) (-3924 (($ $) 96 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3405 (($ |#1| $) 124 (|has| |#1| (-1090))) (($ (-1 (-121) |#1|) $) 119)) (-4328 (($ (-1 (-121) |#1|) $) 100 (|has| $ (-6 -4519))) (($ |#1| $) 97 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $) 102 (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 101 (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 98 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3989 ((|#1| $ (-568) |#1|) 82 (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-568)) 84)) (-1601 (((-121) $) 80)) (-2764 (((-568) |#1| $ (-568)) 133 (|has| |#1| (-1090))) (((-568) |#1| $) 132 (|has| |#1| (-1090))) (((-568) (-1 (-121) |#1|) $) 131)) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-2287 (((-634 $) $) 47)) (-1700 (((-121) $ $) 39 (|has| |#1| (-1090)))) (-1849 (($ (-763) |#1|) 105)) (-1737 (((-121) $ (-763)) 9)) (-1881 (((-568) $) 92 (|has| (-568) (-842)))) (-2521 (($ $ $) 141 (|has| |#1| (-842)))) (-3349 (($ $ $) 126 (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $ $) 122)) (-1347 (($ $ $) 134 (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $ $) 127)) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-2223 (((-568) $) 91 (|has| (-568) (-842)))) (-3268 (($ $ $) 142 (|has| |#1| (-842)))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 108)) (-3896 (($ |#1|) 116)) (-2166 (((-121) $ (-763)) 10)) (-2869 (((-634 |#1|) $) 42)) (-1651 (((-121) $) 46)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4162 ((|#1| $) 67) (($ $ (-763)) 65)) (-4450 (($ $ $ (-568)) 121) (($ |#1| $ (-568)) 120)) (-4122 (($ $ $ (-568)) 113) (($ |#1| $ (-568)) 112)) (-4174 (((-634 (-568)) $) 89)) (-3578 (((-121) (-568) $) 88)) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3876 ((|#1| $) 73) (($ $ (-763)) 71)) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 103)) (-3724 (($ $ |#1|) 93 (|has| $ (-6 -4520)))) (-1786 (((-121) $) 81)) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-4467 (((-121) |#1| $) 90 (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) 87)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 ((|#1| $ "value") 44) ((|#1| $ "first") 72) (($ $ "rest") 69) ((|#1| $ "last") 66) (($ $ (-1210 (-568))) 109) ((|#1| $ (-568)) 86) ((|#1| $ (-568) |#1|) 85)) (-4075 (((-568) $ $) 41)) (-1783 (($ $ (-1210 (-568))) 118) (($ $ (-568)) 117)) (-2826 (($ $ (-1210 (-568))) 111) (($ $ (-568)) 110)) (-3790 (((-121) $) 43)) (-2340 (($ $) 59)) (-2714 (($ $) 56 (|has| $ (-6 -4520)))) (-2775 (((-763) $) 60)) (-3335 (($ $) 61)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-2256 (($ $ $ (-568)) 137 (|has| $ (-6 -4520)))) (-3863 (($ $) 13)) (-4278 (((-541) $) 95 (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) 104)) (-3845 (($ $ $) 58) (($ $ |#1|) 57)) (-2768 (($ $ $) 75) (($ |#1| $) 74) (($ (-634 $)) 107) (($ $ |#1|) 106)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-4339 (((-634 $) $) 48)) (-3491 (((-121) $ $) 40 (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1751 (((-121) $ $) 144 (|has| |#1| (-842)))) (-1738 (((-121) $ $) 145 (|has| |#1| (-842)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1745 (((-121) $ $) 143 (|has| |#1| (-842)))) (-1732 (((-121) $ $) 146 (|has| |#1| (-842)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-2319 ((|#1| $) 21)) (-1732 (($ $ $) NIL (|has| |#1| (-786)))) (-2047 (($ $ $) NIL (|has| |#1| (-786)))) (-1893 (((-1143) $) 46)) (-4025 (((-1108) $) NIL)) (-2326 ((|#3| $) 22)) (-2747 (((-850) $) 42)) (-3058 (($) 10 T CONST)) (-1753 (((-121) $ $) NIL (|has| |#1| (-786)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-786)))) (-1719 (((-121) $ $) 20)) (-1747 (((-121) $ $) NIL (|has| |#1| (-786)))) (-1734 (((-121) $ $) 24 (|has| |#1| (-786)))) (-1781 (($ $ |#3|) 34) (($ |#1| |#3|) 35)) (-1775 (($ $) 17) (($ $ $) NIL)) (-1769 (($ $ $) 27)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 30) (($ |#2| $) 32) (($ $ |#2|) NIL))) 
+(((-652 |#1| |#2| |#3|) (-13 (-707 |#2|) (-10 -8 (IF (|has| |#1| (-786)) (-6 (-786)) |noBranch|) (-15 -1781 ($ $ |#3|)) (-15 -1781 ($ |#1| |#3|)) (-15 -2319 (|#1| $)) (-15 -2326 (|#3| $)))) (-707 |#2|) (-172) (|SubsetCategory| (-716) |#2|)) (T -652)) 
+((-1781 (*1 *1 *1 *2) (-12 (-4 *4 (-172)) (-5 *1 (-652 *3 *4 *2)) (-4 *3 (-707 *4)) (-4 *2 (|SubsetCategory| (-716) *4)))) (-1781 (*1 *1 *2 *3) (-12 (-4 *4 (-172)) (-5 *1 (-652 *2 *4 *3)) (-4 *2 (-707 *4)) (-4 *3 (|SubsetCategory| (-716) *4)))) (-2319 (*1 *2 *1) (-12 (-4 *3 (-172)) (-4 *2 (-707 *3)) (-5 *1 (-652 *2 *3 *4)) (-4 *4 (|SubsetCategory| (-716) *3)))) (-2326 (*1 *2 *1) (-12 (-4 *4 (-172)) (-4 *2 (|SubsetCategory| (-716) *4)) (-5 *1 (-652 *3 *4 *2)) (-4 *3 (-707 *4))))) 
+(-13 (-707 |#2|) (-10 -8 (IF (|has| |#1| (-786)) (-6 (-786)) |noBranch|) (-15 -1781 ($ $ |#3|)) (-15 -1781 ($ |#1| |#3|)) (-15 -2319 (|#1| $)) (-15 -2326 (|#3| $)))) 
+((-3997 (((-679 |#1|) (-679 |#1|)) 27)) (-4473 (((-679 |#1|) (-679 |#1|)) 26)) (-2502 (((-634 (-634 |#1|)) (-634 |#1|) (-634 (-634 |#1|))) 44)) (-2856 (((-634 (-634 |#1|)) (-634 (-634 |#1|))) 29)) (-2546 (((-634 |#1|) (-634 |#1|) (-634 |#1|) |#1|) 43)) (-3672 (((-634 (-634 |#1|)) (-634 (-634 |#1|)) (-634 (-634 |#1|))) 34))) 
+(((-653 |#1|) (-10 -7 (-15 -3997 ((-679 |#1|) (-679 |#1|))) (-15 -4473 ((-679 |#1|) (-679 |#1|))) (-15 -2856 ((-634 (-634 |#1|)) (-634 (-634 |#1|)))) (-15 -3672 ((-634 (-634 |#1|)) (-634 (-634 |#1|)) (-634 (-634 |#1|)))) (-15 -2546 ((-634 |#1|) (-634 |#1|) (-634 |#1|) |#1|)) (-15 -2502 ((-634 (-634 |#1|)) (-634 |#1|) (-634 (-634 |#1|))))) (-365)) (T -653)) 
+((-2502 (*1 *2 *3 *2) (-12 (-5 *2 (-634 (-634 *4))) (-5 *3 (-634 *4)) (-4 *4 (-365)) (-5 *1 (-653 *4)))) (-2546 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-5 *1 (-653 *3)))) (-3672 (*1 *2 *2 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-365)) (-5 *1 (-653 *3)))) (-2856 (*1 *2 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-365)) (-5 *1 (-653 *3)))) (-4473 (*1 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-365)) (-5 *1 (-653 *3)))) (-3997 (*1 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-365)) (-5 *1 (-653 *3))))) 
+(-10 -7 (-15 -3997 ((-679 |#1|) (-679 |#1|))) (-15 -4473 ((-679 |#1|) (-679 |#1|))) (-15 -2856 ((-634 (-634 |#1|)) (-634 (-634 |#1|)))) (-15 -3672 ((-634 (-634 |#1|)) (-634 (-634 |#1|)) (-634 (-634 |#1|)))) (-15 -2546 ((-634 |#1|) (-634 |#1|) (-634 |#1|) |#1|)) (-15 -2502 ((-634 (-634 |#1|)) (-634 |#1|) (-634 (-634 |#1|))))) 
+((-1277 (((-121)) 46) (((-121) (-121)) 47)) (-3390 ((|#7| |#5| |#3|) 44)) (-1345 ((|#5| |#7|) 29)) (-1458 (((-2 (|:| |fnc| |#3|) (|:| |crv| |#3|) (|:| |chart| (-634 (-568)))) |#3| |#5| |#3| (-568)) 99)) (-2877 (((-634 |#6|) |#5| |#3| (-568)) 35))) 
+(((-654 |#1| |#2| |#3| |#4| |#5| |#6| |#7|) (-10 -7 (-15 -1277 ((-121) (-121))) (-15 -1277 ((-121))) (-15 -3390 (|#7| |#5| |#3|)) (-15 -2877 ((-634 |#6|) |#5| |#3| (-568))) (-15 -1345 (|#5| |#7|)) (-15 -1458 ((-2 (|:| |fnc| |#3|) (|:| |crv| |#3|) (|:| |chart| (-634 (-568)))) |#3| |#5| |#3| (-568)))) (-365) (-634 (-1161)) (-950 |#1| |#4| (-852 |#2|)) (-230 (-1699 |#2|) (-763)) (-971 |#1|) (-641 |#1|) (-920 |#1| |#6|)) (T -654)) 
+((-1458 (*1 *2 *3 *4 *3 *5) (-12 (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *8 (-230 (-1699 *7) (-763))) (-4 *9 (-641 *6)) (-5 *2 (-2 (|:| |fnc| *3) (|:| |crv| *3) (|:| |chart| (-634 (-568))))) (-5 *1 (-654 *6 *7 *3 *8 *4 *9 *10)) (-5 *5 (-568)) (-4 *3 (-950 *6 *8 (-852 *7))) (-4 *4 (-971 *6)) (-4 *10 (-920 *6 *9)))) (-1345 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-641 *4)) (-4 *2 (-971 *4)) (-5 *1 (-654 *4 *5 *6 *7 *2 *8 *3)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *3 (-920 *4 *8)))) (-2877 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-568)) (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *8 (-230 (-1699 *7) (-763))) (-4 *9 (-641 *6)) (-5 *2 (-634 *9)) (-5 *1 (-654 *6 *7 *4 *8 *3 *9 *10)) (-4 *4 (-950 *6 *8 (-852 *7))) (-4 *3 (-971 *6)) (-4 *10 (-920 *6 *9)))) (-3390 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1699 *6) (-763))) (-4 *2 (-920 *5 *8)) (-5 *1 (-654 *5 *6 *4 *7 *3 *8 *2)) (-4 *4 (-950 *5 *7 (-852 *6))) (-4 *3 (-971 *5)) (-4 *8 (-641 *5)))) (-1277 (*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *8 (-641 *3)) (-5 *2 (-121)) (-5 *1 (-654 *3 *4 *5 *6 *7 *8 *9)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *7 (-971 *3)) (-4 *9 (-920 *3 *8)))) (-1277 (*1 *2 *2) (-12 (-5 *2 (-121)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *8 (-641 *3)) (-5 *1 (-654 *3 *4 *5 *6 *7 *8 *9)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *7 (-971 *3)) (-4 *9 (-920 *3 *8))))) 
+(-10 -7 (-15 -1277 ((-121) (-121))) (-15 -1277 ((-121))) (-15 -3390 (|#7| |#5| |#3|)) (-15 -2877 ((-634 |#6|) |#5| |#3| (-568))) (-15 -1345 (|#5| |#7|)) (-15 -1458 ((-2 (|:| |fnc| |#3|) (|:| |crv| |#3|) (|:| |chart| (-634 (-568)))) |#3| |#5| |#3| (-568)))) 
+((-2952 (((-3 (-634 (-1157 |#1|)) "failed") (-634 (-1157 |#1|)) (-1157 |#1|)) 33))) 
+(((-655 |#1|) (-10 -7 (-15 -2952 ((-3 (-634 (-1157 |#1|)) "failed") (-634 (-1157 |#1|)) (-1157 |#1|)))) (-904)) (T -655)) 
+((-2952 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 *4))) (-5 *3 (-1157 *4)) (-4 *4 (-904)) (-5 *1 (-655 *4))))) 
+(-10 -7 (-15 -2952 ((-3 (-634 (-1157 |#1|)) "failed") (-634 (-1157 |#1|)) (-1157 |#1|)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2981 (((-634 |#1|) $) 82)) (-3784 (($ $ (-763)) 90)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-4242 (((-1266 |#1| |#2|) (-1266 |#1| |#2|) $) 48)) (-3668 (((-3 (-663 |#1|) "failed") $) NIL)) (-2857 (((-663 |#1|) $) NIL)) (-2116 (($ $) 89)) (-3971 (((-763) $) NIL)) (-3062 (((-634 $) $) NIL)) (-2171 (((-121) $) NIL)) (-2356 (($ (-663 |#1|) |#2|) 68)) (-2310 (($ $) 86)) (-2797 (($ (-1 |#2| |#2|) $) NIL)) (-1797 (((-1266 |#1| |#2|) (-1266 |#1| |#2|) $) 47)) (-3016 (((-634 (-2 (|:| |k| (-663 |#1|)) (|:| |c| |#2|))) $) NIL)) (-3749 (((-2 (|:| |k| (-663 |#1|)) (|:| |c| |#2|)) $) NIL)) (-2099 (((-663 |#1|) $) NIL)) (-2104 ((|#2| $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-1339 (($ $ |#1| $) 30) (($ $ (-634 |#1|) (-634 $)) 32)) (-1836 (((-763) $) 88)) (-4289 (($ $ $) 20) (($ (-663 |#1|) (-663 |#1|)) 77) (($ (-663 |#1|) $) 75) (($ $ (-663 |#1|)) 76)) (-2747 (((-850) $) NIL) (($ |#1|) 74) (((-1257 |#1| |#2|) $) 58) (((-1266 |#1| |#2|) $) 41) (($ (-663 |#1|)) 25)) (-3304 (((-634 |#2|) $) NIL)) (-2079 ((|#2| $ (-663 |#1|)) NIL)) (-2350 ((|#2| (-1266 |#1| |#2|) $) 43)) (-3058 (($) 23 T CONST)) (-3288 (((-3 $ "failed") (-1257 |#1| |#2|)) 60)) (-2081 (($ (-663 |#1|)) 14)) (-1719 (((-121) $ $) 44)) (-1781 (($ $ |#2|) NIL (|has| |#2| (-365)))) (-1775 (($ $) 66) (($ $ $) NIL)) (-1769 (($ $ $) 29)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ |#2| $) 28) (($ $ |#2|) NIL) (($ |#2| (-663 |#1|)) NIL))) 
+(((-656 |#1| |#2|) (-13 (-376 |#1| |#2|) (-384 |#2| (-663 |#1|)) (-10 -8 (-15 -3288 ((-3 $ "failed") (-1257 |#1| |#2|))) (-15 -4289 ($ (-663 |#1|) (-663 |#1|))) (-15 -4289 ($ (-663 |#1|) $)) (-15 -4289 ($ $ (-663 |#1|))))) (-842) (-172)) (T -656)) 
+((-3288 (*1 *1 *2) (|partial| -12 (-5 *2 (-1257 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *1 (-656 *3 *4)))) (-4289 (*1 *1 *2 *2) (-12 (-5 *2 (-663 *3)) (-4 *3 (-842)) (-5 *1 (-656 *3 *4)) (-4 *4 (-172)))) (-4289 (*1 *1 *2 *1) (-12 (-5 *2 (-663 *3)) (-4 *3 (-842)) (-5 *1 (-656 *3 *4)) (-4 *4 (-172)))) (-4289 (*1 *1 *1 *2) (-12 (-5 *2 (-663 *3)) (-4 *3 (-842)) (-5 *1 (-656 *3 *4)) (-4 *4 (-172))))) 
+(-13 (-376 |#1| |#2|) (-384 |#2| (-663 |#1|)) (-10 -8 (-15 -3288 ((-3 $ "failed") (-1257 |#1| |#2|))) (-15 -4289 ($ (-663 |#1|) (-663 |#1|))) (-15 -4289 ($ (-663 |#1|) $)) (-15 -4289 ($ $ (-663 |#1|))))) 
+((-1324 (((-121) $) NIL) (((-121) (-1 (-121) |#2| |#2|) $) 49)) (-2109 (($ $) NIL) (($ (-1 (-121) |#2| |#2|) $) 11)) (-3963 (($ (-1 (-121) |#2|) $) 27)) (-4452 (($ $) 55)) (-1377 (($ $) 62)) (-1568 (($ |#2| $) NIL) (($ (-1 (-121) |#2|) $) 36)) (-3094 ((|#2| (-1 |#2| |#2| |#2|) $) 21) ((|#2| (-1 |#2| |#2| |#2|) $ |#2|) 50) ((|#2| (-1 |#2| |#2| |#2|) $ |#2| |#2|) 52)) (-2766 (((-568) |#2| $ (-568)) 60) (((-568) |#2| $) NIL) (((-568) (-1 (-121) |#2|) $) 46)) (-1851 (($ (-763) |#2|) 53)) (-4496 (($ $ $) NIL) (($ (-1 (-121) |#2| |#2|) $ $) 29)) (-3645 (($ $ $) NIL) (($ (-1 (-121) |#2| |#2|) $ $) 24)) (-2797 (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) 54)) (-3897 (($ |#2|) 14)) (-1708 (($ $ $ (-568)) 35) (($ |#2| $ (-568)) 33)) (-2712 (((-3 |#2| "failed") (-1 (-121) |#2|) $) 45)) (-4031 (($ $ (-1210 (-568))) 43) (($ $ (-568)) 37)) (-3306 (($ $ $ (-568)) 59)) (-3865 (($ $) 57)) (-1734 (((-121) $ $) 64))) 
+(((-657 |#1| |#2|) (-10 -8 (-15 -3897 (|#1| |#2|)) (-15 -4031 (|#1| |#1| (-568))) (-15 -4031 (|#1| |#1| (-1210 (-568)))) (-15 -1568 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -1708 (|#1| |#2| |#1| (-568))) (-15 -1708 (|#1| |#1| |#1| (-568))) (-15 -4496 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -3963 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -1568 (|#1| |#2| |#1|)) (-15 -1377 (|#1| |#1|)) (-15 -4496 (|#1| |#1| |#1|)) (-15 -3645 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -1324 ((-121) (-1 (-121) |#2| |#2|) |#1|)) (-15 -2766 ((-568) (-1 (-121) |#2|) |#1|)) (-15 -2766 ((-568) |#2| |#1|)) (-15 -2766 ((-568) |#2| |#1| (-568))) (-15 -3645 (|#1| |#1| |#1|)) (-15 -1324 ((-121) |#1|)) (-15 -3306 (|#1| |#1| |#1| (-568))) (-15 -4452 (|#1| |#1|)) (-15 -2109 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -2109 (|#1| |#1|)) (-15 -1734 ((-121) |#1| |#1|)) (-15 -3094 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -3094 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3094 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -2712 ((-3 |#2| "failed") (-1 (-121) |#2|) |#1|)) (-15 -1851 (|#1| (-763) |#2|)) (-15 -2797 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -2797 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -3865 (|#1| |#1|))) (-658 |#2|) (-1195)) (T -657)) 
+NIL 
+(-10 -8 (-15 -3897 (|#1| |#2|)) (-15 -4031 (|#1| |#1| (-568))) (-15 -4031 (|#1| |#1| (-1210 (-568)))) (-15 -1568 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -1708 (|#1| |#2| |#1| (-568))) (-15 -1708 (|#1| |#1| |#1| (-568))) (-15 -4496 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -3963 (|#1| (-1 (-121) |#2|) |#1|)) (-15 -1568 (|#1| |#2| |#1|)) (-15 -1377 (|#1| |#1|)) (-15 -4496 (|#1| |#1| |#1|)) (-15 -3645 (|#1| (-1 (-121) |#2| |#2|) |#1| |#1|)) (-15 -1324 ((-121) (-1 (-121) |#2| |#2|) |#1|)) (-15 -2766 ((-568) (-1 (-121) |#2|) |#1|)) (-15 -2766 ((-568) |#2| |#1|)) (-15 -2766 ((-568) |#2| |#1| (-568))) (-15 -3645 (|#1| |#1| |#1|)) (-15 -1324 ((-121) |#1|)) (-15 -3306 (|#1| |#1| |#1| (-568))) (-15 -4452 (|#1| |#1|)) (-15 -2109 (|#1| (-1 (-121) |#2| |#2|) |#1|)) (-15 -2109 (|#1| |#1|)) (-15 -1734 ((-121) |#1| |#1|)) (-15 -3094 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2| |#2|)) (-15 -3094 (|#2| (-1 |#2| |#2| |#2|) |#1| |#2|)) (-15 -3094 (|#2| (-1 |#2| |#2| |#2|) |#1|)) (-15 -2712 ((-3 |#2| "failed") (-1 (-121) |#2|) |#1|)) (-15 -1851 (|#1| (-763) |#2|)) (-15 -2797 (|#1| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -2797 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -3865 (|#1| |#1|))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2852 ((|#1| $) 45)) (-2237 ((|#1| $) 62)) (-3623 (($ $) 64)) (-2481 (((-1249) $ (-568) (-568)) 94 (|has| $ (-6 -4522)))) (-2121 (($ $ (-568)) 49 (|has| $ (-6 -4522)))) (-1324 (((-121) $) 136 (|has| |#1| (-842))) (((-121) (-1 (-121) |#1| |#1|) $) 130)) (-2109 (($ $) 140 (-12 (|has| |#1| (-842)) (|has| $ (-6 -4522)))) (($ (-1 (-121) |#1| |#1|) $) 139 (|has| $ (-6 -4522)))) (-3647 (($ $) 135 (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $) 129)) (-1667 (((-121) $ (-763)) 8)) (-3370 ((|#1| $ |#1|) 36 (|has| $ (-6 -4522)))) (-1958 (($ $ $) 53 (|has| $ (-6 -4522)))) (-2257 ((|#1| $ |#1|) 51 (|has| $ (-6 -4522)))) (-1706 ((|#1| $ |#1|) 55 (|has| $ (-6 -4522)))) (-2438 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4522))) ((|#1| $ "first" |#1|) 54 (|has| $ (-6 -4522))) (($ $ "rest" $) 52 (|has| $ (-6 -4522))) ((|#1| $ "last" |#1|) 50 (|has| $ (-6 -4522))) ((|#1| $ (-1210 (-568)) |#1|) 114 (|has| $ (-6 -4522))) ((|#1| $ (-568) |#1|) 83 (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) 38 (|has| $ (-6 -4522)))) (-3963 (($ (-1 (-121) |#1|) $) 123)) (-2803 (($ (-1 (-121) |#1|) $) 99 (|has| $ (-6 -4521)))) (-1681 ((|#1| $) 63)) (-4490 (($) 7 T CONST)) (-4452 (($ $) 138 (|has| $ (-6 -4522)))) (-3945 (($ $) 128)) (-3936 (($ $) 70) (($ $ (-763)) 68)) (-1377 (($ $) 125 (|has| |#1| (-1090)))) (-3926 (($ $) 96 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-1568 (($ |#1| $) 124 (|has| |#1| (-1090))) (($ (-1 (-121) |#1|) $) 119)) (-4330 (($ (-1 (-121) |#1|) $) 100 (|has| $ (-6 -4521))) (($ |#1| $) 97 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $) 102 (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 101 (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 98 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-1292 ((|#1| $ (-568) |#1|) 82 (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-568)) 84)) (-1340 (((-121) $) 80)) (-2766 (((-568) |#1| $ (-568)) 133 (|has| |#1| (-1090))) (((-568) |#1| $) 132 (|has| |#1| (-1090))) (((-568) (-1 (-121) |#1|) $) 131)) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-3534 (((-634 $) $) 47)) (-3606 (((-121) $ $) 39 (|has| |#1| (-1090)))) (-1851 (($ (-763) |#1|) 105)) (-3791 (((-121) $ (-763)) 9)) (-2539 (((-568) $) 92 (|has| (-568) (-842)))) (-1732 (($ $ $) 141 (|has| |#1| (-842)))) (-4496 (($ $ $) 126 (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $ $) 122)) (-3645 (($ $ $) 134 (|has| |#1| (-842))) (($ (-1 (-121) |#1| |#1|) $ $) 127)) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3631 (((-568) $) 91 (|has| (-568) (-842)))) (-2047 (($ $ $) 142 (|has| |#1| (-842)))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 108)) (-3897 (($ |#1|) 116)) (-3796 (((-121) $ (-763)) 10)) (-4081 (((-634 |#1|) $) 42)) (-3319 (((-121) $) 46)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4164 ((|#1| $) 67) (($ $ (-763)) 65)) (-1708 (($ $ $ (-568)) 121) (($ |#1| $ (-568)) 120)) (-4124 (($ $ $ (-568)) 113) (($ |#1| $ (-568)) 112)) (-3948 (((-634 (-568)) $) 89)) (-2916 (((-121) (-568) $) 88)) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3877 ((|#1| $) 73) (($ $ (-763)) 71)) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 103)) (-2490 (($ $ |#1|) 93 (|has| $ (-6 -4522)))) (-4049 (((-121) $) 81)) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-1801 (((-121) |#1| $) 90 (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) 87)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 ((|#1| $ "value") 44) ((|#1| $ "first") 72) (($ $ "rest") 69) ((|#1| $ "last") 66) (($ $ (-1210 (-568))) 109) ((|#1| $ (-568)) 86) ((|#1| $ (-568) |#1|) 85)) (-1665 (((-568) $ $) 41)) (-4031 (($ $ (-1210 (-568))) 118) (($ $ (-568)) 117)) (-2828 (($ $ (-1210 (-568))) 111) (($ $ (-568)) 110)) (-2763 (((-121) $) 43)) (-3903 (($ $) 59)) (-1499 (($ $) 56 (|has| $ (-6 -4522)))) (-3535 (((-763) $) 60)) (-4424 (($ $) 61)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3306 (($ $ $ (-568)) 137 (|has| $ (-6 -4522)))) (-3865 (($ $) 13)) (-4280 (((-541) $) 95 (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) 104)) (-1876 (($ $ $) 58) (($ $ |#1|) 57)) (-2770 (($ $ $) 75) (($ |#1| $) 74) (($ (-634 $)) 107) (($ $ |#1|) 106)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-3180 (((-634 $) $) 48)) (-3873 (((-121) $ $) 40 (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1753 (((-121) $ $) 144 (|has| |#1| (-842)))) (-1740 (((-121) $ $) 145 (|has| |#1| (-842)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1747 (((-121) $ $) 143 (|has| |#1| (-842)))) (-1734 (((-121) $ $) 146 (|has| |#1| (-842)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-658 |#1|) (-1275) (-1195)) (T -658)) 
-((-3896 (*1 *1 *2) (-12 (-4 *1 (-658 *2)) (-4 *2 (-1195))))) 
-(-13 (-1134 |t#1|) (-375 |t#1|) (-277 |t#1|) (-10 -8 (-15 -3896 ($ |t#1|)))) 
-(((-39) . T) ((-105) -2198 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-608 (-850)) -2198 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-154 |#1|) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-281 (-568) |#1|) . T) ((-283 (-568) |#1|) . T) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-277 |#1|) . T) ((-375 |#1|) . T) ((-499 |#1|) . T) ((-601 (-568) |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-640 |#1|) . T) ((-842) |has| |#1| (-842)) ((-1010 |#1|) . T) ((-1090) -2198 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-1134 |#1|) . T) ((-1195) . T) ((-1231 |#1|) . T)) 
-((-4351 (((-634 (-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -3746 (-634 (-1244 |#1|))))) (-634 (-634 |#1|)) (-634 (-1244 |#1|))) 21) (((-634 (-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -3746 (-634 (-1244 |#1|))))) (-679 |#1|) (-634 (-1244 |#1|))) 20) (((-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -3746 (-634 (-1244 |#1|)))) (-634 (-634 |#1|)) (-1244 |#1|)) 16) (((-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -3746 (-634 (-1244 |#1|)))) (-679 |#1|) (-1244 |#1|)) 13)) (-3700 (((-763) (-679 |#1|) (-1244 |#1|)) 29)) (-4314 (((-3 (-1244 |#1|) "failed") (-679 |#1|) (-1244 |#1|)) 23)) (-4485 (((-121) (-679 |#1|) (-1244 |#1|)) 26))) 
-(((-659 |#1|) (-10 -7 (-15 -4351 ((-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -3746 (-634 (-1244 |#1|)))) (-679 |#1|) (-1244 |#1|))) (-15 -4351 ((-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -3746 (-634 (-1244 |#1|)))) (-634 (-634 |#1|)) (-1244 |#1|))) (-15 -4351 ((-634 (-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -3746 (-634 (-1244 |#1|))))) (-679 |#1|) (-634 (-1244 |#1|)))) (-15 -4351 ((-634 (-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -3746 (-634 (-1244 |#1|))))) (-634 (-634 |#1|)) (-634 (-1244 |#1|)))) (-15 -4314 ((-3 (-1244 |#1|) "failed") (-679 |#1|) (-1244 |#1|))) (-15 -4485 ((-121) (-679 |#1|) (-1244 |#1|))) (-15 -3700 ((-763) (-679 |#1|) (-1244 |#1|)))) (-365)) (T -659)) 
-((-3700 (*1 *2 *3 *4) (-12 (-5 *3 (-679 *5)) (-5 *4 (-1244 *5)) (-4 *5 (-365)) (-5 *2 (-763)) (-5 *1 (-659 *5)))) (-4485 (*1 *2 *3 *4) (-12 (-5 *3 (-679 *5)) (-5 *4 (-1244 *5)) (-4 *5 (-365)) (-5 *2 (-121)) (-5 *1 (-659 *5)))) (-4314 (*1 *2 *3 *2) (|partial| -12 (-5 *2 (-1244 *4)) (-5 *3 (-679 *4)) (-4 *4 (-365)) (-5 *1 (-659 *4)))) (-4351 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-634 *5))) (-4 *5 (-365)) (-5 *2 (-634 (-2 (|:| |particular| (-3 (-1244 *5) "failed")) (|:| -3746 (-634 (-1244 *5)))))) (-5 *1 (-659 *5)) (-5 *4 (-634 (-1244 *5))))) (-4351 (*1 *2 *3 *4) (-12 (-5 *3 (-679 *5)) (-4 *5 (-365)) (-5 *2 (-634 (-2 (|:| |particular| (-3 (-1244 *5) "failed")) (|:| -3746 (-634 (-1244 *5)))))) (-5 *1 (-659 *5)) (-5 *4 (-634 (-1244 *5))))) (-4351 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-634 *5))) (-4 *5 (-365)) (-5 *2 (-2 (|:| |particular| (-3 (-1244 *5) "failed")) (|:| -3746 (-634 (-1244 *5))))) (-5 *1 (-659 *5)) (-5 *4 (-1244 *5)))) (-4351 (*1 *2 *3 *4) (-12 (-5 *3 (-679 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| |particular| (-3 (-1244 *5) "failed")) (|:| -3746 (-634 (-1244 *5))))) (-5 *1 (-659 *5)) (-5 *4 (-1244 *5))))) 
-(-10 -7 (-15 -4351 ((-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -3746 (-634 (-1244 |#1|)))) (-679 |#1|) (-1244 |#1|))) (-15 -4351 ((-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -3746 (-634 (-1244 |#1|)))) (-634 (-634 |#1|)) (-1244 |#1|))) (-15 -4351 ((-634 (-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -3746 (-634 (-1244 |#1|))))) (-679 |#1|) (-634 (-1244 |#1|)))) (-15 -4351 ((-634 (-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -3746 (-634 (-1244 |#1|))))) (-634 (-634 |#1|)) (-634 (-1244 |#1|)))) (-15 -4314 ((-3 (-1244 |#1|) "failed") (-679 |#1|) (-1244 |#1|))) (-15 -4485 ((-121) (-679 |#1|) (-1244 |#1|))) (-15 -3700 ((-763) (-679 |#1|) (-1244 |#1|)))) 
-((-4351 (((-634 (-2 (|:| |particular| (-3 |#3| "failed")) (|:| -3746 (-634 |#3|)))) |#4| (-634 |#3|)) 47) (((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -3746 (-634 |#3|))) |#4| |#3|) 45)) (-3700 (((-763) |#4| |#3|) 17)) (-4314 (((-3 |#3| "failed") |#4| |#3|) 20)) (-4485 (((-121) |#4| |#3|) 13))) 
-(((-660 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4351 ((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -3746 (-634 |#3|))) |#4| |#3|)) (-15 -4351 ((-634 (-2 (|:| |particular| (-3 |#3| "failed")) (|:| -3746 (-634 |#3|)))) |#4| (-634 |#3|))) (-15 -4314 ((-3 |#3| "failed") |#4| |#3|)) (-15 -4485 ((-121) |#4| |#3|)) (-15 -3700 ((-763) |#4| |#3|))) (-365) (-13 (-375 |#1|) (-10 -7 (-6 -4520))) (-13 (-375 |#1|) (-10 -7 (-6 -4520))) (-677 |#1| |#2| |#3|)) (T -660)) 
-((-3700 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-13 (-375 *5) (-10 -7 (-6 -4520)))) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4520)))) (-5 *2 (-763)) (-5 *1 (-660 *5 *6 *4 *3)) (-4 *3 (-677 *5 *6 *4)))) (-4485 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-13 (-375 *5) (-10 -7 (-6 -4520)))) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4520)))) (-5 *2 (-121)) (-5 *1 (-660 *5 *6 *4 *3)) (-4 *3 (-677 *5 *6 *4)))) (-4314 (*1 *2 *3 *2) (|partial| -12 (-4 *4 (-365)) (-4 *5 (-13 (-375 *4) (-10 -7 (-6 -4520)))) (-4 *2 (-13 (-375 *4) (-10 -7 (-6 -4520)))) (-5 *1 (-660 *4 *5 *2 *3)) (-4 *3 (-677 *4 *5 *2)))) (-4351 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-13 (-375 *5) (-10 -7 (-6 -4520)))) (-4 *7 (-13 (-375 *5) (-10 -7 (-6 -4520)))) (-5 *2 (-634 (-2 (|:| |particular| (-3 *7 "failed")) (|:| -3746 (-634 *7))))) (-5 *1 (-660 *5 *6 *7 *3)) (-5 *4 (-634 *7)) (-4 *3 (-677 *5 *6 *7)))) (-4351 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-13 (-375 *5) (-10 -7 (-6 -4520)))) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4520)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -3746 (-634 *4)))) (-5 *1 (-660 *5 *6 *4 *3)) (-4 *3 (-677 *5 *6 *4))))) 
-(-10 -7 (-15 -4351 ((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -3746 (-634 |#3|))) |#4| |#3|)) (-15 -4351 ((-634 (-2 (|:| |particular| (-3 |#3| "failed")) (|:| -3746 (-634 |#3|)))) |#4| (-634 |#3|))) (-15 -4314 ((-3 |#3| "failed") |#4| |#3|)) (-15 -4485 ((-121) |#4| |#3|)) (-15 -3700 ((-763) |#4| |#3|))) 
-((-2901 (((-2 (|:| |particular| (-3 (-1244 (-409 |#4|)) "failed")) (|:| -3746 (-634 (-1244 (-409 |#4|))))) (-634 |#4|) (-634 |#3|)) 44))) 
-(((-661 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2901 ((-2 (|:| |particular| (-3 (-1244 (-409 |#4|)) "failed")) (|:| -3746 (-634 (-1244 (-409 |#4|))))) (-634 |#4|) (-634 |#3|)))) (-558) (-788) (-842) (-950 |#1| |#2| |#3|)) (T -661)) 
-((-2901 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 *7)) (-4 *7 (-842)) (-4 *8 (-950 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-5 *2 (-2 (|:| |particular| (-3 (-1244 (-409 *8)) "failed")) (|:| -3746 (-634 (-1244 (-409 *8)))))) (-5 *1 (-661 *5 *6 *7 *8))))) 
-(-10 -7 (-15 -2901 ((-2 (|:| |particular| (-3 (-1244 (-409 |#4|)) "failed")) (|:| -3746 (-634 (-1244 (-409 |#4|))))) (-634 |#4|) (-634 |#3|)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2295 (((-3 $ "failed")) NIL (|has| |#2| (-558)))) (-1932 ((|#2| $) NIL)) (-1335 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2776 (((-1244 (-679 |#2|))) NIL) (((-1244 (-679 |#2|)) (-1244 $)) NIL)) (-2230 (((-121) $) NIL)) (-1741 (((-1244 $)) 37)) (-2510 (((-121) $ (-763)) NIL)) (-3422 (($ |#2|) NIL)) (-2671 (($) NIL T CONST)) (-4167 (($ $) NIL (|has| |#2| (-301)))) (-1818 (((-232 |#1| |#2|) $ (-568)) NIL)) (-1309 (((-3 (-2 (|:| |particular| $) (|:| -3746 (-634 $))) "failed")) NIL (|has| |#2| (-558)))) (-2593 (((-3 $ "failed")) NIL (|has| |#2| (-558)))) (-1631 (((-679 |#2|)) NIL) (((-679 |#2|) (-1244 $)) NIL)) (-1866 ((|#2| $) NIL)) (-3042 (((-679 |#2|) $) NIL) (((-679 |#2|) $ (-1244 $)) NIL)) (-3550 (((-3 $ "failed") $) NIL (|has| |#2| (-558)))) (-4408 (((-1157 (-953 |#2|))) NIL (|has| |#2| (-365)))) (-3551 (($ $ (-917)) NIL)) (-4409 ((|#2| $) NIL)) (-1371 (((-1157 |#2|) $) NIL (|has| |#2| (-558)))) (-3569 ((|#2|) NIL) ((|#2| (-1244 $)) NIL)) (-2989 (((-1157 |#2|) $) NIL)) (-3384 (((-121)) NIL)) (-3666 (((-3 (-568) "failed") $) NIL (|has| |#2| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-3 |#2| "failed") $) NIL)) (-2854 (((-568) $) NIL (|has| |#2| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#2| (-1037 (-409 (-568))))) ((|#2| $) NIL)) (-3498 (($ (-1244 |#2|)) NIL) (($ (-1244 |#2|) (-1244 $)) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL) (((-679 |#2|) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3700 (((-763) $) NIL (|has| |#2| (-558))) (((-917)) 38)) (-2602 ((|#2| $ (-568) (-568)) NIL)) (-4370 (((-121)) NIL)) (-4373 (($ $ (-917)) NIL)) (-4360 (((-634 |#2|) $) NIL (|has| $ (-6 -4519)))) (-2735 (((-121) $) NIL)) (-2121 (((-763) $) NIL (|has| |#2| (-558)))) (-4272 (((-634 (-232 |#1| |#2|)) $) NIL (|has| |#2| (-558)))) (-3043 (((-763) $) NIL)) (-1537 (((-121)) NIL)) (-2555 (((-763) $) NIL)) (-1737 (((-121) $ (-763)) NIL)) (-3082 ((|#2| $) NIL (|has| |#2| (-6 (-4521 "*"))))) (-2087 (((-568) $) NIL)) (-3364 (((-568) $) NIL)) (-1979 (((-634 |#2|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-1663 (((-568) $) NIL)) (-2893 (((-568) $) NIL)) (-2269 (($ (-634 (-634 |#2|))) NIL)) (-3674 (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#2| |#2| |#2|) $ $) NIL) (($ (-1 |#2| |#2|) $) NIL)) (-3208 (((-634 (-634 |#2|)) $) NIL)) (-1580 (((-121)) NIL)) (-1695 (((-121)) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-3116 (((-3 (-2 (|:| |particular| $) (|:| -3746 (-634 $))) "failed")) NIL (|has| |#2| (-558)))) (-2599 (((-3 $ "failed")) NIL (|has| |#2| (-558)))) (-4210 (((-679 |#2|)) NIL) (((-679 |#2|) (-1244 $)) NIL)) (-2889 ((|#2| $) NIL)) (-4333 (((-679 |#2|) $) NIL) (((-679 |#2|) $ (-1244 $)) NIL)) (-3243 (((-3 $ "failed") $) NIL (|has| |#2| (-558)))) (-4454 (((-1157 (-953 |#2|))) NIL (|has| |#2| (-365)))) (-4222 (($ $ (-917)) NIL)) (-3329 ((|#2| $) NIL)) (-2265 (((-1157 |#2|) $) NIL (|has| |#2| (-558)))) (-3898 ((|#2|) NIL) ((|#2| (-1244 $)) NIL)) (-3626 (((-1157 |#2|) $) NIL)) (-2767 (((-121)) NIL)) (-4487 (((-1143) $) NIL)) (-1804 (((-121)) NIL)) (-2919 (((-121)) NIL)) (-3840 (((-121)) NIL)) (-3140 (((-3 $ "failed") $) NIL (|has| |#2| (-365)))) (-4022 (((-1108) $) NIL)) (-1346 (((-121)) NIL)) (-2595 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-558)))) (-1387 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#2| $ (-568) (-568) |#2|) NIL) ((|#2| $ (-568) (-568)) 22) ((|#2| $ (-568)) NIL)) (-4189 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-763)) NIL (|has| |#2| (-225))) (($ $) NIL (|has| |#2| (-225)))) (-3241 ((|#2| $) NIL)) (-2282 (($ (-634 |#2|)) NIL)) (-1960 (((-121) $) NIL)) (-3815 (((-232 |#1| |#2|) $) NIL)) (-2465 ((|#2| $) NIL (|has| |#2| (-6 (-4521 "*"))))) (-4168 (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-3863 (($ $) NIL)) (-4073 (((-679 |#2|) (-1244 $)) NIL) (((-1244 |#2|) $) NIL) (((-679 |#2|) (-1244 $) (-1244 $)) NIL) (((-1244 |#2|) $ (-1244 $)) 25)) (-4278 (($ (-1244 |#2|)) NIL) (((-1244 |#2|) $) NIL)) (-3295 (((-634 (-953 |#2|))) NIL) (((-634 (-953 |#2|)) (-1244 $)) NIL)) (-2353 (($ $ $) NIL)) (-3433 (((-121)) NIL)) (-3731 (((-232 |#1| |#2|) $ (-568)) NIL)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ (-409 (-568))) NIL (|has| |#2| (-1037 (-409 (-568))))) (($ |#2|) NIL) (((-679 |#2|) $) NIL)) (-4078 (((-763)) NIL)) (-3746 (((-1244 $)) 36)) (-1509 (((-634 (-1244 |#2|))) NIL (|has| |#2| (-558)))) (-3882 (($ $ $ $) NIL)) (-4177 (((-121)) NIL)) (-3823 (($ (-679 |#2|) $) NIL)) (-1319 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-1910 (((-121) $) NIL)) (-3500 (($ $ $) NIL)) (-2433 (((-121)) NIL)) (-2189 (((-121)) NIL)) (-4107 (((-121)) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-763)) NIL (|has| |#2| (-225))) (($ $) NIL (|has| |#2| (-225)))) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ |#2|) NIL (|has| |#2| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#2| (-365)))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) NIL) (((-232 |#1| |#2|) $ (-232 |#1| |#2|)) NIL) (((-232 |#1| |#2|) (-232 |#1| |#2|) $) NIL)) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
+((-3897 (*1 *1 *2) (-12 (-4 *1 (-658 *2)) (-4 *2 (-1195))))) 
+(-13 (-1134 |t#1|) (-375 |t#1|) (-277 |t#1|) (-10 -8 (-15 -3897 ($ |t#1|)))) 
+(((-39) . T) ((-105) -2199 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-608 (-850)) -2199 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-154 |#1|) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-281 (-568) |#1|) . T) ((-283 (-568) |#1|) . T) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-277 |#1|) . T) ((-375 |#1|) . T) ((-499 |#1|) . T) ((-601 (-568) |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-640 |#1|) . T) ((-842) |has| |#1| (-842)) ((-1010 |#1|) . T) ((-1090) -2199 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-1134 |#1|) . T) ((-1195) . T) ((-1231 |#1|) . T)) 
+((-3259 (((-634 (-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -2588 (-634 (-1244 |#1|))))) (-634 (-634 |#1|)) (-634 (-1244 |#1|))) 21) (((-634 (-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -2588 (-634 (-1244 |#1|))))) (-679 |#1|) (-634 (-1244 |#1|))) 20) (((-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -2588 (-634 (-1244 |#1|)))) (-634 (-634 |#1|)) (-1244 |#1|)) 16) (((-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -2588 (-634 (-1244 |#1|)))) (-679 |#1|) (-1244 |#1|)) 13)) (-2371 (((-763) (-679 |#1|) (-1244 |#1|)) 29)) (-3075 (((-3 (-1244 |#1|) "failed") (-679 |#1|) (-1244 |#1|)) 23)) (-1883 (((-121) (-679 |#1|) (-1244 |#1|)) 26))) 
+(((-659 |#1|) (-10 -7 (-15 -3259 ((-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -2588 (-634 (-1244 |#1|)))) (-679 |#1|) (-1244 |#1|))) (-15 -3259 ((-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -2588 (-634 (-1244 |#1|)))) (-634 (-634 |#1|)) (-1244 |#1|))) (-15 -3259 ((-634 (-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -2588 (-634 (-1244 |#1|))))) (-679 |#1|) (-634 (-1244 |#1|)))) (-15 -3259 ((-634 (-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -2588 (-634 (-1244 |#1|))))) (-634 (-634 |#1|)) (-634 (-1244 |#1|)))) (-15 -3075 ((-3 (-1244 |#1|) "failed") (-679 |#1|) (-1244 |#1|))) (-15 -1883 ((-121) (-679 |#1|) (-1244 |#1|))) (-15 -2371 ((-763) (-679 |#1|) (-1244 |#1|)))) (-365)) (T -659)) 
+((-2371 (*1 *2 *3 *4) (-12 (-5 *3 (-679 *5)) (-5 *4 (-1244 *5)) (-4 *5 (-365)) (-5 *2 (-763)) (-5 *1 (-659 *5)))) (-1883 (*1 *2 *3 *4) (-12 (-5 *3 (-679 *5)) (-5 *4 (-1244 *5)) (-4 *5 (-365)) (-5 *2 (-121)) (-5 *1 (-659 *5)))) (-3075 (*1 *2 *3 *2) (|partial| -12 (-5 *2 (-1244 *4)) (-5 *3 (-679 *4)) (-4 *4 (-365)) (-5 *1 (-659 *4)))) (-3259 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-634 *5))) (-4 *5 (-365)) (-5 *2 (-634 (-2 (|:| |particular| (-3 (-1244 *5) "failed")) (|:| -2588 (-634 (-1244 *5)))))) (-5 *1 (-659 *5)) (-5 *4 (-634 (-1244 *5))))) (-3259 (*1 *2 *3 *4) (-12 (-5 *3 (-679 *5)) (-4 *5 (-365)) (-5 *2 (-634 (-2 (|:| |particular| (-3 (-1244 *5) "failed")) (|:| -2588 (-634 (-1244 *5)))))) (-5 *1 (-659 *5)) (-5 *4 (-634 (-1244 *5))))) (-3259 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-634 *5))) (-4 *5 (-365)) (-5 *2 (-2 (|:| |particular| (-3 (-1244 *5) "failed")) (|:| -2588 (-634 (-1244 *5))))) (-5 *1 (-659 *5)) (-5 *4 (-1244 *5)))) (-3259 (*1 *2 *3 *4) (-12 (-5 *3 (-679 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| |particular| (-3 (-1244 *5) "failed")) (|:| -2588 (-634 (-1244 *5))))) (-5 *1 (-659 *5)) (-5 *4 (-1244 *5))))) 
+(-10 -7 (-15 -3259 ((-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -2588 (-634 (-1244 |#1|)))) (-679 |#1|) (-1244 |#1|))) (-15 -3259 ((-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -2588 (-634 (-1244 |#1|)))) (-634 (-634 |#1|)) (-1244 |#1|))) (-15 -3259 ((-634 (-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -2588 (-634 (-1244 |#1|))))) (-679 |#1|) (-634 (-1244 |#1|)))) (-15 -3259 ((-634 (-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -2588 (-634 (-1244 |#1|))))) (-634 (-634 |#1|)) (-634 (-1244 |#1|)))) (-15 -3075 ((-3 (-1244 |#1|) "failed") (-679 |#1|) (-1244 |#1|))) (-15 -1883 ((-121) (-679 |#1|) (-1244 |#1|))) (-15 -2371 ((-763) (-679 |#1|) (-1244 |#1|)))) 
+((-3259 (((-634 (-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2588 (-634 |#3|)))) |#4| (-634 |#3|)) 47) (((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2588 (-634 |#3|))) |#4| |#3|) 45)) (-2371 (((-763) |#4| |#3|) 17)) (-3075 (((-3 |#3| "failed") |#4| |#3|) 20)) (-1883 (((-121) |#4| |#3|) 13))) 
+(((-660 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3259 ((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2588 (-634 |#3|))) |#4| |#3|)) (-15 -3259 ((-634 (-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2588 (-634 |#3|)))) |#4| (-634 |#3|))) (-15 -3075 ((-3 |#3| "failed") |#4| |#3|)) (-15 -1883 ((-121) |#4| |#3|)) (-15 -2371 ((-763) |#4| |#3|))) (-365) (-13 (-375 |#1|) (-10 -7 (-6 -4522))) (-13 (-375 |#1|) (-10 -7 (-6 -4522))) (-677 |#1| |#2| |#3|)) (T -660)) 
+((-2371 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-13 (-375 *5) (-10 -7 (-6 -4522)))) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4522)))) (-5 *2 (-763)) (-5 *1 (-660 *5 *6 *4 *3)) (-4 *3 (-677 *5 *6 *4)))) (-1883 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-13 (-375 *5) (-10 -7 (-6 -4522)))) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4522)))) (-5 *2 (-121)) (-5 *1 (-660 *5 *6 *4 *3)) (-4 *3 (-677 *5 *6 *4)))) (-3075 (*1 *2 *3 *2) (|partial| -12 (-4 *4 (-365)) (-4 *5 (-13 (-375 *4) (-10 -7 (-6 -4522)))) (-4 *2 (-13 (-375 *4) (-10 -7 (-6 -4522)))) (-5 *1 (-660 *4 *5 *2 *3)) (-4 *3 (-677 *4 *5 *2)))) (-3259 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-13 (-375 *5) (-10 -7 (-6 -4522)))) (-4 *7 (-13 (-375 *5) (-10 -7 (-6 -4522)))) (-5 *2 (-634 (-2 (|:| |particular| (-3 *7 "failed")) (|:| -2588 (-634 *7))))) (-5 *1 (-660 *5 *6 *7 *3)) (-5 *4 (-634 *7)) (-4 *3 (-677 *5 *6 *7)))) (-3259 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-13 (-375 *5) (-10 -7 (-6 -4522)))) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4522)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2588 (-634 *4)))) (-5 *1 (-660 *5 *6 *4 *3)) (-4 *3 (-677 *5 *6 *4))))) 
+(-10 -7 (-15 -3259 ((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2588 (-634 |#3|))) |#4| |#3|)) (-15 -3259 ((-634 (-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2588 (-634 |#3|)))) |#4| (-634 |#3|))) (-15 -3075 ((-3 |#3| "failed") |#4| |#3|)) (-15 -1883 ((-121) |#4| |#3|)) (-15 -2371 ((-763) |#4| |#3|))) 
+((-2827 (((-2 (|:| |particular| (-3 (-1244 (-409 |#4|)) "failed")) (|:| -2588 (-634 (-1244 (-409 |#4|))))) (-634 |#4|) (-634 |#3|)) 44))) 
+(((-661 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2827 ((-2 (|:| |particular| (-3 (-1244 (-409 |#4|)) "failed")) (|:| -2588 (-634 (-1244 (-409 |#4|))))) (-634 |#4|) (-634 |#3|)))) (-558) (-788) (-842) (-950 |#1| |#2| |#3|)) (T -661)) 
+((-2827 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 *7)) (-4 *7 (-842)) (-4 *8 (-950 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-5 *2 (-2 (|:| |particular| (-3 (-1244 (-409 *8)) "failed")) (|:| -2588 (-634 (-1244 (-409 *8)))))) (-5 *1 (-661 *5 *6 *7 *8))))) 
+(-10 -7 (-15 -2827 ((-2 (|:| |particular| (-3 (-1244 (-409 |#4|)) "failed")) (|:| -2588 (-634 (-1244 (-409 |#4|))))) (-634 |#4|) (-634 |#3|)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-3591 (((-3 $ "failed")) NIL (|has| |#2| (-558)))) (-1934 ((|#2| $) NIL)) (-3560 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3542 (((-1244 (-679 |#2|))) NIL) (((-1244 (-679 |#2|)) (-1244 $)) NIL)) (-3691 (((-121) $) NIL)) (-3818 (((-1244 $)) 37)) (-1667 (((-121) $ (-763)) NIL)) (-1637 (($ |#2|) NIL)) (-4490 (($) NIL T CONST)) (-3912 (($ $) NIL (|has| |#2| (-301)))) (-2228 (((-232 |#1| |#2|) $ (-568)) NIL)) (-3354 (((-3 (-2 (|:| |particular| $) (|:| -2588 (-634 $))) "failed")) NIL (|has| |#2| (-558)))) (-2046 (((-3 $ "failed")) NIL (|has| |#2| (-558)))) (-1524 (((-679 |#2|)) NIL) (((-679 |#2|) (-1244 $)) NIL)) (-2467 ((|#2| $) NIL)) (-2235 (((-679 |#2|) $) NIL) (((-679 |#2|) $ (-1244 $)) NIL)) (-2812 (((-3 $ "failed") $) NIL (|has| |#2| (-558)))) (-1503 (((-1157 (-953 |#2|))) NIL (|has| |#2| (-365)))) (-2815 (($ $ (-917)) NIL)) (-1509 ((|#2| $) NIL)) (-3839 (((-1157 |#2|) $) NIL (|has| |#2| (-558)))) (-2886 ((|#2|) NIL) ((|#2| (-1244 $)) NIL)) (-3105 (((-1157 |#2|) $) NIL)) (-1463 (((-121)) NIL)) (-3668 (((-3 (-568) "failed") $) NIL (|has| |#2| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-3 |#2| "failed") $) NIL)) (-2857 (((-568) $) NIL (|has| |#2| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#2| (-1037 (-409 (-568))))) ((|#2| $) NIL)) (-3899 (($ (-1244 |#2|)) NIL) (($ (-1244 |#2|) (-1244 $)) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL) (((-679 |#2|) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-2371 (((-763) $) NIL (|has| |#2| (-558))) (((-917)) 38)) (-2069 ((|#2| $ (-568) (-568)) NIL)) (-3375 (((-121)) NIL)) (-3402 (($ $ (-917)) NIL)) (-3317 (((-634 |#2|) $) NIL (|has| $ (-6 -4521)))) (-1598 (((-121) $) NIL)) (-3344 (((-763) $) NIL (|has| |#2| (-558)))) (-2934 (((-634 (-232 |#1| |#2|)) $) NIL (|has| |#2| (-558)))) (-2241 (((-763) $) NIL)) (-4221 (((-121)) NIL)) (-1901 (((-763) $) NIL)) (-3791 (((-121) $ (-763)) NIL)) (-2424 ((|#2| $) NIL (|has| |#2| (-6 (-4523 "*"))))) (-3139 (((-568) $) NIL)) (-1343 (((-568) $) NIL)) (-4406 (((-634 |#2|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-3405 (((-568) $) NIL)) (-2801 (((-568) $) NIL)) (-2271 (($ (-634 (-634 |#2|))) NIL)) (-2253 (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#2| |#2| |#2|) $ $) NIL) (($ (-1 |#2| |#2|) $) NIL)) (-1843 (((-634 (-634 |#2|)) $) NIL)) (-4463 (((-121)) NIL)) (-3582 (((-121)) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-2587 (((-3 (-2 (|:| |particular| $) (|:| -2588 (-634 $))) "failed")) NIL (|has| |#2| (-558)))) (-2061 (((-3 $ "failed")) NIL (|has| |#2| (-558)))) (-4134 (((-679 |#2|)) NIL) (((-679 |#2|) (-1244 $)) NIL)) (-2786 ((|#2| $) NIL)) (-3147 (((-679 |#2|) $) NIL) (((-679 |#2|) $ (-1244 $)) NIL)) (-1974 (((-3 $ "failed") $) NIL (|has| |#2| (-558)))) (-1730 (((-1157 (-953 |#2|))) NIL (|has| |#2| (-365)))) (-4202 (($ $ (-917)) NIL)) (-4390 ((|#2| $) NIL)) (-3364 (((-1157 |#2|) $) NIL (|has| |#2| (-558)))) (-2060 ((|#2|) NIL) ((|#2| (-1244 $)) NIL)) (-3114 (((-1157 |#2|) $) NIL)) (-3487 (((-121)) NIL)) (-1893 (((-1143) $) NIL)) (-2153 (((-121)) NIL)) (-2889 (((-121)) NIL)) (-1852 (((-121)) NIL)) (-2715 (((-3 $ "failed") $) NIL (|has| |#2| (-365)))) (-4025 (((-1108) $) NIL)) (-3636 (((-121)) NIL)) (-2597 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-558)))) (-3951 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#2| $ (-568) (-568) |#2|) NIL) ((|#2| $ (-568) (-568)) 22) ((|#2| $ (-568)) NIL)) (-4191 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-763)) NIL (|has| |#2| (-225))) (($ $) NIL (|has| |#2| (-225)))) (-1966 ((|#2| $) NIL)) (-3499 (($ (-634 |#2|)) NIL)) (-4322 (((-121) $) NIL)) (-1760 (((-232 |#1| |#2|) $) NIL)) (-2591 ((|#2| $) NIL (|has| |#2| (-6 (-4523 "*"))))) (-4170 (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-3865 (($ $) NIL)) (-1656 (((-679 |#2|) (-1244 $)) NIL) (((-1244 |#2|) $) NIL) (((-679 |#2|) (-1244 $) (-1244 $)) NIL) (((-1244 |#2|) $ (-1244 $)) 25)) (-4280 (($ (-1244 |#2|)) NIL) (((-1244 |#2|) $) NIL)) (-2155 (((-634 (-953 |#2|))) NIL) (((-634 (-953 |#2|)) (-1244 $)) NIL)) (-3985 (($ $ $) NIL)) (-3441 (((-121)) NIL)) (-2522 (((-232 |#1| |#2|) $ (-568)) NIL)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ (-409 (-568))) NIL (|has| |#2| (-1037 (-409 (-568))))) (($ |#2|) NIL) (((-679 |#2|) $) NIL)) (-3425 (((-763)) NIL)) (-2588 (((-1244 $)) 36)) (-2657 (((-634 (-1244 |#2|))) NIL (|has| |#2| (-558)))) (-2007 (($ $ $ $) NIL)) (-3964 (((-121)) NIL)) (-3828 (($ (-679 |#2|) $) NIL)) (-3437 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-2675 (((-121) $) NIL)) (-3911 (($ $ $) NIL)) (-2435 (((-121)) NIL)) (-2984 (((-121)) NIL)) (-3579 (((-121)) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-763)) NIL (|has| |#2| (-225))) (($ $) NIL (|has| |#2| (-225)))) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ |#2|) NIL (|has| |#2| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#2| (-365)))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) NIL) (((-232 |#1| |#2|) $ (-232 |#1| |#2|)) NIL) (((-232 |#1| |#2|) (-232 |#1| |#2|) $) NIL)) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
 (((-662 |#1| |#2|) (-13 (-1111 |#1| |#2| (-232 |#1| |#2|) (-232 |#1| |#2|)) (-608 (-679 |#2|)) (-419 |#2|)) (-917) (-172)) (T -662)) 
 NIL 
 (-13 (-1111 |#1| |#2| (-232 |#1| |#2|) (-232 |#1| |#2|)) (-608 (-679 |#2|)) (-419 |#2|)) 
-((-2447 (((-121) $ $) NIL)) (-3595 (((-634 |#1|) $) NIL)) (-3284 (($ $) 50)) (-3374 (((-121) $) NIL)) (-3666 (((-3 |#1| "failed") $) NIL)) (-2854 ((|#1| $) NIL)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-2590 (((-3 $ "failed") (-814 |#1|)) 22)) (-2193 (((-121) (-814 |#1|)) 14)) (-3034 (($ (-814 |#1|)) 23)) (-4081 (((-121) $ $) 28)) (-3678 (((-917) $) 35)) (-3028 (($ $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-3848 (((-634 $) (-814 |#1|)) 16)) (-2745 (((-850) $) 41) (($ |#1|) 32) (((-814 |#1|) $) 37) (((-667 |#1|) $) 42)) (-3747 (((-64 (-634 $)) (-634 |#1|) (-917)) 55)) (-4242 (((-634 $) (-634 |#1|) (-917)) 57)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 51)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 36))) 
-(((-663 |#1|) (-13 (-842) (-1037 |#1|) (-10 -8 (-15 -3374 ((-121) $)) (-15 -3028 ($ $)) (-15 -3284 ($ $)) (-15 -3678 ((-917) $)) (-15 -4081 ((-121) $ $)) (-15 -2745 ((-814 |#1|) $)) (-15 -2745 ((-667 |#1|) $)) (-15 -3848 ((-634 $) (-814 |#1|))) (-15 -2193 ((-121) (-814 |#1|))) (-15 -3034 ($ (-814 |#1|))) (-15 -2590 ((-3 $ "failed") (-814 |#1|))) (-15 -3595 ((-634 |#1|) $)) (-15 -3747 ((-64 (-634 $)) (-634 |#1|) (-917))) (-15 -4242 ((-634 $) (-634 |#1|) (-917))))) (-842)) (T -663)) 
-((-3374 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) (-3028 (*1 *1 *1) (-12 (-5 *1 (-663 *2)) (-4 *2 (-842)))) (-3284 (*1 *1 *1) (-12 (-5 *1 (-663 *2)) (-4 *2 (-842)))) (-3678 (*1 *2 *1) (-12 (-5 *2 (-917)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) (-4081 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-814 *3)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-667 *3)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) (-3848 (*1 *2 *3) (-12 (-5 *3 (-814 *4)) (-4 *4 (-842)) (-5 *2 (-634 (-663 *4))) (-5 *1 (-663 *4)))) (-2193 (*1 *2 *3) (-12 (-5 *3 (-814 *4)) (-4 *4 (-842)) (-5 *2 (-121)) (-5 *1 (-663 *4)))) (-3034 (*1 *1 *2) (-12 (-5 *2 (-814 *3)) (-4 *3 (-842)) (-5 *1 (-663 *3)))) (-2590 (*1 *1 *2) (|partial| -12 (-5 *2 (-814 *3)) (-4 *3 (-842)) (-5 *1 (-663 *3)))) (-3595 (*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) (-3747 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-917)) (-4 *5 (-842)) (-5 *2 (-64 (-634 (-663 *5)))) (-5 *1 (-663 *5)))) (-4242 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-917)) (-4 *5 (-842)) (-5 *2 (-634 (-663 *5))) (-5 *1 (-663 *5))))) 
-(-13 (-842) (-1037 |#1|) (-10 -8 (-15 -3374 ((-121) $)) (-15 -3028 ($ $)) (-15 -3284 ($ $)) (-15 -3678 ((-917) $)) (-15 -4081 ((-121) $ $)) (-15 -2745 ((-814 |#1|) $)) (-15 -2745 ((-667 |#1|) $)) (-15 -3848 ((-634 $) (-814 |#1|))) (-15 -2193 ((-121) (-814 |#1|))) (-15 -3034 ($ (-814 |#1|))) (-15 -2590 ((-3 $ "failed") (-814 |#1|))) (-15 -3595 ((-634 |#1|) $)) (-15 -3747 ((-64 (-634 $)) (-634 |#1|) (-917))) (-15 -4242 ((-634 $) (-634 |#1|) (-917))))) 
-((-2850 ((|#2| $) 76)) (-2796 (($ $) 96)) (-2510 (((-121) $ (-763)) 26)) (-3935 (($ $) 85) (($ $ (-763)) 88)) (-1601 (((-121) $) 97)) (-2287 (((-634 $) $) 72)) (-1700 (((-121) $ $) 71)) (-1737 (((-121) $ (-763)) 24)) (-1881 (((-568) $) 46)) (-2223 (((-568) $) 45)) (-2166 (((-121) $ (-763)) 22)) (-1651 (((-121) $) 74)) (-4162 ((|#2| $) 89) (($ $ (-763)) 92)) (-4122 (($ $ $ (-568)) 62) (($ |#2| $ (-568)) 61)) (-4174 (((-634 (-568)) $) 44)) (-3578 (((-121) (-568) $) 42)) (-3876 ((|#2| $) NIL) (($ $ (-763)) 84)) (-1807 (($ $ (-568)) 99)) (-1786 (((-121) $) 98)) (-1387 (((-121) (-1 (-121) |#2|) $) 32)) (-2041 (((-634 |#2|) $) 33)) (-2779 ((|#2| $ "value") NIL) ((|#2| $ "first") 83) (($ $ "rest") 87) ((|#2| $ "last") 95) (($ $ (-1210 (-568))) 58) ((|#2| $ (-568)) 40) ((|#2| $ (-568) |#2|) 41)) (-4075 (((-568) $ $) 70)) (-2826 (($ $ (-1210 (-568))) 57) (($ $ (-568)) 51)) (-3790 (((-121) $) 66)) (-2340 (($ $) 81)) (-2775 (((-763) $) 80)) (-3335 (($ $) 79)) (-4287 (($ (-634 |#2|)) 37)) (-1811 (($ $) 100)) (-4339 (((-634 $) $) 69)) (-3491 (((-121) $ $) 68)) (-1319 (((-121) (-1 (-121) |#2|) $) 31)) (-1717 (((-121) $ $) 18)) (-1697 (((-763) $) 29))) 
-(((-664 |#1| |#2|) (-10 -8 (-15 -1811 (|#1| |#1|)) (-15 -1807 (|#1| |#1| (-568))) (-15 -1601 ((-121) |#1|)) (-15 -1786 ((-121) |#1|)) (-15 -2779 (|#2| |#1| (-568) |#2|)) (-15 -2779 (|#2| |#1| (-568))) (-15 -2041 ((-634 |#2|) |#1|)) (-15 -3578 ((-121) (-568) |#1|)) (-15 -4174 ((-634 (-568)) |#1|)) (-15 -2223 ((-568) |#1|)) (-15 -1881 ((-568) |#1|)) (-15 -4287 (|#1| (-634 |#2|))) (-15 -2779 (|#1| |#1| (-1210 (-568)))) (-15 -2826 (|#1| |#1| (-568))) (-15 -2826 (|#1| |#1| (-1210 (-568)))) (-15 -4122 (|#1| |#2| |#1| (-568))) (-15 -4122 (|#1| |#1| |#1| (-568))) (-15 -2340 (|#1| |#1|)) (-15 -2775 ((-763) |#1|)) (-15 -3335 (|#1| |#1|)) (-15 -2796 (|#1| |#1|)) (-15 -4162 (|#1| |#1| (-763))) (-15 -2779 (|#2| |#1| "last")) (-15 -4162 (|#2| |#1|)) (-15 -3935 (|#1| |#1| (-763))) (-15 -2779 (|#1| |#1| "rest")) (-15 -3935 (|#1| |#1|)) (-15 -3876 (|#1| |#1| (-763))) (-15 -2779 (|#2| |#1| "first")) (-15 -3876 (|#2| |#1|)) (-15 -1700 ((-121) |#1| |#1|)) (-15 -3491 ((-121) |#1| |#1|)) (-15 -4075 ((-568) |#1| |#1|)) (-15 -3790 ((-121) |#1|)) (-15 -2779 (|#2| |#1| "value")) (-15 -2850 (|#2| |#1|)) (-15 -1651 ((-121) |#1|)) (-15 -2287 ((-634 |#1|) |#1|)) (-15 -4339 ((-634 |#1|) |#1|)) (-15 -1717 ((-121) |#1| |#1|)) (-15 -1387 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -1319 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -1697 ((-763) |#1|)) (-15 -2510 ((-121) |#1| (-763))) (-15 -1737 ((-121) |#1| (-763))) (-15 -2166 ((-121) |#1| (-763)))) (-665 |#2|) (-1195)) (T -664)) 
-NIL 
-(-10 -8 (-15 -1811 (|#1| |#1|)) (-15 -1807 (|#1| |#1| (-568))) (-15 -1601 ((-121) |#1|)) (-15 -1786 ((-121) |#1|)) (-15 -2779 (|#2| |#1| (-568) |#2|)) (-15 -2779 (|#2| |#1| (-568))) (-15 -2041 ((-634 |#2|) |#1|)) (-15 -3578 ((-121) (-568) |#1|)) (-15 -4174 ((-634 (-568)) |#1|)) (-15 -2223 ((-568) |#1|)) (-15 -1881 ((-568) |#1|)) (-15 -4287 (|#1| (-634 |#2|))) (-15 -2779 (|#1| |#1| (-1210 (-568)))) (-15 -2826 (|#1| |#1| (-568))) (-15 -2826 (|#1| |#1| (-1210 (-568)))) (-15 -4122 (|#1| |#2| |#1| (-568))) (-15 -4122 (|#1| |#1| |#1| (-568))) (-15 -2340 (|#1| |#1|)) (-15 -2775 ((-763) |#1|)) (-15 -3335 (|#1| |#1|)) (-15 -2796 (|#1| |#1|)) (-15 -4162 (|#1| |#1| (-763))) (-15 -2779 (|#2| |#1| "last")) (-15 -4162 (|#2| |#1|)) (-15 -3935 (|#1| |#1| (-763))) (-15 -2779 (|#1| |#1| "rest")) (-15 -3935 (|#1| |#1|)) (-15 -3876 (|#1| |#1| (-763))) (-15 -2779 (|#2| |#1| "first")) (-15 -3876 (|#2| |#1|)) (-15 -1700 ((-121) |#1| |#1|)) (-15 -3491 ((-121) |#1| |#1|)) (-15 -4075 ((-568) |#1| |#1|)) (-15 -3790 ((-121) |#1|)) (-15 -2779 (|#2| |#1| "value")) (-15 -2850 (|#2| |#1|)) (-15 -1651 ((-121) |#1|)) (-15 -2287 ((-634 |#1|) |#1|)) (-15 -4339 ((-634 |#1|) |#1|)) (-15 -1717 ((-121) |#1| |#1|)) (-15 -1387 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -1319 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -1697 ((-763) |#1|)) (-15 -2510 ((-121) |#1| (-763))) (-15 -1737 ((-121) |#1| (-763))) (-15 -2166 ((-121) |#1| (-763)))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2850 ((|#1| $) 45)) (-2235 ((|#1| $) 62)) (-2796 (($ $) 64)) (-1868 (((-1249) $ (-568) (-568)) 94 (|has| $ (-6 -4520)))) (-3910 (($ $ (-568)) 49 (|has| $ (-6 -4520)))) (-2510 (((-121) $ (-763)) 8)) (-1659 ((|#1| $ |#1|) 36 (|has| $ (-6 -4520)))) (-3869 (($ $ $) 53 (|has| $ (-6 -4520)))) (-2395 ((|#1| $ |#1|) 51 (|has| $ (-6 -4520)))) (-2517 ((|#1| $ |#1|) 55 (|has| $ (-6 -4520)))) (-2436 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4520))) ((|#1| $ "first" |#1|) 54 (|has| $ (-6 -4520))) (($ $ "rest" $) 52 (|has| $ (-6 -4520))) ((|#1| $ "last" |#1|) 50 (|has| $ (-6 -4520))) ((|#1| $ (-1210 (-568)) |#1|) 114 (|has| $ (-6 -4520))) ((|#1| $ (-568) |#1|) 83 (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) 38 (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) |#1|) $) 99)) (-1679 ((|#1| $) 63)) (-2671 (($) 7 T CONST)) (-1496 (($ $) 118)) (-3935 (($ $) 70) (($ $ (-763)) 68)) (-3924 (($ $) 96 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-4328 (($ |#1| $) 97 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) |#1|) $) 100)) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $) 102 (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 101 (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 98 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3989 ((|#1| $ (-568) |#1|) 82 (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-568)) 84)) (-1601 (((-121) $) 80)) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-3836 (((-763) $) 117)) (-2287 (((-634 $) $) 47)) (-1700 (((-121) $ $) 39 (|has| |#1| (-1090)))) (-1849 (($ (-763) |#1|) 105)) (-1737 (((-121) $ (-763)) 9)) (-1881 (((-568) $) 92 (|has| (-568) (-842)))) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-2223 (((-568) $) 91 (|has| (-568) (-842)))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 108)) (-2166 (((-121) $ (-763)) 10)) (-2869 (((-634 |#1|) $) 42)) (-1651 (((-121) $) 46)) (-2892 (($ $) 120)) (-3851 (((-121) $) 121)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4162 ((|#1| $) 67) (($ $ (-763)) 65)) (-4122 (($ $ $ (-568)) 113) (($ |#1| $ (-568)) 112)) (-4174 (((-634 (-568)) $) 89)) (-3578 (((-121) (-568) $) 88)) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3121 ((|#1| $) 119)) (-3876 ((|#1| $) 73) (($ $ (-763)) 71)) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 103)) (-3724 (($ $ |#1|) 93 (|has| $ (-6 -4520)))) (-1807 (($ $ (-568)) 116)) (-1786 (((-121) $) 81)) (-1368 (((-121) $) 122)) (-3552 (((-121) $) 123)) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-4467 (((-121) |#1| $) 90 (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) 87)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 ((|#1| $ "value") 44) ((|#1| $ "first") 72) (($ $ "rest") 69) ((|#1| $ "last") 66) (($ $ (-1210 (-568))) 109) ((|#1| $ (-568)) 86) ((|#1| $ (-568) |#1|) 85)) (-4075 (((-568) $ $) 41)) (-2826 (($ $ (-1210 (-568))) 111) (($ $ (-568)) 110)) (-3790 (((-121) $) 43)) (-2340 (($ $) 59)) (-2714 (($ $) 56 (|has| $ (-6 -4520)))) (-2775 (((-763) $) 60)) (-3335 (($ $) 61)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-4278 (((-541) $) 95 (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) 104)) (-3845 (($ $ $) 58 (|has| $ (-6 -4520))) (($ $ |#1|) 57 (|has| $ (-6 -4520)))) (-2768 (($ $ $) 75) (($ |#1| $) 74) (($ (-634 $)) 107) (($ $ |#1|) 106)) (-1811 (($ $) 115)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-4339 (((-634 $) $) 48)) (-3491 (((-121) $ $) 40 (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL)) (-2981 (((-634 |#1|) $) NIL)) (-3286 (($ $) 50)) (-1407 (((-121) $) NIL)) (-3668 (((-3 |#1| "failed") $) NIL)) (-2857 ((|#1| $) NIL)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-2035 (((-3 $ "failed") (-814 |#1|)) 22)) (-3047 (((-121) (-814 |#1|)) 14)) (-2196 (($ (-814 |#1|)) 23)) (-3451 (((-121) $ $) 28)) (-3680 (((-917) $) 35)) (-3030 (($ $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-3850 (((-634 $) (-814 |#1|)) 16)) (-2747 (((-850) $) 41) (($ |#1|) 32) (((-814 |#1|) $) 37) (((-667 |#1|) $) 42)) (-2593 (((-64 (-634 $)) (-634 |#1|) (-917)) 55)) (-2843 (((-634 $) (-634 |#1|) (-917)) 57)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 51)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 36))) 
+(((-663 |#1|) (-13 (-842) (-1037 |#1|) (-10 -8 (-15 -1407 ((-121) $)) (-15 -3030 ($ $)) (-15 -3286 ($ $)) (-15 -3680 ((-917) $)) (-15 -3451 ((-121) $ $)) (-15 -2747 ((-814 |#1|) $)) (-15 -2747 ((-667 |#1|) $)) (-15 -3850 ((-634 $) (-814 |#1|))) (-15 -3047 ((-121) (-814 |#1|))) (-15 -2196 ($ (-814 |#1|))) (-15 -2035 ((-3 $ "failed") (-814 |#1|))) (-15 -2981 ((-634 |#1|) $)) (-15 -2593 ((-64 (-634 $)) (-634 |#1|) (-917))) (-15 -2843 ((-634 $) (-634 |#1|) (-917))))) (-842)) (T -663)) 
+((-1407 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) (-3030 (*1 *1 *1) (-12 (-5 *1 (-663 *2)) (-4 *2 (-842)))) (-3286 (*1 *1 *1) (-12 (-5 *1 (-663 *2)) (-4 *2 (-842)))) (-3680 (*1 *2 *1) (-12 (-5 *2 (-917)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) (-3451 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-814 *3)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-667 *3)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) (-3850 (*1 *2 *3) (-12 (-5 *3 (-814 *4)) (-4 *4 (-842)) (-5 *2 (-634 (-663 *4))) (-5 *1 (-663 *4)))) (-3047 (*1 *2 *3) (-12 (-5 *3 (-814 *4)) (-4 *4 (-842)) (-5 *2 (-121)) (-5 *1 (-663 *4)))) (-2196 (*1 *1 *2) (-12 (-5 *2 (-814 *3)) (-4 *3 (-842)) (-5 *1 (-663 *3)))) (-2035 (*1 *1 *2) (|partial| -12 (-5 *2 (-814 *3)) (-4 *3 (-842)) (-5 *1 (-663 *3)))) (-2981 (*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) (-2593 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-917)) (-4 *5 (-842)) (-5 *2 (-64 (-634 (-663 *5)))) (-5 *1 (-663 *5)))) (-2843 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-917)) (-4 *5 (-842)) (-5 *2 (-634 (-663 *5))) (-5 *1 (-663 *5))))) 
+(-13 (-842) (-1037 |#1|) (-10 -8 (-15 -1407 ((-121) $)) (-15 -3030 ($ $)) (-15 -3286 ($ $)) (-15 -3680 ((-917) $)) (-15 -3451 ((-121) $ $)) (-15 -2747 ((-814 |#1|) $)) (-15 -2747 ((-667 |#1|) $)) (-15 -3850 ((-634 $) (-814 |#1|))) (-15 -3047 ((-121) (-814 |#1|))) (-15 -2196 ($ (-814 |#1|))) (-15 -2035 ((-3 $ "failed") (-814 |#1|))) (-15 -2981 ((-634 |#1|) $)) (-15 -2593 ((-64 (-634 $)) (-634 |#1|) (-917))) (-15 -2843 ((-634 $) (-634 |#1|) (-917))))) 
+((-2852 ((|#2| $) 76)) (-3623 (($ $) 96)) (-1667 (((-121) $ (-763)) 26)) (-3936 (($ $) 85) (($ $ (-763)) 88)) (-1340 (((-121) $) 97)) (-3534 (((-634 $) $) 72)) (-3606 (((-121) $ $) 71)) (-3791 (((-121) $ (-763)) 24)) (-2539 (((-568) $) 46)) (-3631 (((-568) $) 45)) (-3796 (((-121) $ (-763)) 22)) (-3319 (((-121) $) 74)) (-4164 ((|#2| $) 89) (($ $ (-763)) 92)) (-4124 (($ $ $ (-568)) 62) (($ |#2| $ (-568)) 61)) (-3948 (((-634 (-568)) $) 44)) (-2916 (((-121) (-568) $) 42)) (-3877 ((|#2| $) NIL) (($ $ (-763)) 84)) (-2168 (($ $ (-568)) 99)) (-4049 (((-121) $) 98)) (-3951 (((-121) (-1 (-121) |#2|) $) 32)) (-1480 (((-634 |#2|) $) 33)) (-2781 ((|#2| $ "value") NIL) ((|#2| $ "first") 83) (($ $ "rest") 87) ((|#2| $ "last") 95) (($ $ (-1210 (-568))) 58) ((|#2| $ (-568)) 40) ((|#2| $ (-568) |#2|) 41)) (-1665 (((-568) $ $) 70)) (-2828 (($ $ (-1210 (-568))) 57) (($ $ (-568)) 51)) (-2763 (((-121) $) 66)) (-3903 (($ $) 81)) (-3535 (((-763) $) 80)) (-4424 (($ $) 79)) (-4289 (($ (-634 |#2|)) 37)) (-2188 (($ $) 100)) (-3180 (((-634 $) $) 69)) (-3873 (((-121) $ $) 68)) (-3437 (((-121) (-1 (-121) |#2|) $) 31)) (-1719 (((-121) $ $) 18)) (-1699 (((-763) $) 29))) 
+(((-664 |#1| |#2|) (-10 -8 (-15 -2188 (|#1| |#1|)) (-15 -2168 (|#1| |#1| (-568))) (-15 -1340 ((-121) |#1|)) (-15 -4049 ((-121) |#1|)) (-15 -2781 (|#2| |#1| (-568) |#2|)) (-15 -2781 (|#2| |#1| (-568))) (-15 -1480 ((-634 |#2|) |#1|)) (-15 -2916 ((-121) (-568) |#1|)) (-15 -3948 ((-634 (-568)) |#1|)) (-15 -3631 ((-568) |#1|)) (-15 -2539 ((-568) |#1|)) (-15 -4289 (|#1| (-634 |#2|))) (-15 -2781 (|#1| |#1| (-1210 (-568)))) (-15 -2828 (|#1| |#1| (-568))) (-15 -2828 (|#1| |#1| (-1210 (-568)))) (-15 -4124 (|#1| |#2| |#1| (-568))) (-15 -4124 (|#1| |#1| |#1| (-568))) (-15 -3903 (|#1| |#1|)) (-15 -3535 ((-763) |#1|)) (-15 -4424 (|#1| |#1|)) (-15 -3623 (|#1| |#1|)) (-15 -4164 (|#1| |#1| (-763))) (-15 -2781 (|#2| |#1| "last")) (-15 -4164 (|#2| |#1|)) (-15 -3936 (|#1| |#1| (-763))) (-15 -2781 (|#1| |#1| "rest")) (-15 -3936 (|#1| |#1|)) (-15 -3877 (|#1| |#1| (-763))) (-15 -2781 (|#2| |#1| "first")) (-15 -3877 (|#2| |#1|)) (-15 -3606 ((-121) |#1| |#1|)) (-15 -3873 ((-121) |#1| |#1|)) (-15 -1665 ((-568) |#1| |#1|)) (-15 -2763 ((-121) |#1|)) (-15 -2781 (|#2| |#1| "value")) (-15 -2852 (|#2| |#1|)) (-15 -3319 ((-121) |#1|)) (-15 -3534 ((-634 |#1|) |#1|)) (-15 -3180 ((-634 |#1|) |#1|)) (-15 -1719 ((-121) |#1| |#1|)) (-15 -3951 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3437 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -1699 ((-763) |#1|)) (-15 -1667 ((-121) |#1| (-763))) (-15 -3791 ((-121) |#1| (-763))) (-15 -3796 ((-121) |#1| (-763)))) (-665 |#2|) (-1195)) (T -664)) 
+NIL 
+(-10 -8 (-15 -2188 (|#1| |#1|)) (-15 -2168 (|#1| |#1| (-568))) (-15 -1340 ((-121) |#1|)) (-15 -4049 ((-121) |#1|)) (-15 -2781 (|#2| |#1| (-568) |#2|)) (-15 -2781 (|#2| |#1| (-568))) (-15 -1480 ((-634 |#2|) |#1|)) (-15 -2916 ((-121) (-568) |#1|)) (-15 -3948 ((-634 (-568)) |#1|)) (-15 -3631 ((-568) |#1|)) (-15 -2539 ((-568) |#1|)) (-15 -4289 (|#1| (-634 |#2|))) (-15 -2781 (|#1| |#1| (-1210 (-568)))) (-15 -2828 (|#1| |#1| (-568))) (-15 -2828 (|#1| |#1| (-1210 (-568)))) (-15 -4124 (|#1| |#2| |#1| (-568))) (-15 -4124 (|#1| |#1| |#1| (-568))) (-15 -3903 (|#1| |#1|)) (-15 -3535 ((-763) |#1|)) (-15 -4424 (|#1| |#1|)) (-15 -3623 (|#1| |#1|)) (-15 -4164 (|#1| |#1| (-763))) (-15 -2781 (|#2| |#1| "last")) (-15 -4164 (|#2| |#1|)) (-15 -3936 (|#1| |#1| (-763))) (-15 -2781 (|#1| |#1| "rest")) (-15 -3936 (|#1| |#1|)) (-15 -3877 (|#1| |#1| (-763))) (-15 -2781 (|#2| |#1| "first")) (-15 -3877 (|#2| |#1|)) (-15 -3606 ((-121) |#1| |#1|)) (-15 -3873 ((-121) |#1| |#1|)) (-15 -1665 ((-568) |#1| |#1|)) (-15 -2763 ((-121) |#1|)) (-15 -2781 (|#2| |#1| "value")) (-15 -2852 (|#2| |#1|)) (-15 -3319 ((-121) |#1|)) (-15 -3534 ((-634 |#1|) |#1|)) (-15 -3180 ((-634 |#1|) |#1|)) (-15 -1719 ((-121) |#1| |#1|)) (-15 -3951 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -3437 ((-121) (-1 (-121) |#2|) |#1|)) (-15 -1699 ((-763) |#1|)) (-15 -1667 ((-121) |#1| (-763))) (-15 -3791 ((-121) |#1| (-763))) (-15 -3796 ((-121) |#1| (-763)))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2852 ((|#1| $) 45)) (-2237 ((|#1| $) 62)) (-3623 (($ $) 64)) (-2481 (((-1249) $ (-568) (-568)) 94 (|has| $ (-6 -4522)))) (-2121 (($ $ (-568)) 49 (|has| $ (-6 -4522)))) (-1667 (((-121) $ (-763)) 8)) (-3370 ((|#1| $ |#1|) 36 (|has| $ (-6 -4522)))) (-1958 (($ $ $) 53 (|has| $ (-6 -4522)))) (-2257 ((|#1| $ |#1|) 51 (|has| $ (-6 -4522)))) (-1706 ((|#1| $ |#1|) 55 (|has| $ (-6 -4522)))) (-2438 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4522))) ((|#1| $ "first" |#1|) 54 (|has| $ (-6 -4522))) (($ $ "rest" $) 52 (|has| $ (-6 -4522))) ((|#1| $ "last" |#1|) 50 (|has| $ (-6 -4522))) ((|#1| $ (-1210 (-568)) |#1|) 114 (|has| $ (-6 -4522))) ((|#1| $ (-568) |#1|) 83 (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) 38 (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) |#1|) $) 99)) (-1681 ((|#1| $) 63)) (-4490 (($) 7 T CONST)) (-2584 (($ $) 118)) (-3936 (($ $) 70) (($ $ (-763)) 68)) (-3926 (($ $) 96 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-4330 (($ |#1| $) 97 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) |#1|) $) 100)) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $) 102 (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 101 (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 98 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-1292 ((|#1| $ (-568) |#1|) 82 (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-568)) 84)) (-1340 (((-121) $) 80)) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-1841 (((-763) $) 117)) (-3534 (((-634 $) $) 47)) (-3606 (((-121) $ $) 39 (|has| |#1| (-1090)))) (-1851 (($ (-763) |#1|) 105)) (-3791 (((-121) $ (-763)) 9)) (-2539 (((-568) $) 92 (|has| (-568) (-842)))) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3631 (((-568) $) 91 (|has| (-568) (-842)))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 108)) (-3796 (((-121) $ (-763)) 10)) (-4081 (((-634 |#1|) $) 42)) (-3319 (((-121) $) 46)) (-2798 (($ $) 120)) (-1898 (((-121) $) 121)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4164 ((|#1| $) 67) (($ $ (-763)) 65)) (-4124 (($ $ $ (-568)) 113) (($ |#1| $ (-568)) 112)) (-3948 (((-634 (-568)) $) 89)) (-2916 (((-121) (-568) $) 88)) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-2616 ((|#1| $) 119)) (-3877 ((|#1| $) 73) (($ $ (-763)) 71)) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 103)) (-2490 (($ $ |#1|) 93 (|has| $ (-6 -4522)))) (-2168 (($ $ (-568)) 116)) (-4049 (((-121) $) 81)) (-3817 (((-121) $) 122)) (-2818 (((-121) $) 123)) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-1801 (((-121) |#1| $) 90 (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) 87)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 ((|#1| $ "value") 44) ((|#1| $ "first") 72) (($ $ "rest") 69) ((|#1| $ "last") 66) (($ $ (-1210 (-568))) 109) ((|#1| $ (-568)) 86) ((|#1| $ (-568) |#1|) 85)) (-1665 (((-568) $ $) 41)) (-2828 (($ $ (-1210 (-568))) 111) (($ $ (-568)) 110)) (-2763 (((-121) $) 43)) (-3903 (($ $) 59)) (-1499 (($ $) 56 (|has| $ (-6 -4522)))) (-3535 (((-763) $) 60)) (-4424 (($ $) 61)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-4280 (((-541) $) 95 (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) 104)) (-1876 (($ $ $) 58 (|has| $ (-6 -4522))) (($ $ |#1|) 57 (|has| $ (-6 -4522)))) (-2770 (($ $ $) 75) (($ |#1| $) 74) (($ (-634 $)) 107) (($ $ |#1|) 106)) (-2188 (($ $) 115)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-3180 (((-634 $) $) 48)) (-3873 (((-121) $ $) 40 (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-665 |#1|) (-1275) (-1195)) (T -665)) 
-((-4328 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-665 *3)) (-4 *3 (-1195)))) (-2801 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-665 *3)) (-4 *3 (-1195)))) (-3552 (*1 *2 *1) (-12 (-4 *1 (-665 *3)) (-4 *3 (-1195)) (-5 *2 (-121)))) (-1368 (*1 *2 *1) (-12 (-4 *1 (-665 *3)) (-4 *3 (-1195)) (-5 *2 (-121)))) (-3851 (*1 *2 *1) (-12 (-4 *1 (-665 *3)) (-4 *3 (-1195)) (-5 *2 (-121)))) (-2892 (*1 *1 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-1195)))) (-3121 (*1 *2 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-1195)))) (-1496 (*1 *1 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-1195)))) (-3836 (*1 *2 *1) (-12 (-4 *1 (-665 *3)) (-4 *3 (-1195)) (-5 *2 (-763)))) (-1807 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-665 *3)) (-4 *3 (-1195)))) (-1811 (*1 *1 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-1195))))) 
-(-13 (-1134 |t#1|) (-10 -8 (-15 -4328 ($ (-1 (-121) |t#1|) $)) (-15 -2801 ($ (-1 (-121) |t#1|) $)) (-15 -3552 ((-121) $)) (-15 -1368 ((-121) $)) (-15 -3851 ((-121) $)) (-15 -2892 ($ $)) (-15 -3121 (|t#1| $)) (-15 -1496 ($ $)) (-15 -3836 ((-763) $)) (-15 -1807 ($ $ (-568))) (-15 -1811 ($ $)))) 
+((-4330 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-665 *3)) (-4 *3 (-1195)))) (-2803 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-665 *3)) (-4 *3 (-1195)))) (-2818 (*1 *2 *1) (-12 (-4 *1 (-665 *3)) (-4 *3 (-1195)) (-5 *2 (-121)))) (-3817 (*1 *2 *1) (-12 (-4 *1 (-665 *3)) (-4 *3 (-1195)) (-5 *2 (-121)))) (-1898 (*1 *2 *1) (-12 (-4 *1 (-665 *3)) (-4 *3 (-1195)) (-5 *2 (-121)))) (-2798 (*1 *1 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-1195)))) (-2616 (*1 *2 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-1195)))) (-2584 (*1 *1 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-1195)))) (-1841 (*1 *2 *1) (-12 (-4 *1 (-665 *3)) (-4 *3 (-1195)) (-5 *2 (-763)))) (-2168 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-665 *3)) (-4 *3 (-1195)))) (-2188 (*1 *1 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-1195))))) 
+(-13 (-1134 |t#1|) (-10 -8 (-15 -4330 ($ (-1 (-121) |t#1|) $)) (-15 -2803 ($ (-1 (-121) |t#1|) $)) (-15 -2818 ((-121) $)) (-15 -3817 ((-121) $)) (-15 -1898 ((-121) $)) (-15 -2798 ($ $)) (-15 -2616 (|t#1| $)) (-15 -2584 ($ $)) (-15 -1841 ((-763) $)) (-15 -2168 ($ $ (-568))) (-15 -2188 ($ $)))) 
 (((-39) . T) ((-105) |has| |#1| (-1090)) ((-608 (-850)) |has| |#1| (-1090)) ((-154 |#1|) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-281 (-568) |#1|) . T) ((-283 (-568) |#1|) . T) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-601 (-568) |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-640 |#1|) . T) ((-1010 |#1|) . T) ((-1090) |has| |#1| (-1090)) ((-1134 |#1|) . T) ((-1195) . T) ((-1231 |#1|) . T)) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2820 (($ (-763) (-763) (-763)) 32 (|has| |#1| (-1047)))) (-2510 (((-121) $ (-763)) NIL)) (-3780 ((|#1| $ (-763) (-763) (-763) |#1|) 27)) (-2671 (($) NIL T CONST)) (-1548 (($ $ $) 36 (|has| |#1| (-1047)))) (-4360 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) NIL)) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-1361 (((-1244 (-763)) $) 8)) (-3127 (($ (-1161) $ $) 22)) (-3674 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-2181 (($ (-763)) 34 (|has| |#1| (-1047)))) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#1| $ (-763) (-763) (-763)) 25)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) NIL)) (-4287 (($ (-634 (-634 (-634 |#1|)))) 43)) (-2745 (((-850) $) NIL (|has| |#1| (-1090))) (($ (-958 (-958 (-958 |#1|)))) 15) (((-958 (-958 (-958 |#1|))) $) 12)) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-666 |#1|) (-13 (-499 |#1|) (-10 -8 (IF (|has| |#1| (-1047)) (PROGN (-15 -2820 ($ (-763) (-763) (-763))) (-15 -2181 ($ (-763))) (-15 -1548 ($ $ $))) |noBranch|) (-15 -4287 ($ (-634 (-634 (-634 |#1|))))) (-15 -2779 (|#1| $ (-763) (-763) (-763))) (-15 -3780 (|#1| $ (-763) (-763) (-763) |#1|)) (-15 -2745 ($ (-958 (-958 (-958 |#1|))))) (-15 -2745 ((-958 (-958 (-958 |#1|))) $)) (-15 -3127 ($ (-1161) $ $)) (-15 -1361 ((-1244 (-763)) $)))) (-1090)) (T -666)) 
-((-2820 (*1 *1 *2 *2 *2) (-12 (-5 *2 (-763)) (-5 *1 (-666 *3)) (-4 *3 (-1047)) (-4 *3 (-1090)))) (-2181 (*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-666 *3)) (-4 *3 (-1047)) (-4 *3 (-1090)))) (-1548 (*1 *1 *1 *1) (-12 (-5 *1 (-666 *2)) (-4 *2 (-1047)) (-4 *2 (-1090)))) (-4287 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 (-634 *3)))) (-4 *3 (-1090)) (-5 *1 (-666 *3)))) (-2779 (*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-763)) (-5 *1 (-666 *2)) (-4 *2 (-1090)))) (-3780 (*1 *2 *1 *3 *3 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-666 *2)) (-4 *2 (-1090)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-958 (-958 (-958 *3)))) (-4 *3 (-1090)) (-5 *1 (-666 *3)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-958 (-958 (-958 *3)))) (-5 *1 (-666 *3)) (-4 *3 (-1090)))) (-3127 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-666 *3)) (-4 *3 (-1090)))) (-1361 (*1 *2 *1) (-12 (-5 *2 (-1244 (-763))) (-5 *1 (-666 *3)) (-4 *3 (-1090))))) 
-(-13 (-499 |#1|) (-10 -8 (IF (|has| |#1| (-1047)) (PROGN (-15 -2820 ($ (-763) (-763) (-763))) (-15 -2181 ($ (-763))) (-15 -1548 ($ $ $))) |noBranch|) (-15 -4287 ($ (-634 (-634 (-634 |#1|))))) (-15 -2779 (|#1| $ (-763) (-763) (-763))) (-15 -3780 (|#1| $ (-763) (-763) (-763) |#1|)) (-15 -2745 ($ (-958 (-958 (-958 |#1|))))) (-15 -2745 ((-958 (-958 (-958 |#1|))) $)) (-15 -3127 ($ (-1161) $ $)) (-15 -1361 ((-1244 (-763)) $)))) 
-((-2447 (((-121) $ $) NIL)) (-3595 (((-634 |#1|) $) 14)) (-3284 (($ $) 18)) (-3374 (((-121) $) 19)) (-3666 (((-3 |#1| "failed") $) 22)) (-2854 ((|#1| $) 20)) (-3935 (($ $) 36)) (-2407 (($ $) 24)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-4081 (((-121) $ $) 41)) (-3678 (((-917) $) 38)) (-3028 (($ $) 17)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-3876 ((|#1| $) 35)) (-2745 (((-850) $) 31) (($ |#1|) 23) (((-814 |#1|) $) 27)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 12)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 40)) (* (($ $ $) 34))) 
-(((-667 |#1|) (-13 (-842) (-1037 |#1|) (-10 -8 (-15 * ($ $ $)) (-15 -2745 ((-814 |#1|) $)) (-15 -3876 (|#1| $)) (-15 -3028 ($ $)) (-15 -3678 ((-917) $)) (-15 -4081 ((-121) $ $)) (-15 -2407 ($ $)) (-15 -3935 ($ $)) (-15 -3374 ((-121) $)) (-15 -3284 ($ $)) (-15 -3595 ((-634 |#1|) $)))) (-842)) (T -667)) 
-((* (*1 *1 *1 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-842)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-814 *3)) (-5 *1 (-667 *3)) (-4 *3 (-842)))) (-3876 (*1 *2 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-842)))) (-3028 (*1 *1 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-842)))) (-3678 (*1 *2 *1) (-12 (-5 *2 (-917)) (-5 *1 (-667 *3)) (-4 *3 (-842)))) (-4081 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-667 *3)) (-4 *3 (-842)))) (-2407 (*1 *1 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-842)))) (-3935 (*1 *1 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-842)))) (-3374 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-667 *3)) (-4 *3 (-842)))) (-3284 (*1 *1 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-842)))) (-3595 (*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-667 *3)) (-4 *3 (-842))))) 
-(-13 (-842) (-1037 |#1|) (-10 -8 (-15 * ($ $ $)) (-15 -2745 ((-814 |#1|) $)) (-15 -3876 (|#1| $)) (-15 -3028 ($ $)) (-15 -3678 ((-917) $)) (-15 -4081 ((-121) $ $)) (-15 -2407 ($ $)) (-15 -3935 ($ $)) (-15 -3374 ((-121) $)) (-15 -3284 ($ $)) (-15 -3595 ((-634 |#1|) $)))) 
-((-3337 ((|#1| (-1 |#1| (-763) |#1|) (-763) |#1|) 11)) (-1287 ((|#1| (-1 |#1| |#1|) (-763) |#1|) 9))) 
-(((-668 |#1|) (-10 -7 (-15 -1287 (|#1| (-1 |#1| |#1|) (-763) |#1|)) (-15 -3337 (|#1| (-1 |#1| (-763) |#1|) (-763) |#1|))) (-1090)) (T -668)) 
-((-3337 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 (-763) *2)) (-5 *4 (-763)) (-4 *2 (-1090)) (-5 *1 (-668 *2)))) (-1287 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *2)) (-5 *4 (-763)) (-4 *2 (-1090)) (-5 *1 (-668 *2))))) 
-(-10 -7 (-15 -1287 (|#1| (-1 |#1| |#1|) (-763) |#1|)) (-15 -3337 (|#1| (-1 |#1| (-763) |#1|) (-763) |#1|))) 
-((-1727 ((|#2| |#1| |#2|) 9)) (-1720 ((|#1| |#1| |#2|) 8))) 
-(((-669 |#1| |#2|) (-10 -7 (-15 -1720 (|#1| |#1| |#2|)) (-15 -1727 (|#2| |#1| |#2|))) (-1090) (-1090)) (T -669)) 
-((-1727 (*1 *2 *3 *2) (-12 (-5 *1 (-669 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090)))) (-1720 (*1 *2 *2 *3) (-12 (-5 *1 (-669 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090))))) 
-(-10 -7 (-15 -1720 (|#1| |#1| |#2|)) (-15 -1727 (|#2| |#1| |#2|))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3775 (($ (-763) (-763) (-763)) 32 (|has| |#1| (-1047)))) (-1667 (((-121) $ (-763)) NIL)) (-2729 ((|#1| $ (-763) (-763) (-763) |#1|) 27)) (-4490 (($) NIL T CONST)) (-4290 (($ $ $) 36 (|has| |#1| (-1047)))) (-3317 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) NIL)) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3755 (((-1244 (-763)) $) 8)) (-2650 (($ (-1161) $ $) 22)) (-2253 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-2491 (($ (-763)) 34 (|has| |#1| (-1047)))) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#1| $ (-763) (-763) (-763)) 25)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) NIL)) (-4289 (($ (-634 (-634 (-634 |#1|)))) 43)) (-2747 (((-850) $) NIL (|has| |#1| (-1090))) (($ (-958 (-958 (-958 |#1|)))) 15) (((-958 (-958 (-958 |#1|))) $) 12)) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-666 |#1|) (-13 (-499 |#1|) (-10 -8 (IF (|has| |#1| (-1047)) (PROGN (-15 -3775 ($ (-763) (-763) (-763))) (-15 -2491 ($ (-763))) (-15 -4290 ($ $ $))) |noBranch|) (-15 -4289 ($ (-634 (-634 (-634 |#1|))))) (-15 -2781 (|#1| $ (-763) (-763) (-763))) (-15 -2729 (|#1| $ (-763) (-763) (-763) |#1|)) (-15 -2747 ($ (-958 (-958 (-958 |#1|))))) (-15 -2747 ((-958 (-958 (-958 |#1|))) $)) (-15 -2650 ($ (-1161) $ $)) (-15 -3755 ((-1244 (-763)) $)))) (-1090)) (T -666)) 
+((-3775 (*1 *1 *2 *2 *2) (-12 (-5 *2 (-763)) (-5 *1 (-666 *3)) (-4 *3 (-1047)) (-4 *3 (-1090)))) (-2491 (*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-666 *3)) (-4 *3 (-1047)) (-4 *3 (-1090)))) (-4290 (*1 *1 *1 *1) (-12 (-5 *1 (-666 *2)) (-4 *2 (-1047)) (-4 *2 (-1090)))) (-4289 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 (-634 *3)))) (-4 *3 (-1090)) (-5 *1 (-666 *3)))) (-2781 (*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-763)) (-5 *1 (-666 *2)) (-4 *2 (-1090)))) (-2729 (*1 *2 *1 *3 *3 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-666 *2)) (-4 *2 (-1090)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-958 (-958 (-958 *3)))) (-4 *3 (-1090)) (-5 *1 (-666 *3)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-958 (-958 (-958 *3)))) (-5 *1 (-666 *3)) (-4 *3 (-1090)))) (-2650 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-666 *3)) (-4 *3 (-1090)))) (-3755 (*1 *2 *1) (-12 (-5 *2 (-1244 (-763))) (-5 *1 (-666 *3)) (-4 *3 (-1090))))) 
+(-13 (-499 |#1|) (-10 -8 (IF (|has| |#1| (-1047)) (PROGN (-15 -3775 ($ (-763) (-763) (-763))) (-15 -2491 ($ (-763))) (-15 -4290 ($ $ $))) |noBranch|) (-15 -4289 ($ (-634 (-634 (-634 |#1|))))) (-15 -2781 (|#1| $ (-763) (-763) (-763))) (-15 -2729 (|#1| $ (-763) (-763) (-763) |#1|)) (-15 -2747 ($ (-958 (-958 (-958 |#1|))))) (-15 -2747 ((-958 (-958 (-958 |#1|))) $)) (-15 -2650 ($ (-1161) $ $)) (-15 -3755 ((-1244 (-763)) $)))) 
+((-2449 (((-121) $ $) NIL)) (-2981 (((-634 |#1|) $) 14)) (-3286 (($ $) 18)) (-1407 (((-121) $) 19)) (-3668 (((-3 |#1| "failed") $) 22)) (-2857 ((|#1| $) 20)) (-3936 (($ $) 36)) (-2310 (($ $) 24)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-3451 (((-121) $ $) 41)) (-3680 (((-917) $) 38)) (-3030 (($ $) 17)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-3877 ((|#1| $) 35)) (-2747 (((-850) $) 31) (($ |#1|) 23) (((-814 |#1|) $) 27)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 12)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 40)) (* (($ $ $) 34))) 
+(((-667 |#1|) (-13 (-842) (-1037 |#1|) (-10 -8 (-15 * ($ $ $)) (-15 -2747 ((-814 |#1|) $)) (-15 -3877 (|#1| $)) (-15 -3030 ($ $)) (-15 -3680 ((-917) $)) (-15 -3451 ((-121) $ $)) (-15 -2310 ($ $)) (-15 -3936 ($ $)) (-15 -1407 ((-121) $)) (-15 -3286 ($ $)) (-15 -2981 ((-634 |#1|) $)))) (-842)) (T -667)) 
+((* (*1 *1 *1 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-842)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-814 *3)) (-5 *1 (-667 *3)) (-4 *3 (-842)))) (-3877 (*1 *2 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-842)))) (-3030 (*1 *1 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-842)))) (-3680 (*1 *2 *1) (-12 (-5 *2 (-917)) (-5 *1 (-667 *3)) (-4 *3 (-842)))) (-3451 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-667 *3)) (-4 *3 (-842)))) (-2310 (*1 *1 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-842)))) (-3936 (*1 *1 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-842)))) (-1407 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-667 *3)) (-4 *3 (-842)))) (-3286 (*1 *1 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-842)))) (-2981 (*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-667 *3)) (-4 *3 (-842))))) 
+(-13 (-842) (-1037 |#1|) (-10 -8 (-15 * ($ $ $)) (-15 -2747 ((-814 |#1|) $)) (-15 -3877 (|#1| $)) (-15 -3030 ($ $)) (-15 -3680 ((-917) $)) (-15 -3451 ((-121) $ $)) (-15 -2310 ($ $)) (-15 -3936 ($ $)) (-15 -1407 ((-121) $)) (-15 -3286 ($ $)) (-15 -2981 ((-634 |#1|) $)))) 
+((-4434 ((|#1| (-1 |#1| (-763) |#1|) (-763) |#1|) 11)) (-3181 ((|#1| (-1 |#1| |#1|) (-763) |#1|) 9))) 
+(((-668 |#1|) (-10 -7 (-15 -3181 (|#1| (-1 |#1| |#1|) (-763) |#1|)) (-15 -4434 (|#1| (-1 |#1| (-763) |#1|) (-763) |#1|))) (-1090)) (T -668)) 
+((-4434 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 (-763) *2)) (-5 *4 (-763)) (-4 *2 (-1090)) (-5 *1 (-668 *2)))) (-3181 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *2)) (-5 *4 (-763)) (-4 *2 (-1090)) (-5 *1 (-668 *2))))) 
+(-10 -7 (-15 -3181 (|#1| (-1 |#1| |#1|) (-763) |#1|)) (-15 -4434 (|#1| (-1 |#1| (-763) |#1|) (-763) |#1|))) 
+((-1729 ((|#2| |#1| |#2|) 9)) (-1722 ((|#1| |#1| |#2|) 8))) 
+(((-669 |#1| |#2|) (-10 -7 (-15 -1722 (|#1| |#1| |#2|)) (-15 -1729 (|#2| |#1| |#2|))) (-1090) (-1090)) (T -669)) 
+((-1729 (*1 *2 *3 *2) (-12 (-5 *1 (-669 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090)))) (-1722 (*1 *2 *2 *3) (-12 (-5 *1 (-669 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090))))) 
+(-10 -7 (-15 -1722 (|#1| |#1| |#2|)) (-15 -1729 (|#2| |#1| |#2|))) 
 ((-1446 ((|#3| (-1 |#3| |#2|) (-1 |#2| |#1|) |#1|) 11))) 
 (((-670 |#1| |#2| |#3|) (-10 -7 (-15 -1446 (|#3| (-1 |#3| |#2|) (-1 |#2| |#1|) |#1|))) (-1090) (-1090) (-1090)) (T -670)) 
 ((-1446 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *6)) (-5 *4 (-1 *6 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-1090)) (-5 *1 (-670 *5 *6 *2))))) 
 (-10 -7 (-15 -1446 (|#3| (-1 |#3| |#2|) (-1 |#2| |#1|) |#1|))) 
-((-3337 (((-1 |#1| (-763) |#1|) (-1 |#1| (-763) |#1|)) 23)) (-4315 (((-1 |#1|) |#1|) 8)) (-1713 ((|#1| |#1|) 16)) (-3859 (((-634 |#1|) (-1 (-634 |#1|) (-634 |#1|)) (-568)) 15) ((|#1| (-1 |#1| |#1|)) 11)) (-2745 (((-1 |#1|) |#1|) 9)) (** (((-1 |#1| |#1|) (-1 |#1| |#1|) (-763)) 20))) 
-(((-671 |#1|) (-10 -7 (-15 -4315 ((-1 |#1|) |#1|)) (-15 -2745 ((-1 |#1|) |#1|)) (-15 -3859 (|#1| (-1 |#1| |#1|))) (-15 -3859 ((-634 |#1|) (-1 (-634 |#1|) (-634 |#1|)) (-568))) (-15 -1713 (|#1| |#1|)) (-15 ** ((-1 |#1| |#1|) (-1 |#1| |#1|) (-763))) (-15 -3337 ((-1 |#1| (-763) |#1|) (-1 |#1| (-763) |#1|)))) (-1090)) (T -671)) 
-((-3337 (*1 *2 *2) (-12 (-5 *2 (-1 *3 (-763) *3)) (-4 *3 (-1090)) (-5 *1 (-671 *3)))) (** (*1 *2 *2 *3) (-12 (-5 *2 (-1 *4 *4)) (-5 *3 (-763)) (-4 *4 (-1090)) (-5 *1 (-671 *4)))) (-1713 (*1 *2 *2) (-12 (-5 *1 (-671 *2)) (-4 *2 (-1090)))) (-3859 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-634 *5) (-634 *5))) (-5 *4 (-568)) (-5 *2 (-634 *5)) (-5 *1 (-671 *5)) (-4 *5 (-1090)))) (-3859 (*1 *2 *3) (-12 (-5 *3 (-1 *2 *2)) (-5 *1 (-671 *2)) (-4 *2 (-1090)))) (-2745 (*1 *2 *3) (-12 (-5 *2 (-1 *3)) (-5 *1 (-671 *3)) (-4 *3 (-1090)))) (-4315 (*1 *2 *3) (-12 (-5 *2 (-1 *3)) (-5 *1 (-671 *3)) (-4 *3 (-1090))))) 
-(-10 -7 (-15 -4315 ((-1 |#1|) |#1|)) (-15 -2745 ((-1 |#1|) |#1|)) (-15 -3859 (|#1| (-1 |#1| |#1|))) (-15 -3859 ((-634 |#1|) (-1 (-634 |#1|) (-634 |#1|)) (-568))) (-15 -1713 (|#1| |#1|)) (-15 ** ((-1 |#1| |#1|) (-1 |#1| |#1|) (-763))) (-15 -3337 ((-1 |#1| (-763) |#1|) (-1 |#1| (-763) |#1|)))) 
-((-2302 (((-1 |#2| |#1|) (-1 |#2| |#1| |#1|)) 16)) (-2210 (((-1 |#2|) (-1 |#2| |#1|) |#1|) 13)) (-3495 (((-1 |#2| |#1|) (-1 |#2|)) 14)) (-1841 (((-1 |#2| |#1|) |#2|) 11))) 
-(((-672 |#1| |#2|) (-10 -7 (-15 -1841 ((-1 |#2| |#1|) |#2|)) (-15 -2210 ((-1 |#2|) (-1 |#2| |#1|) |#1|)) (-15 -3495 ((-1 |#2| |#1|) (-1 |#2|))) (-15 -2302 ((-1 |#2| |#1|) (-1 |#2| |#1| |#1|)))) (-1090) (-1090)) (T -672)) 
-((-2302 (*1 *2 *3) (-12 (-5 *3 (-1 *5 *4 *4)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-5 *2 (-1 *5 *4)) (-5 *1 (-672 *4 *5)))) (-3495 (*1 *2 *3) (-12 (-5 *3 (-1 *5)) (-4 *5 (-1090)) (-5 *2 (-1 *5 *4)) (-5 *1 (-672 *4 *5)) (-4 *4 (-1090)))) (-2210 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *5 *4)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-5 *2 (-1 *5)) (-5 *1 (-672 *4 *5)))) (-1841 (*1 *2 *3) (-12 (-5 *2 (-1 *3 *4)) (-5 *1 (-672 *4 *3)) (-4 *4 (-1090)) (-4 *3 (-1090))))) 
-(-10 -7 (-15 -1841 ((-1 |#2| |#1|) |#2|)) (-15 -2210 ((-1 |#2|) (-1 |#2| |#1|) |#1|)) (-15 -3495 ((-1 |#2| |#1|) (-1 |#2|))) (-15 -2302 ((-1 |#2| |#1|) (-1 |#2| |#1| |#1|)))) 
-((-3740 (((-1 |#3| |#2| |#1|) (-1 |#3| |#1| |#2|)) 17)) (-2958 (((-1 |#3| |#1|) (-1 |#3| |#1| |#2|) |#2|) 11)) (-2738 (((-1 |#3| |#2|) (-1 |#3| |#1| |#2|) |#1|) 13)) (-2402 (((-1 |#3| |#1| |#2|) (-1 |#3| |#1|)) 14)) (-1455 (((-1 |#3| |#1| |#2|) (-1 |#3| |#2|)) 15)) (* (((-1 |#3| |#1|) (-1 |#3| |#2|) (-1 |#2| |#1|)) 21))) 
-(((-673 |#1| |#2| |#3|) (-10 -7 (-15 -2958 ((-1 |#3| |#1|) (-1 |#3| |#1| |#2|) |#2|)) (-15 -2738 ((-1 |#3| |#2|) (-1 |#3| |#1| |#2|) |#1|)) (-15 -2402 ((-1 |#3| |#1| |#2|) (-1 |#3| |#1|))) (-15 -1455 ((-1 |#3| |#1| |#2|) (-1 |#3| |#2|))) (-15 -3740 ((-1 |#3| |#2| |#1|) (-1 |#3| |#1| |#2|))) (-15 * ((-1 |#3| |#1|) (-1 |#3| |#2|) (-1 |#2| |#1|)))) (-1090) (-1090) (-1090)) (T -673)) 
-((* (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-1 *6 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-1 *7 *5)) (-5 *1 (-673 *5 *6 *7)))) (-3740 (*1 *2 *3) (-12 (-5 *3 (-1 *6 *4 *5)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-1 *6 *5 *4)) (-5 *1 (-673 *4 *5 *6)))) (-1455 (*1 *2 *3) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-1 *6 *4 *5)) (-5 *1 (-673 *4 *5 *6)) (-4 *4 (-1090)))) (-2402 (*1 *2 *3) (-12 (-5 *3 (-1 *6 *4)) (-4 *4 (-1090)) (-4 *6 (-1090)) (-5 *2 (-1 *6 *4 *5)) (-5 *1 (-673 *4 *5 *6)) (-4 *5 (-1090)))) (-2738 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *4 *5)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-1 *6 *5)) (-5 *1 (-673 *4 *5 *6)))) (-2958 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5 *4)) (-4 *5 (-1090)) (-4 *4 (-1090)) (-4 *6 (-1090)) (-5 *2 (-1 *6 *5)) (-5 *1 (-673 *5 *4 *6))))) 
-(-10 -7 (-15 -2958 ((-1 |#3| |#1|) (-1 |#3| |#1| |#2|) |#2|)) (-15 -2738 ((-1 |#3| |#2|) (-1 |#3| |#1| |#2|) |#1|)) (-15 -2402 ((-1 |#3| |#1| |#2|) (-1 |#3| |#1|))) (-15 -1455 ((-1 |#3| |#1| |#2|) (-1 |#3| |#2|))) (-15 -3740 ((-1 |#3| |#2| |#1|) (-1 |#3| |#1| |#2|))) (-15 * ((-1 |#3| |#1|) (-1 |#3| |#2|) (-1 |#2| |#1|)))) 
-((-1779 (((-1 (-310 (-568)) |#1|) (-1 (-310 (-568)) |#1|) (-1 (-310 (-568)) |#1|)) 18)) (-1773 (((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|)) 12)) (-1767 (((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|)) 10)) (* (((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|)) 14))) 
-(((-674 |#1| |#2|) (-10 -7 (-15 -1767 ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 -1773 ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 * ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 -1779 ((-1 (-310 (-568)) |#1|) (-1 (-310 (-568)) |#1|) (-1 (-310 (-568)) |#1|)))) (-1090) (-1047)) (T -674)) 
-((-1779 (*1 *2 *2 *2) (-12 (-5 *2 (-1 (-310 (-568)) *3)) (-4 *3 (-1090)) (-5 *1 (-674 *3 *4)) (-4 *4 (-1047)))) (* (*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1090)) (-4 *4 (-1047)) (-5 *1 (-674 *3 *4)))) (-1773 (*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1090)) (-4 *4 (-1047)) (-5 *1 (-674 *3 *4)))) (-1767 (*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1090)) (-4 *4 (-1047)) (-5 *1 (-674 *3 *4))))) 
-(-10 -7 (-15 -1767 ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 -1773 ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 * ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 -1779 ((-1 (-310 (-568)) |#1|) (-1 (-310 (-568)) |#1|) (-1 (-310 (-568)) |#1|)))) 
-((-3092 ((|#5| (-1 |#5| |#1| |#5|) |#4| |#5|) 39)) (-2795 (((-3 |#8| "failed") (-1 (-3 |#5| "failed") |#1|) |#4|) 37) ((|#8| (-1 |#5| |#1|) |#4|) 31))) 
-(((-675 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -2795 (|#8| (-1 |#5| |#1|) |#4|)) (-15 -2795 ((-3 |#8| "failed") (-1 (-3 |#5| "failed") |#1|) |#4|)) (-15 -3092 (|#5| (-1 |#5| |#1| |#5|) |#4| |#5|))) (-1047) (-375 |#1|) (-375 |#1|) (-677 |#1| |#2| |#3|) (-1047) (-375 |#5|) (-375 |#5|) (-677 |#5| |#6| |#7|)) (T -675)) 
-((-3092 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1047)) (-4 *2 (-1047)) (-4 *6 (-375 *5)) (-4 *7 (-375 *5)) (-4 *8 (-375 *2)) (-4 *9 (-375 *2)) (-5 *1 (-675 *5 *6 *7 *4 *2 *8 *9 *10)) (-4 *4 (-677 *5 *6 *7)) (-4 *10 (-677 *2 *8 *9)))) (-2795 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *8 "failed") *5)) (-4 *5 (-1047)) (-4 *8 (-1047)) (-4 *6 (-375 *5)) (-4 *7 (-375 *5)) (-4 *2 (-677 *8 *9 *10)) (-5 *1 (-675 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-677 *5 *6 *7)) (-4 *9 (-375 *8)) (-4 *10 (-375 *8)))) (-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *5)) (-4 *5 (-1047)) (-4 *8 (-1047)) (-4 *6 (-375 *5)) (-4 *7 (-375 *5)) (-4 *2 (-677 *8 *9 *10)) (-5 *1 (-675 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-677 *5 *6 *7)) (-4 *9 (-375 *8)) (-4 *10 (-375 *8))))) 
-(-10 -7 (-15 -2795 (|#8| (-1 |#5| |#1|) |#4|)) (-15 -2795 ((-3 |#8| "failed") (-1 (-3 |#5| "failed") |#1|) |#4|)) (-15 -3092 (|#5| (-1 |#5| |#1| |#5|) |#4| |#5|))) 
-((-3205 (($ (-763) (-763)) 31)) (-3347 (($ $ $) 54)) (-2870 (($ |#3|) 50) (($ $) 51)) (-1335 (((-121) $) 26)) (-4343 (($ $ (-568) (-568)) 56)) (-3622 (($ $ (-568) (-568)) 57)) (-3676 (($ $ (-568) (-568) (-568) (-568)) 61)) (-3976 (($ $) 52)) (-2230 (((-121) $) 14)) (-1785 (($ $ (-568) (-568) $) 62)) (-2436 ((|#2| $ (-568) (-568) |#2|) NIL) (($ $ (-634 (-568)) (-634 (-568)) $) 60)) (-3422 (($ (-763) |#2|) 36)) (-2076 ((|#2| $) 105)) (-2269 (($ (-634 (-634 |#2|))) 34)) (-3208 (((-634 (-634 |#2|)) $) 55)) (-2858 (($ $ $) 53)) (-2595 (((-3 $ "failed") $ |#2|) 108)) (-2779 ((|#2| $ (-568) (-568)) NIL) ((|#2| $ (-568) (-568) |#2|) NIL) (($ $ (-634 (-568)) (-634 (-568))) 59)) (-2282 (($ (-634 |#2|)) 38) (($ (-634 $)) 40)) (-1960 (((-121) $) 23)) (-2365 (((-634 |#4|) $) 91)) (-2745 (((-850) $) NIL) (($ |#4|) 45)) (-1910 (((-121) $) 28)) (-1779 (($ $ |#2|) 110)) (-1773 (($ $ $) 66) (($ $) 69)) (-1767 (($ $ $) 64)) (** (($ $ (-763)) 78) (($ $ (-568)) 113)) (* (($ $ $) 75) (($ |#2| $) 71) (($ $ |#2|) 72) (($ (-568) $) 74) ((|#4| $ |#4|) 82) ((|#3| |#3| $) 86))) 
-(((-676 |#1| |#2| |#3| |#4|) (-10 -8 (-15 ** (|#1| |#1| (-568))) (-15 -2076 (|#2| |#1|)) (-15 -2365 ((-634 |#4|) |#1|)) (-15 -1779 (|#1| |#1| |#2|)) (-15 -2595 ((-3 |#1| "failed") |#1| |#2|)) (-15 ** (|#1| |#1| (-763))) (-15 * (|#3| |#3| |#1|)) (-15 * (|#4| |#1| |#4|)) (-15 * (|#1| (-568) |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 -1773 (|#1| |#1|)) (-15 -1773 (|#1| |#1| |#1|)) (-15 -1767 (|#1| |#1| |#1|)) (-15 -1785 (|#1| |#1| (-568) (-568) |#1|)) (-15 -3676 (|#1| |#1| (-568) (-568) (-568) (-568))) (-15 -3622 (|#1| |#1| (-568) (-568))) (-15 -4343 (|#1| |#1| (-568) (-568))) (-15 -2436 (|#1| |#1| (-634 (-568)) (-634 (-568)) |#1|)) (-15 -2779 (|#1| |#1| (-634 (-568)) (-634 (-568)))) (-15 -3208 ((-634 (-634 |#2|)) |#1|)) (-15 -3347 (|#1| |#1| |#1|)) (-15 -2858 (|#1| |#1| |#1|)) (-15 -3976 (|#1| |#1|)) (-15 -2870 (|#1| |#1|)) (-15 -2870 (|#1| |#3|)) (-15 -2745 (|#1| |#4|)) (-15 -2282 (|#1| (-634 |#1|))) (-15 -2282 (|#1| (-634 |#2|))) (-15 -3422 (|#1| (-763) |#2|)) (-15 -2269 (|#1| (-634 (-634 |#2|)))) (-15 -3205 (|#1| (-763) (-763))) (-15 -1910 ((-121) |#1|)) (-15 -1335 ((-121) |#1|)) (-15 -1960 ((-121) |#1|)) (-15 -2230 ((-121) |#1|)) (-15 -2436 (|#2| |#1| (-568) (-568) |#2|)) (-15 -2779 (|#2| |#1| (-568) (-568) |#2|)) (-15 -2779 (|#2| |#1| (-568) (-568))) (-15 -2745 ((-850) |#1|))) (-677 |#2| |#3| |#4|) (-1047) (-375 |#2|) (-375 |#2|)) (T -676)) 
-NIL 
-(-10 -8 (-15 ** (|#1| |#1| (-568))) (-15 -2076 (|#2| |#1|)) (-15 -2365 ((-634 |#4|) |#1|)) (-15 -1779 (|#1| |#1| |#2|)) (-15 -2595 ((-3 |#1| "failed") |#1| |#2|)) (-15 ** (|#1| |#1| (-763))) (-15 * (|#3| |#3| |#1|)) (-15 * (|#4| |#1| |#4|)) (-15 * (|#1| (-568) |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 -1773 (|#1| |#1|)) (-15 -1773 (|#1| |#1| |#1|)) (-15 -1767 (|#1| |#1| |#1|)) (-15 -1785 (|#1| |#1| (-568) (-568) |#1|)) (-15 -3676 (|#1| |#1| (-568) (-568) (-568) (-568))) (-15 -3622 (|#1| |#1| (-568) (-568))) (-15 -4343 (|#1| |#1| (-568) (-568))) (-15 -2436 (|#1| |#1| (-634 (-568)) (-634 (-568)) |#1|)) (-15 -2779 (|#1| |#1| (-634 (-568)) (-634 (-568)))) (-15 -3208 ((-634 (-634 |#2|)) |#1|)) (-15 -3347 (|#1| |#1| |#1|)) (-15 -2858 (|#1| |#1| |#1|)) (-15 -3976 (|#1| |#1|)) (-15 -2870 (|#1| |#1|)) (-15 -2870 (|#1| |#3|)) (-15 -2745 (|#1| |#4|)) (-15 -2282 (|#1| (-634 |#1|))) (-15 -2282 (|#1| (-634 |#2|))) (-15 -3422 (|#1| (-763) |#2|)) (-15 -2269 (|#1| (-634 (-634 |#2|)))) (-15 -3205 (|#1| (-763) (-763))) (-15 -1910 ((-121) |#1|)) (-15 -1335 ((-121) |#1|)) (-15 -1960 ((-121) |#1|)) (-15 -2230 ((-121) |#1|)) (-15 -2436 (|#2| |#1| (-568) (-568) |#2|)) (-15 -2779 (|#2| |#1| (-568) (-568) |#2|)) (-15 -2779 (|#2| |#1| (-568) (-568))) (-15 -2745 ((-850) |#1|))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-3205 (($ (-763) (-763)) 94)) (-3347 (($ $ $) 84)) (-2870 (($ |#2|) 88) (($ $) 87)) (-1335 (((-121) $) 96)) (-4343 (($ $ (-568) (-568)) 80)) (-3622 (($ $ (-568) (-568)) 79)) (-3676 (($ $ (-568) (-568) (-568) (-568)) 78)) (-3976 (($ $) 86)) (-2230 (((-121) $) 98)) (-2510 (((-121) $ (-763)) 8)) (-1785 (($ $ (-568) (-568) $) 77)) (-2436 ((|#1| $ (-568) (-568) |#1|) 41) (($ $ (-634 (-568)) (-634 (-568)) $) 81)) (-4159 (($ $ (-568) |#2|) 39)) (-2451 (($ $ (-568) |#3|) 38)) (-3422 (($ (-763) |#1|) 92)) (-2671 (($) 7 T CONST)) (-4167 (($ $) 64 (|has| |#1| (-301)))) (-1818 ((|#2| $ (-568)) 43)) (-3700 (((-763) $) 62 (|has| |#1| (-558)))) (-3989 ((|#1| $ (-568) (-568) |#1|) 40)) (-2602 ((|#1| $ (-568) (-568)) 45)) (-2076 ((|#1| $) 57 (|has| |#1| (-172)))) (-4360 (((-634 |#1|) $) 30)) (-2121 (((-763) $) 61 (|has| |#1| (-558)))) (-4272 (((-634 |#3|) $) 60 (|has| |#1| (-558)))) (-3043 (((-763) $) 48)) (-1849 (($ (-763) (-763) |#1|) 54)) (-2555 (((-763) $) 47)) (-1737 (((-121) $ (-763)) 9)) (-3082 ((|#1| $) 58 (|has| |#1| (-6 (-4521 "*"))))) (-2087 (((-568) $) 52)) (-3364 (((-568) $) 50)) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-1663 (((-568) $) 51)) (-2893 (((-568) $) 49)) (-2269 (($ (-634 (-634 |#1|))) 93)) (-3674 (($ (-1 |#1| |#1|) $) 34)) (-2795 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 37) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) 36)) (-3208 (((-634 (-634 |#1|)) $) 83)) (-2166 (((-121) $ (-763)) 10)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-3140 (((-3 $ "failed") $) 56 (|has| |#1| (-365)))) (-2858 (($ $ $) 85)) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3724 (($ $ |#1|) 53)) (-2595 (((-3 $ "failed") $ |#1|) 66 (|has| |#1| (-558)))) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 ((|#1| $ (-568) (-568)) 46) ((|#1| $ (-568) (-568) |#1|) 44) (($ $ (-634 (-568)) (-634 (-568))) 82)) (-2282 (($ (-634 |#1|)) 91) (($ (-634 $)) 90)) (-1960 (((-121) $) 97)) (-2465 ((|#1| $) 59 (|has| |#1| (-6 (-4521 "*"))))) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-2365 (((-634 |#3|) $) 63 (|has| |#1| (-301)))) (-3731 ((|#3| $ (-568)) 42)) (-2745 (((-850) $) 20 (|has| |#1| (-1090))) (($ |#3|) 89)) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1910 (((-121) $) 95)) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1779 (($ $ |#1|) 65 (|has| |#1| (-365)))) (-1773 (($ $ $) 75) (($ $) 74)) (-1767 (($ $ $) 76)) (** (($ $ (-763)) 67) (($ $ (-568)) 55 (|has| |#1| (-365)))) (* (($ $ $) 73) (($ |#1| $) 72) (($ $ |#1|) 71) (($ (-568) $) 70) ((|#3| $ |#3|) 69) ((|#2| |#2| $) 68)) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-4434 (((-1 |#1| (-763) |#1|) (-1 |#1| (-763) |#1|)) 23)) (-3080 (((-1 |#1|) |#1|) 8)) (-1716 ((|#1| |#1|) 16)) (-1926 (((-634 |#1|) (-1 (-634 |#1|) (-634 |#1|)) (-568)) 15) ((|#1| (-1 |#1| |#1|)) 11)) (-2747 (((-1 |#1|) |#1|) 9)) (** (((-1 |#1| |#1|) (-1 |#1| |#1|) (-763)) 20))) 
+(((-671 |#1|) (-10 -7 (-15 -3080 ((-1 |#1|) |#1|)) (-15 -2747 ((-1 |#1|) |#1|)) (-15 -1926 (|#1| (-1 |#1| |#1|))) (-15 -1926 ((-634 |#1|) (-1 (-634 |#1|) (-634 |#1|)) (-568))) (-15 -1716 (|#1| |#1|)) (-15 ** ((-1 |#1| |#1|) (-1 |#1| |#1|) (-763))) (-15 -4434 ((-1 |#1| (-763) |#1|) (-1 |#1| (-763) |#1|)))) (-1090)) (T -671)) 
+((-4434 (*1 *2 *2) (-12 (-5 *2 (-1 *3 (-763) *3)) (-4 *3 (-1090)) (-5 *1 (-671 *3)))) (** (*1 *2 *2 *3) (-12 (-5 *2 (-1 *4 *4)) (-5 *3 (-763)) (-4 *4 (-1090)) (-5 *1 (-671 *4)))) (-1716 (*1 *2 *2) (-12 (-5 *1 (-671 *2)) (-4 *2 (-1090)))) (-1926 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-634 *5) (-634 *5))) (-5 *4 (-568)) (-5 *2 (-634 *5)) (-5 *1 (-671 *5)) (-4 *5 (-1090)))) (-1926 (*1 *2 *3) (-12 (-5 *3 (-1 *2 *2)) (-5 *1 (-671 *2)) (-4 *2 (-1090)))) (-2747 (*1 *2 *3) (-12 (-5 *2 (-1 *3)) (-5 *1 (-671 *3)) (-4 *3 (-1090)))) (-3080 (*1 *2 *3) (-12 (-5 *2 (-1 *3)) (-5 *1 (-671 *3)) (-4 *3 (-1090))))) 
+(-10 -7 (-15 -3080 ((-1 |#1|) |#1|)) (-15 -2747 ((-1 |#1|) |#1|)) (-15 -1926 (|#1| (-1 |#1| |#1|))) (-15 -1926 ((-634 |#1|) (-1 (-634 |#1|) (-634 |#1|)) (-568))) (-15 -1716 (|#1| |#1|)) (-15 ** ((-1 |#1| |#1|) (-1 |#1| |#1|) (-763))) (-15 -4434 ((-1 |#1| (-763) |#1|) (-1 |#1| (-763) |#1|)))) 
+((-3646 (((-1 |#2| |#1|) (-1 |#2| |#1| |#1|)) 16)) (-3357 (((-1 |#2|) (-1 |#2| |#1|) |#1|) 13)) (-3497 (((-1 |#2| |#1|) (-1 |#2|)) 14)) (-2358 (((-1 |#2| |#1|) |#2|) 11))) 
+(((-672 |#1| |#2|) (-10 -7 (-15 -2358 ((-1 |#2| |#1|) |#2|)) (-15 -3357 ((-1 |#2|) (-1 |#2| |#1|) |#1|)) (-15 -3497 ((-1 |#2| |#1|) (-1 |#2|))) (-15 -3646 ((-1 |#2| |#1|) (-1 |#2| |#1| |#1|)))) (-1090) (-1090)) (T -672)) 
+((-3646 (*1 *2 *3) (-12 (-5 *3 (-1 *5 *4 *4)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-5 *2 (-1 *5 *4)) (-5 *1 (-672 *4 *5)))) (-3497 (*1 *2 *3) (-12 (-5 *3 (-1 *5)) (-4 *5 (-1090)) (-5 *2 (-1 *5 *4)) (-5 *1 (-672 *4 *5)) (-4 *4 (-1090)))) (-3357 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *5 *4)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-5 *2 (-1 *5)) (-5 *1 (-672 *4 *5)))) (-2358 (*1 *2 *3) (-12 (-5 *2 (-1 *3 *4)) (-5 *1 (-672 *4 *3)) (-4 *4 (-1090)) (-4 *3 (-1090))))) 
+(-10 -7 (-15 -2358 ((-1 |#2| |#1|) |#2|)) (-15 -3357 ((-1 |#2|) (-1 |#2| |#1|) |#1|)) (-15 -3497 ((-1 |#2| |#1|) (-1 |#2|))) (-15 -3646 ((-1 |#2| |#1|) (-1 |#2| |#1| |#1|)))) 
+((-2562 (((-1 |#3| |#2| |#1|) (-1 |#3| |#1| |#2|)) 17)) (-3010 (((-1 |#3| |#1|) (-1 |#3| |#1| |#2|) |#2|) 11)) (-3314 (((-1 |#3| |#2|) (-1 |#3| |#1| |#2|) |#1|) 13)) (-2284 (((-1 |#3| |#1| |#2|) (-1 |#3| |#1|)) 14)) (-2372 (((-1 |#3| |#1| |#2|) (-1 |#3| |#2|)) 15)) (* (((-1 |#3| |#1|) (-1 |#3| |#2|) (-1 |#2| |#1|)) 21))) 
+(((-673 |#1| |#2| |#3|) (-10 -7 (-15 -3010 ((-1 |#3| |#1|) (-1 |#3| |#1| |#2|) |#2|)) (-15 -3314 ((-1 |#3| |#2|) (-1 |#3| |#1| |#2|) |#1|)) (-15 -2284 ((-1 |#3| |#1| |#2|) (-1 |#3| |#1|))) (-15 -2372 ((-1 |#3| |#1| |#2|) (-1 |#3| |#2|))) (-15 -2562 ((-1 |#3| |#2| |#1|) (-1 |#3| |#1| |#2|))) (-15 * ((-1 |#3| |#1|) (-1 |#3| |#2|) (-1 |#2| |#1|)))) (-1090) (-1090) (-1090)) (T -673)) 
+((* (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-1 *6 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-1 *7 *5)) (-5 *1 (-673 *5 *6 *7)))) (-2562 (*1 *2 *3) (-12 (-5 *3 (-1 *6 *4 *5)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-1 *6 *5 *4)) (-5 *1 (-673 *4 *5 *6)))) (-2372 (*1 *2 *3) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-1 *6 *4 *5)) (-5 *1 (-673 *4 *5 *6)) (-4 *4 (-1090)))) (-2284 (*1 *2 *3) (-12 (-5 *3 (-1 *6 *4)) (-4 *4 (-1090)) (-4 *6 (-1090)) (-5 *2 (-1 *6 *4 *5)) (-5 *1 (-673 *4 *5 *6)) (-4 *5 (-1090)))) (-3314 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *4 *5)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-1 *6 *5)) (-5 *1 (-673 *4 *5 *6)))) (-3010 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5 *4)) (-4 *5 (-1090)) (-4 *4 (-1090)) (-4 *6 (-1090)) (-5 *2 (-1 *6 *5)) (-5 *1 (-673 *5 *4 *6))))) 
+(-10 -7 (-15 -3010 ((-1 |#3| |#1|) (-1 |#3| |#1| |#2|) |#2|)) (-15 -3314 ((-1 |#3| |#2|) (-1 |#3| |#1| |#2|) |#1|)) (-15 -2284 ((-1 |#3| |#1| |#2|) (-1 |#3| |#1|))) (-15 -2372 ((-1 |#3| |#1| |#2|) (-1 |#3| |#2|))) (-15 -2562 ((-1 |#3| |#2| |#1|) (-1 |#3| |#1| |#2|))) (-15 * ((-1 |#3| |#1|) (-1 |#3| |#2|) (-1 |#2| |#1|)))) 
+((-1781 (((-1 (-310 (-568)) |#1|) (-1 (-310 (-568)) |#1|) (-1 (-310 (-568)) |#1|)) 18)) (-1775 (((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|)) 12)) (-1769 (((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|)) 10)) (* (((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|)) 14))) 
+(((-674 |#1| |#2|) (-10 -7 (-15 -1769 ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 -1775 ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 * ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 -1781 ((-1 (-310 (-568)) |#1|) (-1 (-310 (-568)) |#1|) (-1 (-310 (-568)) |#1|)))) (-1090) (-1047)) (T -674)) 
+((-1781 (*1 *2 *2 *2) (-12 (-5 *2 (-1 (-310 (-568)) *3)) (-4 *3 (-1090)) (-5 *1 (-674 *3 *4)) (-4 *4 (-1047)))) (* (*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1090)) (-4 *4 (-1047)) (-5 *1 (-674 *3 *4)))) (-1775 (*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1090)) (-4 *4 (-1047)) (-5 *1 (-674 *3 *4)))) (-1769 (*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1090)) (-4 *4 (-1047)) (-5 *1 (-674 *3 *4))))) 
+(-10 -7 (-15 -1769 ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 -1775 ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 * ((-1 |#2| |#1|) (-1 |#2| |#1|) (-1 |#2| |#1|))) (-15 -1781 ((-1 (-310 (-568)) |#1|) (-1 (-310 (-568)) |#1|) (-1 (-310 (-568)) |#1|)))) 
+((-3094 ((|#5| (-1 |#5| |#1| |#5|) |#4| |#5|) 39)) (-2797 (((-3 |#8| "failed") (-1 (-3 |#5| "failed") |#1|) |#4|) 37) ((|#8| (-1 |#5| |#1|) |#4|) 31))) 
+(((-675 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8|) (-10 -7 (-15 -2797 (|#8| (-1 |#5| |#1|) |#4|)) (-15 -2797 ((-3 |#8| "failed") (-1 (-3 |#5| "failed") |#1|) |#4|)) (-15 -3094 (|#5| (-1 |#5| |#1| |#5|) |#4| |#5|))) (-1047) (-375 |#1|) (-375 |#1|) (-677 |#1| |#2| |#3|) (-1047) (-375 |#5|) (-375 |#5|) (-677 |#5| |#6| |#7|)) (T -675)) 
+((-3094 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1047)) (-4 *2 (-1047)) (-4 *6 (-375 *5)) (-4 *7 (-375 *5)) (-4 *8 (-375 *2)) (-4 *9 (-375 *2)) (-5 *1 (-675 *5 *6 *7 *4 *2 *8 *9 *10)) (-4 *4 (-677 *5 *6 *7)) (-4 *10 (-677 *2 *8 *9)))) (-2797 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *8 "failed") *5)) (-4 *5 (-1047)) (-4 *8 (-1047)) (-4 *6 (-375 *5)) (-4 *7 (-375 *5)) (-4 *2 (-677 *8 *9 *10)) (-5 *1 (-675 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-677 *5 *6 *7)) (-4 *9 (-375 *8)) (-4 *10 (-375 *8)))) (-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *5)) (-4 *5 (-1047)) (-4 *8 (-1047)) (-4 *6 (-375 *5)) (-4 *7 (-375 *5)) (-4 *2 (-677 *8 *9 *10)) (-5 *1 (-675 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-677 *5 *6 *7)) (-4 *9 (-375 *8)) (-4 *10 (-375 *8))))) 
+(-10 -7 (-15 -2797 (|#8| (-1 |#5| |#1|) |#4|)) (-15 -2797 ((-3 |#8| "failed") (-1 (-3 |#5| "failed") |#1|) |#4|)) (-15 -3094 (|#5| (-1 |#5| |#1| |#5|) |#4| |#5|))) 
+((-3207 (($ (-763) (-763)) 31)) (-4486 (($ $ $) 54)) (-4089 (($ |#3|) 50) (($ $) 51)) (-3560 (((-121) $) 26)) (-3211 (($ $ (-568) (-568)) 56)) (-3096 (($ $ (-568) (-568)) 57)) (-2265 (($ $ (-568) (-568) (-568) (-568)) 61)) (-4467 (($ $) 52)) (-3691 (((-121) $) 14)) (-4043 (($ $ (-568) (-568) $) 62)) (-2438 ((|#2| $ (-568) (-568) |#2|) NIL) (($ $ (-634 (-568)) (-634 (-568)) $) 60)) (-1637 (($ (-763) |#2|) 36)) (-3102 ((|#2| $) 105)) (-2271 (($ (-634 (-634 |#2|))) 34)) (-1843 (((-634 (-634 |#2|)) $) 55)) (-4018 (($ $ $) 53)) (-2597 (((-3 $ "failed") $ |#2|) 108)) (-2781 ((|#2| $ (-568) (-568)) NIL) ((|#2| $ (-568) (-568) |#2|) NIL) (($ $ (-634 (-568)) (-634 (-568))) 59)) (-3499 (($ (-634 |#2|)) 38) (($ (-634 $)) 40)) (-4322 (((-121) $) 23)) (-4063 (((-634 |#4|) $) 91)) (-2747 (((-850) $) NIL) (($ |#4|) 45)) (-2675 (((-121) $) 28)) (-1781 (($ $ |#2|) 110)) (-1775 (($ $ $) 66) (($ $) 69)) (-1769 (($ $ $) 64)) (** (($ $ (-763)) 78) (($ $ (-568)) 113)) (* (($ $ $) 75) (($ |#2| $) 71) (($ $ |#2|) 72) (($ (-568) $) 74) ((|#4| $ |#4|) 82) ((|#3| |#3| $) 86))) 
+(((-676 |#1| |#2| |#3| |#4|) (-10 -8 (-15 ** (|#1| |#1| (-568))) (-15 -3102 (|#2| |#1|)) (-15 -4063 ((-634 |#4|) |#1|)) (-15 -1781 (|#1| |#1| |#2|)) (-15 -2597 ((-3 |#1| "failed") |#1| |#2|)) (-15 ** (|#1| |#1| (-763))) (-15 * (|#3| |#3| |#1|)) (-15 * (|#4| |#1| |#4|)) (-15 * (|#1| (-568) |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 -1775 (|#1| |#1|)) (-15 -1775 (|#1| |#1| |#1|)) (-15 -1769 (|#1| |#1| |#1|)) (-15 -4043 (|#1| |#1| (-568) (-568) |#1|)) (-15 -2265 (|#1| |#1| (-568) (-568) (-568) (-568))) (-15 -3096 (|#1| |#1| (-568) (-568))) (-15 -3211 (|#1| |#1| (-568) (-568))) (-15 -2438 (|#1| |#1| (-634 (-568)) (-634 (-568)) |#1|)) (-15 -2781 (|#1| |#1| (-634 (-568)) (-634 (-568)))) (-15 -1843 ((-634 (-634 |#2|)) |#1|)) (-15 -4486 (|#1| |#1| |#1|)) (-15 -4018 (|#1| |#1| |#1|)) (-15 -4467 (|#1| |#1|)) (-15 -4089 (|#1| |#1|)) (-15 -4089 (|#1| |#3|)) (-15 -2747 (|#1| |#4|)) (-15 -3499 (|#1| (-634 |#1|))) (-15 -3499 (|#1| (-634 |#2|))) (-15 -1637 (|#1| (-763) |#2|)) (-15 -2271 (|#1| (-634 (-634 |#2|)))) (-15 -3207 (|#1| (-763) (-763))) (-15 -2675 ((-121) |#1|)) (-15 -3560 ((-121) |#1|)) (-15 -4322 ((-121) |#1|)) (-15 -3691 ((-121) |#1|)) (-15 -2438 (|#2| |#1| (-568) (-568) |#2|)) (-15 -2781 (|#2| |#1| (-568) (-568) |#2|)) (-15 -2781 (|#2| |#1| (-568) (-568))) (-15 -2747 ((-850) |#1|))) (-677 |#2| |#3| |#4|) (-1047) (-375 |#2|) (-375 |#2|)) (T -676)) 
+NIL 
+(-10 -8 (-15 ** (|#1| |#1| (-568))) (-15 -3102 (|#2| |#1|)) (-15 -4063 ((-634 |#4|) |#1|)) (-15 -1781 (|#1| |#1| |#2|)) (-15 -2597 ((-3 |#1| "failed") |#1| |#2|)) (-15 ** (|#1| |#1| (-763))) (-15 * (|#3| |#3| |#1|)) (-15 * (|#4| |#1| |#4|)) (-15 * (|#1| (-568) |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 -1775 (|#1| |#1|)) (-15 -1775 (|#1| |#1| |#1|)) (-15 -1769 (|#1| |#1| |#1|)) (-15 -4043 (|#1| |#1| (-568) (-568) |#1|)) (-15 -2265 (|#1| |#1| (-568) (-568) (-568) (-568))) (-15 -3096 (|#1| |#1| (-568) (-568))) (-15 -3211 (|#1| |#1| (-568) (-568))) (-15 -2438 (|#1| |#1| (-634 (-568)) (-634 (-568)) |#1|)) (-15 -2781 (|#1| |#1| (-634 (-568)) (-634 (-568)))) (-15 -1843 ((-634 (-634 |#2|)) |#1|)) (-15 -4486 (|#1| |#1| |#1|)) (-15 -4018 (|#1| |#1| |#1|)) (-15 -4467 (|#1| |#1|)) (-15 -4089 (|#1| |#1|)) (-15 -4089 (|#1| |#3|)) (-15 -2747 (|#1| |#4|)) (-15 -3499 (|#1| (-634 |#1|))) (-15 -3499 (|#1| (-634 |#2|))) (-15 -1637 (|#1| (-763) |#2|)) (-15 -2271 (|#1| (-634 (-634 |#2|)))) (-15 -3207 (|#1| (-763) (-763))) (-15 -2675 ((-121) |#1|)) (-15 -3560 ((-121) |#1|)) (-15 -4322 ((-121) |#1|)) (-15 -3691 ((-121) |#1|)) (-15 -2438 (|#2| |#1| (-568) (-568) |#2|)) (-15 -2781 (|#2| |#1| (-568) (-568) |#2|)) (-15 -2781 (|#2| |#1| (-568) (-568))) (-15 -2747 ((-850) |#1|))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-3207 (($ (-763) (-763)) 94)) (-4486 (($ $ $) 84)) (-4089 (($ |#2|) 88) (($ $) 87)) (-3560 (((-121) $) 96)) (-3211 (($ $ (-568) (-568)) 80)) (-3096 (($ $ (-568) (-568)) 79)) (-2265 (($ $ (-568) (-568) (-568) (-568)) 78)) (-4467 (($ $) 86)) (-3691 (((-121) $) 98)) (-1667 (((-121) $ (-763)) 8)) (-4043 (($ $ (-568) (-568) $) 77)) (-2438 ((|#1| $ (-568) (-568) |#1|) 41) (($ $ (-634 (-568)) (-634 (-568)) $) 81)) (-3874 (($ $ (-568) |#2|) 39)) (-2525 (($ $ (-568) |#3|) 38)) (-1637 (($ (-763) |#1|) 92)) (-4490 (($) 7 T CONST)) (-3912 (($ $) 64 (|has| |#1| (-301)))) (-2228 ((|#2| $ (-568)) 43)) (-2371 (((-763) $) 62 (|has| |#1| (-558)))) (-1292 ((|#1| $ (-568) (-568) |#1|) 40)) (-2069 ((|#1| $ (-568) (-568)) 45)) (-3102 ((|#1| $) 57 (|has| |#1| (-172)))) (-3317 (((-634 |#1|) $) 30)) (-3344 (((-763) $) 61 (|has| |#1| (-558)))) (-2934 (((-634 |#3|) $) 60 (|has| |#1| (-558)))) (-2241 (((-763) $) 48)) (-1851 (($ (-763) (-763) |#1|) 54)) (-1901 (((-763) $) 47)) (-3791 (((-121) $ (-763)) 9)) (-2424 ((|#1| $) 58 (|has| |#1| (-6 (-4523 "*"))))) (-3139 (((-568) $) 52)) (-1343 (((-568) $) 50)) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3405 (((-568) $) 51)) (-2801 (((-568) $) 49)) (-2271 (($ (-634 (-634 |#1|))) 93)) (-2253 (($ (-1 |#1| |#1|) $) 34)) (-2797 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 37) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) 36)) (-1843 (((-634 (-634 |#1|)) $) 83)) (-3796 (((-121) $ (-763)) 10)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-2715 (((-3 $ "failed") $) 56 (|has| |#1| (-365)))) (-4018 (($ $ $) 85)) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-2490 (($ $ |#1|) 53)) (-2597 (((-3 $ "failed") $ |#1|) 66 (|has| |#1| (-558)))) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 ((|#1| $ (-568) (-568)) 46) ((|#1| $ (-568) (-568) |#1|) 44) (($ $ (-634 (-568)) (-634 (-568))) 82)) (-3499 (($ (-634 |#1|)) 91) (($ (-634 $)) 90)) (-4322 (((-121) $) 97)) (-2591 ((|#1| $) 59 (|has| |#1| (-6 (-4523 "*"))))) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-4063 (((-634 |#3|) $) 63 (|has| |#1| (-301)))) (-2522 ((|#3| $ (-568)) 42)) (-2747 (((-850) $) 20 (|has| |#1| (-1090))) (($ |#3|) 89)) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-2675 (((-121) $) 95)) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1781 (($ $ |#1|) 65 (|has| |#1| (-365)))) (-1775 (($ $ $) 75) (($ $) 74)) (-1769 (($ $ $) 76)) (** (($ $ (-763)) 67) (($ $ (-568)) 55 (|has| |#1| (-365)))) (* (($ $ $) 73) (($ |#1| $) 72) (($ $ |#1|) 71) (($ (-568) $) 70) ((|#3| $ |#3|) 69) ((|#2| |#2| $) 68)) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-677 |#1| |#2| |#3|) (-1275) (-1047) (-375 |t#1|) (-375 |t#1|)) (T -677)) 
-((-2230 (*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-121)))) (-1960 (*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-121)))) (-1335 (*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-121)))) (-1910 (*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-121)))) (-3205 (*1 *1 *2 *2) (-12 (-5 *2 (-763)) (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *5)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-2269 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *5)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-3422 (*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *5)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-2282 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *5)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-2282 (*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *5)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-2745 (*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *2)) (-4 *4 (-375 *3)) (-4 *2 (-375 *3)))) (-2870 (*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *1 (-677 *3 *2 *4)) (-4 *2 (-375 *3)) (-4 *4 (-375 *3)))) (-2870 (*1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) (-3976 (*1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) (-2858 (*1 *1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) (-3347 (*1 *1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) (-3208 (*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-634 (-634 *3))))) (-2779 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-634 (-568))) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-2436 (*1 *1 *1 *2 *2 *1) (-12 (-5 *2 (-634 (-568))) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-4343 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-3622 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-3676 (*1 *1 *1 *2 *2 *2 *2) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-1785 (*1 *1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-1767 (*1 *1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) (-1773 (*1 *1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) (-1773 (*1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) (* (*1 *1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) (* (*1 *1 *1 *2) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) (* (*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (* (*1 *2 *1 *2) (-12 (-4 *1 (-677 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *2 (-375 *3)))) (* (*1 *2 *2 *1) (-12 (-4 *1 (-677 *3 *2 *4)) (-4 *3 (-1047)) (-4 *2 (-375 *3)) (-4 *4 (-375 *3)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-2595 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (-4 *2 (-558)))) (-1779 (*1 *1 *1 *2) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (-4 *2 (-365)))) (-4167 (*1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (-4 *2 (-301)))) (-2365 (*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-4 *3 (-301)) (-5 *2 (-634 *5)))) (-3700 (*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-4 *3 (-558)) (-5 *2 (-763)))) (-2121 (*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-4 *3 (-558)) (-5 *2 (-763)))) (-4272 (*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-4 *3 (-558)) (-5 *2 (-634 *5)))) (-2465 (*1 *2 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (|has| *2 (-6 (-4521 "*"))) (-4 *2 (-1047)))) (-3082 (*1 *2 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (|has| *2 (-6 (-4521 "*"))) (-4 *2 (-1047)))) (-2076 (*1 *2 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (-4 *2 (-1047)) (-4 *2 (-172)))) (-3140 (*1 *1 *1) (|partial| -12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (-4 *2 (-365)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-4 *3 (-365))))) 
-(-13 (-62 |t#1| |t#2| |t#3|) (-10 -8 (-6 -4520) (-6 -4519) (-15 -2230 ((-121) $)) (-15 -1960 ((-121) $)) (-15 -1335 ((-121) $)) (-15 -1910 ((-121) $)) (-15 -3205 ($ (-763) (-763))) (-15 -2269 ($ (-634 (-634 |t#1|)))) (-15 -3422 ($ (-763) |t#1|)) (-15 -2282 ($ (-634 |t#1|))) (-15 -2282 ($ (-634 $))) (-15 -2745 ($ |t#3|)) (-15 -2870 ($ |t#2|)) (-15 -2870 ($ $)) (-15 -3976 ($ $)) (-15 -2858 ($ $ $)) (-15 -3347 ($ $ $)) (-15 -3208 ((-634 (-634 |t#1|)) $)) (-15 -2779 ($ $ (-634 (-568)) (-634 (-568)))) (-15 -2436 ($ $ (-634 (-568)) (-634 (-568)) $)) (-15 -4343 ($ $ (-568) (-568))) (-15 -3622 ($ $ (-568) (-568))) (-15 -3676 ($ $ (-568) (-568) (-568) (-568))) (-15 -1785 ($ $ (-568) (-568) $)) (-15 -1767 ($ $ $)) (-15 -1773 ($ $ $)) (-15 -1773 ($ $)) (-15 * ($ $ $)) (-15 * ($ |t#1| $)) (-15 * ($ $ |t#1|)) (-15 * ($ (-568) $)) (-15 * (|t#3| $ |t#3|)) (-15 * (|t#2| |t#2| $)) (-15 ** ($ $ (-763))) (IF (|has| |t#1| (-558)) (-15 -2595 ((-3 $ "failed") $ |t#1|)) |noBranch|) (IF (|has| |t#1| (-365)) (-15 -1779 ($ $ |t#1|)) |noBranch|) (IF (|has| |t#1| (-301)) (PROGN (-15 -4167 ($ $)) (-15 -2365 ((-634 |t#3|) $))) |noBranch|) (IF (|has| |t#1| (-558)) (PROGN (-15 -3700 ((-763) $)) (-15 -2121 ((-763) $)) (-15 -4272 ((-634 |t#3|) $))) |noBranch|) (IF (|has| |t#1| (-6 (-4521 "*"))) (PROGN (-15 -2465 (|t#1| $)) (-15 -3082 (|t#1| $))) |noBranch|) (IF (|has| |t#1| (-172)) (-15 -2076 (|t#1| $)) |noBranch|) (IF (|has| |t#1| (-365)) (PROGN (-15 -3140 ((-3 $ "failed") $)) (-15 ** ($ $ (-568)))) |noBranch|))) 
+((-3691 (*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-121)))) (-4322 (*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-121)))) (-3560 (*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-121)))) (-2675 (*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-121)))) (-3207 (*1 *1 *2 *2) (-12 (-5 *2 (-763)) (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *5)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-2271 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *5)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-1637 (*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *5)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-3499 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *5)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-3499 (*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *5)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-2747 (*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *2)) (-4 *4 (-375 *3)) (-4 *2 (-375 *3)))) (-4089 (*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *1 (-677 *3 *2 *4)) (-4 *2 (-375 *3)) (-4 *4 (-375 *3)))) (-4089 (*1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) (-4467 (*1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) (-4018 (*1 *1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) (-4486 (*1 *1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) (-1843 (*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-634 (-634 *3))))) (-2781 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-634 (-568))) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-2438 (*1 *1 *1 *2 *2 *1) (-12 (-5 *2 (-634 (-568))) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-3211 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-3096 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-2265 (*1 *1 *1 *2 *2 *2 *2) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-4043 (*1 *1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-1769 (*1 *1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) (-1775 (*1 *1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) (-1775 (*1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) (* (*1 *1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) (* (*1 *1 *1 *2) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) (* (*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (* (*1 *2 *1 *2) (-12 (-4 *1 (-677 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *2 (-375 *3)))) (* (*1 *2 *2 *1) (-12 (-4 *1 (-677 *3 *2 *4)) (-4 *3 (-1047)) (-4 *2 (-375 *3)) (-4 *4 (-375 *3)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) (-2597 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (-4 *2 (-558)))) (-1781 (*1 *1 *1 *2) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (-4 *2 (-365)))) (-3912 (*1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (-4 *2 (-301)))) (-4063 (*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-4 *3 (-301)) (-5 *2 (-634 *5)))) (-2371 (*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-4 *3 (-558)) (-5 *2 (-763)))) (-3344 (*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-4 *3 (-558)) (-5 *2 (-763)))) (-2934 (*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-4 *3 (-558)) (-5 *2 (-634 *5)))) (-2591 (*1 *2 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (|has| *2 (-6 (-4523 "*"))) (-4 *2 (-1047)))) (-2424 (*1 *2 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (|has| *2 (-6 (-4523 "*"))) (-4 *2 (-1047)))) (-3102 (*1 *2 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (-4 *2 (-1047)) (-4 *2 (-172)))) (-2715 (*1 *1 *1) (|partial| -12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (-4 *2 (-365)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-4 *3 (-365))))) 
+(-13 (-62 |t#1| |t#2| |t#3|) (-10 -8 (-6 -4522) (-6 -4521) (-15 -3691 ((-121) $)) (-15 -4322 ((-121) $)) (-15 -3560 ((-121) $)) (-15 -2675 ((-121) $)) (-15 -3207 ($ (-763) (-763))) (-15 -2271 ($ (-634 (-634 |t#1|)))) (-15 -1637 ($ (-763) |t#1|)) (-15 -3499 ($ (-634 |t#1|))) (-15 -3499 ($ (-634 $))) (-15 -2747 ($ |t#3|)) (-15 -4089 ($ |t#2|)) (-15 -4089 ($ $)) (-15 -4467 ($ $)) (-15 -4018 ($ $ $)) (-15 -4486 ($ $ $)) (-15 -1843 ((-634 (-634 |t#1|)) $)) (-15 -2781 ($ $ (-634 (-568)) (-634 (-568)))) (-15 -2438 ($ $ (-634 (-568)) (-634 (-568)) $)) (-15 -3211 ($ $ (-568) (-568))) (-15 -3096 ($ $ (-568) (-568))) (-15 -2265 ($ $ (-568) (-568) (-568) (-568))) (-15 -4043 ($ $ (-568) (-568) $)) (-15 -1769 ($ $ $)) (-15 -1775 ($ $ $)) (-15 -1775 ($ $)) (-15 * ($ $ $)) (-15 * ($ |t#1| $)) (-15 * ($ $ |t#1|)) (-15 * ($ (-568) $)) (-15 * (|t#3| $ |t#3|)) (-15 * (|t#2| |t#2| $)) (-15 ** ($ $ (-763))) (IF (|has| |t#1| (-558)) (-15 -2597 ((-3 $ "failed") $ |t#1|)) |noBranch|) (IF (|has| |t#1| (-365)) (-15 -1781 ($ $ |t#1|)) |noBranch|) (IF (|has| |t#1| (-301)) (PROGN (-15 -3912 ($ $)) (-15 -4063 ((-634 |t#3|) $))) |noBranch|) (IF (|has| |t#1| (-558)) (PROGN (-15 -2371 ((-763) $)) (-15 -3344 ((-763) $)) (-15 -2934 ((-634 |t#3|) $))) |noBranch|) (IF (|has| |t#1| (-6 (-4523 "*"))) (PROGN (-15 -2591 (|t#1| $)) (-15 -2424 (|t#1| $))) |noBranch|) (IF (|has| |t#1| (-172)) (-15 -3102 (|t#1| $)) |noBranch|) (IF (|has| |t#1| (-365)) (PROGN (-15 -2715 ((-3 $ "failed") $)) (-15 ** ($ $ (-568)))) |noBranch|))) 
 (((-39) . T) ((-105) |has| |#1| (-1090)) ((-608 (-850)) |has| |#1| (-1090)) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-1090) |has| |#1| (-1090)) ((-62 |#1| |#2| |#3|) . T) ((-1195) . T)) 
-((-4167 ((|#4| |#4|) 67 (|has| |#1| (-301)))) (-3700 (((-763) |#4|) 69 (|has| |#1| (-558)))) (-2121 (((-763) |#4|) 71 (|has| |#1| (-558)))) (-4272 (((-634 |#3|) |#4|) 78 (|has| |#1| (-558)))) (-4045 (((-2 (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1|) 95 (|has| |#1| (-301)))) (-3082 ((|#1| |#4|) 33)) (-3255 (((-3 |#4| "failed") |#4|) 61 (|has| |#1| (-558)))) (-3140 (((-3 |#4| "failed") |#4|) 75 (|has| |#1| (-365)))) (-1628 ((|#4| |#4|) 54 (|has| |#1| (-558)))) (-2584 ((|#4| |#4| |#1| (-568) (-568)) 41)) (-1920 ((|#4| |#4| (-568) (-568)) 36)) (-1528 ((|#4| |#4| |#1| (-568) (-568)) 46)) (-2465 ((|#1| |#4|) 73)) (-4391 (((-2 (|:| |adjMat| |#4|) (|:| |detMat| |#1|)) |#4|) 57 (|has| |#1| (-558))))) 
-(((-678 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2465 (|#1| |#4|)) (-15 -3082 (|#1| |#4|)) (-15 -1920 (|#4| |#4| (-568) (-568))) (-15 -2584 (|#4| |#4| |#1| (-568) (-568))) (-15 -1528 (|#4| |#4| |#1| (-568) (-568))) (IF (|has| |#1| (-558)) (PROGN (-15 -3700 ((-763) |#4|)) (-15 -2121 ((-763) |#4|)) (-15 -4272 ((-634 |#3|) |#4|)) (-15 -1628 (|#4| |#4|)) (-15 -3255 ((-3 |#4| "failed") |#4|)) (-15 -4391 ((-2 (|:| |adjMat| |#4|) (|:| |detMat| |#1|)) |#4|))) |noBranch|) (IF (|has| |#1| (-301)) (PROGN (-15 -4167 (|#4| |#4|)) (-15 -4045 ((-2 (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1|))) |noBranch|) (IF (|has| |#1| (-365)) (-15 -3140 ((-3 |#4| "failed") |#4|)) |noBranch|)) (-172) (-375 |#1|) (-375 |#1|) (-677 |#1| |#2| |#3|)) (T -678)) 
-((-3140 (*1 *2 *2) (|partial| -12 (-4 *3 (-365)) (-4 *3 (-172)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-678 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) (-4045 (*1 *2 *3 *3) (-12 (-4 *3 (-301)) (-4 *3 (-172)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-2 (|:| -3961 *3) (|:| -1500 *3))) (-5 *1 (-678 *3 *4 *5 *6)) (-4 *6 (-677 *3 *4 *5)))) (-4167 (*1 *2 *2) (-12 (-4 *3 (-301)) (-4 *3 (-172)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-678 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) (-4391 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *4 (-172)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-2 (|:| |adjMat| *3) (|:| |detMat| *4))) (-5 *1 (-678 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) (-3255 (*1 *2 *2) (|partial| -12 (-4 *3 (-558)) (-4 *3 (-172)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-678 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) (-1628 (*1 *2 *2) (-12 (-4 *3 (-558)) (-4 *3 (-172)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-678 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) (-4272 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *4 (-172)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-634 *6)) (-5 *1 (-678 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) (-2121 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *4 (-172)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-763)) (-5 *1 (-678 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) (-3700 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *4 (-172)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-763)) (-5 *1 (-678 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) (-1528 (*1 *2 *2 *3 *4 *4) (-12 (-5 *4 (-568)) (-4 *3 (-172)) (-4 *5 (-375 *3)) (-4 *6 (-375 *3)) (-5 *1 (-678 *3 *5 *6 *2)) (-4 *2 (-677 *3 *5 *6)))) (-2584 (*1 *2 *2 *3 *4 *4) (-12 (-5 *4 (-568)) (-4 *3 (-172)) (-4 *5 (-375 *3)) (-4 *6 (-375 *3)) (-5 *1 (-678 *3 *5 *6 *2)) (-4 *2 (-677 *3 *5 *6)))) (-1920 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-568)) (-4 *4 (-172)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *1 (-678 *4 *5 *6 *2)) (-4 *2 (-677 *4 *5 *6)))) (-3082 (*1 *2 *3) (-12 (-4 *4 (-375 *2)) (-4 *5 (-375 *2)) (-4 *2 (-172)) (-5 *1 (-678 *2 *4 *5 *3)) (-4 *3 (-677 *2 *4 *5)))) (-2465 (*1 *2 *3) (-12 (-4 *4 (-375 *2)) (-4 *5 (-375 *2)) (-4 *2 (-172)) (-5 *1 (-678 *2 *4 *5 *3)) (-4 *3 (-677 *2 *4 *5))))) 
-(-10 -7 (-15 -2465 (|#1| |#4|)) (-15 -3082 (|#1| |#4|)) (-15 -1920 (|#4| |#4| (-568) (-568))) (-15 -2584 (|#4| |#4| |#1| (-568) (-568))) (-15 -1528 (|#4| |#4| |#1| (-568) (-568))) (IF (|has| |#1| (-558)) (PROGN (-15 -3700 ((-763) |#4|)) (-15 -2121 ((-763) |#4|)) (-15 -4272 ((-634 |#3|) |#4|)) (-15 -1628 (|#4| |#4|)) (-15 -3255 ((-3 |#4| "failed") |#4|)) (-15 -4391 ((-2 (|:| |adjMat| |#4|) (|:| |detMat| |#1|)) |#4|))) |noBranch|) (IF (|has| |#1| (-301)) (PROGN (-15 -4167 (|#4| |#4|)) (-15 -4045 ((-2 (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1|))) |noBranch|) (IF (|has| |#1| (-365)) (-15 -3140 ((-3 |#4| "failed") |#4|)) |noBranch|)) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3205 (($ (-763) (-763)) 45)) (-3347 (($ $ $) NIL)) (-2870 (($ (-1244 |#1|)) NIL) (($ $) NIL)) (-1335 (((-121) $) NIL)) (-4343 (($ $ (-568) (-568)) 12)) (-3622 (($ $ (-568) (-568)) NIL)) (-3676 (($ $ (-568) (-568) (-568) (-568)) NIL)) (-3976 (($ $) NIL)) (-2230 (((-121) $) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-1785 (($ $ (-568) (-568) $) NIL)) (-2436 ((|#1| $ (-568) (-568) |#1|) NIL) (($ $ (-634 (-568)) (-634 (-568)) $) NIL)) (-4159 (($ $ (-568) (-1244 |#1|)) NIL)) (-2451 (($ $ (-568) (-1244 |#1|)) NIL)) (-3422 (($ (-763) |#1|) 22)) (-2671 (($) NIL T CONST)) (-4167 (($ $) 30 (|has| |#1| (-301)))) (-1818 (((-1244 |#1|) $ (-568)) NIL)) (-3700 (((-763) $) 32 (|has| |#1| (-558)))) (-3989 ((|#1| $ (-568) (-568) |#1|) 50)) (-2602 ((|#1| $ (-568) (-568)) NIL)) (-2076 ((|#1| $) NIL (|has| |#1| (-172)))) (-4360 (((-634 |#1|) $) NIL)) (-2121 (((-763) $) 34 (|has| |#1| (-558)))) (-4272 (((-634 (-1244 |#1|)) $) 37 (|has| |#1| (-558)))) (-3043 (((-763) $) 20)) (-1849 (($ (-763) (-763) |#1|) NIL)) (-2555 (((-763) $) 21)) (-1737 (((-121) $ (-763)) NIL)) (-3082 ((|#1| $) 28 (|has| |#1| (-6 (-4521 "*"))))) (-2087 (((-568) $) 9)) (-3364 (((-568) $) 10)) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-1663 (((-568) $) 11)) (-2893 (((-568) $) 46)) (-2269 (($ (-634 (-634 |#1|))) NIL)) (-3674 (($ (-1 |#1| |#1|) $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-3208 (((-634 (-634 |#1|)) $) 58)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-3140 (((-3 $ "failed") $) 41 (|has| |#1| (-365)))) (-2858 (($ $ $) NIL)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3724 (($ $ |#1|) NIL)) (-2595 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558)))) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#1| $ (-568) (-568)) NIL) ((|#1| $ (-568) (-568) |#1|) NIL) (($ $ (-634 (-568)) (-634 (-568))) NIL)) (-2282 (($ (-634 |#1|)) NIL) (($ (-634 $)) NIL) (($ (-1244 |#1|)) 51)) (-1960 (((-121) $) NIL)) (-2465 ((|#1| $) 26 (|has| |#1| (-6 (-4521 "*"))))) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) NIL)) (-4278 (((-541) $) 62 (|has| |#1| (-609 (-541))))) (-2365 (((-634 (-1244 |#1|)) $) NIL (|has| |#1| (-301)))) (-3731 (((-1244 |#1|) $ (-568)) NIL)) (-2745 (((-850) $) NIL (|has| |#1| (-1090))) (($ (-1244 |#1|)) NIL)) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1910 (((-121) $) NIL)) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1773 (($ $ $) NIL) (($ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-763)) 23) (($ $ (-568)) 44 (|has| |#1| (-365)))) (* (($ $ $) 13) (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ (-568) $) NIL) (((-1244 |#1|) $ (-1244 |#1|)) NIL) (((-1244 |#1|) (-1244 |#1|) $) NIL)) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-679 |#1|) (-13 (-677 |#1| (-1244 |#1|) (-1244 |#1|)) (-10 -8 (-15 -2282 ($ (-1244 |#1|))) (IF (|has| |#1| (-609 (-541))) (-6 (-609 (-541))) |noBranch|) (IF (|has| |#1| (-365)) (-15 -3140 ((-3 $ "failed") $)) |noBranch|))) (-1047)) (T -679)) 
-((-3140 (*1 *1 *1) (|partial| -12 (-5 *1 (-679 *2)) (-4 *2 (-365)) (-4 *2 (-1047)))) (-2282 (*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-1047)) (-5 *1 (-679 *3))))) 
-(-13 (-677 |#1| (-1244 |#1|) (-1244 |#1|)) (-10 -8 (-15 -2282 ($ (-1244 |#1|))) (IF (|has| |#1| (-609 (-541))) (-6 (-609 (-541))) |noBranch|) (IF (|has| |#1| (-365)) (-15 -3140 ((-3 $ "failed") $)) |noBranch|))) 
-((-2998 (((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|)) 25)) (-3410 (((-679 |#1|) (-679 |#1|) (-679 |#1|) |#1|) 21)) (-4483 (((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|) (-763)) 26)) (-2151 (((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|)) 14)) (-3835 (((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|)) 18) (((-679 |#1|) (-679 |#1|) (-679 |#1|)) 16)) (-3184 (((-679 |#1|) (-679 |#1|) |#1| (-679 |#1|)) 20)) (-3489 (((-679 |#1|) (-679 |#1|) (-679 |#1|)) 12)) (** (((-679 |#1|) (-679 |#1|) (-763)) 30))) 
-(((-680 |#1|) (-10 -7 (-15 -3489 ((-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -2151 ((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -3835 ((-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -3835 ((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -3184 ((-679 |#1|) (-679 |#1|) |#1| (-679 |#1|))) (-15 -3410 ((-679 |#1|) (-679 |#1|) (-679 |#1|) |#1|)) (-15 -2998 ((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -4483 ((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|) (-763))) (-15 ** ((-679 |#1|) (-679 |#1|) (-763)))) (-1047)) (T -680)) 
-((** (*1 *2 *2 *3) (-12 (-5 *2 (-679 *4)) (-5 *3 (-763)) (-4 *4 (-1047)) (-5 *1 (-680 *4)))) (-4483 (*1 *2 *2 *2 *2 *2 *3) (-12 (-5 *2 (-679 *4)) (-5 *3 (-763)) (-4 *4 (-1047)) (-5 *1 (-680 *4)))) (-2998 (*1 *2 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3)))) (-3410 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3)))) (-3184 (*1 *2 *2 *3 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3)))) (-3835 (*1 *2 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3)))) (-3835 (*1 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3)))) (-2151 (*1 *2 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3)))) (-3489 (*1 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3))))) 
-(-10 -7 (-15 -3489 ((-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -2151 ((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -3835 ((-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -3835 ((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -3184 ((-679 |#1|) (-679 |#1|) |#1| (-679 |#1|))) (-15 -3410 ((-679 |#1|) (-679 |#1|) (-679 |#1|) |#1|)) (-15 -2998 ((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -4483 ((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|) (-763))) (-15 ** ((-679 |#1|) (-679 |#1|) (-763)))) 
-((-1426 ((|#2| |#2| |#4|) 25)) (-3147 (((-679 |#2|) |#3| |#4|) 31)) (-4142 (((-679 |#2|) |#2| |#4|) 30)) (-1842 (((-1244 |#2|) |#2| |#4|) 16)) (-2982 ((|#2| |#3| |#4|) 24)) (-4392 (((-679 |#2|) |#3| |#4| (-763) (-763)) 38)) (-4152 (((-679 |#2|) |#2| |#4| (-763)) 37))) 
-(((-681 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1842 ((-1244 |#2|) |#2| |#4|)) (-15 -2982 (|#2| |#3| |#4|)) (-15 -1426 (|#2| |#2| |#4|)) (-15 -4142 ((-679 |#2|) |#2| |#4|)) (-15 -4152 ((-679 |#2|) |#2| |#4| (-763))) (-15 -3147 ((-679 |#2|) |#3| |#4|)) (-15 -4392 ((-679 |#2|) |#3| |#4| (-763) (-763)))) (-1090) (-895 |#1|) (-375 |#2|) (-13 (-375 |#1|) (-10 -7 (-6 -4519)))) (T -681)) 
-((-4392 (*1 *2 *3 *4 *5 *5) (-12 (-5 *5 (-763)) (-4 *6 (-1090)) (-4 *7 (-895 *6)) (-5 *2 (-679 *7)) (-5 *1 (-681 *6 *7 *3 *4)) (-4 *3 (-375 *7)) (-4 *4 (-13 (-375 *6) (-10 -7 (-6 -4519)))))) (-3147 (*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-4 *6 (-895 *5)) (-5 *2 (-679 *6)) (-5 *1 (-681 *5 *6 *3 *4)) (-4 *3 (-375 *6)) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4519)))))) (-4152 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-763)) (-4 *6 (-1090)) (-4 *3 (-895 *6)) (-5 *2 (-679 *3)) (-5 *1 (-681 *6 *3 *7 *4)) (-4 *7 (-375 *3)) (-4 *4 (-13 (-375 *6) (-10 -7 (-6 -4519)))))) (-4142 (*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-4 *3 (-895 *5)) (-5 *2 (-679 *3)) (-5 *1 (-681 *5 *3 *6 *4)) (-4 *6 (-375 *3)) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4519)))))) (-1426 (*1 *2 *2 *3) (-12 (-4 *4 (-1090)) (-4 *2 (-895 *4)) (-5 *1 (-681 *4 *2 *5 *3)) (-4 *5 (-375 *2)) (-4 *3 (-13 (-375 *4) (-10 -7 (-6 -4519)))))) (-2982 (*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-4 *2 (-895 *5)) (-5 *1 (-681 *5 *2 *3 *4)) (-4 *3 (-375 *2)) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4519)))))) (-1842 (*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-4 *3 (-895 *5)) (-5 *2 (-1244 *3)) (-5 *1 (-681 *5 *3 *6 *4)) (-4 *6 (-375 *3)) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4519))))))) 
-(-10 -7 (-15 -1842 ((-1244 |#2|) |#2| |#4|)) (-15 -2982 (|#2| |#3| |#4|)) (-15 -1426 (|#2| |#2| |#4|)) (-15 -4142 ((-679 |#2|) |#2| |#4|)) (-15 -4152 ((-679 |#2|) |#2| |#4| (-763))) (-15 -3147 ((-679 |#2|) |#3| |#4|)) (-15 -4392 ((-679 |#2|) |#3| |#4| (-763) (-763)))) 
-((-4114 (((-2 (|:| |num| (-679 |#1|)) (|:| |den| |#1|)) (-679 |#2|)) 18)) (-3093 ((|#1| (-679 |#2|)) 9)) (-2469 (((-679 |#1|) (-679 |#2|)) 16))) 
-(((-682 |#1| |#2|) (-10 -7 (-15 -3093 (|#1| (-679 |#2|))) (-15 -2469 ((-679 |#1|) (-679 |#2|))) (-15 -4114 ((-2 (|:| |num| (-679 |#1|)) (|:| |den| |#1|)) (-679 |#2|)))) (-558) (-993 |#1|)) (T -682)) 
-((-4114 (*1 *2 *3) (-12 (-5 *3 (-679 *5)) (-4 *5 (-993 *4)) (-4 *4 (-558)) (-5 *2 (-2 (|:| |num| (-679 *4)) (|:| |den| *4))) (-5 *1 (-682 *4 *5)))) (-2469 (*1 *2 *3) (-12 (-5 *3 (-679 *5)) (-4 *5 (-993 *4)) (-4 *4 (-558)) (-5 *2 (-679 *4)) (-5 *1 (-682 *4 *5)))) (-3093 (*1 *2 *3) (-12 (-5 *3 (-679 *4)) (-4 *4 (-993 *2)) (-4 *2 (-558)) (-5 *1 (-682 *2 *4))))) 
-(-10 -7 (-15 -3093 (|#1| (-679 |#2|))) (-15 -2469 ((-679 |#1|) (-679 |#2|))) (-15 -4114 ((-2 (|:| |num| (-679 |#1|)) (|:| |den| |#1|)) (-679 |#2|)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-4255 (((-679 (-688))) NIL) (((-679 (-688)) (-1244 $)) NIL)) (-1932 (((-688) $) NIL)) (-1982 (($ $) NIL (|has| (-688) (-1181)))) (-1933 (($ $) NIL (|has| (-688) (-1181)))) (-3211 (((-1169 (-917) (-763)) (-568)) NIL (|has| (-688) (-350)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-688) (-301)) (|has| (-688) (-904))))) (-4305 (($ $) NIL (-2198 (-12 (|has| (-688) (-301)) (|has| (-688) (-904))) (|has| (-688) (-365))))) (-1678 (((-420 $) $) NIL (-2198 (-12 (|has| (-688) (-301)) (|has| (-688) (-904))) (|has| (-688) (-365))))) (-1902 (($ $) NIL (-12 (|has| (-688) (-1002)) (|has| (-688) (-1181))))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-688) (-301)) (|has| (-688) (-904))))) (-1497 (((-121) $ $) NIL (|has| (-688) (-301)))) (-3983 (((-763)) NIL (|has| (-688) (-370)))) (-1974 (($ $) NIL (|has| (-688) (-1181)))) (-2786 (($ $) NIL (|has| (-688) (-1181)))) (-1990 (($ $) NIL (|has| (-688) (-1181)))) (-1941 (($ $) NIL (|has| (-688) (-1181)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) NIL) (((-3 (-688) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| (-688) (-1037 (-409 (-568)))))) (-2854 (((-568) $) NIL) (((-688) $) NIL) (((-409 (-568)) $) NIL (|has| (-688) (-1037 (-409 (-568)))))) (-3498 (($ (-1244 (-688))) NIL) (($ (-1244 (-688)) (-1244 $)) NIL)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-688) (-350)))) (-2401 (($ $ $) NIL (|has| (-688) (-301)))) (-1709 (((-679 (-688)) $) NIL) (((-679 (-688)) $ (-1244 $)) NIL)) (-3164 (((-679 (-688)) (-679 $)) NIL) (((-2 (|:| -2928 (-679 (-688))) (|:| |vec| (-1244 (-688)))) (-679 $) (-1244 $)) NIL) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| (-688) (-630 (-568)))) (((-679 (-568)) (-679 $)) NIL (|has| (-688) (-630 (-568))))) (-3092 (((-3 $ "failed") (-409 (-1157 (-688)))) NIL (|has| (-688) (-365))) (($ (-1157 (-688))) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3857 (((-688) $) 29)) (-1642 (((-3 (-409 (-568)) "failed") $) NIL (|has| (-688) (-550)))) (-2688 (((-121) $) NIL (|has| (-688) (-550)))) (-2425 (((-409 (-568)) $) NIL (|has| (-688) (-550)))) (-3700 (((-917)) NIL)) (-1731 (($) NIL (|has| (-688) (-370)))) (-2412 (($ $ $) NIL (|has| (-688) (-301)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| (-688) (-301)))) (-4220 (($) NIL (|has| (-688) (-350)))) (-4456 (((-121) $) NIL (|has| (-688) (-350)))) (-3218 (($ $) NIL (|has| (-688) (-350))) (($ $ (-763)) NIL (|has| (-688) (-350)))) (-3927 (((-121) $) NIL (-2198 (-12 (|has| (-688) (-301)) (|has| (-688) (-904))) (|has| (-688) (-365))))) (-3378 (((-2 (|:| |r| (-688)) (|:| |phi| (-688))) $) NIL (-12 (|has| (-688) (-1056)) (|has| (-688) (-1181))))) (-1897 (($) NIL (|has| (-688) (-1181)))) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| (-688) (-881 (-381)))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| (-688) (-881 (-568))))) (-4477 (((-828 (-917)) $) NIL (|has| (-688) (-350))) (((-917) $) NIL (|has| (-688) (-350)))) (-2735 (((-121) $) NIL)) (-4044 (($ $ (-568)) NIL (-12 (|has| (-688) (-1002)) (|has| (-688) (-1181))))) (-2657 (((-688) $) NIL)) (-3038 (((-3 $ "failed") $) NIL (|has| (-688) (-350)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| (-688) (-301)))) (-2045 (((-1157 (-688)) $) NIL (|has| (-688) (-365)))) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-2795 (($ (-1 (-688) (-688)) $) NIL)) (-3683 (((-917) $) NIL (|has| (-688) (-370)))) (-4416 (($ $) NIL (|has| (-688) (-1181)))) (-3085 (((-1157 (-688)) $) NIL)) (-2495 (($ (-634 $)) NIL (|has| (-688) (-301))) (($ $ $) NIL (|has| (-688) (-301)))) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL (|has| (-688) (-365)))) (-4434 (($) NIL (|has| (-688) (-350)) CONST)) (-4355 (($ (-917)) NIL (|has| (-688) (-370)))) (-3777 (($) NIL)) (-3866 (((-688) $) 31)) (-4022 (((-1108) $) NIL)) (-2704 (($) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| (-688) (-301)))) (-2721 (($ (-634 $)) NIL (|has| (-688) (-301))) (($ $ $) NIL (|has| (-688) (-301)))) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) NIL (|has| (-688) (-350)))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-688) (-301)) (|has| (-688) (-904))))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-688) (-301)) (|has| (-688) (-904))))) (-3848 (((-420 $) $) NIL (-2198 (-12 (|has| (-688) (-301)) (|has| (-688) (-904))) (|has| (-688) (-365))))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| (-688) (-301))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| (-688) (-301)))) (-2595 (((-3 $ "failed") $ $) NIL) (((-3 $ "failed") $ (-688)) NIL (|has| (-688) (-558)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| (-688) (-301)))) (-1892 (($ $) NIL (|has| (-688) (-1181)))) (-1339 (($ $ (-1161) (-688)) NIL (|has| (-688) (-523 (-1161) (-688)))) (($ $ (-634 (-1161)) (-634 (-688))) NIL (|has| (-688) (-523 (-1161) (-688)))) (($ $ (-634 (-288 (-688)))) NIL (|has| (-688) (-303 (-688)))) (($ $ (-288 (-688))) NIL (|has| (-688) (-303 (-688)))) (($ $ (-688) (-688)) NIL (|has| (-688) (-303 (-688)))) (($ $ (-634 (-688)) (-634 (-688))) NIL (|has| (-688) (-303 (-688))))) (-2709 (((-763) $) NIL (|has| (-688) (-301)))) (-2779 (($ $ (-688)) NIL (|has| (-688) (-281 (-688) (-688))))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| (-688) (-301)))) (-2217 (((-688)) NIL) (((-688) (-1244 $)) NIL)) (-3143 (((-3 (-763) "failed") $ $) NIL (|has| (-688) (-350))) (((-763) $) NIL (|has| (-688) (-350)))) (-4189 (($ $ (-1 (-688) (-688))) NIL) (($ $ (-1 (-688) (-688)) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-688) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-688) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-688) (-895 (-1161)))) (($ $ (-1161)) NIL (|has| (-688) (-895 (-1161)))) (($ $ (-763)) NIL (|has| (-688) (-225))) (($ $) NIL (|has| (-688) (-225)))) (-4387 (((-679 (-688)) (-1244 $) (-1 (-688) (-688))) NIL (|has| (-688) (-365)))) (-1626 (((-1157 (-688))) NIL)) (-1994 (($ $) NIL (|has| (-688) (-1181)))) (-1945 (($ $) NIL (|has| (-688) (-1181)))) (-3065 (($) NIL (|has| (-688) (-350)))) (-1986 (($ $) NIL (|has| (-688) (-1181)))) (-1937 (($ $) NIL (|has| (-688) (-1181)))) (-1978 (($ $) NIL (|has| (-688) (-1181)))) (-2790 (($ $) NIL (|has| (-688) (-1181)))) (-4073 (((-679 (-688)) (-1244 $)) NIL) (((-1244 (-688)) $) NIL) (((-679 (-688)) (-1244 $) (-1244 $)) NIL) (((-1244 (-688)) $ (-1244 $)) NIL)) (-4278 (((-541) $) NIL (|has| (-688) (-609 (-541)))) (((-169 (-215)) $) NIL (|has| (-688) (-1021))) (((-169 (-381)) $) NIL (|has| (-688) (-1021))) (((-887 (-381)) $) NIL (|has| (-688) (-609 (-887 (-381))))) (((-887 (-568)) $) NIL (|has| (-688) (-609 (-887 (-568))))) (($ (-1157 (-688))) NIL) (((-1157 (-688)) $) NIL) (($ (-1244 (-688))) NIL) (((-1244 (-688)) $) NIL)) (-1458 (($ $) NIL)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-2198 (-12 (|has| $ (-148)) (|has| (-688) (-301)) (|has| (-688) (-904))) (|has| (-688) (-350))))) (-4003 (($ (-688) (-688)) 12)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-568)) NIL) (($ (-688)) NIL) (($ (-169 (-381))) 13) (($ (-169 (-568))) 19) (($ (-169 (-688))) 28) (($ (-169 (-690))) 25) (((-169 (-381)) $) 33) (($ (-409 (-568))) NIL (-2198 (|has| (-688) (-365)) (|has| (-688) (-1037 (-409 (-568))))))) (-4371 (($ $) NIL (|has| (-688) (-350))) (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| (-688) (-301)) (|has| (-688) (-904))) (|has| (-688) (-148))))) (-2678 (((-1157 (-688)) $) NIL)) (-4078 (((-763)) NIL)) (-3746 (((-1244 $)) NIL)) (-2006 (($ $) NIL (|has| (-688) (-1181)))) (-1958 (($ $) NIL (|has| (-688) (-1181)))) (-1826 (((-121) $ $) NIL)) (-1998 (($ $) NIL (|has| (-688) (-1181)))) (-1949 (($ $) NIL (|has| (-688) (-1181)))) (-2014 (($ $) NIL (|has| (-688) (-1181)))) (-1966 (($ $) NIL (|has| (-688) (-1181)))) (-3256 (((-688) $) NIL (|has| (-688) (-1181)))) (-4023 (($ $) NIL (|has| (-688) (-1181)))) (-1970 (($ $) NIL (|has| (-688) (-1181)))) (-2010 (($ $) NIL (|has| (-688) (-1181)))) (-1962 (($ $) NIL (|has| (-688) (-1181)))) (-2002 (($ $) NIL (|has| (-688) (-1181)))) (-1953 (($ $) NIL (|has| (-688) (-1181)))) (-2897 (($ $) NIL (|has| (-688) (-1056)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| (-688) (-365)))) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $ (-1 (-688) (-688))) NIL) (($ $ (-1 (-688) (-688)) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-688) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-688) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-688) (-895 (-1161)))) (($ $ (-1161)) NIL (|has| (-688) (-895 (-1161)))) (($ $ (-763)) NIL (|has| (-688) (-225))) (($ $) NIL (|has| (-688) (-225)))) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) NIL)) (-1779 (($ $ $) NIL (|has| (-688) (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ $) NIL (|has| (-688) (-1181))) (($ $ (-409 (-568))) NIL (-12 (|has| (-688) (-1002)) (|has| (-688) (-1181)))) (($ $ (-568)) NIL (|has| (-688) (-365)))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ (-688) $) NIL) (($ $ (-688)) NIL) (($ (-409 (-568)) $) NIL (|has| (-688) (-365))) (($ $ (-409 (-568))) NIL (|has| (-688) (-365))))) 
-(((-683) (-13 (-389) (-166 (-688)) (-10 -8 (-15 -2745 ($ (-169 (-381)))) (-15 -2745 ($ (-169 (-568)))) (-15 -2745 ($ (-169 (-688)))) (-15 -2745 ($ (-169 (-690)))) (-15 -2745 ((-169 (-381)) $))))) (T -683)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-169 (-381))) (-5 *1 (-683)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-169 (-568))) (-5 *1 (-683)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-169 (-688))) (-5 *1 (-683)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-169 (-690))) (-5 *1 (-683)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-169 (-381))) (-5 *1 (-683))))) 
-(-13 (-389) (-166 (-688)) (-10 -8 (-15 -2745 ($ (-169 (-381)))) (-15 -2745 ($ (-169 (-568)))) (-15 -2745 ($ (-169 (-688)))) (-15 -2745 ($ (-169 (-690)))) (-15 -2745 ((-169 (-381)) $)))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2510 (((-121) $ (-763)) 8)) (-3507 (($ (-1 (-121) |#1|) $) 42 (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) |#1|) $) 52 (|has| $ (-6 -4519)))) (-2671 (($) 7 T CONST)) (-3369 (($ $) 58)) (-3924 (($ $) 55 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3405 (($ |#1| $) 44 (|has| $ (-6 -4519))) (($ (-1 (-121) |#1|) $) 43 (|has| $ (-6 -4519)))) (-4328 (($ |#1| $) 54 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) |#1|) $) 51 (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4519)))) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) 9)) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35)) (-2166 (((-121) $ (-763)) 10)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-1890 ((|#1| $) 36)) (-4450 (($ |#1| $) 37) (($ |#1| $ (-763)) 59)) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 48)) (-1315 ((|#1| $) 38)) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-1799 (((-634 (-2 (|:| -4083 |#1|) (|:| -4168 (-763)))) $) 57)) (-2085 (($) 46) (($ (-634 |#1|)) 45)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-4278 (((-541) $) 56 (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) 47)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-2367 (($ (-634 |#1|)) 39)) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-3912 ((|#4| |#4|) 67 (|has| |#1| (-301)))) (-2371 (((-763) |#4|) 69 (|has| |#1| (-558)))) (-3344 (((-763) |#4|) 71 (|has| |#1| (-558)))) (-2934 (((-634 |#3|) |#4|) 78 (|has| |#1| (-558)))) (-1555 (((-2 (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1|) 95 (|has| |#1| (-301)))) (-2424 ((|#1| |#4|) 33)) (-2010 (((-3 |#4| "failed") |#4|) 61 (|has| |#1| (-558)))) (-2715 (((-3 |#4| "failed") |#4|) 75 (|has| |#1| (-365)))) (-1504 ((|#4| |#4|) 54 (|has| |#1| (-558)))) (-2017 ((|#4| |#4| |#1| (-568) (-568)) 41)) (-2713 ((|#4| |#4| (-568) (-568)) 36)) (-4163 ((|#4| |#4| |#1| (-568) (-568)) 46)) (-2591 ((|#1| |#4|) 73)) (-1419 (((-2 (|:| |adjMat| |#4|) (|:| |detMat| |#1|)) |#4|) 57 (|has| |#1| (-558))))) 
+(((-678 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2591 (|#1| |#4|)) (-15 -2424 (|#1| |#4|)) (-15 -2713 (|#4| |#4| (-568) (-568))) (-15 -2017 (|#4| |#4| |#1| (-568) (-568))) (-15 -4163 (|#4| |#4| |#1| (-568) (-568))) (IF (|has| |#1| (-558)) (PROGN (-15 -2371 ((-763) |#4|)) (-15 -3344 ((-763) |#4|)) (-15 -2934 ((-634 |#3|) |#4|)) (-15 -1504 (|#4| |#4|)) (-15 -2010 ((-3 |#4| "failed") |#4|)) (-15 -1419 ((-2 (|:| |adjMat| |#4|) (|:| |detMat| |#1|)) |#4|))) |noBranch|) (IF (|has| |#1| (-301)) (PROGN (-15 -3912 (|#4| |#4|)) (-15 -1555 ((-2 (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1|))) |noBranch|) (IF (|has| |#1| (-365)) (-15 -2715 ((-3 |#4| "failed") |#4|)) |noBranch|)) (-172) (-375 |#1|) (-375 |#1|) (-677 |#1| |#2| |#3|)) (T -678)) 
+((-2715 (*1 *2 *2) (|partial| -12 (-4 *3 (-365)) (-4 *3 (-172)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-678 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) (-1555 (*1 *2 *3 *3) (-12 (-4 *3 (-301)) (-4 *3 (-172)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-2 (|:| -4409 *3) (|:| -2607 *3))) (-5 *1 (-678 *3 *4 *5 *6)) (-4 *6 (-677 *3 *4 *5)))) (-3912 (*1 *2 *2) (-12 (-4 *3 (-301)) (-4 *3 (-172)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-678 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) (-1419 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *4 (-172)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-2 (|:| |adjMat| *3) (|:| |detMat| *4))) (-5 *1 (-678 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) (-2010 (*1 *2 *2) (|partial| -12 (-4 *3 (-558)) (-4 *3 (-172)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-678 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) (-1504 (*1 *2 *2) (-12 (-4 *3 (-558)) (-4 *3 (-172)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-678 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) (-2934 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *4 (-172)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-634 *6)) (-5 *1 (-678 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) (-3344 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *4 (-172)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-763)) (-5 *1 (-678 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) (-2371 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *4 (-172)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-763)) (-5 *1 (-678 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) (-4163 (*1 *2 *2 *3 *4 *4) (-12 (-5 *4 (-568)) (-4 *3 (-172)) (-4 *5 (-375 *3)) (-4 *6 (-375 *3)) (-5 *1 (-678 *3 *5 *6 *2)) (-4 *2 (-677 *3 *5 *6)))) (-2017 (*1 *2 *2 *3 *4 *4) (-12 (-5 *4 (-568)) (-4 *3 (-172)) (-4 *5 (-375 *3)) (-4 *6 (-375 *3)) (-5 *1 (-678 *3 *5 *6 *2)) (-4 *2 (-677 *3 *5 *6)))) (-2713 (*1 *2 *2 *3 *3) (-12 (-5 *3 (-568)) (-4 *4 (-172)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *1 (-678 *4 *5 *6 *2)) (-4 *2 (-677 *4 *5 *6)))) (-2424 (*1 *2 *3) (-12 (-4 *4 (-375 *2)) (-4 *5 (-375 *2)) (-4 *2 (-172)) (-5 *1 (-678 *2 *4 *5 *3)) (-4 *3 (-677 *2 *4 *5)))) (-2591 (*1 *2 *3) (-12 (-4 *4 (-375 *2)) (-4 *5 (-375 *2)) (-4 *2 (-172)) (-5 *1 (-678 *2 *4 *5 *3)) (-4 *3 (-677 *2 *4 *5))))) 
+(-10 -7 (-15 -2591 (|#1| |#4|)) (-15 -2424 (|#1| |#4|)) (-15 -2713 (|#4| |#4| (-568) (-568))) (-15 -2017 (|#4| |#4| |#1| (-568) (-568))) (-15 -4163 (|#4| |#4| |#1| (-568) (-568))) (IF (|has| |#1| (-558)) (PROGN (-15 -2371 ((-763) |#4|)) (-15 -3344 ((-763) |#4|)) (-15 -2934 ((-634 |#3|) |#4|)) (-15 -1504 (|#4| |#4|)) (-15 -2010 ((-3 |#4| "failed") |#4|)) (-15 -1419 ((-2 (|:| |adjMat| |#4|) (|:| |detMat| |#1|)) |#4|))) |noBranch|) (IF (|has| |#1| (-301)) (PROGN (-15 -3912 (|#4| |#4|)) (-15 -1555 ((-2 (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1|))) |noBranch|) (IF (|has| |#1| (-365)) (-15 -2715 ((-3 |#4| "failed") |#4|)) |noBranch|)) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3207 (($ (-763) (-763)) 45)) (-4486 (($ $ $) NIL)) (-4089 (($ (-1244 |#1|)) NIL) (($ $) NIL)) (-3560 (((-121) $) NIL)) (-3211 (($ $ (-568) (-568)) 12)) (-3096 (($ $ (-568) (-568)) NIL)) (-2265 (($ $ (-568) (-568) (-568) (-568)) NIL)) (-4467 (($ $) NIL)) (-3691 (((-121) $) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-4043 (($ $ (-568) (-568) $) NIL)) (-2438 ((|#1| $ (-568) (-568) |#1|) NIL) (($ $ (-634 (-568)) (-634 (-568)) $) NIL)) (-3874 (($ $ (-568) (-1244 |#1|)) NIL)) (-2525 (($ $ (-568) (-1244 |#1|)) NIL)) (-1637 (($ (-763) |#1|) 22)) (-4490 (($) NIL T CONST)) (-3912 (($ $) 30 (|has| |#1| (-301)))) (-2228 (((-1244 |#1|) $ (-568)) NIL)) (-2371 (((-763) $) 32 (|has| |#1| (-558)))) (-1292 ((|#1| $ (-568) (-568) |#1|) 50)) (-2069 ((|#1| $ (-568) (-568)) NIL)) (-3102 ((|#1| $) NIL (|has| |#1| (-172)))) (-3317 (((-634 |#1|) $) NIL)) (-3344 (((-763) $) 34 (|has| |#1| (-558)))) (-2934 (((-634 (-1244 |#1|)) $) 37 (|has| |#1| (-558)))) (-2241 (((-763) $) 20)) (-1851 (($ (-763) (-763) |#1|) NIL)) (-1901 (((-763) $) 21)) (-3791 (((-121) $ (-763)) NIL)) (-2424 ((|#1| $) 28 (|has| |#1| (-6 (-4523 "*"))))) (-3139 (((-568) $) 9)) (-1343 (((-568) $) 10)) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3405 (((-568) $) 11)) (-2801 (((-568) $) 46)) (-2271 (($ (-634 (-634 |#1|))) NIL)) (-2253 (($ (-1 |#1| |#1|) $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL) (($ (-1 |#1| |#1| |#1|) $ $ |#1|) NIL)) (-1843 (((-634 (-634 |#1|)) $) 58)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-2715 (((-3 $ "failed") $) 41 (|has| |#1| (-365)))) (-4018 (($ $ $) NIL)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-2490 (($ $ |#1|) NIL)) (-2597 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558)))) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#1| $ (-568) (-568)) NIL) ((|#1| $ (-568) (-568) |#1|) NIL) (($ $ (-634 (-568)) (-634 (-568))) NIL)) (-3499 (($ (-634 |#1|)) NIL) (($ (-634 $)) NIL) (($ (-1244 |#1|)) 51)) (-4322 (((-121) $) NIL)) (-2591 ((|#1| $) 26 (|has| |#1| (-6 (-4523 "*"))))) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) NIL)) (-4280 (((-541) $) 62 (|has| |#1| (-609 (-541))))) (-4063 (((-634 (-1244 |#1|)) $) NIL (|has| |#1| (-301)))) (-2522 (((-1244 |#1|) $ (-568)) NIL)) (-2747 (((-850) $) NIL (|has| |#1| (-1090))) (($ (-1244 |#1|)) NIL)) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-2675 (((-121) $) NIL)) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1775 (($ $ $) NIL) (($ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-763)) 23) (($ $ (-568)) 44 (|has| |#1| (-365)))) (* (($ $ $) 13) (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ (-568) $) NIL) (((-1244 |#1|) $ (-1244 |#1|)) NIL) (((-1244 |#1|) (-1244 |#1|) $) NIL)) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-679 |#1|) (-13 (-677 |#1| (-1244 |#1|) (-1244 |#1|)) (-10 -8 (-15 -3499 ($ (-1244 |#1|))) (IF (|has| |#1| (-609 (-541))) (-6 (-609 (-541))) |noBranch|) (IF (|has| |#1| (-365)) (-15 -2715 ((-3 $ "failed") $)) |noBranch|))) (-1047)) (T -679)) 
+((-2715 (*1 *1 *1) (|partial| -12 (-5 *1 (-679 *2)) (-4 *2 (-365)) (-4 *2 (-1047)))) (-3499 (*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-1047)) (-5 *1 (-679 *3))))) 
+(-13 (-677 |#1| (-1244 |#1|) (-1244 |#1|)) (-10 -8 (-15 -3499 ($ (-1244 |#1|))) (IF (|has| |#1| (-609 (-541))) (-6 (-609 (-541))) |noBranch|) (IF (|has| |#1| (-365)) (-15 -2715 ((-3 $ "failed") $)) |noBranch|))) 
+((-3133 (((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|)) 25)) (-1592 (((-679 |#1|) (-679 |#1|) (-679 |#1|) |#1|) 21)) (-1875 (((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|) (-763)) 26)) (-3573 (((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|)) 14)) (-1834 (((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|)) 18) (((-679 |#1|) (-679 |#1|) (-679 |#1|)) 16)) (-1757 (((-679 |#1|) (-679 |#1|) |#1| (-679 |#1|)) 20)) (-3853 (((-679 |#1|) (-679 |#1|) (-679 |#1|)) 12)) (** (((-679 |#1|) (-679 |#1|) (-763)) 30))) 
+(((-680 |#1|) (-10 -7 (-15 -3853 ((-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -3573 ((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -1834 ((-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -1834 ((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -1757 ((-679 |#1|) (-679 |#1|) |#1| (-679 |#1|))) (-15 -1592 ((-679 |#1|) (-679 |#1|) (-679 |#1|) |#1|)) (-15 -3133 ((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -1875 ((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|) (-763))) (-15 ** ((-679 |#1|) (-679 |#1|) (-763)))) (-1047)) (T -680)) 
+((** (*1 *2 *2 *3) (-12 (-5 *2 (-679 *4)) (-5 *3 (-763)) (-4 *4 (-1047)) (-5 *1 (-680 *4)))) (-1875 (*1 *2 *2 *2 *2 *2 *3) (-12 (-5 *2 (-679 *4)) (-5 *3 (-763)) (-4 *4 (-1047)) (-5 *1 (-680 *4)))) (-3133 (*1 *2 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3)))) (-1592 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3)))) (-1757 (*1 *2 *2 *3 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3)))) (-1834 (*1 *2 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3)))) (-1834 (*1 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3)))) (-3573 (*1 *2 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3)))) (-3853 (*1 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3))))) 
+(-10 -7 (-15 -3853 ((-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -3573 ((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -1834 ((-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -1834 ((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -1757 ((-679 |#1|) (-679 |#1|) |#1| (-679 |#1|))) (-15 -1592 ((-679 |#1|) (-679 |#1|) (-679 |#1|) |#1|)) (-15 -3133 ((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -1875 ((-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|) (-679 |#1|) (-763))) (-15 ** ((-679 |#1|) (-679 |#1|) (-763)))) 
+((-2216 ((|#2| |#2| |#4|) 25)) (-2740 (((-679 |#2|) |#3| |#4|) 31)) (-3769 (((-679 |#2|) |#2| |#4|) 30)) (-2363 (((-1244 |#2|) |#2| |#4|) 16)) (-3078 ((|#2| |#3| |#4|) 24)) (-1425 (((-679 |#2|) |#3| |#4| (-763) (-763)) 38)) (-3831 (((-679 |#2|) |#2| |#4| (-763)) 37))) 
+(((-681 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2363 ((-1244 |#2|) |#2| |#4|)) (-15 -3078 (|#2| |#3| |#4|)) (-15 -2216 (|#2| |#2| |#4|)) (-15 -3769 ((-679 |#2|) |#2| |#4|)) (-15 -3831 ((-679 |#2|) |#2| |#4| (-763))) (-15 -2740 ((-679 |#2|) |#3| |#4|)) (-15 -1425 ((-679 |#2|) |#3| |#4| (-763) (-763)))) (-1090) (-895 |#1|) (-375 |#2|) (-13 (-375 |#1|) (-10 -7 (-6 -4521)))) (T -681)) 
+((-1425 (*1 *2 *3 *4 *5 *5) (-12 (-5 *5 (-763)) (-4 *6 (-1090)) (-4 *7 (-895 *6)) (-5 *2 (-679 *7)) (-5 *1 (-681 *6 *7 *3 *4)) (-4 *3 (-375 *7)) (-4 *4 (-13 (-375 *6) (-10 -7 (-6 -4521)))))) (-2740 (*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-4 *6 (-895 *5)) (-5 *2 (-679 *6)) (-5 *1 (-681 *5 *6 *3 *4)) (-4 *3 (-375 *6)) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4521)))))) (-3831 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-763)) (-4 *6 (-1090)) (-4 *3 (-895 *6)) (-5 *2 (-679 *3)) (-5 *1 (-681 *6 *3 *7 *4)) (-4 *7 (-375 *3)) (-4 *4 (-13 (-375 *6) (-10 -7 (-6 -4521)))))) (-3769 (*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-4 *3 (-895 *5)) (-5 *2 (-679 *3)) (-5 *1 (-681 *5 *3 *6 *4)) (-4 *6 (-375 *3)) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4521)))))) (-2216 (*1 *2 *2 *3) (-12 (-4 *4 (-1090)) (-4 *2 (-895 *4)) (-5 *1 (-681 *4 *2 *5 *3)) (-4 *5 (-375 *2)) (-4 *3 (-13 (-375 *4) (-10 -7 (-6 -4521)))))) (-3078 (*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-4 *2 (-895 *5)) (-5 *1 (-681 *5 *2 *3 *4)) (-4 *3 (-375 *2)) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4521)))))) (-2363 (*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-4 *3 (-895 *5)) (-5 *2 (-1244 *3)) (-5 *1 (-681 *5 *3 *6 *4)) (-4 *6 (-375 *3)) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4521))))))) 
+(-10 -7 (-15 -2363 ((-1244 |#2|) |#2| |#4|)) (-15 -3078 (|#2| |#3| |#4|)) (-15 -2216 (|#2| |#2| |#4|)) (-15 -3769 ((-679 |#2|) |#2| |#4|)) (-15 -3831 ((-679 |#2|) |#2| |#4| (-763))) (-15 -2740 ((-679 |#2|) |#3| |#4|)) (-15 -1425 ((-679 |#2|) |#3| |#4| (-763) (-763)))) 
+((-3618 (((-2 (|:| |num| (-679 |#1|)) (|:| |den| |#1|)) (-679 |#2|)) 18)) (-2471 ((|#1| (-679 |#2|)) 9)) (-2609 (((-679 |#1|) (-679 |#2|)) 16))) 
+(((-682 |#1| |#2|) (-10 -7 (-15 -2471 (|#1| (-679 |#2|))) (-15 -2609 ((-679 |#1|) (-679 |#2|))) (-15 -3618 ((-2 (|:| |num| (-679 |#1|)) (|:| |den| |#1|)) (-679 |#2|)))) (-558) (-993 |#1|)) (T -682)) 
+((-3618 (*1 *2 *3) (-12 (-5 *3 (-679 *5)) (-4 *5 (-993 *4)) (-4 *4 (-558)) (-5 *2 (-2 (|:| |num| (-679 *4)) (|:| |den| *4))) (-5 *1 (-682 *4 *5)))) (-2609 (*1 *2 *3) (-12 (-5 *3 (-679 *5)) (-4 *5 (-993 *4)) (-4 *4 (-558)) (-5 *2 (-679 *4)) (-5 *1 (-682 *4 *5)))) (-2471 (*1 *2 *3) (-12 (-5 *3 (-679 *4)) (-4 *4 (-993 *2)) (-4 *2 (-558)) (-5 *1 (-682 *2 *4))))) 
+(-10 -7 (-15 -2471 (|#1| (-679 |#2|))) (-15 -2609 ((-679 |#1|) (-679 |#2|))) (-15 -3618 ((-2 (|:| |num| (-679 |#1|)) (|:| |den| |#1|)) (-679 |#2|)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2883 (((-679 (-688))) NIL) (((-679 (-688)) (-1244 $)) NIL)) (-1934 (((-688) $) NIL)) (-1984 (($ $) NIL (|has| (-688) (-1181)))) (-1935 (($ $) NIL (|has| (-688) (-1181)))) (-1856 (((-1169 (-917) (-763)) (-568)) NIL (|has| (-688) (-350)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-688) (-301)) (|has| (-688) (-904))))) (-3045 (($ $) NIL (-2199 (-12 (|has| (-688) (-301)) (|has| (-688) (-904))) (|has| (-688) (-365))))) (-3498 (((-420 $) $) NIL (-2199 (-12 (|has| (-688) (-301)) (|has| (-688) (-904))) (|has| (-688) (-365))))) (-1904 (($ $) NIL (-12 (|has| (-688) (-1002)) (|has| (-688) (-1181))))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-688) (-301)) (|has| (-688) (-904))))) (-2589 (((-121) $ $) NIL (|has| (-688) (-301)))) (-3986 (((-763)) NIL (|has| (-688) (-370)))) (-1976 (($ $) NIL (|has| (-688) (-1181)))) (-2788 (($ $) NIL (|has| (-688) (-1181)))) (-1992 (($ $) NIL (|has| (-688) (-1181)))) (-1943 (($ $) NIL (|has| (-688) (-1181)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) NIL) (((-3 (-688) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| (-688) (-1037 (-409 (-568)))))) (-2857 (((-568) $) NIL) (((-688) $) NIL) (((-409 (-568)) $) NIL (|has| (-688) (-1037 (-409 (-568)))))) (-3899 (($ (-1244 (-688))) NIL) (($ (-1244 (-688)) (-1244 $)) NIL)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-688) (-350)))) (-2403 (($ $ $) NIL (|has| (-688) (-301)))) (-3653 (((-679 (-688)) $) NIL) (((-679 (-688)) $ (-1244 $)) NIL)) (-1668 (((-679 (-688)) (-679 $)) NIL) (((-2 (|:| -2908 (-679 (-688))) (|:| |vec| (-1244 (-688)))) (-679 $) (-1244 $)) NIL) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| (-688) (-630 (-568)))) (((-679 (-568)) (-679 $)) NIL (|has| (-688) (-630 (-568))))) (-3094 (((-3 $ "failed") (-409 (-1157 (-688)))) NIL (|has| (-688) (-365))) (($ (-1157 (-688))) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-3859 (((-688) $) 29)) (-3254 (((-3 (-409 (-568)) "failed") $) NIL (|has| (-688) (-550)))) (-1338 (((-121) $) NIL (|has| (-688) (-550)))) (-2394 (((-409 (-568)) $) NIL (|has| (-688) (-550)))) (-2371 (((-917)) NIL)) (-1733 (($) NIL (|has| (-688) (-370)))) (-2414 (($ $ $) NIL (|has| (-688) (-301)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| (-688) (-301)))) (-4188 (($) NIL (|has| (-688) (-350)))) (-1748 (((-121) $) NIL (|has| (-688) (-350)))) (-1887 (($ $) NIL (|has| (-688) (-350))) (($ $ (-763)) NIL (|has| (-688) (-350)))) (-2197 (((-121) $) NIL (-2199 (-12 (|has| (-688) (-301)) (|has| (-688) (-904))) (|has| (-688) (-365))))) (-1432 (((-2 (|:| |r| (-688)) (|:| |phi| (-688))) $) NIL (-12 (|has| (-688) (-1056)) (|has| (-688) (-1181))))) (-1899 (($) NIL (|has| (-688) (-1181)))) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| (-688) (-881 (-381)))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| (-688) (-881 (-568))))) (-1844 (((-828 (-917)) $) NIL (|has| (-688) (-350))) (((-917) $) NIL (|has| (-688) (-350)))) (-1598 (((-121) $) NIL)) (-1550 (($ $ (-568)) NIL (-12 (|has| (-688) (-1002)) (|has| (-688) (-1181))))) (-4417 (((-688) $) NIL)) (-2214 (((-3 $ "failed") $) NIL (|has| (-688) (-350)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| (-688) (-301)))) (-1497 (((-1157 (-688)) $) NIL (|has| (-688) (-365)))) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-2797 (($ (-1 (-688) (-688)) $) NIL)) (-2291 (((-917) $) NIL (|has| (-688) (-370)))) (-4418 (($ $) NIL (|has| (-688) (-1181)))) (-3087 (((-1157 (-688)) $) NIL)) (-2498 (($ (-634 $)) NIL (|has| (-688) (-301))) (($ $ $) NIL (|has| (-688) (-301)))) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL (|has| (-688) (-365)))) (-4436 (($) NIL (|has| (-688) (-350)) CONST)) (-4357 (($ (-917)) NIL (|has| (-688) (-370)))) (-2719 (($) NIL)) (-3868 (((-688) $) 31)) (-4025 (((-1108) $) NIL)) (-2707 (($) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| (-688) (-301)))) (-2723 (($ (-634 $)) NIL (|has| (-688) (-301))) (($ $ $) NIL (|has| (-688) (-301)))) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) NIL (|has| (-688) (-350)))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-688) (-301)) (|has| (-688) (-904))))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-688) (-301)) (|has| (-688) (-904))))) (-3850 (((-420 $) $) NIL (-2199 (-12 (|has| (-688) (-301)) (|has| (-688) (-904))) (|has| (-688) (-365))))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| (-688) (-301))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| (-688) (-301)))) (-2597 (((-3 $ "failed") $ $) NIL) (((-3 $ "failed") $ (-688)) NIL (|has| (-688) (-558)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| (-688) (-301)))) (-1894 (($ $) NIL (|has| (-688) (-1181)))) (-1339 (($ $ (-1161) (-688)) NIL (|has| (-688) (-523 (-1161) (-688)))) (($ $ (-634 (-1161)) (-634 (-688))) NIL (|has| (-688) (-523 (-1161) (-688)))) (($ $ (-634 (-288 (-688)))) NIL (|has| (-688) (-303 (-688)))) (($ $ (-288 (-688))) NIL (|has| (-688) (-303 (-688)))) (($ $ (-688) (-688)) NIL (|has| (-688) (-303 (-688)))) (($ $ (-634 (-688)) (-634 (-688))) NIL (|has| (-688) (-303 (-688))))) (-1466 (((-763) $) NIL (|has| (-688) (-301)))) (-2781 (($ $ (-688)) NIL (|has| (-688) (-281 (-688) (-688))))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| (-688) (-301)))) (-3440 (((-688)) NIL) (((-688) (-1244 $)) NIL)) (-2721 (((-3 (-763) "failed") $ $) NIL (|has| (-688) (-350))) (((-763) $) NIL (|has| (-688) (-350)))) (-4191 (($ $ (-1 (-688) (-688))) NIL) (($ $ (-1 (-688) (-688)) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-688) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-688) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-688) (-895 (-1161)))) (($ $ (-1161)) NIL (|has| (-688) (-895 (-1161)))) (($ $ (-763)) NIL (|has| (-688) (-225))) (($ $) NIL (|has| (-688) (-225)))) (-1391 (((-679 (-688)) (-1244 $) (-1 (-688) (-688))) NIL (|has| (-688) (-365)))) (-1492 (((-1157 (-688))) NIL)) (-1996 (($ $) NIL (|has| (-688) (-1181)))) (-1947 (($ $) NIL (|has| (-688) (-1181)))) (-2330 (($) NIL (|has| (-688) (-350)))) (-1988 (($ $) NIL (|has| (-688) (-1181)))) (-1939 (($ $) NIL (|has| (-688) (-1181)))) (-1980 (($ $) NIL (|has| (-688) (-1181)))) (-2792 (($ $) NIL (|has| (-688) (-1181)))) (-1656 (((-679 (-688)) (-1244 $)) NIL) (((-1244 (-688)) $) NIL) (((-679 (-688)) (-1244 $) (-1244 $)) NIL) (((-1244 (-688)) $ (-1244 $)) NIL)) (-4280 (((-541) $) NIL (|has| (-688) (-609 (-541)))) (((-169 (-215)) $) NIL (|has| (-688) (-1021))) (((-169 (-381)) $) NIL (|has| (-688) (-1021))) (((-887 (-381)) $) NIL (|has| (-688) (-609 (-887 (-381))))) (((-887 (-568)) $) NIL (|has| (-688) (-609 (-887 (-568))))) (($ (-1157 (-688))) NIL) (((-1157 (-688)) $) NIL) (($ (-1244 (-688))) NIL) (((-1244 (-688)) $) NIL)) (-2387 (($ $) NIL)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-2199 (-12 (|has| $ (-148)) (|has| (-688) (-301)) (|has| (-688) (-904))) (|has| (-688) (-350))))) (-4005 (($ (-688) (-688)) 12)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-568)) NIL) (($ (-688)) NIL) (($ (-169 (-381))) 13) (($ (-169 (-568))) 19) (($ (-169 (-688))) 28) (($ (-169 (-690))) 25) (((-169 (-381)) $) 33) (($ (-409 (-568))) NIL (-2199 (|has| (-688) (-365)) (|has| (-688) (-1037 (-409 (-568))))))) (-3385 (($ $) NIL (|has| (-688) (-350))) (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| (-688) (-301)) (|has| (-688) (-904))) (|has| (-688) (-148))))) (-1295 (((-1157 (-688)) $) NIL)) (-3425 (((-763)) NIL)) (-2588 (((-1244 $)) NIL)) (-2008 (($ $) NIL (|has| (-688) (-1181)))) (-1959 (($ $) NIL (|has| (-688) (-1181)))) (-2273 (((-121) $ $) NIL)) (-2000 (($ $) NIL (|has| (-688) (-1181)))) (-1951 (($ $) NIL (|has| (-688) (-1181)))) (-2016 (($ $) NIL (|has| (-688) (-1181)))) (-1968 (($ $) NIL (|has| (-688) (-1181)))) (-2014 (((-688) $) NIL (|has| (-688) (-1181)))) (-1439 (($ $) NIL (|has| (-688) (-1181)))) (-1972 (($ $) NIL (|has| (-688) (-1181)))) (-2012 (($ $) NIL (|has| (-688) (-1181)))) (-1964 (($ $) NIL (|has| (-688) (-1181)))) (-2004 (($ $) NIL (|has| (-688) (-1181)))) (-1955 (($ $) NIL (|has| (-688) (-1181)))) (-2811 (($ $) NIL (|has| (-688) (-1056)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| (-688) (-365)))) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $ (-1 (-688) (-688))) NIL) (($ $ (-1 (-688) (-688)) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-688) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-688) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-688) (-895 (-1161)))) (($ $ (-1161)) NIL (|has| (-688) (-895 (-1161)))) (($ $ (-763)) NIL (|has| (-688) (-225))) (($ $) NIL (|has| (-688) (-225)))) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) NIL)) (-1781 (($ $ $) NIL (|has| (-688) (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ $) NIL (|has| (-688) (-1181))) (($ $ (-409 (-568))) NIL (-12 (|has| (-688) (-1002)) (|has| (-688) (-1181)))) (($ $ (-568)) NIL (|has| (-688) (-365)))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ (-688) $) NIL) (($ $ (-688)) NIL) (($ (-409 (-568)) $) NIL (|has| (-688) (-365))) (($ $ (-409 (-568))) NIL (|has| (-688) (-365))))) 
+(((-683) (-13 (-389) (-166 (-688)) (-10 -8 (-15 -2747 ($ (-169 (-381)))) (-15 -2747 ($ (-169 (-568)))) (-15 -2747 ($ (-169 (-688)))) (-15 -2747 ($ (-169 (-690)))) (-15 -2747 ((-169 (-381)) $))))) (T -683)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-169 (-381))) (-5 *1 (-683)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-169 (-568))) (-5 *1 (-683)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-169 (-688))) (-5 *1 (-683)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-169 (-690))) (-5 *1 (-683)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-169 (-381))) (-5 *1 (-683))))) 
+(-13 (-389) (-166 (-688)) (-10 -8 (-15 -2747 ($ (-169 (-381)))) (-15 -2747 ($ (-169 (-568)))) (-15 -2747 ($ (-169 (-688)))) (-15 -2747 ($ (-169 (-690)))) (-15 -2747 ((-169 (-381)) $)))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-1667 (((-121) $ (-763)) 8)) (-3963 (($ (-1 (-121) |#1|) $) 42 (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) |#1|) $) 52 (|has| $ (-6 -4521)))) (-4490 (($) 7 T CONST)) (-1377 (($ $) 58)) (-3926 (($ $) 55 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-1568 (($ |#1| $) 44 (|has| $ (-6 -4521))) (($ (-1 (-121) |#1|) $) 43 (|has| $ (-6 -4521)))) (-4330 (($ |#1| $) 54 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) |#1|) $) 51 (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4521)))) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) 9)) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35)) (-3796 (((-121) $ (-763)) 10)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-2580 ((|#1| $) 36)) (-1708 (($ |#1| $) 37) (($ |#1| $ (-763)) 59)) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 48)) (-3403 ((|#1| $) 38)) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2138 (((-634 (-2 (|:| -4085 |#1|) (|:| -4170 (-763)))) $) 57)) (-3132 (($) 46) (($ (-634 |#1|)) 45)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-4280 (((-541) $) 56 (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) 47)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-4074 (($ (-634 |#1|)) 39)) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-684 |#1|) (-1275) (-1090)) (T -684)) 
-((-4450 (*1 *1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-684 *2)) (-4 *2 (-1090)))) (-3369 (*1 *1 *1) (-12 (-4 *1 (-684 *2)) (-4 *2 (-1090)))) (-1799 (*1 *2 *1) (-12 (-4 *1 (-684 *3)) (-4 *3 (-1090)) (-5 *2 (-634 (-2 (|:| -4083 *3) (|:| -4168 (-763)))))))) 
-(-13 (-227 |t#1|) (-10 -8 (-15 -4450 ($ |t#1| $ (-763))) (-15 -3369 ($ $)) (-15 -1799 ((-634 (-2 (|:| -4083 |t#1|) (|:| -4168 (-763)))) $)))) 
+((-1708 (*1 *1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-684 *2)) (-4 *2 (-1090)))) (-1377 (*1 *1 *1) (-12 (-4 *1 (-684 *2)) (-4 *2 (-1090)))) (-2138 (*1 *2 *1) (-12 (-4 *1 (-684 *3)) (-4 *3 (-1090)) (-5 *2 (-634 (-2 (|:| -4085 *3) (|:| -4170 (-763)))))))) 
+(-13 (-227 |t#1|) (-10 -8 (-15 -1708 ($ |t#1| $ (-763))) (-15 -1377 ($ $)) (-15 -2138 ((-634 (-2 (|:| -4085 |t#1|) (|:| -4170 (-763)))) $)))) 
 (((-39) . T) ((-111 |#1|) . T) ((-105) |has| |#1| (-1090)) ((-608 (-850)) |has| |#1| (-1090)) ((-154 |#1|) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-227 |#1|) . T) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-1090) |has| |#1| (-1090)) ((-1195) . T)) 
-((-2117 (((-634 |#1|) (-634 (-2 (|:| -3848 |#1|) (|:| -3206 (-568)))) (-568)) 46)) (-2737 ((|#1| |#1| (-568)) 45)) (-2721 ((|#1| |#1| |#1| (-568)) 35)) (-3848 (((-634 |#1|) |#1| (-568)) 38)) (-3333 ((|#1| |#1| (-568) |#1| (-568)) 32)) (-1857 (((-634 (-2 (|:| -3848 |#1|) (|:| -3206 (-568)))) |#1| (-568)) 44))) 
-(((-685 |#1|) (-10 -7 (-15 -2721 (|#1| |#1| |#1| (-568))) (-15 -2737 (|#1| |#1| (-568))) (-15 -3848 ((-634 |#1|) |#1| (-568))) (-15 -1857 ((-634 (-2 (|:| -3848 |#1|) (|:| -3206 (-568)))) |#1| (-568))) (-15 -2117 ((-634 |#1|) (-634 (-2 (|:| -3848 |#1|) (|:| -3206 (-568)))) (-568))) (-15 -3333 (|#1| |#1| (-568) |#1| (-568)))) (-1219 (-568))) (T -685)) 
-((-3333 (*1 *2 *2 *3 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-685 *2)) (-4 *2 (-1219 *3)))) (-2117 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-2 (|:| -3848 *5) (|:| -3206 (-568))))) (-5 *4 (-568)) (-4 *5 (-1219 *4)) (-5 *2 (-634 *5)) (-5 *1 (-685 *5)))) (-1857 (*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-5 *2 (-634 (-2 (|:| -3848 *3) (|:| -3206 *4)))) (-5 *1 (-685 *3)) (-4 *3 (-1219 *4)))) (-3848 (*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-5 *2 (-634 *3)) (-5 *1 (-685 *3)) (-4 *3 (-1219 *4)))) (-2737 (*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-685 *2)) (-4 *2 (-1219 *3)))) (-2721 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-685 *2)) (-4 *2 (-1219 *3))))) 
-(-10 -7 (-15 -2721 (|#1| |#1| |#1| (-568))) (-15 -2737 (|#1| |#1| (-568))) (-15 -3848 ((-634 |#1|) |#1| (-568))) (-15 -1857 ((-634 (-2 (|:| -3848 |#1|) (|:| -3206 (-568)))) |#1| (-568))) (-15 -2117 ((-634 |#1|) (-634 (-2 (|:| -3848 |#1|) (|:| -3206 (-568)))) (-568))) (-15 -3333 (|#1| |#1| (-568) |#1| (-568)))) 
-((-3579 (((-1 (-944 (-215)) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215) (-215))) 17)) (-4124 (((-1121 (-215)) (-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-634 (-256))) 38) (((-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-634 (-256))) 40) (((-1121 (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-3 (-1 (-215) (-215) (-215) (-215)) "undefined") (-1084 (-215)) (-1084 (-215)) (-634 (-256))) 42)) (-2257 (((-1121 (-215)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-634 (-256))) NIL)) (-3688 (((-1121 (-215)) (-1 (-215) (-215) (-215)) (-3 (-1 (-215) (-215) (-215) (-215)) "undefined") (-1084 (-215)) (-1084 (-215)) (-634 (-256))) 43))) 
-(((-686) (-10 -7 (-15 -4124 ((-1121 (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-3 (-1 (-215) (-215) (-215) (-215)) "undefined") (-1084 (-215)) (-1084 (-215)) (-634 (-256)))) (-15 -4124 ((-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-634 (-256)))) (-15 -4124 ((-1121 (-215)) (-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-634 (-256)))) (-15 -3688 ((-1121 (-215)) (-1 (-215) (-215) (-215)) (-3 (-1 (-215) (-215) (-215) (-215)) "undefined") (-1084 (-215)) (-1084 (-215)) (-634 (-256)))) (-15 -2257 ((-1121 (-215)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-634 (-256)))) (-15 -3579 ((-1 (-944 (-215)) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215) (-215)))))) (T -686)) 
-((-3579 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-1 (-215) (-215) (-215) (-215))) (-5 *2 (-1 (-944 (-215)) (-215) (-215))) (-5 *1 (-686)))) (-2257 (*1 *2 *3 *3 *3 *4 *5 *6) (-12 (-5 *3 (-310 (-568))) (-5 *4 (-1 (-215) (-215))) (-5 *5 (-1084 (-215))) (-5 *6 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-686)))) (-3688 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-3 (-1 (-215) (-215) (-215) (-215)) "undefined")) (-5 *5 (-1084 (-215))) (-5 *6 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-686)))) (-4124 (*1 *2 *2 *3 *4 *4 *5) (-12 (-5 *2 (-1121 (-215))) (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-215))) (-5 *5 (-634 (-256))) (-5 *1 (-686)))) (-4124 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-215))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-686)))) (-4124 (*1 *2 *3 *3 *3 *4 *5 *5 *6) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-3 (-1 (-215) (-215) (-215) (-215)) "undefined")) (-5 *5 (-1084 (-215))) (-5 *6 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-686))))) 
-(-10 -7 (-15 -4124 ((-1121 (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-3 (-1 (-215) (-215) (-215) (-215)) "undefined") (-1084 (-215)) (-1084 (-215)) (-634 (-256)))) (-15 -4124 ((-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-634 (-256)))) (-15 -4124 ((-1121 (-215)) (-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-634 (-256)))) (-15 -3688 ((-1121 (-215)) (-1 (-215) (-215) (-215)) (-3 (-1 (-215) (-215) (-215) (-215)) "undefined") (-1084 (-215)) (-1084 (-215)) (-634 (-256)))) (-15 -2257 ((-1121 (-215)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-634 (-256)))) (-15 -3579 ((-1 (-944 (-215)) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215) (-215))))) 
-((-3848 (((-420 (-1157 |#4|)) (-1157 |#4|)) 73) (((-420 |#4|) |#4|) 215))) 
-(((-687 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3848 ((-420 |#4|) |#4|)) (-15 -3848 ((-420 (-1157 |#4|)) (-1157 |#4|)))) (-842) (-788) (-350) (-950 |#3| |#2| |#1|)) (T -687)) 
-((-3848 (*1 *2 *3) (-12 (-4 *4 (-842)) (-4 *5 (-788)) (-4 *6 (-350)) (-4 *7 (-950 *6 *5 *4)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-687 *4 *5 *6 *7)) (-5 *3 (-1157 *7)))) (-3848 (*1 *2 *3) (-12 (-4 *4 (-842)) (-4 *5 (-788)) (-4 *6 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-687 *4 *5 *6 *3)) (-4 *3 (-950 *6 *5 *4))))) 
-(-10 -7 (-15 -3848 ((-420 |#4|) |#4|)) (-15 -3848 ((-420 (-1157 |#4|)) (-1157 |#4|)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 84)) (-1492 (((-568) $) 30)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-2617 (($ $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1902 (($ $) NIL)) (-1497 (((-121) $ $) NIL)) (-3662 (((-568) $) NIL)) (-2671 (($) NIL T CONST)) (-3047 (($ $) NIL)) (-3666 (((-3 (-568) "failed") $) 73) (((-3 (-409 (-568)) "failed") $) 26) (((-3 (-381) "failed") $) 70)) (-2854 (((-568) $) 75) (((-409 (-568)) $) 67) (((-381) $) 68)) (-2401 (($ $ $) 96)) (-2925 (((-3 $ "failed") $) 87)) (-2412 (($ $ $) 95)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-3359 (((-917)) 77) (((-917) (-917)) 76)) (-2033 (((-121) $) NIL)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL)) (-4477 (((-568) $) NIL)) (-2735 (((-121) $) NIL)) (-4044 (($ $ (-568)) NIL)) (-2657 (($ $) NIL)) (-2245 (((-121) $) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1950 (((-568) (-568)) 81) (((-568)) 82)) (-2521 (($ $ $) NIL) (($) NIL (-12 (-3044 (|has| $ (-6 -4502))) (-3044 (|has| $ (-6 -4510)))))) (-3652 (((-568) (-568)) 79) (((-568)) 80)) (-3268 (($ $ $) NIL) (($) NIL (-12 (-3044 (|has| $ (-6 -4502))) (-3044 (|has| $ (-6 -4510)))))) (-3544 (((-568) $) 16)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) 91)) (-2719 (((-917) (-568)) NIL (|has| $ (-6 -4510)))) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3880 (($ $) NIL)) (-1519 (($ $) NIL)) (-3768 (($ (-568) (-568)) NIL) (($ (-568) (-568) (-917)) NIL)) (-3848 (((-420 $) $) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) 92)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3438 (((-568) $) 22)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 94)) (-3396 (((-917)) NIL) (((-917) (-917)) NIL (|has| $ (-6 -4510)))) (-2573 (((-917) (-568)) NIL (|has| $ (-6 -4510)))) (-4278 (((-381) $) NIL) (((-215) $) NIL) (((-887 (-381)) $) NIL)) (-2745 (((-850) $) 52) (($ (-568)) 63) (($ $) NIL) (($ (-409 (-568))) 66) (($ (-568)) 63) (($ (-409 (-568))) 66) (($ (-381)) 60) (((-381) $) 50) (($ (-690)) 55)) (-4078 (((-763)) 103)) (-3799 (($ (-568) (-568) (-917)) 44)) (-2285 (($ $) NIL)) (-4042 (((-917)) NIL) (((-917) (-917)) NIL (|has| $ (-6 -4510)))) (-1461 (((-917)) 35) (((-917) (-917)) 78)) (-1826 (((-121) $ $) NIL)) (-2897 (($ $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) 32 T CONST)) (-1556 (($) 17 T CONST)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 83)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 101)) (-1779 (($ $ $) 65)) (-1773 (($ $) 99) (($ $ $) 100)) (-1767 (($ $ $) 98)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL) (($ $ (-409 (-568))) 90)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 97) (($ $ $) 88) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL))) 
-(((-688) (-13 (-406) (-389) (-365) (-1037 (-381)) (-1037 (-409 (-568))) (-150) (-10 -8 (-15 -3359 ((-917) (-917))) (-15 -3359 ((-917))) (-15 -1461 ((-917) (-917))) (-15 -1461 ((-917))) (-15 -3652 ((-568) (-568))) (-15 -3652 ((-568))) (-15 -1950 ((-568) (-568))) (-15 -1950 ((-568))) (-15 -2745 ((-381) $)) (-15 -2745 ($ (-690))) (-15 -3544 ((-568) $)) (-15 -3438 ((-568) $)) (-15 -3799 ($ (-568) (-568) (-917)))))) (T -688)) 
-((-1461 (*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-688)))) (-3438 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-688)))) (-3544 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-688)))) (-3359 (*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-688)))) (-3359 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-688)))) (-1461 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-688)))) (-3652 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-688)))) (-3652 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-688)))) (-1950 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-688)))) (-1950 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-688)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-381)) (-5 *1 (-688)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-690)) (-5 *1 (-688)))) (-3799 (*1 *1 *2 *2 *3) (-12 (-5 *2 (-568)) (-5 *3 (-917)) (-5 *1 (-688))))) 
-(-13 (-406) (-389) (-365) (-1037 (-381)) (-1037 (-409 (-568))) (-150) (-10 -8 (-15 -3359 ((-917) (-917))) (-15 -3359 ((-917))) (-15 -1461 ((-917) (-917))) (-15 -1461 ((-917))) (-15 -3652 ((-568) (-568))) (-15 -3652 ((-568))) (-15 -1950 ((-568) (-568))) (-15 -1950 ((-568))) (-15 -2745 ((-381) $)) (-15 -2745 ($ (-690))) (-15 -3544 ((-568) $)) (-15 -3438 ((-568) $)) (-15 -3799 ($ (-568) (-568) (-917))))) 
-((-3727 (((-679 |#1|) (-679 |#1|) |#1| |#1|) 66)) (-4167 (((-679 |#1|) (-679 |#1|) |#1|) 49)) (-3977 (((-679 |#1|) (-679 |#1|) |#1|) 67)) (-1521 (((-679 |#1|) (-679 |#1|)) 50)) (-4045 (((-2 (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1|) 65))) 
-(((-689 |#1|) (-10 -7 (-15 -1521 ((-679 |#1|) (-679 |#1|))) (-15 -4167 ((-679 |#1|) (-679 |#1|) |#1|)) (-15 -3977 ((-679 |#1|) (-679 |#1|) |#1|)) (-15 -3727 ((-679 |#1|) (-679 |#1|) |#1| |#1|)) (-15 -4045 ((-2 (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1|))) (-301)) (T -689)) 
-((-4045 (*1 *2 *3 *3) (-12 (-5 *2 (-2 (|:| -3961 *3) (|:| -1500 *3))) (-5 *1 (-689 *3)) (-4 *3 (-301)))) (-3727 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-679 *3)) (-4 *3 (-301)) (-5 *1 (-689 *3)))) (-3977 (*1 *2 *2 *3) (-12 (-5 *2 (-679 *3)) (-4 *3 (-301)) (-5 *1 (-689 *3)))) (-4167 (*1 *2 *2 *3) (-12 (-5 *2 (-679 *3)) (-4 *3 (-301)) (-5 *1 (-689 *3)))) (-1521 (*1 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-301)) (-5 *1 (-689 *3))))) 
-(-10 -7 (-15 -1521 ((-679 |#1|) (-679 |#1|))) (-15 -4167 ((-679 |#1|) (-679 |#1|) |#1|)) (-15 -3977 ((-679 |#1|) (-679 |#1|) |#1|)) (-15 -3727 ((-679 |#1|) (-679 |#1|) |#1| |#1|)) (-15 -4045 ((-2 (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-1877 (($ $ $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2690 (($ $ $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1497 (((-121) $ $) NIL)) (-3662 (((-568) $) NIL)) (-1870 (($ $ $) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) 27)) (-2854 (((-568) $) 25)) (-2401 (($ $ $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1642 (((-3 (-409 (-568)) "failed") $) NIL)) (-2688 (((-121) $) NIL)) (-2425 (((-409 (-568)) $) NIL)) (-1731 (($ $) NIL) (($) NIL)) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-1457 (($ $ $ $) NIL)) (-1283 (($ $ $) NIL)) (-2033 (((-121) $) NIL)) (-2413 (($ $ $) NIL)) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL)) (-2735 (((-121) $) NIL)) (-1825 (((-121) $) NIL)) (-3038 (((-3 $ "failed") $) NIL)) (-2245 (((-121) $) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3326 (($ $ $ $) NIL)) (-2521 (($ $ $) NIL)) (-1408 (((-917) (-917)) 10) (((-917)) 9)) (-3268 (($ $ $) NIL)) (-3651 (($ $) NIL)) (-3678 (($ $) NIL)) (-2495 (($ (-634 $)) NIL) (($ $ $) NIL)) (-4487 (((-1143) $) NIL)) (-2110 (($ $ $) NIL)) (-4434 (($) NIL T CONST)) (-3850 (($ $) NIL)) (-4022 (((-1108) $) NIL) (($ $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ (-634 $)) NIL) (($ $ $) NIL)) (-2427 (($ $) NIL)) (-3848 (((-420 $) $) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3277 (((-121) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-4189 (($ $) NIL) (($ $ (-763)) NIL)) (-2349 (($ $) NIL)) (-3863 (($ $) NIL)) (-4278 (((-215) $) NIL) (((-381) $) NIL) (((-887 (-568)) $) NIL) (((-541) $) NIL) (((-568) $) NIL)) (-2745 (((-850) $) NIL) (($ (-568)) 24) (($ $) NIL) (($ (-568)) 24) (((-310 $) (-310 (-568))) 18)) (-4078 (((-763)) NIL)) (-2791 (((-121) $ $) NIL)) (-2787 (($ $ $) NIL)) (-1461 (($) NIL)) (-1826 (((-121) $ $) NIL)) (-4419 (($ $ $ $) NIL)) (-2897 (($ $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $) NIL) (($ $ (-763)) NIL)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL))) 
-(((-690) (-13 (-389) (-550) (-10 -8 (-15 -1408 ((-917) (-917))) (-15 -1408 ((-917))) (-15 -2745 ((-310 $) (-310 (-568))))))) (T -690)) 
-((-1408 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-690)))) (-1408 (*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-690)))) (-2745 (*1 *2 *3) (-12 (-5 *3 (-310 (-568))) (-5 *2 (-310 (-690))) (-5 *1 (-690))))) 
-(-13 (-389) (-550) (-10 -8 (-15 -1408 ((-917) (-917))) (-15 -1408 ((-917))) (-15 -2745 ((-310 $) (-310 (-568)))))) 
-((-1755 (((-1 |#4| |#2| |#3|) |#1| (-1161) (-1161)) 19)) (-4496 (((-1 |#4| |#2| |#3|) (-1161)) 12))) 
-(((-691 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4496 ((-1 |#4| |#2| |#3|) (-1161))) (-15 -1755 ((-1 |#4| |#2| |#3|) |#1| (-1161) (-1161)))) (-609 (-541)) (-1195) (-1195) (-1195)) (T -691)) 
-((-1755 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-1161)) (-5 *2 (-1 *7 *5 *6)) (-5 *1 (-691 *3 *5 *6 *7)) (-4 *3 (-609 (-541))) (-4 *5 (-1195)) (-4 *6 (-1195)) (-4 *7 (-1195)))) (-4496 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 *7 *5 *6)) (-5 *1 (-691 *4 *5 *6 *7)) (-4 *4 (-609 (-541))) (-4 *5 (-1195)) (-4 *6 (-1195)) (-4 *7 (-1195))))) 
-(-10 -7 (-15 -4496 ((-1 |#4| |#2| |#3|) (-1161))) (-15 -1755 ((-1 |#4| |#2| |#3|) |#1| (-1161) (-1161)))) 
-((-2447 (((-121) $ $) NIL)) (-3138 (((-1249) $ (-763)) 14)) (-2764 (((-763) $) 12)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 18) ((|#1| $) 15) (($ |#1|) 23)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 25)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 24))) 
-(((-692 |#1|) (-13 (-138) (-608 |#1|) (-10 -8 (-15 -2745 ($ |#1|)))) (-1090)) (T -692)) 
-((-2745 (*1 *1 *2) (-12 (-5 *1 (-692 *2)) (-4 *2 (-1090))))) 
-(-13 (-138) (-608 |#1|) (-10 -8 (-15 -2745 ($ |#1|)))) 
-((-4458 (((-1 (-215) (-215) (-215)) |#1| (-1161) (-1161)) 33) (((-1 (-215) (-215)) |#1| (-1161)) 38))) 
-(((-693 |#1|) (-10 -7 (-15 -4458 ((-1 (-215) (-215)) |#1| (-1161))) (-15 -4458 ((-1 (-215) (-215) (-215)) |#1| (-1161) (-1161)))) (-609 (-541))) (T -693)) 
-((-4458 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-1161)) (-5 *2 (-1 (-215) (-215) (-215))) (-5 *1 (-693 *3)) (-4 *3 (-609 (-541))))) (-4458 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-5 *2 (-1 (-215) (-215))) (-5 *1 (-693 *3)) (-4 *3 (-609 (-541)))))) 
-(-10 -7 (-15 -4458 ((-1 (-215) (-215)) |#1| (-1161))) (-15 -4458 ((-1 (-215) (-215) (-215)) |#1| (-1161) (-1161)))) 
-((-1864 (((-1161) |#1| (-1161) (-634 (-1161))) 9) (((-1161) |#1| (-1161) (-1161) (-1161)) 12) (((-1161) |#1| (-1161) (-1161)) 11) (((-1161) |#1| (-1161)) 10))) 
-(((-694 |#1|) (-10 -7 (-15 -1864 ((-1161) |#1| (-1161))) (-15 -1864 ((-1161) |#1| (-1161) (-1161))) (-15 -1864 ((-1161) |#1| (-1161) (-1161) (-1161))) (-15 -1864 ((-1161) |#1| (-1161) (-634 (-1161))))) (-609 (-541))) (T -694)) 
-((-1864 (*1 *2 *3 *2 *4) (-12 (-5 *4 (-634 (-1161))) (-5 *2 (-1161)) (-5 *1 (-694 *3)) (-4 *3 (-609 (-541))))) (-1864 (*1 *2 *3 *2 *2 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-694 *3)) (-4 *3 (-609 (-541))))) (-1864 (*1 *2 *3 *2 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-694 *3)) (-4 *3 (-609 (-541))))) (-1864 (*1 *2 *3 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-694 *3)) (-4 *3 (-609 (-541)))))) 
-(-10 -7 (-15 -1864 ((-1161) |#1| (-1161))) (-15 -1864 ((-1161) |#1| (-1161) (-1161))) (-15 -1864 ((-1161) |#1| (-1161) (-1161) (-1161))) (-15 -1864 ((-1161) |#1| (-1161) (-634 (-1161))))) 
-((-2817 (((-2 (|:| |part1| |#1|) (|:| |part2| |#2|)) |#1| |#2|) 9))) 
-(((-695 |#1| |#2|) (-10 -7 (-15 -2817 ((-2 (|:| |part1| |#1|) (|:| |part2| |#2|)) |#1| |#2|))) (-1195) (-1195)) (T -695)) 
-((-2817 (*1 *2 *3 *4) (-12 (-5 *2 (-2 (|:| |part1| *3) (|:| |part2| *4))) (-5 *1 (-695 *3 *4)) (-4 *3 (-1195)) (-4 *4 (-1195))))) 
-(-10 -7 (-15 -2817 ((-2 (|:| |part1| |#1|) (|:| |part2| |#2|)) |#1| |#2|))) 
-((-2175 (((-1 |#3| |#2|) (-1161)) 11)) (-1755 (((-1 |#3| |#2|) |#1| (-1161)) 21))) 
-(((-696 |#1| |#2| |#3|) (-10 -7 (-15 -2175 ((-1 |#3| |#2|) (-1161))) (-15 -1755 ((-1 |#3| |#2|) |#1| (-1161)))) (-609 (-541)) (-1195) (-1195)) (T -696)) 
-((-1755 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-5 *2 (-1 *6 *5)) (-5 *1 (-696 *3 *5 *6)) (-4 *3 (-609 (-541))) (-4 *5 (-1195)) (-4 *6 (-1195)))) (-2175 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 *6 *5)) (-5 *1 (-696 *4 *5 *6)) (-4 *4 (-609 (-541))) (-4 *5 (-1195)) (-4 *6 (-1195))))) 
-(-10 -7 (-15 -2175 ((-1 |#3| |#2|) (-1161))) (-15 -1755 ((-1 |#3| |#2|) |#1| (-1161)))) 
-((-3288 (((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-634 |#2|) (-634 (-1157 |#4|)) (-634 |#3|) (-634 |#4|) (-634 (-634 (-2 (|:| -1876 (-763)) (|:| |pcoef| |#4|)))) (-634 (-763)) (-1244 (-634 (-1157 |#3|))) |#3|) 58)) (-2157 (((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-634 |#2|) (-634 (-1157 |#3|)) (-634 |#3|) (-634 |#4|) (-634 (-763)) |#3|) 71)) (-4245 (((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-634 |#2|) (-634 |#3|) (-634 (-763)) (-634 (-1157 |#4|)) (-1244 (-634 (-1157 |#3|))) |#3|) 32))) 
-(((-697 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4245 ((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-634 |#2|) (-634 |#3|) (-634 (-763)) (-634 (-1157 |#4|)) (-1244 (-634 (-1157 |#3|))) |#3|)) (-15 -2157 ((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-634 |#2|) (-634 (-1157 |#3|)) (-634 |#3|) (-634 |#4|) (-634 (-763)) |#3|)) (-15 -3288 ((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-634 |#2|) (-634 (-1157 |#4|)) (-634 |#3|) (-634 |#4|) (-634 (-634 (-2 (|:| -1876 (-763)) (|:| |pcoef| |#4|)))) (-634 (-763)) (-1244 (-634 (-1157 |#3|))) |#3|))) (-788) (-842) (-301) (-950 |#3| |#1| |#2|)) (T -697)) 
-((-3288 (*1 *2 *3 *4 *2 *5 *6 *7 *8 *9 *10) (|partial| -12 (-5 *2 (-634 (-1157 *13))) (-5 *3 (-1157 *13)) (-5 *4 (-634 *12)) (-5 *5 (-634 *10)) (-5 *6 (-634 *13)) (-5 *7 (-634 (-634 (-2 (|:| -1876 (-763)) (|:| |pcoef| *13))))) (-5 *8 (-634 (-763))) (-5 *9 (-1244 (-634 (-1157 *10)))) (-4 *12 (-842)) (-4 *10 (-301)) (-4 *13 (-950 *10 *11 *12)) (-4 *11 (-788)) (-5 *1 (-697 *11 *12 *10 *13)))) (-2157 (*1 *2 *3 *4 *5 *6 *7 *8 *9) (|partial| -12 (-5 *4 (-634 *11)) (-5 *5 (-634 (-1157 *9))) (-5 *6 (-634 *9)) (-5 *7 (-634 *12)) (-5 *8 (-634 (-763))) (-4 *11 (-842)) (-4 *9 (-301)) (-4 *12 (-950 *9 *10 *11)) (-4 *10 (-788)) (-5 *2 (-634 (-1157 *12))) (-5 *1 (-697 *10 *11 *9 *12)) (-5 *3 (-1157 *12)))) (-4245 (*1 *2 *3 *4 *5 *6 *2 *7 *8) (|partial| -12 (-5 *2 (-634 (-1157 *11))) (-5 *3 (-1157 *11)) (-5 *4 (-634 *10)) (-5 *5 (-634 *8)) (-5 *6 (-634 (-763))) (-5 *7 (-1244 (-634 (-1157 *8)))) (-4 *10 (-842)) (-4 *8 (-301)) (-4 *11 (-950 *8 *9 *10)) (-4 *9 (-788)) (-5 *1 (-697 *9 *10 *8 *11))))) 
-(-10 -7 (-15 -4245 ((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-634 |#2|) (-634 |#3|) (-634 (-763)) (-634 (-1157 |#4|)) (-1244 (-634 (-1157 |#3|))) |#3|)) (-15 -2157 ((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-634 |#2|) (-634 (-1157 |#3|)) (-634 |#3|) (-634 |#4|) (-634 (-763)) |#3|)) (-15 -3288 ((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-634 |#2|) (-634 (-1157 |#4|)) (-634 |#3|) (-634 |#4|) (-634 (-634 (-2 (|:| -1876 (-763)) (|:| |pcoef| |#4|)))) (-634 (-763)) (-1244 (-634 (-1157 |#3|))) |#3|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-2114 (($ $) 40)) (-2925 (((-3 $ "failed") $) 33)) (-2735 (((-121) $) 30)) (-2047 (($ |#1| (-763)) 38)) (-2144 (((-763) $) 42)) (-2102 ((|#1| $) 41)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-3206 (((-763) $) 43)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 37 (|has| |#1| (-172)))) (-2604 ((|#1| $ (-763)) 39)) (-4078 (((-763)) 28)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 45) (($ |#1| $) 44))) 
+((-3316 (((-634 |#1|) (-634 (-2 (|:| -3850 |#1|) (|:| -1836 (-568)))) (-568)) 46)) (-1606 ((|#1| |#1| (-568)) 45)) (-2723 ((|#1| |#1| |#1| (-568)) 35)) (-3850 (((-634 |#1|) |#1| (-568)) 38)) (-4413 ((|#1| |#1| (-568) |#1| (-568)) 32)) (-2428 (((-634 (-2 (|:| -3850 |#1|) (|:| -1836 (-568)))) |#1| (-568)) 44))) 
+(((-685 |#1|) (-10 -7 (-15 -2723 (|#1| |#1| |#1| (-568))) (-15 -1606 (|#1| |#1| (-568))) (-15 -3850 ((-634 |#1|) |#1| (-568))) (-15 -2428 ((-634 (-2 (|:| -3850 |#1|) (|:| -1836 (-568)))) |#1| (-568))) (-15 -3316 ((-634 |#1|) (-634 (-2 (|:| -3850 |#1|) (|:| -1836 (-568)))) (-568))) (-15 -4413 (|#1| |#1| (-568) |#1| (-568)))) (-1219 (-568))) (T -685)) 
+((-4413 (*1 *2 *2 *3 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-685 *2)) (-4 *2 (-1219 *3)))) (-3316 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-2 (|:| -3850 *5) (|:| -1836 (-568))))) (-5 *4 (-568)) (-4 *5 (-1219 *4)) (-5 *2 (-634 *5)) (-5 *1 (-685 *5)))) (-2428 (*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-5 *2 (-634 (-2 (|:| -3850 *3) (|:| -1836 *4)))) (-5 *1 (-685 *3)) (-4 *3 (-1219 *4)))) (-3850 (*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-5 *2 (-634 *3)) (-5 *1 (-685 *3)) (-4 *3 (-1219 *4)))) (-1606 (*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-685 *2)) (-4 *2 (-1219 *3)))) (-2723 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-685 *2)) (-4 *2 (-1219 *3))))) 
+(-10 -7 (-15 -2723 (|#1| |#1| |#1| (-568))) (-15 -1606 (|#1| |#1| (-568))) (-15 -3850 ((-634 |#1|) |#1| (-568))) (-15 -2428 ((-634 (-2 (|:| -3850 |#1|) (|:| -1836 (-568)))) |#1| (-568))) (-15 -3316 ((-634 |#1|) (-634 (-2 (|:| -3850 |#1|) (|:| -1836 (-568)))) (-568))) (-15 -4413 (|#1| |#1| (-568) |#1| (-568)))) 
+((-2920 (((-1 (-944 (-215)) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215) (-215))) 17)) (-3676 (((-1121 (-215)) (-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-634 (-256))) 38) (((-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-634 (-256))) 40) (((-1121 (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-3 (-1 (-215) (-215) (-215) (-215)) "undefined") (-1084 (-215)) (-1084 (-215)) (-634 (-256))) 42)) (-3313 (((-1121 (-215)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-634 (-256))) NIL)) (-2307 (((-1121 (-215)) (-1 (-215) (-215) (-215)) (-3 (-1 (-215) (-215) (-215) (-215)) "undefined") (-1084 (-215)) (-1084 (-215)) (-634 (-256))) 43))) 
+(((-686) (-10 -7 (-15 -3676 ((-1121 (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-3 (-1 (-215) (-215) (-215) (-215)) "undefined") (-1084 (-215)) (-1084 (-215)) (-634 (-256)))) (-15 -3676 ((-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-634 (-256)))) (-15 -3676 ((-1121 (-215)) (-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-634 (-256)))) (-15 -2307 ((-1121 (-215)) (-1 (-215) (-215) (-215)) (-3 (-1 (-215) (-215) (-215) (-215)) "undefined") (-1084 (-215)) (-1084 (-215)) (-634 (-256)))) (-15 -3313 ((-1121 (-215)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-634 (-256)))) (-15 -2920 ((-1 (-944 (-215)) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215) (-215)))))) (T -686)) 
+((-2920 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-1 (-215) (-215) (-215) (-215))) (-5 *2 (-1 (-944 (-215)) (-215) (-215))) (-5 *1 (-686)))) (-3313 (*1 *2 *3 *3 *3 *4 *5 *6) (-12 (-5 *3 (-310 (-568))) (-5 *4 (-1 (-215) (-215))) (-5 *5 (-1084 (-215))) (-5 *6 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-686)))) (-2307 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-3 (-1 (-215) (-215) (-215) (-215)) "undefined")) (-5 *5 (-1084 (-215))) (-5 *6 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-686)))) (-3676 (*1 *2 *2 *3 *4 *4 *5) (-12 (-5 *2 (-1121 (-215))) (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-215))) (-5 *5 (-634 (-256))) (-5 *1 (-686)))) (-3676 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-215))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-686)))) (-3676 (*1 *2 *3 *3 *3 *4 *5 *5 *6) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-3 (-1 (-215) (-215) (-215) (-215)) "undefined")) (-5 *5 (-1084 (-215))) (-5 *6 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-686))))) 
+(-10 -7 (-15 -3676 ((-1121 (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-3 (-1 (-215) (-215) (-215) (-215)) "undefined") (-1084 (-215)) (-1084 (-215)) (-634 (-256)))) (-15 -3676 ((-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-634 (-256)))) (-15 -3676 ((-1121 (-215)) (-1121 (-215)) (-1 (-944 (-215)) (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-634 (-256)))) (-15 -2307 ((-1121 (-215)) (-1 (-215) (-215) (-215)) (-3 (-1 (-215) (-215) (-215) (-215)) "undefined") (-1084 (-215)) (-1084 (-215)) (-634 (-256)))) (-15 -3313 ((-1121 (-215)) (-310 (-568)) (-310 (-568)) (-310 (-568)) (-1 (-215) (-215)) (-1084 (-215)) (-634 (-256)))) (-15 -2920 ((-1 (-944 (-215)) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215)) (-1 (-215) (-215) (-215) (-215))))) 
+((-3850 (((-420 (-1157 |#4|)) (-1157 |#4|)) 73) (((-420 |#4|) |#4|) 215))) 
+(((-687 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3850 ((-420 |#4|) |#4|)) (-15 -3850 ((-420 (-1157 |#4|)) (-1157 |#4|)))) (-842) (-788) (-350) (-950 |#3| |#2| |#1|)) (T -687)) 
+((-3850 (*1 *2 *3) (-12 (-4 *4 (-842)) (-4 *5 (-788)) (-4 *6 (-350)) (-4 *7 (-950 *6 *5 *4)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-687 *4 *5 *6 *7)) (-5 *3 (-1157 *7)))) (-3850 (*1 *2 *3) (-12 (-4 *4 (-842)) (-4 *5 (-788)) (-4 *6 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-687 *4 *5 *6 *3)) (-4 *3 (-950 *6 *5 *4))))) 
+(-10 -7 (-15 -3850 ((-420 |#4|) |#4|)) (-15 -3850 ((-420 (-1157 |#4|)) (-1157 |#4|)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 84)) (-2563 (((-568) $) 30)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-4179 (($ $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-1904 (($ $) NIL)) (-2589 (((-121) $ $) NIL)) (-3337 (((-568) $) NIL)) (-4490 (($) NIL T CONST)) (-2252 (($ $) NIL)) (-3668 (((-3 (-568) "failed") $) 73) (((-3 (-409 (-568)) "failed") $) 26) (((-3 (-381) "failed") $) 70)) (-2857 (((-568) $) 75) (((-409 (-568)) $) 67) (((-381) $) 68)) (-2403 (($ $ $) 96)) (-2902 (((-3 $ "failed") $) 87)) (-2414 (($ $ $) 95)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-3359 (((-917)) 77) (((-917) (-917)) 76)) (-1436 (((-121) $) NIL)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL)) (-1844 (((-568) $) NIL)) (-1598 (((-121) $) NIL)) (-1550 (($ $ (-568)) NIL)) (-4417 (($ $) NIL)) (-2859 (((-121) $) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-4271 (((-568) (-568)) 81) (((-568)) 82)) (-1732 (($ $ $) NIL) (($) NIL (-12 (-3046 (|has| $ (-6 -4504))) (-3046 (|has| $ (-6 -4512)))))) (-3258 (((-568) (-568)) 79) (((-568)) 80)) (-2047 (($ $ $) NIL) (($) NIL (-12 (-3046 (|has| $ (-6 -4504))) (-3046 (|has| $ (-6 -4512)))))) (-2790 (((-568) $) 16)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) 91)) (-1529 (((-917) (-568)) NIL (|has| $ (-6 -4512)))) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1999 (($ $) NIL)) (-4115 (($ $) NIL)) (-3770 (($ (-568) (-568)) NIL) (($ (-568) (-568) (-917)) NIL)) (-3850 (((-420 $) $) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) 92)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3483 (((-568) $) 22)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 94)) (-1513 (((-917)) NIL) (((-917) (-917)) NIL (|has| $ (-6 -4512)))) (-1973 (((-917) (-568)) NIL (|has| $ (-6 -4512)))) (-4280 (((-381) $) NIL) (((-215) $) NIL) (((-887 (-381)) $) NIL)) (-2747 (((-850) $) 52) (($ (-568)) 63) (($ $) NIL) (($ (-409 (-568))) 66) (($ (-568)) 63) (($ (-409 (-568))) 66) (($ (-381)) 60) (((-381) $) 50) (($ (-690)) 55)) (-3425 (((-763)) 103)) (-1680 (($ (-568) (-568) (-917)) 44)) (-3520 (($ $) NIL)) (-1540 (((-917)) NIL) (((-917) (-917)) NIL (|has| $ (-6 -4512)))) (-2404 (((-917)) 35) (((-917) (-917)) 78)) (-2273 (((-121) $ $) NIL)) (-2811 (($ $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) 32 T CONST)) (-1557 (($) 17 T CONST)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 83)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 101)) (-1781 (($ $ $) 65)) (-1775 (($ $) 99) (($ $ $) 100)) (-1769 (($ $ $) 98)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL) (($ $ (-409 (-568))) 90)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 97) (($ $ $) 88) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL))) 
+(((-688) (-13 (-406) (-389) (-365) (-1037 (-381)) (-1037 (-409 (-568))) (-150) (-10 -8 (-15 -3359 ((-917) (-917))) (-15 -3359 ((-917))) (-15 -2404 ((-917) (-917))) (-15 -2404 ((-917))) (-15 -3258 ((-568) (-568))) (-15 -3258 ((-568))) (-15 -4271 ((-568) (-568))) (-15 -4271 ((-568))) (-15 -2747 ((-381) $)) (-15 -2747 ($ (-690))) (-15 -2790 ((-568) $)) (-15 -3483 ((-568) $)) (-15 -1680 ($ (-568) (-568) (-917)))))) (T -688)) 
+((-2404 (*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-688)))) (-3483 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-688)))) (-2790 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-688)))) (-3359 (*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-688)))) (-3359 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-688)))) (-2404 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-688)))) (-3258 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-688)))) (-3258 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-688)))) (-4271 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-688)))) (-4271 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-688)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-381)) (-5 *1 (-688)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-690)) (-5 *1 (-688)))) (-1680 (*1 *1 *2 *2 *3) (-12 (-5 *2 (-568)) (-5 *3 (-917)) (-5 *1 (-688))))) 
+(-13 (-406) (-389) (-365) (-1037 (-381)) (-1037 (-409 (-568))) (-150) (-10 -8 (-15 -3359 ((-917) (-917))) (-15 -3359 ((-917))) (-15 -2404 ((-917) (-917))) (-15 -2404 ((-917))) (-15 -3258 ((-568) (-568))) (-15 -3258 ((-568))) (-15 -4271 ((-568) (-568))) (-15 -4271 ((-568))) (-15 -2747 ((-381) $)) (-15 -2747 ($ (-690))) (-15 -2790 ((-568) $)) (-15 -3483 ((-568) $)) (-15 -1680 ($ (-568) (-568) (-917))))) 
+((-2507 (((-679 |#1|) (-679 |#1|) |#1| |#1|) 66)) (-3912 (((-679 |#1|) (-679 |#1|) |#1|) 49)) (-4472 (((-679 |#1|) (-679 |#1|) |#1|) 67)) (-4121 (((-679 |#1|) (-679 |#1|)) 50)) (-1555 (((-2 (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1|) 65))) 
+(((-689 |#1|) (-10 -7 (-15 -4121 ((-679 |#1|) (-679 |#1|))) (-15 -3912 ((-679 |#1|) (-679 |#1|) |#1|)) (-15 -4472 ((-679 |#1|) (-679 |#1|) |#1|)) (-15 -2507 ((-679 |#1|) (-679 |#1|) |#1| |#1|)) (-15 -1555 ((-2 (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1|))) (-301)) (T -689)) 
+((-1555 (*1 *2 *3 *3) (-12 (-5 *2 (-2 (|:| -4409 *3) (|:| -2607 *3))) (-5 *1 (-689 *3)) (-4 *3 (-301)))) (-2507 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-679 *3)) (-4 *3 (-301)) (-5 *1 (-689 *3)))) (-4472 (*1 *2 *2 *3) (-12 (-5 *2 (-679 *3)) (-4 *3 (-301)) (-5 *1 (-689 *3)))) (-3912 (*1 *2 *2 *3) (-12 (-5 *2 (-679 *3)) (-4 *3 (-301)) (-5 *1 (-689 *3)))) (-4121 (*1 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-301)) (-5 *1 (-689 *3))))) 
+(-10 -7 (-15 -4121 ((-679 |#1|) (-679 |#1|))) (-15 -3912 ((-679 |#1|) (-679 |#1|) |#1|)) (-15 -4472 ((-679 |#1|) (-679 |#1|) |#1|)) (-15 -2507 ((-679 |#1|) (-679 |#1|) |#1| |#1|)) (-15 -1555 ((-2 (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2519 (($ $ $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-1353 (($ $ $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2589 (((-121) $ $) NIL)) (-3337 (((-568) $) NIL)) (-1872 (($ $ $) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) 27)) (-2857 (((-568) $) 25)) (-2403 (($ $ $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-3254 (((-3 (-409 (-568)) "failed") $) NIL)) (-1338 (((-121) $) NIL)) (-2394 (((-409 (-568)) $) NIL)) (-1733 (($ $) NIL) (($) NIL)) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-2382 (($ $ $ $) NIL)) (-3155 (($ $ $) NIL)) (-1436 (((-121) $) NIL)) (-2341 (($ $ $) NIL)) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL)) (-1598 (((-121) $) NIL)) (-2268 (((-121) $) NIL)) (-2214 (((-3 $ "failed") $) NIL)) (-2859 (((-121) $) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-4374 (($ $ $ $) NIL)) (-1732 (($ $ $) NIL)) (-2127 (((-917) (-917)) 10) (((-917)) 9)) (-2047 (($ $ $) NIL)) (-3248 (($ $) NIL)) (-3680 (($ $) NIL)) (-2498 (($ (-634 $)) NIL) (($ $ $) NIL)) (-1893 (((-1143) $) NIL)) (-3264 (($ $ $) NIL)) (-4436 (($) NIL T CONST)) (-1890 (($ $) NIL)) (-4025 (((-1108) $) NIL) (($ $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ (-634 $)) NIL) (($ $ $) NIL)) (-2406 (($ $) NIL)) (-3850 (((-420 $) $) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2080 (((-121) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-4191 (($ $) NIL) (($ $ (-763)) NIL)) (-3953 (($ $) NIL)) (-3865 (($ $) NIL)) (-4280 (((-215) $) NIL) (((-381) $) NIL) (((-887 (-568)) $) NIL) (((-541) $) NIL) (((-568) $) NIL)) (-2747 (((-850) $) NIL) (($ (-568)) 24) (($ $) NIL) (($ (-568)) 24) (((-310 $) (-310 (-568))) 18)) (-3425 (((-763)) NIL)) (-3600 (((-121) $ $) NIL)) (-3584 (($ $ $) NIL)) (-2404 (($) NIL)) (-2273 (((-121) $ $) NIL)) (-1564 (($ $ $ $) NIL)) (-2811 (($ $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $) NIL) (($ $ (-763)) NIL)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL))) 
+(((-690) (-13 (-389) (-550) (-10 -8 (-15 -2127 ((-917) (-917))) (-15 -2127 ((-917))) (-15 -2747 ((-310 $) (-310 (-568))))))) (T -690)) 
+((-2127 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-690)))) (-2127 (*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-690)))) (-2747 (*1 *2 *3) (-12 (-5 *3 (-310 (-568))) (-5 *2 (-310 (-690))) (-5 *1 (-690))))) 
+(-13 (-389) (-550) (-10 -8 (-15 -2127 ((-917) (-917))) (-15 -2127 ((-917))) (-15 -2747 ((-310 $) (-310 (-568)))))) 
+((-3883 (((-1 |#4| |#2| |#3|) |#1| (-1161) (-1161)) 19)) (-3824 (((-1 |#4| |#2| |#3|) (-1161)) 12))) 
+(((-691 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3824 ((-1 |#4| |#2| |#3|) (-1161))) (-15 -3883 ((-1 |#4| |#2| |#3|) |#1| (-1161) (-1161)))) (-609 (-541)) (-1195) (-1195) (-1195)) (T -691)) 
+((-3883 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-1161)) (-5 *2 (-1 *7 *5 *6)) (-5 *1 (-691 *3 *5 *6 *7)) (-4 *3 (-609 (-541))) (-4 *5 (-1195)) (-4 *6 (-1195)) (-4 *7 (-1195)))) (-3824 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 *7 *5 *6)) (-5 *1 (-691 *4 *5 *6 *7)) (-4 *4 (-609 (-541))) (-4 *5 (-1195)) (-4 *6 (-1195)) (-4 *7 (-1195))))) 
+(-10 -7 (-15 -3824 ((-1 |#4| |#2| |#3|) (-1161))) (-15 -3883 ((-1 |#4| |#2| |#3|) |#1| (-1161) (-1161)))) 
+((-2449 (((-121) $ $) NIL)) (-2704 (((-1249) $ (-763)) 14)) (-2766 (((-763) $) 12)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 18) ((|#1| $) 15) (($ |#1|) 23)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 25)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 24))) 
+(((-692 |#1|) (-13 (-138) (-608 |#1|) (-10 -8 (-15 -2747 ($ |#1|)))) (-1090)) (T -692)) 
+((-2747 (*1 *1 *2) (-12 (-5 *1 (-692 *2)) (-4 *2 (-1090))))) 
+(-13 (-138) (-608 |#1|) (-10 -8 (-15 -2747 ($ |#1|)))) 
+((-1759 (((-1 (-215) (-215) (-215)) |#1| (-1161) (-1161)) 33) (((-1 (-215) (-215)) |#1| (-1161)) 38))) 
+(((-693 |#1|) (-10 -7 (-15 -1759 ((-1 (-215) (-215)) |#1| (-1161))) (-15 -1759 ((-1 (-215) (-215) (-215)) |#1| (-1161) (-1161)))) (-609 (-541))) (T -693)) 
+((-1759 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-1161)) (-5 *2 (-1 (-215) (-215) (-215))) (-5 *1 (-693 *3)) (-4 *3 (-609 (-541))))) (-1759 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-5 *2 (-1 (-215) (-215))) (-5 *1 (-693 *3)) (-4 *3 (-609 (-541)))))) 
+(-10 -7 (-15 -1759 ((-1 (-215) (-215)) |#1| (-1161))) (-15 -1759 ((-1 (-215) (-215) (-215)) |#1| (-1161) (-1161)))) 
+((-1866 (((-1161) |#1| (-1161) (-634 (-1161))) 9) (((-1161) |#1| (-1161) (-1161) (-1161)) 12) (((-1161) |#1| (-1161) (-1161)) 11) (((-1161) |#1| (-1161)) 10))) 
+(((-694 |#1|) (-10 -7 (-15 -1866 ((-1161) |#1| (-1161))) (-15 -1866 ((-1161) |#1| (-1161) (-1161))) (-15 -1866 ((-1161) |#1| (-1161) (-1161) (-1161))) (-15 -1866 ((-1161) |#1| (-1161) (-634 (-1161))))) (-609 (-541))) (T -694)) 
+((-1866 (*1 *2 *3 *2 *4) (-12 (-5 *4 (-634 (-1161))) (-5 *2 (-1161)) (-5 *1 (-694 *3)) (-4 *3 (-609 (-541))))) (-1866 (*1 *2 *3 *2 *2 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-694 *3)) (-4 *3 (-609 (-541))))) (-1866 (*1 *2 *3 *2 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-694 *3)) (-4 *3 (-609 (-541))))) (-1866 (*1 *2 *3 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-694 *3)) (-4 *3 (-609 (-541)))))) 
+(-10 -7 (-15 -1866 ((-1161) |#1| (-1161))) (-15 -1866 ((-1161) |#1| (-1161) (-1161))) (-15 -1866 ((-1161) |#1| (-1161) (-1161) (-1161))) (-15 -1866 ((-1161) |#1| (-1161) (-634 (-1161))))) 
+((-2820 (((-2 (|:| |part1| |#1|) (|:| |part2| |#2|)) |#1| |#2|) 9))) 
+(((-695 |#1| |#2|) (-10 -7 (-15 -2820 ((-2 (|:| |part1| |#1|) (|:| |part2| |#2|)) |#1| |#2|))) (-1195) (-1195)) (T -695)) 
+((-2820 (*1 *2 *3 *4) (-12 (-5 *2 (-2 (|:| |part1| *3) (|:| |part2| *4))) (-5 *1 (-695 *3 *4)) (-4 *3 (-1195)) (-4 *4 (-1195))))) 
+(-10 -7 (-15 -2820 ((-2 (|:| |part1| |#1|) (|:| |part2| |#2|)) |#1| |#2|))) 
+((-3004 (((-1 |#3| |#2|) (-1161)) 11)) (-3883 (((-1 |#3| |#2|) |#1| (-1161)) 21))) 
+(((-696 |#1| |#2| |#3|) (-10 -7 (-15 -3004 ((-1 |#3| |#2|) (-1161))) (-15 -3883 ((-1 |#3| |#2|) |#1| (-1161)))) (-609 (-541)) (-1195) (-1195)) (T -696)) 
+((-3883 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-5 *2 (-1 *6 *5)) (-5 *1 (-696 *3 *5 *6)) (-4 *3 (-609 (-541))) (-4 *5 (-1195)) (-4 *6 (-1195)))) (-3004 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 *6 *5)) (-5 *1 (-696 *4 *5 *6)) (-4 *4 (-609 (-541))) (-4 *5 (-1195)) (-4 *6 (-1195))))) 
+(-10 -7 (-15 -3004 ((-1 |#3| |#2|) (-1161))) (-15 -3883 ((-1 |#3| |#2|) |#1| (-1161)))) 
+((-2130 (((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-634 |#2|) (-634 (-1157 |#4|)) (-634 |#3|) (-634 |#4|) (-634 (-634 (-2 (|:| -2514 (-763)) (|:| |pcoef| |#4|)))) (-634 (-763)) (-1244 (-634 (-1157 |#3|))) |#3|) 58)) (-3619 (((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-634 |#2|) (-634 (-1157 |#3|)) (-634 |#3|) (-634 |#4|) (-634 (-763)) |#3|) 71)) (-2850 (((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-634 |#2|) (-634 |#3|) (-634 (-763)) (-634 (-1157 |#4|)) (-1244 (-634 (-1157 |#3|))) |#3|) 32))) 
+(((-697 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2850 ((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-634 |#2|) (-634 |#3|) (-634 (-763)) (-634 (-1157 |#4|)) (-1244 (-634 (-1157 |#3|))) |#3|)) (-15 -3619 ((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-634 |#2|) (-634 (-1157 |#3|)) (-634 |#3|) (-634 |#4|) (-634 (-763)) |#3|)) (-15 -2130 ((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-634 |#2|) (-634 (-1157 |#4|)) (-634 |#3|) (-634 |#4|) (-634 (-634 (-2 (|:| -2514 (-763)) (|:| |pcoef| |#4|)))) (-634 (-763)) (-1244 (-634 (-1157 |#3|))) |#3|))) (-788) (-842) (-301) (-950 |#3| |#1| |#2|)) (T -697)) 
+((-2130 (*1 *2 *3 *4 *2 *5 *6 *7 *8 *9 *10) (|partial| -12 (-5 *2 (-634 (-1157 *13))) (-5 *3 (-1157 *13)) (-5 *4 (-634 *12)) (-5 *5 (-634 *10)) (-5 *6 (-634 *13)) (-5 *7 (-634 (-634 (-2 (|:| -2514 (-763)) (|:| |pcoef| *13))))) (-5 *8 (-634 (-763))) (-5 *9 (-1244 (-634 (-1157 *10)))) (-4 *12 (-842)) (-4 *10 (-301)) (-4 *13 (-950 *10 *11 *12)) (-4 *11 (-788)) (-5 *1 (-697 *11 *12 *10 *13)))) (-3619 (*1 *2 *3 *4 *5 *6 *7 *8 *9) (|partial| -12 (-5 *4 (-634 *11)) (-5 *5 (-634 (-1157 *9))) (-5 *6 (-634 *9)) (-5 *7 (-634 *12)) (-5 *8 (-634 (-763))) (-4 *11 (-842)) (-4 *9 (-301)) (-4 *12 (-950 *9 *10 *11)) (-4 *10 (-788)) (-5 *2 (-634 (-1157 *12))) (-5 *1 (-697 *10 *11 *9 *12)) (-5 *3 (-1157 *12)))) (-2850 (*1 *2 *3 *4 *5 *6 *2 *7 *8) (|partial| -12 (-5 *2 (-634 (-1157 *11))) (-5 *3 (-1157 *11)) (-5 *4 (-634 *10)) (-5 *5 (-634 *8)) (-5 *6 (-634 (-763))) (-5 *7 (-1244 (-634 (-1157 *8)))) (-4 *10 (-842)) (-4 *8 (-301)) (-4 *11 (-950 *8 *9 *10)) (-4 *9 (-788)) (-5 *1 (-697 *9 *10 *8 *11))))) 
+(-10 -7 (-15 -2850 ((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-634 |#2|) (-634 |#3|) (-634 (-763)) (-634 (-1157 |#4|)) (-1244 (-634 (-1157 |#3|))) |#3|)) (-15 -3619 ((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-634 |#2|) (-634 (-1157 |#3|)) (-634 |#3|) (-634 |#4|) (-634 (-763)) |#3|)) (-15 -2130 ((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-634 |#2|) (-634 (-1157 |#4|)) (-634 |#3|) (-634 |#4|) (-634 (-634 (-2 (|:| -2514 (-763)) (|:| |pcoef| |#4|)))) (-634 (-763)) (-1244 (-634 (-1157 |#3|))) |#3|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-2116 (($ $) 40)) (-2902 (((-3 $ "failed") $) 33)) (-1598 (((-121) $) 30)) (-2049 (($ |#1| (-763)) 38)) (-3524 (((-763) $) 42)) (-2104 ((|#1| $) 41)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-1836 (((-763) $) 43)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 37 (|has| |#1| (-172)))) (-2079 ((|#1| $ (-763)) 39)) (-3425 (((-763)) 28)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 45) (($ |#1| $) 44))) 
 (((-698 |#1|) (-1275) (-1047)) (T -698)) 
-((-3206 (*1 *2 *1) (-12 (-4 *1 (-698 *3)) (-4 *3 (-1047)) (-5 *2 (-763)))) (-2144 (*1 *2 *1) (-12 (-4 *1 (-698 *3)) (-4 *3 (-1047)) (-5 *2 (-763)))) (-2102 (*1 *2 *1) (-12 (-4 *1 (-698 *2)) (-4 *2 (-1047)))) (-2114 (*1 *1 *1) (-12 (-4 *1 (-698 *2)) (-4 *2 (-1047)))) (-2604 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-698 *2)) (-4 *2 (-1047)))) (-2047 (*1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-698 *2)) (-4 *2 (-1047))))) 
-(-13 (-1047) (-120 |t#1| |t#1|) (-10 -8 (IF (|has| |t#1| (-172)) (-6 (-43 |t#1|)) |noBranch|) (-15 -3206 ((-763) $)) (-15 -2144 ((-763) $)) (-15 -2102 (|t#1| $)) (-15 -2114 ($ $)) (-15 -2604 (|t#1| $ (-763))) (-15 -2047 ($ |t#1| (-763))))) 
+((-1836 (*1 *2 *1) (-12 (-4 *1 (-698 *3)) (-4 *3 (-1047)) (-5 *2 (-763)))) (-3524 (*1 *2 *1) (-12 (-4 *1 (-698 *3)) (-4 *3 (-1047)) (-5 *2 (-763)))) (-2104 (*1 *2 *1) (-12 (-4 *1 (-698 *2)) (-4 *2 (-1047)))) (-2116 (*1 *1 *1) (-12 (-4 *1 (-698 *2)) (-4 *2 (-1047)))) (-2079 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-698 *2)) (-4 *2 (-1047)))) (-2049 (*1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-698 *2)) (-4 *2 (-1047))))) 
+(-13 (-1047) (-120 |t#1| |t#1|) (-10 -8 (IF (|has| |t#1| (-172)) (-6 (-43 |t#1|)) |noBranch|) (-15 -1836 ((-763) $)) (-15 -3524 ((-763) $)) (-15 -2104 (|t#1| $)) (-15 -2116 ($ $)) (-15 -2079 (|t#1| $ (-763))) (-15 -2049 ($ |t#1| (-763))))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#1|) |has| |#1| (-172)) ((-105) . T) ((-120 |#1| |#1|) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 |#1|) . T) ((-637 $) . T) ((-707 |#1|) |has| |#1| (-172)) ((-716) . T) ((-1053 |#1|) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-2795 ((|#6| (-1 |#4| |#1|) |#3|) 23))) 
-(((-699 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -2795 (|#6| (-1 |#4| |#1|) |#3|))) (-558) (-1219 |#1|) (-1219 (-409 |#2|)) (-558) (-1219 |#4|) (-1219 (-409 |#5|))) (T -699)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-558)) (-4 *7 (-558)) (-4 *6 (-1219 *5)) (-4 *2 (-1219 (-409 *8))) (-5 *1 (-699 *5 *6 *4 *7 *8 *2)) (-4 *4 (-1219 (-409 *6))) (-4 *8 (-1219 *7))))) 
-(-10 -7 (-15 -2795 (|#6| (-1 |#4| |#1|) |#3|))) 
-((-2447 (((-121) $ $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-3253 (((-1143) (-850)) 31)) (-4125 (((-1249) (-1143)) 28)) (-3346 (((-1143) (-850)) 24)) (-2857 (((-1143) (-850)) 25)) (-2745 (((-850) $) NIL) (((-1143) (-850)) 23)) (-1717 (((-121) $ $) NIL))) 
-(((-700) (-13 (-1090) (-10 -7 (-15 -2745 ((-1143) (-850))) (-15 -3346 ((-1143) (-850))) (-15 -2857 ((-1143) (-850))) (-15 -3253 ((-1143) (-850))) (-15 -4125 ((-1249) (-1143)))))) (T -700)) 
-((-2745 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-700)))) (-3346 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-700)))) (-2857 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-700)))) (-3253 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-700)))) (-4125 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-700))))) 
-(-13 (-1090) (-10 -7 (-15 -2745 ((-1143) (-850))) (-15 -3346 ((-1143) (-850))) (-15 -2857 ((-1143) (-850))) (-15 -3253 ((-1143) (-850))) (-15 -4125 ((-1249) (-1143))))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1497 (((-121) $ $) NIL)) (-2671 (($) NIL T CONST)) (-2401 (($ $ $) NIL)) (-3092 (($ |#1| |#2|) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-2735 (((-121) $) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3094 ((|#2| $) NIL)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3848 (((-420 $) $) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3697 (((-3 $ "failed") $ $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) ((|#1| $) NIL)) (-4078 (((-763)) NIL)) (-1826 (((-121) $ $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL))) 
-(((-701 |#1| |#2| |#3| |#4| |#5|) (-13 (-365) (-10 -8 (-15 -3094 (|#2| $)) (-15 -2745 (|#1| $)) (-15 -3092 ($ |#1| |#2|)) (-15 -3697 ((-3 $ "failed") $ $)))) (-172) (-23) (-1 |#1| |#1| |#2|) (-1 (-3 |#2| "failed") |#2| |#2|) (-1 (-3 |#1| "failed") |#1| |#1| |#2|)) (T -701)) 
-((-3094 (*1 *2 *1) (-12 (-4 *2 (-23)) (-5 *1 (-701 *3 *2 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-1 *3 *3 *2)) (-14 *5 (-1 (-3 *2 "failed") *2 *2)) (-14 *6 (-1 (-3 *3 "failed") *3 *3 *2)))) (-2745 (*1 *2 *1) (-12 (-4 *2 (-172)) (-5 *1 (-701 *2 *3 *4 *5 *6)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-3092 (*1 *1 *2 *3) (-12 (-5 *1 (-701 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-3697 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-701 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3))))) 
-(-13 (-365) (-10 -8 (-15 -3094 (|#2| $)) (-15 -2745 (|#1| $)) (-15 -3092 ($ |#1| |#2|)) (-15 -3697 ((-3 $ "failed") $ $)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 30)) (-2572 (((-1244 |#1|) $ (-763)) NIL)) (-2055 (((-634 (-1075)) $) NIL)) (-3197 (($ (-1157 |#1|)) NIL)) (-3839 (((-1157 $) $ (-1075)) NIL) (((-1157 |#1|) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-2773 (((-763) $) NIL) (((-763) $ (-634 (-1075))) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-3809 (($ $ $) NIL (|has| |#1| (-558)))) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-4305 (($ $) NIL (|has| |#1| (-453)))) (-1678 (((-420 $) $) NIL (|has| |#1| (-453)))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-1497 (((-121) $ $) NIL (|has| |#1| (-365)))) (-3983 (((-763)) 46 (|has| |#1| (-370)))) (-3151 (($ $ (-763)) NIL)) (-3772 (($ $ (-763)) NIL)) (-3010 ((|#2| |#2|) 43)) (-1619 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#1| (-453)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-1075) "failed") $) NIL)) (-2854 ((|#1| $) NIL) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-1075) $) NIL)) (-4265 (($ $ $ (-1075)) NIL (|has| |#1| (-172))) ((|#1| $ $) NIL (|has| |#1| (-172)))) (-2401 (($ $ $) NIL (|has| |#1| (-365)))) (-2114 (($ $) 33)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-3092 (($ |#2|) 41)) (-2925 (((-3 $ "failed") $) 84)) (-1731 (($) 50 (|has| |#1| (-370)))) (-2412 (($ $ $) NIL (|has| |#1| (-365)))) (-3002 (($ $ $) NIL)) (-3581 (($ $ $) NIL (|has| |#1| (-558)))) (-4144 (((-2 (|:| -2348 |#1|) (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-558)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-3250 (($ $) NIL (|has| |#1| (-453))) (($ $ (-1075)) NIL (|has| |#1| (-453)))) (-2108 (((-634 $) $) NIL)) (-3927 (((-121) $) NIL (|has| |#1| (-904)))) (-3959 (((-958 $)) 78)) (-3088 (($ $ |#1| (-763) $) NIL)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-1075) (-881 (-381))) (|has| |#1| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-1075) (-881 (-568))) (|has| |#1| (-881 (-568)))))) (-4477 (((-763) $ $) NIL (|has| |#1| (-558)))) (-2735 (((-121) $) NIL)) (-4178 (((-763) $) NIL)) (-3038 (((-3 $ "failed") $) NIL (|has| |#1| (-1136)))) (-2051 (($ (-1157 |#1|) (-1075)) NIL) (($ (-1157 $) (-1075)) NIL)) (-3536 (($ $ (-763)) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-2976 (((-634 $) $) NIL)) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| (-763)) 76) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-3379 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $ (-1075)) NIL) (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3094 ((|#2|) 44)) (-2144 (((-763) $) NIL) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-3842 (($ (-1 (-763) (-763)) $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-3764 (((-1157 |#1|) $) NIL)) (-2244 (((-3 (-1075) "failed") $) NIL)) (-3683 (((-917) $) NIL (|has| |#1| (-370)))) (-3085 ((|#2| $) 40)) (-2097 (($ $) NIL)) (-2102 ((|#1| $) 28)) (-2495 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-4487 (((-1143) $) NIL)) (-1643 (((-2 (|:| -3961 $) (|:| -1500 $)) $ (-763)) NIL)) (-3324 (((-3 (-634 $) "failed") $) NIL)) (-1794 (((-3 (-634 $) "failed") $) NIL)) (-3751 (((-3 (-2 (|:| |var| (-1075)) (|:| -3438 (-763))) "failed") $) NIL)) (-3837 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4434 (($) NIL (|has| |#1| (-1136)) CONST)) (-4355 (($ (-917)) NIL (|has| |#1| (-370)))) (-4022 (((-1108) $) NIL)) (-2086 (((-121) $) NIL)) (-2091 ((|#1| $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-453)))) (-2721 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-3146 (($ $) 77 (|has| |#1| (-350)))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3848 (((-420 $) $) NIL (|has| |#1| (-904)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-365)))) (-2595 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558))) (((-3 $ "failed") $ $) 83 (|has| |#1| (-558)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-1075) |#1|) NIL) (($ $ (-634 (-1075)) (-634 |#1|)) NIL) (($ $ (-1075) $) NIL) (($ $ (-634 (-1075)) (-634 $)) NIL)) (-2709 (((-763) $) NIL (|has| |#1| (-365)))) (-2779 ((|#1| $ |#1|) NIL) (($ $ $) NIL) (((-409 $) (-409 $) (-409 $)) NIL (|has| |#1| (-558))) ((|#1| (-409 $) |#1|) NIL (|has| |#1| (-365))) (((-409 $) $ (-409 $)) NIL (|has| |#1| (-558)))) (-2167 (((-3 $ "failed") $ (-763)) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 85 (|has| |#1| (-365)))) (-2217 (($ $ (-1075)) NIL (|has| |#1| (-172))) ((|#1| $) NIL (|has| |#1| (-172)))) (-4189 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-1 |#1| |#1|) $) NIL)) (-3206 (((-763) $) 31) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-4278 (((-887 (-381)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-1075) (-609 (-541))) (|has| |#1| (-609 (-541)))))) (-3367 ((|#1| $) NIL (|has| |#1| (-453))) (($ $ (-1075)) NIL (|has| |#1| (-453)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#1| (-904))))) (-1449 (((-958 $)) 35)) (-3950 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558))) (((-3 (-409 $) "failed") (-409 $) $) NIL (|has| |#1| (-558)))) (-2745 (((-850) $) 60) (($ (-568)) NIL) (($ |#1|) 57) (($ (-1075)) NIL) (($ |#2|) 67) (($ (-409 (-568))) NIL (-2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#1| (-558)))) (-1302 (((-634 |#1|) $) NIL)) (-2604 ((|#1| $ (-763)) 62) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-4078 (((-763)) NIL)) (-4171 (($ $ $ (-763)) NIL (|has| |#1| (-172)))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 20 T CONST)) (-1977 (((-1244 |#1|) $) 74)) (-4172 (($ (-1244 |#1|)) 49)) (-1556 (($) 8 T CONST)) (-3190 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-2332 (((-1244 |#1|) $) NIL)) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) 68)) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1773 (($ $) 71) (($ $ $) NIL)) (-1767 (($ $ $) 32)) (** (($ $ (-917)) NIL) (($ $ (-763)) 79)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 56) (($ $ $) 73) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) 54) (($ $ |#1|) NIL))) 
-(((-702 |#1| |#2|) (-13 (-1219 |#1|) (-10 -8 (-15 -3010 (|#2| |#2|)) (-15 -3094 (|#2|)) (-15 -3092 ($ |#2|)) (-15 -3085 (|#2| $)) (-15 -2745 ($ |#2|)) (-15 -1977 ((-1244 |#1|) $)) (-15 -4172 ($ (-1244 |#1|))) (-15 -2332 ((-1244 |#1|) $)) (-15 -3959 ((-958 $))) (-15 -1449 ((-958 $))) (IF (|has| |#1| (-350)) (-15 -3146 ($ $)) |noBranch|) (IF (|has| |#1| (-370)) (-6 (-370)) |noBranch|))) (-1047) (-1219 |#1|)) (T -702)) 
-((-3010 (*1 *2 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-702 *3 *2)) (-4 *2 (-1219 *3)))) (-3094 (*1 *2) (-12 (-4 *2 (-1219 *3)) (-5 *1 (-702 *3 *2)) (-4 *3 (-1047)))) (-3092 (*1 *1 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-702 *3 *2)) (-4 *2 (-1219 *3)))) (-3085 (*1 *2 *1) (-12 (-4 *2 (-1219 *3)) (-5 *1 (-702 *3 *2)) (-4 *3 (-1047)))) (-2745 (*1 *1 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-702 *3 *2)) (-4 *2 (-1219 *3)))) (-1977 (*1 *2 *1) (-12 (-4 *3 (-1047)) (-5 *2 (-1244 *3)) (-5 *1 (-702 *3 *4)) (-4 *4 (-1219 *3)))) (-4172 (*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-1047)) (-5 *1 (-702 *3 *4)) (-4 *4 (-1219 *3)))) (-2332 (*1 *2 *1) (-12 (-4 *3 (-1047)) (-5 *2 (-1244 *3)) (-5 *1 (-702 *3 *4)) (-4 *4 (-1219 *3)))) (-3959 (*1 *2) (-12 (-4 *3 (-1047)) (-5 *2 (-958 (-702 *3 *4))) (-5 *1 (-702 *3 *4)) (-4 *4 (-1219 *3)))) (-1449 (*1 *2) (-12 (-4 *3 (-1047)) (-5 *2 (-958 (-702 *3 *4))) (-5 *1 (-702 *3 *4)) (-4 *4 (-1219 *3)))) (-3146 (*1 *1 *1) (-12 (-4 *2 (-350)) (-4 *2 (-1047)) (-5 *1 (-702 *2 *3)) (-4 *3 (-1219 *2))))) 
-(-13 (-1219 |#1|) (-10 -8 (-15 -3010 (|#2| |#2|)) (-15 -3094 (|#2|)) (-15 -3092 ($ |#2|)) (-15 -3085 (|#2| $)) (-15 -2745 ($ |#2|)) (-15 -1977 ((-1244 |#1|) $)) (-15 -4172 ($ (-1244 |#1|))) (-15 -2332 ((-1244 |#1|) $)) (-15 -3959 ((-958 $))) (-15 -1449 ((-958 $))) (IF (|has| |#1| (-350)) (-15 -3146 ($ $)) |noBranch|) (IF (|has| |#1| (-370)) (-6 (-370)) |noBranch|))) 
-((-2447 (((-121) $ $) NIL)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-4487 (((-1143) $) NIL)) (-4355 ((|#1| $) 13)) (-4022 (((-1108) $) NIL)) (-3438 ((|#2| $) 12)) (-4287 (($ |#1| |#2|) 16)) (-2745 (((-850) $) NIL) (($ (-2 (|:| -4355 |#1|) (|:| -3438 |#2|))) 15) (((-2 (|:| -4355 |#1|) (|:| -3438 |#2|)) $) 14)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 11))) 
-(((-703 |#1| |#2| |#3|) (-13 (-842) (-10 -8 (-15 -3438 (|#2| $)) (-15 -4355 (|#1| $)) (-15 -2745 ($ (-2 (|:| -4355 |#1|) (|:| -3438 |#2|)))) (-15 -2745 ((-2 (|:| -4355 |#1|) (|:| -3438 |#2|)) $)) (-15 -4287 ($ |#1| |#2|)))) (-842) (-1090) (-1 (-121) (-2 (|:| -4355 |#1|) (|:| -3438 |#2|)) (-2 (|:| -4355 |#1|) (|:| -3438 |#2|)))) (T -703)) 
-((-3438 (*1 *2 *1) (-12 (-4 *2 (-1090)) (-5 *1 (-703 *3 *2 *4)) (-4 *3 (-842)) (-14 *4 (-1 (-121) (-2 (|:| -4355 *3) (|:| -3438 *2)) (-2 (|:| -4355 *3) (|:| -3438 *2)))))) (-4355 (*1 *2 *1) (-12 (-4 *2 (-842)) (-5 *1 (-703 *2 *3 *4)) (-4 *3 (-1090)) (-14 *4 (-1 (-121) (-2 (|:| -4355 *2) (|:| -3438 *3)) (-2 (|:| -4355 *2) (|:| -3438 *3)))))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| -4355 *3) (|:| -3438 *4))) (-4 *3 (-842)) (-4 *4 (-1090)) (-5 *1 (-703 *3 *4 *5)) (-14 *5 (-1 (-121) *2 *2)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| -4355 *3) (|:| -3438 *4))) (-5 *1 (-703 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-1090)) (-14 *5 (-1 (-121) *2 *2)))) (-4287 (*1 *1 *2 *3) (-12 (-5 *1 (-703 *2 *3 *4)) (-4 *2 (-842)) (-4 *3 (-1090)) (-14 *4 (-1 (-121) (-2 (|:| -4355 *2) (|:| -3438 *3)) (-2 (|:| -4355 *2) (|:| -3438 *3))))))) 
-(-13 (-842) (-10 -8 (-15 -3438 (|#2| $)) (-15 -4355 (|#1| $)) (-15 -2745 ($ (-2 (|:| -4355 |#1|) (|:| -3438 |#2|)))) (-15 -2745 ((-2 (|:| -4355 |#1|) (|:| -3438 |#2|)) $)) (-15 -4287 ($ |#1| |#2|)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 59)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) 89) (((-3 (-123) "failed") $) 95)) (-2854 ((|#1| $) NIL) (((-123) $) 39)) (-2925 (((-3 $ "failed") $) 90)) (-4432 ((|#2| (-123) |#2|) 82)) (-2735 (((-121) $) NIL)) (-2276 (($ |#1| (-363 (-123))) 13)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2082 (($ $ (-1 |#2| |#2|)) 58)) (-1481 (($ $ (-1 |#2| |#2|)) 44)) (-2779 ((|#2| $ |#2|) 32)) (-1730 ((|#1| |#1|) 100 (|has| |#1| (-172)))) (-2745 (((-850) $) 66) (($ (-568)) 17) (($ |#1|) 16) (($ (-123)) 23)) (-4371 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-4078 (((-763)) 36)) (-4391 (($ $) 99 (|has| |#1| (-172))) (($ $ $) 103 (|has| |#1| (-172)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 20 T CONST)) (-1556 (($) 9 T CONST)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) 48) (($ $ $) NIL)) (-1767 (($ $ $) 73)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ (-123) (-568)) NIL) (($ $ (-568)) 57)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 98) (($ $ $) 50) (($ |#1| $) 96 (|has| |#1| (-172))) (($ $ |#1|) 97 (|has| |#1| (-172))))) 
-(((-704 |#1| |#2|) (-13 (-1047) (-1037 |#1|) (-1037 (-123)) (-281 |#2| |#2|) (-10 -8 (IF (|has| |#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |#1| (-172)) (PROGN (-6 (-43 |#1|)) (-15 -4391 ($ $)) (-15 -4391 ($ $ $)) (-15 -1730 (|#1| |#1|))) |noBranch|) (-15 -1481 ($ $ (-1 |#2| |#2|))) (-15 -2082 ($ $ (-1 |#2| |#2|))) (-15 ** ($ (-123) (-568))) (-15 ** ($ $ (-568))) (-15 -4432 (|#2| (-123) |#2|)) (-15 -2276 ($ |#1| (-363 (-123)))))) (-1047) (-637 |#1|)) (T -704)) 
-((-4391 (*1 *1 *1) (-12 (-4 *2 (-172)) (-4 *2 (-1047)) (-5 *1 (-704 *2 *3)) (-4 *3 (-637 *2)))) (-4391 (*1 *1 *1 *1) (-12 (-4 *2 (-172)) (-4 *2 (-1047)) (-5 *1 (-704 *2 *3)) (-4 *3 (-637 *2)))) (-1730 (*1 *2 *2) (-12 (-4 *2 (-172)) (-4 *2 (-1047)) (-5 *1 (-704 *2 *3)) (-4 *3 (-637 *2)))) (-1481 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-637 *3)) (-4 *3 (-1047)) (-5 *1 (-704 *3 *4)))) (-2082 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-637 *3)) (-4 *3 (-1047)) (-5 *1 (-704 *3 *4)))) (** (*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-568)) (-4 *4 (-1047)) (-5 *1 (-704 *4 *5)) (-4 *5 (-637 *4)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *3 (-1047)) (-5 *1 (-704 *3 *4)) (-4 *4 (-637 *3)))) (-4432 (*1 *2 *3 *2) (-12 (-5 *3 (-123)) (-4 *4 (-1047)) (-5 *1 (-704 *4 *2)) (-4 *2 (-637 *4)))) (-2276 (*1 *1 *2 *3) (-12 (-5 *3 (-363 (-123))) (-4 *2 (-1047)) (-5 *1 (-704 *2 *4)) (-4 *4 (-637 *2))))) 
-(-13 (-1047) (-1037 |#1|) (-1037 (-123)) (-281 |#2| |#2|) (-10 -8 (IF (|has| |#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |#1| (-172)) (PROGN (-6 (-43 |#1|)) (-15 -4391 ($ $)) (-15 -4391 ($ $ $)) (-15 -1730 (|#1| |#1|))) |noBranch|) (-15 -1481 ($ $ (-1 |#2| |#2|))) (-15 -2082 ($ $ (-1 |#2| |#2|))) (-15 ** ($ (-123) (-568))) (-15 ** ($ $ (-568))) (-15 -4432 (|#2| (-123) |#2|)) (-15 -2276 ($ |#1| (-363 (-123)))))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 33)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-3092 (($ |#1| |#2|) 25)) (-2925 (((-3 $ "failed") $) 47)) (-2735 (((-121) $) 35)) (-3094 ((|#2| $) 12)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) 48)) (-4022 (((-1108) $) NIL)) (-3697 (((-3 $ "failed") $ $) 46)) (-2745 (((-850) $) 24) (($ (-568)) 19) ((|#1| $) 13)) (-4078 (((-763)) 28)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 16 T CONST)) (-1556 (($) 30 T CONST)) (-1717 (((-121) $ $) 38)) (-1773 (($ $) 43) (($ $ $) 37)) (-1767 (($ $ $) 40)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 21) (($ $ $) 20))) 
-(((-705 |#1| |#2| |#3| |#4| |#5|) (-13 (-1047) (-10 -8 (-15 -3094 (|#2| $)) (-15 -2745 (|#1| $)) (-15 -3092 ($ |#1| |#2|)) (-15 -3697 ((-3 $ "failed") $ $)) (-15 -2925 ((-3 $ "failed") $)) (-15 -2081 ($ $)))) (-172) (-23) (-1 |#1| |#1| |#2|) (-1 (-3 |#2| "failed") |#2| |#2|) (-1 (-3 |#1| "failed") |#1| |#1| |#2|)) (T -705)) 
-((-2925 (*1 *1 *1) (|partial| -12 (-5 *1 (-705 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-3094 (*1 *2 *1) (-12 (-4 *2 (-23)) (-5 *1 (-705 *3 *2 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-1 *3 *3 *2)) (-14 *5 (-1 (-3 *2 "failed") *2 *2)) (-14 *6 (-1 (-3 *3 "failed") *3 *3 *2)))) (-2745 (*1 *2 *1) (-12 (-4 *2 (-172)) (-5 *1 (-705 *2 *3 *4 *5 *6)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-3092 (*1 *1 *2 *3) (-12 (-5 *1 (-705 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-3697 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-705 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-2081 (*1 *1 *1) (-12 (-5 *1 (-705 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3))))) 
-(-13 (-1047) (-10 -8 (-15 -3094 (|#2| $)) (-15 -2745 (|#1| $)) (-15 -3092 ($ |#1| |#2|)) (-15 -3697 ((-3 $ "failed") $ $)) (-15 -2925 ((-3 $ "failed") $)) (-15 -2081 ($ $)))) 
+((-2797 ((|#6| (-1 |#4| |#1|) |#3|) 23))) 
+(((-699 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -2797 (|#6| (-1 |#4| |#1|) |#3|))) (-558) (-1219 |#1|) (-1219 (-409 |#2|)) (-558) (-1219 |#4|) (-1219 (-409 |#5|))) (T -699)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-558)) (-4 *7 (-558)) (-4 *6 (-1219 *5)) (-4 *2 (-1219 (-409 *8))) (-5 *1 (-699 *5 *6 *4 *7 *8 *2)) (-4 *4 (-1219 (-409 *6))) (-4 *8 (-1219 *7))))) 
+(-10 -7 (-15 -2797 (|#6| (-1 |#4| |#1|) |#3|))) 
+((-2449 (((-121) $ $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2002 (((-1143) (-850)) 31)) (-4127 (((-1249) (-1143)) 28)) (-4481 (((-1143) (-850)) 24)) (-4010 (((-1143) (-850)) 25)) (-2747 (((-850) $) NIL) (((-1143) (-850)) 23)) (-1719 (((-121) $ $) NIL))) 
+(((-700) (-13 (-1090) (-10 -7 (-15 -2747 ((-1143) (-850))) (-15 -4481 ((-1143) (-850))) (-15 -4010 ((-1143) (-850))) (-15 -2002 ((-1143) (-850))) (-15 -4127 ((-1249) (-1143)))))) (T -700)) 
+((-2747 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-700)))) (-4481 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-700)))) (-4010 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-700)))) (-2002 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-700)))) (-4127 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-700))))) 
+(-13 (-1090) (-10 -7 (-15 -2747 ((-1143) (-850))) (-15 -4481 ((-1143) (-850))) (-15 -4010 ((-1143) (-850))) (-15 -2002 ((-1143) (-850))) (-15 -4127 ((-1249) (-1143))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2589 (((-121) $ $) NIL)) (-4490 (($) NIL T CONST)) (-2403 (($ $ $) NIL)) (-3094 (($ |#1| |#2|) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-1598 (((-121) $) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2477 ((|#2| $) NIL)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3850 (((-420 $) $) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2355 (((-3 $ "failed") $ $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) ((|#1| $) NIL)) (-3425 (((-763)) NIL)) (-2273 (((-121) $ $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL))) 
+(((-701 |#1| |#2| |#3| |#4| |#5|) (-13 (-365) (-10 -8 (-15 -2477 (|#2| $)) (-15 -2747 (|#1| $)) (-15 -3094 ($ |#1| |#2|)) (-15 -2355 ((-3 $ "failed") $ $)))) (-172) (-23) (-1 |#1| |#1| |#2|) (-1 (-3 |#2| "failed") |#2| |#2|) (-1 (-3 |#1| "failed") |#1| |#1| |#2|)) (T -701)) 
+((-2477 (*1 *2 *1) (-12 (-4 *2 (-23)) (-5 *1 (-701 *3 *2 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-1 *3 *3 *2)) (-14 *5 (-1 (-3 *2 "failed") *2 *2)) (-14 *6 (-1 (-3 *3 "failed") *3 *3 *2)))) (-2747 (*1 *2 *1) (-12 (-4 *2 (-172)) (-5 *1 (-701 *2 *3 *4 *5 *6)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-3094 (*1 *1 *2 *3) (-12 (-5 *1 (-701 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-2355 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-701 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3))))) 
+(-13 (-365) (-10 -8 (-15 -2477 (|#2| $)) (-15 -2747 (|#1| $)) (-15 -3094 ($ |#1| |#2|)) (-15 -2355 ((-3 $ "failed") $ $)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 30)) (-1969 (((-1244 |#1|) $ (-763)) NIL)) (-2057 (((-634 (-1075)) $) NIL)) (-1807 (($ (-1157 |#1|)) NIL)) (-3840 (((-1157 $) $ (-1075)) NIL) (((-1157 |#1|) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-3528 (((-763) $) NIL) (((-763) $ (-634 (-1075))) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-1736 (($ $ $) NIL (|has| |#1| (-558)))) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3045 (($ $) NIL (|has| |#1| (-453)))) (-3498 (((-420 $) $) NIL (|has| |#1| (-453)))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-2589 (((-121) $ $) NIL (|has| |#1| (-365)))) (-3986 (((-763)) 46 (|has| |#1| (-370)))) (-2752 (($ $ (-763)) NIL)) (-2699 (($ $ (-763)) NIL)) (-3194 ((|#2| |#2|) 43)) (-1448 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#1| (-453)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-1075) "failed") $) NIL)) (-2857 ((|#1| $) NIL) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-1075) $) NIL)) (-2910 (($ $ $ (-1075)) NIL (|has| |#1| (-172))) ((|#1| $ $) NIL (|has| |#1| (-172)))) (-2403 (($ $ $) NIL (|has| |#1| (-365)))) (-2116 (($ $) 33)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-3094 (($ |#2|) 41)) (-2902 (((-3 $ "failed") $) 84)) (-1733 (($) 50 (|has| |#1| (-370)))) (-2414 (($ $ $) NIL (|has| |#1| (-365)))) (-3152 (($ $ $) NIL)) (-2929 (($ $ $) NIL (|has| |#1| (-558)))) (-3777 (((-2 (|:| -2350 |#1|) (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-558)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-1998 (($ $) NIL (|has| |#1| (-453))) (($ $ (-1075)) NIL (|has| |#1| (-453)))) (-2110 (((-634 $) $) NIL)) (-2197 (((-121) $) NIL (|has| |#1| (-904)))) (-4402 (((-958 $)) 78)) (-2453 (($ $ |#1| (-763) $) NIL)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-1075) (-881 (-381))) (|has| |#1| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-1075) (-881 (-568))) (|has| |#1| (-881 (-568)))))) (-1844 (((-763) $ $) NIL (|has| |#1| (-558)))) (-1598 (((-121) $) NIL)) (-3971 (((-763) $) NIL)) (-2214 (((-3 $ "failed") $) NIL (|has| |#1| (-1136)))) (-2053 (($ (-1157 |#1|) (-1075)) NIL) (($ (-1157 $) (-1075)) NIL)) (-4168 (($ $ (-763)) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-3062 (((-634 $) $) NIL)) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| (-763)) 76) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-1438 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $ (-1075)) NIL) (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-2477 ((|#2|) 44)) (-3524 (((-763) $) NIL) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-1865 (($ (-1 (-763) (-763)) $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-2671 (((-1157 |#1|) $) NIL)) (-2817 (((-3 (-1075) "failed") $) NIL)) (-2291 (((-917) $) NIL (|has| |#1| (-370)))) (-3087 ((|#2| $) 40)) (-2099 (($ $) NIL)) (-2104 ((|#1| $) 28)) (-2498 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-1893 (((-1143) $) NIL)) (-3262 (((-2 (|:| -4409 $) (|:| -2607 $)) $ (-763)) NIL)) (-4362 (((-3 (-634 $) "failed") $) NIL)) (-2112 (((-3 (-634 $) "failed") $) NIL)) (-2617 (((-3 (-2 (|:| |var| (-1075)) (|:| -3483 (-763))) "failed") $) NIL)) (-1845 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4436 (($) NIL (|has| |#1| (-1136)) CONST)) (-4357 (($ (-917)) NIL (|has| |#1| (-370)))) (-4025 (((-1108) $) NIL)) (-2088 (((-121) $) NIL)) (-2093 ((|#1| $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-453)))) (-2723 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-2736 (($ $) 77 (|has| |#1| (-350)))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3850 (((-420 $) $) NIL (|has| |#1| (-904)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-365)))) (-2597 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558))) (((-3 $ "failed") $ $) 83 (|has| |#1| (-558)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-1075) |#1|) NIL) (($ $ (-634 (-1075)) (-634 |#1|)) NIL) (($ $ (-1075) $) NIL) (($ $ (-634 (-1075)) (-634 $)) NIL)) (-1466 (((-763) $) NIL (|has| |#1| (-365)))) (-2781 ((|#1| $ |#1|) NIL) (($ $ $) NIL) (((-409 $) (-409 $) (-409 $)) NIL (|has| |#1| (-558))) ((|#1| (-409 $) |#1|) NIL (|has| |#1| (-365))) (((-409 $) $ (-409 $)) NIL (|has| |#1| (-558)))) (-3805 (((-3 $ "failed") $ (-763)) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 85 (|has| |#1| (-365)))) (-3440 (($ $ (-1075)) NIL (|has| |#1| (-172))) ((|#1| $) NIL (|has| |#1| (-172)))) (-4191 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-1 |#1| |#1|) $) NIL)) (-1836 (((-763) $) 31) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-4280 (((-887 (-381)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-1075) (-609 (-541))) (|has| |#1| (-609 (-541)))))) (-1364 ((|#1| $) NIL (|has| |#1| (-453))) (($ $ (-1075)) NIL (|has| |#1| (-453)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#1| (-904))))) (-2339 (((-958 $)) 35)) (-4363 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558))) (((-3 (-409 $) "failed") (-409 $) $) NIL (|has| |#1| (-558)))) (-2747 (((-850) $) 60) (($ (-568)) NIL) (($ |#1|) 57) (($ (-1075)) NIL) (($ |#2|) 67) (($ (-409 (-568))) NIL (-2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#1| (-558)))) (-3304 (((-634 |#1|) $) NIL)) (-2079 ((|#1| $ (-763)) 62) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-3425 (((-763)) NIL)) (-3925 (($ $ $ (-763)) NIL (|has| |#1| (-172)))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 20 T CONST)) (-4399 (((-1244 |#1|) $) 74)) (-3932 (($ (-1244 |#1|)) 49)) (-1557 (($) 8 T CONST)) (-3192 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-3854 (((-1244 |#1|) $) NIL)) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) 68)) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1775 (($ $) 71) (($ $ $) NIL)) (-1769 (($ $ $) 32)) (** (($ $ (-917)) NIL) (($ $ (-763)) 79)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 56) (($ $ $) 73) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) 54) (($ $ |#1|) NIL))) 
+(((-702 |#1| |#2|) (-13 (-1219 |#1|) (-10 -8 (-15 -3194 (|#2| |#2|)) (-15 -2477 (|#2|)) (-15 -3094 ($ |#2|)) (-15 -3087 (|#2| $)) (-15 -2747 ($ |#2|)) (-15 -4399 ((-1244 |#1|) $)) (-15 -3932 ($ (-1244 |#1|))) (-15 -3854 ((-1244 |#1|) $)) (-15 -4402 ((-958 $))) (-15 -2339 ((-958 $))) (IF (|has| |#1| (-350)) (-15 -2736 ($ $)) |noBranch|) (IF (|has| |#1| (-370)) (-6 (-370)) |noBranch|))) (-1047) (-1219 |#1|)) (T -702)) 
+((-3194 (*1 *2 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-702 *3 *2)) (-4 *2 (-1219 *3)))) (-2477 (*1 *2) (-12 (-4 *2 (-1219 *3)) (-5 *1 (-702 *3 *2)) (-4 *3 (-1047)))) (-3094 (*1 *1 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-702 *3 *2)) (-4 *2 (-1219 *3)))) (-3087 (*1 *2 *1) (-12 (-4 *2 (-1219 *3)) (-5 *1 (-702 *3 *2)) (-4 *3 (-1047)))) (-2747 (*1 *1 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-702 *3 *2)) (-4 *2 (-1219 *3)))) (-4399 (*1 *2 *1) (-12 (-4 *3 (-1047)) (-5 *2 (-1244 *3)) (-5 *1 (-702 *3 *4)) (-4 *4 (-1219 *3)))) (-3932 (*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-1047)) (-5 *1 (-702 *3 *4)) (-4 *4 (-1219 *3)))) (-3854 (*1 *2 *1) (-12 (-4 *3 (-1047)) (-5 *2 (-1244 *3)) (-5 *1 (-702 *3 *4)) (-4 *4 (-1219 *3)))) (-4402 (*1 *2) (-12 (-4 *3 (-1047)) (-5 *2 (-958 (-702 *3 *4))) (-5 *1 (-702 *3 *4)) (-4 *4 (-1219 *3)))) (-2339 (*1 *2) (-12 (-4 *3 (-1047)) (-5 *2 (-958 (-702 *3 *4))) (-5 *1 (-702 *3 *4)) (-4 *4 (-1219 *3)))) (-2736 (*1 *1 *1) (-12 (-4 *2 (-350)) (-4 *2 (-1047)) (-5 *1 (-702 *2 *3)) (-4 *3 (-1219 *2))))) 
+(-13 (-1219 |#1|) (-10 -8 (-15 -3194 (|#2| |#2|)) (-15 -2477 (|#2|)) (-15 -3094 ($ |#2|)) (-15 -3087 (|#2| $)) (-15 -2747 ($ |#2|)) (-15 -4399 ((-1244 |#1|) $)) (-15 -3932 ($ (-1244 |#1|))) (-15 -3854 ((-1244 |#1|) $)) (-15 -4402 ((-958 $))) (-15 -2339 ((-958 $))) (IF (|has| |#1| (-350)) (-15 -2736 ($ $)) |noBranch|) (IF (|has| |#1| (-370)) (-6 (-370)) |noBranch|))) 
+((-2449 (((-121) $ $) NIL)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-1893 (((-1143) $) NIL)) (-4357 ((|#1| $) 13)) (-4025 (((-1108) $) NIL)) (-3483 ((|#2| $) 12)) (-4289 (($ |#1| |#2|) 16)) (-2747 (((-850) $) NIL) (($ (-2 (|:| -4357 |#1|) (|:| -3483 |#2|))) 15) (((-2 (|:| -4357 |#1|) (|:| -3483 |#2|)) $) 14)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 11))) 
+(((-703 |#1| |#2| |#3|) (-13 (-842) (-10 -8 (-15 -3483 (|#2| $)) (-15 -4357 (|#1| $)) (-15 -2747 ($ (-2 (|:| -4357 |#1|) (|:| -3483 |#2|)))) (-15 -2747 ((-2 (|:| -4357 |#1|) (|:| -3483 |#2|)) $)) (-15 -4289 ($ |#1| |#2|)))) (-842) (-1090) (-1 (-121) (-2 (|:| -4357 |#1|) (|:| -3483 |#2|)) (-2 (|:| -4357 |#1|) (|:| -3483 |#2|)))) (T -703)) 
+((-3483 (*1 *2 *1) (-12 (-4 *2 (-1090)) (-5 *1 (-703 *3 *2 *4)) (-4 *3 (-842)) (-14 *4 (-1 (-121) (-2 (|:| -4357 *3) (|:| -3483 *2)) (-2 (|:| -4357 *3) (|:| -3483 *2)))))) (-4357 (*1 *2 *1) (-12 (-4 *2 (-842)) (-5 *1 (-703 *2 *3 *4)) (-4 *3 (-1090)) (-14 *4 (-1 (-121) (-2 (|:| -4357 *2) (|:| -3483 *3)) (-2 (|:| -4357 *2) (|:| -3483 *3)))))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| -4357 *3) (|:| -3483 *4))) (-4 *3 (-842)) (-4 *4 (-1090)) (-5 *1 (-703 *3 *4 *5)) (-14 *5 (-1 (-121) *2 *2)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| -4357 *3) (|:| -3483 *4))) (-5 *1 (-703 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-1090)) (-14 *5 (-1 (-121) *2 *2)))) (-4289 (*1 *1 *2 *3) (-12 (-5 *1 (-703 *2 *3 *4)) (-4 *2 (-842)) (-4 *3 (-1090)) (-14 *4 (-1 (-121) (-2 (|:| -4357 *2) (|:| -3483 *3)) (-2 (|:| -4357 *2) (|:| -3483 *3))))))) 
+(-13 (-842) (-10 -8 (-15 -3483 (|#2| $)) (-15 -4357 (|#1| $)) (-15 -2747 ($ (-2 (|:| -4357 |#1|) (|:| -3483 |#2|)))) (-15 -2747 ((-2 (|:| -4357 |#1|) (|:| -3483 |#2|)) $)) (-15 -4289 ($ |#1| |#2|)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 59)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) 89) (((-3 (-123) "failed") $) 95)) (-2857 ((|#1| $) NIL) (((-123) $) 39)) (-2902 (((-3 $ "failed") $) 90)) (-1624 ((|#2| (-123) |#2|) 82)) (-1598 (((-121) $) NIL)) (-3448 (($ |#1| (-363 (-123))) 13)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-3122 (($ $ (-1 |#2| |#2|)) 58)) (-2513 (($ $ (-1 |#2| |#2|)) 44)) (-2781 ((|#2| $ |#2|) 32)) (-3756 ((|#1| |#1|) 100 (|has| |#1| (-172)))) (-2747 (((-850) $) 66) (($ (-568)) 17) (($ |#1|) 16) (($ (-123)) 23)) (-3385 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-3425 (((-763)) 36)) (-1419 (($ $) 99 (|has| |#1| (-172))) (($ $ $) 103 (|has| |#1| (-172)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 20 T CONST)) (-1557 (($) 9 T CONST)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) 48) (($ $ $) NIL)) (-1769 (($ $ $) 73)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ (-123) (-568)) NIL) (($ $ (-568)) 57)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 98) (($ $ $) 50) (($ |#1| $) 96 (|has| |#1| (-172))) (($ $ |#1|) 97 (|has| |#1| (-172))))) 
+(((-704 |#1| |#2|) (-13 (-1047) (-1037 |#1|) (-1037 (-123)) (-281 |#2| |#2|) (-10 -8 (IF (|has| |#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |#1| (-172)) (PROGN (-6 (-43 |#1|)) (-15 -1419 ($ $)) (-15 -1419 ($ $ $)) (-15 -3756 (|#1| |#1|))) |noBranch|) (-15 -2513 ($ $ (-1 |#2| |#2|))) (-15 -3122 ($ $ (-1 |#2| |#2|))) (-15 ** ($ (-123) (-568))) (-15 ** ($ $ (-568))) (-15 -1624 (|#2| (-123) |#2|)) (-15 -3448 ($ |#1| (-363 (-123)))))) (-1047) (-637 |#1|)) (T -704)) 
+((-1419 (*1 *1 *1) (-12 (-4 *2 (-172)) (-4 *2 (-1047)) (-5 *1 (-704 *2 *3)) (-4 *3 (-637 *2)))) (-1419 (*1 *1 *1 *1) (-12 (-4 *2 (-172)) (-4 *2 (-1047)) (-5 *1 (-704 *2 *3)) (-4 *3 (-637 *2)))) (-3756 (*1 *2 *2) (-12 (-4 *2 (-172)) (-4 *2 (-1047)) (-5 *1 (-704 *2 *3)) (-4 *3 (-637 *2)))) (-2513 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-637 *3)) (-4 *3 (-1047)) (-5 *1 (-704 *3 *4)))) (-3122 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-637 *3)) (-4 *3 (-1047)) (-5 *1 (-704 *3 *4)))) (** (*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-568)) (-4 *4 (-1047)) (-5 *1 (-704 *4 *5)) (-4 *5 (-637 *4)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *3 (-1047)) (-5 *1 (-704 *3 *4)) (-4 *4 (-637 *3)))) (-1624 (*1 *2 *3 *2) (-12 (-5 *3 (-123)) (-4 *4 (-1047)) (-5 *1 (-704 *4 *2)) (-4 *2 (-637 *4)))) (-3448 (*1 *1 *2 *3) (-12 (-5 *3 (-363 (-123))) (-4 *2 (-1047)) (-5 *1 (-704 *2 *4)) (-4 *4 (-637 *2))))) 
+(-13 (-1047) (-1037 |#1|) (-1037 (-123)) (-281 |#2| |#2|) (-10 -8 (IF (|has| |#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |#1| (-172)) (PROGN (-6 (-43 |#1|)) (-15 -1419 ($ $)) (-15 -1419 ($ $ $)) (-15 -3756 (|#1| |#1|))) |noBranch|) (-15 -2513 ($ $ (-1 |#2| |#2|))) (-15 -3122 ($ $ (-1 |#2| |#2|))) (-15 ** ($ (-123) (-568))) (-15 ** ($ $ (-568))) (-15 -1624 (|#2| (-123) |#2|)) (-15 -3448 ($ |#1| (-363 (-123)))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 33)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-3094 (($ |#1| |#2|) 25)) (-2902 (((-3 $ "failed") $) 47)) (-1598 (((-121) $) 35)) (-2477 ((|#2| $) 12)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) 48)) (-4025 (((-1108) $) NIL)) (-2355 (((-3 $ "failed") $ $) 46)) (-2747 (((-850) $) 24) (($ (-568)) 19) ((|#1| $) 13)) (-3425 (((-763)) 28)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 16 T CONST)) (-1557 (($) 30 T CONST)) (-1719 (((-121) $ $) 38)) (-1775 (($ $) 43) (($ $ $) 37)) (-1769 (($ $ $) 40)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 21) (($ $ $) 20))) 
+(((-705 |#1| |#2| |#3| |#4| |#5|) (-13 (-1047) (-10 -8 (-15 -2477 (|#2| $)) (-15 -2747 (|#1| $)) (-15 -3094 ($ |#1| |#2|)) (-15 -2355 ((-3 $ "failed") $ $)) (-15 -2902 ((-3 $ "failed") $)) (-15 -2083 ($ $)))) (-172) (-23) (-1 |#1| |#1| |#2|) (-1 (-3 |#2| "failed") |#2| |#2|) (-1 (-3 |#1| "failed") |#1| |#1| |#2|)) (T -705)) 
+((-2902 (*1 *1 *1) (|partial| -12 (-5 *1 (-705 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-2477 (*1 *2 *1) (-12 (-4 *2 (-23)) (-5 *1 (-705 *3 *2 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-1 *3 *3 *2)) (-14 *5 (-1 (-3 *2 "failed") *2 *2)) (-14 *6 (-1 (-3 *3 "failed") *3 *3 *2)))) (-2747 (*1 *2 *1) (-12 (-4 *2 (-172)) (-5 *1 (-705 *2 *3 *4 *5 *6)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-3094 (*1 *1 *2 *3) (-12 (-5 *1 (-705 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-2355 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-705 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) (-2083 (*1 *1 *1) (-12 (-5 *1 (-705 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3))))) 
+(-13 (-1047) (-10 -8 (-15 -2477 (|#2| $)) (-15 -2747 (|#1| $)) (-15 -3094 ($ |#1| |#2|)) (-15 -2355 ((-3 $ "failed") $ $)) (-15 -2902 ((-3 $ "failed") $)) (-15 -2083 ($ $)))) 
 ((* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ |#2| $) NIL) (($ $ |#2|) 9))) 
 (((-706 |#1| |#2|) (-10 -8 (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|))) (-707 |#2|) (-172)) (T -706)) 
 NIL 
 (-10 -8 (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-3056 (($) 17 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ |#1| $) 22) (($ $ |#1|) 24))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-3058 (($) 17 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ |#1| $) 22) (($ $ |#1|) 24))) 
 (((-707 |#1|) (-1275) (-172)) (T -707)) 
 NIL 
 (-13 (-120 |t#1| |t#1|)) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 |#1| |#1|) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 |#1|) . T) ((-1053 |#1|) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-1870 (($ |#1|) 17) (($ $ |#1|) 20)) (-3646 (($ |#1|) 18) (($ $ |#1|) 21)) (-2671 (($) NIL T CONST)) (-2925 (((-3 $ "failed") $) NIL) (($) 19) (($ $) 22)) (-2735 (((-121) $) NIL)) (-3264 (($ |#1| |#1| |#1| |#1|) 8)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) 16)) (-4022 (((-1108) $) NIL)) (-1339 ((|#1| $ |#1|) 24) (((-828 |#1|) $ (-828 |#1|)) 32)) (-1458 (($ $ $) NIL)) (-2353 (($ $ $) NIL)) (-2745 (((-850) $) 39)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-1556 (($) 9 T CONST)) (-1717 (((-121) $ $) 44)) (-1779 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ $ $) 14))) 
-(((-708 |#1|) (-13 (-478) (-10 -8 (-15 -3264 ($ |#1| |#1| |#1| |#1|)) (-15 -1870 ($ |#1|)) (-15 -3646 ($ |#1|)) (-15 -2925 ($)) (-15 -1870 ($ $ |#1|)) (-15 -3646 ($ $ |#1|)) (-15 -2925 ($ $)) (-15 -1339 (|#1| $ |#1|)) (-15 -1339 ((-828 |#1|) $ (-828 |#1|))))) (-365)) (T -708)) 
-((-3264 (*1 *1 *2 *2 *2 *2) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) (-1870 (*1 *1 *2) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) (-3646 (*1 *1 *2) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) (-2925 (*1 *1) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) (-1870 (*1 *1 *1 *2) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) (-3646 (*1 *1 *1 *2) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) (-2925 (*1 *1 *1) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) (-1339 (*1 *2 *1 *2) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) (-1339 (*1 *2 *1 *2) (-12 (-5 *2 (-828 *3)) (-4 *3 (-365)) (-5 *1 (-708 *3))))) 
-(-13 (-478) (-10 -8 (-15 -3264 ($ |#1| |#1| |#1| |#1|)) (-15 -1870 ($ |#1|)) (-15 -3646 ($ |#1|)) (-15 -2925 ($)) (-15 -1870 ($ $ |#1|)) (-15 -3646 ($ $ |#1|)) (-15 -2925 ($ $)) (-15 -1339 (|#1| $ |#1|)) (-15 -1339 ((-828 |#1|) $ (-828 |#1|))))) 
-((-3551 (($ $ (-917)) 12)) (-4222 (($ $ (-917)) 13)) (** (($ $ (-917)) 10))) 
-(((-709 |#1|) (-10 -8 (-15 ** (|#1| |#1| (-917))) (-15 -4222 (|#1| |#1| (-917))) (-15 -3551 (|#1| |#1| (-917)))) (-710)) (T -709)) 
-NIL 
-(-10 -8 (-15 ** (|#1| |#1| (-917))) (-15 -4222 (|#1| |#1| (-917))) (-15 -3551 (|#1| |#1| (-917)))) 
-((-2447 (((-121) $ $) 7)) (-3551 (($ $ (-917)) 14)) (-4222 (($ $ (-917)) 13)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-1717 (((-121) $ $) 6)) (** (($ $ (-917)) 12)) (* (($ $ $) 15))) 
+((-2449 (((-121) $ $) NIL)) (-1872 (($ |#1|) 17) (($ $ |#1|) 20)) (-3225 (($ |#1|) 18) (($ $ |#1|) 21)) (-4490 (($) NIL T CONST)) (-2902 (((-3 $ "failed") $) NIL) (($) 19) (($ $) 22)) (-1598 (((-121) $) NIL)) (-2036 (($ |#1| |#1| |#1| |#1|) 8)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) 16)) (-4025 (((-1108) $) NIL)) (-1339 ((|#1| $ |#1|) 24) (((-828 |#1|) $ (-828 |#1|)) 32)) (-2387 (($ $ $) NIL)) (-3985 (($ $ $) NIL)) (-2747 (((-850) $) 39)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-1557 (($) 9 T CONST)) (-1719 (((-121) $ $) 44)) (-1781 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ $ $) 14))) 
+(((-708 |#1|) (-13 (-478) (-10 -8 (-15 -2036 ($ |#1| |#1| |#1| |#1|)) (-15 -1872 ($ |#1|)) (-15 -3225 ($ |#1|)) (-15 -2902 ($)) (-15 -1872 ($ $ |#1|)) (-15 -3225 ($ $ |#1|)) (-15 -2902 ($ $)) (-15 -1339 (|#1| $ |#1|)) (-15 -1339 ((-828 |#1|) $ (-828 |#1|))))) (-365)) (T -708)) 
+((-2036 (*1 *1 *2 *2 *2 *2) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) (-1872 (*1 *1 *2) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) (-3225 (*1 *1 *2) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) (-2902 (*1 *1) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) (-1872 (*1 *1 *1 *2) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) (-3225 (*1 *1 *1 *2) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) (-2902 (*1 *1 *1) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) (-1339 (*1 *2 *1 *2) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) (-1339 (*1 *2 *1 *2) (-12 (-5 *2 (-828 *3)) (-4 *3 (-365)) (-5 *1 (-708 *3))))) 
+(-13 (-478) (-10 -8 (-15 -2036 ($ |#1| |#1| |#1| |#1|)) (-15 -1872 ($ |#1|)) (-15 -3225 ($ |#1|)) (-15 -2902 ($)) (-15 -1872 ($ $ |#1|)) (-15 -3225 ($ $ |#1|)) (-15 -2902 ($ $)) (-15 -1339 (|#1| $ |#1|)) (-15 -1339 ((-828 |#1|) $ (-828 |#1|))))) 
+((-2815 (($ $ (-917)) 12)) (-4202 (($ $ (-917)) 13)) (** (($ $ (-917)) 10))) 
+(((-709 |#1|) (-10 -8 (-15 ** (|#1| |#1| (-917))) (-15 -4202 (|#1| |#1| (-917))) (-15 -2815 (|#1| |#1| (-917)))) (-710)) (T -709)) 
+NIL 
+(-10 -8 (-15 ** (|#1| |#1| (-917))) (-15 -4202 (|#1| |#1| (-917))) (-15 -2815 (|#1| |#1| (-917)))) 
+((-2449 (((-121) $ $) 7)) (-2815 (($ $ (-917)) 14)) (-4202 (($ $ (-917)) 13)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-1719 (((-121) $ $) 6)) (** (($ $ (-917)) 12)) (* (($ $ $) 15))) 
 (((-710) (-1275)) (T -710)) 
-((* (*1 *1 *1 *1) (-4 *1 (-710))) (-3551 (*1 *1 *1 *2) (-12 (-4 *1 (-710)) (-5 *2 (-917)))) (-4222 (*1 *1 *1 *2) (-12 (-4 *1 (-710)) (-5 *2 (-917)))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-710)) (-5 *2 (-917))))) 
-(-13 (-1090) (-10 -8 (-15 * ($ $ $)) (-15 -3551 ($ $ (-917))) (-15 -4222 ($ $ (-917))) (-15 ** ($ $ (-917))))) 
+((* (*1 *1 *1 *1) (-4 *1 (-710))) (-2815 (*1 *1 *1 *2) (-12 (-4 *1 (-710)) (-5 *2 (-917)))) (-4202 (*1 *1 *1 *2) (-12 (-4 *1 (-710)) (-5 *2 (-917)))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-710)) (-5 *2 (-917))))) 
+(-13 (-1090) (-10 -8 (-15 * ($ $ $)) (-15 -2815 ($ $ (-917))) (-15 -4202 ($ $ (-917))) (-15 ** ($ $ (-917))))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-3551 (($ $ (-917)) NIL) (($ $ (-763)) 17)) (-2735 (((-121) $) 10)) (-4222 (($ $ (-917)) NIL) (($ $ (-763)) 18)) (** (($ $ (-917)) NIL) (($ $ (-763)) 15))) 
-(((-711 |#1|) (-10 -8 (-15 ** (|#1| |#1| (-763))) (-15 -4222 (|#1| |#1| (-763))) (-15 -3551 (|#1| |#1| (-763))) (-15 -2735 ((-121) |#1|)) (-15 ** (|#1| |#1| (-917))) (-15 -4222 (|#1| |#1| (-917))) (-15 -3551 (|#1| |#1| (-917)))) (-712)) (T -711)) 
+((-2815 (($ $ (-917)) NIL) (($ $ (-763)) 17)) (-1598 (((-121) $) 10)) (-4202 (($ $ (-917)) NIL) (($ $ (-763)) 18)) (** (($ $ (-917)) NIL) (($ $ (-763)) 15))) 
+(((-711 |#1|) (-10 -8 (-15 ** (|#1| |#1| (-763))) (-15 -4202 (|#1| |#1| (-763))) (-15 -2815 (|#1| |#1| (-763))) (-15 -1598 ((-121) |#1|)) (-15 ** (|#1| |#1| (-917))) (-15 -4202 (|#1| |#1| (-917))) (-15 -2815 (|#1| |#1| (-917)))) (-712)) (T -711)) 
 NIL 
-(-10 -8 (-15 ** (|#1| |#1| (-763))) (-15 -4222 (|#1| |#1| (-763))) (-15 -3551 (|#1| |#1| (-763))) (-15 -2735 ((-121) |#1|)) (-15 ** (|#1| |#1| (-917))) (-15 -4222 (|#1| |#1| (-917))) (-15 -3551 (|#1| |#1| (-917)))) 
-((-2447 (((-121) $ $) 7)) (-3550 (((-3 $ "failed") $) 16)) (-3551 (($ $ (-917)) 14) (($ $ (-763)) 21)) (-2925 (((-3 $ "failed") $) 18)) (-2735 (((-121) $) 22)) (-3243 (((-3 $ "failed") $) 17)) (-4222 (($ $ (-917)) 13) (($ $ (-763)) 20)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-1556 (($) 23 T CONST)) (-1717 (((-121) $ $) 6)) (** (($ $ (-917)) 12) (($ $ (-763)) 19)) (* (($ $ $) 15))) 
+(-10 -8 (-15 ** (|#1| |#1| (-763))) (-15 -4202 (|#1| |#1| (-763))) (-15 -2815 (|#1| |#1| (-763))) (-15 -1598 ((-121) |#1|)) (-15 ** (|#1| |#1| (-917))) (-15 -4202 (|#1| |#1| (-917))) (-15 -2815 (|#1| |#1| (-917)))) 
+((-2449 (((-121) $ $) 7)) (-2812 (((-3 $ "failed") $) 16)) (-2815 (($ $ (-917)) 14) (($ $ (-763)) 21)) (-2902 (((-3 $ "failed") $) 18)) (-1598 (((-121) $) 22)) (-1974 (((-3 $ "failed") $) 17)) (-4202 (($ $ (-917)) 13) (($ $ (-763)) 20)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-1557 (($) 23 T CONST)) (-1719 (((-121) $ $) 6)) (** (($ $ (-917)) 12) (($ $ (-763)) 19)) (* (($ $ $) 15))) 
 (((-712) (-1275)) (T -712)) 
-((-1556 (*1 *1) (-4 *1 (-712))) (-2735 (*1 *2 *1) (-12 (-4 *1 (-712)) (-5 *2 (-121)))) (-3551 (*1 *1 *1 *2) (-12 (-4 *1 (-712)) (-5 *2 (-763)))) (-4222 (*1 *1 *1 *2) (-12 (-4 *1 (-712)) (-5 *2 (-763)))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-712)) (-5 *2 (-763)))) (-2925 (*1 *1 *1) (|partial| -4 *1 (-712))) (-3243 (*1 *1 *1) (|partial| -4 *1 (-712))) (-3550 (*1 *1 *1) (|partial| -4 *1 (-712)))) 
-(-13 (-710) (-10 -8 (-15 (-1556) ($) -3495) (-15 -2735 ((-121) $)) (-15 -3551 ($ $ (-763))) (-15 -4222 ($ $ (-763))) (-15 ** ($ $ (-763))) (-15 -2925 ((-3 $ "failed") $)) (-15 -3243 ((-3 $ "failed") $)) (-15 -3550 ((-3 $ "failed") $)))) 
+((-1557 (*1 *1) (-4 *1 (-712))) (-1598 (*1 *2 *1) (-12 (-4 *1 (-712)) (-5 *2 (-121)))) (-2815 (*1 *1 *1 *2) (-12 (-4 *1 (-712)) (-5 *2 (-763)))) (-4202 (*1 *1 *1 *2) (-12 (-4 *1 (-712)) (-5 *2 (-763)))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-712)) (-5 *2 (-763)))) (-2902 (*1 *1 *1) (|partial| -4 *1 (-712))) (-1974 (*1 *1 *1) (|partial| -4 *1 (-712))) (-2812 (*1 *1 *1) (|partial| -4 *1 (-712)))) 
+(-13 (-710) (-10 -8 (-15 (-1557) ($) -3497) (-15 -1598 ((-121) $)) (-15 -2815 ($ $ (-763))) (-15 -4202 ($ $ (-763))) (-15 ** ($ $ (-763))) (-15 -2902 ((-3 $ "failed") $)) (-15 -1974 ((-3 $ "failed") $)) (-15 -2812 ((-3 $ "failed") $)))) 
 (((-105) . T) ((-608 (-850)) . T) ((-710) . T) ((-1090) . T)) 
-((-3983 (((-763)) 35)) (-3666 (((-3 (-568) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 |#2| "failed") $) 25)) (-2854 (((-568) $) NIL) (((-409 (-568)) $) NIL) ((|#2| $) 22)) (-3092 (($ |#3|) NIL) (((-3 $ "failed") (-409 |#3|)) 45)) (-2925 (((-3 $ "failed") $) 65)) (-1731 (($) 39)) (-2657 ((|#2| $) 20)) (-2704 (($) 17)) (-4189 (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) 53) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) NIL) (($ $ (-763)) NIL) (($ $) NIL)) (-4387 (((-679 |#2|) (-1244 $) (-1 |#2| |#2|)) 60)) (-4278 (((-1244 |#2|) $) NIL) (($ (-1244 |#2|)) NIL) ((|#3| $) 10) (($ |#3|) 12)) (-2678 ((|#3| $) 32)) (-3746 (((-1244 $)) 29))) 
-(((-713 |#1| |#2| |#3|) (-10 -8 (-15 -4189 (|#1| |#1|)) (-15 -4189 (|#1| |#1| (-763))) (-15 -4189 (|#1| |#1| (-1161))) (-15 -4189 (|#1| |#1| (-634 (-1161)))) (-15 -4189 (|#1| |#1| (-1161) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -1731 (|#1|)) (-15 -3983 ((-763))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -4387 ((-679 |#2|) (-1244 |#1|) (-1 |#2| |#2|))) (-15 -3092 ((-3 |#1| "failed") (-409 |#3|))) (-15 -4278 (|#1| |#3|)) (-15 -3092 (|#1| |#3|)) (-15 -2704 (|#1|)) (-15 -2854 (|#2| |#1|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2854 ((-568) |#1|)) (-15 -4278 (|#3| |#1|)) (-15 -4278 (|#1| (-1244 |#2|))) (-15 -4278 ((-1244 |#2|) |#1|)) (-15 -3746 ((-1244 |#1|))) (-15 -2678 (|#3| |#1|)) (-15 -2657 (|#2| |#1|)) (-15 -2925 ((-3 |#1| "failed") |#1|))) (-714 |#2| |#3|) (-172) (-1219 |#2|)) (T -713)) 
-((-3983 (*1 *2) (-12 (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-763)) (-5 *1 (-713 *3 *4 *5)) (-4 *3 (-714 *4 *5))))) 
-(-10 -8 (-15 -4189 (|#1| |#1|)) (-15 -4189 (|#1| |#1| (-763))) (-15 -4189 (|#1| |#1| (-1161))) (-15 -4189 (|#1| |#1| (-634 (-1161)))) (-15 -4189 (|#1| |#1| (-1161) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -1731 (|#1|)) (-15 -3983 ((-763))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -4387 ((-679 |#2|) (-1244 |#1|) (-1 |#2| |#2|))) (-15 -3092 ((-3 |#1| "failed") (-409 |#3|))) (-15 -4278 (|#1| |#3|)) (-15 -3092 (|#1| |#3|)) (-15 -2704 (|#1|)) (-15 -2854 (|#2| |#1|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2854 ((-568) |#1|)) (-15 -4278 (|#3| |#1|)) (-15 -4278 (|#1| (-1244 |#2|))) (-15 -4278 ((-1244 |#2|) |#1|)) (-15 -3746 ((-1244 |#1|))) (-15 -2678 (|#3| |#1|)) (-15 -2657 (|#2| |#1|)) (-15 -2925 ((-3 |#1| "failed") |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 87 (|has| |#1| (-365)))) (-2227 (($ $) 88 (|has| |#1| (-365)))) (-1573 (((-121) $) 90 (|has| |#1| (-365)))) (-4255 (((-679 |#1|) (-1244 $)) 44) (((-679 |#1|)) 55)) (-1932 ((|#1| $) 50)) (-3211 (((-1169 (-917) (-763)) (-568)) 141 (|has| |#1| (-350)))) (-3134 (((-3 $ "failed") $ $) 18)) (-4305 (($ $) 107 (|has| |#1| (-365)))) (-1678 (((-420 $) $) 108 (|has| |#1| (-365)))) (-1497 (((-121) $ $) 98 (|has| |#1| (-365)))) (-3983 (((-763)) 81 (|has| |#1| (-370)))) (-2671 (($) 16 T CONST)) (-3666 (((-3 (-568) "failed") $) 163 (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) 161 (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 160)) (-2854 (((-568) $) 164 (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) 162 (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) 159)) (-3498 (($ (-1244 |#1|) (-1244 $)) 46) (($ (-1244 |#1|)) 58)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) 147 (|has| |#1| (-350)))) (-2401 (($ $ $) 102 (|has| |#1| (-365)))) (-1709 (((-679 |#1|) $ (-1244 $)) 51) (((-679 |#1|) $) 53)) (-3164 (((-679 (-568)) (-679 $)) 158 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 157 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 156) (((-679 |#1|) (-679 $)) 155)) (-3092 (($ |#2|) 152) (((-3 $ "failed") (-409 |#2|)) 149 (|has| |#1| (-365)))) (-2925 (((-3 $ "failed") $) 33)) (-3700 (((-917)) 52)) (-1731 (($) 84 (|has| |#1| (-370)))) (-2412 (($ $ $) 101 (|has| |#1| (-365)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 96 (|has| |#1| (-365)))) (-4220 (($) 143 (|has| |#1| (-350)))) (-4456 (((-121) $) 144 (|has| |#1| (-350)))) (-3218 (($ $ (-763)) 135 (|has| |#1| (-350))) (($ $) 134 (|has| |#1| (-350)))) (-3927 (((-121) $) 109 (|has| |#1| (-365)))) (-4477 (((-917) $) 146 (|has| |#1| (-350))) (((-828 (-917)) $) 132 (|has| |#1| (-350)))) (-2735 (((-121) $) 30)) (-2657 ((|#1| $) 49)) (-3038 (((-3 $ "failed") $) 136 (|has| |#1| (-350)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 105 (|has| |#1| (-365)))) (-2045 ((|#2| $) 42 (|has| |#1| (-365)))) (-3683 (((-917) $) 83 (|has| |#1| (-370)))) (-3085 ((|#2| $) 150)) (-2495 (($ (-634 $)) 94 (|has| |#1| (-365))) (($ $ $) 93 (|has| |#1| (-365)))) (-4487 (((-1143) $) 9)) (-2081 (($ $) 110 (|has| |#1| (-365)))) (-4434 (($) 137 (|has| |#1| (-350)) CONST)) (-4355 (($ (-917)) 82 (|has| |#1| (-370)))) (-4022 (((-1108) $) 10)) (-2704 (($) 154)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 95 (|has| |#1| (-365)))) (-2721 (($ (-634 $)) 92 (|has| |#1| (-365))) (($ $ $) 91 (|has| |#1| (-365)))) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) 140 (|has| |#1| (-350)))) (-3848 (((-420 $) $) 106 (|has| |#1| (-365)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 104 (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 103 (|has| |#1| (-365)))) (-2595 (((-3 $ "failed") $ $) 86 (|has| |#1| (-365)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 97 (|has| |#1| (-365)))) (-2709 (((-763) $) 99 (|has| |#1| (-365)))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 100 (|has| |#1| (-365)))) (-2217 ((|#1| (-1244 $)) 45) ((|#1|) 54)) (-3143 (((-763) $) 145 (|has| |#1| (-350))) (((-3 (-763) "failed") $ $) 133 (|has| |#1| (-350)))) (-4189 (($ $) 131 (-2198 (-2139 (|has| |#1| (-225)) (|has| |#1| (-365))) (|has| |#1| (-350)))) (($ $ (-763)) 129 (-2198 (-2139 (|has| |#1| (-225)) (|has| |#1| (-365))) (|has| |#1| (-350)))) (($ $ (-1161)) 127 (-2139 (|has| |#1| (-895 (-1161))) (|has| |#1| (-365)))) (($ $ (-634 (-1161))) 126 (-2139 (|has| |#1| (-895 (-1161))) (|has| |#1| (-365)))) (($ $ (-1161) (-763)) 125 (-2139 (|has| |#1| (-895 (-1161))) (|has| |#1| (-365)))) (($ $ (-634 (-1161)) (-634 (-763))) 124 (-2139 (|has| |#1| (-895 (-1161))) (|has| |#1| (-365)))) (($ $ (-1 |#1| |#1|) (-763)) 117 (|has| |#1| (-365))) (($ $ (-1 |#1| |#1|)) 116 (|has| |#1| (-365)))) (-4387 (((-679 |#1|) (-1244 $) (-1 |#1| |#1|)) 148 (|has| |#1| (-365)))) (-1626 ((|#2|) 153)) (-3065 (($) 142 (|has| |#1| (-350)))) (-4073 (((-1244 |#1|) $ (-1244 $)) 48) (((-679 |#1|) (-1244 $) (-1244 $)) 47) (((-1244 |#1|) $) 60) (((-679 |#1|) (-1244 $)) 59)) (-4278 (((-1244 |#1|) $) 57) (($ (-1244 |#1|)) 56) ((|#2| $) 165) (($ |#2|) 151)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) 139 (|has| |#1| (-350)))) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 36) (($ $) 85 (|has| |#1| (-365))) (($ (-409 (-568))) 80 (-2198 (|has| |#1| (-365)) (|has| |#1| (-1037 (-409 (-568))))))) (-4371 (($ $) 138 (|has| |#1| (-350))) (((-3 $ "failed") $) 41 (|has| |#1| (-148)))) (-2678 ((|#2| $) 43)) (-4078 (((-763)) 28)) (-3746 (((-1244 $)) 61)) (-1826 (((-121) $ $) 89 (|has| |#1| (-365)))) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 111 (|has| |#1| (-365)))) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $) 130 (-2198 (-2139 (|has| |#1| (-225)) (|has| |#1| (-365))) (|has| |#1| (-350)))) (($ $ (-763)) 128 (-2198 (-2139 (|has| |#1| (-225)) (|has| |#1| (-365))) (|has| |#1| (-350)))) (($ $ (-1161)) 123 (-2139 (|has| |#1| (-895 (-1161))) (|has| |#1| (-365)))) (($ $ (-634 (-1161))) 122 (-2139 (|has| |#1| (-895 (-1161))) (|has| |#1| (-365)))) (($ $ (-1161) (-763)) 121 (-2139 (|has| |#1| (-895 (-1161))) (|has| |#1| (-365)))) (($ $ (-634 (-1161)) (-634 (-763))) 120 (-2139 (|has| |#1| (-895 (-1161))) (|has| |#1| (-365)))) (($ $ (-1 |#1| |#1|) (-763)) 119 (|has| |#1| (-365))) (($ $ (-1 |#1| |#1|)) 118 (|has| |#1| (-365)))) (-1717 (((-121) $ $) 6)) (-1779 (($ $ $) 115 (|has| |#1| (-365)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 112 (|has| |#1| (-365)))) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37) (($ (-409 (-568)) $) 114 (|has| |#1| (-365))) (($ $ (-409 (-568))) 113 (|has| |#1| (-365))))) 
+((-3986 (((-763)) 35)) (-3668 (((-3 (-568) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 |#2| "failed") $) 25)) (-2857 (((-568) $) NIL) (((-409 (-568)) $) NIL) ((|#2| $) 22)) (-3094 (($ |#3|) NIL) (((-3 $ "failed") (-409 |#3|)) 45)) (-2902 (((-3 $ "failed") $) 65)) (-1733 (($) 39)) (-4417 ((|#2| $) 20)) (-2707 (($) 17)) (-4191 (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) 53) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) NIL) (($ $ (-763)) NIL) (($ $) NIL)) (-1391 (((-679 |#2|) (-1244 $) (-1 |#2| |#2|)) 60)) (-4280 (((-1244 |#2|) $) NIL) (($ (-1244 |#2|)) NIL) ((|#3| $) 10) (($ |#3|) 12)) (-1295 ((|#3| $) 32)) (-2588 (((-1244 $)) 29))) 
+(((-713 |#1| |#2| |#3|) (-10 -8 (-15 -4191 (|#1| |#1|)) (-15 -4191 (|#1| |#1| (-763))) (-15 -4191 (|#1| |#1| (-1161))) (-15 -4191 (|#1| |#1| (-634 (-1161)))) (-15 -4191 (|#1| |#1| (-1161) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -1733 (|#1|)) (-15 -3986 ((-763))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -1391 ((-679 |#2|) (-1244 |#1|) (-1 |#2| |#2|))) (-15 -3094 ((-3 |#1| "failed") (-409 |#3|))) (-15 -4280 (|#1| |#3|)) (-15 -3094 (|#1| |#3|)) (-15 -2707 (|#1|)) (-15 -2857 (|#2| |#1|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2857 ((-568) |#1|)) (-15 -4280 (|#3| |#1|)) (-15 -4280 (|#1| (-1244 |#2|))) (-15 -4280 ((-1244 |#2|) |#1|)) (-15 -2588 ((-1244 |#1|))) (-15 -1295 (|#3| |#1|)) (-15 -4417 (|#2| |#1|)) (-15 -2902 ((-3 |#1| "failed") |#1|))) (-714 |#2| |#3|) (-172) (-1219 |#2|)) (T -713)) 
+((-3986 (*1 *2) (-12 (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-763)) (-5 *1 (-713 *3 *4 *5)) (-4 *3 (-714 *4 *5))))) 
+(-10 -8 (-15 -4191 (|#1| |#1|)) (-15 -4191 (|#1| |#1| (-763))) (-15 -4191 (|#1| |#1| (-1161))) (-15 -4191 (|#1| |#1| (-634 (-1161)))) (-15 -4191 (|#1| |#1| (-1161) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -1733 (|#1|)) (-15 -3986 ((-763))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -1391 ((-679 |#2|) (-1244 |#1|) (-1 |#2| |#2|))) (-15 -3094 ((-3 |#1| "failed") (-409 |#3|))) (-15 -4280 (|#1| |#3|)) (-15 -3094 (|#1| |#3|)) (-15 -2707 (|#1|)) (-15 -2857 (|#2| |#1|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2857 ((-568) |#1|)) (-15 -4280 (|#3| |#1|)) (-15 -4280 (|#1| (-1244 |#2|))) (-15 -4280 ((-1244 |#2|) |#1|)) (-15 -2588 ((-1244 |#1|))) (-15 -1295 (|#3| |#1|)) (-15 -4417 (|#2| |#1|)) (-15 -2902 ((-3 |#1| "failed") |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 87 (|has| |#1| (-365)))) (-3661 (($ $) 88 (|has| |#1| (-365)))) (-4426 (((-121) $) 90 (|has| |#1| (-365)))) (-2883 (((-679 |#1|) (-1244 $)) 44) (((-679 |#1|)) 55)) (-1934 ((|#1| $) 50)) (-1856 (((-1169 (-917) (-763)) (-568)) 141 (|has| |#1| (-350)))) (-2689 (((-3 $ "failed") $ $) 18)) (-3045 (($ $) 107 (|has| |#1| (-365)))) (-3498 (((-420 $) $) 108 (|has| |#1| (-365)))) (-2589 (((-121) $ $) 98 (|has| |#1| (-365)))) (-3986 (((-763)) 81 (|has| |#1| (-370)))) (-4490 (($) 16 T CONST)) (-3668 (((-3 (-568) "failed") $) 163 (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) 161 (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 160)) (-2857 (((-568) $) 164 (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) 162 (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) 159)) (-3899 (($ (-1244 |#1|) (-1244 $)) 46) (($ (-1244 |#1|)) 58)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) 147 (|has| |#1| (-350)))) (-2403 (($ $ $) 102 (|has| |#1| (-365)))) (-3653 (((-679 |#1|) $ (-1244 $)) 51) (((-679 |#1|) $) 53)) (-1668 (((-679 (-568)) (-679 $)) 158 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 157 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 156) (((-679 |#1|) (-679 $)) 155)) (-3094 (($ |#2|) 152) (((-3 $ "failed") (-409 |#2|)) 149 (|has| |#1| (-365)))) (-2902 (((-3 $ "failed") $) 33)) (-2371 (((-917)) 52)) (-1733 (($) 84 (|has| |#1| (-370)))) (-2414 (($ $ $) 101 (|has| |#1| (-365)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 96 (|has| |#1| (-365)))) (-4188 (($) 143 (|has| |#1| (-350)))) (-1748 (((-121) $) 144 (|has| |#1| (-350)))) (-1887 (($ $ (-763)) 135 (|has| |#1| (-350))) (($ $) 134 (|has| |#1| (-350)))) (-2197 (((-121) $) 109 (|has| |#1| (-365)))) (-1844 (((-917) $) 146 (|has| |#1| (-350))) (((-828 (-917)) $) 132 (|has| |#1| (-350)))) (-1598 (((-121) $) 30)) (-4417 ((|#1| $) 49)) (-2214 (((-3 $ "failed") $) 136 (|has| |#1| (-350)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 105 (|has| |#1| (-365)))) (-1497 ((|#2| $) 42 (|has| |#1| (-365)))) (-2291 (((-917) $) 83 (|has| |#1| (-370)))) (-3087 ((|#2| $) 150)) (-2498 (($ (-634 $)) 94 (|has| |#1| (-365))) (($ $ $) 93 (|has| |#1| (-365)))) (-1893 (((-1143) $) 9)) (-2083 (($ $) 110 (|has| |#1| (-365)))) (-4436 (($) 137 (|has| |#1| (-350)) CONST)) (-4357 (($ (-917)) 82 (|has| |#1| (-370)))) (-4025 (((-1108) $) 10)) (-2707 (($) 154)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 95 (|has| |#1| (-365)))) (-2723 (($ (-634 $)) 92 (|has| |#1| (-365))) (($ $ $) 91 (|has| |#1| (-365)))) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) 140 (|has| |#1| (-350)))) (-3850 (((-420 $) $) 106 (|has| |#1| (-365)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 104 (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 103 (|has| |#1| (-365)))) (-2597 (((-3 $ "failed") $ $) 86 (|has| |#1| (-365)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 97 (|has| |#1| (-365)))) (-1466 (((-763) $) 99 (|has| |#1| (-365)))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 100 (|has| |#1| (-365)))) (-3440 ((|#1| (-1244 $)) 45) ((|#1|) 54)) (-2721 (((-763) $) 145 (|has| |#1| (-350))) (((-3 (-763) "failed") $ $) 133 (|has| |#1| (-350)))) (-4191 (($ $) 131 (-2199 (-2141 (|has| |#1| (-225)) (|has| |#1| (-365))) (|has| |#1| (-350)))) (($ $ (-763)) 129 (-2199 (-2141 (|has| |#1| (-225)) (|has| |#1| (-365))) (|has| |#1| (-350)))) (($ $ (-1161)) 127 (-2141 (|has| |#1| (-895 (-1161))) (|has| |#1| (-365)))) (($ $ (-634 (-1161))) 126 (-2141 (|has| |#1| (-895 (-1161))) (|has| |#1| (-365)))) (($ $ (-1161) (-763)) 125 (-2141 (|has| |#1| (-895 (-1161))) (|has| |#1| (-365)))) (($ $ (-634 (-1161)) (-634 (-763))) 124 (-2141 (|has| |#1| (-895 (-1161))) (|has| |#1| (-365)))) (($ $ (-1 |#1| |#1|) (-763)) 117 (|has| |#1| (-365))) (($ $ (-1 |#1| |#1|)) 116 (|has| |#1| (-365)))) (-1391 (((-679 |#1|) (-1244 $) (-1 |#1| |#1|)) 148 (|has| |#1| (-365)))) (-1492 ((|#2|) 153)) (-2330 (($) 142 (|has| |#1| (-350)))) (-1656 (((-1244 |#1|) $ (-1244 $)) 48) (((-679 |#1|) (-1244 $) (-1244 $)) 47) (((-1244 |#1|) $) 60) (((-679 |#1|) (-1244 $)) 59)) (-4280 (((-1244 |#1|) $) 57) (($ (-1244 |#1|)) 56) ((|#2| $) 165) (($ |#2|) 151)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) 139 (|has| |#1| (-350)))) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 36) (($ $) 85 (|has| |#1| (-365))) (($ (-409 (-568))) 80 (-2199 (|has| |#1| (-365)) (|has| |#1| (-1037 (-409 (-568))))))) (-3385 (($ $) 138 (|has| |#1| (-350))) (((-3 $ "failed") $) 41 (|has| |#1| (-148)))) (-1295 ((|#2| $) 43)) (-3425 (((-763)) 28)) (-2588 (((-1244 $)) 61)) (-2273 (((-121) $ $) 89 (|has| |#1| (-365)))) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 111 (|has| |#1| (-365)))) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $) 130 (-2199 (-2141 (|has| |#1| (-225)) (|has| |#1| (-365))) (|has| |#1| (-350)))) (($ $ (-763)) 128 (-2199 (-2141 (|has| |#1| (-225)) (|has| |#1| (-365))) (|has| |#1| (-350)))) (($ $ (-1161)) 123 (-2141 (|has| |#1| (-895 (-1161))) (|has| |#1| (-365)))) (($ $ (-634 (-1161))) 122 (-2141 (|has| |#1| (-895 (-1161))) (|has| |#1| (-365)))) (($ $ (-1161) (-763)) 121 (-2141 (|has| |#1| (-895 (-1161))) (|has| |#1| (-365)))) (($ $ (-634 (-1161)) (-634 (-763))) 120 (-2141 (|has| |#1| (-895 (-1161))) (|has| |#1| (-365)))) (($ $ (-1 |#1| |#1|) (-763)) 119 (|has| |#1| (-365))) (($ $ (-1 |#1| |#1|)) 118 (|has| |#1| (-365)))) (-1719 (((-121) $ $) 6)) (-1781 (($ $ $) 115 (|has| |#1| (-365)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 112 (|has| |#1| (-365)))) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37) (($ (-409 (-568)) $) 114 (|has| |#1| (-365))) (($ $ (-409 (-568))) 113 (|has| |#1| (-365))))) 
 (((-714 |#1| |#2|) (-1275) (-172) (-1219 |t#1|)) (T -714)) 
-((-2704 (*1 *1) (-12 (-4 *2 (-172)) (-4 *1 (-714 *2 *3)) (-4 *3 (-1219 *2)))) (-1626 (*1 *2) (-12 (-4 *1 (-714 *3 *2)) (-4 *3 (-172)) (-4 *2 (-1219 *3)))) (-3092 (*1 *1 *2) (-12 (-4 *3 (-172)) (-4 *1 (-714 *3 *2)) (-4 *2 (-1219 *3)))) (-4278 (*1 *1 *2) (-12 (-4 *3 (-172)) (-4 *1 (-714 *3 *2)) (-4 *2 (-1219 *3)))) (-3085 (*1 *2 *1) (-12 (-4 *1 (-714 *3 *2)) (-4 *3 (-172)) (-4 *2 (-1219 *3)))) (-3092 (*1 *1 *2) (|partial| -12 (-5 *2 (-409 *4)) (-4 *4 (-1219 *3)) (-4 *3 (-365)) (-4 *3 (-172)) (-4 *1 (-714 *3 *4)))) (-4387 (*1 *2 *3 *4) (-12 (-5 *3 (-1244 *1)) (-5 *4 (-1 *5 *5)) (-4 *5 (-365)) (-4 *1 (-714 *5 *6)) (-4 *5 (-172)) (-4 *6 (-1219 *5)) (-5 *2 (-679 *5))))) 
-(-13 (-411 |t#1| |t#2|) (-172) (-609 |t#2|) (-413 |t#1|) (-379 |t#1|) (-10 -8 (-15 -2704 ($)) (-15 -1626 (|t#2|)) (-15 -3092 ($ |t#2|)) (-15 -4278 ($ |t#2|)) (-15 -3085 (|t#2| $)) (IF (|has| |t#1| (-370)) (-6 (-370)) |noBranch|) (IF (|has| |t#1| (-365)) (PROGN (-6 (-365)) (-6 (-223 |t#1|)) (-15 -3092 ((-3 $ "failed") (-409 |t#2|))) (-15 -4387 ((-679 |t#1|) (-1244 $) (-1 |t#1| |t#1|)))) |noBranch|) (IF (|has| |t#1| (-350)) (-6 (-350)) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) -2198 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-43 |#1|) . T) ((-43 $) -2198 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) -2198 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-120 |#1| |#1|) . T) ((-120 $ $) . T) ((-137) . T) ((-148) -2198 (|has| |#1| (-350)) (|has| |#1| (-148))) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) . T) ((-609 |#2|) . T) ((-223 |#1|) |has| |#1| (-365)) ((-225) -2198 (|has| |#1| (-350)) (-12 (|has| |#1| (-225)) (|has| |#1| (-365)))) ((-238) -2198 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-285) -2198 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-301) -2198 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-365) -2198 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-404) |has| |#1| (-350)) ((-370) -2198 (|has| |#1| (-370)) (|has| |#1| (-350))) ((-350) |has| |#1| (-350)) ((-372 |#1| |#2|) . T) ((-411 |#1| |#2|) . T) ((-379 |#1|) . T) ((-413 |#1|) . T) ((-453) -2198 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-558) -2198 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-637 (-409 (-568))) -2198 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-637 |#1|) . T) ((-637 $) . T) ((-630 (-568)) |has| |#1| (-630 (-568))) ((-630 |#1|) . T) ((-707 (-409 (-568))) -2198 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-707 |#1|) . T) ((-707 $) -2198 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-716) . T) ((-895 (-1161)) -12 (|has| |#1| (-365)) (|has| |#1| (-895 (-1161)))) ((-916) -2198 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-1037 (-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 |#1|) . T) ((-1053 (-409 (-568))) -2198 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-1053 |#1|) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1136) |has| |#1| (-350)) ((-1199) -2198 (|has| |#1| (-350)) (|has| |#1| (-365)))) 
-((-2671 (($) 14)) (-2925 (((-3 $ "failed") $) 16)) (-2735 (((-121) $) 13)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) 9)) (** (($ $ (-917)) NIL) (($ $ (-763)) 20))) 
-(((-715 |#1|) (-10 -8 (-15 -2925 ((-3 |#1| "failed") |#1|)) (-15 -1887 (|#1| |#1| (-763))) (-15 ** (|#1| |#1| (-763))) (-15 -2735 ((-121) |#1|)) (-15 -2671 (|#1|)) (-15 -1887 (|#1| |#1| (-917))) (-15 ** (|#1| |#1| (-917)))) (-716)) (T -715)) 
-NIL 
-(-10 -8 (-15 -2925 ((-3 |#1| "failed") |#1|)) (-15 -1887 (|#1| |#1| (-763))) (-15 ** (|#1| |#1| (-763))) (-15 -2735 ((-121) |#1|)) (-15 -2671 (|#1|)) (-15 -1887 (|#1| |#1| (-917))) (-15 ** (|#1| |#1| (-917)))) 
-((-2447 (((-121) $ $) 7)) (-2671 (($) 19 T CONST)) (-2925 (((-3 $ "failed") $) 15)) (-2735 (((-121) $) 18)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-1887 (($ $ (-917)) 12) (($ $ (-763)) 16)) (-1556 (($) 20 T CONST)) (-1717 (((-121) $ $) 6)) (** (($ $ (-917)) 13) (($ $ (-763)) 17)) (* (($ $ $) 14))) 
+((-2707 (*1 *1) (-12 (-4 *2 (-172)) (-4 *1 (-714 *2 *3)) (-4 *3 (-1219 *2)))) (-1492 (*1 *2) (-12 (-4 *1 (-714 *3 *2)) (-4 *3 (-172)) (-4 *2 (-1219 *3)))) (-3094 (*1 *1 *2) (-12 (-4 *3 (-172)) (-4 *1 (-714 *3 *2)) (-4 *2 (-1219 *3)))) (-4280 (*1 *1 *2) (-12 (-4 *3 (-172)) (-4 *1 (-714 *3 *2)) (-4 *2 (-1219 *3)))) (-3087 (*1 *2 *1) (-12 (-4 *1 (-714 *3 *2)) (-4 *3 (-172)) (-4 *2 (-1219 *3)))) (-3094 (*1 *1 *2) (|partial| -12 (-5 *2 (-409 *4)) (-4 *4 (-1219 *3)) (-4 *3 (-365)) (-4 *3 (-172)) (-4 *1 (-714 *3 *4)))) (-1391 (*1 *2 *3 *4) (-12 (-5 *3 (-1244 *1)) (-5 *4 (-1 *5 *5)) (-4 *5 (-365)) (-4 *1 (-714 *5 *6)) (-4 *5 (-172)) (-4 *6 (-1219 *5)) (-5 *2 (-679 *5))))) 
+(-13 (-411 |t#1| |t#2|) (-172) (-609 |t#2|) (-413 |t#1|) (-379 |t#1|) (-10 -8 (-15 -2707 ($)) (-15 -1492 (|t#2|)) (-15 -3094 ($ |t#2|)) (-15 -4280 ($ |t#2|)) (-15 -3087 (|t#2| $)) (IF (|has| |t#1| (-370)) (-6 (-370)) |noBranch|) (IF (|has| |t#1| (-365)) (PROGN (-6 (-365)) (-6 (-223 |t#1|)) (-15 -3094 ((-3 $ "failed") (-409 |t#2|))) (-15 -1391 ((-679 |t#1|) (-1244 $) (-1 |t#1| |t#1|)))) |noBranch|) (IF (|has| |t#1| (-350)) (-6 (-350)) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) -2199 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-43 |#1|) . T) ((-43 $) -2199 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) -2199 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-120 |#1| |#1|) . T) ((-120 $ $) . T) ((-137) . T) ((-148) -2199 (|has| |#1| (-350)) (|has| |#1| (-148))) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) . T) ((-609 |#2|) . T) ((-223 |#1|) |has| |#1| (-365)) ((-225) -2199 (|has| |#1| (-350)) (-12 (|has| |#1| (-225)) (|has| |#1| (-365)))) ((-238) -2199 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-285) -2199 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-301) -2199 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-365) -2199 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-404) |has| |#1| (-350)) ((-370) -2199 (|has| |#1| (-370)) (|has| |#1| (-350))) ((-350) |has| |#1| (-350)) ((-372 |#1| |#2|) . T) ((-411 |#1| |#2|) . T) ((-379 |#1|) . T) ((-413 |#1|) . T) ((-453) -2199 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-558) -2199 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-637 (-409 (-568))) -2199 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-637 |#1|) . T) ((-637 $) . T) ((-630 (-568)) |has| |#1| (-630 (-568))) ((-630 |#1|) . T) ((-707 (-409 (-568))) -2199 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-707 |#1|) . T) ((-707 $) -2199 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-716) . T) ((-895 (-1161)) -12 (|has| |#1| (-365)) (|has| |#1| (-895 (-1161)))) ((-916) -2199 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-1037 (-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 |#1|) . T) ((-1053 (-409 (-568))) -2199 (|has| |#1| (-350)) (|has| |#1| (-365))) ((-1053 |#1|) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1136) |has| |#1| (-350)) ((-1199) -2199 (|has| |#1| (-350)) (|has| |#1| (-365)))) 
+((-4490 (($) 14)) (-2902 (((-3 $ "failed") $) 16)) (-1598 (((-121) $) 13)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) 9)) (** (($ $ (-917)) NIL) (($ $ (-763)) 20))) 
+(((-715 |#1|) (-10 -8 (-15 -2902 ((-3 |#1| "failed") |#1|)) (-15 -1889 (|#1| |#1| (-763))) (-15 ** (|#1| |#1| (-763))) (-15 -1598 ((-121) |#1|)) (-15 -4490 (|#1|)) (-15 -1889 (|#1| |#1| (-917))) (-15 ** (|#1| |#1| (-917)))) (-716)) (T -715)) 
+NIL 
+(-10 -8 (-15 -2902 ((-3 |#1| "failed") |#1|)) (-15 -1889 (|#1| |#1| (-763))) (-15 ** (|#1| |#1| (-763))) (-15 -1598 ((-121) |#1|)) (-15 -4490 (|#1|)) (-15 -1889 (|#1| |#1| (-917))) (-15 ** (|#1| |#1| (-917)))) 
+((-2449 (((-121) $ $) 7)) (-4490 (($) 19 T CONST)) (-2902 (((-3 $ "failed") $) 15)) (-1598 (((-121) $) 18)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-1889 (($ $ (-917)) 12) (($ $ (-763)) 16)) (-1557 (($) 20 T CONST)) (-1719 (((-121) $ $) 6)) (** (($ $ (-917)) 13) (($ $ (-763)) 17)) (* (($ $ $) 14))) 
 (((-716) (-1275)) (T -716)) 
-((-1556 (*1 *1) (-4 *1 (-716))) (-2671 (*1 *1) (-4 *1 (-716))) (-2735 (*1 *2 *1) (-12 (-4 *1 (-716)) (-5 *2 (-121)))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-716)) (-5 *2 (-763)))) (-1887 (*1 *1 *1 *2) (-12 (-4 *1 (-716)) (-5 *2 (-763)))) (-2925 (*1 *1 *1) (|partial| -4 *1 (-716)))) 
-(-13 (-1102) (-10 -8 (-15 (-1556) ($) -3495) (-15 -2671 ($) -3495) (-15 -2735 ((-121) $)) (-15 ** ($ $ (-763))) (-15 -1887 ($ $ (-763))) (-15 -2925 ((-3 $ "failed") $)))) 
+((-1557 (*1 *1) (-4 *1 (-716))) (-4490 (*1 *1) (-4 *1 (-716))) (-1598 (*1 *2 *1) (-12 (-4 *1 (-716)) (-5 *2 (-121)))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-716)) (-5 *2 (-763)))) (-1889 (*1 *1 *1 *2) (-12 (-4 *1 (-716)) (-5 *2 (-763)))) (-2902 (*1 *1 *1) (|partial| -4 *1 (-716)))) 
+(-13 (-1102) (-10 -8 (-15 (-1557) ($) -3497) (-15 -4490 ($) -3497) (-15 -1598 ((-121) $)) (-15 ** ($ $ (-763))) (-15 -1889 ($ $ (-763))) (-15 -2902 ((-3 $ "failed") $)))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1102) . T) ((-1090) . T)) 
-((-2311 (((-2 (|:| -2242 (-420 |#2|)) (|:| |special| (-420 |#2|))) |#2| (-1 |#2| |#2|)) 38)) (-3969 (((-2 (|:| -2242 |#2|) (|:| |special| |#2|)) |#2| (-1 |#2| |#2|)) 12)) (-2191 ((|#2| (-409 |#2|) (-1 |#2| |#2|)) 13)) (-2847 (((-2 (|:| |poly| |#2|) (|:| -2242 (-409 |#2|)) (|:| |special| (-409 |#2|))) (-409 |#2|) (-1 |#2| |#2|)) 47))) 
-(((-717 |#1| |#2|) (-10 -7 (-15 -3969 ((-2 (|:| -2242 |#2|) (|:| |special| |#2|)) |#2| (-1 |#2| |#2|))) (-15 -2311 ((-2 (|:| -2242 (-420 |#2|)) (|:| |special| (-420 |#2|))) |#2| (-1 |#2| |#2|))) (-15 -2191 (|#2| (-409 |#2|) (-1 |#2| |#2|))) (-15 -2847 ((-2 (|:| |poly| |#2|) (|:| -2242 (-409 |#2|)) (|:| |special| (-409 |#2|))) (-409 |#2|) (-1 |#2| |#2|)))) (-365) (-1219 |#1|)) (T -717)) 
-((-2847 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| |poly| *6) (|:| -2242 (-409 *6)) (|:| |special| (-409 *6)))) (-5 *1 (-717 *5 *6)) (-5 *3 (-409 *6)))) (-2191 (*1 *2 *3 *4) (-12 (-5 *3 (-409 *2)) (-5 *4 (-1 *2 *2)) (-4 *2 (-1219 *5)) (-5 *1 (-717 *5 *2)) (-4 *5 (-365)))) (-2311 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| -2242 (-420 *3)) (|:| |special| (-420 *3)))) (-5 *1 (-717 *5 *3)))) (-3969 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| -2242 *3) (|:| |special| *3))) (-5 *1 (-717 *5 *3))))) 
-(-10 -7 (-15 -3969 ((-2 (|:| -2242 |#2|) (|:| |special| |#2|)) |#2| (-1 |#2| |#2|))) (-15 -2311 ((-2 (|:| -2242 (-420 |#2|)) (|:| |special| (-420 |#2|))) |#2| (-1 |#2| |#2|))) (-15 -2191 (|#2| (-409 |#2|) (-1 |#2| |#2|))) (-15 -2847 ((-2 (|:| |poly| |#2|) (|:| -2242 (-409 |#2|)) (|:| |special| (-409 |#2|))) (-409 |#2|) (-1 |#2| |#2|)))) 
-((-4183 ((|#7| (-634 |#5|) |#6|) NIL)) (-2795 ((|#7| (-1 |#5| |#4|) |#6|) 26))) 
-(((-718 |#1| |#2| |#3| |#4| |#5| |#6| |#7|) (-10 -7 (-15 -2795 (|#7| (-1 |#5| |#4|) |#6|)) (-15 -4183 (|#7| (-634 |#5|) |#6|))) (-842) (-788) (-788) (-1047) (-1047) (-950 |#4| |#2| |#1|) (-950 |#5| |#3| |#1|)) (T -718)) 
-((-4183 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *9)) (-4 *9 (-1047)) (-4 *5 (-842)) (-4 *6 (-788)) (-4 *8 (-1047)) (-4 *2 (-950 *9 *7 *5)) (-5 *1 (-718 *5 *6 *7 *8 *9 *4 *2)) (-4 *7 (-788)) (-4 *4 (-950 *8 *6 *5)))) (-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *8)) (-4 *8 (-1047)) (-4 *9 (-1047)) (-4 *5 (-842)) (-4 *6 (-788)) (-4 *2 (-950 *9 *7 *5)) (-5 *1 (-718 *5 *6 *7 *8 *9 *4 *2)) (-4 *7 (-788)) (-4 *4 (-950 *8 *6 *5))))) 
-(-10 -7 (-15 -2795 (|#7| (-1 |#5| |#4|) |#6|)) (-15 -4183 (|#7| (-634 |#5|) |#6|))) 
-((-2795 ((|#7| (-1 |#2| |#1|) |#6|) 28))) 
-(((-719 |#1| |#2| |#3| |#4| |#5| |#6| |#7|) (-10 -7 (-15 -2795 (|#7| (-1 |#2| |#1|) |#6|))) (-842) (-842) (-788) (-788) (-1047) (-950 |#5| |#3| |#1|) (-950 |#5| |#4| |#2|)) (T -719)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-842)) (-4 *6 (-842)) (-4 *7 (-788)) (-4 *9 (-1047)) (-4 *2 (-950 *9 *8 *6)) (-5 *1 (-719 *5 *6 *7 *8 *9 *4 *2)) (-4 *8 (-788)) (-4 *4 (-950 *9 *7 *5))))) 
-(-10 -7 (-15 -2795 (|#7| (-1 |#2| |#1|) |#6|))) 
-((-3848 (((-420 |#4|) |#4|) 39))) 
-(((-720 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3848 ((-420 |#4|) |#4|))) (-788) (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $)) (-15 -1305 ((-3 $ "failed") (-1161))))) (-301) (-950 (-953 |#3|) |#1| |#2|)) (T -720)) 
-((-3848 (*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $)) (-15 -1305 ((-3 $ "failed") (-1161)))))) (-4 *6 (-301)) (-5 *2 (-420 *3)) (-5 *1 (-720 *4 *5 *6 *3)) (-4 *3 (-950 (-953 *6) *4 *5))))) 
-(-10 -7 (-15 -3848 ((-420 |#4|) |#4|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2055 (((-634 (-852 |#1|)) $) NIL)) (-3839 (((-1157 $) $ (-852 |#1|)) NIL) (((-1157 |#2|) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#2| (-558)))) (-2227 (($ $) NIL (|has| |#2| (-558)))) (-1573 (((-121) $) NIL (|has| |#2| (-558)))) (-2773 (((-763) $) NIL) (((-763) $ (-634 (-852 |#1|))) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-4305 (($ $) NIL (|has| |#2| (-453)))) (-1678 (((-420 $) $) NIL (|has| |#2| (-453)))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#2| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#2| (-1037 (-568)))) (((-3 (-852 |#1|) "failed") $) NIL)) (-2854 ((|#2| $) NIL) (((-409 (-568)) $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#2| (-1037 (-568)))) (((-852 |#1|) $) NIL)) (-4265 (($ $ $ (-852 |#1|)) NIL (|has| |#2| (-172)))) (-2114 (($ $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL) (((-679 |#2|) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3250 (($ $) NIL (|has| |#2| (-453))) (($ $ (-852 |#1|)) NIL (|has| |#2| (-453)))) (-2108 (((-634 $) $) NIL)) (-3927 (((-121) $) NIL (|has| |#2| (-904)))) (-3088 (($ $ |#2| (-534 (-852 |#1|)) $) NIL)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-852 |#1|) (-881 (-381))) (|has| |#2| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-852 |#1|) (-881 (-568))) (|has| |#2| (-881 (-568)))))) (-2735 (((-121) $) NIL)) (-4178 (((-763) $) NIL)) (-2051 (($ (-1157 |#2|) (-852 |#1|)) NIL) (($ (-1157 $) (-852 |#1|)) NIL)) (-2976 (((-634 $) $) NIL)) (-3921 (((-121) $) NIL)) (-2047 (($ |#2| (-534 (-852 |#1|))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-3379 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $ (-852 |#1|)) NIL)) (-2144 (((-534 (-852 |#1|)) $) NIL) (((-763) $ (-852 |#1|)) NIL) (((-634 (-763)) $ (-634 (-852 |#1|))) NIL)) (-2521 (($ $ $) NIL (|has| |#2| (-842)))) (-3268 (($ $ $) NIL (|has| |#2| (-842)))) (-3842 (($ (-1 (-534 (-852 |#1|)) (-534 (-852 |#1|))) $) NIL)) (-2795 (($ (-1 |#2| |#2|) $) NIL)) (-2244 (((-3 (-852 |#1|) "failed") $) NIL)) (-2097 (($ $) NIL)) (-2102 ((|#2| $) NIL)) (-2495 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) NIL (|has| |#2| (-453)))) (-4487 (((-1143) $) NIL)) (-3324 (((-3 (-634 $) "failed") $) NIL)) (-1794 (((-3 (-634 $) "failed") $) NIL)) (-3751 (((-3 (-2 (|:| |var| (-852 |#1|)) (|:| -3438 (-763))) "failed") $) NIL)) (-4022 (((-1108) $) NIL)) (-2086 (((-121) $) NIL)) (-2091 ((|#2| $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#2| (-453)))) (-2721 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) NIL (|has| |#2| (-453)))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3848 (((-420 $) $) NIL (|has| |#2| (-904)))) (-2595 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-558)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-852 |#1|) |#2|) NIL) (($ $ (-634 (-852 |#1|)) (-634 |#2|)) NIL) (($ $ (-852 |#1|) $) NIL) (($ $ (-634 (-852 |#1|)) (-634 $)) NIL)) (-2217 (($ $ (-852 |#1|)) NIL (|has| |#2| (-172)))) (-4189 (($ $ (-852 |#1|)) NIL) (($ $ (-634 (-852 |#1|))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-3206 (((-534 (-852 |#1|)) $) NIL) (((-763) $ (-852 |#1|)) NIL) (((-634 (-763)) $ (-634 (-852 |#1|))) NIL)) (-4278 (((-887 (-381)) $) NIL (-12 (|has| (-852 |#1|) (-609 (-887 (-381)))) (|has| |#2| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-852 |#1|) (-609 (-887 (-568)))) (|has| |#2| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-852 |#1|) (-609 (-541))) (|has| |#2| (-609 (-541)))))) (-3367 ((|#2| $) NIL (|has| |#2| (-453))) (($ $ (-852 |#1|)) NIL (|has| |#2| (-453)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#2| (-904))))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#2|) NIL) (($ (-852 |#1|)) NIL) (($ $) NIL (|has| |#2| (-558))) (($ (-409 (-568))) NIL (-2198 (|has| |#2| (-43 (-409 (-568)))) (|has| |#2| (-1037 (-409 (-568))))))) (-1302 (((-634 |#2|) $) NIL)) (-2604 ((|#2| $ (-534 (-852 |#1|))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| |#2| (-904))) (|has| |#2| (-148))))) (-4078 (((-763)) NIL)) (-4171 (($ $ $ (-763)) NIL (|has| |#2| (-172)))) (-1826 (((-121) $ $) NIL (|has| |#2| (-558)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $ (-852 |#1|)) NIL) (($ $ (-634 (-852 |#1|))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-1751 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1779 (($ $ |#2|) NIL (|has| |#2| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#2| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#2| (-43 (-409 (-568))))) (($ |#2| $) NIL) (($ $ |#2|) NIL))) 
+((-3720 (((-2 (|:| -2244 (-420 |#2|)) (|:| |special| (-420 |#2|))) |#2| (-1 |#2| |#2|)) 38)) (-4446 (((-2 (|:| -2244 |#2|) (|:| |special| |#2|)) |#2| (-1 |#2| |#2|)) 12)) (-3018 ((|#2| (-409 |#2|) (-1 |#2| |#2|)) 13)) (-3946 (((-2 (|:| |poly| |#2|) (|:| -2244 (-409 |#2|)) (|:| |special| (-409 |#2|))) (-409 |#2|) (-1 |#2| |#2|)) 47))) 
+(((-717 |#1| |#2|) (-10 -7 (-15 -4446 ((-2 (|:| -2244 |#2|) (|:| |special| |#2|)) |#2| (-1 |#2| |#2|))) (-15 -3720 ((-2 (|:| -2244 (-420 |#2|)) (|:| |special| (-420 |#2|))) |#2| (-1 |#2| |#2|))) (-15 -3018 (|#2| (-409 |#2|) (-1 |#2| |#2|))) (-15 -3946 ((-2 (|:| |poly| |#2|) (|:| -2244 (-409 |#2|)) (|:| |special| (-409 |#2|))) (-409 |#2|) (-1 |#2| |#2|)))) (-365) (-1219 |#1|)) (T -717)) 
+((-3946 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| |poly| *6) (|:| -2244 (-409 *6)) (|:| |special| (-409 *6)))) (-5 *1 (-717 *5 *6)) (-5 *3 (-409 *6)))) (-3018 (*1 *2 *3 *4) (-12 (-5 *3 (-409 *2)) (-5 *4 (-1 *2 *2)) (-4 *2 (-1219 *5)) (-5 *1 (-717 *5 *2)) (-4 *5 (-365)))) (-3720 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| -2244 (-420 *3)) (|:| |special| (-420 *3)))) (-5 *1 (-717 *5 *3)))) (-4446 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| -2244 *3) (|:| |special| *3))) (-5 *1 (-717 *5 *3))))) 
+(-10 -7 (-15 -4446 ((-2 (|:| -2244 |#2|) (|:| |special| |#2|)) |#2| (-1 |#2| |#2|))) (-15 -3720 ((-2 (|:| -2244 (-420 |#2|)) (|:| |special| (-420 |#2|))) |#2| (-1 |#2| |#2|))) (-15 -3018 (|#2| (-409 |#2|) (-1 |#2| |#2|))) (-15 -3946 ((-2 (|:| |poly| |#2|) (|:| -2244 (-409 |#2|)) (|:| |special| (-409 |#2|))) (-409 |#2|) (-1 |#2| |#2|)))) 
+((-4182 ((|#7| (-634 |#5|) |#6|) NIL)) (-2797 ((|#7| (-1 |#5| |#4|) |#6|) 26))) 
+(((-718 |#1| |#2| |#3| |#4| |#5| |#6| |#7|) (-10 -7 (-15 -2797 (|#7| (-1 |#5| |#4|) |#6|)) (-15 -4182 (|#7| (-634 |#5|) |#6|))) (-842) (-788) (-788) (-1047) (-1047) (-950 |#4| |#2| |#1|) (-950 |#5| |#3| |#1|)) (T -718)) 
+((-4182 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *9)) (-4 *9 (-1047)) (-4 *5 (-842)) (-4 *6 (-788)) (-4 *8 (-1047)) (-4 *2 (-950 *9 *7 *5)) (-5 *1 (-718 *5 *6 *7 *8 *9 *4 *2)) (-4 *7 (-788)) (-4 *4 (-950 *8 *6 *5)))) (-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *8)) (-4 *8 (-1047)) (-4 *9 (-1047)) (-4 *5 (-842)) (-4 *6 (-788)) (-4 *2 (-950 *9 *7 *5)) (-5 *1 (-718 *5 *6 *7 *8 *9 *4 *2)) (-4 *7 (-788)) (-4 *4 (-950 *8 *6 *5))))) 
+(-10 -7 (-15 -2797 (|#7| (-1 |#5| |#4|) |#6|)) (-15 -4182 (|#7| (-634 |#5|) |#6|))) 
+((-2797 ((|#7| (-1 |#2| |#1|) |#6|) 28))) 
+(((-719 |#1| |#2| |#3| |#4| |#5| |#6| |#7|) (-10 -7 (-15 -2797 (|#7| (-1 |#2| |#1|) |#6|))) (-842) (-842) (-788) (-788) (-1047) (-950 |#5| |#3| |#1|) (-950 |#5| |#4| |#2|)) (T -719)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-842)) (-4 *6 (-842)) (-4 *7 (-788)) (-4 *9 (-1047)) (-4 *2 (-950 *9 *8 *6)) (-5 *1 (-719 *5 *6 *7 *8 *9 *4 *2)) (-4 *8 (-788)) (-4 *4 (-950 *9 *7 *5))))) 
+(-10 -7 (-15 -2797 (|#7| (-1 |#2| |#1|) |#6|))) 
+((-3850 (((-420 |#4|) |#4|) 39))) 
+(((-720 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3850 ((-420 |#4|) |#4|))) (-788) (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $)) (-15 -3325 ((-3 $ "failed") (-1161))))) (-301) (-950 (-953 |#3|) |#1| |#2|)) (T -720)) 
+((-3850 (*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $)) (-15 -3325 ((-3 $ "failed") (-1161)))))) (-4 *6 (-301)) (-5 *2 (-420 *3)) (-5 *1 (-720 *4 *5 *6 *3)) (-4 *3 (-950 (-953 *6) *4 *5))))) 
+(-10 -7 (-15 -3850 ((-420 |#4|) |#4|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2057 (((-634 (-852 |#1|)) $) NIL)) (-3840 (((-1157 $) $ (-852 |#1|)) NIL) (((-1157 |#2|) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#2| (-558)))) (-3661 (($ $) NIL (|has| |#2| (-558)))) (-4426 (((-121) $) NIL (|has| |#2| (-558)))) (-3528 (((-763) $) NIL) (((-763) $ (-634 (-852 |#1|))) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3045 (($ $) NIL (|has| |#2| (-453)))) (-3498 (((-420 $) $) NIL (|has| |#2| (-453)))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#2| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#2| (-1037 (-568)))) (((-3 (-852 |#1|) "failed") $) NIL)) (-2857 ((|#2| $) NIL) (((-409 (-568)) $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#2| (-1037 (-568)))) (((-852 |#1|) $) NIL)) (-2910 (($ $ $ (-852 |#1|)) NIL (|has| |#2| (-172)))) (-2116 (($ $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL) (((-679 |#2|) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1998 (($ $) NIL (|has| |#2| (-453))) (($ $ (-852 |#1|)) NIL (|has| |#2| (-453)))) (-2110 (((-634 $) $) NIL)) (-2197 (((-121) $) NIL (|has| |#2| (-904)))) (-2453 (($ $ |#2| (-534 (-852 |#1|)) $) NIL)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-852 |#1|) (-881 (-381))) (|has| |#2| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-852 |#1|) (-881 (-568))) (|has| |#2| (-881 (-568)))))) (-1598 (((-121) $) NIL)) (-3971 (((-763) $) NIL)) (-2053 (($ (-1157 |#2|) (-852 |#1|)) NIL) (($ (-1157 $) (-852 |#1|)) NIL)) (-3062 (((-634 $) $) NIL)) (-2171 (((-121) $) NIL)) (-2049 (($ |#2| (-534 (-852 |#1|))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-1438 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $ (-852 |#1|)) NIL)) (-3524 (((-534 (-852 |#1|)) $) NIL) (((-763) $ (-852 |#1|)) NIL) (((-634 (-763)) $ (-634 (-852 |#1|))) NIL)) (-1732 (($ $ $) NIL (|has| |#2| (-842)))) (-2047 (($ $ $) NIL (|has| |#2| (-842)))) (-1865 (($ (-1 (-534 (-852 |#1|)) (-534 (-852 |#1|))) $) NIL)) (-2797 (($ (-1 |#2| |#2|) $) NIL)) (-2817 (((-3 (-852 |#1|) "failed") $) NIL)) (-2099 (($ $) NIL)) (-2104 ((|#2| $) NIL)) (-2498 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) NIL (|has| |#2| (-453)))) (-1893 (((-1143) $) NIL)) (-4362 (((-3 (-634 $) "failed") $) NIL)) (-2112 (((-3 (-634 $) "failed") $) NIL)) (-2617 (((-3 (-2 (|:| |var| (-852 |#1|)) (|:| -3483 (-763))) "failed") $) NIL)) (-4025 (((-1108) $) NIL)) (-2088 (((-121) $) NIL)) (-2093 ((|#2| $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#2| (-453)))) (-2723 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) NIL (|has| |#2| (-453)))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3850 (((-420 $) $) NIL (|has| |#2| (-904)))) (-2597 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-558)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-852 |#1|) |#2|) NIL) (($ $ (-634 (-852 |#1|)) (-634 |#2|)) NIL) (($ $ (-852 |#1|) $) NIL) (($ $ (-634 (-852 |#1|)) (-634 $)) NIL)) (-3440 (($ $ (-852 |#1|)) NIL (|has| |#2| (-172)))) (-4191 (($ $ (-852 |#1|)) NIL) (($ $ (-634 (-852 |#1|))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-1836 (((-534 (-852 |#1|)) $) NIL) (((-763) $ (-852 |#1|)) NIL) (((-634 (-763)) $ (-634 (-852 |#1|))) NIL)) (-4280 (((-887 (-381)) $) NIL (-12 (|has| (-852 |#1|) (-609 (-887 (-381)))) (|has| |#2| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-852 |#1|) (-609 (-887 (-568)))) (|has| |#2| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-852 |#1|) (-609 (-541))) (|has| |#2| (-609 (-541)))))) (-1364 ((|#2| $) NIL (|has| |#2| (-453))) (($ $ (-852 |#1|)) NIL (|has| |#2| (-453)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#2| (-904))))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#2|) NIL) (($ (-852 |#1|)) NIL) (($ $) NIL (|has| |#2| (-558))) (($ (-409 (-568))) NIL (-2199 (|has| |#2| (-43 (-409 (-568)))) (|has| |#2| (-1037 (-409 (-568))))))) (-3304 (((-634 |#2|) $) NIL)) (-2079 ((|#2| $ (-534 (-852 |#1|))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| |#2| (-904))) (|has| |#2| (-148))))) (-3425 (((-763)) NIL)) (-3925 (($ $ $ (-763)) NIL (|has| |#2| (-172)))) (-2273 (((-121) $ $) NIL (|has| |#2| (-558)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $ (-852 |#1|)) NIL) (($ $ (-634 (-852 |#1|))) NIL) (($ $ (-852 |#1|) (-763)) NIL) (($ $ (-634 (-852 |#1|)) (-634 (-763))) NIL)) (-1753 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1781 (($ $ |#2|) NIL (|has| |#2| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#2| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#2| (-43 (-409 (-568))))) (($ |#2| $) NIL) (($ $ |#2|) NIL))) 
 (((-721 |#1| |#2|) (-950 |#2| (-534 (-852 |#1|)) (-852 |#1|)) (-634 (-1161)) (-1047)) (T -721)) 
 NIL 
 (-950 |#2| (-534 (-852 |#1|)) (-852 |#1|)) 
-((-2448 (((-2 (|:| -1462 (-953 |#3|)) (|:| -3582 (-953 |#3|))) |#4|) 13)) (-2917 ((|#4| |#4| |#2|) 30)) (-1388 ((|#4| (-409 (-953 |#3|)) |#2|) 63)) (-2038 ((|#4| (-1157 (-953 |#3|)) |#2|) 76)) (-2291 ((|#4| (-1157 |#4|) |#2|) 49)) (-3352 ((|#4| |#4| |#2|) 52)) (-3848 (((-420 |#4|) |#4|) 38))) 
-(((-722 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2448 ((-2 (|:| -1462 (-953 |#3|)) (|:| -3582 (-953 |#3|))) |#4|)) (-15 -3352 (|#4| |#4| |#2|)) (-15 -2291 (|#4| (-1157 |#4|) |#2|)) (-15 -2917 (|#4| |#4| |#2|)) (-15 -2038 (|#4| (-1157 (-953 |#3|)) |#2|)) (-15 -1388 (|#4| (-409 (-953 |#3|)) |#2|)) (-15 -3848 ((-420 |#4|) |#4|))) (-788) (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $)))) (-558) (-950 (-409 (-953 |#3|)) |#1| |#2|)) (T -722)) 
-((-3848 (*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $))))) (-4 *6 (-558)) (-5 *2 (-420 *3)) (-5 *1 (-722 *4 *5 *6 *3)) (-4 *3 (-950 (-409 (-953 *6)) *4 *5)))) (-1388 (*1 *2 *3 *4) (-12 (-4 *6 (-558)) (-4 *2 (-950 *3 *5 *4)) (-5 *1 (-722 *5 *4 *6 *2)) (-5 *3 (-409 (-953 *6))) (-4 *5 (-788)) (-4 *4 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $))))))) (-2038 (*1 *2 *3 *4) (-12 (-5 *3 (-1157 (-953 *6))) (-4 *6 (-558)) (-4 *2 (-950 (-409 (-953 *6)) *5 *4)) (-5 *1 (-722 *5 *4 *6 *2)) (-4 *5 (-788)) (-4 *4 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $))))))) (-2917 (*1 *2 *2 *3) (-12 (-4 *4 (-788)) (-4 *3 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $))))) (-4 *5 (-558)) (-5 *1 (-722 *4 *3 *5 *2)) (-4 *2 (-950 (-409 (-953 *5)) *4 *3)))) (-2291 (*1 *2 *3 *4) (-12 (-5 *3 (-1157 *2)) (-4 *2 (-950 (-409 (-953 *6)) *5 *4)) (-5 *1 (-722 *5 *4 *6 *2)) (-4 *5 (-788)) (-4 *4 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $))))) (-4 *6 (-558)))) (-3352 (*1 *2 *2 *3) (-12 (-4 *4 (-788)) (-4 *3 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $))))) (-4 *5 (-558)) (-5 *1 (-722 *4 *3 *5 *2)) (-4 *2 (-950 (-409 (-953 *5)) *4 *3)))) (-2448 (*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $))))) (-4 *6 (-558)) (-5 *2 (-2 (|:| -1462 (-953 *6)) (|:| -3582 (-953 *6)))) (-5 *1 (-722 *4 *5 *6 *3)) (-4 *3 (-950 (-409 (-953 *6)) *4 *5))))) 
-(-10 -7 (-15 -2448 ((-2 (|:| -1462 (-953 |#3|)) (|:| -3582 (-953 |#3|))) |#4|)) (-15 -3352 (|#4| |#4| |#2|)) (-15 -2291 (|#4| (-1157 |#4|) |#2|)) (-15 -2917 (|#4| |#4| |#2|)) (-15 -2038 (|#4| (-1157 (-953 |#3|)) |#2|)) (-15 -1388 (|#4| (-409 (-953 |#3|)) |#2|)) (-15 -3848 ((-420 |#4|) |#4|))) 
-((-3848 (((-420 |#4|) |#4|) 51))) 
-(((-723 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3848 ((-420 |#4|) |#4|))) (-788) (-842) (-13 (-301) (-150)) (-950 (-409 |#3|) |#1| |#2|)) (T -723)) 
-((-3848 (*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-13 (-301) (-150))) (-5 *2 (-420 *3)) (-5 *1 (-723 *4 *5 *6 *3)) (-4 *3 (-950 (-409 *6) *4 *5))))) 
-(-10 -7 (-15 -3848 ((-420 |#4|) |#4|))) 
-((-2795 (((-725 |#2| |#3|) (-1 |#2| |#1|) (-725 |#1| |#3|)) 18))) 
-(((-724 |#1| |#2| |#3|) (-10 -7 (-15 -2795 ((-725 |#2| |#3|) (-1 |#2| |#1|) (-725 |#1| |#3|)))) (-1047) (-1047) (-716)) (T -724)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-725 *5 *7)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-4 *7 (-716)) (-5 *2 (-725 *6 *7)) (-5 *1 (-724 *5 *6 *7))))) 
-(-10 -7 (-15 -2795 ((-725 |#2| |#3|) (-1 |#2| |#1|) (-725 |#1| |#3|)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 26)) (-2583 (((-634 (-2 (|:| -2348 |#1|) (|:| -2354 |#2|))) $) 27)) (-3134 (((-3 $ "failed") $ $) NIL)) (-3983 (((-763)) 20 (-12 (|has| |#2| (-370)) (|has| |#1| (-370))))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#2| "failed") $) 55) (((-3 |#1| "failed") $) 58)) (-2854 ((|#2| $) NIL) ((|#1| $) NIL)) (-2114 (($ $) 75 (|has| |#2| (-842)))) (-2925 (((-3 $ "failed") $) 62)) (-1731 (($) 33 (-12 (|has| |#2| (-370)) (|has| |#1| (-370))))) (-2735 (((-121) $) NIL)) (-4178 (((-763) $) 53)) (-2976 (((-634 $) $) 37)) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| |#2|) 16)) (-2795 (($ (-1 |#1| |#1|) $) 52)) (-3683 (((-917) $) 30 (-12 (|has| |#2| (-370)) (|has| |#1| (-370))))) (-2097 ((|#2| $) 74 (|has| |#2| (-842)))) (-2102 ((|#1| $) 73 (|has| |#2| (-842)))) (-4487 (((-1143) $) NIL)) (-4355 (($ (-917)) 25 (-12 (|has| |#2| (-370)) (|has| |#1| (-370))))) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 72) (($ (-568)) 44) (($ |#2|) 40) (($ |#1|) 41) (($ (-634 (-2 (|:| -2348 |#1|) (|:| -2354 |#2|)))) 11)) (-1302 (((-634 |#1|) $) 39)) (-2604 ((|#1| $ |#2|) 83)) (-4371 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-4078 (((-763)) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 12 T CONST)) (-1556 (($) 31 T CONST)) (-1717 (((-121) $ $) 76)) (-1773 (($ $) 46) (($ $ $) NIL)) (-1767 (($ $ $) 24)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 50) (($ $ $) 85) (($ |#1| $) 48 (|has| |#1| (-172))) (($ $ |#1|) NIL (|has| |#1| (-172))))) 
-(((-725 |#1| |#2|) (-13 (-1047) (-1037 |#2|) (-1037 |#1|) (-10 -8 (-15 -2047 ($ |#1| |#2|)) (-15 -2604 (|#1| $ |#2|)) (-15 -2745 ($ (-634 (-2 (|:| -2348 |#1|) (|:| -2354 |#2|))))) (-15 -2583 ((-634 (-2 (|:| -2348 |#1|) (|:| -2354 |#2|))) $)) (-15 -2795 ($ (-1 |#1| |#1|) $)) (-15 -3921 ((-121) $)) (-15 -1302 ((-634 |#1|) $)) (-15 -2976 ((-634 $) $)) (-15 -4178 ((-763) $)) (IF (|has| |#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |#1| (-172)) (-6 (-43 |#1|)) |noBranch|) (IF (|has| |#1| (-370)) (IF (|has| |#2| (-370)) (-6 (-370)) |noBranch|) |noBranch|) (IF (|has| |#2| (-842)) (PROGN (-15 -2097 (|#2| $)) (-15 -2102 (|#1| $)) (-15 -2114 ($ $))) |noBranch|))) (-1047) (-716)) (T -725)) 
-((-2047 (*1 *1 *2 *3) (-12 (-5 *1 (-725 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-716)))) (-2604 (*1 *2 *1 *3) (-12 (-4 *2 (-1047)) (-5 *1 (-725 *2 *3)) (-4 *3 (-716)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -2348 *3) (|:| -2354 *4)))) (-4 *3 (-1047)) (-4 *4 (-716)) (-5 *1 (-725 *3 *4)))) (-2583 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| -2348 *3) (|:| -2354 *4)))) (-5 *1 (-725 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-716)))) (-2795 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-725 *3 *4)) (-4 *4 (-716)))) (-3921 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-725 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-716)))) (-1302 (*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-725 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-716)))) (-2976 (*1 *2 *1) (-12 (-5 *2 (-634 (-725 *3 *4))) (-5 *1 (-725 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-716)))) (-4178 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-725 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-716)))) (-2097 (*1 *2 *1) (-12 (-4 *2 (-716)) (-4 *2 (-842)) (-5 *1 (-725 *3 *2)) (-4 *3 (-1047)))) (-2102 (*1 *2 *1) (-12 (-4 *2 (-1047)) (-5 *1 (-725 *2 *3)) (-4 *3 (-842)) (-4 *3 (-716)))) (-2114 (*1 *1 *1) (-12 (-5 *1 (-725 *2 *3)) (-4 *3 (-842)) (-4 *2 (-1047)) (-4 *3 (-716))))) 
-(-13 (-1047) (-1037 |#2|) (-1037 |#1|) (-10 -8 (-15 -2047 ($ |#1| |#2|)) (-15 -2604 (|#1| $ |#2|)) (-15 -2745 ($ (-634 (-2 (|:| -2348 |#1|) (|:| -2354 |#2|))))) (-15 -2583 ((-634 (-2 (|:| -2348 |#1|) (|:| -2354 |#2|))) $)) (-15 -2795 ($ (-1 |#1| |#1|) $)) (-15 -3921 ((-121) $)) (-15 -1302 ((-634 |#1|) $)) (-15 -2976 ((-634 $) $)) (-15 -4178 ((-763) $)) (IF (|has| |#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |#1| (-172)) (-6 (-43 |#1|)) |noBranch|) (IF (|has| |#1| (-370)) (IF (|has| |#2| (-370)) (-6 (-370)) |noBranch|) |noBranch|) (IF (|has| |#2| (-842)) (PROGN (-15 -2097 (|#2| $)) (-15 -2102 (|#1| $)) (-15 -2114 ($ $))) |noBranch|))) 
-((-2447 (((-121) $ $) 18)) (-1791 (($ |#1| $) 72) (($ $ |#1|) 71) (($ $ $) 70)) (-1536 (($ $ $) 68)) (-2032 (((-121) $ $) 69)) (-2510 (((-121) $ (-763)) 8)) (-2749 (($ (-634 |#1|)) 64) (($) 63)) (-3507 (($ (-1 (-121) |#1|) $) 42 (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) |#1|) $) 52 (|has| $ (-6 -4519)))) (-2671 (($) 7 T CONST)) (-3369 (($ $) 58)) (-3924 (($ $) 55 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3405 (($ |#1| $) 44 (|has| $ (-6 -4519))) (($ (-1 (-121) |#1|) $) 43 (|has| $ (-6 -4519)))) (-4328 (($ |#1| $) 54 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) |#1|) $) 51 (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4519)))) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) 9)) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35)) (-2166 (((-121) $ (-763)) 10)) (-4487 (((-1143) $) 22)) (-3212 (($ $ $) 65)) (-1890 ((|#1| $) 36)) (-4450 (($ |#1| $) 37) (($ |#1| $ (-763)) 59)) (-4022 (((-1108) $) 21)) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 48)) (-1315 ((|#1| $) 38)) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-1799 (((-634 (-2 (|:| -4083 |#1|) (|:| -4168 (-763)))) $) 57)) (-4382 (($ $ |#1|) 67) (($ $ $) 66)) (-2085 (($) 46) (($ (-634 |#1|)) 45)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-4278 (((-541) $) 56 (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) 47)) (-2745 (((-850) $) 20)) (-3844 (($ (-634 |#1|)) 62) (($) 61)) (-2367 (($ (-634 |#1|)) 39)) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19)) (-1732 (((-121) $ $) 60)) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-2510 (((-2 (|:| -2409 (-953 |#3|)) (|:| -2933 (-953 |#3|))) |#4|) 13)) (-2881 ((|#4| |#4| |#2|) 30)) (-3959 ((|#4| (-409 (-953 |#3|)) |#2|) 63)) (-1467 ((|#4| (-1157 (-953 |#3|)) |#2|) 76)) (-3562 ((|#4| (-1157 |#4|) |#2|) 49)) (-1286 ((|#4| |#4| |#2|) 52)) (-3850 (((-420 |#4|) |#4|) 38))) 
+(((-722 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2510 ((-2 (|:| -2409 (-953 |#3|)) (|:| -2933 (-953 |#3|))) |#4|)) (-15 -1286 (|#4| |#4| |#2|)) (-15 -3562 (|#4| (-1157 |#4|) |#2|)) (-15 -2881 (|#4| |#4| |#2|)) (-15 -1467 (|#4| (-1157 (-953 |#3|)) |#2|)) (-15 -3959 (|#4| (-409 (-953 |#3|)) |#2|)) (-15 -3850 ((-420 |#4|) |#4|))) (-788) (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $)))) (-558) (-950 (-409 (-953 |#3|)) |#1| |#2|)) (T -722)) 
+((-3850 (*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $))))) (-4 *6 (-558)) (-5 *2 (-420 *3)) (-5 *1 (-722 *4 *5 *6 *3)) (-4 *3 (-950 (-409 (-953 *6)) *4 *5)))) (-3959 (*1 *2 *3 *4) (-12 (-4 *6 (-558)) (-4 *2 (-950 *3 *5 *4)) (-5 *1 (-722 *5 *4 *6 *2)) (-5 *3 (-409 (-953 *6))) (-4 *5 (-788)) (-4 *4 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $))))))) (-1467 (*1 *2 *3 *4) (-12 (-5 *3 (-1157 (-953 *6))) (-4 *6 (-558)) (-4 *2 (-950 (-409 (-953 *6)) *5 *4)) (-5 *1 (-722 *5 *4 *6 *2)) (-4 *5 (-788)) (-4 *4 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $))))))) (-2881 (*1 *2 *2 *3) (-12 (-4 *4 (-788)) (-4 *3 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $))))) (-4 *5 (-558)) (-5 *1 (-722 *4 *3 *5 *2)) (-4 *2 (-950 (-409 (-953 *5)) *4 *3)))) (-3562 (*1 *2 *3 *4) (-12 (-5 *3 (-1157 *2)) (-4 *2 (-950 (-409 (-953 *6)) *5 *4)) (-5 *1 (-722 *5 *4 *6 *2)) (-4 *5 (-788)) (-4 *4 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $))))) (-4 *6 (-558)))) (-1286 (*1 *2 *2 *3) (-12 (-4 *4 (-788)) (-4 *3 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $))))) (-4 *5 (-558)) (-5 *1 (-722 *4 *3 *5 *2)) (-4 *2 (-950 (-409 (-953 *5)) *4 *3)))) (-2510 (*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $))))) (-4 *6 (-558)) (-5 *2 (-2 (|:| -2409 (-953 *6)) (|:| -2933 (-953 *6)))) (-5 *1 (-722 *4 *5 *6 *3)) (-4 *3 (-950 (-409 (-953 *6)) *4 *5))))) 
+(-10 -7 (-15 -2510 ((-2 (|:| -2409 (-953 |#3|)) (|:| -2933 (-953 |#3|))) |#4|)) (-15 -1286 (|#4| |#4| |#2|)) (-15 -3562 (|#4| (-1157 |#4|) |#2|)) (-15 -2881 (|#4| |#4| |#2|)) (-15 -1467 (|#4| (-1157 (-953 |#3|)) |#2|)) (-15 -3959 (|#4| (-409 (-953 |#3|)) |#2|)) (-15 -3850 ((-420 |#4|) |#4|))) 
+((-3850 (((-420 |#4|) |#4|) 51))) 
+(((-723 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3850 ((-420 |#4|) |#4|))) (-788) (-842) (-13 (-301) (-150)) (-950 (-409 |#3|) |#1| |#2|)) (T -723)) 
+((-3850 (*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-13 (-301) (-150))) (-5 *2 (-420 *3)) (-5 *1 (-723 *4 *5 *6 *3)) (-4 *3 (-950 (-409 *6) *4 *5))))) 
+(-10 -7 (-15 -3850 ((-420 |#4|) |#4|))) 
+((-2797 (((-725 |#2| |#3|) (-1 |#2| |#1|) (-725 |#1| |#3|)) 18))) 
+(((-724 |#1| |#2| |#3|) (-10 -7 (-15 -2797 ((-725 |#2| |#3|) (-1 |#2| |#1|) (-725 |#1| |#3|)))) (-1047) (-1047) (-716)) (T -724)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-725 *5 *7)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-4 *7 (-716)) (-5 *2 (-725 *6 *7)) (-5 *1 (-724 *5 *6 *7))))) 
+(-10 -7 (-15 -2797 ((-725 |#2| |#3|) (-1 |#2| |#1|) (-725 |#1| |#3|)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 26)) (-2013 (((-634 (-2 (|:| -2350 |#1|) (|:| -2356 |#2|))) $) 27)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3986 (((-763)) 20 (-12 (|has| |#2| (-370)) (|has| |#1| (-370))))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#2| "failed") $) 55) (((-3 |#1| "failed") $) 58)) (-2857 ((|#2| $) NIL) ((|#1| $) NIL)) (-2116 (($ $) 75 (|has| |#2| (-842)))) (-2902 (((-3 $ "failed") $) 62)) (-1733 (($) 33 (-12 (|has| |#2| (-370)) (|has| |#1| (-370))))) (-1598 (((-121) $) NIL)) (-3971 (((-763) $) 53)) (-3062 (((-634 $) $) 37)) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| |#2|) 16)) (-2797 (($ (-1 |#1| |#1|) $) 52)) (-2291 (((-917) $) 30 (-12 (|has| |#2| (-370)) (|has| |#1| (-370))))) (-2099 ((|#2| $) 74 (|has| |#2| (-842)))) (-2104 ((|#1| $) 73 (|has| |#2| (-842)))) (-1893 (((-1143) $) NIL)) (-4357 (($ (-917)) 25 (-12 (|has| |#2| (-370)) (|has| |#1| (-370))))) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 72) (($ (-568)) 44) (($ |#2|) 40) (($ |#1|) 41) (($ (-634 (-2 (|:| -2350 |#1|) (|:| -2356 |#2|)))) 11)) (-3304 (((-634 |#1|) $) 39)) (-2079 ((|#1| $ |#2|) 83)) (-3385 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-3425 (((-763)) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 12 T CONST)) (-1557 (($) 31 T CONST)) (-1719 (((-121) $ $) 76)) (-1775 (($ $) 46) (($ $ $) NIL)) (-1769 (($ $ $) 24)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 50) (($ $ $) 85) (($ |#1| $) 48 (|has| |#1| (-172))) (($ $ |#1|) NIL (|has| |#1| (-172))))) 
+(((-725 |#1| |#2|) (-13 (-1047) (-1037 |#2|) (-1037 |#1|) (-10 -8 (-15 -2049 ($ |#1| |#2|)) (-15 -2079 (|#1| $ |#2|)) (-15 -2747 ($ (-634 (-2 (|:| -2350 |#1|) (|:| -2356 |#2|))))) (-15 -2013 ((-634 (-2 (|:| -2350 |#1|) (|:| -2356 |#2|))) $)) (-15 -2797 ($ (-1 |#1| |#1|) $)) (-15 -2171 ((-121) $)) (-15 -3304 ((-634 |#1|) $)) (-15 -3062 ((-634 $) $)) (-15 -3971 ((-763) $)) (IF (|has| |#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |#1| (-172)) (-6 (-43 |#1|)) |noBranch|) (IF (|has| |#1| (-370)) (IF (|has| |#2| (-370)) (-6 (-370)) |noBranch|) |noBranch|) (IF (|has| |#2| (-842)) (PROGN (-15 -2099 (|#2| $)) (-15 -2104 (|#1| $)) (-15 -2116 ($ $))) |noBranch|))) (-1047) (-716)) (T -725)) 
+((-2049 (*1 *1 *2 *3) (-12 (-5 *1 (-725 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-716)))) (-2079 (*1 *2 *1 *3) (-12 (-4 *2 (-1047)) (-5 *1 (-725 *2 *3)) (-4 *3 (-716)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -2350 *3) (|:| -2356 *4)))) (-4 *3 (-1047)) (-4 *4 (-716)) (-5 *1 (-725 *3 *4)))) (-2013 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| -2350 *3) (|:| -2356 *4)))) (-5 *1 (-725 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-716)))) (-2797 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-725 *3 *4)) (-4 *4 (-716)))) (-2171 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-725 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-716)))) (-3304 (*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-725 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-716)))) (-3062 (*1 *2 *1) (-12 (-5 *2 (-634 (-725 *3 *4))) (-5 *1 (-725 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-716)))) (-3971 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-725 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-716)))) (-2099 (*1 *2 *1) (-12 (-4 *2 (-716)) (-4 *2 (-842)) (-5 *1 (-725 *3 *2)) (-4 *3 (-1047)))) (-2104 (*1 *2 *1) (-12 (-4 *2 (-1047)) (-5 *1 (-725 *2 *3)) (-4 *3 (-842)) (-4 *3 (-716)))) (-2116 (*1 *1 *1) (-12 (-5 *1 (-725 *2 *3)) (-4 *3 (-842)) (-4 *2 (-1047)) (-4 *3 (-716))))) 
+(-13 (-1047) (-1037 |#2|) (-1037 |#1|) (-10 -8 (-15 -2049 ($ |#1| |#2|)) (-15 -2079 (|#1| $ |#2|)) (-15 -2747 ($ (-634 (-2 (|:| -2350 |#1|) (|:| -2356 |#2|))))) (-15 -2013 ((-634 (-2 (|:| -2350 |#1|) (|:| -2356 |#2|))) $)) (-15 -2797 ($ (-1 |#1| |#1|) $)) (-15 -2171 ((-121) $)) (-15 -3304 ((-634 |#1|) $)) (-15 -3062 ((-634 $) $)) (-15 -3971 ((-763) $)) (IF (|has| |#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |#1| (-172)) (-6 (-43 |#1|)) |noBranch|) (IF (|has| |#1| (-370)) (IF (|has| |#2| (-370)) (-6 (-370)) |noBranch|) |noBranch|) (IF (|has| |#2| (-842)) (PROGN (-15 -2099 (|#2| $)) (-15 -2104 (|#1| $)) (-15 -2116 ($ $))) |noBranch|))) 
+((-2449 (((-121) $ $) 18)) (-1793 (($ |#1| $) 72) (($ $ |#1|) 71) (($ $ $) 70)) (-4217 (($ $ $) 68)) (-1430 (((-121) $ $) 69)) (-1667 (((-121) $ (-763)) 8)) (-2751 (($ (-634 |#1|)) 64) (($) 63)) (-3963 (($ (-1 (-121) |#1|) $) 42 (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) |#1|) $) 52 (|has| $ (-6 -4521)))) (-4490 (($) 7 T CONST)) (-1377 (($ $) 58)) (-3926 (($ $) 55 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-1568 (($ |#1| $) 44 (|has| $ (-6 -4521))) (($ (-1 (-121) |#1|) $) 43 (|has| $ (-6 -4521)))) (-4330 (($ |#1| $) 54 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) |#1|) $) 51 (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4521)))) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) 9)) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35)) (-3796 (((-121) $ (-763)) 10)) (-1893 (((-1143) $) 22)) (-1864 (($ $ $) 65)) (-2580 ((|#1| $) 36)) (-1708 (($ |#1| $) 37) (($ |#1| $ (-763)) 59)) (-4025 (((-1108) $) 21)) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 48)) (-3403 ((|#1| $) 38)) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2138 (((-634 (-2 (|:| -4085 |#1|) (|:| -4170 (-763)))) $) 57)) (-1363 (($ $ |#1|) 67) (($ $ $) 66)) (-3132 (($) 46) (($ (-634 |#1|)) 45)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-4280 (((-541) $) 56 (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) 47)) (-2747 (((-850) $) 20)) (-3846 (($ (-634 |#1|)) 62) (($) 61)) (-4074 (($ (-634 |#1|)) 39)) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19)) (-1734 (((-121) $ $) 60)) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-726 |#1|) (-1275) (-1090)) (T -726)) 
 NIL 
 (-13 (-684 |t#1|) (-1087 |t#1|)) 
 (((-39) . T) ((-111 |#1|) . T) ((-105) . T) ((-608 (-850)) . T) ((-154 |#1|) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-227 |#1|) . T) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-684 |#1|) . T) ((-1087 |#1|) . T) ((-1090) . T) ((-1195) . T)) 
-((-2447 (((-121) $ $) NIL)) (-1791 (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ $ $) 77)) (-1536 (($ $ $) 80)) (-2032 (((-121) $ $) 83)) (-2510 (((-121) $ (-763)) NIL)) (-2749 (($ (-634 |#1|)) 24) (($) 15)) (-3507 (($ (-1 (-121) |#1|) $) 71 (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-2671 (($) NIL T CONST)) (-3369 (($ $) 72)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3405 (($ |#1| $) 61 (|has| $ (-6 -4519))) (($ (-1 (-121) |#1|) $) 64 (|has| $ (-6 -4519))) (($ |#1| $ (-568)) 62) (($ (-1 (-121) |#1|) $ (-568)) 65)) (-4328 (($ |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (($ |#1| $ (-568)) 67) (($ (-1 (-121) |#1|) $ (-568)) 68)) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4519)))) (-4360 (((-634 |#1|) $) 32 (|has| $ (-6 -4519)))) (-2419 (($) 13) (($ |#1|) 26) (($ (-634 |#1|)) 21)) (-1737 (((-121) $ (-763)) NIL)) (-1979 (((-634 |#1|) $) 38)) (-3109 (((-121) |#1| $) 57 (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3674 (($ (-1 |#1| |#1|) $) 75 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 76)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL)) (-3212 (($ $ $) 78)) (-1890 ((|#1| $) 54)) (-4450 (($ |#1| $) 55) (($ |#1| $ (-763)) 73)) (-4022 (((-1108) $) NIL)) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-1315 ((|#1| $) 53)) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) 49)) (-3248 (($) 12)) (-1799 (((-634 (-2 (|:| -4083 |#1|) (|:| -4168 (-763)))) $) 47)) (-4382 (($ $ |#1|) NIL) (($ $ $) 79)) (-2085 (($) 14) (($ (-634 |#1|)) 23)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) 60 (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) 66)) (-4278 (((-541) $) 36 (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) 20)) (-2745 (((-850) $) 44)) (-3844 (($ (-634 |#1|)) 25) (($) 16)) (-2367 (($ (-634 |#1|)) 22)) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 81)) (-1732 (((-121) $ $) 82)) (-1697 (((-763) $) 59 (|has| $ (-6 -4519))))) 
-(((-727 |#1|) (-13 (-726 |#1|) (-10 -8 (-6 -4519) (-6 -4520) (-15 -2419 ($)) (-15 -2419 ($ |#1|)) (-15 -2419 ($ (-634 |#1|))) (-15 -1979 ((-634 |#1|) $)) (-15 -4328 ($ |#1| $ (-568))) (-15 -4328 ($ (-1 (-121) |#1|) $ (-568))) (-15 -3405 ($ |#1| $ (-568))) (-15 -3405 ($ (-1 (-121) |#1|) $ (-568))))) (-1090)) (T -727)) 
-((-2419 (*1 *1) (-12 (-5 *1 (-727 *2)) (-4 *2 (-1090)))) (-2419 (*1 *1 *2) (-12 (-5 *1 (-727 *2)) (-4 *2 (-1090)))) (-2419 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-727 *3)))) (-1979 (*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-727 *3)) (-4 *3 (-1090)))) (-4328 (*1 *1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-727 *2)) (-4 *2 (-1090)))) (-4328 (*1 *1 *2 *1 *3) (-12 (-5 *2 (-1 (-121) *4)) (-5 *3 (-568)) (-4 *4 (-1090)) (-5 *1 (-727 *4)))) (-3405 (*1 *1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-727 *2)) (-4 *2 (-1090)))) (-3405 (*1 *1 *2 *1 *3) (-12 (-5 *2 (-1 (-121) *4)) (-5 *3 (-568)) (-4 *4 (-1090)) (-5 *1 (-727 *4))))) 
-(-13 (-726 |#1|) (-10 -8 (-6 -4519) (-6 -4520) (-15 -2419 ($)) (-15 -2419 ($ |#1|)) (-15 -2419 ($ (-634 |#1|))) (-15 -1979 ((-634 |#1|) $)) (-15 -4328 ($ |#1| $ (-568))) (-15 -4328 ($ (-1 (-121) |#1|) $ (-568))) (-15 -3405 ($ |#1| $ (-568))) (-15 -3405 ($ (-1 (-121) |#1|) $ (-568))))) 
-((-3229 (((-1249) (-1143)) 8))) 
-(((-728) (-10 -7 (-15 -3229 ((-1249) (-1143))))) (T -728)) 
-((-3229 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-728))))) 
-(-10 -7 (-15 -3229 ((-1249) (-1143)))) 
-((-2914 (((-634 |#1|) (-634 |#1|) (-634 |#1|)) 10))) 
-(((-729 |#1|) (-10 -7 (-15 -2914 ((-634 |#1|) (-634 |#1|) (-634 |#1|)))) (-842)) (T -729)) 
-((-2914 (*1 *2 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-729 *3))))) 
-(-10 -7 (-15 -2914 ((-634 |#1|) (-634 |#1|) (-634 |#1|)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-2055 (((-634 |#2|) $) 134)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 127 (|has| |#1| (-558)))) (-2227 (($ $) 126 (|has| |#1| (-558)))) (-1573 (((-121) $) 124 (|has| |#1| (-558)))) (-1982 (($ $) 83 (|has| |#1| (-43 (-409 (-568)))))) (-1933 (($ $) 66 (|has| |#1| (-43 (-409 (-568)))))) (-3134 (((-3 $ "failed") $ $) 18)) (-1902 (($ $) 65 (|has| |#1| (-43 (-409 (-568)))))) (-1974 (($ $) 82 (|has| |#1| (-43 (-409 (-568)))))) (-2786 (($ $) 67 (|has| |#1| (-43 (-409 (-568)))))) (-1990 (($ $) 81 (|has| |#1| (-43 (-409 (-568)))))) (-1941 (($ $) 68 (|has| |#1| (-43 (-409 (-568)))))) (-2671 (($) 16 T CONST)) (-2114 (($ $) 118)) (-2925 (((-3 $ "failed") $) 33)) (-1367 (((-953 |#1|) $ (-763)) 96) (((-953 |#1|) $ (-763) (-763)) 95)) (-3992 (((-121) $) 135)) (-1897 (($) 93 (|has| |#1| (-43 (-409 (-568)))))) (-4477 (((-763) $ |#2|) 98) (((-763) $ |#2| (-763)) 97)) (-2735 (((-121) $) 30)) (-4044 (($ $ (-568)) 64 (|has| |#1| (-43 (-409 (-568)))))) (-3921 (((-121) $) 116)) (-2047 (($ $ (-634 |#2|) (-634 (-534 |#2|))) 133) (($ $ |#2| (-534 |#2|)) 132) (($ |#1| (-534 |#2|)) 117) (($ $ |#2| (-763)) 100) (($ $ (-634 |#2|) (-634 (-763))) 99)) (-2795 (($ (-1 |#1| |#1|) $) 115)) (-4416 (($ $) 90 (|has| |#1| (-43 (-409 (-568)))))) (-2097 (($ $) 113)) (-2102 ((|#1| $) 112)) (-4487 (((-1143) $) 9)) (-3837 (($ $ |#2|) 94 (|has| |#1| (-43 (-409 (-568)))))) (-4022 (((-1108) $) 10)) (-1807 (($ $ (-763)) 101)) (-2595 (((-3 $ "failed") $ $) 128 (|has| |#1| (-558)))) (-1892 (($ $) 91 (|has| |#1| (-43 (-409 (-568)))))) (-1339 (($ $ |#2| $) 109) (($ $ (-634 |#2|) (-634 $)) 108) (($ $ (-634 (-288 $))) 107) (($ $ (-288 $)) 106) (($ $ $ $) 105) (($ $ (-634 $) (-634 $)) 104)) (-4189 (($ $ |#2|) 41) (($ $ (-634 |#2|)) 40) (($ $ |#2| (-763)) 39) (($ $ (-634 |#2|) (-634 (-763))) 38)) (-3206 (((-534 |#2|) $) 114)) (-1994 (($ $) 80 (|has| |#1| (-43 (-409 (-568)))))) (-1945 (($ $) 69 (|has| |#1| (-43 (-409 (-568)))))) (-1986 (($ $) 79 (|has| |#1| (-43 (-409 (-568)))))) (-1937 (($ $) 70 (|has| |#1| (-43 (-409 (-568)))))) (-1978 (($ $) 78 (|has| |#1| (-43 (-409 (-568)))))) (-2790 (($ $) 71 (|has| |#1| (-43 (-409 (-568)))))) (-1811 (($ $) 136)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 131 (|has| |#1| (-172))) (($ $) 129 (|has| |#1| (-558))) (($ (-409 (-568))) 121 (|has| |#1| (-43 (-409 (-568)))))) (-2604 ((|#1| $ (-534 |#2|)) 119) (($ $ |#2| (-763)) 103) (($ $ (-634 |#2|) (-634 (-763))) 102)) (-4371 (((-3 $ "failed") $) 130 (|has| |#1| (-148)))) (-4078 (((-763)) 28)) (-2006 (($ $) 89 (|has| |#1| (-43 (-409 (-568)))))) (-1958 (($ $) 77 (|has| |#1| (-43 (-409 (-568)))))) (-1826 (((-121) $ $) 125 (|has| |#1| (-558)))) (-1998 (($ $) 88 (|has| |#1| (-43 (-409 (-568)))))) (-1949 (($ $) 76 (|has| |#1| (-43 (-409 (-568)))))) (-2014 (($ $) 87 (|has| |#1| (-43 (-409 (-568)))))) (-1966 (($ $) 75 (|has| |#1| (-43 (-409 (-568)))))) (-4023 (($ $) 86 (|has| |#1| (-43 (-409 (-568)))))) (-1970 (($ $) 74 (|has| |#1| (-43 (-409 (-568)))))) (-2010 (($ $) 85 (|has| |#1| (-43 (-409 (-568)))))) (-1962 (($ $) 73 (|has| |#1| (-43 (-409 (-568)))))) (-2002 (($ $) 84 (|has| |#1| (-43 (-409 (-568)))))) (-1953 (($ $) 72 (|has| |#1| (-43 (-409 (-568)))))) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $ |#2|) 37) (($ $ (-634 |#2|)) 36) (($ $ |#2| (-763)) 35) (($ $ (-634 |#2|) (-634 (-763))) 34)) (-1717 (((-121) $ $) 6)) (-1779 (($ $ |#1|) 120 (|has| |#1| (-365)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ $) 92 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 63 (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 123 (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) 122 (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) 111) (($ $ |#1|) 110))) 
+((-2449 (((-121) $ $) NIL)) (-1793 (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ $ $) 77)) (-4217 (($ $ $) 80)) (-1430 (((-121) $ $) 83)) (-1667 (((-121) $ (-763)) NIL)) (-2751 (($ (-634 |#1|)) 24) (($) 15)) (-3963 (($ (-1 (-121) |#1|) $) 71 (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-4490 (($) NIL T CONST)) (-1377 (($ $) 72)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1568 (($ |#1| $) 61 (|has| $ (-6 -4521))) (($ (-1 (-121) |#1|) $) 64 (|has| $ (-6 -4521))) (($ |#1| $ (-568)) 62) (($ (-1 (-121) |#1|) $ (-568)) 65)) (-4330 (($ |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (($ |#1| $ (-568)) 67) (($ (-1 (-121) |#1|) $ (-568)) 68)) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4521)))) (-3317 (((-634 |#1|) $) 32 (|has| $ (-6 -4521)))) (-2369 (($) 13) (($ |#1|) 26) (($ (-634 |#1|)) 21)) (-3791 (((-121) $ (-763)) NIL)) (-4406 (((-634 |#1|) $) 38)) (-2551 (((-121) |#1| $) 57 (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-2253 (($ (-1 |#1| |#1|) $) 75 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 76)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL)) (-1864 (($ $ $) 78)) (-2580 ((|#1| $) 54)) (-1708 (($ |#1| $) 55) (($ |#1| $ (-763)) 73)) (-4025 (((-1108) $) NIL)) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3403 ((|#1| $) 53)) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) 49)) (-1990 (($) 12)) (-2138 (((-634 (-2 (|:| -4085 |#1|) (|:| -4170 (-763)))) $) 47)) (-1363 (($ $ |#1|) NIL) (($ $ $) 79)) (-3132 (($) 14) (($ (-634 |#1|)) 23)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) 60 (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) 66)) (-4280 (((-541) $) 36 (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) 20)) (-2747 (((-850) $) 44)) (-3846 (($ (-634 |#1|)) 25) (($) 16)) (-4074 (($ (-634 |#1|)) 22)) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 81)) (-1734 (((-121) $ $) 82)) (-1699 (((-763) $) 59 (|has| $ (-6 -4521))))) 
+(((-727 |#1|) (-13 (-726 |#1|) (-10 -8 (-6 -4521) (-6 -4522) (-15 -2369 ($)) (-15 -2369 ($ |#1|)) (-15 -2369 ($ (-634 |#1|))) (-15 -4406 ((-634 |#1|) $)) (-15 -4330 ($ |#1| $ (-568))) (-15 -4330 ($ (-1 (-121) |#1|) $ (-568))) (-15 -1568 ($ |#1| $ (-568))) (-15 -1568 ($ (-1 (-121) |#1|) $ (-568))))) (-1090)) (T -727)) 
+((-2369 (*1 *1) (-12 (-5 *1 (-727 *2)) (-4 *2 (-1090)))) (-2369 (*1 *1 *2) (-12 (-5 *1 (-727 *2)) (-4 *2 (-1090)))) (-2369 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-727 *3)))) (-4406 (*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-727 *3)) (-4 *3 (-1090)))) (-4330 (*1 *1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-727 *2)) (-4 *2 (-1090)))) (-4330 (*1 *1 *2 *1 *3) (-12 (-5 *2 (-1 (-121) *4)) (-5 *3 (-568)) (-4 *4 (-1090)) (-5 *1 (-727 *4)))) (-1568 (*1 *1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-727 *2)) (-4 *2 (-1090)))) (-1568 (*1 *1 *2 *1 *3) (-12 (-5 *2 (-1 (-121) *4)) (-5 *3 (-568)) (-4 *4 (-1090)) (-5 *1 (-727 *4))))) 
+(-13 (-726 |#1|) (-10 -8 (-6 -4521) (-6 -4522) (-15 -2369 ($)) (-15 -2369 ($ |#1|)) (-15 -2369 ($ (-634 |#1|))) (-15 -4406 ((-634 |#1|) $)) (-15 -4330 ($ |#1| $ (-568))) (-15 -4330 ($ (-1 (-121) |#1|) $ (-568))) (-15 -1568 ($ |#1| $ (-568))) (-15 -1568 ($ (-1 (-121) |#1|) $ (-568))))) 
+((-3231 (((-1249) (-1143)) 8))) 
+(((-728) (-10 -7 (-15 -3231 ((-1249) (-1143))))) (T -728)) 
+((-3231 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-728))))) 
+(-10 -7 (-15 -3231 ((-1249) (-1143)))) 
+((-2875 (((-634 |#1|) (-634 |#1|) (-634 |#1|)) 10))) 
+(((-729 |#1|) (-10 -7 (-15 -2875 ((-634 |#1|) (-634 |#1|) (-634 |#1|)))) (-842)) (T -729)) 
+((-2875 (*1 *2 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-729 *3))))) 
+(-10 -7 (-15 -2875 ((-634 |#1|) (-634 |#1|) (-634 |#1|)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2057 (((-634 |#2|) $) 134)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 127 (|has| |#1| (-558)))) (-3661 (($ $) 126 (|has| |#1| (-558)))) (-4426 (((-121) $) 124 (|has| |#1| (-558)))) (-1984 (($ $) 83 (|has| |#1| (-43 (-409 (-568)))))) (-1935 (($ $) 66 (|has| |#1| (-43 (-409 (-568)))))) (-2689 (((-3 $ "failed") $ $) 18)) (-1904 (($ $) 65 (|has| |#1| (-43 (-409 (-568)))))) (-1976 (($ $) 82 (|has| |#1| (-43 (-409 (-568)))))) (-2788 (($ $) 67 (|has| |#1| (-43 (-409 (-568)))))) (-1992 (($ $) 81 (|has| |#1| (-43 (-409 (-568)))))) (-1943 (($ $) 68 (|has| |#1| (-43 (-409 (-568)))))) (-4490 (($) 16 T CONST)) (-2116 (($ $) 118)) (-2902 (((-3 $ "failed") $) 33)) (-3808 (((-953 |#1|) $ (-763)) 96) (((-953 |#1|) $ (-763) (-763)) 95)) (-1302 (((-121) $) 135)) (-1899 (($) 93 (|has| |#1| (-43 (-409 (-568)))))) (-1844 (((-763) $ |#2|) 98) (((-763) $ |#2| (-763)) 97)) (-1598 (((-121) $) 30)) (-1550 (($ $ (-568)) 64 (|has| |#1| (-43 (-409 (-568)))))) (-2171 (((-121) $) 116)) (-2049 (($ $ (-634 |#2|) (-634 (-534 |#2|))) 133) (($ $ |#2| (-534 |#2|)) 132) (($ |#1| (-534 |#2|)) 117) (($ $ |#2| (-763)) 100) (($ $ (-634 |#2|) (-634 (-763))) 99)) (-2797 (($ (-1 |#1| |#1|) $) 115)) (-4418 (($ $) 90 (|has| |#1| (-43 (-409 (-568)))))) (-2099 (($ $) 113)) (-2104 ((|#1| $) 112)) (-1893 (((-1143) $) 9)) (-1845 (($ $ |#2|) 94 (|has| |#1| (-43 (-409 (-568)))))) (-4025 (((-1108) $) 10)) (-2168 (($ $ (-763)) 101)) (-2597 (((-3 $ "failed") $ $) 128 (|has| |#1| (-558)))) (-1894 (($ $) 91 (|has| |#1| (-43 (-409 (-568)))))) (-1339 (($ $ |#2| $) 109) (($ $ (-634 |#2|) (-634 $)) 108) (($ $ (-634 (-288 $))) 107) (($ $ (-288 $)) 106) (($ $ $ $) 105) (($ $ (-634 $) (-634 $)) 104)) (-4191 (($ $ |#2|) 41) (($ $ (-634 |#2|)) 40) (($ $ |#2| (-763)) 39) (($ $ (-634 |#2|) (-634 (-763))) 38)) (-1836 (((-534 |#2|) $) 114)) (-1996 (($ $) 80 (|has| |#1| (-43 (-409 (-568)))))) (-1947 (($ $) 69 (|has| |#1| (-43 (-409 (-568)))))) (-1988 (($ $) 79 (|has| |#1| (-43 (-409 (-568)))))) (-1939 (($ $) 70 (|has| |#1| (-43 (-409 (-568)))))) (-1980 (($ $) 78 (|has| |#1| (-43 (-409 (-568)))))) (-2792 (($ $) 71 (|has| |#1| (-43 (-409 (-568)))))) (-2188 (($ $) 136)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 131 (|has| |#1| (-172))) (($ $) 129 (|has| |#1| (-558))) (($ (-409 (-568))) 121 (|has| |#1| (-43 (-409 (-568)))))) (-2079 ((|#1| $ (-534 |#2|)) 119) (($ $ |#2| (-763)) 103) (($ $ (-634 |#2|) (-634 (-763))) 102)) (-3385 (((-3 $ "failed") $) 130 (|has| |#1| (-148)))) (-3425 (((-763)) 28)) (-2008 (($ $) 89 (|has| |#1| (-43 (-409 (-568)))))) (-1959 (($ $) 77 (|has| |#1| (-43 (-409 (-568)))))) (-2273 (((-121) $ $) 125 (|has| |#1| (-558)))) (-2000 (($ $) 88 (|has| |#1| (-43 (-409 (-568)))))) (-1951 (($ $) 76 (|has| |#1| (-43 (-409 (-568)))))) (-2016 (($ $) 87 (|has| |#1| (-43 (-409 (-568)))))) (-1968 (($ $) 75 (|has| |#1| (-43 (-409 (-568)))))) (-1439 (($ $) 86 (|has| |#1| (-43 (-409 (-568)))))) (-1972 (($ $) 74 (|has| |#1| (-43 (-409 (-568)))))) (-2012 (($ $) 85 (|has| |#1| (-43 (-409 (-568)))))) (-1964 (($ $) 73 (|has| |#1| (-43 (-409 (-568)))))) (-2004 (($ $) 84 (|has| |#1| (-43 (-409 (-568)))))) (-1955 (($ $) 72 (|has| |#1| (-43 (-409 (-568)))))) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $ |#2|) 37) (($ $ (-634 |#2|)) 36) (($ $ |#2| (-763)) 35) (($ $ (-634 |#2|) (-634 (-763))) 34)) (-1719 (((-121) $ $) 6)) (-1781 (($ $ |#1|) 120 (|has| |#1| (-365)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ $) 92 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 63 (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 123 (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) 122 (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) 111) (($ $ |#1|) 110))) 
 (((-730 |#1| |#2|) (-1275) (-1047) (-842)) (T -730)) 
-((-2604 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-730 *4 *2)) (-4 *4 (-1047)) (-4 *2 (-842)))) (-2604 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *5)) (-5 *3 (-634 (-763))) (-4 *1 (-730 *4 *5)) (-4 *4 (-1047)) (-4 *5 (-842)))) (-1807 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-730 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-842)))) (-2047 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-730 *4 *2)) (-4 *4 (-1047)) (-4 *2 (-842)))) (-2047 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *5)) (-5 *3 (-634 (-763))) (-4 *1 (-730 *4 *5)) (-4 *4 (-1047)) (-4 *5 (-842)))) (-4477 (*1 *2 *1 *3) (-12 (-4 *1 (-730 *4 *3)) (-4 *4 (-1047)) (-4 *3 (-842)) (-5 *2 (-763)))) (-4477 (*1 *2 *1 *3 *2) (-12 (-5 *2 (-763)) (-4 *1 (-730 *4 *3)) (-4 *4 (-1047)) (-4 *3 (-842)))) (-1367 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-730 *4 *5)) (-4 *4 (-1047)) (-4 *5 (-842)) (-5 *2 (-953 *4)))) (-1367 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-4 *1 (-730 *4 *5)) (-4 *4 (-1047)) (-4 *5 (-842)) (-5 *2 (-953 *4)))) (-3837 (*1 *1 *1 *2) (-12 (-4 *1 (-730 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-842)) (-4 *3 (-43 (-409 (-568))))))) 
-(-13 (-895 |t#2|) (-974 |t#1| (-534 |t#2|) |t#2|) (-523 |t#2| $) (-303 $) (-10 -8 (-15 -2604 ($ $ |t#2| (-763))) (-15 -2604 ($ $ (-634 |t#2|) (-634 (-763)))) (-15 -1807 ($ $ (-763))) (-15 -2047 ($ $ |t#2| (-763))) (-15 -2047 ($ $ (-634 |t#2|) (-634 (-763)))) (-15 -4477 ((-763) $ |t#2|)) (-15 -4477 ((-763) $ |t#2| (-763))) (-15 -1367 ((-953 |t#1|) $ (-763))) (-15 -1367 ((-953 |t#1|) $ (-763) (-763))) (IF (|has| |t#1| (-43 (-409 (-568)))) (PROGN (-15 -3837 ($ $ |t#2|)) (-6 (-1002)) (-6 (-1181))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| (-534 |#2|)) . T) ((-25) . T) ((-43 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) |has| |#1| (-558)) ((-40) |has| |#1| (-43 (-409 (-568)))) ((-98) |has| |#1| (-43 (-409 (-568)))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2198 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2198 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-279) |has| |#1| (-43 (-409 (-568)))) ((-285) |has| |#1| (-558)) ((-303 $) . T) ((-502) |has| |#1| (-43 (-409 (-568)))) ((-523 |#2| $) . T) ((-523 $ $) . T) ((-558) |has| |#1| (-558)) ((-637 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) |has| |#1| (-558)) ((-716) . T) ((-895 |#2|) . T) ((-974 |#1| (-534 |#2|) |#2|) . T) ((-1002) |has| |#1| (-43 (-409 (-568)))) ((-1053 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-1053 |#1|) . T) ((-1053 $) -2198 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1181) |has| |#1| (-43 (-409 (-568)))) ((-1184) |has| |#1| (-43 (-409 (-568))))) 
-((-3848 (((-420 (-1157 |#4|)) (-1157 |#4|)) 28) (((-420 |#4|) |#4|) 24))) 
-(((-731 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3848 ((-420 |#4|) |#4|)) (-15 -3848 ((-420 (-1157 |#4|)) (-1157 |#4|)))) (-842) (-788) (-13 (-301) (-150)) (-950 |#3| |#2| |#1|)) (T -731)) 
-((-3848 (*1 *2 *3) (-12 (-4 *4 (-842)) (-4 *5 (-788)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-950 *6 *5 *4)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-731 *4 *5 *6 *7)) (-5 *3 (-1157 *7)))) (-3848 (*1 *2 *3) (-12 (-4 *4 (-842)) (-4 *5 (-788)) (-4 *6 (-13 (-301) (-150))) (-5 *2 (-420 *3)) (-5 *1 (-731 *4 *5 *6 *3)) (-4 *3 (-950 *6 *5 *4))))) 
-(-10 -7 (-15 -3848 ((-420 |#4|) |#4|)) (-15 -3848 ((-420 (-1157 |#4|)) (-1157 |#4|)))) 
-((-1589 (((-420 |#4|) |#4| |#2|) 116)) (-2389 (((-420 |#4|) |#4|) NIL)) (-1678 (((-420 (-1157 |#4|)) (-1157 |#4|)) 107) (((-420 |#4|) |#4|) 38)) (-2837 (((-2 (|:| |unitPart| |#4|) (|:| |suPart| (-634 (-2 (|:| -3848 (-1157 |#4|)) (|:| -3438 (-568)))))) (-1157 |#4|) (-634 |#2|) (-634 (-634 |#3|))) 65)) (-3966 (((-1157 |#3|) (-1157 |#3|) (-568)) 133)) (-3448 (((-634 (-763)) (-1157 |#4|) (-634 |#2|) (-763)) 58)) (-3085 (((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-1157 |#3|) (-1157 |#3|) |#4| (-634 |#2|) (-634 (-763)) (-634 |#3|)) 62)) (-3280 (((-2 (|:| |upol| (-1157 |#3|)) (|:| |Lval| (-634 |#3|)) (|:| |Lfact| (-634 (-2 (|:| -3848 (-1157 |#3|)) (|:| -3438 (-568))))) (|:| |ctpol| |#3|)) (-1157 |#4|) (-634 |#2|) (-634 (-634 |#3|))) 22)) (-1724 (((-2 (|:| -2700 (-1157 |#4|)) (|:| |polval| (-1157 |#3|))) (-1157 |#4|) (-1157 |#3|) (-568)) 54)) (-1843 (((-568) (-634 (-2 (|:| -3848 (-1157 |#3|)) (|:| -3438 (-568))))) 130)) (-2331 ((|#4| (-568) (-420 |#4|)) 55)) (-1644 (((-121) (-634 (-2 (|:| -3848 (-1157 |#3|)) (|:| -3438 (-568)))) (-634 (-2 (|:| -3848 (-1157 |#3|)) (|:| -3438 (-568))))) NIL))) 
-(((-732 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1678 ((-420 |#4|) |#4|)) (-15 -1678 ((-420 (-1157 |#4|)) (-1157 |#4|))) (-15 -2389 ((-420 |#4|) |#4|)) (-15 -1843 ((-568) (-634 (-2 (|:| -3848 (-1157 |#3|)) (|:| -3438 (-568)))))) (-15 -1589 ((-420 |#4|) |#4| |#2|)) (-15 -1724 ((-2 (|:| -2700 (-1157 |#4|)) (|:| |polval| (-1157 |#3|))) (-1157 |#4|) (-1157 |#3|) (-568))) (-15 -2837 ((-2 (|:| |unitPart| |#4|) (|:| |suPart| (-634 (-2 (|:| -3848 (-1157 |#4|)) (|:| -3438 (-568)))))) (-1157 |#4|) (-634 |#2|) (-634 (-634 |#3|)))) (-15 -3280 ((-2 (|:| |upol| (-1157 |#3|)) (|:| |Lval| (-634 |#3|)) (|:| |Lfact| (-634 (-2 (|:| -3848 (-1157 |#3|)) (|:| -3438 (-568))))) (|:| |ctpol| |#3|)) (-1157 |#4|) (-634 |#2|) (-634 (-634 |#3|)))) (-15 -2331 (|#4| (-568) (-420 |#4|))) (-15 -1644 ((-121) (-634 (-2 (|:| -3848 (-1157 |#3|)) (|:| -3438 (-568)))) (-634 (-2 (|:| -3848 (-1157 |#3|)) (|:| -3438 (-568)))))) (-15 -3085 ((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-1157 |#3|) (-1157 |#3|) |#4| (-634 |#2|) (-634 (-763)) (-634 |#3|))) (-15 -3448 ((-634 (-763)) (-1157 |#4|) (-634 |#2|) (-763))) (-15 -3966 ((-1157 |#3|) (-1157 |#3|) (-568)))) (-788) (-842) (-301) (-950 |#3| |#1| |#2|)) (T -732)) 
-((-3966 (*1 *2 *2 *3) (-12 (-5 *2 (-1157 *6)) (-5 *3 (-568)) (-4 *6 (-301)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-732 *4 *5 *6 *7)) (-4 *7 (-950 *6 *4 *5)))) (-3448 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1157 *9)) (-5 *4 (-634 *7)) (-4 *7 (-842)) (-4 *9 (-950 *8 *6 *7)) (-4 *6 (-788)) (-4 *8 (-301)) (-5 *2 (-634 (-763))) (-5 *1 (-732 *6 *7 *8 *9)) (-5 *5 (-763)))) (-3085 (*1 *2 *3 *4 *4 *5 *6 *7 *8) (|partial| -12 (-5 *4 (-1157 *11)) (-5 *6 (-634 *10)) (-5 *7 (-634 (-763))) (-5 *8 (-634 *11)) (-4 *10 (-842)) (-4 *11 (-301)) (-4 *9 (-788)) (-4 *5 (-950 *11 *9 *10)) (-5 *2 (-634 (-1157 *5))) (-5 *1 (-732 *9 *10 *11 *5)) (-5 *3 (-1157 *5)))) (-1644 (*1 *2 *3 *3) (-12 (-5 *3 (-634 (-2 (|:| -3848 (-1157 *6)) (|:| -3438 (-568))))) (-4 *6 (-301)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-732 *4 *5 *6 *7)) (-4 *7 (-950 *6 *4 *5)))) (-2331 (*1 *2 *3 *4) (-12 (-5 *3 (-568)) (-5 *4 (-420 *2)) (-4 *2 (-950 *7 *5 *6)) (-5 *1 (-732 *5 *6 *7 *2)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-301)))) (-3280 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1157 *9)) (-5 *4 (-634 *7)) (-5 *5 (-634 (-634 *8))) (-4 *7 (-842)) (-4 *8 (-301)) (-4 *9 (-950 *8 *6 *7)) (-4 *6 (-788)) (-5 *2 (-2 (|:| |upol| (-1157 *8)) (|:| |Lval| (-634 *8)) (|:| |Lfact| (-634 (-2 (|:| -3848 (-1157 *8)) (|:| -3438 (-568))))) (|:| |ctpol| *8))) (-5 *1 (-732 *6 *7 *8 *9)))) (-2837 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 *7)) (-5 *5 (-634 (-634 *8))) (-4 *7 (-842)) (-4 *8 (-301)) (-4 *6 (-788)) (-4 *9 (-950 *8 *6 *7)) (-5 *2 (-2 (|:| |unitPart| *9) (|:| |suPart| (-634 (-2 (|:| -3848 (-1157 *9)) (|:| -3438 (-568))))))) (-5 *1 (-732 *6 *7 *8 *9)) (-5 *3 (-1157 *9)))) (-1724 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-568)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-301)) (-4 *9 (-950 *8 *6 *7)) (-5 *2 (-2 (|:| -2700 (-1157 *9)) (|:| |polval| (-1157 *8)))) (-5 *1 (-732 *6 *7 *8 *9)) (-5 *3 (-1157 *9)) (-5 *4 (-1157 *8)))) (-1589 (*1 *2 *3 *4) (-12 (-4 *5 (-788)) (-4 *4 (-842)) (-4 *6 (-301)) (-5 *2 (-420 *3)) (-5 *1 (-732 *5 *4 *6 *3)) (-4 *3 (-950 *6 *5 *4)))) (-1843 (*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3848 (-1157 *6)) (|:| -3438 (-568))))) (-4 *6 (-301)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-568)) (-5 *1 (-732 *4 *5 *6 *7)) (-4 *7 (-950 *6 *4 *5)))) (-2389 (*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)) (-5 *2 (-420 *3)) (-5 *1 (-732 *4 *5 *6 *3)) (-4 *3 (-950 *6 *4 *5)))) (-1678 (*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-732 *4 *5 *6 *7)) (-5 *3 (-1157 *7)))) (-1678 (*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)) (-5 *2 (-420 *3)) (-5 *1 (-732 *4 *5 *6 *3)) (-4 *3 (-950 *6 *4 *5))))) 
-(-10 -7 (-15 -1678 ((-420 |#4|) |#4|)) (-15 -1678 ((-420 (-1157 |#4|)) (-1157 |#4|))) (-15 -2389 ((-420 |#4|) |#4|)) (-15 -1843 ((-568) (-634 (-2 (|:| -3848 (-1157 |#3|)) (|:| -3438 (-568)))))) (-15 -1589 ((-420 |#4|) |#4| |#2|)) (-15 -1724 ((-2 (|:| -2700 (-1157 |#4|)) (|:| |polval| (-1157 |#3|))) (-1157 |#4|) (-1157 |#3|) (-568))) (-15 -2837 ((-2 (|:| |unitPart| |#4|) (|:| |suPart| (-634 (-2 (|:| -3848 (-1157 |#4|)) (|:| -3438 (-568)))))) (-1157 |#4|) (-634 |#2|) (-634 (-634 |#3|)))) (-15 -3280 ((-2 (|:| |upol| (-1157 |#3|)) (|:| |Lval| (-634 |#3|)) (|:| |Lfact| (-634 (-2 (|:| -3848 (-1157 |#3|)) (|:| -3438 (-568))))) (|:| |ctpol| |#3|)) (-1157 |#4|) (-634 |#2|) (-634 (-634 |#3|)))) (-15 -2331 (|#4| (-568) (-420 |#4|))) (-15 -1644 ((-121) (-634 (-2 (|:| -3848 (-1157 |#3|)) (|:| -3438 (-568)))) (-634 (-2 (|:| -3848 (-1157 |#3|)) (|:| -3438 (-568)))))) (-15 -3085 ((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-1157 |#3|) (-1157 |#3|) |#4| (-634 |#2|) (-634 (-763)) (-634 |#3|))) (-15 -3448 ((-634 (-763)) (-1157 |#4|) (-634 |#2|) (-763))) (-15 -3966 ((-1157 |#3|) (-1157 |#3|) (-568)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2055 (((-634 (-1161)) $) NIL)) (-3839 (((-409 (-1157 $)) $ (-607 $)) NIL (|has| |#2| (-558)))) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-3001 (((-634 (-607 $)) $) NIL)) (-4452 (($ $ (-1082 $)) NIL) (($ $ (-1161)) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2366 (($ $ (-288 $)) NIL) (($ $ (-634 (-288 $))) NIL) (($ $ (-634 (-607 $)) (-634 $)) NIL)) (-4305 (($ $) NIL (|has| |#2| (-558)))) (-1678 (((-420 $) $) NIL (|has| |#2| (-558)))) (-1497 (((-121) $ $) NIL (|has| |#2| (-558)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-607 $) "failed") $) NIL) (((-3 (-1161) "failed") $) NIL) (((-3 |#2| "failed") $) NIL) (((-3 (-409 (-953 |#2|)) "failed") $) NIL (|has| |#2| (-558))) (((-3 (-953 |#2|) "failed") $) NIL (|has| |#2| (-1047))) (((-3 (-734 |#1| |#2|) "failed") $) NIL) (((-3 (-568) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (-2198 (-12 (|has| |#2| (-558)) (|has| |#2| (-1037 (-568)))) (|has| |#2| (-1037 (-409 (-568))))))) (-2854 (((-607 $) $) NIL) (((-1161) $) NIL) ((|#2| $) NIL) (((-409 (-953 |#2|)) $) 20 (|has| |#2| (-558))) (((-953 |#2|) $) 26 (|has| |#2| (-1047))) (((-734 |#1| |#2|) $) 27) (((-568) $) NIL) (((-409 (-734 |#1| |#2|)) $) 25) (((-409 (-568)) $) NIL (-2198 (-12 (|has| |#2| (-558)) (|has| |#2| (-1037 (-568)))) (|has| |#2| (-1037 (-409 (-568))))))) (-2401 (($ $ $) NIL (|has| |#2| (-558)))) (-3164 (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL (|has| |#2| (-1047))) (((-679 |#2|) (-679 $)) NIL (|has| |#2| (-1047))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (-12 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047)))) (((-679 (-568)) (-679 $)) NIL (-12 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047))))) (-2925 (((-3 $ "failed") $) NIL)) (-2412 (($ $ $) NIL (|has| |#2| (-558)))) (-3272 (($ $ (-1082 $)) NIL) (($ $ (-1161)) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| |#2| (-558)))) (-3927 (((-121) $) NIL (|has| |#2| (-558)))) (-2413 (($ $ $) NIL)) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| |#2| (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| |#2| (-881 (-381))))) (-4499 (($ $) NIL) (($ (-634 $)) NIL)) (-3296 (((-634 (-123)) $) NIL)) (-3488 (((-123) (-123)) NIL)) (-2735 (((-121) $) NIL)) (-1825 (((-121) $) NIL (|has| $ (-1037 (-568))))) (-1332 (($ $) NIL)) (-2317 (((-1113 |#2| (-607 $)) $) NIL (|has| |#2| (-1047)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#2| (-558)))) (-3007 (((-1157 $) (-607 $)) NIL (|has| $ (-1047)))) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-2795 (($ (-1 $ $) (-607 $)) NIL)) (-3693 (((-3 (-607 $) "failed") $) NIL)) (-2495 (($ (-634 $)) NIL (|has| |#2| (-558))) (($ $ $) NIL (|has| |#2| (-558)))) (-4487 (((-1143) $) NIL)) (-3804 (((-634 (-607 $)) $) NIL)) (-3443 (($ (-123) $) NIL) (($ (-123) (-634 $)) NIL)) (-3324 (((-3 (-634 $) "failed") $) NIL (|has| |#2| (-1102)))) (-2672 (((-3 (-2 (|:| |val| $) (|:| -3438 (-568))) "failed") $) NIL (|has| |#2| (-1047)))) (-1794 (((-3 (-634 $) "failed") $) NIL (|has| |#2| (-25)))) (-2392 (((-3 (-2 (|:| -2348 (-568)) (|:| |var| (-607 $))) "failed") $) NIL (|has| |#2| (-25)))) (-3751 (((-3 (-2 (|:| |var| (-607 $)) (|:| -3438 (-568))) "failed") $) NIL (|has| |#2| (-1102))) (((-3 (-2 (|:| |var| (-607 $)) (|:| -3438 (-568))) "failed") $ (-123)) NIL (|has| |#2| (-1047))) (((-3 (-2 (|:| |var| (-607 $)) (|:| -3438 (-568))) "failed") $ (-1161)) NIL (|has| |#2| (-1047)))) (-2841 (((-121) $ (-123)) NIL) (((-121) $ (-1161)) NIL)) (-2081 (($ $) NIL (-2198 (|has| |#2| (-478)) (|has| |#2| (-558))))) (-2961 (((-763) $) NIL)) (-4022 (((-1108) $) NIL)) (-2086 (((-121) $) NIL)) (-2091 ((|#2| $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#2| (-558)))) (-2721 (($ (-634 $)) NIL (|has| |#2| (-558))) (($ $ $) NIL (|has| |#2| (-558)))) (-4059 (((-121) $ $) NIL) (((-121) $ (-1161)) NIL)) (-2784 (($ $ (-1161)) NIL) (($ $) NIL)) (-2427 (($ $) NIL)) (-3848 (((-420 $) $) NIL (|has| |#2| (-558)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#2| (-558))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#2| (-558)))) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#2| (-558)))) (-3277 (((-121) $) NIL (|has| $ (-1037 (-568))))) (-1339 (($ $ (-607 $) $) NIL) (($ $ (-634 (-607 $)) (-634 $)) NIL) (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ $))) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-1161) (-1 $ (-634 $))) NIL) (($ $ (-1161) (-1 $ $)) NIL) (($ $ (-634 (-123)) (-634 (-1 $ $))) NIL) (($ $ (-634 (-123)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-123) (-1 $ (-634 $))) NIL) (($ $ (-123) (-1 $ $)) NIL) (($ $ (-1161)) NIL (|has| |#2| (-609 (-541)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-609 (-541)))) (($ $) NIL (|has| |#2| (-609 (-541)))) (($ $ (-123) $ (-1161)) NIL (|has| |#2| (-609 (-541)))) (($ $ (-634 (-123)) (-634 $) (-1161)) NIL (|has| |#2| (-609 (-541)))) (($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ $))) NIL (|has| |#2| (-1047))) (($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ (-634 $)))) NIL (|has| |#2| (-1047))) (($ $ (-1161) (-763) (-1 $ (-634 $))) NIL (|has| |#2| (-1047))) (($ $ (-1161) (-763) (-1 $ $)) NIL (|has| |#2| (-1047)))) (-2709 (((-763) $) NIL (|has| |#2| (-558)))) (-2779 (($ (-123) $) NIL) (($ (-123) $ $) NIL) (($ (-123) $ $ $) NIL) (($ (-123) $ $ $ $) NIL) (($ (-123) (-634 $)) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#2| (-558)))) (-3502 (($ $) NIL) (($ $ $) NIL)) (-4189 (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) NIL)) (-3013 (($ $) NIL)) (-2324 (((-1113 |#2| (-607 $)) $) NIL (|has| |#2| (-558)))) (-1626 (($ $) NIL (|has| $ (-1047)))) (-4278 (((-887 (-568)) $) NIL (|has| |#2| (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| |#2| (-609 (-887 (-381))))) (($ (-420 $)) NIL (|has| |#2| (-558))) (((-541) $) NIL (|has| |#2| (-609 (-541))))) (-1458 (($ $ $) NIL (|has| |#2| (-478)))) (-2353 (($ $ $) NIL (|has| |#2| (-478)))) (-2745 (((-850) $) NIL) (($ (-607 $)) NIL) (($ (-1161)) NIL) (($ |#2|) NIL) (($ (-1113 |#2| (-607 $))) NIL (|has| |#2| (-1047))) (($ (-409 |#2|)) NIL (|has| |#2| (-558))) (($ (-953 (-409 |#2|))) NIL (|has| |#2| (-558))) (($ (-409 (-953 (-409 |#2|)))) NIL (|has| |#2| (-558))) (($ (-409 (-953 |#2|))) NIL (|has| |#2| (-558))) (($ (-953 |#2|)) NIL (|has| |#2| (-1047))) (($ $) NIL) (($ (-568)) NIL) (($ (-734 |#1| |#2|)) NIL) (($ (-409 (-734 |#1| |#2|))) 35) (($ (-409 (-568))) NIL (-2198 (|has| |#2| (-558)) (|has| |#2| (-1037 (-409 (-568))))))) (-4371 (((-3 $ "failed") $) NIL (|has| |#2| (-148)))) (-4078 (((-763)) NIL)) (-2092 (($ $) NIL) (($ (-634 $)) NIL)) (-2787 (($ $ $) NIL)) (-2887 (((-121) (-123)) NIL)) (-1826 (((-121) $ $) NIL)) (-3058 (($ (-1161) $) NIL) (($ (-1161) $ $) NIL) (($ (-1161) $ $ $) NIL) (($ (-1161) $ $ $ $) NIL) (($ (-1161) (-634 $)) NIL)) (-1887 (($ $ (-763)) NIL) (($ $ (-917)) NIL) (($ $ (-568)) NIL (-2198 (|has| |#2| (-478)) (|has| |#2| (-558))))) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) NIL)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) NIL)) (-1779 (($ (-1113 |#2| (-607 $)) (-1113 |#2| (-607 $))) NIL (|has| |#2| (-558))) (($ $ $) NIL)) (-1773 (($ $ $) NIL) (($ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-763)) NIL) (($ $ (-917)) NIL) (($ $ $) NIL) (($ $ (-568)) NIL (-2198 (|has| |#2| (-478)) (|has| |#2| (-558))))) (* (($ (-409 (-568)) $) NIL (|has| |#2| (-558))) (($ $ (-409 (-568))) NIL (|has| |#2| (-558))) (($ |#2| $) NIL (|has| |#2| (-172))) (($ $ |#2|) NIL (|has| |#2| (-172))) (($ $ $) NIL) (($ (-568) $) NIL) (($ (-763) $) NIL) (($ (-917) $) NIL))) 
-(((-733 |#1| |#2|) (-13 (-432 |#2|) (-558) (-1037 (-734 |#1| |#2|)) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $)) (-15 -2745 ($ (-409 (-734 |#1| |#2|)))) (-15 -2854 ((-409 (-734 |#1| |#2|)) $)))) (-1161) (-13 (-1047) (-842) (-558))) (T -733)) 
-((-2086 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-733 *3 *4)) (-14 *3 (-1161)) (-4 *4 (-13 (-1047) (-842) (-558))))) (* (*1 *1 *1 *1) (-12 (-5 *1 (-733 *2 *3)) (-14 *2 (-1161)) (-4 *3 (-13 (-1047) (-842) (-558))))) (-1779 (*1 *1 *1 *1) (-12 (-5 *1 (-733 *2 *3)) (-14 *2 (-1161)) (-4 *3 (-13 (-1047) (-842) (-558))))) (** (*1 *1 *1 *1) (-12 (-5 *1 (-733 *2 *3)) (-14 *2 (-1161)) (-4 *3 (-13 (-1047) (-842) (-558))))) (-1332 (*1 *1 *1) (-12 (-5 *1 (-733 *2 *3)) (-14 *2 (-1161)) (-4 *3 (-13 (-1047) (-842) (-558))))) (-3013 (*1 *1 *1) (-12 (-5 *1 (-733 *2 *3)) (-14 *2 (-1161)) (-4 *3 (-13 (-1047) (-842) (-558))))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-409 (-734 *3 *4))) (-14 *3 (-1161)) (-4 *4 (-13 (-1047) (-842) (-558))) (-5 *1 (-733 *3 *4)))) (-2854 (*1 *2 *1) (-12 (-5 *2 (-409 (-734 *3 *4))) (-5 *1 (-733 *3 *4)) (-14 *3 (-1161)) (-4 *4 (-13 (-1047) (-842) (-558)))))) 
-(-13 (-432 |#2|) (-558) (-1037 (-734 |#1| |#2|)) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $)) (-15 -2745 ($ (-409 (-734 |#1| |#2|)))) (-15 -2854 ((-409 (-734 |#1| |#2|)) $)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2572 (((-1244 |#2|) $ (-763)) NIL)) (-2055 (((-634 (-1075)) $) NIL)) (-3197 (($ (-1157 |#2|)) NIL)) (-3839 (((-1157 $) $ (-1075)) NIL) (((-1157 |#2|) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#2| (-558)))) (-2227 (($ $) NIL (|has| |#2| (-558)))) (-1573 (((-121) $) NIL (|has| |#2| (-558)))) (-2773 (((-763) $) NIL) (((-763) $ (-634 (-1075))) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-3809 (($ $ $) NIL (|has| |#2| (-558)))) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-4305 (($ $) NIL (|has| |#2| (-453)))) (-1678 (((-420 $) $) NIL (|has| |#2| (-453)))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-1497 (((-121) $ $) NIL (|has| |#2| (-365)))) (-3151 (($ $ (-763)) NIL)) (-3772 (($ $ (-763)) NIL)) (-1619 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#2| (-453)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#2| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#2| (-1037 (-568)))) (((-3 (-1075) "failed") $) NIL) (((-3 (-1161) "failed") $) NIL)) (-2854 ((|#2| $) NIL) (((-409 (-568)) $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#2| (-1037 (-568)))) (((-1075) $) 22) (((-1161) $) 23)) (-4265 (($ $ $ (-1075)) NIL (|has| |#2| (-172))) ((|#2| $ $) NIL (|has| |#2| (-172)))) (-2401 (($ $ $) NIL (|has| |#2| (-365)))) (-2114 (($ $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL) (((-679 |#2|) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-2412 (($ $ $) NIL (|has| |#2| (-365)))) (-3002 (($ $ $) NIL)) (-3581 (($ $ $) NIL (|has| |#2| (-558)))) (-4144 (((-2 (|:| -2348 |#2|) (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#2| (-558)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| |#2| (-365)))) (-3250 (($ $) NIL (|has| |#2| (-453))) (($ $ (-1075)) NIL (|has| |#2| (-453)))) (-2108 (((-634 $) $) NIL)) (-3927 (((-121) $) NIL (|has| |#2| (-904)))) (-3088 (($ $ |#2| (-763) $) NIL)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-1075) (-881 (-381))) (|has| |#2| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-1075) (-881 (-568))) (|has| |#2| (-881 (-568)))))) (-4477 (((-763) $ $) NIL (|has| |#2| (-558)))) (-2735 (((-121) $) NIL)) (-4178 (((-763) $) NIL)) (-3038 (((-3 $ "failed") $) NIL (|has| |#2| (-1136)))) (-2051 (($ (-1157 |#2|) (-1075)) NIL) (($ (-1157 $) (-1075)) NIL)) (-3536 (($ $ (-763)) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#2| (-365)))) (-2976 (((-634 $) $) NIL)) (-3921 (((-121) $) NIL)) (-2047 (($ |#2| (-763)) 17) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-3379 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $ (-1075)) NIL) (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-2144 (((-763) $) NIL) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-2521 (($ $ $) NIL (|has| |#2| (-842)))) (-3268 (($ $ $) NIL (|has| |#2| (-842)))) (-3842 (($ (-1 (-763) (-763)) $) NIL)) (-2795 (($ (-1 |#2| |#2|) $) NIL)) (-3764 (((-1157 |#2|) $) NIL)) (-2244 (((-3 (-1075) "failed") $) NIL)) (-2097 (($ $) NIL)) (-2102 ((|#2| $) NIL)) (-2495 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) NIL (|has| |#2| (-453)))) (-4487 (((-1143) $) NIL)) (-1643 (((-2 (|:| -3961 $) (|:| -1500 $)) $ (-763)) NIL)) (-3324 (((-3 (-634 $) "failed") $) NIL)) (-1794 (((-3 (-634 $) "failed") $) NIL)) (-3751 (((-3 (-2 (|:| |var| (-1075)) (|:| -3438 (-763))) "failed") $) NIL)) (-3837 (($ $) NIL (|has| |#2| (-43 (-409 (-568)))))) (-4434 (($) NIL (|has| |#2| (-1136)) CONST)) (-4022 (((-1108) $) NIL)) (-2086 (((-121) $) NIL)) (-2091 ((|#2| $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#2| (-453)))) (-2721 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) NIL (|has| |#2| (-453)))) (-4285 (($ $ (-763) |#2| $) NIL)) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3848 (((-420 $) $) NIL (|has| |#2| (-904)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#2| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#2| (-365)))) (-2595 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-558)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#2| (-365)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-1075) |#2|) NIL) (($ $ (-634 (-1075)) (-634 |#2|)) NIL) (($ $ (-1075) $) NIL) (($ $ (-634 (-1075)) (-634 $)) NIL)) (-2709 (((-763) $) NIL (|has| |#2| (-365)))) (-2779 ((|#2| $ |#2|) NIL) (($ $ $) NIL) (((-409 $) (-409 $) (-409 $)) NIL (|has| |#2| (-558))) ((|#2| (-409 $) |#2|) NIL (|has| |#2| (-365))) (((-409 $) $ (-409 $)) NIL (|has| |#2| (-558)))) (-2167 (((-3 $ "failed") $ (-763)) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#2| (-365)))) (-2217 (($ $ (-1075)) NIL (|has| |#2| (-172))) ((|#2| $) NIL (|has| |#2| (-172)))) (-4189 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) $) NIL)) (-3206 (((-763) $) NIL) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-4278 (((-887 (-381)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-381)))) (|has| |#2| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-568)))) (|has| |#2| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-1075) (-609 (-541))) (|has| |#2| (-609 (-541)))))) (-3367 ((|#2| $) NIL (|has| |#2| (-453))) (($ $ (-1075)) NIL (|has| |#2| (-453)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#2| (-904))))) (-3950 (((-3 $ "failed") $ $) NIL (|has| |#2| (-558))) (((-3 (-409 $) "failed") (-409 $) $) NIL (|has| |#2| (-558)))) (-2745 (((-850) $) 13) (($ (-568)) NIL) (($ |#2|) 26) (($ (-1075)) NIL) (($ (-1240 |#1|)) 20) (($ (-953 |#2|)) 34) (($ (-1161)) 18) (($ (-409 (-568))) NIL (-2198 (|has| |#2| (-43 (-409 (-568)))) (|has| |#2| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#2| (-558)))) (-1302 (((-634 |#2|) $) NIL)) (-2604 ((|#2| $ (-763)) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| |#2| (-904))) (|has| |#2| (-148))))) (-4078 (((-763)) NIL)) (-4171 (($ $ $ (-763)) NIL (|has| |#2| (-172)))) (-1826 (((-121) $ $) NIL (|has| |#2| (-558)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) 14 T CONST)) (-3190 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) NIL)) (-1751 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1779 (($ $ |#2|) NIL (|has| |#2| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#2| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#2| (-43 (-409 (-568))))) (($ |#2| $) NIL) (($ $ |#2|) NIL))) 
-(((-734 |#1| |#2|) (-13 (-1219 |#2|) (-10 -8 (-6 (-1037 (-1161))) (-15 -2745 ($ (-1240 |#1|))) (-15 -4285 ($ $ (-763) |#2| $)) (IF (|has| |#2| (-15 -3839 ((-1157 |#2|) |#2| (-1161)))) (-15 -2745 ($ |#2|)) |noBranch|) (-15 -2745 ($ (-953 |#2|))))) (-1161) (-1047)) (T -734)) 
-((-2745 (*1 *1 *2) (-12 (-5 *1 (-734 *3 *2)) (-14 *3 (-1161)) (-4 *2 (-1047)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-1240 *3)) (-14 *3 (-1161)) (-5 *1 (-734 *3 *4)) (-4 *4 (-1047)))) (-4285 (*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-763)) (-5 *1 (-734 *4 *3)) (-14 *4 (-1161)) (-4 *3 (-1047)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-953 *4)) (-4 *4 (-1047)) (-5 *1 (-734 *3 *4)) (-14 *3 (-1161))))) 
-(-13 (-1219 |#2|) (-10 -8 (-6 (-1037 (-1161))) (-15 -2745 ($ (-1240 |#1|))) (-15 -4285 ($ $ (-763) |#2| $)) (IF (|has| |#2| (-15 -3839 ((-1157 |#2|) |#2| (-1161)))) (-15 -2745 ($ |#2|)) |noBranch|) (-15 -2745 ($ (-953 |#2|))))) 
-((-4373 (($ $ (-917)) 12))) 
-(((-735 |#1| |#2|) (-10 -8 (-15 -4373 (|#1| |#1| (-917)))) (-736 |#2|) (-172)) (T -735)) 
-NIL 
-(-10 -8 (-15 -4373 (|#1| |#1| (-917)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-3551 (($ $ (-917)) 27)) (-4373 (($ $ (-917)) 32)) (-4222 (($ $ (-917)) 28)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2353 (($ $ $) 24)) (-2745 (((-850) $) 11)) (-3882 (($ $ $ $) 25)) (-3500 (($ $ $) 23)) (-3056 (($) 17 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 29)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 26) (($ $ |#1|) 34) (($ |#1| $) 33))) 
+((-2079 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-730 *4 *2)) (-4 *4 (-1047)) (-4 *2 (-842)))) (-2079 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *5)) (-5 *3 (-634 (-763))) (-4 *1 (-730 *4 *5)) (-4 *4 (-1047)) (-4 *5 (-842)))) (-2168 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-730 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-842)))) (-2049 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-730 *4 *2)) (-4 *4 (-1047)) (-4 *2 (-842)))) (-2049 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *5)) (-5 *3 (-634 (-763))) (-4 *1 (-730 *4 *5)) (-4 *4 (-1047)) (-4 *5 (-842)))) (-1844 (*1 *2 *1 *3) (-12 (-4 *1 (-730 *4 *3)) (-4 *4 (-1047)) (-4 *3 (-842)) (-5 *2 (-763)))) (-1844 (*1 *2 *1 *3 *2) (-12 (-5 *2 (-763)) (-4 *1 (-730 *4 *3)) (-4 *4 (-1047)) (-4 *3 (-842)))) (-3808 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-730 *4 *5)) (-4 *4 (-1047)) (-4 *5 (-842)) (-5 *2 (-953 *4)))) (-3808 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-4 *1 (-730 *4 *5)) (-4 *4 (-1047)) (-4 *5 (-842)) (-5 *2 (-953 *4)))) (-1845 (*1 *1 *1 *2) (-12 (-4 *1 (-730 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-842)) (-4 *3 (-43 (-409 (-568))))))) 
+(-13 (-895 |t#2|) (-974 |t#1| (-534 |t#2|) |t#2|) (-523 |t#2| $) (-303 $) (-10 -8 (-15 -2079 ($ $ |t#2| (-763))) (-15 -2079 ($ $ (-634 |t#2|) (-634 (-763)))) (-15 -2168 ($ $ (-763))) (-15 -2049 ($ $ |t#2| (-763))) (-15 -2049 ($ $ (-634 |t#2|) (-634 (-763)))) (-15 -1844 ((-763) $ |t#2|)) (-15 -1844 ((-763) $ |t#2| (-763))) (-15 -3808 ((-953 |t#1|) $ (-763))) (-15 -3808 ((-953 |t#1|) $ (-763) (-763))) (IF (|has| |t#1| (-43 (-409 (-568)))) (PROGN (-15 -1845 ($ $ |t#2|)) (-6 (-1002)) (-6 (-1181))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| (-534 |#2|)) . T) ((-25) . T) ((-43 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) |has| |#1| (-558)) ((-40) |has| |#1| (-43 (-409 (-568)))) ((-98) |has| |#1| (-43 (-409 (-568)))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2199 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2199 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-279) |has| |#1| (-43 (-409 (-568)))) ((-285) |has| |#1| (-558)) ((-303 $) . T) ((-502) |has| |#1| (-43 (-409 (-568)))) ((-523 |#2| $) . T) ((-523 $ $) . T) ((-558) |has| |#1| (-558)) ((-637 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) |has| |#1| (-558)) ((-716) . T) ((-895 |#2|) . T) ((-974 |#1| (-534 |#2|) |#2|) . T) ((-1002) |has| |#1| (-43 (-409 (-568)))) ((-1053 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-1053 |#1|) . T) ((-1053 $) -2199 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1181) |has| |#1| (-43 (-409 (-568)))) ((-1184) |has| |#1| (-43 (-409 (-568))))) 
+((-3850 (((-420 (-1157 |#4|)) (-1157 |#4|)) 28) (((-420 |#4|) |#4|) 24))) 
+(((-731 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3850 ((-420 |#4|) |#4|)) (-15 -3850 ((-420 (-1157 |#4|)) (-1157 |#4|)))) (-842) (-788) (-13 (-301) (-150)) (-950 |#3| |#2| |#1|)) (T -731)) 
+((-3850 (*1 *2 *3) (-12 (-4 *4 (-842)) (-4 *5 (-788)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-950 *6 *5 *4)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-731 *4 *5 *6 *7)) (-5 *3 (-1157 *7)))) (-3850 (*1 *2 *3) (-12 (-4 *4 (-842)) (-4 *5 (-788)) (-4 *6 (-13 (-301) (-150))) (-5 *2 (-420 *3)) (-5 *1 (-731 *4 *5 *6 *3)) (-4 *3 (-950 *6 *5 *4))))) 
+(-10 -7 (-15 -3850 ((-420 |#4|) |#4|)) (-15 -3850 ((-420 (-1157 |#4|)) (-1157 |#4|)))) 
+((-4498 (((-420 |#4|) |#4| |#2|) 116)) (-2224 (((-420 |#4|) |#4|) NIL)) (-3498 (((-420 (-1157 |#4|)) (-1157 |#4|)) 107) (((-420 |#4|) |#4|) 38)) (-3891 (((-2 (|:| |unitPart| |#4|) (|:| |suPart| (-634 (-2 (|:| -3850 (-1157 |#4|)) (|:| -3483 (-568)))))) (-1157 |#4|) (-634 |#2|) (-634 (-634 |#3|))) 65)) (-4430 (((-1157 |#3|) (-1157 |#3|) (-568)) 133)) (-3550 (((-634 (-763)) (-1157 |#4|) (-634 |#2|) (-763)) 58)) (-3087 (((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-1157 |#3|) (-1157 |#3|) |#4| (-634 |#2|) (-634 (-763)) (-634 |#3|)) 62)) (-2097 (((-2 (|:| |upol| (-1157 |#3|)) (|:| |Lval| (-634 |#3|)) (|:| |Lfact| (-634 (-2 (|:| -3850 (-1157 |#3|)) (|:| -3483 (-568))))) (|:| |ctpol| |#3|)) (-1157 |#4|) (-634 |#2|) (-634 (-634 |#3|))) 22)) (-3726 (((-2 (|:| -1416 (-1157 |#4|)) (|:| |polval| (-1157 |#3|))) (-1157 |#4|) (-1157 |#3|) (-568)) 54)) (-2368 (((-568) (-634 (-2 (|:| -3850 (-1157 |#3|)) (|:| -3483 (-568))))) 130)) (-3843 ((|#4| (-568) (-420 |#4|)) 55)) (-3270 (((-121) (-634 (-2 (|:| -3850 (-1157 |#3|)) (|:| -3483 (-568)))) (-634 (-2 (|:| -3850 (-1157 |#3|)) (|:| -3483 (-568))))) NIL))) 
+(((-732 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3498 ((-420 |#4|) |#4|)) (-15 -3498 ((-420 (-1157 |#4|)) (-1157 |#4|))) (-15 -2224 ((-420 |#4|) |#4|)) (-15 -2368 ((-568) (-634 (-2 (|:| -3850 (-1157 |#3|)) (|:| -3483 (-568)))))) (-15 -4498 ((-420 |#4|) |#4| |#2|)) (-15 -3726 ((-2 (|:| -1416 (-1157 |#4|)) (|:| |polval| (-1157 |#3|))) (-1157 |#4|) (-1157 |#3|) (-568))) (-15 -3891 ((-2 (|:| |unitPart| |#4|) (|:| |suPart| (-634 (-2 (|:| -3850 (-1157 |#4|)) (|:| -3483 (-568)))))) (-1157 |#4|) (-634 |#2|) (-634 (-634 |#3|)))) (-15 -2097 ((-2 (|:| |upol| (-1157 |#3|)) (|:| |Lval| (-634 |#3|)) (|:| |Lfact| (-634 (-2 (|:| -3850 (-1157 |#3|)) (|:| -3483 (-568))))) (|:| |ctpol| |#3|)) (-1157 |#4|) (-634 |#2|) (-634 (-634 |#3|)))) (-15 -3843 (|#4| (-568) (-420 |#4|))) (-15 -3270 ((-121) (-634 (-2 (|:| -3850 (-1157 |#3|)) (|:| -3483 (-568)))) (-634 (-2 (|:| -3850 (-1157 |#3|)) (|:| -3483 (-568)))))) (-15 -3087 ((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-1157 |#3|) (-1157 |#3|) |#4| (-634 |#2|) (-634 (-763)) (-634 |#3|))) (-15 -3550 ((-634 (-763)) (-1157 |#4|) (-634 |#2|) (-763))) (-15 -4430 ((-1157 |#3|) (-1157 |#3|) (-568)))) (-788) (-842) (-301) (-950 |#3| |#1| |#2|)) (T -732)) 
+((-4430 (*1 *2 *2 *3) (-12 (-5 *2 (-1157 *6)) (-5 *3 (-568)) (-4 *6 (-301)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-732 *4 *5 *6 *7)) (-4 *7 (-950 *6 *4 *5)))) (-3550 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1157 *9)) (-5 *4 (-634 *7)) (-4 *7 (-842)) (-4 *9 (-950 *8 *6 *7)) (-4 *6 (-788)) (-4 *8 (-301)) (-5 *2 (-634 (-763))) (-5 *1 (-732 *6 *7 *8 *9)) (-5 *5 (-763)))) (-3087 (*1 *2 *3 *4 *4 *5 *6 *7 *8) (|partial| -12 (-5 *4 (-1157 *11)) (-5 *6 (-634 *10)) (-5 *7 (-634 (-763))) (-5 *8 (-634 *11)) (-4 *10 (-842)) (-4 *11 (-301)) (-4 *9 (-788)) (-4 *5 (-950 *11 *9 *10)) (-5 *2 (-634 (-1157 *5))) (-5 *1 (-732 *9 *10 *11 *5)) (-5 *3 (-1157 *5)))) (-3270 (*1 *2 *3 *3) (-12 (-5 *3 (-634 (-2 (|:| -3850 (-1157 *6)) (|:| -3483 (-568))))) (-4 *6 (-301)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-732 *4 *5 *6 *7)) (-4 *7 (-950 *6 *4 *5)))) (-3843 (*1 *2 *3 *4) (-12 (-5 *3 (-568)) (-5 *4 (-420 *2)) (-4 *2 (-950 *7 *5 *6)) (-5 *1 (-732 *5 *6 *7 *2)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-301)))) (-2097 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1157 *9)) (-5 *4 (-634 *7)) (-5 *5 (-634 (-634 *8))) (-4 *7 (-842)) (-4 *8 (-301)) (-4 *9 (-950 *8 *6 *7)) (-4 *6 (-788)) (-5 *2 (-2 (|:| |upol| (-1157 *8)) (|:| |Lval| (-634 *8)) (|:| |Lfact| (-634 (-2 (|:| -3850 (-1157 *8)) (|:| -3483 (-568))))) (|:| |ctpol| *8))) (-5 *1 (-732 *6 *7 *8 *9)))) (-3891 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 *7)) (-5 *5 (-634 (-634 *8))) (-4 *7 (-842)) (-4 *8 (-301)) (-4 *6 (-788)) (-4 *9 (-950 *8 *6 *7)) (-5 *2 (-2 (|:| |unitPart| *9) (|:| |suPart| (-634 (-2 (|:| -3850 (-1157 *9)) (|:| -3483 (-568))))))) (-5 *1 (-732 *6 *7 *8 *9)) (-5 *3 (-1157 *9)))) (-3726 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-568)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-301)) (-4 *9 (-950 *8 *6 *7)) (-5 *2 (-2 (|:| -1416 (-1157 *9)) (|:| |polval| (-1157 *8)))) (-5 *1 (-732 *6 *7 *8 *9)) (-5 *3 (-1157 *9)) (-5 *4 (-1157 *8)))) (-4498 (*1 *2 *3 *4) (-12 (-4 *5 (-788)) (-4 *4 (-842)) (-4 *6 (-301)) (-5 *2 (-420 *3)) (-5 *1 (-732 *5 *4 *6 *3)) (-4 *3 (-950 *6 *5 *4)))) (-2368 (*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3850 (-1157 *6)) (|:| -3483 (-568))))) (-4 *6 (-301)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-568)) (-5 *1 (-732 *4 *5 *6 *7)) (-4 *7 (-950 *6 *4 *5)))) (-2224 (*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)) (-5 *2 (-420 *3)) (-5 *1 (-732 *4 *5 *6 *3)) (-4 *3 (-950 *6 *4 *5)))) (-3498 (*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-732 *4 *5 *6 *7)) (-5 *3 (-1157 *7)))) (-3498 (*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)) (-5 *2 (-420 *3)) (-5 *1 (-732 *4 *5 *6 *3)) (-4 *3 (-950 *6 *4 *5))))) 
+(-10 -7 (-15 -3498 ((-420 |#4|) |#4|)) (-15 -3498 ((-420 (-1157 |#4|)) (-1157 |#4|))) (-15 -2224 ((-420 |#4|) |#4|)) (-15 -2368 ((-568) (-634 (-2 (|:| -3850 (-1157 |#3|)) (|:| -3483 (-568)))))) (-15 -4498 ((-420 |#4|) |#4| |#2|)) (-15 -3726 ((-2 (|:| -1416 (-1157 |#4|)) (|:| |polval| (-1157 |#3|))) (-1157 |#4|) (-1157 |#3|) (-568))) (-15 -3891 ((-2 (|:| |unitPart| |#4|) (|:| |suPart| (-634 (-2 (|:| -3850 (-1157 |#4|)) (|:| -3483 (-568)))))) (-1157 |#4|) (-634 |#2|) (-634 (-634 |#3|)))) (-15 -2097 ((-2 (|:| |upol| (-1157 |#3|)) (|:| |Lval| (-634 |#3|)) (|:| |Lfact| (-634 (-2 (|:| -3850 (-1157 |#3|)) (|:| -3483 (-568))))) (|:| |ctpol| |#3|)) (-1157 |#4|) (-634 |#2|) (-634 (-634 |#3|)))) (-15 -3843 (|#4| (-568) (-420 |#4|))) (-15 -3270 ((-121) (-634 (-2 (|:| -3850 (-1157 |#3|)) (|:| -3483 (-568)))) (-634 (-2 (|:| -3850 (-1157 |#3|)) (|:| -3483 (-568)))))) (-15 -3087 ((-3 (-634 (-1157 |#4|)) "failed") (-1157 |#4|) (-1157 |#3|) (-1157 |#3|) |#4| (-634 |#2|) (-634 (-763)) (-634 |#3|))) (-15 -3550 ((-634 (-763)) (-1157 |#4|) (-634 |#2|) (-763))) (-15 -4430 ((-1157 |#3|) (-1157 |#3|) (-568)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2057 (((-634 (-1161)) $) NIL)) (-3840 (((-409 (-1157 $)) $ (-607 $)) NIL (|has| |#2| (-558)))) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-3145 (((-634 (-607 $)) $) NIL)) (-1715 (($ $ (-1082 $)) NIL) (($ $ (-1161)) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4069 (($ $ (-288 $)) NIL) (($ $ (-634 (-288 $))) NIL) (($ $ (-634 (-607 $)) (-634 $)) NIL)) (-3045 (($ $) NIL (|has| |#2| (-558)))) (-3498 (((-420 $) $) NIL (|has| |#2| (-558)))) (-2589 (((-121) $ $) NIL (|has| |#2| (-558)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-607 $) "failed") $) NIL) (((-3 (-1161) "failed") $) NIL) (((-3 |#2| "failed") $) NIL) (((-3 (-409 (-953 |#2|)) "failed") $) NIL (|has| |#2| (-558))) (((-3 (-953 |#2|) "failed") $) NIL (|has| |#2| (-1047))) (((-3 (-734 |#1| |#2|) "failed") $) NIL) (((-3 (-568) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (-2199 (-12 (|has| |#2| (-558)) (|has| |#2| (-1037 (-568)))) (|has| |#2| (-1037 (-409 (-568))))))) (-2857 (((-607 $) $) NIL) (((-1161) $) NIL) ((|#2| $) NIL) (((-409 (-953 |#2|)) $) 20 (|has| |#2| (-558))) (((-953 |#2|) $) 26 (|has| |#2| (-1047))) (((-734 |#1| |#2|) $) 27) (((-568) $) NIL) (((-409 (-734 |#1| |#2|)) $) 25) (((-409 (-568)) $) NIL (-2199 (-12 (|has| |#2| (-558)) (|has| |#2| (-1037 (-568)))) (|has| |#2| (-1037 (-409 (-568))))))) (-2403 (($ $ $) NIL (|has| |#2| (-558)))) (-1668 (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL (|has| |#2| (-1047))) (((-679 |#2|) (-679 $)) NIL (|has| |#2| (-1047))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (-12 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047)))) (((-679 (-568)) (-679 $)) NIL (-12 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047))))) (-2902 (((-3 $ "failed") $) NIL)) (-2414 (($ $ $) NIL (|has| |#2| (-558)))) (-2062 (($ $ (-1082 $)) NIL) (($ $ (-1161)) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| |#2| (-558)))) (-2197 (((-121) $) NIL (|has| |#2| (-558)))) (-2341 (($ $ $) NIL)) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| |#2| (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| |#2| (-881 (-381))))) (-3855 (($ $) NIL) (($ (-634 $)) NIL)) (-2160 (((-634 (-123)) $) NIL)) (-3842 (((-123) (-123)) NIL)) (-1598 (((-121) $) NIL)) (-2268 (((-121) $) NIL (|has| $ (-1037 (-568))))) (-3539 (($ $) NIL)) (-2319 (((-1113 |#2| (-607 $)) $) NIL (|has| |#2| (-1047)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#2| (-558)))) (-3170 (((-1157 $) (-607 $)) NIL (|has| $ (-1047)))) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-2797 (($ (-1 $ $) (-607 $)) NIL)) (-2337 (((-3 (-607 $) "failed") $) NIL)) (-2498 (($ (-634 $)) NIL (|has| |#2| (-558))) (($ $ $) NIL (|has| |#2| (-558)))) (-1893 (((-1143) $) NIL)) (-3832 (((-634 (-607 $)) $) NIL)) (-3446 (($ (-123) $) NIL) (($ (-123) (-634 $)) NIL)) (-4362 (((-3 (-634 $) "failed") $) NIL (|has| |#2| (-1102)))) (-4495 (((-3 (-2 (|:| |val| $) (|:| -3483 (-568))) "failed") $) NIL (|has| |#2| (-1047)))) (-2112 (((-3 (-634 $) "failed") $) NIL (|has| |#2| (-25)))) (-2240 (((-3 (-2 (|:| -2350 (-568)) (|:| |var| (-607 $))) "failed") $) NIL (|has| |#2| (-25)))) (-2617 (((-3 (-2 (|:| |var| (-607 $)) (|:| -3483 (-568))) "failed") $) NIL (|has| |#2| (-1102))) (((-3 (-2 (|:| |var| (-607 $)) (|:| -3483 (-568))) "failed") $ (-123)) NIL (|has| |#2| (-1047))) (((-3 (-2 (|:| |var| (-607 $)) (|:| -3483 (-568))) "failed") $ (-1161)) NIL (|has| |#2| (-1047)))) (-3910 (((-121) $ (-123)) NIL) (((-121) $ (-1161)) NIL)) (-2083 (($ $) NIL (-2199 (|has| |#2| (-478)) (|has| |#2| (-558))))) (-2963 (((-763) $) NIL)) (-4025 (((-1108) $) NIL)) (-2088 (((-121) $) NIL)) (-2093 ((|#2| $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#2| (-558)))) (-2723 (($ (-634 $)) NIL (|has| |#2| (-558))) (($ $ $) NIL (|has| |#2| (-558)))) (-1609 (((-121) $ $) NIL) (((-121) $ (-1161)) NIL)) (-3577 (($ $ (-1161)) NIL) (($ $) NIL)) (-2406 (($ $) NIL)) (-3850 (((-420 $) $) NIL (|has| |#2| (-558)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#2| (-558))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#2| (-558)))) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#2| (-558)))) (-2080 (((-121) $) NIL (|has| $ (-1037 (-568))))) (-1339 (($ $ (-607 $) $) NIL) (($ $ (-634 (-607 $)) (-634 $)) NIL) (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ $))) NIL) (($ $ (-634 (-1161)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-1161) (-1 $ (-634 $))) NIL) (($ $ (-1161) (-1 $ $)) NIL) (($ $ (-634 (-123)) (-634 (-1 $ $))) NIL) (($ $ (-634 (-123)) (-634 (-1 $ (-634 $)))) NIL) (($ $ (-123) (-1 $ (-634 $))) NIL) (($ $ (-123) (-1 $ $)) NIL) (($ $ (-1161)) NIL (|has| |#2| (-609 (-541)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-609 (-541)))) (($ $) NIL (|has| |#2| (-609 (-541)))) (($ $ (-123) $ (-1161)) NIL (|has| |#2| (-609 (-541)))) (($ $ (-634 (-123)) (-634 $) (-1161)) NIL (|has| |#2| (-609 (-541)))) (($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ $))) NIL (|has| |#2| (-1047))) (($ $ (-634 (-1161)) (-634 (-763)) (-634 (-1 $ (-634 $)))) NIL (|has| |#2| (-1047))) (($ $ (-1161) (-763) (-1 $ (-634 $))) NIL (|has| |#2| (-1047))) (($ $ (-1161) (-763) (-1 $ $)) NIL (|has| |#2| (-1047)))) (-1466 (((-763) $) NIL (|has| |#2| (-558)))) (-2781 (($ (-123) $) NIL) (($ (-123) $ $) NIL) (($ (-123) $ $ $) NIL) (($ (-123) $ $ $ $) NIL) (($ (-123) (-634 $)) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#2| (-558)))) (-3924 (($ $) NIL) (($ $ $) NIL)) (-4191 (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) NIL)) (-3210 (($ $) NIL)) (-2326 (((-1113 |#2| (-607 $)) $) NIL (|has| |#2| (-558)))) (-1492 (($ $) NIL (|has| $ (-1047)))) (-4280 (((-887 (-568)) $) NIL (|has| |#2| (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| |#2| (-609 (-887 (-381))))) (($ (-420 $)) NIL (|has| |#2| (-558))) (((-541) $) NIL (|has| |#2| (-609 (-541))))) (-2387 (($ $ $) NIL (|has| |#2| (-478)))) (-3985 (($ $ $) NIL (|has| |#2| (-478)))) (-2747 (((-850) $) NIL) (($ (-607 $)) NIL) (($ (-1161)) NIL) (($ |#2|) NIL) (($ (-1113 |#2| (-607 $))) NIL (|has| |#2| (-1047))) (($ (-409 |#2|)) NIL (|has| |#2| (-558))) (($ (-953 (-409 |#2|))) NIL (|has| |#2| (-558))) (($ (-409 (-953 (-409 |#2|)))) NIL (|has| |#2| (-558))) (($ (-409 (-953 |#2|))) NIL (|has| |#2| (-558))) (($ (-953 |#2|)) NIL (|has| |#2| (-1047))) (($ $) NIL) (($ (-568)) NIL) (($ (-734 |#1| |#2|)) NIL) (($ (-409 (-734 |#1| |#2|))) 35) (($ (-409 (-568))) NIL (-2199 (|has| |#2| (-558)) (|has| |#2| (-1037 (-409 (-568))))))) (-3385 (((-3 $ "failed") $) NIL (|has| |#2| (-148)))) (-3425 (((-763)) NIL)) (-3159 (($ $) NIL) (($ (-634 $)) NIL)) (-3584 (($ $ $) NIL)) (-2779 (((-121) (-123)) NIL)) (-2273 (((-121) $ $) NIL)) (-3060 (($ (-1161) $) NIL) (($ (-1161) $ $) NIL) (($ (-1161) $ $ $) NIL) (($ (-1161) $ $ $ $) NIL) (($ (-1161) (-634 $)) NIL)) (-1889 (($ $ (-763)) NIL) (($ $ (-917)) NIL) (($ $ (-568)) NIL (-2199 (|has| |#2| (-478)) (|has| |#2| (-558))))) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) NIL)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) NIL)) (-1781 (($ (-1113 |#2| (-607 $)) (-1113 |#2| (-607 $))) NIL (|has| |#2| (-558))) (($ $ $) NIL)) (-1775 (($ $ $) NIL) (($ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-763)) NIL) (($ $ (-917)) NIL) (($ $ $) NIL) (($ $ (-568)) NIL (-2199 (|has| |#2| (-478)) (|has| |#2| (-558))))) (* (($ (-409 (-568)) $) NIL (|has| |#2| (-558))) (($ $ (-409 (-568))) NIL (|has| |#2| (-558))) (($ |#2| $) NIL (|has| |#2| (-172))) (($ $ |#2|) NIL (|has| |#2| (-172))) (($ $ $) NIL) (($ (-568) $) NIL) (($ (-763) $) NIL) (($ (-917) $) NIL))) 
+(((-733 |#1| |#2|) (-13 (-432 |#2|) (-558) (-1037 (-734 |#1| |#2|)) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $)) (-15 -2747 ($ (-409 (-734 |#1| |#2|)))) (-15 -2857 ((-409 (-734 |#1| |#2|)) $)))) (-1161) (-13 (-1047) (-842) (-558))) (T -733)) 
+((-2088 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-733 *3 *4)) (-14 *3 (-1161)) (-4 *4 (-13 (-1047) (-842) (-558))))) (* (*1 *1 *1 *1) (-12 (-5 *1 (-733 *2 *3)) (-14 *2 (-1161)) (-4 *3 (-13 (-1047) (-842) (-558))))) (-1781 (*1 *1 *1 *1) (-12 (-5 *1 (-733 *2 *3)) (-14 *2 (-1161)) (-4 *3 (-13 (-1047) (-842) (-558))))) (** (*1 *1 *1 *1) (-12 (-5 *1 (-733 *2 *3)) (-14 *2 (-1161)) (-4 *3 (-13 (-1047) (-842) (-558))))) (-3539 (*1 *1 *1) (-12 (-5 *1 (-733 *2 *3)) (-14 *2 (-1161)) (-4 *3 (-13 (-1047) (-842) (-558))))) (-3210 (*1 *1 *1) (-12 (-5 *1 (-733 *2 *3)) (-14 *2 (-1161)) (-4 *3 (-13 (-1047) (-842) (-558))))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-409 (-734 *3 *4))) (-14 *3 (-1161)) (-4 *4 (-13 (-1047) (-842) (-558))) (-5 *1 (-733 *3 *4)))) (-2857 (*1 *2 *1) (-12 (-5 *2 (-409 (-734 *3 *4))) (-5 *1 (-733 *3 *4)) (-14 *3 (-1161)) (-4 *4 (-13 (-1047) (-842) (-558)))))) 
+(-13 (-432 |#2|) (-558) (-1037 (-734 |#1| |#2|)) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $)) (-15 -2747 ($ (-409 (-734 |#1| |#2|)))) (-15 -2857 ((-409 (-734 |#1| |#2|)) $)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-1969 (((-1244 |#2|) $ (-763)) NIL)) (-2057 (((-634 (-1075)) $) NIL)) (-1807 (($ (-1157 |#2|)) NIL)) (-3840 (((-1157 $) $ (-1075)) NIL) (((-1157 |#2|) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#2| (-558)))) (-3661 (($ $) NIL (|has| |#2| (-558)))) (-4426 (((-121) $) NIL (|has| |#2| (-558)))) (-3528 (((-763) $) NIL) (((-763) $ (-634 (-1075))) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-1736 (($ $ $) NIL (|has| |#2| (-558)))) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3045 (($ $) NIL (|has| |#2| (-453)))) (-3498 (((-420 $) $) NIL (|has| |#2| (-453)))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-2589 (((-121) $ $) NIL (|has| |#2| (-365)))) (-2752 (($ $ (-763)) NIL)) (-2699 (($ $ (-763)) NIL)) (-1448 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#2| (-453)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#2| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#2| (-1037 (-568)))) (((-3 (-1075) "failed") $) NIL) (((-3 (-1161) "failed") $) NIL)) (-2857 ((|#2| $) NIL) (((-409 (-568)) $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#2| (-1037 (-568)))) (((-1075) $) 22) (((-1161) $) 23)) (-2910 (($ $ $ (-1075)) NIL (|has| |#2| (-172))) ((|#2| $ $) NIL (|has| |#2| (-172)))) (-2403 (($ $ $) NIL (|has| |#2| (-365)))) (-2116 (($ $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL) (((-679 |#2|) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-2414 (($ $ $) NIL (|has| |#2| (-365)))) (-3152 (($ $ $) NIL)) (-2929 (($ $ $) NIL (|has| |#2| (-558)))) (-3777 (((-2 (|:| -2350 |#2|) (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#2| (-558)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| |#2| (-365)))) (-1998 (($ $) NIL (|has| |#2| (-453))) (($ $ (-1075)) NIL (|has| |#2| (-453)))) (-2110 (((-634 $) $) NIL)) (-2197 (((-121) $) NIL (|has| |#2| (-904)))) (-2453 (($ $ |#2| (-763) $) NIL)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-1075) (-881 (-381))) (|has| |#2| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-1075) (-881 (-568))) (|has| |#2| (-881 (-568)))))) (-1844 (((-763) $ $) NIL (|has| |#2| (-558)))) (-1598 (((-121) $) NIL)) (-3971 (((-763) $) NIL)) (-2214 (((-3 $ "failed") $) NIL (|has| |#2| (-1136)))) (-2053 (($ (-1157 |#2|) (-1075)) NIL) (($ (-1157 $) (-1075)) NIL)) (-4168 (($ $ (-763)) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#2| (-365)))) (-3062 (((-634 $) $) NIL)) (-2171 (((-121) $) NIL)) (-2049 (($ |#2| (-763)) 17) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-1438 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $ (-1075)) NIL) (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-3524 (((-763) $) NIL) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-1732 (($ $ $) NIL (|has| |#2| (-842)))) (-2047 (($ $ $) NIL (|has| |#2| (-842)))) (-1865 (($ (-1 (-763) (-763)) $) NIL)) (-2797 (($ (-1 |#2| |#2|) $) NIL)) (-2671 (((-1157 |#2|) $) NIL)) (-2817 (((-3 (-1075) "failed") $) NIL)) (-2099 (($ $) NIL)) (-2104 ((|#2| $) NIL)) (-2498 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) NIL (|has| |#2| (-453)))) (-1893 (((-1143) $) NIL)) (-3262 (((-2 (|:| -4409 $) (|:| -2607 $)) $ (-763)) NIL)) (-4362 (((-3 (-634 $) "failed") $) NIL)) (-2112 (((-3 (-634 $) "failed") $) NIL)) (-2617 (((-3 (-2 (|:| |var| (-1075)) (|:| -3483 (-763))) "failed") $) NIL)) (-1845 (($ $) NIL (|has| |#2| (-43 (-409 (-568)))))) (-4436 (($) NIL (|has| |#2| (-1136)) CONST)) (-4025 (((-1108) $) NIL)) (-2088 (((-121) $) NIL)) (-2093 ((|#2| $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#2| (-453)))) (-2723 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) NIL (|has| |#2| (-453)))) (-2973 (($ $ (-763) |#2| $) NIL)) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3850 (((-420 $) $) NIL (|has| |#2| (-904)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#2| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#2| (-365)))) (-2597 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-558)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#2| (-365)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-1075) |#2|) NIL) (($ $ (-634 (-1075)) (-634 |#2|)) NIL) (($ $ (-1075) $) NIL) (($ $ (-634 (-1075)) (-634 $)) NIL)) (-1466 (((-763) $) NIL (|has| |#2| (-365)))) (-2781 ((|#2| $ |#2|) NIL) (($ $ $) NIL) (((-409 $) (-409 $) (-409 $)) NIL (|has| |#2| (-558))) ((|#2| (-409 $) |#2|) NIL (|has| |#2| (-365))) (((-409 $) $ (-409 $)) NIL (|has| |#2| (-558)))) (-3805 (((-3 $ "failed") $ (-763)) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#2| (-365)))) (-3440 (($ $ (-1075)) NIL (|has| |#2| (-172))) ((|#2| $) NIL (|has| |#2| (-172)))) (-4191 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) $) NIL)) (-1836 (((-763) $) NIL) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-4280 (((-887 (-381)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-381)))) (|has| |#2| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-568)))) (|has| |#2| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-1075) (-609 (-541))) (|has| |#2| (-609 (-541)))))) (-1364 ((|#2| $) NIL (|has| |#2| (-453))) (($ $ (-1075)) NIL (|has| |#2| (-453)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#2| (-904))))) (-4363 (((-3 $ "failed") $ $) NIL (|has| |#2| (-558))) (((-3 (-409 $) "failed") (-409 $) $) NIL (|has| |#2| (-558)))) (-2747 (((-850) $) 13) (($ (-568)) NIL) (($ |#2|) 26) (($ (-1075)) NIL) (($ (-1240 |#1|)) 20) (($ (-953 |#2|)) 34) (($ (-1161)) 18) (($ (-409 (-568))) NIL (-2199 (|has| |#2| (-43 (-409 (-568)))) (|has| |#2| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#2| (-558)))) (-3304 (((-634 |#2|) $) NIL)) (-2079 ((|#2| $ (-763)) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| |#2| (-904))) (|has| |#2| (-148))))) (-3425 (((-763)) NIL)) (-3925 (($ $ $ (-763)) NIL (|has| |#2| (-172)))) (-2273 (((-121) $ $) NIL (|has| |#2| (-558)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) 14 T CONST)) (-3192 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) NIL)) (-1753 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1781 (($ $ |#2|) NIL (|has| |#2| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#2| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#2| (-43 (-409 (-568))))) (($ |#2| $) NIL) (($ $ |#2|) NIL))) 
+(((-734 |#1| |#2|) (-13 (-1219 |#2|) (-10 -8 (-6 (-1037 (-1161))) (-15 -2747 ($ (-1240 |#1|))) (-15 -2973 ($ $ (-763) |#2| $)) (IF (|has| |#2| (-15 -3840 ((-1157 |#2|) |#2| (-1161)))) (-15 -2747 ($ |#2|)) |noBranch|) (-15 -2747 ($ (-953 |#2|))))) (-1161) (-1047)) (T -734)) 
+((-2747 (*1 *1 *2) (-12 (-5 *1 (-734 *3 *2)) (-14 *3 (-1161)) (-4 *2 (-1047)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-1240 *3)) (-14 *3 (-1161)) (-5 *1 (-734 *3 *4)) (-4 *4 (-1047)))) (-2973 (*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-763)) (-5 *1 (-734 *4 *3)) (-14 *4 (-1161)) (-4 *3 (-1047)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-953 *4)) (-4 *4 (-1047)) (-5 *1 (-734 *3 *4)) (-14 *3 (-1161))))) 
+(-13 (-1219 |#2|) (-10 -8 (-6 (-1037 (-1161))) (-15 -2747 ($ (-1240 |#1|))) (-15 -2973 ($ $ (-763) |#2| $)) (IF (|has| |#2| (-15 -3840 ((-1157 |#2|) |#2| (-1161)))) (-15 -2747 ($ |#2|)) |noBranch|) (-15 -2747 ($ (-953 |#2|))))) 
+((-3402 (($ $ (-917)) 12))) 
+(((-735 |#1| |#2|) (-10 -8 (-15 -3402 (|#1| |#1| (-917)))) (-736 |#2|) (-172)) (T -735)) 
+NIL 
+(-10 -8 (-15 -3402 (|#1| |#1| (-917)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-2815 (($ $ (-917)) 27)) (-3402 (($ $ (-917)) 32)) (-4202 (($ $ (-917)) 28)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-3985 (($ $ $) 24)) (-2747 (((-850) $) 11)) (-2007 (($ $ $ $) 25)) (-3911 (($ $ $) 23)) (-3058 (($) 17 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 29)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 26) (($ $ |#1|) 34) (($ |#1| $) 33))) 
 (((-736 |#1|) (-1275) (-172)) (T -736)) 
-((-4373 (*1 *1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-736 *3)) (-4 *3 (-172))))) 
-(-13 (-753) (-707 |t#1|) (-10 -8 (-15 -4373 ($ $ (-917))))) 
+((-3402 (*1 *1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-736 *3)) (-4 *3 (-172))))) 
+(-13 (-753) (-707 |t#1|) (-10 -8 (-15 -3402 ($ $ (-917))))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 |#1| |#1|) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 |#1|) . T) ((-707 |#1|) . T) ((-710) . T) ((-753) . T) ((-1053 |#1|) . T) ((-1090) . T)) 
-((-1664 (((-1035) (-679 (-215)) (-568) (-121) (-568)) 24)) (-1669 (((-1035) (-679 (-215)) (-568) (-121) (-568)) 23))) 
-(((-737) (-10 -7 (-15 -1669 ((-1035) (-679 (-215)) (-568) (-121) (-568))) (-15 -1664 ((-1035) (-679 (-215)) (-568) (-121) (-568))))) (T -737)) 
-((-1664 (*1 *2 *3 *4 *5 *4) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *5 (-121)) (-5 *2 (-1035)) (-5 *1 (-737)))) (-1669 (*1 *2 *3 *4 *5 *4) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *5 (-121)) (-5 *2 (-1035)) (-5 *1 (-737))))) 
-(-10 -7 (-15 -1669 ((-1035) (-679 (-215)) (-568) (-121) (-568))) (-15 -1664 ((-1035) (-679 (-215)) (-568) (-121) (-568)))) 
-((-1680 (((-1035) (-568) (-568) (-568) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-79 FCN)))) 43)) (-3932 (((-1035) (-568) (-568) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-86 FCN)))) 39)) (-3940 (((-1035) (-215) (-215) (-215) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) 32))) 
-(((-738) (-10 -7 (-15 -3940 ((-1035) (-215) (-215) (-215) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478))))) (-15 -3932 ((-1035) (-568) (-568) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-86 FCN))))) (-15 -1680 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-79 FCN))))))) (T -738)) 
-((-1680 (*1 *2 *3 *3 *3 *4 *5 *3 *6) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-79 FCN)))) (-5 *2 (-1035)) (-5 *1 (-738)))) (-3932 (*1 *2 *3 *3 *4 *5 *3 *6) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-86 FCN)))) (-5 *2 (-1035)) (-5 *1 (-738)))) (-3940 (*1 *2 *3 *3 *3 *3 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) (-5 *2 (-1035)) (-5 *1 (-738))))) 
-(-10 -7 (-15 -3940 ((-1035) (-215) (-215) (-215) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478))))) (-15 -3932 ((-1035) (-568) (-568) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-86 FCN))))) (-15 -1680 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-79 FCN)))))) 
-((-3948 (((-1035) (-568) (-568) (-679 (-215)) (-568)) 33)) (-3956 (((-1035) (-568) (-568) (-679 (-215)) (-568)) 32)) (-3963 (((-1035) (-568) (-679 (-215)) (-568)) 31)) (-3972 (((-1035) (-568) (-679 (-215)) (-568)) 30)) (-3980 (((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568)) 29)) (-3988 (((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568)) 28)) (-3995 (((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-568)) 27)) (-4004 (((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-568)) 26)) (-4012 (((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568)) 23)) (-4021 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568)) 22)) (-4028 (((-1035) (-568) (-679 (-215)) (-568)) 21)) (-4034 (((-1035) (-568) (-679 (-215)) (-568)) 20))) 
-(((-739) (-10 -7 (-15 -4034 ((-1035) (-568) (-679 (-215)) (-568))) (-15 -4028 ((-1035) (-568) (-679 (-215)) (-568))) (-15 -4021 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -4012 ((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -4004 ((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3995 ((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3988 ((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3980 ((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3972 ((-1035) (-568) (-679 (-215)) (-568))) (-15 -3963 ((-1035) (-568) (-679 (-215)) (-568))) (-15 -3956 ((-1035) (-568) (-568) (-679 (-215)) (-568))) (-15 -3948 ((-1035) (-568) (-568) (-679 (-215)) (-568))))) (T -739)) 
-((-3948 (*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739)))) (-3956 (*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739)))) (-3963 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739)))) (-3972 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739)))) (-3980 (*1 *2 *3 *3 *4 *5 *5 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-1143)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739)))) (-3988 (*1 *2 *3 *3 *4 *5 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-1143)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739)))) (-3995 (*1 *2 *3 *3 *4 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-1143)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739)))) (-4004 (*1 *2 *3 *3 *4 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-1143)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739)))) (-4012 (*1 *2 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739)))) (-4021 (*1 *2 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739)))) (-4028 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739)))) (-4034 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739))))) 
-(-10 -7 (-15 -4034 ((-1035) (-568) (-679 (-215)) (-568))) (-15 -4028 ((-1035) (-568) (-679 (-215)) (-568))) (-15 -4021 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -4012 ((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -4004 ((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3995 ((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3988 ((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3980 ((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3972 ((-1035) (-568) (-679 (-215)) (-568))) (-15 -3963 ((-1035) (-568) (-679 (-215)) (-568))) (-15 -3956 ((-1035) (-568) (-568) (-679 (-215)) (-568))) (-15 -3948 ((-1035) (-568) (-568) (-679 (-215)) (-568)))) 
-((-3668 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568) (-215) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-83 FUNCTN)))) 52)) (-3677 (((-1035) (-679 (-215)) (-679 (-215)) (-568) (-568)) 51)) (-3685 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-83 FUNCTN)))) 50)) (-3694 (((-1035) (-215) (-215) (-568) (-568) (-568) (-568)) 46)) (-3701 (((-1035) (-215) (-215) (-568) (-215) (-568) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G)))) 45)) (-4214 (((-1035) (-215) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G)))) 44)) (-4226 (((-1035) (-215) (-215) (-215) (-215) (-568) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G)))) 43)) (-4238 (((-1035) (-215) (-215) (-215) (-568) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G)))) 42)) (-4244 (((-1035) (-215) (-568) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) 38)) (-4250 (((-1035) (-215) (-215) (-568) (-679 (-215)) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) 37)) (-4262 (((-1035) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) 33)) (-4274 (((-1035) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) 32))) 
-(((-740) (-10 -7 (-15 -4274 ((-1035) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478))))) (-15 -4262 ((-1035) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478))))) (-15 -4250 ((-1035) (-215) (-215) (-568) (-679 (-215)) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478))))) (-15 -4244 ((-1035) (-215) (-568) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478))))) (-15 -4238 ((-1035) (-215) (-215) (-215) (-568) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G))))) (-15 -4226 ((-1035) (-215) (-215) (-215) (-215) (-568) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G))))) (-15 -4214 ((-1035) (-215) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G))))) (-15 -3701 ((-1035) (-215) (-215) (-568) (-215) (-568) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G))))) (-15 -3694 ((-1035) (-215) (-215) (-568) (-568) (-568) (-568))) (-15 -3685 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-83 FUNCTN))))) (-15 -3677 ((-1035) (-679 (-215)) (-679 (-215)) (-568) (-568))) (-15 -3668 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568) (-215) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-83 FUNCTN))))))) (T -740)) 
-((-3668 (*1 *2 *3 *4 *4 *3 *5 *3 *3 *4 *3 *6) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-83 FUNCTN)))) (-5 *2 (-1035)) (-5 *1 (-740)))) (-3677 (*1 *2 *3 *3 *4 *4) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-740)))) (-3685 (*1 *2 *3 *4 *4 *3 *5 *3 *3 *3 *6) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-83 FUNCTN)))) (-5 *2 (-1035)) (-5 *1 (-740)))) (-3694 (*1 *2 *3 *3 *4 *4 *4 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-740)))) (-3701 (*1 *2 *3 *3 *4 *3 *4 *4 *4 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G)))) (-5 *2 (-1035)) (-5 *1 (-740)))) (-4214 (*1 *2 *3 *3 *3 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G)))) (-5 *2 (-1035)) (-5 *1 (-740)))) (-4226 (*1 *2 *3 *3 *3 *3 *4 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G)))) (-5 *2 (-1035)) (-5 *1 (-740)))) (-4238 (*1 *2 *3 *3 *3 *4 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G)))) (-5 *2 (-1035)) (-5 *1 (-740)))) (-4244 (*1 *2 *3 *4 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) (-5 *2 (-1035)) (-5 *1 (-740)))) (-4250 (*1 *2 *3 *3 *4 *5 *3 *3 *4 *4 *4 *6) (-12 (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-740)))) (-4262 (*1 *2 *3 *3 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) (-5 *2 (-1035)) (-5 *1 (-740)))) (-4274 (*1 *2 *3 *3 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) (-5 *2 (-1035)) (-5 *1 (-740))))) 
-(-10 -7 (-15 -4274 ((-1035) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478))))) (-15 -4262 ((-1035) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478))))) (-15 -4250 ((-1035) (-215) (-215) (-568) (-679 (-215)) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478))))) (-15 -4244 ((-1035) (-215) (-568) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478))))) (-15 -4238 ((-1035) (-215) (-215) (-215) (-568) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G))))) (-15 -4226 ((-1035) (-215) (-215) (-215) (-215) (-568) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G))))) (-15 -4214 ((-1035) (-215) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G))))) (-15 -3701 ((-1035) (-215) (-215) (-568) (-215) (-568) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G))))) (-15 -3694 ((-1035) (-215) (-215) (-568) (-568) (-568) (-568))) (-15 -3685 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-83 FUNCTN))))) (-15 -3677 ((-1035) (-679 (-215)) (-679 (-215)) (-568) (-568))) (-15 -3668 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568) (-215) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-83 FUNCTN)))))) 
-((-3715 (((-1035) (-568) (-568) (-568) (-568) (-215) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-80 FCN JACOBF JACEPS))) (-3 (|:| |fn| (-390)) (|:| |fp| (-81 G JACOBG JACGEP)))) 76)) (-3722 (((-1035) (-679 (-215)) (-568) (-568) (-215) (-568) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-92 BDYVAL))) (-390) (-390)) 69) (((-1035) (-679 (-215)) (-568) (-568) (-215) (-568) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-92 BDYVAL)))) 68)) (-3729 (((-1035) (-215) (-215) (-568) (-215) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-89 FCNF))) (-3 (|:| |fn| (-390)) (|:| |fp| (-90 FCNG)))) 57)) (-3736 (((-1035) (-679 (-215)) (-679 (-215)) (-568) (-215) (-215) (-215) (-568) (-568) (-568) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN)))) 50)) (-3744 (((-1035) (-215) (-568) (-568) (-1143) (-568) (-215) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-76 PEDERV))) (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT)))) 49)) (-3752 (((-1035) (-215) (-568) (-568) (-215) (-1143) (-215) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT)))) 45)) (-3761 (((-1035) (-215) (-568) (-568) (-215) (-215) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN)))) 42)) (-3769 (((-1035) (-215) (-568) (-568) (-568) (-215) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT)))) 38))) 
-(((-741) (-10 -7 (-15 -3769 ((-1035) (-215) (-568) (-568) (-568) (-215) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT))))) (-15 -3761 ((-1035) (-215) (-568) (-568) (-215) (-215) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))))) (-15 -3752 ((-1035) (-215) (-568) (-568) (-215) (-1143) (-215) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT))))) (-15 -3744 ((-1035) (-215) (-568) (-568) (-1143) (-568) (-215) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-76 PEDERV))) (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT))))) (-15 -3736 ((-1035) (-679 (-215)) (-679 (-215)) (-568) (-215) (-215) (-215) (-568) (-568) (-568) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))))) (-15 -3729 ((-1035) (-215) (-215) (-568) (-215) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-89 FCNF))) (-3 (|:| |fn| (-390)) (|:| |fp| (-90 FCNG))))) (-15 -3722 ((-1035) (-679 (-215)) (-568) (-568) (-215) (-568) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-92 BDYVAL))))) (-15 -3722 ((-1035) (-679 (-215)) (-568) (-568) (-215) (-568) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-92 BDYVAL))) (-390) (-390))) (-15 -3715 ((-1035) (-568) (-568) (-568) (-568) (-215) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-80 FCN JACOBF JACEPS))) (-3 (|:| |fn| (-390)) (|:| |fp| (-81 G JACOBG JACGEP))))))) (T -741)) 
-((-3715 (*1 *2 *3 *3 *3 *3 *4 *3 *3 *3 *3 *3 *3 *5 *5 *4 *3 *6 *7) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-80 FCN JACOBF JACEPS)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-81 G JACOBG JACGEP)))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-741)))) (-3722 (*1 *2 *3 *4 *4 *5 *4 *4 *5 *5 *3 *4 *4 *6 *7 *8 *8) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *5 (-215)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-66 COEFFN)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-92 BDYVAL)))) (-5 *8 (-390)) (-5 *2 (-1035)) (-5 *1 (-741)))) (-3722 (*1 *2 *3 *4 *4 *5 *4 *4 *5 *5 *3 *4 *4 *6 *7) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *5 (-215)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-66 COEFFN)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-92 BDYVAL)))) (-5 *2 (-1035)) (-5 *1 (-741)))) (-3729 (*1 *2 *3 *3 *4 *3 *4 *4 *4 *5 *5 *5 *5 *4 *4 *6 *7) (-12 (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-89 FCNF)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-90 FCNG)))) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-741)))) (-3736 (*1 *2 *3 *3 *4 *5 *5 *5 *4 *4 *4 *3 *4 *4 *6) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *5 (-215)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN)))) (-5 *2 (-1035)) (-5 *1 (-741)))) (-3744 (*1 *2 *3 *4 *4 *5 *4 *3 *6 *3 *4 *7 *8 *9 *10) (-12 (-5 *4 (-568)) (-5 *5 (-1143)) (-5 *6 (-679 (-215))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G)))) (-5 *8 (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN)))) (-5 *9 (-3 (|:| |fn| (-390)) (|:| |fp| (-76 PEDERV)))) (-5 *10 (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT)))) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-741)))) (-3752 (*1 *2 *3 *4 *4 *3 *5 *3 *6 *4 *7 *8 *9) (-12 (-5 *4 (-568)) (-5 *5 (-1143)) (-5 *6 (-679 (-215))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G)))) (-5 *8 (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN)))) (-5 *9 (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT)))) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-741)))) (-3761 (*1 *2 *3 *4 *4 *3 *3 *5 *3 *4 *6 *7) (-12 (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN)))) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-741)))) (-3769 (*1 *2 *3 *4 *4 *4 *3 *5 *3 *4 *6 *7) (-12 (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT)))) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-741))))) 
-(-10 -7 (-15 -3769 ((-1035) (-215) (-568) (-568) (-568) (-215) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT))))) (-15 -3761 ((-1035) (-215) (-568) (-568) (-215) (-215) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))))) (-15 -3752 ((-1035) (-215) (-568) (-568) (-215) (-1143) (-215) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT))))) (-15 -3744 ((-1035) (-215) (-568) (-568) (-1143) (-568) (-215) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-76 PEDERV))) (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT))))) (-15 -3736 ((-1035) (-679 (-215)) (-679 (-215)) (-568) (-215) (-215) (-215) (-568) (-568) (-568) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))))) (-15 -3729 ((-1035) (-215) (-215) (-568) (-215) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-89 FCNF))) (-3 (|:| |fn| (-390)) (|:| |fp| (-90 FCNG))))) (-15 -3722 ((-1035) (-679 (-215)) (-568) (-568) (-215) (-568) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-92 BDYVAL))))) (-15 -3722 ((-1035) (-679 (-215)) (-568) (-568) (-215) (-568) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-92 BDYVAL))) (-390) (-390))) (-15 -3715 ((-1035) (-568) (-568) (-568) (-568) (-215) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-80 FCN JACOBF JACEPS))) (-3 (|:| |fn| (-390)) (|:| |fp| (-81 G JACOBG JACGEP)))))) 
-((-3814 (((-1035) (-215) (-215) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-215) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-215) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-666 (-215)) (-568)) 45)) (-3822 (((-1035) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-1143) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-87 PDEF))) (-3 (|:| |fn| (-390)) (|:| |fp| (-88 BNDY)))) 41)) (-3832 (((-1035) (-568) (-568) (-568) (-568) (-215) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568)) 23))) 
-(((-742) (-10 -7 (-15 -3832 ((-1035) (-568) (-568) (-568) (-568) (-215) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3822 ((-1035) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-1143) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-87 PDEF))) (-3 (|:| |fn| (-390)) (|:| |fp| (-88 BNDY))))) (-15 -3814 ((-1035) (-215) (-215) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-215) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-215) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-666 (-215)) (-568))))) (T -742)) 
-((-3814 (*1 *2 *3 *3 *4 *4 *5 *5 *3 *3 *4 *4 *5 *5 *3 *3 *4 *4 *5 *5 *3 *4 *4 *4 *6 *4) (-12 (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-666 (-215))) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-742)))) (-3822 (*1 *2 *3 *3 *3 *3 *4 *4 *4 *5 *4 *6 *7) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-1143)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-87 PDEF)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-88 BNDY)))) (-5 *2 (-1035)) (-5 *1 (-742)))) (-3832 (*1 *2 *3 *3 *3 *3 *4 *3 *5 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-742))))) 
-(-10 -7 (-15 -3832 ((-1035) (-568) (-568) (-568) (-568) (-215) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3822 ((-1035) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-1143) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-87 PDEF))) (-3 (|:| |fn| (-390)) (|:| |fp| (-88 BNDY))))) (-15 -3814 ((-1035) (-215) (-215) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-215) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-215) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-666 (-215)) (-568)))) 
-((-1454 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-679 (-215)) (-215) (-215) (-568)) 35)) (-1702 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-215) (-215) (-568)) 34)) (-1803 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-679 (-215)) (-215) (-215) (-568)) 33)) (-1708 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568)) 29)) (-1714 (((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568)) 28)) (-1722 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-215) (-568)) 27)) (-1729 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-568)) 23)) (-1736 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-568)) 22)) (-1743 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568)) 21)) (-1749 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568) (-568) (-568)) 20))) 
-(((-743) (-10 -7 (-15 -1749 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568) (-568) (-568))) (-15 -1743 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1736 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-568))) (-15 -1729 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-568))) (-15 -1722 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-215) (-568))) (-15 -1714 ((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1708 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1803 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-679 (-215)) (-215) (-215) (-568))) (-15 -1702 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-215) (-215) (-568))) (-15 -1454 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-679 (-215)) (-215) (-215) (-568))))) (T -743)) 
-((-1454 (*1 *2 *3 *4 *4 *4 *5 *4 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *2 (-1035)) (-5 *1 (-743)))) (-1702 (*1 *2 *3 *4 *4 *4 *3 *3 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *2 (-1035)) (-5 *1 (-743)))) (-1803 (*1 *2 *3 *4 *4 *4 *5 *4 *6 *6 *3) (-12 (-5 *4 (-679 (-215))) (-5 *5 (-679 (-568))) (-5 *6 (-215)) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-743)))) (-1708 (*1 *2 *3 *4 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-743)))) (-1714 (*1 *2 *3 *3 *4 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-743)))) (-1722 (*1 *2 *3 *4 *4 *4 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *2 (-1035)) (-5 *1 (-743)))) (-1729 (*1 *2 *3 *4 *4 *4 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-743)))) (-1736 (*1 *2 *3 *4 *4 *4 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-743)))) (-1743 (*1 *2 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-743)))) (-1749 (*1 *2 *3 *4 *4 *3 *3 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-743))))) 
-(-10 -7 (-15 -1749 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568) (-568) (-568))) (-15 -1743 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1736 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-568))) (-15 -1729 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-568))) (-15 -1722 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-215) (-568))) (-15 -1714 ((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1708 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1803 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-679 (-215)) (-215) (-215) (-568))) (-15 -1702 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-215) (-215) (-568))) (-15 -1454 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-679 (-215)) (-215) (-215) (-568)))) 
-((-1754 (((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-568) (-568) (-568)) 45)) (-1759 (((-1035) (-568) (-568) (-568) (-215) (-679 (-215)) (-679 (-215)) (-568)) 44)) (-1765 (((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-568)) 43)) (-1771 (((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568)) 42)) (-1777 (((-1035) (-1143) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-568)) 41)) (-1782 (((-1035) (-1143) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-568)) 40)) (-1788 (((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-568) (-568) (-568) (-215) (-679 (-215)) (-568)) 39)) (-1793 (((-1035) (-1143) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-568))) 38)) (-3586 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568)) 35)) (-3142 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568)) 34)) (-3148 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568)) 33)) (-3154 (((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568)) 32)) (-3160 (((-1035) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-215) (-568)) 31)) (-3167 (((-1035) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-215) (-568) (-568) (-568)) 30)) (-3778 (((-1035) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-568) (-568) (-568)) 29)) (-4202 (((-1035) (-568) (-568) (-568) (-215) (-215) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-568) (-679 (-568)) (-568) (-568) (-568)) 28)) (-1655 (((-1035) (-568) (-679 (-215)) (-215) (-568)) 24)) (-1674 (((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568)) 20))) 
-(((-744) (-10 -7 (-15 -1674 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1655 ((-1035) (-568) (-679 (-215)) (-215) (-568))) (-15 -4202 ((-1035) (-568) (-568) (-568) (-215) (-215) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-568) (-679 (-568)) (-568) (-568) (-568))) (-15 -3778 ((-1035) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-568) (-568) (-568))) (-15 -3167 ((-1035) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-215) (-568) (-568) (-568))) (-15 -3160 ((-1035) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-215) (-568))) (-15 -3154 ((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3148 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568))) (-15 -3142 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568))) (-15 -3586 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1793 ((-1035) (-1143) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-568)))) (-15 -1788 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-568) (-568) (-568) (-215) (-679 (-215)) (-568))) (-15 -1782 ((-1035) (-1143) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-568))) (-15 -1777 ((-1035) (-1143) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1771 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1765 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-568))) (-15 -1759 ((-1035) (-568) (-568) (-568) (-215) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1754 ((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-568) (-568) (-568))))) (T -744)) 
-((-1754 (*1 *2 *3 *3 *4 *4 *3 *4 *4 *3 *3 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-744)))) (-1759 (*1 *2 *3 *3 *3 *4 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-1765 (*1 *2 *3 *3 *3 *3 *4 *4 *4 *4 *4 *3 *3 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-744)))) (-1771 (*1 *2 *3 *3 *3 *4 *4 *4 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-744)))) (-1777 (*1 *2 *3 *4 *5 *5 *5 *5 *6 *4 *4 *4 *4 *4 *5 *4 *5 *5 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-215)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-1782 (*1 *2 *3 *4 *5 *4 *5 *5 *6 *4 *4 *4 *4 *4 *5 *4 *5 *5 *7 *4) (-12 (-5 *3 (-1143)) (-5 *5 (-679 (-215))) (-5 *6 (-215)) (-5 *7 (-679 (-568))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-1788 (*1 *2 *3 *3 *3 *4 *4 *4 *4 *4 *5 *3 *3 *3 *6 *4 *3) (-12 (-5 *4 (-679 (-215))) (-5 *5 (-679 (-568))) (-5 *6 (-215)) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-1793 (*1 *2 *3 *4 *5 *5 *5 *6 *4 *4 *4 *5 *4 *5 *7) (-12 (-5 *3 (-1143)) (-5 *5 (-679 (-215))) (-5 *6 (-215)) (-5 *7 (-679 (-568))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-3586 (*1 *2 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-744)))) (-3142 (*1 *2 *3 *4 *4 *5 *3 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-3148 (*1 *2 *3 *4 *4 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-3154 (*1 *2 *3 *3 *4 *4 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-744)))) (-3160 (*1 *2 *3 *4 *4 *5 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-3167 (*1 *2 *3 *4 *4 *5 *3 *3 *4 *3 *3 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-3778 (*1 *2 *3 *4 *4 *5 *3 *3 *3 *3 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-4202 (*1 *2 *3 *3 *3 *4 *4 *5 *5 *5 *3 *5 *5 *3 *6 *3 *3 *3) (-12 (-5 *5 (-679 (-215))) (-5 *6 (-679 (-568))) (-5 *3 (-568)) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-1655 (*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-1674 (*1 *2 *3 *3 *3 *4 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-744))))) 
-(-10 -7 (-15 -1674 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1655 ((-1035) (-568) (-679 (-215)) (-215) (-568))) (-15 -4202 ((-1035) (-568) (-568) (-568) (-215) (-215) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-568) (-679 (-568)) (-568) (-568) (-568))) (-15 -3778 ((-1035) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-568) (-568) (-568))) (-15 -3167 ((-1035) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-215) (-568) (-568) (-568))) (-15 -3160 ((-1035) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-215) (-568))) (-15 -3154 ((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3148 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568))) (-15 -3142 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568))) (-15 -3586 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1793 ((-1035) (-1143) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-568)))) (-15 -1788 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-568) (-568) (-568) (-215) (-679 (-215)) (-568))) (-15 -1782 ((-1035) (-1143) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-568))) (-15 -1777 ((-1035) (-1143) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1771 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1765 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-568))) (-15 -1759 ((-1035) (-568) (-568) (-568) (-215) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1754 ((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-568) (-568) (-568)))) 
-((-3173 (((-1035) (-568) (-568) (-568) (-215) (-679 (-215)) (-568) (-679 (-215)) (-568)) 63)) (-3181 (((-1035) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-121) (-215) (-568) (-215) (-215) (-121) (-215) (-215) (-215) (-215) (-121) (-568) (-568) (-568) (-568) (-568) (-215) (-215) (-215) (-568) (-568) (-568) (-568) (-568) (-679 (-568)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-85 CONFUN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-82 OBJFUN)))) 62)) (-3188 (((-1035) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-215) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-121) (-121) (-121) (-568) (-568) (-679 (-215)) (-679 (-568)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-70 QPHESS)))) 58)) (-3195 (((-1035) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-121) (-568) (-568) (-679 (-215)) (-568)) 51)) (-3204 (((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-71 FUNCT1)))) 50)) (-3213 (((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-68 LSFUN2)))) 46)) (-3219 (((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-84 LSFUN1)))) 42)) (-3228 (((-1035) (-568) (-215) (-215) (-568) (-215) (-121) (-215) (-215) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-82 OBJFUN)))) 38))) 
-(((-745) (-10 -7 (-15 -3228 ((-1035) (-568) (-215) (-215) (-568) (-215) (-121) (-215) (-215) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-82 OBJFUN))))) (-15 -3219 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-84 LSFUN1))))) (-15 -3213 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-68 LSFUN2))))) (-15 -3204 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-71 FUNCT1))))) (-15 -3195 ((-1035) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-121) (-568) (-568) (-679 (-215)) (-568))) (-15 -3188 ((-1035) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-215) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-121) (-121) (-121) (-568) (-568) (-679 (-215)) (-679 (-568)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-70 QPHESS))))) (-15 -3181 ((-1035) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-121) (-215) (-568) (-215) (-215) (-121) (-215) (-215) (-215) (-215) (-121) (-568) (-568) (-568) (-568) (-568) (-215) (-215) (-215) (-568) (-568) (-568) (-568) (-568) (-679 (-568)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-85 CONFUN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-82 OBJFUN))))) (-15 -3173 ((-1035) (-568) (-568) (-568) (-215) (-679 (-215)) (-568) (-679 (-215)) (-568))))) (T -745)) 
-((-3173 (*1 *2 *3 *3 *3 *4 *5 *3 *5 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-745)))) (-3181 (*1 *2 *3 *3 *3 *3 *3 *3 *4 *4 *4 *3 *3 *5 *6 *3 *6 *6 *5 *6 *6 *6 *6 *5 *3 *3 *3 *3 *3 *6 *6 *6 *3 *3 *3 *3 *3 *7 *4 *4 *4 *4 *3 *8 *9) (-12 (-5 *4 (-679 (-215))) (-5 *5 (-121)) (-5 *6 (-215)) (-5 *7 (-679 (-568))) (-5 *8 (-3 (|:| |fn| (-390)) (|:| |fp| (-85 CONFUN)))) (-5 *9 (-3 (|:| |fn| (-390)) (|:| |fp| (-82 OBJFUN)))) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-745)))) (-3188 (*1 *2 *3 *3 *3 *3 *3 *3 *3 *3 *4 *5 *5 *5 *5 *5 *5 *6 *6 *6 *3 *3 *5 *7 *3 *8) (-12 (-5 *5 (-679 (-215))) (-5 *6 (-121)) (-5 *7 (-679 (-568))) (-5 *8 (-3 (|:| |fn| (-390)) (|:| |fp| (-70 QPHESS)))) (-5 *3 (-568)) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-745)))) (-3195 (*1 *2 *3 *3 *3 *3 *3 *3 *4 *4 *4 *4 *5 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-121)) (-5 *2 (-1035)) (-5 *1 (-745)))) (-3204 (*1 *2 *3 *3 *3 *3 *4 *4 *4 *3 *5) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-71 FUNCT1)))) (-5 *2 (-1035)) (-5 *1 (-745)))) (-3213 (*1 *2 *3 *3 *3 *3 *4 *3 *5) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-68 LSFUN2)))) (-5 *2 (-1035)) (-5 *1 (-745)))) (-3219 (*1 *2 *3 *3 *3 *3 *4 *3 *5) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-84 LSFUN1)))) (-5 *2 (-1035)) (-5 *1 (-745)))) (-3228 (*1 *2 *3 *4 *4 *3 *4 *5 *4 *4 *3 *3 *3 *3 *6 *3 *7) (-12 (-5 *3 (-568)) (-5 *5 (-121)) (-5 *6 (-679 (-215))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-82 OBJFUN)))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-745))))) 
-(-10 -7 (-15 -3228 ((-1035) (-568) (-215) (-215) (-568) (-215) (-121) (-215) (-215) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-82 OBJFUN))))) (-15 -3219 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-84 LSFUN1))))) (-15 -3213 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-68 LSFUN2))))) (-15 -3204 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-71 FUNCT1))))) (-15 -3195 ((-1035) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-121) (-568) (-568) (-679 (-215)) (-568))) (-15 -3188 ((-1035) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-215) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-121) (-121) (-121) (-568) (-568) (-679 (-215)) (-679 (-568)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-70 QPHESS))))) (-15 -3181 ((-1035) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-121) (-215) (-568) (-215) (-215) (-121) (-215) (-215) (-215) (-215) (-121) (-568) (-568) (-568) (-568) (-568) (-215) (-215) (-215) (-568) (-568) (-568) (-568) (-568) (-679 (-568)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-85 CONFUN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-82 OBJFUN))))) (-15 -3173 ((-1035) (-568) (-568) (-568) (-215) (-679 (-215)) (-568) (-679 (-215)) (-568)))) 
-((-3237 (((-1035) (-1143) (-568) (-568) (-568) (-568) (-679 (-169 (-215))) (-679 (-169 (-215))) (-568)) 46)) (-3244 (((-1035) (-1143) (-1143) (-568) (-568) (-679 (-169 (-215))) (-568) (-679 (-169 (-215))) (-568) (-568) (-679 (-169 (-215))) (-568)) 45)) (-3252 (((-1035) (-568) (-568) (-568) (-679 (-169 (-215))) (-568)) 44)) (-3258 (((-1035) (-1143) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568)) 40)) (-3266 (((-1035) (-1143) (-1143) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-568) (-568) (-679 (-215)) (-568)) 39)) (-3275 (((-1035) (-568) (-568) (-568) (-679 (-215)) (-568)) 36)) (-3285 (((-1035) (-568) (-679 (-215)) (-568) (-679 (-568)) (-568)) 35)) (-3289 (((-1035) (-568) (-568) (-568) (-568) (-634 (-121)) (-679 (-215)) (-679 (-568)) (-679 (-568)) (-215) (-215) (-568)) 34)) (-3303 (((-1035) (-568) (-568) (-568) (-679 (-568)) (-679 (-568)) (-679 (-568)) (-679 (-568)) (-121) (-215) (-121) (-679 (-568)) (-679 (-215)) (-568)) 33)) (-3308 (((-1035) (-568) (-568) (-568) (-568) (-215) (-121) (-121) (-634 (-121)) (-679 (-215)) (-679 (-568)) (-679 (-568)) (-568)) 32))) 
-(((-746) (-10 -7 (-15 -3308 ((-1035) (-568) (-568) (-568) (-568) (-215) (-121) (-121) (-634 (-121)) (-679 (-215)) (-679 (-568)) (-679 (-568)) (-568))) (-15 -3303 ((-1035) (-568) (-568) (-568) (-679 (-568)) (-679 (-568)) (-679 (-568)) (-679 (-568)) (-121) (-215) (-121) (-679 (-568)) (-679 (-215)) (-568))) (-15 -3289 ((-1035) (-568) (-568) (-568) (-568) (-634 (-121)) (-679 (-215)) (-679 (-568)) (-679 (-568)) (-215) (-215) (-568))) (-15 -3285 ((-1035) (-568) (-679 (-215)) (-568) (-679 (-568)) (-568))) (-15 -3275 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-568))) (-15 -3266 ((-1035) (-1143) (-1143) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-568) (-568) (-679 (-215)) (-568))) (-15 -3258 ((-1035) (-1143) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3252 ((-1035) (-568) (-568) (-568) (-679 (-169 (-215))) (-568))) (-15 -3244 ((-1035) (-1143) (-1143) (-568) (-568) (-679 (-169 (-215))) (-568) (-679 (-169 (-215))) (-568) (-568) (-679 (-169 (-215))) (-568))) (-15 -3237 ((-1035) (-1143) (-568) (-568) (-568) (-568) (-679 (-169 (-215))) (-679 (-169 (-215))) (-568))))) (T -746)) 
-((-3237 (*1 *2 *3 *4 *4 *4 *4 *5 *5 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-169 (-215)))) (-5 *2 (-1035)) (-5 *1 (-746)))) (-3244 (*1 *2 *3 *3 *4 *4 *5 *4 *5 *4 *4 *5 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-169 (-215)))) (-5 *2 (-1035)) (-5 *1 (-746)))) (-3252 (*1 *2 *3 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-169 (-215)))) (-5 *2 (-1035)) (-5 *1 (-746)))) (-3258 (*1 *2 *3 *4 *4 *4 *4 *5 *5 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-746)))) (-3266 (*1 *2 *3 *3 *4 *4 *5 *4 *5 *4 *4 *5 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-746)))) (-3275 (*1 *2 *3 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-746)))) (-3285 (*1 *2 *3 *4 *3 *5 *3) (-12 (-5 *4 (-679 (-215))) (-5 *5 (-679 (-568))) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-746)))) (-3289 (*1 *2 *3 *3 *3 *3 *4 *5 *6 *6 *7 *7 *3) (-12 (-5 *4 (-634 (-121))) (-5 *5 (-679 (-215))) (-5 *6 (-679 (-568))) (-5 *7 (-215)) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-746)))) (-3303 (*1 *2 *3 *3 *3 *4 *4 *4 *4 *5 *6 *5 *4 *7 *3) (-12 (-5 *4 (-679 (-568))) (-5 *5 (-121)) (-5 *7 (-679 (-215))) (-5 *3 (-568)) (-5 *6 (-215)) (-5 *2 (-1035)) (-5 *1 (-746)))) (-3308 (*1 *2 *3 *3 *3 *3 *4 *5 *5 *6 *7 *8 *8 *3) (-12 (-5 *6 (-634 (-121))) (-5 *7 (-679 (-215))) (-5 *8 (-679 (-568))) (-5 *3 (-568)) (-5 *4 (-215)) (-5 *5 (-121)) (-5 *2 (-1035)) (-5 *1 (-746))))) 
-(-10 -7 (-15 -3308 ((-1035) (-568) (-568) (-568) (-568) (-215) (-121) (-121) (-634 (-121)) (-679 (-215)) (-679 (-568)) (-679 (-568)) (-568))) (-15 -3303 ((-1035) (-568) (-568) (-568) (-679 (-568)) (-679 (-568)) (-679 (-568)) (-679 (-568)) (-121) (-215) (-121) (-679 (-568)) (-679 (-215)) (-568))) (-15 -3289 ((-1035) (-568) (-568) (-568) (-568) (-634 (-121)) (-679 (-215)) (-679 (-568)) (-679 (-568)) (-215) (-215) (-568))) (-15 -3285 ((-1035) (-568) (-679 (-215)) (-568) (-679 (-568)) (-568))) (-15 -3275 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-568))) (-15 -3266 ((-1035) (-1143) (-1143) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-568) (-568) (-679 (-215)) (-568))) (-15 -3258 ((-1035) (-1143) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3252 ((-1035) (-568) (-568) (-568) (-679 (-169 (-215))) (-568))) (-15 -3244 ((-1035) (-1143) (-1143) (-568) (-568) (-679 (-169 (-215))) (-568) (-679 (-169 (-215))) (-568) (-568) (-679 (-169 (-215))) (-568))) (-15 -3237 ((-1035) (-1143) (-568) (-568) (-568) (-568) (-679 (-169 (-215))) (-679 (-169 (-215))) (-568)))) 
-((-2952 (((-1035) (-568) (-568) (-568) (-568) (-568) (-121) (-568) (-121) (-568) (-679 (-169 (-215))) (-679 (-169 (-215))) (-568)) 64)) (-2956 (((-1035) (-568) (-568) (-568) (-568) (-568) (-121) (-568) (-121) (-568) (-679 (-215)) (-679 (-215)) (-568)) 60)) (-2962 (((-1035) (-568) (-568) (-215) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-390)) (|:| |fp| (-73 IMAGE))) (-390)) 56) (((-1035) (-568) (-568) (-215) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-390)) (|:| |fp| (-73 IMAGE)))) 55)) (-2966 (((-1035) (-568) (-568) (-568) (-215) (-121) (-568) (-679 (-215)) (-679 (-215)) (-568)) 37)) (-2972 (((-1035) (-568) (-568) (-215) (-215) (-568) (-568) (-679 (-215)) (-568)) 33)) (-2977 (((-1035) (-679 (-215)) (-568) (-679 (-215)) (-568) (-568) (-568) (-568) (-568)) 29)) (-2981 (((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568)) 28)) (-2987 (((-1035) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568)) 27)) (-2992 (((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568)) 26)) (-2997 (((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-568)) 25)) (-3006 (((-1035) (-568) (-568) (-679 (-215)) (-568)) 24)) (-3011 (((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568)) 23)) (-3015 (((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568)) 22)) (-3020 (((-1035) (-679 (-215)) (-568) (-568) (-568) (-568)) 21)) (-3024 (((-1035) (-568) (-568) (-679 (-215)) (-568)) 20))) 
-(((-747) (-10 -7 (-15 -3024 ((-1035) (-568) (-568) (-679 (-215)) (-568))) (-15 -3020 ((-1035) (-679 (-215)) (-568) (-568) (-568) (-568))) (-15 -3015 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3011 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3006 ((-1035) (-568) (-568) (-679 (-215)) (-568))) (-15 -2997 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-568))) (-15 -2992 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -2987 ((-1035) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -2981 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -2977 ((-1035) (-679 (-215)) (-568) (-679 (-215)) (-568) (-568) (-568) (-568) (-568))) (-15 -2972 ((-1035) (-568) (-568) (-215) (-215) (-568) (-568) (-679 (-215)) (-568))) (-15 -2966 ((-1035) (-568) (-568) (-568) (-215) (-121) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -2962 ((-1035) (-568) (-568) (-215) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-390)) (|:| |fp| (-73 IMAGE))))) (-15 -2962 ((-1035) (-568) (-568) (-215) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-390)) (|:| |fp| (-73 IMAGE))) (-390))) (-15 -2956 ((-1035) (-568) (-568) (-568) (-568) (-568) (-121) (-568) (-121) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -2952 ((-1035) (-568) (-568) (-568) (-568) (-568) (-121) (-568) (-121) (-568) (-679 (-169 (-215))) (-679 (-169 (-215))) (-568))))) (T -747)) 
-((-2952 (*1 *2 *3 *3 *3 *3 *3 *4 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-121)) (-5 *5 (-679 (-169 (-215)))) (-5 *2 (-1035)) (-5 *1 (-747)))) (-2956 (*1 *2 *3 *3 *3 *3 *3 *4 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-121)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747)))) (-2962 (*1 *2 *3 *3 *4 *3 *3 *3 *3 *3 *3 *3 *5 *3 *6 *7 *8) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-72 DOT)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-73 IMAGE)))) (-5 *8 (-390)) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-747)))) (-2962 (*1 *2 *3 *3 *4 *3 *3 *3 *3 *3 *3 *3 *5 *3 *6 *7) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-72 DOT)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-73 IMAGE)))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-747)))) (-2966 (*1 *2 *3 *3 *3 *4 *5 *3 *6 *6 *3) (-12 (-5 *3 (-568)) (-5 *5 (-121)) (-5 *6 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-747)))) (-2972 (*1 *2 *3 *3 *4 *4 *3 *3 *5 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-747)))) (-2977 (*1 *2 *3 *4 *3 *4 *4 *4 *4 *4) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-747)))) (-2981 (*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747)))) (-2987 (*1 *2 *3 *3 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747)))) (-2992 (*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747)))) (-2997 (*1 *2 *3 *3 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747)))) (-3006 (*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747)))) (-3011 (*1 *2 *3 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747)))) (-3015 (*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747)))) (-3020 (*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-747)))) (-3024 (*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747))))) 
-(-10 -7 (-15 -3024 ((-1035) (-568) (-568) (-679 (-215)) (-568))) (-15 -3020 ((-1035) (-679 (-215)) (-568) (-568) (-568) (-568))) (-15 -3015 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3011 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3006 ((-1035) (-568) (-568) (-679 (-215)) (-568))) (-15 -2997 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-568))) (-15 -2992 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -2987 ((-1035) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -2981 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -2977 ((-1035) (-679 (-215)) (-568) (-679 (-215)) (-568) (-568) (-568) (-568) (-568))) (-15 -2972 ((-1035) (-568) (-568) (-215) (-215) (-568) (-568) (-679 (-215)) (-568))) (-15 -2966 ((-1035) (-568) (-568) (-568) (-215) (-121) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -2962 ((-1035) (-568) (-568) (-215) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-390)) (|:| |fp| (-73 IMAGE))))) (-15 -2962 ((-1035) (-568) (-568) (-215) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-390)) (|:| |fp| (-73 IMAGE))) (-390))) (-15 -2956 ((-1035) (-568) (-568) (-568) (-568) (-568) (-121) (-568) (-121) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -2952 ((-1035) (-568) (-568) (-568) (-568) (-568) (-121) (-568) (-121) (-568) (-679 (-169 (-215))) (-679 (-169 (-215))) (-568)))) 
-((-4319 (((-1035) (-568) (-568) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-75 APROD)))) 60)) (-4326 (((-1035) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-568)) (-568) (-679 (-215)) (-568) (-568) (-568) (-568)) 56)) (-4331 (((-1035) (-568) (-679 (-215)) (-121) (-215) (-568) (-568) (-568) (-568) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-73 APROD))) (-3 (|:| |fn| (-390)) (|:| |fp| (-78 MSOLVE)))) 55)) (-4337 (((-1035) (-568) (-568) (-679 (-215)) (-568) (-679 (-568)) (-568) (-679 (-568)) (-679 (-215)) (-679 (-568)) (-679 (-568)) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-568)) 36)) (-4344 (((-1035) (-568) (-568) (-568) (-215) (-568) (-679 (-215)) (-679 (-215)) (-568)) 35)) (-4349 (((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568)) 31)) (-4357 (((-1035) (-568) (-679 (-215)) (-568) (-679 (-568)) (-679 (-568)) (-568) (-679 (-568)) (-679 (-215))) 30)) (-4363 (((-1035) (-679 (-215)) (-568) (-679 (-215)) (-568) (-568) (-568)) 26)) (-4369 (((-1035) (-568) (-679 (-215)) (-568) (-679 (-215)) (-568)) 25)) (-4380 (((-1035) (-568) (-679 (-215)) (-568) (-679 (-215)) (-568)) 24)) (-2896 (((-1035) (-568) (-679 (-169 (-215))) (-568) (-568) (-568) (-568) (-679 (-169 (-215))) (-568)) 20))) 
-(((-748) (-10 -7 (-15 -2896 ((-1035) (-568) (-679 (-169 (-215))) (-568) (-568) (-568) (-568) (-679 (-169 (-215))) (-568))) (-15 -4380 ((-1035) (-568) (-679 (-215)) (-568) (-679 (-215)) (-568))) (-15 -4369 ((-1035) (-568) (-679 (-215)) (-568) (-679 (-215)) (-568))) (-15 -4363 ((-1035) (-679 (-215)) (-568) (-679 (-215)) (-568) (-568) (-568))) (-15 -4357 ((-1035) (-568) (-679 (-215)) (-568) (-679 (-568)) (-679 (-568)) (-568) (-679 (-568)) (-679 (-215)))) (-15 -4349 ((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -4344 ((-1035) (-568) (-568) (-568) (-215) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -4337 ((-1035) (-568) (-568) (-679 (-215)) (-568) (-679 (-568)) (-568) (-679 (-568)) (-679 (-215)) (-679 (-568)) (-679 (-568)) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-568))) (-15 -4331 ((-1035) (-568) (-679 (-215)) (-121) (-215) (-568) (-568) (-568) (-568) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-73 APROD))) (-3 (|:| |fn| (-390)) (|:| |fp| (-78 MSOLVE))))) (-15 -4326 ((-1035) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-568)) (-568) (-679 (-215)) (-568) (-568) (-568) (-568))) (-15 -4319 ((-1035) (-568) (-568) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-75 APROD))))))) (T -748)) 
-((-4319 (*1 *2 *3 *3 *4 *4 *4 *4 *3 *3 *3 *3 *5 *3 *6) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-75 APROD)))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-748)))) (-4326 (*1 *2 *3 *4 *3 *4 *5 *3 *4 *3 *3 *3 *3) (-12 (-5 *4 (-679 (-215))) (-5 *5 (-679 (-568))) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-748)))) (-4331 (*1 *2 *3 *4 *5 *6 *3 *3 *3 *3 *6 *3 *7 *8) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-121)) (-5 *6 (-215)) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-73 APROD)))) (-5 *8 (-3 (|:| |fn| (-390)) (|:| |fp| (-78 MSOLVE)))) (-5 *2 (-1035)) (-5 *1 (-748)))) (-4337 (*1 *2 *3 *3 *4 *3 *5 *3 *5 *4 *5 *5 *4 *4 *5 *3) (-12 (-5 *4 (-679 (-215))) (-5 *5 (-679 (-568))) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-748)))) (-4344 (*1 *2 *3 *3 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-748)))) (-4349 (*1 *2 *3 *3 *4 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-748)))) (-4357 (*1 *2 *3 *4 *3 *5 *5 *3 *5 *4) (-12 (-5 *4 (-679 (-215))) (-5 *5 (-679 (-568))) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-748)))) (-4363 (*1 *2 *3 *4 *3 *4 *4 *4) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-748)))) (-4369 (*1 *2 *3 *4 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-748)))) (-4380 (*1 *2 *3 *4 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-748)))) (-2896 (*1 *2 *3 *4 *3 *3 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-169 (-215)))) (-5 *2 (-1035)) (-5 *1 (-748))))) 
-(-10 -7 (-15 -2896 ((-1035) (-568) (-679 (-169 (-215))) (-568) (-568) (-568) (-568) (-679 (-169 (-215))) (-568))) (-15 -4380 ((-1035) (-568) (-679 (-215)) (-568) (-679 (-215)) (-568))) (-15 -4369 ((-1035) (-568) (-679 (-215)) (-568) (-679 (-215)) (-568))) (-15 -4363 ((-1035) (-679 (-215)) (-568) (-679 (-215)) (-568) (-568) (-568))) (-15 -4357 ((-1035) (-568) (-679 (-215)) (-568) (-679 (-568)) (-679 (-568)) (-568) (-679 (-568)) (-679 (-215)))) (-15 -4349 ((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -4344 ((-1035) (-568) (-568) (-568) (-215) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -4337 ((-1035) (-568) (-568) (-679 (-215)) (-568) (-679 (-568)) (-568) (-679 (-568)) (-679 (-215)) (-679 (-568)) (-679 (-568)) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-568))) (-15 -4331 ((-1035) (-568) (-679 (-215)) (-121) (-215) (-568) (-568) (-568) (-568) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-73 APROD))) (-3 (|:| |fn| (-390)) (|:| |fp| (-78 MSOLVE))))) (-15 -4326 ((-1035) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-568)) (-568) (-679 (-215)) (-568) (-568) (-568) (-568))) (-15 -4319 ((-1035) (-568) (-568) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-75 APROD)))))) 
-((-2920 (((-1035) (-1143) (-568) (-568) (-679 (-215)) (-568) (-568) (-679 (-215))) 28)) (-2924 (((-1035) (-1143) (-568) (-568) (-679 (-215))) 27)) (-2929 (((-1035) (-1143) (-568) (-568) (-679 (-215)) (-568) (-679 (-568)) (-568) (-679 (-215))) 26)) (-2933 (((-1035) (-568) (-568) (-568) (-679 (-215))) 20))) 
-(((-749) (-10 -7 (-15 -2933 ((-1035) (-568) (-568) (-568) (-679 (-215)))) (-15 -2929 ((-1035) (-1143) (-568) (-568) (-679 (-215)) (-568) (-679 (-568)) (-568) (-679 (-215)))) (-15 -2924 ((-1035) (-1143) (-568) (-568) (-679 (-215)))) (-15 -2920 ((-1035) (-1143) (-568) (-568) (-679 (-215)) (-568) (-568) (-679 (-215)))))) (T -749)) 
-((-2920 (*1 *2 *3 *4 *4 *5 *4 *4 *5) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-749)))) (-2924 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-749)))) (-2929 (*1 *2 *3 *4 *4 *5 *4 *6 *4 *5) (-12 (-5 *3 (-1143)) (-5 *5 (-679 (-215))) (-5 *6 (-679 (-568))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-749)))) (-2933 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-749))))) 
-(-10 -7 (-15 -2933 ((-1035) (-568) (-568) (-568) (-679 (-215)))) (-15 -2929 ((-1035) (-1143) (-568) (-568) (-679 (-215)) (-568) (-679 (-568)) (-568) (-679 (-215)))) (-15 -2924 ((-1035) (-1143) (-568) (-568) (-679 (-215)))) (-15 -2920 ((-1035) (-1143) (-568) (-568) (-679 (-215)) (-568) (-568) (-679 (-215))))) 
-((-4170 (((-1035) (-215) (-215) (-215) (-215) (-568)) 62)) (-4175 (((-1035) (-215) (-215) (-215) (-568)) 61)) (-4182 (((-1035) (-215) (-215) (-215) (-568)) 60)) (-4188 (((-1035) (-215) (-215) (-568)) 59)) (-4196 (((-1035) (-215) (-568)) 58)) (-4208 (((-1035) (-215) (-568)) 57)) (-4219 (((-1035) (-215) (-568)) 56)) (-4232 (((-1035) (-215) (-568)) 55)) (-4256 (((-1035) (-215) (-568)) 54)) (-4268 (((-1035) (-215) (-568)) 53)) (-4282 (((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568)) 52)) (-4289 (((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568)) 51)) (-4294 (((-1035) (-215) (-568)) 50)) (-4301 (((-1035) (-215) (-568)) 49)) (-4307 (((-1035) (-215) (-568)) 48)) (-4312 (((-1035) (-215) (-568)) 47)) (-2940 (((-1035) (-568) (-215) (-169 (-215)) (-568) (-1143) (-568)) 46)) (-2944 (((-1035) (-1143) (-169 (-215)) (-1143) (-568)) 45)) (-2948 (((-1035) (-1143) (-169 (-215)) (-1143) (-568)) 44)) (-4040 (((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568)) 43)) (-4046 (((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568)) 42)) (-4052 (((-1035) (-215) (-568)) 39)) (-4058 (((-1035) (-215) (-568)) 38)) (-4065 (((-1035) (-215) (-568)) 37)) (-4071 (((-1035) (-215) (-568)) 36)) (-4076 (((-1035) (-215) (-568)) 35)) (-4084 (((-1035) (-215) (-568)) 34)) (-4090 (((-1035) (-215) (-568)) 33)) (-4098 (((-1035) (-215) (-568)) 32)) (-4105 (((-1035) (-215) (-568)) 31)) (-4112 (((-1035) (-215) (-568)) 30)) (-4120 (((-1035) (-215) (-215) (-215) (-568)) 29)) (-4127 (((-1035) (-215) (-568)) 28)) (-4135 (((-1035) (-215) (-568)) 27)) (-4140 (((-1035) (-215) (-568)) 26)) (-4148 (((-1035) (-215) (-568)) 25)) (-4155 (((-1035) (-215) (-568)) 24)) (-4161 (((-1035) (-169 (-215)) (-568)) 20))) 
-(((-750) (-10 -7 (-15 -4161 ((-1035) (-169 (-215)) (-568))) (-15 -4155 ((-1035) (-215) (-568))) (-15 -4148 ((-1035) (-215) (-568))) (-15 -4140 ((-1035) (-215) (-568))) (-15 -4135 ((-1035) (-215) (-568))) (-15 -4127 ((-1035) (-215) (-568))) (-15 -4120 ((-1035) (-215) (-215) (-215) (-568))) (-15 -4112 ((-1035) (-215) (-568))) (-15 -4105 ((-1035) (-215) (-568))) (-15 -4098 ((-1035) (-215) (-568))) (-15 -4090 ((-1035) (-215) (-568))) (-15 -4084 ((-1035) (-215) (-568))) (-15 -4076 ((-1035) (-215) (-568))) (-15 -4071 ((-1035) (-215) (-568))) (-15 -4065 ((-1035) (-215) (-568))) (-15 -4058 ((-1035) (-215) (-568))) (-15 -4052 ((-1035) (-215) (-568))) (-15 -4046 ((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568))) (-15 -4040 ((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568))) (-15 -2948 ((-1035) (-1143) (-169 (-215)) (-1143) (-568))) (-15 -2944 ((-1035) (-1143) (-169 (-215)) (-1143) (-568))) (-15 -2940 ((-1035) (-568) (-215) (-169 (-215)) (-568) (-1143) (-568))) (-15 -4312 ((-1035) (-215) (-568))) (-15 -4307 ((-1035) (-215) (-568))) (-15 -4301 ((-1035) (-215) (-568))) (-15 -4294 ((-1035) (-215) (-568))) (-15 -4289 ((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568))) (-15 -4282 ((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568))) (-15 -4268 ((-1035) (-215) (-568))) (-15 -4256 ((-1035) (-215) (-568))) (-15 -4232 ((-1035) (-215) (-568))) (-15 -4219 ((-1035) (-215) (-568))) (-15 -4208 ((-1035) (-215) (-568))) (-15 -4196 ((-1035) (-215) (-568))) (-15 -4188 ((-1035) (-215) (-215) (-568))) (-15 -4182 ((-1035) (-215) (-215) (-215) (-568))) (-15 -4175 ((-1035) (-215) (-215) (-215) (-568))) (-15 -4170 ((-1035) (-215) (-215) (-215) (-215) (-568))))) (T -750)) 
-((-4170 (*1 *2 *3 *3 *3 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4175 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4182 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4188 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4196 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4208 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4219 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4232 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4256 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4268 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4282 (*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-169 (-215))) (-5 *5 (-568)) (-5 *6 (-1143)) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4289 (*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-169 (-215))) (-5 *5 (-568)) (-5 *6 (-1143)) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4294 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4301 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4307 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4312 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-2940 (*1 *2 *3 *4 *5 *3 *6 *3) (-12 (-5 *3 (-568)) (-5 *5 (-169 (-215))) (-5 *6 (-1143)) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-2944 (*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-1143)) (-5 *4 (-169 (-215))) (-5 *5 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-2948 (*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-1143)) (-5 *4 (-169 (-215))) (-5 *5 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4040 (*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-169 (-215))) (-5 *5 (-568)) (-5 *6 (-1143)) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4046 (*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-169 (-215))) (-5 *5 (-568)) (-5 *6 (-1143)) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4052 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4058 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4065 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4071 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4076 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4084 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4090 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4098 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4105 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4112 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4120 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4127 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4135 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4140 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4148 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4155 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4161 (*1 *2 *3 *4) (-12 (-5 *3 (-169 (-215))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(-10 -7 (-15 -4161 ((-1035) (-169 (-215)) (-568))) (-15 -4155 ((-1035) (-215) (-568))) (-15 -4148 ((-1035) (-215) (-568))) (-15 -4140 ((-1035) (-215) (-568))) (-15 -4135 ((-1035) (-215) (-568))) (-15 -4127 ((-1035) (-215) (-568))) (-15 -4120 ((-1035) (-215) (-215) (-215) (-568))) (-15 -4112 ((-1035) (-215) (-568))) (-15 -4105 ((-1035) (-215) (-568))) (-15 -4098 ((-1035) (-215) (-568))) (-15 -4090 ((-1035) (-215) (-568))) (-15 -4084 ((-1035) (-215) (-568))) (-15 -4076 ((-1035) (-215) (-568))) (-15 -4071 ((-1035) (-215) (-568))) (-15 -4065 ((-1035) (-215) (-568))) (-15 -4058 ((-1035) (-215) (-568))) (-15 -4052 ((-1035) (-215) (-568))) (-15 -4046 ((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568))) (-15 -4040 ((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568))) (-15 -2948 ((-1035) (-1143) (-169 (-215)) (-1143) (-568))) (-15 -2944 ((-1035) (-1143) (-169 (-215)) (-1143) (-568))) (-15 -2940 ((-1035) (-568) (-215) (-169 (-215)) (-568) (-1143) (-568))) (-15 -4312 ((-1035) (-215) (-568))) (-15 -4307 ((-1035) (-215) (-568))) (-15 -4301 ((-1035) (-215) (-568))) (-15 -4294 ((-1035) (-215) (-568))) (-15 -4289 ((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568))) (-15 -4282 ((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568))) (-15 -4268 ((-1035) (-215) (-568))) (-15 -4256 ((-1035) (-215) (-568))) (-15 -4232 ((-1035) (-215) (-568))) (-15 -4219 ((-1035) (-215) (-568))) (-15 -4208 ((-1035) (-215) (-568))) (-15 -4196 ((-1035) (-215) (-568))) (-15 -4188 ((-1035) (-215) (-215) (-568))) (-15 -4182 ((-1035) (-215) (-215) (-215) (-568))) (-15 -4175 ((-1035) (-215) (-215) (-215) (-568))) (-15 -4170 ((-1035) (-215) (-215) (-215) (-215) (-568)))) 
-((-2603 (((-1249)) 18)) (-1450 (((-1143)) 22)) (-2908 (((-1143)) 21)) (-3273 (((-1094) (-1161) (-679 (-568))) 35) (((-1094) (-1161) (-679 (-215))) 31)) (-1587 (((-121)) 16)) (-3009 (((-1143) (-1143)) 25))) 
-(((-751) (-10 -7 (-15 -2908 ((-1143))) (-15 -1450 ((-1143))) (-15 -3009 ((-1143) (-1143))) (-15 -3273 ((-1094) (-1161) (-679 (-215)))) (-15 -3273 ((-1094) (-1161) (-679 (-568)))) (-15 -1587 ((-121))) (-15 -2603 ((-1249))))) (T -751)) 
-((-2603 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-751)))) (-1587 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-751)))) (-3273 (*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-679 (-568))) (-5 *2 (-1094)) (-5 *1 (-751)))) (-3273 (*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-679 (-215))) (-5 *2 (-1094)) (-5 *1 (-751)))) (-3009 (*1 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-751)))) (-1450 (*1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-751)))) (-2908 (*1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-751))))) 
-(-10 -7 (-15 -2908 ((-1143))) (-15 -1450 ((-1143))) (-15 -3009 ((-1143) (-1143))) (-15 -3273 ((-1094) (-1161) (-679 (-215)))) (-15 -3273 ((-1094) (-1161) (-679 (-568)))) (-15 -1587 ((-121))) (-15 -2603 ((-1249)))) 
-((-2353 (($ $ $) 10)) (-3882 (($ $ $ $) 9)) (-3500 (($ $ $) 12))) 
-(((-752 |#1|) (-10 -8 (-15 -3500 (|#1| |#1| |#1|)) (-15 -2353 (|#1| |#1| |#1|)) (-15 -3882 (|#1| |#1| |#1| |#1|))) (-753)) (T -752)) 
-NIL 
-(-10 -8 (-15 -3500 (|#1| |#1| |#1|)) (-15 -2353 (|#1| |#1| |#1|)) (-15 -3882 (|#1| |#1| |#1| |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-3551 (($ $ (-917)) 27)) (-4222 (($ $ (-917)) 28)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2353 (($ $ $) 24)) (-2745 (((-850) $) 11)) (-3882 (($ $ $ $) 25)) (-3500 (($ $ $) 23)) (-3056 (($) 17 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 29)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 26))) 
+((-1666 (((-1035) (-679 (-215)) (-568) (-121) (-568)) 24)) (-1671 (((-1035) (-679 (-215)) (-568) (-121) (-568)) 23))) 
+(((-737) (-10 -7 (-15 -1671 ((-1035) (-679 (-215)) (-568) (-121) (-568))) (-15 -1666 ((-1035) (-679 (-215)) (-568) (-121) (-568))))) (T -737)) 
+((-1666 (*1 *2 *3 *4 *5 *4) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *5 (-121)) (-5 *2 (-1035)) (-5 *1 (-737)))) (-1671 (*1 *2 *3 *4 *5 *4) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *5 (-121)) (-5 *2 (-1035)) (-5 *1 (-737))))) 
+(-10 -7 (-15 -1671 ((-1035) (-679 (-215)) (-568) (-121) (-568))) (-15 -1666 ((-1035) (-679 (-215)) (-568) (-121) (-568)))) 
+((-1682 (((-1035) (-568) (-568) (-568) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-79 FCN)))) 43)) (-3934 (((-1035) (-568) (-568) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-86 FCN)))) 39)) (-3942 (((-1035) (-215) (-215) (-215) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) 32))) 
+(((-738) (-10 -7 (-15 -3942 ((-1035) (-215) (-215) (-215) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478))))) (-15 -3934 ((-1035) (-568) (-568) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-86 FCN))))) (-15 -1682 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-79 FCN))))))) (T -738)) 
+((-1682 (*1 *2 *3 *3 *3 *4 *5 *3 *6) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-79 FCN)))) (-5 *2 (-1035)) (-5 *1 (-738)))) (-3934 (*1 *2 *3 *3 *4 *5 *3 *6) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-86 FCN)))) (-5 *2 (-1035)) (-5 *1 (-738)))) (-3942 (*1 *2 *3 *3 *3 *3 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) (-5 *2 (-1035)) (-5 *1 (-738))))) 
+(-10 -7 (-15 -3942 ((-1035) (-215) (-215) (-215) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478))))) (-15 -3934 ((-1035) (-568) (-568) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-86 FCN))))) (-15 -1682 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-79 FCN)))))) 
+((-3950 (((-1035) (-568) (-568) (-679 (-215)) (-568)) 33)) (-3958 (((-1035) (-568) (-568) (-679 (-215)) (-568)) 32)) (-3965 (((-1035) (-568) (-679 (-215)) (-568)) 31)) (-3974 (((-1035) (-568) (-679 (-215)) (-568)) 30)) (-3982 (((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568)) 29)) (-3990 (((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568)) 28)) (-3998 (((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-568)) 27)) (-4006 (((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-568)) 26)) (-4014 (((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568)) 23)) (-4023 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568)) 22)) (-4030 (((-1035) (-568) (-679 (-215)) (-568)) 21)) (-4036 (((-1035) (-568) (-679 (-215)) (-568)) 20))) 
+(((-739) (-10 -7 (-15 -4036 ((-1035) (-568) (-679 (-215)) (-568))) (-15 -4030 ((-1035) (-568) (-679 (-215)) (-568))) (-15 -4023 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -4014 ((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -4006 ((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3998 ((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3990 ((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3982 ((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3974 ((-1035) (-568) (-679 (-215)) (-568))) (-15 -3965 ((-1035) (-568) (-679 (-215)) (-568))) (-15 -3958 ((-1035) (-568) (-568) (-679 (-215)) (-568))) (-15 -3950 ((-1035) (-568) (-568) (-679 (-215)) (-568))))) (T -739)) 
+((-3950 (*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739)))) (-3958 (*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739)))) (-3965 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739)))) (-3974 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739)))) (-3982 (*1 *2 *3 *3 *4 *5 *5 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-1143)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739)))) (-3990 (*1 *2 *3 *3 *4 *5 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-1143)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739)))) (-3998 (*1 *2 *3 *3 *4 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-1143)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739)))) (-4006 (*1 *2 *3 *3 *4 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-1143)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739)))) (-4014 (*1 *2 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739)))) (-4023 (*1 *2 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739)))) (-4030 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739)))) (-4036 (*1 *2 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739))))) 
+(-10 -7 (-15 -4036 ((-1035) (-568) (-679 (-215)) (-568))) (-15 -4030 ((-1035) (-568) (-679 (-215)) (-568))) (-15 -4023 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -4014 ((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -4006 ((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3998 ((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3990 ((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3982 ((-1035) (-568) (-568) (-1143) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3974 ((-1035) (-568) (-679 (-215)) (-568))) (-15 -3965 ((-1035) (-568) (-679 (-215)) (-568))) (-15 -3958 ((-1035) (-568) (-568) (-679 (-215)) (-568))) (-15 -3950 ((-1035) (-568) (-568) (-679 (-215)) (-568)))) 
+((-3670 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568) (-215) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-83 FUNCTN)))) 52)) (-3677 (((-1035) (-679 (-215)) (-679 (-215)) (-568) (-568)) 51)) (-3688 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-83 FUNCTN)))) 50)) (-3696 (((-1035) (-215) (-215) (-568) (-568) (-568) (-568)) 46)) (-3703 (((-1035) (-215) (-215) (-568) (-215) (-568) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G)))) 45)) (-4216 (((-1035) (-215) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G)))) 44)) (-4227 (((-1035) (-215) (-215) (-215) (-215) (-568) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G)))) 43)) (-4240 (((-1035) (-215) (-215) (-215) (-568) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G)))) 42)) (-4246 (((-1035) (-215) (-568) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) 38)) (-4252 (((-1035) (-215) (-215) (-568) (-679 (-215)) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) 37)) (-4264 (((-1035) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) 33)) (-4277 (((-1035) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) 32))) 
+(((-740) (-10 -7 (-15 -4277 ((-1035) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478))))) (-15 -4264 ((-1035) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478))))) (-15 -4252 ((-1035) (-215) (-215) (-568) (-679 (-215)) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478))))) (-15 -4246 ((-1035) (-215) (-568) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478))))) (-15 -4240 ((-1035) (-215) (-215) (-215) (-568) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G))))) (-15 -4227 ((-1035) (-215) (-215) (-215) (-215) (-568) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G))))) (-15 -4216 ((-1035) (-215) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G))))) (-15 -3703 ((-1035) (-215) (-215) (-568) (-215) (-568) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G))))) (-15 -3696 ((-1035) (-215) (-215) (-568) (-568) (-568) (-568))) (-15 -3688 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-83 FUNCTN))))) (-15 -3677 ((-1035) (-679 (-215)) (-679 (-215)) (-568) (-568))) (-15 -3670 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568) (-215) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-83 FUNCTN))))))) (T -740)) 
+((-3670 (*1 *2 *3 *4 *4 *3 *5 *3 *3 *4 *3 *6) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-83 FUNCTN)))) (-5 *2 (-1035)) (-5 *1 (-740)))) (-3677 (*1 *2 *3 *3 *4 *4) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-740)))) (-3688 (*1 *2 *3 *4 *4 *3 *5 *3 *3 *3 *6) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-83 FUNCTN)))) (-5 *2 (-1035)) (-5 *1 (-740)))) (-3696 (*1 *2 *3 *3 *4 *4 *4 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-740)))) (-3703 (*1 *2 *3 *3 *4 *3 *4 *4 *4 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G)))) (-5 *2 (-1035)) (-5 *1 (-740)))) (-4216 (*1 *2 *3 *3 *3 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G)))) (-5 *2 (-1035)) (-5 *1 (-740)))) (-4227 (*1 *2 *3 *3 *3 *3 *4 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G)))) (-5 *2 (-1035)) (-5 *1 (-740)))) (-4240 (*1 *2 *3 *3 *3 *4 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G)))) (-5 *2 (-1035)) (-5 *1 (-740)))) (-4246 (*1 *2 *3 *4 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) (-5 *2 (-1035)) (-5 *1 (-740)))) (-4252 (*1 *2 *3 *3 *4 *5 *3 *3 *4 *4 *4 *6) (-12 (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-740)))) (-4264 (*1 *2 *3 *3 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) (-5 *2 (-1035)) (-5 *1 (-740)))) (-4277 (*1 *2 *3 *3 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) (-5 *2 (-1035)) (-5 *1 (-740))))) 
+(-10 -7 (-15 -4277 ((-1035) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478))))) (-15 -4264 ((-1035) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478))))) (-15 -4252 ((-1035) (-215) (-215) (-568) (-679 (-215)) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478))))) (-15 -4246 ((-1035) (-215) (-568) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478))))) (-15 -4240 ((-1035) (-215) (-215) (-215) (-568) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G))))) (-15 -4227 ((-1035) (-215) (-215) (-215) (-215) (-568) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G))))) (-15 -4216 ((-1035) (-215) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G))))) (-15 -3703 ((-1035) (-215) (-215) (-568) (-215) (-568) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G))))) (-15 -3696 ((-1035) (-215) (-215) (-568) (-568) (-568) (-568))) (-15 -3688 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568) (-215) (-568) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-83 FUNCTN))))) (-15 -3677 ((-1035) (-679 (-215)) (-679 (-215)) (-568) (-568))) (-15 -3670 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568) (-215) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-83 FUNCTN)))))) 
+((-3717 (((-1035) (-568) (-568) (-568) (-568) (-215) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-80 FCN JACOBF JACEPS))) (-3 (|:| |fn| (-390)) (|:| |fp| (-81 G JACOBG JACGEP)))) 76)) (-3724 (((-1035) (-679 (-215)) (-568) (-568) (-215) (-568) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-92 BDYVAL))) (-390) (-390)) 69) (((-1035) (-679 (-215)) (-568) (-568) (-215) (-568) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-92 BDYVAL)))) 68)) (-3731 (((-1035) (-215) (-215) (-568) (-215) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-89 FCNF))) (-3 (|:| |fn| (-390)) (|:| |fp| (-90 FCNG)))) 57)) (-3738 (((-1035) (-679 (-215)) (-679 (-215)) (-568) (-215) (-215) (-215) (-568) (-568) (-568) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN)))) 50)) (-3746 (((-1035) (-215) (-568) (-568) (-1143) (-568) (-215) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-76 PEDERV))) (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT)))) 49)) (-3754 (((-1035) (-215) (-568) (-568) (-215) (-1143) (-215) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT)))) 45)) (-3761 (((-1035) (-215) (-568) (-568) (-215) (-215) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN)))) 42)) (-3771 (((-1035) (-215) (-568) (-568) (-568) (-215) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT)))) 38))) 
+(((-741) (-10 -7 (-15 -3771 ((-1035) (-215) (-568) (-568) (-568) (-215) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT))))) (-15 -3761 ((-1035) (-215) (-568) (-568) (-215) (-215) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))))) (-15 -3754 ((-1035) (-215) (-568) (-568) (-215) (-1143) (-215) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT))))) (-15 -3746 ((-1035) (-215) (-568) (-568) (-1143) (-568) (-215) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-76 PEDERV))) (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT))))) (-15 -3738 ((-1035) (-679 (-215)) (-679 (-215)) (-568) (-215) (-215) (-215) (-568) (-568) (-568) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))))) (-15 -3731 ((-1035) (-215) (-215) (-568) (-215) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-89 FCNF))) (-3 (|:| |fn| (-390)) (|:| |fp| (-90 FCNG))))) (-15 -3724 ((-1035) (-679 (-215)) (-568) (-568) (-215) (-568) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-92 BDYVAL))))) (-15 -3724 ((-1035) (-679 (-215)) (-568) (-568) (-215) (-568) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-92 BDYVAL))) (-390) (-390))) (-15 -3717 ((-1035) (-568) (-568) (-568) (-568) (-215) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-80 FCN JACOBF JACEPS))) (-3 (|:| |fn| (-390)) (|:| |fp| (-81 G JACOBG JACGEP))))))) (T -741)) 
+((-3717 (*1 *2 *3 *3 *3 *3 *4 *3 *3 *3 *3 *3 *3 *5 *5 *4 *3 *6 *7) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-80 FCN JACOBF JACEPS)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-81 G JACOBG JACGEP)))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-741)))) (-3724 (*1 *2 *3 *4 *4 *5 *4 *4 *5 *5 *3 *4 *4 *6 *7 *8 *8) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *5 (-215)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-66 COEFFN)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-92 BDYVAL)))) (-5 *8 (-390)) (-5 *2 (-1035)) (-5 *1 (-741)))) (-3724 (*1 *2 *3 *4 *4 *5 *4 *4 *5 *5 *3 *4 *4 *6 *7) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *5 (-215)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-66 COEFFN)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-92 BDYVAL)))) (-5 *2 (-1035)) (-5 *1 (-741)))) (-3731 (*1 *2 *3 *3 *4 *3 *4 *4 *4 *5 *5 *5 *5 *4 *4 *6 *7) (-12 (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-89 FCNF)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-90 FCNG)))) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-741)))) (-3738 (*1 *2 *3 *3 *4 *5 *5 *5 *4 *4 *4 *3 *4 *4 *6) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *5 (-215)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN)))) (-5 *2 (-1035)) (-5 *1 (-741)))) (-3746 (*1 *2 *3 *4 *4 *5 *4 *3 *6 *3 *4 *7 *8 *9 *10) (-12 (-5 *4 (-568)) (-5 *5 (-1143)) (-5 *6 (-679 (-215))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G)))) (-5 *8 (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN)))) (-5 *9 (-3 (|:| |fn| (-390)) (|:| |fp| (-76 PEDERV)))) (-5 *10 (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT)))) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-741)))) (-3754 (*1 *2 *3 *4 *4 *3 *5 *3 *6 *4 *7 *8 *9) (-12 (-5 *4 (-568)) (-5 *5 (-1143)) (-5 *6 (-679 (-215))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G)))) (-5 *8 (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN)))) (-5 *9 (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT)))) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-741)))) (-3761 (*1 *2 *3 *4 *4 *3 *3 *5 *3 *4 *6 *7) (-12 (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN)))) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-741)))) (-3771 (*1 *2 *3 *4 *4 *4 *3 *5 *3 *4 *6 *7) (-12 (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT)))) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-741))))) 
+(-10 -7 (-15 -3771 ((-1035) (-215) (-568) (-568) (-568) (-215) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT))))) (-15 -3761 ((-1035) (-215) (-568) (-568) (-215) (-215) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))))) (-15 -3754 ((-1035) (-215) (-568) (-568) (-215) (-1143) (-215) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT))))) (-15 -3746 ((-1035) (-215) (-568) (-568) (-1143) (-568) (-215) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G))) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-76 PEDERV))) (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT))))) (-15 -3738 ((-1035) (-679 (-215)) (-679 (-215)) (-568) (-215) (-215) (-215) (-568) (-568) (-568) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN))))) (-15 -3731 ((-1035) (-215) (-215) (-568) (-215) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-89 FCNF))) (-3 (|:| |fn| (-390)) (|:| |fp| (-90 FCNG))))) (-15 -3724 ((-1035) (-679 (-215)) (-568) (-568) (-215) (-568) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-92 BDYVAL))))) (-15 -3724 ((-1035) (-679 (-215)) (-568) (-568) (-215) (-568) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-66 COEFFN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-92 BDYVAL))) (-390) (-390))) (-15 -3717 ((-1035) (-568) (-568) (-568) (-568) (-215) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-80 FCN JACOBF JACEPS))) (-3 (|:| |fn| (-390)) (|:| |fp| (-81 G JACOBG JACGEP)))))) 
+((-3816 (((-1035) (-215) (-215) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-215) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-215) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-666 (-215)) (-568)) 45)) (-3825 (((-1035) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-1143) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-87 PDEF))) (-3 (|:| |fn| (-390)) (|:| |fp| (-88 BNDY)))) 41)) (-3834 (((-1035) (-568) (-568) (-568) (-568) (-215) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568)) 23))) 
+(((-742) (-10 -7 (-15 -3834 ((-1035) (-568) (-568) (-568) (-568) (-215) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3825 ((-1035) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-1143) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-87 PDEF))) (-3 (|:| |fn| (-390)) (|:| |fp| (-88 BNDY))))) (-15 -3816 ((-1035) (-215) (-215) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-215) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-215) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-666 (-215)) (-568))))) (T -742)) 
+((-3816 (*1 *2 *3 *3 *4 *4 *5 *5 *3 *3 *4 *4 *5 *5 *3 *3 *4 *4 *5 *5 *3 *4 *4 *4 *6 *4) (-12 (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-666 (-215))) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-742)))) (-3825 (*1 *2 *3 *3 *3 *3 *4 *4 *4 *5 *4 *6 *7) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-1143)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-87 PDEF)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-88 BNDY)))) (-5 *2 (-1035)) (-5 *1 (-742)))) (-3834 (*1 *2 *3 *3 *3 *3 *4 *3 *5 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-742))))) 
+(-10 -7 (-15 -3834 ((-1035) (-568) (-568) (-568) (-568) (-215) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3825 ((-1035) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-1143) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-87 PDEF))) (-3 (|:| |fn| (-390)) (|:| |fp| (-88 BNDY))))) (-15 -3816 ((-1035) (-215) (-215) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-215) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-215) (-568) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-666 (-215)) (-568)))) 
+((-2367 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-679 (-215)) (-215) (-215) (-568)) 35)) (-1704 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-215) (-215) (-568)) 34)) (-1805 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-679 (-215)) (-215) (-215) (-568)) 33)) (-1710 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568)) 29)) (-1717 (((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568)) 28)) (-1724 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-215) (-568)) 27)) (-1731 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-568)) 23)) (-1738 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-568)) 22)) (-1745 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568)) 21)) (-1751 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568) (-568) (-568)) 20))) 
+(((-743) (-10 -7 (-15 -1751 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568) (-568) (-568))) (-15 -1745 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1738 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-568))) (-15 -1731 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-568))) (-15 -1724 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-215) (-568))) (-15 -1717 ((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1710 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1805 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-679 (-215)) (-215) (-215) (-568))) (-15 -1704 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-215) (-215) (-568))) (-15 -2367 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-679 (-215)) (-215) (-215) (-568))))) (T -743)) 
+((-2367 (*1 *2 *3 *4 *4 *4 *5 *4 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *2 (-1035)) (-5 *1 (-743)))) (-1704 (*1 *2 *3 *4 *4 *4 *3 *3 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *2 (-1035)) (-5 *1 (-743)))) (-1805 (*1 *2 *3 *4 *4 *4 *5 *4 *6 *6 *3) (-12 (-5 *4 (-679 (-215))) (-5 *5 (-679 (-568))) (-5 *6 (-215)) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-743)))) (-1710 (*1 *2 *3 *4 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-743)))) (-1717 (*1 *2 *3 *3 *4 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-743)))) (-1724 (*1 *2 *3 *4 *4 *4 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *2 (-1035)) (-5 *1 (-743)))) (-1731 (*1 *2 *3 *4 *4 *4 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-743)))) (-1738 (*1 *2 *3 *4 *4 *4 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-743)))) (-1745 (*1 *2 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-743)))) (-1751 (*1 *2 *3 *4 *4 *3 *3 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-743))))) 
+(-10 -7 (-15 -1751 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568) (-568) (-568))) (-15 -1745 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1738 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-568))) (-15 -1731 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-568))) (-15 -1724 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-215) (-568))) (-15 -1717 ((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1710 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1805 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-679 (-215)) (-215) (-215) (-568))) (-15 -1704 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-215) (-215) (-568))) (-15 -2367 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-679 (-215)) (-215) (-215) (-568)))) 
+((-1756 (((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-568) (-568) (-568)) 45)) (-1761 (((-1035) (-568) (-568) (-568) (-215) (-679 (-215)) (-679 (-215)) (-568)) 44)) (-1766 (((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-568)) 43)) (-1773 (((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568)) 42)) (-1779 (((-1035) (-1143) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-568)) 41)) (-1784 (((-1035) (-1143) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-568)) 40)) (-1790 (((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-568) (-568) (-568) (-215) (-679 (-215)) (-568)) 39)) (-1795 (((-1035) (-1143) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-568))) 38)) (-3588 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568)) 35)) (-3144 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568)) 34)) (-3150 (((-1035) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568)) 33)) (-3156 (((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568)) 32)) (-3162 (((-1035) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-215) (-568)) 31)) (-3169 (((-1035) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-215) (-568) (-568) (-568)) 30)) (-3780 (((-1035) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-568) (-568) (-568)) 29)) (-4204 (((-1035) (-568) (-568) (-568) (-215) (-215) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-568) (-679 (-568)) (-568) (-568) (-568)) 28)) (-1657 (((-1035) (-568) (-679 (-215)) (-215) (-568)) 24)) (-1676 (((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568)) 20))) 
+(((-744) (-10 -7 (-15 -1676 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1657 ((-1035) (-568) (-679 (-215)) (-215) (-568))) (-15 -4204 ((-1035) (-568) (-568) (-568) (-215) (-215) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-568) (-679 (-568)) (-568) (-568) (-568))) (-15 -3780 ((-1035) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-568) (-568) (-568))) (-15 -3169 ((-1035) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-215) (-568) (-568) (-568))) (-15 -3162 ((-1035) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-215) (-568))) (-15 -3156 ((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3150 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568))) (-15 -3144 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568))) (-15 -3588 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1795 ((-1035) (-1143) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-568)))) (-15 -1790 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-568) (-568) (-568) (-215) (-679 (-215)) (-568))) (-15 -1784 ((-1035) (-1143) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-568))) (-15 -1779 ((-1035) (-1143) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1773 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1766 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-568))) (-15 -1761 ((-1035) (-568) (-568) (-568) (-215) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1756 ((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-568) (-568) (-568))))) (T -744)) 
+((-1756 (*1 *2 *3 *3 *4 *4 *3 *4 *4 *3 *3 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-744)))) (-1761 (*1 *2 *3 *3 *3 *4 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-1766 (*1 *2 *3 *3 *3 *3 *4 *4 *4 *4 *4 *3 *3 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-744)))) (-1773 (*1 *2 *3 *3 *3 *4 *4 *4 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-744)))) (-1779 (*1 *2 *3 *4 *5 *5 *5 *5 *6 *4 *4 *4 *4 *4 *5 *4 *5 *5 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-215)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-1784 (*1 *2 *3 *4 *5 *4 *5 *5 *6 *4 *4 *4 *4 *4 *5 *4 *5 *5 *7 *4) (-12 (-5 *3 (-1143)) (-5 *5 (-679 (-215))) (-5 *6 (-215)) (-5 *7 (-679 (-568))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-1790 (*1 *2 *3 *3 *3 *4 *4 *4 *4 *4 *5 *3 *3 *3 *6 *4 *3) (-12 (-5 *4 (-679 (-215))) (-5 *5 (-679 (-568))) (-5 *6 (-215)) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-1795 (*1 *2 *3 *4 *5 *5 *5 *6 *4 *4 *4 *5 *4 *5 *7) (-12 (-5 *3 (-1143)) (-5 *5 (-679 (-215))) (-5 *6 (-215)) (-5 *7 (-679 (-568))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-3588 (*1 *2 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-744)))) (-3144 (*1 *2 *3 *4 *4 *5 *3 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-3150 (*1 *2 *3 *4 *4 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-3156 (*1 *2 *3 *3 *4 *4 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-744)))) (-3162 (*1 *2 *3 *4 *4 *5 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-3169 (*1 *2 *3 *4 *4 *5 *3 *3 *4 *3 *3 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-3780 (*1 *2 *3 *4 *4 *5 *3 *3 *3 *3 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-4204 (*1 *2 *3 *3 *3 *4 *4 *5 *5 *5 *3 *5 *5 *3 *6 *3 *3 *3) (-12 (-5 *5 (-679 (-215))) (-5 *6 (-679 (-568))) (-5 *3 (-568)) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-1657 (*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *2 (-1035)) (-5 *1 (-744)))) (-1676 (*1 *2 *3 *3 *3 *4 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-744))))) 
+(-10 -7 (-15 -1676 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1657 ((-1035) (-568) (-679 (-215)) (-215) (-568))) (-15 -4204 ((-1035) (-568) (-568) (-568) (-215) (-215) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-568) (-679 (-568)) (-568) (-568) (-568))) (-15 -3780 ((-1035) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-568) (-568) (-568))) (-15 -3169 ((-1035) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-215) (-568) (-568) (-568))) (-15 -3162 ((-1035) (-568) (-215) (-215) (-679 (-215)) (-568) (-568) (-215) (-568))) (-15 -3156 ((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3150 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568))) (-15 -3144 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568))) (-15 -3588 ((-1035) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1795 ((-1035) (-1143) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-568)))) (-15 -1790 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-568) (-568) (-568) (-215) (-679 (-215)) (-568))) (-15 -1784 ((-1035) (-1143) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-568))) (-15 -1779 ((-1035) (-1143) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-215) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1773 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1766 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-568))) (-15 -1761 ((-1035) (-568) (-568) (-568) (-215) (-679 (-215)) (-679 (-215)) (-568))) (-15 -1756 ((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568) (-679 (-215)) (-679 (-215)) (-568) (-568) (-568)))) 
+((-3174 (((-1035) (-568) (-568) (-568) (-215) (-679 (-215)) (-568) (-679 (-215)) (-568)) 63)) (-3183 (((-1035) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-121) (-215) (-568) (-215) (-215) (-121) (-215) (-215) (-215) (-215) (-121) (-568) (-568) (-568) (-568) (-568) (-215) (-215) (-215) (-568) (-568) (-568) (-568) (-568) (-679 (-568)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-85 CONFUN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-82 OBJFUN)))) 62)) (-3190 (((-1035) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-215) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-121) (-121) (-121) (-568) (-568) (-679 (-215)) (-679 (-568)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-70 QPHESS)))) 58)) (-3197 (((-1035) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-121) (-568) (-568) (-679 (-215)) (-568)) 51)) (-3202 (((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-71 FUNCT1)))) 50)) (-3213 (((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-68 LSFUN2)))) 46)) (-3221 (((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-84 LSFUN1)))) 42)) (-3230 (((-1035) (-568) (-215) (-215) (-568) (-215) (-121) (-215) (-215) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-82 OBJFUN)))) 38))) 
+(((-745) (-10 -7 (-15 -3230 ((-1035) (-568) (-215) (-215) (-568) (-215) (-121) (-215) (-215) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-82 OBJFUN))))) (-15 -3221 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-84 LSFUN1))))) (-15 -3213 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-68 LSFUN2))))) (-15 -3202 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-71 FUNCT1))))) (-15 -3197 ((-1035) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-121) (-568) (-568) (-679 (-215)) (-568))) (-15 -3190 ((-1035) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-215) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-121) (-121) (-121) (-568) (-568) (-679 (-215)) (-679 (-568)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-70 QPHESS))))) (-15 -3183 ((-1035) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-121) (-215) (-568) (-215) (-215) (-121) (-215) (-215) (-215) (-215) (-121) (-568) (-568) (-568) (-568) (-568) (-215) (-215) (-215) (-568) (-568) (-568) (-568) (-568) (-679 (-568)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-85 CONFUN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-82 OBJFUN))))) (-15 -3174 ((-1035) (-568) (-568) (-568) (-215) (-679 (-215)) (-568) (-679 (-215)) (-568))))) (T -745)) 
+((-3174 (*1 *2 *3 *3 *3 *4 *5 *3 *5 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-745)))) (-3183 (*1 *2 *3 *3 *3 *3 *3 *3 *4 *4 *4 *3 *3 *5 *6 *3 *6 *6 *5 *6 *6 *6 *6 *5 *3 *3 *3 *3 *3 *6 *6 *6 *3 *3 *3 *3 *3 *7 *4 *4 *4 *4 *3 *8 *9) (-12 (-5 *4 (-679 (-215))) (-5 *5 (-121)) (-5 *6 (-215)) (-5 *7 (-679 (-568))) (-5 *8 (-3 (|:| |fn| (-390)) (|:| |fp| (-85 CONFUN)))) (-5 *9 (-3 (|:| |fn| (-390)) (|:| |fp| (-82 OBJFUN)))) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-745)))) (-3190 (*1 *2 *3 *3 *3 *3 *3 *3 *3 *3 *4 *5 *5 *5 *5 *5 *5 *6 *6 *6 *3 *3 *5 *7 *3 *8) (-12 (-5 *5 (-679 (-215))) (-5 *6 (-121)) (-5 *7 (-679 (-568))) (-5 *8 (-3 (|:| |fn| (-390)) (|:| |fp| (-70 QPHESS)))) (-5 *3 (-568)) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-745)))) (-3197 (*1 *2 *3 *3 *3 *3 *3 *3 *4 *4 *4 *4 *5 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-121)) (-5 *2 (-1035)) (-5 *1 (-745)))) (-3202 (*1 *2 *3 *3 *3 *3 *4 *4 *4 *3 *5) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-71 FUNCT1)))) (-5 *2 (-1035)) (-5 *1 (-745)))) (-3213 (*1 *2 *3 *3 *3 *3 *4 *3 *5) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-68 LSFUN2)))) (-5 *2 (-1035)) (-5 *1 (-745)))) (-3221 (*1 *2 *3 *3 *3 *3 *4 *3 *5) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-84 LSFUN1)))) (-5 *2 (-1035)) (-5 *1 (-745)))) (-3230 (*1 *2 *3 *4 *4 *3 *4 *5 *4 *4 *3 *3 *3 *3 *6 *3 *7) (-12 (-5 *3 (-568)) (-5 *5 (-121)) (-5 *6 (-679 (-215))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-82 OBJFUN)))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-745))))) 
+(-10 -7 (-15 -3230 ((-1035) (-568) (-215) (-215) (-568) (-215) (-121) (-215) (-215) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-82 OBJFUN))))) (-15 -3221 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-84 LSFUN1))))) (-15 -3213 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-68 LSFUN2))))) (-15 -3202 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-71 FUNCT1))))) (-15 -3197 ((-1035) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-121) (-568) (-568) (-679 (-215)) (-568))) (-15 -3190 ((-1035) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-215) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-121) (-121) (-121) (-568) (-568) (-679 (-215)) (-679 (-568)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-70 QPHESS))))) (-15 -3183 ((-1035) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-568) (-121) (-215) (-568) (-215) (-215) (-121) (-215) (-215) (-215) (-215) (-121) (-568) (-568) (-568) (-568) (-568) (-215) (-215) (-215) (-568) (-568) (-568) (-568) (-568) (-679 (-568)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-85 CONFUN))) (-3 (|:| |fn| (-390)) (|:| |fp| (-82 OBJFUN))))) (-15 -3174 ((-1035) (-568) (-568) (-568) (-215) (-679 (-215)) (-568) (-679 (-215)) (-568)))) 
+((-3239 (((-1035) (-1143) (-568) (-568) (-568) (-568) (-679 (-169 (-215))) (-679 (-169 (-215))) (-568)) 46)) (-3244 (((-1035) (-1143) (-1143) (-568) (-568) (-679 (-169 (-215))) (-568) (-679 (-169 (-215))) (-568) (-568) (-679 (-169 (-215))) (-568)) 45)) (-3252 (((-1035) (-568) (-568) (-568) (-679 (-169 (-215))) (-568)) 44)) (-3260 (((-1035) (-1143) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568)) 40)) (-3268 (((-1035) (-1143) (-1143) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-568) (-568) (-679 (-215)) (-568)) 39)) (-3278 (((-1035) (-568) (-568) (-568) (-679 (-215)) (-568)) 36)) (-3285 (((-1035) (-568) (-679 (-215)) (-568) (-679 (-568)) (-568)) 35)) (-3293 (((-1035) (-568) (-568) (-568) (-568) (-634 (-121)) (-679 (-215)) (-679 (-568)) (-679 (-568)) (-215) (-215) (-568)) 34)) (-3305 (((-1035) (-568) (-568) (-568) (-679 (-568)) (-679 (-568)) (-679 (-568)) (-679 (-568)) (-121) (-215) (-121) (-679 (-568)) (-679 (-215)) (-568)) 33)) (-3312 (((-1035) (-568) (-568) (-568) (-568) (-215) (-121) (-121) (-634 (-121)) (-679 (-215)) (-679 (-568)) (-679 (-568)) (-568)) 32))) 
+(((-746) (-10 -7 (-15 -3312 ((-1035) (-568) (-568) (-568) (-568) (-215) (-121) (-121) (-634 (-121)) (-679 (-215)) (-679 (-568)) (-679 (-568)) (-568))) (-15 -3305 ((-1035) (-568) (-568) (-568) (-679 (-568)) (-679 (-568)) (-679 (-568)) (-679 (-568)) (-121) (-215) (-121) (-679 (-568)) (-679 (-215)) (-568))) (-15 -3293 ((-1035) (-568) (-568) (-568) (-568) (-634 (-121)) (-679 (-215)) (-679 (-568)) (-679 (-568)) (-215) (-215) (-568))) (-15 -3285 ((-1035) (-568) (-679 (-215)) (-568) (-679 (-568)) (-568))) (-15 -3278 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-568))) (-15 -3268 ((-1035) (-1143) (-1143) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-568) (-568) (-679 (-215)) (-568))) (-15 -3260 ((-1035) (-1143) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3252 ((-1035) (-568) (-568) (-568) (-679 (-169 (-215))) (-568))) (-15 -3244 ((-1035) (-1143) (-1143) (-568) (-568) (-679 (-169 (-215))) (-568) (-679 (-169 (-215))) (-568) (-568) (-679 (-169 (-215))) (-568))) (-15 -3239 ((-1035) (-1143) (-568) (-568) (-568) (-568) (-679 (-169 (-215))) (-679 (-169 (-215))) (-568))))) (T -746)) 
+((-3239 (*1 *2 *3 *4 *4 *4 *4 *5 *5 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-169 (-215)))) (-5 *2 (-1035)) (-5 *1 (-746)))) (-3244 (*1 *2 *3 *3 *4 *4 *5 *4 *5 *4 *4 *5 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-169 (-215)))) (-5 *2 (-1035)) (-5 *1 (-746)))) (-3252 (*1 *2 *3 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-169 (-215)))) (-5 *2 (-1035)) (-5 *1 (-746)))) (-3260 (*1 *2 *3 *4 *4 *4 *4 *5 *5 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-746)))) (-3268 (*1 *2 *3 *3 *4 *4 *5 *4 *5 *4 *4 *5 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-746)))) (-3278 (*1 *2 *3 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-746)))) (-3285 (*1 *2 *3 *4 *3 *5 *3) (-12 (-5 *4 (-679 (-215))) (-5 *5 (-679 (-568))) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-746)))) (-3293 (*1 *2 *3 *3 *3 *3 *4 *5 *6 *6 *7 *7 *3) (-12 (-5 *4 (-634 (-121))) (-5 *5 (-679 (-215))) (-5 *6 (-679 (-568))) (-5 *7 (-215)) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-746)))) (-3305 (*1 *2 *3 *3 *3 *4 *4 *4 *4 *5 *6 *5 *4 *7 *3) (-12 (-5 *4 (-679 (-568))) (-5 *5 (-121)) (-5 *7 (-679 (-215))) (-5 *3 (-568)) (-5 *6 (-215)) (-5 *2 (-1035)) (-5 *1 (-746)))) (-3312 (*1 *2 *3 *3 *3 *3 *4 *5 *5 *6 *7 *8 *8 *3) (-12 (-5 *6 (-634 (-121))) (-5 *7 (-679 (-215))) (-5 *8 (-679 (-568))) (-5 *3 (-568)) (-5 *4 (-215)) (-5 *5 (-121)) (-5 *2 (-1035)) (-5 *1 (-746))))) 
+(-10 -7 (-15 -3312 ((-1035) (-568) (-568) (-568) (-568) (-215) (-121) (-121) (-634 (-121)) (-679 (-215)) (-679 (-568)) (-679 (-568)) (-568))) (-15 -3305 ((-1035) (-568) (-568) (-568) (-679 (-568)) (-679 (-568)) (-679 (-568)) (-679 (-568)) (-121) (-215) (-121) (-679 (-568)) (-679 (-215)) (-568))) (-15 -3293 ((-1035) (-568) (-568) (-568) (-568) (-634 (-121)) (-679 (-215)) (-679 (-568)) (-679 (-568)) (-215) (-215) (-568))) (-15 -3285 ((-1035) (-568) (-679 (-215)) (-568) (-679 (-568)) (-568))) (-15 -3278 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-568))) (-15 -3268 ((-1035) (-1143) (-1143) (-568) (-568) (-679 (-215)) (-568) (-679 (-215)) (-568) (-568) (-679 (-215)) (-568))) (-15 -3260 ((-1035) (-1143) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3252 ((-1035) (-568) (-568) (-568) (-679 (-169 (-215))) (-568))) (-15 -3244 ((-1035) (-1143) (-1143) (-568) (-568) (-679 (-169 (-215))) (-568) (-679 (-169 (-215))) (-568) (-568) (-679 (-169 (-215))) (-568))) (-15 -3239 ((-1035) (-1143) (-568) (-568) (-568) (-568) (-679 (-169 (-215))) (-679 (-169 (-215))) (-568)))) 
+((-2954 (((-1035) (-568) (-568) (-568) (-568) (-568) (-121) (-568) (-121) (-568) (-679 (-169 (-215))) (-679 (-169 (-215))) (-568)) 64)) (-2958 (((-1035) (-568) (-568) (-568) (-568) (-568) (-121) (-568) (-121) (-568) (-679 (-215)) (-679 (-215)) (-568)) 60)) (-2964 (((-1035) (-568) (-568) (-215) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-390)) (|:| |fp| (-73 IMAGE))) (-390)) 56) (((-1035) (-568) (-568) (-215) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-390)) (|:| |fp| (-73 IMAGE)))) 55)) (-2968 (((-1035) (-568) (-568) (-568) (-215) (-121) (-568) (-679 (-215)) (-679 (-215)) (-568)) 37)) (-2974 (((-1035) (-568) (-568) (-215) (-215) (-568) (-568) (-679 (-215)) (-568)) 33)) (-2979 (((-1035) (-679 (-215)) (-568) (-679 (-215)) (-568) (-568) (-568) (-568) (-568)) 29)) (-2983 (((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568)) 28)) (-2989 (((-1035) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568)) 27)) (-2994 (((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568)) 26)) (-2999 (((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-568)) 25)) (-3008 (((-1035) (-568) (-568) (-679 (-215)) (-568)) 24)) (-3013 (((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568)) 23)) (-3017 (((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568)) 22)) (-3022 (((-1035) (-679 (-215)) (-568) (-568) (-568) (-568)) 21)) (-3026 (((-1035) (-568) (-568) (-679 (-215)) (-568)) 20))) 
+(((-747) (-10 -7 (-15 -3026 ((-1035) (-568) (-568) (-679 (-215)) (-568))) (-15 -3022 ((-1035) (-679 (-215)) (-568) (-568) (-568) (-568))) (-15 -3017 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3013 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3008 ((-1035) (-568) (-568) (-679 (-215)) (-568))) (-15 -2999 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-568))) (-15 -2994 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -2989 ((-1035) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -2983 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -2979 ((-1035) (-679 (-215)) (-568) (-679 (-215)) (-568) (-568) (-568) (-568) (-568))) (-15 -2974 ((-1035) (-568) (-568) (-215) (-215) (-568) (-568) (-679 (-215)) (-568))) (-15 -2968 ((-1035) (-568) (-568) (-568) (-215) (-121) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -2964 ((-1035) (-568) (-568) (-215) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-390)) (|:| |fp| (-73 IMAGE))))) (-15 -2964 ((-1035) (-568) (-568) (-215) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-390)) (|:| |fp| (-73 IMAGE))) (-390))) (-15 -2958 ((-1035) (-568) (-568) (-568) (-568) (-568) (-121) (-568) (-121) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -2954 ((-1035) (-568) (-568) (-568) (-568) (-568) (-121) (-568) (-121) (-568) (-679 (-169 (-215))) (-679 (-169 (-215))) (-568))))) (T -747)) 
+((-2954 (*1 *2 *3 *3 *3 *3 *3 *4 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-121)) (-5 *5 (-679 (-169 (-215)))) (-5 *2 (-1035)) (-5 *1 (-747)))) (-2958 (*1 *2 *3 *3 *3 *3 *3 *4 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-121)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747)))) (-2964 (*1 *2 *3 *3 *4 *3 *3 *3 *3 *3 *3 *3 *5 *3 *6 *7 *8) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-72 DOT)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-73 IMAGE)))) (-5 *8 (-390)) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-747)))) (-2964 (*1 *2 *3 *3 *4 *3 *3 *3 *3 *3 *3 *3 *5 *3 *6 *7) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-72 DOT)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-73 IMAGE)))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-747)))) (-2968 (*1 *2 *3 *3 *3 *4 *5 *3 *6 *6 *3) (-12 (-5 *3 (-568)) (-5 *5 (-121)) (-5 *6 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-747)))) (-2974 (*1 *2 *3 *3 *4 *4 *3 *3 *5 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-747)))) (-2979 (*1 *2 *3 *4 *3 *4 *4 *4 *4 *4) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-747)))) (-2983 (*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747)))) (-2989 (*1 *2 *3 *3 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747)))) (-2994 (*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747)))) (-2999 (*1 *2 *3 *3 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747)))) (-3008 (*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747)))) (-3013 (*1 *2 *3 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747)))) (-3017 (*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747)))) (-3022 (*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-747)))) (-3026 (*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(-10 -7 (-15 -3026 ((-1035) (-568) (-568) (-679 (-215)) (-568))) (-15 -3022 ((-1035) (-679 (-215)) (-568) (-568) (-568) (-568))) (-15 -3017 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3013 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -3008 ((-1035) (-568) (-568) (-679 (-215)) (-568))) (-15 -2999 ((-1035) (-568) (-568) (-568) (-568) (-679 (-215)) (-568))) (-15 -2994 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -2989 ((-1035) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -2983 ((-1035) (-568) (-568) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -2979 ((-1035) (-679 (-215)) (-568) (-679 (-215)) (-568) (-568) (-568) (-568) (-568))) (-15 -2974 ((-1035) (-568) (-568) (-215) (-215) (-568) (-568) (-679 (-215)) (-568))) (-15 -2968 ((-1035) (-568) (-568) (-568) (-215) (-121) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -2964 ((-1035) (-568) (-568) (-215) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-390)) (|:| |fp| (-73 IMAGE))))) (-15 -2964 ((-1035) (-568) (-568) (-215) (-568) (-568) (-568) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-72 DOT))) (-3 (|:| |fn| (-390)) (|:| |fp| (-73 IMAGE))) (-390))) (-15 -2958 ((-1035) (-568) (-568) (-568) (-568) (-568) (-121) (-568) (-121) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -2954 ((-1035) (-568) (-568) (-568) (-568) (-568) (-121) (-568) (-121) (-568) (-679 (-169 (-215))) (-679 (-169 (-215))) (-568)))) 
+((-4320 (((-1035) (-568) (-568) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-75 APROD)))) 60)) (-4327 (((-1035) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-568)) (-568) (-679 (-215)) (-568) (-568) (-568) (-568)) 56)) (-4334 (((-1035) (-568) (-679 (-215)) (-121) (-215) (-568) (-568) (-568) (-568) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-73 APROD))) (-3 (|:| |fn| (-390)) (|:| |fp| (-78 MSOLVE)))) 55)) (-4340 (((-1035) (-568) (-568) (-679 (-215)) (-568) (-679 (-568)) (-568) (-679 (-568)) (-679 (-215)) (-679 (-568)) (-679 (-568)) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-568)) 36)) (-4346 (((-1035) (-568) (-568) (-568) (-215) (-568) (-679 (-215)) (-679 (-215)) (-568)) 35)) (-4351 (((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568)) 31)) (-4359 (((-1035) (-568) (-679 (-215)) (-568) (-679 (-568)) (-679 (-568)) (-568) (-679 (-568)) (-679 (-215))) 30)) (-4364 (((-1035) (-679 (-215)) (-568) (-679 (-215)) (-568) (-568) (-568)) 26)) (-4371 (((-1035) (-568) (-679 (-215)) (-568) (-679 (-215)) (-568)) 25)) (-4381 (((-1035) (-568) (-679 (-215)) (-568) (-679 (-215)) (-568)) 24)) (-2898 (((-1035) (-568) (-679 (-169 (-215))) (-568) (-568) (-568) (-568) (-679 (-169 (-215))) (-568)) 20))) 
+(((-748) (-10 -7 (-15 -2898 ((-1035) (-568) (-679 (-169 (-215))) (-568) (-568) (-568) (-568) (-679 (-169 (-215))) (-568))) (-15 -4381 ((-1035) (-568) (-679 (-215)) (-568) (-679 (-215)) (-568))) (-15 -4371 ((-1035) (-568) (-679 (-215)) (-568) (-679 (-215)) (-568))) (-15 -4364 ((-1035) (-679 (-215)) (-568) (-679 (-215)) (-568) (-568) (-568))) (-15 -4359 ((-1035) (-568) (-679 (-215)) (-568) (-679 (-568)) (-679 (-568)) (-568) (-679 (-568)) (-679 (-215)))) (-15 -4351 ((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -4346 ((-1035) (-568) (-568) (-568) (-215) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -4340 ((-1035) (-568) (-568) (-679 (-215)) (-568) (-679 (-568)) (-568) (-679 (-568)) (-679 (-215)) (-679 (-568)) (-679 (-568)) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-568))) (-15 -4334 ((-1035) (-568) (-679 (-215)) (-121) (-215) (-568) (-568) (-568) (-568) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-73 APROD))) (-3 (|:| |fn| (-390)) (|:| |fp| (-78 MSOLVE))))) (-15 -4327 ((-1035) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-568)) (-568) (-679 (-215)) (-568) (-568) (-568) (-568))) (-15 -4320 ((-1035) (-568) (-568) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-75 APROD))))))) (T -748)) 
+((-4320 (*1 *2 *3 *3 *4 *4 *4 *4 *3 *3 *3 *3 *5 *3 *6) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-75 APROD)))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-748)))) (-4327 (*1 *2 *3 *4 *3 *4 *5 *3 *4 *3 *3 *3 *3) (-12 (-5 *4 (-679 (-215))) (-5 *5 (-679 (-568))) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-748)))) (-4334 (*1 *2 *3 *4 *5 *6 *3 *3 *3 *3 *6 *3 *7 *8) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-121)) (-5 *6 (-215)) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-73 APROD)))) (-5 *8 (-3 (|:| |fn| (-390)) (|:| |fp| (-78 MSOLVE)))) (-5 *2 (-1035)) (-5 *1 (-748)))) (-4340 (*1 *2 *3 *3 *4 *3 *5 *3 *5 *4 *5 *5 *4 *4 *5 *3) (-12 (-5 *4 (-679 (-215))) (-5 *5 (-679 (-568))) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-748)))) (-4346 (*1 *2 *3 *3 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-748)))) (-4351 (*1 *2 *3 *3 *4 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-748)))) (-4359 (*1 *2 *3 *4 *3 *5 *5 *3 *5 *4) (-12 (-5 *4 (-679 (-215))) (-5 *5 (-679 (-568))) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-748)))) (-4364 (*1 *2 *3 *4 *3 *4 *4 *4) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-748)))) (-4371 (*1 *2 *3 *4 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-748)))) (-4381 (*1 *2 *3 *4 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-748)))) (-2898 (*1 *2 *3 *4 *3 *3 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-169 (-215)))) (-5 *2 (-1035)) (-5 *1 (-748))))) 
+(-10 -7 (-15 -2898 ((-1035) (-568) (-679 (-169 (-215))) (-568) (-568) (-568) (-568) (-679 (-169 (-215))) (-568))) (-15 -4381 ((-1035) (-568) (-679 (-215)) (-568) (-679 (-215)) (-568))) (-15 -4371 ((-1035) (-568) (-679 (-215)) (-568) (-679 (-215)) (-568))) (-15 -4364 ((-1035) (-679 (-215)) (-568) (-679 (-215)) (-568) (-568) (-568))) (-15 -4359 ((-1035) (-568) (-679 (-215)) (-568) (-679 (-568)) (-679 (-568)) (-568) (-679 (-568)) (-679 (-215)))) (-15 -4351 ((-1035) (-568) (-568) (-679 (-215)) (-679 (-215)) (-679 (-215)) (-568))) (-15 -4346 ((-1035) (-568) (-568) (-568) (-215) (-568) (-679 (-215)) (-679 (-215)) (-568))) (-15 -4340 ((-1035) (-568) (-568) (-679 (-215)) (-568) (-679 (-568)) (-568) (-679 (-568)) (-679 (-215)) (-679 (-568)) (-679 (-568)) (-679 (-215)) (-679 (-215)) (-679 (-568)) (-568))) (-15 -4334 ((-1035) (-568) (-679 (-215)) (-121) (-215) (-568) (-568) (-568) (-568) (-215) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-73 APROD))) (-3 (|:| |fn| (-390)) (|:| |fp| (-78 MSOLVE))))) (-15 -4327 ((-1035) (-568) (-679 (-215)) (-568) (-679 (-215)) (-679 (-568)) (-568) (-679 (-215)) (-568) (-568) (-568) (-568))) (-15 -4320 ((-1035) (-568) (-568) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-568) (-679 (-215)) (-568) (-3 (|:| |fn| (-390)) (|:| |fp| (-75 APROD)))))) 
+((-2922 (((-1035) (-1143) (-568) (-568) (-679 (-215)) (-568) (-568) (-679 (-215))) 28)) (-2926 (((-1035) (-1143) (-568) (-568) (-679 (-215))) 27)) (-2931 (((-1035) (-1143) (-568) (-568) (-679 (-215)) (-568) (-679 (-568)) (-568) (-679 (-215))) 26)) (-2935 (((-1035) (-568) (-568) (-568) (-679 (-215))) 20))) 
+(((-749) (-10 -7 (-15 -2935 ((-1035) (-568) (-568) (-568) (-679 (-215)))) (-15 -2931 ((-1035) (-1143) (-568) (-568) (-679 (-215)) (-568) (-679 (-568)) (-568) (-679 (-215)))) (-15 -2926 ((-1035) (-1143) (-568) (-568) (-679 (-215)))) (-15 -2922 ((-1035) (-1143) (-568) (-568) (-679 (-215)) (-568) (-568) (-679 (-215)))))) (T -749)) 
+((-2922 (*1 *2 *3 *4 *4 *5 *4 *4 *5) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-749)))) (-2926 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-749)))) (-2931 (*1 *2 *3 *4 *4 *5 *4 *6 *4 *5) (-12 (-5 *3 (-1143)) (-5 *5 (-679 (-215))) (-5 *6 (-679 (-568))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-749)))) (-2935 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-749))))) 
+(-10 -7 (-15 -2935 ((-1035) (-568) (-568) (-568) (-679 (-215)))) (-15 -2931 ((-1035) (-1143) (-568) (-568) (-679 (-215)) (-568) (-679 (-568)) (-568) (-679 (-215)))) (-15 -2926 ((-1035) (-1143) (-568) (-568) (-679 (-215)))) (-15 -2922 ((-1035) (-1143) (-568) (-568) (-679 (-215)) (-568) (-568) (-679 (-215))))) 
+((-4172 (((-1035) (-215) (-215) (-215) (-215) (-568)) 62)) (-4176 (((-1035) (-215) (-215) (-215) (-568)) 61)) (-4183 (((-1035) (-215) (-215) (-215) (-568)) 60)) (-4189 (((-1035) (-215) (-215) (-568)) 59)) (-4198 (((-1035) (-215) (-568)) 58)) (-4210 (((-1035) (-215) (-568)) 57)) (-4222 (((-1035) (-215) (-568)) 56)) (-4234 (((-1035) (-215) (-568)) 55)) (-4259 (((-1035) (-215) (-568)) 54)) (-4269 (((-1035) (-215) (-568)) 53)) (-4283 (((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568)) 52)) (-4291 (((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568)) 51)) (-4296 (((-1035) (-215) (-568)) 50)) (-4302 (((-1035) (-215) (-568)) 49)) (-4309 (((-1035) (-215) (-568)) 48)) (-4315 (((-1035) (-215) (-568)) 47)) (-2942 (((-1035) (-568) (-215) (-169 (-215)) (-568) (-1143) (-568)) 46)) (-2946 (((-1035) (-1143) (-169 (-215)) (-1143) (-568)) 45)) (-2950 (((-1035) (-1143) (-169 (-215)) (-1143) (-568)) 44)) (-4042 (((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568)) 43)) (-4048 (((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568)) 42)) (-4054 (((-1035) (-215) (-568)) 39)) (-4060 (((-1035) (-215) (-568)) 38)) (-4067 (((-1035) (-215) (-568)) 37)) (-4073 (((-1035) (-215) (-568)) 36)) (-4078 (((-1035) (-215) (-568)) 35)) (-4086 (((-1035) (-215) (-568)) 34)) (-4093 (((-1035) (-215) (-568)) 33)) (-4100 (((-1035) (-215) (-568)) 32)) (-4107 (((-1035) (-215) (-568)) 31)) (-4114 (((-1035) (-215) (-568)) 30)) (-4122 (((-1035) (-215) (-215) (-215) (-568)) 29)) (-4129 (((-1035) (-215) (-568)) 28)) (-4136 (((-1035) (-215) (-568)) 27)) (-4142 (((-1035) (-215) (-568)) 26)) (-4149 (((-1035) (-215) (-568)) 25)) (-4157 (((-1035) (-215) (-568)) 24)) (-4165 (((-1035) (-169 (-215)) (-568)) 20))) 
+(((-750) (-10 -7 (-15 -4165 ((-1035) (-169 (-215)) (-568))) (-15 -4157 ((-1035) (-215) (-568))) (-15 -4149 ((-1035) (-215) (-568))) (-15 -4142 ((-1035) (-215) (-568))) (-15 -4136 ((-1035) (-215) (-568))) (-15 -4129 ((-1035) (-215) (-568))) (-15 -4122 ((-1035) (-215) (-215) (-215) (-568))) (-15 -4114 ((-1035) (-215) (-568))) (-15 -4107 ((-1035) (-215) (-568))) (-15 -4100 ((-1035) (-215) (-568))) (-15 -4093 ((-1035) (-215) (-568))) (-15 -4086 ((-1035) (-215) (-568))) (-15 -4078 ((-1035) (-215) (-568))) (-15 -4073 ((-1035) (-215) (-568))) (-15 -4067 ((-1035) (-215) (-568))) (-15 -4060 ((-1035) (-215) (-568))) (-15 -4054 ((-1035) (-215) (-568))) (-15 -4048 ((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568))) (-15 -4042 ((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568))) (-15 -2950 ((-1035) (-1143) (-169 (-215)) (-1143) (-568))) (-15 -2946 ((-1035) (-1143) (-169 (-215)) (-1143) (-568))) (-15 -2942 ((-1035) (-568) (-215) (-169 (-215)) (-568) (-1143) (-568))) (-15 -4315 ((-1035) (-215) (-568))) (-15 -4309 ((-1035) (-215) (-568))) (-15 -4302 ((-1035) (-215) (-568))) (-15 -4296 ((-1035) (-215) (-568))) (-15 -4291 ((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568))) (-15 -4283 ((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568))) (-15 -4269 ((-1035) (-215) (-568))) (-15 -4259 ((-1035) (-215) (-568))) (-15 -4234 ((-1035) (-215) (-568))) (-15 -4222 ((-1035) (-215) (-568))) (-15 -4210 ((-1035) (-215) (-568))) (-15 -4198 ((-1035) (-215) (-568))) (-15 -4189 ((-1035) (-215) (-215) (-568))) (-15 -4183 ((-1035) (-215) (-215) (-215) (-568))) (-15 -4176 ((-1035) (-215) (-215) (-215) (-568))) (-15 -4172 ((-1035) (-215) (-215) (-215) (-215) (-568))))) (T -750)) 
+((-4172 (*1 *2 *3 *3 *3 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4176 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4183 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4189 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4198 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4210 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4222 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4234 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4259 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4269 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4283 (*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-169 (-215))) (-5 *5 (-568)) (-5 *6 (-1143)) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4291 (*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-169 (-215))) (-5 *5 (-568)) (-5 *6 (-1143)) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4296 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4302 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4309 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4315 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-2942 (*1 *2 *3 *4 *5 *3 *6 *3) (-12 (-5 *3 (-568)) (-5 *5 (-169 (-215))) (-5 *6 (-1143)) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-2946 (*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-1143)) (-5 *4 (-169 (-215))) (-5 *5 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-2950 (*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-1143)) (-5 *4 (-169 (-215))) (-5 *5 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4042 (*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-169 (-215))) (-5 *5 (-568)) (-5 *6 (-1143)) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4048 (*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-169 (-215))) (-5 *5 (-568)) (-5 *6 (-1143)) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4054 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4060 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4067 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4073 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4078 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4086 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4093 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4100 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4107 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4114 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4122 (*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4129 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4136 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4142 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4149 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4157 (*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750)))) (-4165 (*1 *2 *3 *4) (-12 (-5 *3 (-169 (-215))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
+(-10 -7 (-15 -4165 ((-1035) (-169 (-215)) (-568))) (-15 -4157 ((-1035) (-215) (-568))) (-15 -4149 ((-1035) (-215) (-568))) (-15 -4142 ((-1035) (-215) (-568))) (-15 -4136 ((-1035) (-215) (-568))) (-15 -4129 ((-1035) (-215) (-568))) (-15 -4122 ((-1035) (-215) (-215) (-215) (-568))) (-15 -4114 ((-1035) (-215) (-568))) (-15 -4107 ((-1035) (-215) (-568))) (-15 -4100 ((-1035) (-215) (-568))) (-15 -4093 ((-1035) (-215) (-568))) (-15 -4086 ((-1035) (-215) (-568))) (-15 -4078 ((-1035) (-215) (-568))) (-15 -4073 ((-1035) (-215) (-568))) (-15 -4067 ((-1035) (-215) (-568))) (-15 -4060 ((-1035) (-215) (-568))) (-15 -4054 ((-1035) (-215) (-568))) (-15 -4048 ((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568))) (-15 -4042 ((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568))) (-15 -2950 ((-1035) (-1143) (-169 (-215)) (-1143) (-568))) (-15 -2946 ((-1035) (-1143) (-169 (-215)) (-1143) (-568))) (-15 -2942 ((-1035) (-568) (-215) (-169 (-215)) (-568) (-1143) (-568))) (-15 -4315 ((-1035) (-215) (-568))) (-15 -4309 ((-1035) (-215) (-568))) (-15 -4302 ((-1035) (-215) (-568))) (-15 -4296 ((-1035) (-215) (-568))) (-15 -4291 ((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568))) (-15 -4283 ((-1035) (-215) (-169 (-215)) (-568) (-1143) (-568))) (-15 -4269 ((-1035) (-215) (-568))) (-15 -4259 ((-1035) (-215) (-568))) (-15 -4234 ((-1035) (-215) (-568))) (-15 -4222 ((-1035) (-215) (-568))) (-15 -4210 ((-1035) (-215) (-568))) (-15 -4198 ((-1035) (-215) (-568))) (-15 -4189 ((-1035) (-215) (-215) (-568))) (-15 -4183 ((-1035) (-215) (-215) (-215) (-568))) (-15 -4176 ((-1035) (-215) (-215) (-215) (-568))) (-15 -4172 ((-1035) (-215) (-215) (-215) (-215) (-568)))) 
+((-2074 (((-1249)) 18)) (-2345 (((-1143)) 22)) (-2851 (((-1143)) 21)) (-2065 (((-1094) (-1161) (-679 (-568))) 35) (((-1094) (-1161) (-679 (-215))) 31)) (-1589 (((-121)) 16)) (-3185 (((-1143) (-1143)) 25))) 
+(((-751) (-10 -7 (-15 -2851 ((-1143))) (-15 -2345 ((-1143))) (-15 -3185 ((-1143) (-1143))) (-15 -2065 ((-1094) (-1161) (-679 (-215)))) (-15 -2065 ((-1094) (-1161) (-679 (-568)))) (-15 -1589 ((-121))) (-15 -2074 ((-1249))))) (T -751)) 
+((-2074 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-751)))) (-1589 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-751)))) (-2065 (*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-679 (-568))) (-5 *2 (-1094)) (-5 *1 (-751)))) (-2065 (*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-679 (-215))) (-5 *2 (-1094)) (-5 *1 (-751)))) (-3185 (*1 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-751)))) (-2345 (*1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-751)))) (-2851 (*1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-751))))) 
+(-10 -7 (-15 -2851 ((-1143))) (-15 -2345 ((-1143))) (-15 -3185 ((-1143) (-1143))) (-15 -2065 ((-1094) (-1161) (-679 (-215)))) (-15 -2065 ((-1094) (-1161) (-679 (-568)))) (-15 -1589 ((-121))) (-15 -2074 ((-1249)))) 
+((-3985 (($ $ $) 10)) (-2007 (($ $ $ $) 9)) (-3911 (($ $ $) 12))) 
+(((-752 |#1|) (-10 -8 (-15 -3911 (|#1| |#1| |#1|)) (-15 -3985 (|#1| |#1| |#1|)) (-15 -2007 (|#1| |#1| |#1| |#1|))) (-753)) (T -752)) 
+NIL 
+(-10 -8 (-15 -3911 (|#1| |#1| |#1|)) (-15 -3985 (|#1| |#1| |#1|)) (-15 -2007 (|#1| |#1| |#1| |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-2815 (($ $ (-917)) 27)) (-4202 (($ $ (-917)) 28)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-3985 (($ $ $) 24)) (-2747 (((-850) $) 11)) (-2007 (($ $ $ $) 25)) (-3911 (($ $ $) 23)) (-3058 (($) 17 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 29)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 26))) 
 (((-753) (-1275)) (T -753)) 
-((-3882 (*1 *1 *1 *1 *1) (-4 *1 (-753))) (-2353 (*1 *1 *1 *1) (-4 *1 (-753))) (-3500 (*1 *1 *1 *1) (-4 *1 (-753)))) 
-(-13 (-21) (-710) (-10 -8 (-15 -3882 ($ $ $ $)) (-15 -2353 ($ $ $)) (-15 -3500 ($ $ $)))) 
+((-2007 (*1 *1 *1 *1 *1) (-4 *1 (-753))) (-3985 (*1 *1 *1 *1) (-4 *1 (-753))) (-3911 (*1 *1 *1 *1) (-4 *1 (-753)))) 
+(-13 (-21) (-710) (-10 -8 (-15 -2007 ($ $ $ $)) (-15 -3985 ($ $ $)) (-15 -3911 ($ $ $)))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-137) . T) ((-608 (-850)) . T) ((-710) . T) ((-1090) . T)) 
-((-2745 (((-850) $) NIL) (($ (-568)) 10))) 
-(((-754 |#1|) (-10 -8 (-15 -2745 (|#1| (-568))) (-15 -2745 ((-850) |#1|))) (-755)) (T -754)) 
+((-2747 (((-850) $) NIL) (($ (-568)) 10))) 
+(((-754 |#1|) (-10 -8 (-15 -2747 (|#1| (-568))) (-15 -2747 ((-850) |#1|))) (-755)) (T -754)) 
 NIL 
-(-10 -8 (-15 -2745 (|#1| (-568))) (-15 -2745 ((-850) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-3550 (((-3 $ "failed") $) 39)) (-3551 (($ $ (-917)) 27) (($ $ (-763)) 34)) (-2925 (((-3 $ "failed") $) 37)) (-2735 (((-121) $) 33)) (-3243 (((-3 $ "failed") $) 38)) (-4222 (($ $ (-917)) 28) (($ $ (-763)) 35)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2353 (($ $ $) 24)) (-2745 (((-850) $) 11) (($ (-568)) 30)) (-4078 (((-763)) 31)) (-3882 (($ $ $ $) 25)) (-3500 (($ $ $) 23)) (-3056 (($) 17 T CONST)) (-1556 (($) 32 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 29) (($ $ (-763)) 36)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 26))) 
+(-10 -8 (-15 -2747 (|#1| (-568))) (-15 -2747 ((-850) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-2812 (((-3 $ "failed") $) 39)) (-2815 (($ $ (-917)) 27) (($ $ (-763)) 34)) (-2902 (((-3 $ "failed") $) 37)) (-1598 (((-121) $) 33)) (-1974 (((-3 $ "failed") $) 38)) (-4202 (($ $ (-917)) 28) (($ $ (-763)) 35)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-3985 (($ $ $) 24)) (-2747 (((-850) $) 11) (($ (-568)) 30)) (-3425 (((-763)) 31)) (-2007 (($ $ $ $) 25)) (-3911 (($ $ $) 23)) (-3058 (($) 17 T CONST)) (-1557 (($) 32 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 29) (($ $ (-763)) 36)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 26))) 
 (((-755) (-1275)) (T -755)) 
-((-4078 (*1 *2) (-12 (-4 *1 (-755)) (-5 *2 (-763)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-755))))) 
-(-13 (-753) (-712) (-10 -8 (-15 -4078 ((-763))) (-15 -2745 ($ (-568))))) 
+((-3425 (*1 *2) (-12 (-4 *1 (-755)) (-5 *2 (-763)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-755))))) 
+(-13 (-753) (-712) (-10 -8 (-15 -3425 ((-763))) (-15 -2747 ($ (-568))))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-137) . T) ((-608 (-850)) . T) ((-710) . T) ((-712) . T) ((-753) . T) ((-1090) . T)) 
-((-1579 (((-634 (-2 (|:| |outval| (-169 |#1|)) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 (-169 |#1|)))))) (-679 (-169 (-409 (-568)))) |#1|) 27)) (-4070 (((-634 (-169 |#1|)) (-679 (-169 (-409 (-568)))) |#1|) 19)) (-2678 (((-953 (-169 (-409 (-568)))) (-679 (-169 (-409 (-568)))) (-1161)) 16) (((-953 (-169 (-409 (-568)))) (-679 (-169 (-409 (-568))))) 15))) 
-(((-756 |#1|) (-10 -7 (-15 -2678 ((-953 (-169 (-409 (-568)))) (-679 (-169 (-409 (-568)))))) (-15 -2678 ((-953 (-169 (-409 (-568)))) (-679 (-169 (-409 (-568)))) (-1161))) (-15 -4070 ((-634 (-169 |#1|)) (-679 (-169 (-409 (-568)))) |#1|)) (-15 -1579 ((-634 (-2 (|:| |outval| (-169 |#1|)) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 (-169 |#1|)))))) (-679 (-169 (-409 (-568)))) |#1|))) (-13 (-365) (-840))) (T -756)) 
-((-1579 (*1 *2 *3 *4) (-12 (-5 *3 (-679 (-169 (-409 (-568))))) (-5 *2 (-634 (-2 (|:| |outval| (-169 *4)) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 (-169 *4))))))) (-5 *1 (-756 *4)) (-4 *4 (-13 (-365) (-840))))) (-4070 (*1 *2 *3 *4) (-12 (-5 *3 (-679 (-169 (-409 (-568))))) (-5 *2 (-634 (-169 *4))) (-5 *1 (-756 *4)) (-4 *4 (-13 (-365) (-840))))) (-2678 (*1 *2 *3 *4) (-12 (-5 *3 (-679 (-169 (-409 (-568))))) (-5 *4 (-1161)) (-5 *2 (-953 (-169 (-409 (-568))))) (-5 *1 (-756 *5)) (-4 *5 (-13 (-365) (-840))))) (-2678 (*1 *2 *3) (-12 (-5 *3 (-679 (-169 (-409 (-568))))) (-5 *2 (-953 (-169 (-409 (-568))))) (-5 *1 (-756 *4)) (-4 *4 (-13 (-365) (-840)))))) 
-(-10 -7 (-15 -2678 ((-953 (-169 (-409 (-568)))) (-679 (-169 (-409 (-568)))))) (-15 -2678 ((-953 (-169 (-409 (-568)))) (-679 (-169 (-409 (-568)))) (-1161))) (-15 -4070 ((-634 (-169 |#1|)) (-679 (-169 (-409 (-568)))) |#1|)) (-15 -1579 ((-634 (-2 (|:| |outval| (-169 |#1|)) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 (-169 |#1|)))))) (-679 (-169 (-409 (-568)))) |#1|))) 
-((-3878 (((-173 (-568)) |#1|) 25))) 
-(((-757 |#1|) (-10 -7 (-15 -3878 ((-173 (-568)) |#1|))) (-406)) (T -757)) 
-((-3878 (*1 *2 *3) (-12 (-5 *2 (-173 (-568))) (-5 *1 (-757 *3)) (-4 *3 (-406))))) 
-(-10 -7 (-15 -3878 ((-173 (-568)) |#1|))) 
-((-3748 ((|#1| |#1| |#1|) 24)) (-1382 ((|#1| |#1| |#1|) 23)) (-1525 ((|#1| |#1| |#1|) 31)) (-2450 ((|#1| |#1| |#1|) 27)) (-2260 (((-3 |#1| "failed") |#1| |#1|) 26)) (-1293 (((-2 (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1|) 22))) 
-(((-758 |#1| |#2|) (-10 -7 (-15 -1293 ((-2 (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1|)) (-15 -1382 (|#1| |#1| |#1|)) (-15 -3748 (|#1| |#1| |#1|)) (-15 -2260 ((-3 |#1| "failed") |#1| |#1|)) (-15 -2450 (|#1| |#1| |#1|)) (-15 -1525 (|#1| |#1| |#1|))) (-698 |#2|) (-365)) (T -758)) 
-((-1525 (*1 *2 *2 *2) (-12 (-4 *3 (-365)) (-5 *1 (-758 *2 *3)) (-4 *2 (-698 *3)))) (-2450 (*1 *2 *2 *2) (-12 (-4 *3 (-365)) (-5 *1 (-758 *2 *3)) (-4 *2 (-698 *3)))) (-2260 (*1 *2 *2 *2) (|partial| -12 (-4 *3 (-365)) (-5 *1 (-758 *2 *3)) (-4 *2 (-698 *3)))) (-3748 (*1 *2 *2 *2) (-12 (-4 *3 (-365)) (-5 *1 (-758 *2 *3)) (-4 *2 (-698 *3)))) (-1382 (*1 *2 *2 *2) (-12 (-4 *3 (-365)) (-5 *1 (-758 *2 *3)) (-4 *2 (-698 *3)))) (-1293 (*1 *2 *3 *3) (-12 (-4 *4 (-365)) (-5 *2 (-2 (|:| -3961 *3) (|:| -1500 *3))) (-5 *1 (-758 *3 *4)) (-4 *3 (-698 *4))))) 
-(-10 -7 (-15 -1293 ((-2 (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1|)) (-15 -1382 (|#1| |#1| |#1|)) (-15 -3748 (|#1| |#1| |#1|)) (-15 -2260 ((-3 |#1| "failed") |#1| |#1|)) (-15 -2450 (|#1| |#1| |#1|)) (-15 -1525 (|#1| |#1| |#1|))) 
-((-3933 (((-1157 |#1|) (-634 |#1|)) 25))) 
-(((-759 |#1|) (-10 -7 (-15 -3933 ((-1157 |#1|) (-634 |#1|)))) (-558)) (T -759)) 
-((-3933 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-558)) (-5 *2 (-1157 *4)) (-5 *1 (-759 *4))))) 
-(-10 -7 (-15 -3933 ((-1157 |#1|) (-634 |#1|)))) 
-((-3714 (((-2 (|:| -3746 (-679 (-568))) (|:| |basisDen| (-568)) (|:| |basisInv| (-679 (-568)))) (-568)) 58)) (-3661 (((-2 (|:| -3746 (-679 (-568))) (|:| |basisDen| (-568)) (|:| |basisInv| (-679 (-568))))) 56)) (-2217 (((-568)) 68))) 
-(((-760 |#1| |#2|) (-10 -7 (-15 -2217 ((-568))) (-15 -3661 ((-2 (|:| -3746 (-679 (-568))) (|:| |basisDen| (-568)) (|:| |basisInv| (-679 (-568)))))) (-15 -3714 ((-2 (|:| -3746 (-679 (-568))) (|:| |basisDen| (-568)) (|:| |basisInv| (-679 (-568)))) (-568)))) (-1219 (-568)) (-411 (-568) |#1|)) (T -760)) 
-((-3714 (*1 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1219 *3)) (-5 *2 (-2 (|:| -3746 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-5 *1 (-760 *4 *5)) (-4 *5 (-411 *3 *4)))) (-3661 (*1 *2) (-12 (-4 *3 (-1219 (-568))) (-5 *2 (-2 (|:| -3746 (-679 (-568))) (|:| |basisDen| (-568)) (|:| |basisInv| (-679 (-568))))) (-5 *1 (-760 *3 *4)) (-4 *4 (-411 (-568) *3)))) (-2217 (*1 *2) (-12 (-4 *3 (-1219 *2)) (-5 *2 (-568)) (-5 *1 (-760 *3 *4)) (-4 *4 (-411 *2 *3))))) 
-(-10 -7 (-15 -2217 ((-568))) (-15 -3661 ((-2 (|:| -3746 (-679 (-568))) (|:| |basisDen| (-568)) (|:| |basisInv| (-679 (-568)))))) (-15 -3714 ((-2 (|:| -3746 (-679 (-568))) (|:| |basisDen| (-568)) (|:| |basisInv| (-679 (-568)))) (-568)))) 
-((-2447 (((-121) $ $) NIL)) (-2854 (((-3 (|:| |nia| (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| |mdnia| (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) $) 15)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 14) (($ (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 8) (($ (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 10) (($ (-3 (|:| |nia| (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| |mdnia| (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))))) 12)) (-1717 (((-121) $ $) NIL))) 
-(((-761) (-13 (-1090) (-10 -8 (-15 -2745 ($ (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2745 ($ (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2745 ($ (-3 (|:| |nia| (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| |mdnia| (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))))) (-15 -2745 ((-850) $)) (-15 -2854 ((-3 (|:| |nia| (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| |mdnia| (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) $))))) (T -761)) 
-((-2745 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-761)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *1 (-761)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *1 (-761)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-3 (|:| |nia| (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| |mdnia| (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))))) (-5 *1 (-761)))) (-2854 (*1 *2 *1) (-12 (-5 *2 (-3 (|:| |nia| (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| |mdnia| (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))))) (-5 *1 (-761))))) 
-(-13 (-1090) (-10 -8 (-15 -2745 ($ (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2745 ($ (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2745 ($ (-3 (|:| |nia| (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| |mdnia| (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))))) (-15 -2745 ((-850) $)) (-15 -2854 ((-3 (|:| |nia| (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| |mdnia| (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) $)))) 
-((-2578 (((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|))) 14) (((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|)) (-634 (-1161))) 13)) (-4351 (((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|))) 16) (((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|)) (-634 (-1161))) 15))) 
-(((-762 |#1|) (-10 -7 (-15 -2578 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|)) (-634 (-1161)))) (-15 -2578 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|)))) (-15 -4351 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|)) (-634 (-1161)))) (-15 -4351 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|))))) (-558)) (T -762)) 
-((-4351 (*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *4)))))) (-5 *1 (-762 *4)))) (-4351 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-634 (-1161))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *5)))))) (-5 *1 (-762 *5)))) (-2578 (*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *4)))))) (-5 *1 (-762 *4)))) (-2578 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-634 (-1161))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *5)))))) (-5 *1 (-762 *5))))) 
-(-10 -7 (-15 -2578 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|)) (-634 (-1161)))) (-15 -2578 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|)))) (-15 -4351 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|)) (-634 (-1161)))) (-15 -4351 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|))))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-1462 (($ $ $) 6)) (-3134 (((-3 $ "failed") $ $) 9)) (-1870 (($ $ (-568)) 7)) (-2671 (($) NIL T CONST)) (-2401 (($ $ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1731 (($ $) NIL)) (-2412 (($ $ $) NIL)) (-2735 (((-121) $) NIL)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2721 (($ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-2745 (((-850) $) NIL)) (-1887 (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (* (($ (-763) $) NIL) (($ (-917) $) NIL) (($ $ $) NIL))) 
-(((-763) (-13 (-788) (-716) (-10 -8 (-15 -2412 ($ $ $)) (-15 -2401 ($ $ $)) (-15 -2721 ($ $ $)) (-15 -3210 ((-2 (|:| -3961 $) (|:| -1500 $)) $ $)) (-15 -2595 ((-3 $ "failed") $ $)) (-15 -1870 ($ $ (-568))) (-15 -1731 ($ $)) (-6 (-4521 "*"))))) (T -763)) 
-((-2412 (*1 *1 *1 *1) (-5 *1 (-763))) (-2401 (*1 *1 *1 *1) (-5 *1 (-763))) (-2721 (*1 *1 *1 *1) (-5 *1 (-763))) (-3210 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3961 (-763)) (|:| -1500 (-763)))) (-5 *1 (-763)))) (-2595 (*1 *1 *1 *1) (|partial| -5 *1 (-763))) (-1870 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-763)))) (-1731 (*1 *1 *1) (-5 *1 (-763)))) 
-(-13 (-788) (-716) (-10 -8 (-15 -2412 ($ $ $)) (-15 -2401 ($ $ $)) (-15 -2721 ($ $ $)) (-15 -3210 ((-2 (|:| -3961 $) (|:| -1500 $)) $ $)) (-15 -2595 ((-3 $ "failed") $ $)) (-15 -1870 ($ $ (-568))) (-15 -1731 ($ $)) (-6 (-4521 "*")))) 
-((-4351 (((-3 |#2| "failed") |#2| |#2| (-123) (-1161)) 35))) 
-(((-764 |#1| |#2|) (-10 -7 (-15 -4351 ((-3 |#2| "failed") |#2| |#2| (-123) (-1161)))) (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150)) (-13 (-29 |#1|) (-1181) (-959))) (T -764)) 
-((-4351 (*1 *2 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-1161)) (-4 *5 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *1 (-764 *5 *2)) (-4 *2 (-13 (-29 *5) (-1181) (-959)))))) 
-(-10 -7 (-15 -4351 ((-3 |#2| "failed") |#2| |#2| (-123) (-1161)))) 
-((-2745 (((-766) |#1|) 8))) 
-(((-765 |#1|) (-10 -7 (-15 -2745 ((-766) |#1|))) (-1195)) (T -765)) 
-((-2745 (*1 *2 *3) (-12 (-5 *2 (-766)) (-5 *1 (-765 *3)) (-4 *3 (-1195))))) 
-(-10 -7 (-15 -2745 ((-766) |#1|))) 
-((-2447 (((-121) $ $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 7)) (-1717 (((-121) $ $) 9))) 
+((-4458 (((-634 (-2 (|:| |outval| (-169 |#1|)) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 (-169 |#1|)))))) (-679 (-169 (-409 (-568)))) |#1|) 27)) (-1647 (((-634 (-169 |#1|)) (-679 (-169 (-409 (-568)))) |#1|) 19)) (-1295 (((-953 (-169 (-409 (-568)))) (-679 (-169 (-409 (-568)))) (-1161)) 16) (((-953 (-169 (-409 (-568)))) (-679 (-169 (-409 (-568))))) 15))) 
+(((-756 |#1|) (-10 -7 (-15 -1295 ((-953 (-169 (-409 (-568)))) (-679 (-169 (-409 (-568)))))) (-15 -1295 ((-953 (-169 (-409 (-568)))) (-679 (-169 (-409 (-568)))) (-1161))) (-15 -1647 ((-634 (-169 |#1|)) (-679 (-169 (-409 (-568)))) |#1|)) (-15 -4458 ((-634 (-2 (|:| |outval| (-169 |#1|)) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 (-169 |#1|)))))) (-679 (-169 (-409 (-568)))) |#1|))) (-13 (-365) (-840))) (T -756)) 
+((-4458 (*1 *2 *3 *4) (-12 (-5 *3 (-679 (-169 (-409 (-568))))) (-5 *2 (-634 (-2 (|:| |outval| (-169 *4)) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 (-169 *4))))))) (-5 *1 (-756 *4)) (-4 *4 (-13 (-365) (-840))))) (-1647 (*1 *2 *3 *4) (-12 (-5 *3 (-679 (-169 (-409 (-568))))) (-5 *2 (-634 (-169 *4))) (-5 *1 (-756 *4)) (-4 *4 (-13 (-365) (-840))))) (-1295 (*1 *2 *3 *4) (-12 (-5 *3 (-679 (-169 (-409 (-568))))) (-5 *4 (-1161)) (-5 *2 (-953 (-169 (-409 (-568))))) (-5 *1 (-756 *5)) (-4 *5 (-13 (-365) (-840))))) (-1295 (*1 *2 *3) (-12 (-5 *3 (-679 (-169 (-409 (-568))))) (-5 *2 (-953 (-169 (-409 (-568))))) (-5 *1 (-756 *4)) (-4 *4 (-13 (-365) (-840)))))) 
+(-10 -7 (-15 -1295 ((-953 (-169 (-409 (-568)))) (-679 (-169 (-409 (-568)))))) (-15 -1295 ((-953 (-169 (-409 (-568)))) (-679 (-169 (-409 (-568)))) (-1161))) (-15 -1647 ((-634 (-169 |#1|)) (-679 (-169 (-409 (-568)))) |#1|)) (-15 -4458 ((-634 (-2 (|:| |outval| (-169 |#1|)) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 (-169 |#1|)))))) (-679 (-169 (-409 (-568)))) |#1|))) 
+((-1991 (((-173 (-568)) |#1|) 25))) 
+(((-757 |#1|) (-10 -7 (-15 -1991 ((-173 (-568)) |#1|))) (-406)) (T -757)) 
+((-1991 (*1 *2 *3) (-12 (-5 *2 (-173 (-568))) (-5 *1 (-757 *3)) (-4 *3 (-406))))) 
+(-10 -7 (-15 -1991 ((-173 (-568)) |#1|))) 
+((-2600 ((|#1| |#1| |#1|) 24)) (-3914 ((|#1| |#1| |#1|) 23)) (-4150 ((|#1| |#1| |#1|) 31)) (-2520 ((|#1| |#1| |#1|) 27)) (-3327 (((-3 |#1| "failed") |#1| |#1|) 26)) (-3229 (((-2 (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1|) 22))) 
+(((-758 |#1| |#2|) (-10 -7 (-15 -3229 ((-2 (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1|)) (-15 -3914 (|#1| |#1| |#1|)) (-15 -2600 (|#1| |#1| |#1|)) (-15 -3327 ((-3 |#1| "failed") |#1| |#1|)) (-15 -2520 (|#1| |#1| |#1|)) (-15 -4150 (|#1| |#1| |#1|))) (-698 |#2|) (-365)) (T -758)) 
+((-4150 (*1 *2 *2 *2) (-12 (-4 *3 (-365)) (-5 *1 (-758 *2 *3)) (-4 *2 (-698 *3)))) (-2520 (*1 *2 *2 *2) (-12 (-4 *3 (-365)) (-5 *1 (-758 *2 *3)) (-4 *2 (-698 *3)))) (-3327 (*1 *2 *2 *2) (|partial| -12 (-4 *3 (-365)) (-5 *1 (-758 *2 *3)) (-4 *2 (-698 *3)))) (-2600 (*1 *2 *2 *2) (-12 (-4 *3 (-365)) (-5 *1 (-758 *2 *3)) (-4 *2 (-698 *3)))) (-3914 (*1 *2 *2 *2) (-12 (-4 *3 (-365)) (-5 *1 (-758 *2 *3)) (-4 *2 (-698 *3)))) (-3229 (*1 *2 *3 *3) (-12 (-4 *4 (-365)) (-5 *2 (-2 (|:| -4409 *3) (|:| -2607 *3))) (-5 *1 (-758 *3 *4)) (-4 *3 (-698 *4))))) 
+(-10 -7 (-15 -3229 ((-2 (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1|)) (-15 -3914 (|#1| |#1| |#1|)) (-15 -2600 (|#1| |#1| |#1|)) (-15 -3327 ((-3 |#1| "failed") |#1| |#1|)) (-15 -2520 (|#1| |#1| |#1|)) (-15 -4150 (|#1| |#1| |#1|))) 
+((-4281 (((-1157 |#1|) (-634 |#1|)) 25))) 
+(((-759 |#1|) (-10 -7 (-15 -4281 ((-1157 |#1|) (-634 |#1|)))) (-558)) (T -759)) 
+((-4281 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-558)) (-5 *2 (-1157 *4)) (-5 *1 (-759 *4))))) 
+(-10 -7 (-15 -4281 ((-1157 |#1|) (-634 |#1|)))) 
+((-2443 (((-2 (|:| -2588 (-679 (-568))) (|:| |basisDen| (-568)) (|:| |basisInv| (-679 (-568)))) (-568)) 58)) (-3330 (((-2 (|:| -2588 (-679 (-568))) (|:| |basisDen| (-568)) (|:| |basisInv| (-679 (-568))))) 56)) (-3440 (((-568)) 68))) 
+(((-760 |#1| |#2|) (-10 -7 (-15 -3440 ((-568))) (-15 -3330 ((-2 (|:| -2588 (-679 (-568))) (|:| |basisDen| (-568)) (|:| |basisInv| (-679 (-568)))))) (-15 -2443 ((-2 (|:| -2588 (-679 (-568))) (|:| |basisDen| (-568)) (|:| |basisInv| (-679 (-568)))) (-568)))) (-1219 (-568)) (-411 (-568) |#1|)) (T -760)) 
+((-2443 (*1 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1219 *3)) (-5 *2 (-2 (|:| -2588 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-5 *1 (-760 *4 *5)) (-4 *5 (-411 *3 *4)))) (-3330 (*1 *2) (-12 (-4 *3 (-1219 (-568))) (-5 *2 (-2 (|:| -2588 (-679 (-568))) (|:| |basisDen| (-568)) (|:| |basisInv| (-679 (-568))))) (-5 *1 (-760 *3 *4)) (-4 *4 (-411 (-568) *3)))) (-3440 (*1 *2) (-12 (-4 *3 (-1219 *2)) (-5 *2 (-568)) (-5 *1 (-760 *3 *4)) (-4 *4 (-411 *2 *3))))) 
+(-10 -7 (-15 -3440 ((-568))) (-15 -3330 ((-2 (|:| -2588 (-679 (-568))) (|:| |basisDen| (-568)) (|:| |basisInv| (-679 (-568)))))) (-15 -2443 ((-2 (|:| -2588 (-679 (-568))) (|:| |basisDen| (-568)) (|:| |basisInv| (-679 (-568)))) (-568)))) 
+((-2449 (((-121) $ $) NIL)) (-2857 (((-3 (|:| |nia| (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| |mdnia| (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) $) 15)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 14) (($ (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 8) (($ (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 10) (($ (-3 (|:| |nia| (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| |mdnia| (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))))) 12)) (-1719 (((-121) $ $) NIL))) 
+(((-761) (-13 (-1090) (-10 -8 (-15 -2747 ($ (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2747 ($ (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2747 ($ (-3 (|:| |nia| (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| |mdnia| (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))))) (-15 -2747 ((-850) $)) (-15 -2857 ((-3 (|:| |nia| (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| |mdnia| (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) $))))) (T -761)) 
+((-2747 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-761)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *1 (-761)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *1 (-761)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-3 (|:| |nia| (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| |mdnia| (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))))) (-5 *1 (-761)))) (-2857 (*1 *2 *1) (-12 (-5 *2 (-3 (|:| |nia| (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| |mdnia| (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))))) (-5 *1 (-761))))) 
+(-13 (-1090) (-10 -8 (-15 -2747 ($ (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2747 ($ (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2747 ($ (-3 (|:| |nia| (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| |mdnia| (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))))) (-15 -2747 ((-850) $)) (-15 -2857 ((-3 (|:| |nia| (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| |mdnia| (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) $)))) 
+((-1993 (((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|))) 14) (((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|)) (-634 (-1161))) 13)) (-3259 (((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|))) 16) (((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|)) (-634 (-1161))) 15))) 
+(((-762 |#1|) (-10 -7 (-15 -1993 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|)) (-634 (-1161)))) (-15 -1993 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|)))) (-15 -3259 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|)) (-634 (-1161)))) (-15 -3259 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|))))) (-558)) (T -762)) 
+((-3259 (*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *4)))))) (-5 *1 (-762 *4)))) (-3259 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-634 (-1161))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *5)))))) (-5 *1 (-762 *5)))) (-1993 (*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *4)))))) (-5 *1 (-762 *4)))) (-1993 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-634 (-1161))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *5)))))) (-5 *1 (-762 *5))))) 
+(-10 -7 (-15 -1993 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|)) (-634 (-1161)))) (-15 -1993 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|)))) (-15 -3259 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|)) (-634 (-1161)))) (-15 -3259 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-953 |#1|))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2409 (($ $ $) 6)) (-2689 (((-3 $ "failed") $ $) 9)) (-1872 (($ $ (-568)) 7)) (-4490 (($) NIL T CONST)) (-2403 (($ $ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1733 (($ $) NIL)) (-2414 (($ $ $) NIL)) (-1598 (((-121) $) NIL)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2723 (($ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-2747 (((-850) $) NIL)) (-1889 (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (* (($ (-763) $) NIL) (($ (-917) $) NIL) (($ $ $) NIL))) 
+(((-763) (-13 (-788) (-716) (-10 -8 (-15 -2414 ($ $ $)) (-15 -2403 ($ $ $)) (-15 -2723 ($ $ $)) (-15 -1854 ((-2 (|:| -4409 $) (|:| -2607 $)) $ $)) (-15 -2597 ((-3 $ "failed") $ $)) (-15 -1872 ($ $ (-568))) (-15 -1733 ($ $)) (-6 (-4523 "*"))))) (T -763)) 
+((-2414 (*1 *1 *1 *1) (-5 *1 (-763))) (-2403 (*1 *1 *1 *1) (-5 *1 (-763))) (-2723 (*1 *1 *1 *1) (-5 *1 (-763))) (-1854 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -4409 (-763)) (|:| -2607 (-763)))) (-5 *1 (-763)))) (-2597 (*1 *1 *1 *1) (|partial| -5 *1 (-763))) (-1872 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-763)))) (-1733 (*1 *1 *1) (-5 *1 (-763)))) 
+(-13 (-788) (-716) (-10 -8 (-15 -2414 ($ $ $)) (-15 -2403 ($ $ $)) (-15 -2723 ($ $ $)) (-15 -1854 ((-2 (|:| -4409 $) (|:| -2607 $)) $ $)) (-15 -2597 ((-3 $ "failed") $ $)) (-15 -1872 ($ $ (-568))) (-15 -1733 ($ $)) (-6 (-4523 "*")))) 
+((-3259 (((-3 |#2| "failed") |#2| |#2| (-123) (-1161)) 35))) 
+(((-764 |#1| |#2|) (-10 -7 (-15 -3259 ((-3 |#2| "failed") |#2| |#2| (-123) (-1161)))) (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150)) (-13 (-29 |#1|) (-1181) (-959))) (T -764)) 
+((-3259 (*1 *2 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-1161)) (-4 *5 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *1 (-764 *5 *2)) (-4 *2 (-13 (-29 *5) (-1181) (-959)))))) 
+(-10 -7 (-15 -3259 ((-3 |#2| "failed") |#2| |#2| (-123) (-1161)))) 
+((-2747 (((-766) |#1|) 8))) 
+(((-765 |#1|) (-10 -7 (-15 -2747 ((-766) |#1|))) (-1195)) (T -765)) 
+((-2747 (*1 *2 *3) (-12 (-5 *2 (-766)) (-5 *1 (-765 *3)) (-4 *3 (-1195))))) 
+(-10 -7 (-15 -2747 ((-766) |#1|))) 
+((-2449 (((-121) $ $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 7)) (-1719 (((-121) $ $) 9))) 
 (((-766) (-1090)) (T -766)) 
 NIL 
 (-1090) 
-((-2657 ((|#2| |#4|) 35))) 
-(((-767 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2657 (|#2| |#4|))) (-453) (-1219 |#1|) (-714 |#1| |#2|) (-1219 |#3|)) (T -767)) 
-((-2657 (*1 *2 *3) (-12 (-4 *4 (-453)) (-4 *5 (-714 *4 *2)) (-4 *2 (-1219 *4)) (-5 *1 (-767 *4 *2 *5 *3)) (-4 *3 (-1219 *5))))) 
-(-10 -7 (-15 -2657 (|#2| |#4|))) 
-((-2925 (((-2 (|:| |num| |#4|) (|:| |den| |#4|)) |#4| |#5|) 56)) (-4381 (((-1249) (-1143) (-1143) |#4| |#5|) 33)) (-2623 ((|#4| |#4| |#5|) 72)) (-3628 (((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#5|) 76)) (-2093 (((-634 (-2 (|:| |val| (-121)) (|:| -3001 |#5|))) |#4| |#5|) 15))) 
-(((-768 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2925 ((-2 (|:| |num| |#4|) (|:| |den| |#4|)) |#4| |#5|)) (-15 -2623 (|#4| |#4| |#5|)) (-15 -3628 ((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#5|)) (-15 -4381 ((-1249) (-1143) (-1143) |#4| |#5|)) (-15 -2093 ((-634 (-2 (|:| |val| (-121)) (|:| -3001 |#5|))) |#4| |#5|))) (-453) (-788) (-842) (-1061 |#1| |#2| |#3|) (-1066 |#1| |#2| |#3| |#4|)) (T -768)) 
-((-2093 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3001 *4)))) (-5 *1 (-768 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-4381 (*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-1143)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *4 (-1061 *6 *7 *8)) (-5 *2 (-1249)) (-5 *1 (-768 *6 *7 *8 *4 *5)) (-4 *5 (-1066 *6 *7 *8 *4)))) (-3628 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *4)))) (-5 *1 (-768 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-2623 (*1 *2 *2 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *2 (-1061 *4 *5 *6)) (-5 *1 (-768 *4 *5 *6 *2 *3)) (-4 *3 (-1066 *4 *5 *6 *2)))) (-2925 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *3))) (-5 *1 (-768 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
-(-10 -7 (-15 -2925 ((-2 (|:| |num| |#4|) (|:| |den| |#4|)) |#4| |#5|)) (-15 -2623 (|#4| |#4| |#5|)) (-15 -3628 ((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#5|)) (-15 -4381 ((-1249) (-1143) (-1143) |#4| |#5|)) (-15 -2093 ((-634 (-2 (|:| |val| (-121)) (|:| -3001 |#5|))) |#4| |#5|))) 
-((-3666 (((-3 (-1157 (-1157 |#1|)) "failed") |#4|) 43)) (-2286 (((-634 |#4|) |#4|) 15)) (-1316 ((|#4| |#4|) 11))) 
-(((-769 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2286 ((-634 |#4|) |#4|)) (-15 -3666 ((-3 (-1157 (-1157 |#1|)) "failed") |#4|)) (-15 -1316 (|#4| |#4|))) (-350) (-327 |#1|) (-1219 |#2|) (-1219 |#3|) (-917)) (T -769)) 
-((-1316 (*1 *2 *2) (-12 (-4 *3 (-350)) (-4 *4 (-327 *3)) (-4 *5 (-1219 *4)) (-5 *1 (-769 *3 *4 *5 *2 *6)) (-4 *2 (-1219 *5)) (-14 *6 (-917)))) (-3666 (*1 *2 *3) (|partial| -12 (-4 *4 (-350)) (-4 *5 (-327 *4)) (-4 *6 (-1219 *5)) (-5 *2 (-1157 (-1157 *4))) (-5 *1 (-769 *4 *5 *6 *3 *7)) (-4 *3 (-1219 *6)) (-14 *7 (-917)))) (-2286 (*1 *2 *3) (-12 (-4 *4 (-350)) (-4 *5 (-327 *4)) (-4 *6 (-1219 *5)) (-5 *2 (-634 *3)) (-5 *1 (-769 *4 *5 *6 *3 *7)) (-4 *3 (-1219 *6)) (-14 *7 (-917))))) 
-(-10 -7 (-15 -2286 ((-634 |#4|) |#4|)) (-15 -3666 ((-3 (-1157 (-1157 |#1|)) "failed") |#4|)) (-15 -1316 (|#4| |#4|))) 
-((-2447 (((-121) $ $) NIL)) (-2671 (($) NIL T CONST)) (-2854 (($ (-1201 |#1|)) 21)) (-2925 (((-3 $ "failed") $) NIL)) (-2735 (((-121) $) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) 26)) (-4022 (((-1108) $) NIL)) (-1458 (($ $ $) NIL)) (-2353 (($ $ $) NIL)) (-2745 (((-850) $) 11)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-1556 (($) 18 T CONST)) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ $ $) 24))) 
-(((-770 |#1|) (-13 (-478) (-10 -8 (-15 -2854 ($ (-1201 |#1|))))) (-350)) (T -770)) 
-((-2854 (*1 *1 *2) (-12 (-5 *2 (-1201 *3)) (-4 *3 (-350)) (-5 *1 (-770 *3))))) 
-(-13 (-478) (-10 -8 (-15 -2854 ($ (-1201 |#1|))))) 
-((-2792 (((-2 (|:| |deter| (-634 (-1157 |#5|))) (|:| |dterm| (-634 (-634 (-2 (|:| -1876 (-763)) (|:| |pcoef| |#5|))))) (|:| |nfacts| (-634 |#1|)) (|:| |nlead| (-634 |#5|))) (-1157 |#5|) (-634 |#1|) (-634 |#5|)) 51)) (-2397 (((-634 (-763)) |#1|) 12))) 
-(((-771 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2792 ((-2 (|:| |deter| (-634 (-1157 |#5|))) (|:| |dterm| (-634 (-634 (-2 (|:| -1876 (-763)) (|:| |pcoef| |#5|))))) (|:| |nfacts| (-634 |#1|)) (|:| |nlead| (-634 |#5|))) (-1157 |#5|) (-634 |#1|) (-634 |#5|))) (-15 -2397 ((-634 (-763)) |#1|))) (-1219 |#4|) (-788) (-842) (-301) (-950 |#4| |#2| |#3|)) (T -771)) 
-((-2397 (*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)) (-5 *2 (-634 (-763))) (-5 *1 (-771 *3 *4 *5 *6 *7)) (-4 *3 (-1219 *6)) (-4 *7 (-950 *6 *4 *5)))) (-2792 (*1 *2 *3 *4 *5) (-12 (-4 *6 (-1219 *9)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *9 (-301)) (-4 *10 (-950 *9 *7 *8)) (-5 *2 (-2 (|:| |deter| (-634 (-1157 *10))) (|:| |dterm| (-634 (-634 (-2 (|:| -1876 (-763)) (|:| |pcoef| *10))))) (|:| |nfacts| (-634 *6)) (|:| |nlead| (-634 *10)))) (-5 *1 (-771 *6 *7 *8 *9 *10)) (-5 *3 (-1157 *10)) (-5 *4 (-634 *6)) (-5 *5 (-634 *10))))) 
-(-10 -7 (-15 -2792 ((-2 (|:| |deter| (-634 (-1157 |#5|))) (|:| |dterm| (-634 (-634 (-2 (|:| -1876 (-763)) (|:| |pcoef| |#5|))))) (|:| |nfacts| (-634 |#1|)) (|:| |nlead| (-634 |#5|))) (-1157 |#5|) (-634 |#1|) (-634 |#5|))) (-15 -2397 ((-634 (-763)) |#1|))) 
-((-1657 (((-2 (|:| -2961 (-568)) (|:| -1461 (-568)) (|:| -3961 (-568)) (|:| |reste| (-568)) (|:| -2219 (-3 "left" "center" "right" "vertical" "horizontal"))) (-634 |#2|)) 18) (((-2 (|:| -2961 (-568)) (|:| -1461 (-568)) (|:| -3961 (-568)) (|:| |reste| (-568)) (|:| -2219 (-3 "left" "center" "right" "vertical" "horizontal"))) |#2| |#2|) 16)) (-2312 (((-634 (-634 |#2|)) |#2| (-568) (-568) (-3 "left" "center" "right" "vertical" "horizontal")) 32)) (-2396 (((-634 (-634 |#2|)) |#2| (-634 (-634 |#2|))) 24)) (-4029 (((-763) (-634 (-634 |#2|))) 27))) 
-(((-772 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2312 ((-634 (-634 |#2|)) |#2| (-568) (-568) (-3 "left" "center" "right" "vertical" "horizontal"))) (-15 -4029 ((-763) (-634 (-634 |#2|)))) (-15 -2396 ((-634 (-634 |#2|)) |#2| (-634 (-634 |#2|)))) (-15 -1657 ((-2 (|:| -2961 (-568)) (|:| -1461 (-568)) (|:| -3961 (-568)) (|:| |reste| (-568)) (|:| -2219 (-3 "left" "center" "right" "vertical" "horizontal"))) |#2| |#2|)) (-15 -1657 ((-2 (|:| -2961 (-568)) (|:| -1461 (-568)) (|:| -3961 (-568)) (|:| |reste| (-568)) (|:| -2219 (-3 "left" "center" "right" "vertical" "horizontal"))) (-634 |#2|)))) (-1047) (-324 |#1| |#3|) (-230 |#4| (-763)) (-763)) (T -772)) 
-((-1657 (*1 *2 *3) (-12 (-5 *3 (-634 *5)) (-4 *5 (-324 *4 *6)) (-4 *6 (-230 *7 (-763))) (-14 *7 (-763)) (-4 *4 (-1047)) (-5 *2 (-2 (|:| -2961 (-568)) (|:| -1461 (-568)) (|:| -3961 (-568)) (|:| |reste| (-568)) (|:| -2219 (-3 "left" "center" "right" "vertical" "horizontal")))) (-5 *1 (-772 *4 *5 *6 *7)))) (-1657 (*1 *2 *3 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *2 (-2 (|:| -2961 (-568)) (|:| -1461 (-568)) (|:| -3961 (-568)) (|:| |reste| (-568)) (|:| -2219 (-3 "left" "center" "right" "vertical" "horizontal")))) (-5 *1 (-772 *4 *3 *5 *6)) (-4 *3 (-324 *4 *5)))) (-2396 (*1 *2 *3 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-324 *4 *5)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-4 *4 (-1047)) (-5 *1 (-772 *4 *3 *5 *6)))) (-4029 (*1 *2 *3) (-12 (-5 *3 (-634 (-634 *5))) (-4 *5 (-324 *4 *6)) (-4 *6 (-230 *7 *2)) (-14 *7 *2) (-4 *4 (-1047)) (-5 *2 (-763)) (-5 *1 (-772 *4 *5 *6 *7)))) (-2312 (*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-568)) (-5 *5 (-3 "left" "center" "right" "vertical" "horizontal")) (-4 *6 (-1047)) (-4 *7 (-230 *8 (-763))) (-14 *8 (-763)) (-5 *2 (-634 (-634 *3))) (-5 *1 (-772 *6 *3 *7 *8)) (-4 *3 (-324 *6 *7))))) 
-(-10 -7 (-15 -2312 ((-634 (-634 |#2|)) |#2| (-568) (-568) (-3 "left" "center" "right" "vertical" "horizontal"))) (-15 -4029 ((-763) (-634 (-634 |#2|)))) (-15 -2396 ((-634 (-634 |#2|)) |#2| (-634 (-634 |#2|)))) (-15 -1657 ((-2 (|:| -2961 (-568)) (|:| -1461 (-568)) (|:| -3961 (-568)) (|:| |reste| (-568)) (|:| -2219 (-3 "left" "center" "right" "vertical" "horizontal"))) |#2| |#2|)) (-15 -1657 ((-2 (|:| -2961 (-568)) (|:| -1461 (-568)) (|:| -3961 (-568)) (|:| |reste| (-568)) (|:| -2219 (-3 "left" "center" "right" "vertical" "horizontal"))) (-634 |#2|)))) 
-((-1757 (((-634 (-2 (|:| |outval| |#1|) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 |#1|))))) (-679 (-409 (-568))) |#1|) 27)) (-2179 (((-634 |#1|) (-679 (-409 (-568))) |#1|) 19)) (-2678 (((-953 (-409 (-568))) (-679 (-409 (-568))) (-1161)) 16) (((-953 (-409 (-568))) (-679 (-409 (-568)))) 15))) 
-(((-773 |#1|) (-10 -7 (-15 -2678 ((-953 (-409 (-568))) (-679 (-409 (-568))))) (-15 -2678 ((-953 (-409 (-568))) (-679 (-409 (-568))) (-1161))) (-15 -2179 ((-634 |#1|) (-679 (-409 (-568))) |#1|)) (-15 -1757 ((-634 (-2 (|:| |outval| |#1|) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 |#1|))))) (-679 (-409 (-568))) |#1|))) (-13 (-365) (-840))) (T -773)) 
-((-1757 (*1 *2 *3 *4) (-12 (-5 *3 (-679 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| |outval| *4) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 *4)))))) (-5 *1 (-773 *4)) (-4 *4 (-13 (-365) (-840))))) (-2179 (*1 *2 *3 *4) (-12 (-5 *3 (-679 (-409 (-568)))) (-5 *2 (-634 *4)) (-5 *1 (-773 *4)) (-4 *4 (-13 (-365) (-840))))) (-2678 (*1 *2 *3 *4) (-12 (-5 *3 (-679 (-409 (-568)))) (-5 *4 (-1161)) (-5 *2 (-953 (-409 (-568)))) (-5 *1 (-773 *5)) (-4 *5 (-13 (-365) (-840))))) (-2678 (*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-568)))) (-5 *2 (-953 (-409 (-568)))) (-5 *1 (-773 *4)) (-4 *4 (-13 (-365) (-840)))))) 
-(-10 -7 (-15 -2678 ((-953 (-409 (-568))) (-679 (-409 (-568))))) (-15 -2678 ((-953 (-409 (-568))) (-679 (-409 (-568))) (-1161))) (-15 -2179 ((-634 |#1|) (-679 (-409 (-568))) |#1|)) (-15 -1757 ((-634 (-2 (|:| |outval| |#1|) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 |#1|))))) (-679 (-409 (-568))) |#1|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 10)) (-2055 (((-634 (-1075)) $) NIL)) (-1305 (((-1161) $) NIL)) (-2850 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-2617 (($ $ (-568) (-568)) NIL) (($ $ (-568)) NIL)) (-2235 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $) NIL)) (-2583 (((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL)) (-2796 (($ $) NIL)) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-3910 (($ $ (-568)) NIL (|has| $ (-6 -4520)))) (-1497 (((-121) $ $) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-1870 (($ $ (-568)) 36)) (-1659 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4520)))) (-3869 (($ $ $) NIL (|has| $ (-6 -4520)))) (-2395 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4520)))) (-2517 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4520)))) (-2436 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-568) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4520))) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-1210 (-568)) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4520))) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ "last" (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4520))) (($ $ "rest" $) NIL (|has| $ (-6 -4520))) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ "first" (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4520))) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ "value" (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) NIL (|has| $ (-6 -4520)))) (-3728 (($ (-568) |#1| $) 41)) (-2801 (($ (-1 (-121) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL)) (-1679 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $) NIL)) (-3975 (($ $ $) 51)) (-2671 (($) NIL T CONST)) (-1496 (($ $) 21)) (-3935 (($ $ (-763)) NIL) (($ $) 14)) (-1429 (($ (-568) $) 78) (($ $) 31)) (-2255 (($ $) 35)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090))))) (-4328 (($ (-1 (-121) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL) (($ (-2 (|:| |k| (-568)) (|:| |c| |#1|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090))))) (-2401 (($ $ $) NIL)) (-2114 (($ $) NIL)) (-3092 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1 (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $ (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090)))) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1 (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $ (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4519))) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1 (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4519)))) (-2925 (((-3 $ "failed") $) 38)) (-2412 (($ $ $) NIL)) (-3989 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-568) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4520)))) (-2602 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-568)) NIL)) (-1277 (((-121) (-121)) 30) (((-121)) 29)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-1601 (((-121) $) NIL)) (-2421 (($ $) 22)) (-3992 (((-121) $) NIL)) (-4360 (((-634 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4519)))) (-2455 (((-3 (-568) "failed") $) 16)) (-4477 (((-568) $ (-568)) NIL) (((-568) $) 19) (((-568) $) 19)) (-2735 (((-121) $) NIL)) (-3836 (((-763) $) NIL)) (-2287 (((-634 $) $) NIL)) (-1700 (((-121) $ $) NIL (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090)))) (-1849 (($ (-763) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL)) (-3536 (($ $ (-917)) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1737 (((-121) $ (-763)) NIL)) (-3921 (((-121) $) NIL)) (-2662 (($ (-634 $) (-634 (-763)) (-568)) 85)) (-2047 (($ $ (-634 (-1075)) (-634 (-568))) NIL) (($ $ (-1075) (-568)) NIL) (($ |#1| (-568)) NIL)) (-1881 (((-568) $) NIL (|has| (-568) (-842)))) (-1979 (((-634 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) (-2 (|:| |k| (-568)) (|:| |c| |#1|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090))))) (-2223 (((-568) $) NIL (|has| (-568) (-842)))) (-3674 (($ (-1 (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $ $) NIL) (($ (-1 (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-2869 (((-634 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL)) (-1651 (((-121) $) NIL)) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-2892 (($ $) NIL)) (-3851 (((-121) $) NIL)) (-4487 (((-1143) $) NIL)) (-4162 (($ $ (-763)) NIL) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $) NIL)) (-2081 (($ $) 39)) (-4122 (($ (-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3121 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $) 12)) (-3876 (($ $ (-763)) NIL) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $) NIL)) (-1682 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-568)) 24)) (-1987 ((|#1| $ (-568)) 25)) (-3775 (((-3 (-2 (|:| |k| (-568)) (|:| |c| |#1|)) "failed") (-1 (-121) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL)) (-4273 (($ $ (-568)) 89)) (-3724 (($ $ (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4520)))) (-3848 (((-420 $) $) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1807 (($ $ (-568)) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1786 (((-121) $) NIL)) (-1368 (((-121) $) NIL)) (-3552 (((-121) $) NIL)) (-1387 (((-121) (-1 (-121) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4519)))) (-1339 (((-1141 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-568))))) (($ $ (-634 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) (-634 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) NIL (-12 (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-303 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090)))) (($ $ (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (-12 (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-303 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090)))) (($ $ (-288 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) NIL (-12 (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-303 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090)))) (($ $ (-634 (-288 (-2 (|:| |k| (-568)) (|:| |c| |#1|))))) NIL (-12 (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-303 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090))))) (-2709 (((-763) $) NIL)) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) (-2 (|:| |k| (-568)) (|:| |c| |#1|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090))))) (-2041 (((-634 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL)) (-3084 (((-121) $) 23)) (-3248 (($) 94)) (-2779 (($ $ $) NIL (|has| (-568) (-1102))) ((|#1| $ (-568)) NIL) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-568) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-568)) NIL) (($ $ (-1210 (-568))) NIL) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ "last") NIL) (($ $ "rest") NIL) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ "first") NIL) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ "value") NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-4075 (((-568) $ $) NIL)) (-4189 (($ $) NIL (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (-2826 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-4493 (($ (-1 $)) 34)) (-3206 (((-568) $) NIL)) (-3790 (((-121) $) NIL)) (-2340 (($ $) NIL)) (-2714 (($ $) NIL (|has| $ (-6 -4520)))) (-2775 (((-763) $) NIL)) (-3335 (($ $) NIL)) (-4168 (((-763) (-2 (|:| |k| (-568)) (|:| |c| |#1|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090)))) (((-763) (-1 (-121) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4519)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-609 (-541))))) (-4287 (($ (-634 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) 95)) (-3845 (($ $ (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4520))) (($ $ $) NIL (|has| $ (-6 -4520)))) (-2768 (($ $ (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL) (($ (-634 $)) NIL) (($ (-2 (|:| |k| (-568)) (|:| |c| |#1|)) $) 32) (($ $ $) NIL)) (-1811 (($ $) NIL)) (-2745 (((-850) $) 65) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ |#1|) NIL (|has| |#1| (-172))) (($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) 27) (((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) 26)) (-2604 ((|#1| $ (-568)) NIL)) (-4447 ((|#1| $) 86)) (-4339 (((-634 $) $) NIL)) (-3491 (((-121) $ $) NIL (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090)))) (-4371 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-4078 (((-763)) NIL)) (-1374 ((|#1| $) NIL)) (-1826 (((-121) $ $) NIL)) (-3996 ((|#1| $ (-568)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-568)))) (|has| |#1| (-15 -2745 (|#1| (-1161))))))) (-1319 (((-121) (-1 (-121) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4519)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) 17 T CONST)) (-1556 (($) 74 T CONST)) (-3190 (($ $) NIL (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ $) NIL) (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1773 (($ $) 47) (($ $ $) 43)) (-1767 (($ $ $) 53)) (** (($ $ (-917)) NIL) (($ $ (-763)) 79) (($ $ (-568)) 52)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 42) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ |#1| $) 46) (($ $ |#1|) 100)) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-774 |#1|) (-13 (-641 |#1|) (-665 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) (-10 -8 (-15 -1682 ((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-568))))) (-365)) (T -774)) 
-((-1682 (*1 *2 *1 *3) (-12 (-5 *2 (-2 (|:| |k| (-568)) (|:| |c| *4))) (-5 *1 (-774 *4)) (-4 *4 (-365)) (-5 *3 (-568))))) 
-(-13 (-641 |#1|) (-665 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) (-10 -8 (-15 -1682 ((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-568))))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 34)) (-2055 (((-634 |#2|) $) NIL)) (-3839 (((-1157 $) $ |#2|) NIL) (((-1157 |#1|) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-2773 (((-763) $) NIL) (((-763) $ (-634 |#2|)) NIL)) (-2796 (($ $) 28)) (-3653 (((-121) $ $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-3809 (($ $ $) 92 (|has| |#1| (-558)))) (-3909 (((-634 $) $ $) 105 (|has| |#1| (-558)))) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-4305 (($ $) NIL (|has| |#1| (-453)))) (-1678 (((-420 $) $) NIL (|has| |#1| (-453)))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 |#2| "failed") $) NIL) (((-3 $ "failed") (-953 (-409 (-568)))) NIL (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#2| (-609 (-1161))))) (((-3 $ "failed") (-953 (-568))) NIL (-2198 (-12 (|has| |#1| (-43 (-568))) (|has| |#2| (-609 (-1161))) (-3044 (|has| |#1| (-43 (-409 (-568)))))) (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#2| (-609 (-1161)))))) (((-3 $ "failed") (-953 |#1|)) NIL (-2198 (-12 (|has| |#2| (-609 (-1161))) (-3044 (|has| |#1| (-43 (-409 (-568))))) (-3044 (|has| |#1| (-43 (-568))))) (-12 (|has| |#1| (-43 (-568))) (|has| |#2| (-609 (-1161))) (-3044 (|has| |#1| (-43 (-409 (-568))))) (-3044 (|has| |#1| (-550)))) (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#2| (-609 (-1161))) (-3044 (|has| |#1| (-993 (-568))))))) (((-3 (-1113 |#1| |#2|) "failed") $) 18)) (-2854 ((|#1| $) NIL) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#1| (-1037 (-568)))) ((|#2| $) NIL) (($ (-953 (-409 (-568)))) NIL (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#2| (-609 (-1161))))) (($ (-953 (-568))) NIL (-2198 (-12 (|has| |#1| (-43 (-568))) (|has| |#2| (-609 (-1161))) (-3044 (|has| |#1| (-43 (-409 (-568)))))) (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#2| (-609 (-1161)))))) (($ (-953 |#1|)) NIL (-2198 (-12 (|has| |#2| (-609 (-1161))) (-3044 (|has| |#1| (-43 (-409 (-568))))) (-3044 (|has| |#1| (-43 (-568))))) (-12 (|has| |#1| (-43 (-568))) (|has| |#2| (-609 (-1161))) (-3044 (|has| |#1| (-43 (-409 (-568))))) (-3044 (|has| |#1| (-550)))) (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#2| (-609 (-1161))) (-3044 (|has| |#1| (-993 (-568))))))) (((-1113 |#1| |#2|) $) NIL)) (-4265 (($ $ $ |#2|) NIL (|has| |#1| (-172))) (($ $ $) 103 (|has| |#1| (-558)))) (-2114 (($ $) NIL) (($ $ |#2|) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-1281 (((-121) $ $) NIL) (((-121) $ (-634 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-4054 (((-121) $) NIL)) (-4144 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 69)) (-2053 (($ $) 118 (|has| |#1| (-453)))) (-3250 (($ $) NIL (|has| |#1| (-453))) (($ $ |#2|) NIL (|has| |#1| (-453)))) (-2108 (((-634 $) $) NIL)) (-3927 (((-121) $) NIL (|has| |#1| (-904)))) (-3069 (($ $) NIL (|has| |#1| (-558)))) (-3431 (($ $) NIL (|has| |#1| (-558)))) (-4293 (($ $ $) 64) (($ $ $ |#2|) NIL)) (-2875 (($ $ $) 67) (($ $ $ |#2|) NIL)) (-3088 (($ $ |#1| (-534 |#2|) $) NIL)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| |#1| (-881 (-381))) (|has| |#2| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| |#1| (-881 (-568))) (|has| |#2| (-881 (-568)))))) (-2735 (((-121) $) NIL)) (-4178 (((-763) $) NIL)) (-1362 (((-121) $ $) NIL) (((-121) $ (-634 $)) NIL)) (-4396 (($ $ $ $ $) 89 (|has| |#1| (-558)))) (-2356 ((|#2| $) 19)) (-2051 (($ (-1157 |#1|) |#2|) NIL) (($ (-1157 $) |#2|) NIL)) (-2976 (((-634 $) $) NIL)) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| (-534 |#2|)) NIL) (($ $ |#2| (-763)) 36) (($ $ (-634 |#2|) (-634 (-763))) NIL)) (-2507 (($ $ $) 60)) (-3379 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $ |#2|) NIL)) (-2278 (((-121) $) NIL)) (-2144 (((-534 |#2|) $) NIL) (((-763) $ |#2|) NIL) (((-634 (-763)) $ (-634 |#2|)) NIL)) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-3838 (((-763) $) 20)) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-3842 (($ (-1 (-534 |#2|) (-534 |#2|)) $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-2244 (((-3 |#2| "failed") $) NIL)) (-3290 (($ $) NIL (|has| |#1| (-453)))) (-2297 (($ $) NIL (|has| |#1| (-453)))) (-4093 (((-634 $) $) NIL)) (-2429 (($ $) 37)) (-2111 (($ $) NIL (|has| |#1| (-453)))) (-2380 (((-634 $) $) 41)) (-2104 (($ $) 39)) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL) (($ $ |#2|) 45)) (-2495 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-2280 (((-2 (|:| |polnum| $) (|:| |polden| $) (|:| -3741 (-763))) $ $) 81)) (-3547 (((-2 (|:| -2348 $) (|:| |gap| (-763)) (|:| -3961 $) (|:| -1500 $)) $ $) 66) (((-2 (|:| -2348 $) (|:| |gap| (-763)) (|:| -3961 $) (|:| -1500 $)) $ $ |#2|) NIL)) (-2409 (((-2 (|:| -2348 $) (|:| |gap| (-763)) (|:| -1500 $)) $ $) NIL) (((-2 (|:| -2348 $) (|:| |gap| (-763)) (|:| -1500 $)) $ $ |#2|) NIL)) (-3413 (($ $ $) 71) (($ $ $ |#2|) NIL)) (-3774 (($ $ $) 74) (($ $ $ |#2|) NIL)) (-4487 (((-1143) $) NIL)) (-4330 (($ $ $) 107 (|has| |#1| (-558)))) (-1901 (((-634 $) $) 30)) (-3324 (((-3 (-634 $) "failed") $) NIL)) (-1794 (((-3 (-634 $) "failed") $) NIL)) (-3751 (((-3 (-2 (|:| |var| |#2|) (|:| -3438 (-763))) "failed") $) NIL)) (-1415 (((-121) $ $) NIL) (((-121) $ (-634 $)) NIL)) (-2682 (($ $ $) NIL)) (-4434 (($ $) 21)) (-2644 (((-121) $ $) NIL)) (-4347 (((-121) $ $) NIL) (((-121) $ (-634 $)) NIL)) (-4025 (($ $ $) NIL)) (-1733 (($ $) 23)) (-4022 (((-1108) $) NIL)) (-2879 (((-2 (|:| -2721 $) (|:| |coef2| $)) $ $) 98 (|has| |#1| (-558)))) (-3203 (((-2 (|:| -2721 $) (|:| |coef1| $)) $ $) 95 (|has| |#1| (-558)))) (-2086 (((-121) $) 52)) (-2091 ((|#1| $) 55)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-453)))) (-2721 ((|#1| |#1| $) 115 (|has| |#1| (-453))) (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3848 (((-420 $) $) NIL (|has| |#1| (-904)))) (-1297 (((-2 (|:| -2721 $) (|:| |coef1| $) (|:| |coef2| $)) $ $) 101 (|has| |#1| (-558)))) (-2595 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558))) (((-3 $ "failed") $ $) 83 (|has| |#1| (-558)))) (-3055 (($ $ |#1|) 111 (|has| |#1| (-558))) (($ $ $) NIL (|has| |#1| (-558)))) (-4049 (($ $ |#1|) 110 (|has| |#1| (-558))) (($ $ $) NIL (|has| |#1| (-558)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ |#2| |#1|) NIL) (($ $ (-634 |#2|) (-634 |#1|)) NIL) (($ $ |#2| $) NIL) (($ $ (-634 |#2|) (-634 $)) NIL)) (-2217 (($ $ |#2|) NIL (|has| |#1| (-172)))) (-4189 (($ $ |#2|) NIL) (($ $ (-634 |#2|)) NIL) (($ $ |#2| (-763)) NIL) (($ $ (-634 |#2|) (-634 (-763))) NIL)) (-3206 (((-534 |#2|) $) NIL) (((-763) $ |#2|) 43) (((-634 (-763)) $ (-634 |#2|)) NIL)) (-1595 (($ $) NIL)) (-2734 (($ $) 33)) (-4278 (((-887 (-381)) $) NIL (-12 (|has| |#1| (-609 (-887 (-381)))) (|has| |#2| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| |#1| (-609 (-887 (-568)))) (|has| |#2| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| |#1| (-609 (-541))) (|has| |#2| (-609 (-541))))) (($ (-953 (-409 (-568)))) NIL (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#2| (-609 (-1161))))) (($ (-953 (-568))) NIL (-2198 (-12 (|has| |#1| (-43 (-568))) (|has| |#2| (-609 (-1161))) (-3044 (|has| |#1| (-43 (-409 (-568)))))) (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#2| (-609 (-1161)))))) (($ (-953 |#1|)) NIL (|has| |#2| (-609 (-1161)))) (((-1143) $) NIL (-12 (|has| |#1| (-1037 (-568))) (|has| |#2| (-609 (-1161))))) (((-953 |#1|) $) NIL (|has| |#2| (-609 (-1161))))) (-3367 ((|#1| $) 114 (|has| |#1| (-453))) (($ $ |#2|) NIL (|has| |#1| (-453)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#1| (-904))))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL) (($ |#2|) NIL) (((-953 |#1|) $) NIL (|has| |#2| (-609 (-1161)))) (((-1113 |#1| |#2|) $) 15) (($ (-1113 |#1| |#2|)) 16) (($ (-409 (-568))) NIL (-2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#1| (-558)))) (-1302 (((-634 |#1|) $) NIL)) (-2604 ((|#1| $ (-534 |#2|)) NIL) (($ $ |#2| (-763)) 44) (($ $ (-634 |#2|) (-634 (-763))) NIL)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-4078 (((-763)) NIL)) (-4171 (($ $ $ (-763)) NIL (|has| |#1| (-172)))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 13 T CONST)) (-3601 (((-3 (-121) "failed") $ $) NIL)) (-1556 (($) 35 T CONST)) (-2361 (($ $ $ $ (-763)) 87 (|has| |#1| (-558)))) (-2156 (($ $ $ (-763)) 86 (|has| |#1| (-558)))) (-3190 (($ $ |#2|) NIL) (($ $ (-634 |#2|)) NIL) (($ $ |#2| (-763)) NIL) (($ $ (-634 |#2|) (-634 (-763))) NIL)) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) 54)) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) 63)) (-1767 (($ $ $) 73)) (** (($ $ (-917)) NIL) (($ $ (-763)) 61)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 59) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) 58) (($ $ |#1|) NIL))) 
+((-4417 ((|#2| |#4|) 35))) 
+(((-767 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4417 (|#2| |#4|))) (-453) (-1219 |#1|) (-714 |#1| |#2|) (-1219 |#3|)) (T -767)) 
+((-4417 (*1 *2 *3) (-12 (-4 *4 (-453)) (-4 *5 (-714 *4 *2)) (-4 *2 (-1219 *4)) (-5 *1 (-767 *4 *2 *5 *3)) (-4 *3 (-1219 *5))))) 
+(-10 -7 (-15 -4417 (|#2| |#4|))) 
+((-2902 (((-2 (|:| |num| |#4|) (|:| |den| |#4|)) |#4| |#5|) 56)) (-1356 (((-1249) (-1143) (-1143) |#4| |#5|) 33)) (-4219 ((|#4| |#4| |#5|) 72)) (-3126 (((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#5|) 76)) (-3164 (((-634 (-2 (|:| |val| (-121)) (|:| -3145 |#5|))) |#4| |#5|) 15))) 
+(((-768 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2902 ((-2 (|:| |num| |#4|) (|:| |den| |#4|)) |#4| |#5|)) (-15 -4219 (|#4| |#4| |#5|)) (-15 -3126 ((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#5|)) (-15 -1356 ((-1249) (-1143) (-1143) |#4| |#5|)) (-15 -3164 ((-634 (-2 (|:| |val| (-121)) (|:| -3145 |#5|))) |#4| |#5|))) (-453) (-788) (-842) (-1061 |#1| |#2| |#3|) (-1066 |#1| |#2| |#3| |#4|)) (T -768)) 
+((-3164 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3145 *4)))) (-5 *1 (-768 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-1356 (*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-1143)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *4 (-1061 *6 *7 *8)) (-5 *2 (-1249)) (-5 *1 (-768 *6 *7 *8 *4 *5)) (-4 *5 (-1066 *6 *7 *8 *4)))) (-3126 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *4)))) (-5 *1 (-768 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-4219 (*1 *2 *2 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *2 (-1061 *4 *5 *6)) (-5 *1 (-768 *4 *5 *6 *2 *3)) (-4 *3 (-1066 *4 *5 *6 *2)))) (-2902 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *3))) (-5 *1 (-768 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
+(-10 -7 (-15 -2902 ((-2 (|:| |num| |#4|) (|:| |den| |#4|)) |#4| |#5|)) (-15 -4219 (|#4| |#4| |#5|)) (-15 -3126 ((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#5|)) (-15 -1356 ((-1249) (-1143) (-1143) |#4| |#5|)) (-15 -3164 ((-634 (-2 (|:| |val| (-121)) (|:| -3145 |#5|))) |#4| |#5|))) 
+((-3668 (((-3 (-1157 (-1157 |#1|)) "failed") |#4|) 43)) (-3527 (((-634 |#4|) |#4|) 15)) (-3412 ((|#4| |#4|) 11))) 
+(((-769 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3527 ((-634 |#4|) |#4|)) (-15 -3668 ((-3 (-1157 (-1157 |#1|)) "failed") |#4|)) (-15 -3412 (|#4| |#4|))) (-350) (-327 |#1|) (-1219 |#2|) (-1219 |#3|) (-917)) (T -769)) 
+((-3412 (*1 *2 *2) (-12 (-4 *3 (-350)) (-4 *4 (-327 *3)) (-4 *5 (-1219 *4)) (-5 *1 (-769 *3 *4 *5 *2 *6)) (-4 *2 (-1219 *5)) (-14 *6 (-917)))) (-3668 (*1 *2 *3) (|partial| -12 (-4 *4 (-350)) (-4 *5 (-327 *4)) (-4 *6 (-1219 *5)) (-5 *2 (-1157 (-1157 *4))) (-5 *1 (-769 *4 *5 *6 *3 *7)) (-4 *3 (-1219 *6)) (-14 *7 (-917)))) (-3527 (*1 *2 *3) (-12 (-4 *4 (-350)) (-4 *5 (-327 *4)) (-4 *6 (-1219 *5)) (-5 *2 (-634 *3)) (-5 *1 (-769 *4 *5 *6 *3 *7)) (-4 *3 (-1219 *6)) (-14 *7 (-917))))) 
+(-10 -7 (-15 -3527 ((-634 |#4|) |#4|)) (-15 -3668 ((-3 (-1157 (-1157 |#1|)) "failed") |#4|)) (-15 -3412 (|#4| |#4|))) 
+((-2449 (((-121) $ $) NIL)) (-4490 (($) NIL T CONST)) (-2857 (($ (-1201 |#1|)) 21)) (-2902 (((-3 $ "failed") $) NIL)) (-1598 (((-121) $) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) 26)) (-4025 (((-1108) $) NIL)) (-2387 (($ $ $) NIL)) (-3985 (($ $ $) NIL)) (-2747 (((-850) $) 11)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-1557 (($) 18 T CONST)) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ $ $) 24))) 
+(((-770 |#1|) (-13 (-478) (-10 -8 (-15 -2857 ($ (-1201 |#1|))))) (-350)) (T -770)) 
+((-2857 (*1 *1 *2) (-12 (-5 *2 (-1201 *3)) (-4 *3 (-350)) (-5 *1 (-770 *3))))) 
+(-13 (-478) (-10 -8 (-15 -2857 ($ (-1201 |#1|))))) 
+((-3608 (((-2 (|:| |deter| (-634 (-1157 |#5|))) (|:| |dterm| (-634 (-634 (-2 (|:| -2514 (-763)) (|:| |pcoef| |#5|))))) (|:| |nfacts| (-634 |#1|)) (|:| |nlead| (-634 |#5|))) (-1157 |#5|) (-634 |#1|) (-634 |#5|)) 51)) (-2266 (((-634 (-763)) |#1|) 12))) 
+(((-771 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3608 ((-2 (|:| |deter| (-634 (-1157 |#5|))) (|:| |dterm| (-634 (-634 (-2 (|:| -2514 (-763)) (|:| |pcoef| |#5|))))) (|:| |nfacts| (-634 |#1|)) (|:| |nlead| (-634 |#5|))) (-1157 |#5|) (-634 |#1|) (-634 |#5|))) (-15 -2266 ((-634 (-763)) |#1|))) (-1219 |#4|) (-788) (-842) (-301) (-950 |#4| |#2| |#3|)) (T -771)) 
+((-2266 (*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)) (-5 *2 (-634 (-763))) (-5 *1 (-771 *3 *4 *5 *6 *7)) (-4 *3 (-1219 *6)) (-4 *7 (-950 *6 *4 *5)))) (-3608 (*1 *2 *3 *4 *5) (-12 (-4 *6 (-1219 *9)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *9 (-301)) (-4 *10 (-950 *9 *7 *8)) (-5 *2 (-2 (|:| |deter| (-634 (-1157 *10))) (|:| |dterm| (-634 (-634 (-2 (|:| -2514 (-763)) (|:| |pcoef| *10))))) (|:| |nfacts| (-634 *6)) (|:| |nlead| (-634 *10)))) (-5 *1 (-771 *6 *7 *8 *9 *10)) (-5 *3 (-1157 *10)) (-5 *4 (-634 *6)) (-5 *5 (-634 *10))))) 
+(-10 -7 (-15 -3608 ((-2 (|:| |deter| (-634 (-1157 |#5|))) (|:| |dterm| (-634 (-634 (-2 (|:| -2514 (-763)) (|:| |pcoef| |#5|))))) (|:| |nfacts| (-634 |#1|)) (|:| |nlead| (-634 |#5|))) (-1157 |#5|) (-634 |#1|) (-634 |#5|))) (-15 -2266 ((-634 (-763)) |#1|))) 
+((-3355 (((-2 (|:| -2963 (-568)) (|:| -2404 (-568)) (|:| -4409 (-568)) (|:| |reste| (-568)) (|:| -2221 (-3 "left" "center" "right" "vertical" "horizontal"))) (-634 |#2|)) 18) (((-2 (|:| -2963 (-568)) (|:| -2404 (-568)) (|:| -4409 (-568)) (|:| |reste| (-568)) (|:| -2221 (-3 "left" "center" "right" "vertical" "horizontal"))) |#2| |#2|) 16)) (-3727 (((-634 (-634 |#2|)) |#2| (-568) (-568) (-3 "left" "center" "right" "vertical" "horizontal")) 32)) (-2263 (((-634 (-634 |#2|)) |#2| (-634 (-634 |#2|))) 24)) (-1470 (((-763) (-634 (-634 |#2|))) 27))) 
+(((-772 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3727 ((-634 (-634 |#2|)) |#2| (-568) (-568) (-3 "left" "center" "right" "vertical" "horizontal"))) (-15 -1470 ((-763) (-634 (-634 |#2|)))) (-15 -2263 ((-634 (-634 |#2|)) |#2| (-634 (-634 |#2|)))) (-15 -3355 ((-2 (|:| -2963 (-568)) (|:| -2404 (-568)) (|:| -4409 (-568)) (|:| |reste| (-568)) (|:| -2221 (-3 "left" "center" "right" "vertical" "horizontal"))) |#2| |#2|)) (-15 -3355 ((-2 (|:| -2963 (-568)) (|:| -2404 (-568)) (|:| -4409 (-568)) (|:| |reste| (-568)) (|:| -2221 (-3 "left" "center" "right" "vertical" "horizontal"))) (-634 |#2|)))) (-1047) (-324 |#1| |#3|) (-230 |#4| (-763)) (-763)) (T -772)) 
+((-3355 (*1 *2 *3) (-12 (-5 *3 (-634 *5)) (-4 *5 (-324 *4 *6)) (-4 *6 (-230 *7 (-763))) (-14 *7 (-763)) (-4 *4 (-1047)) (-5 *2 (-2 (|:| -2963 (-568)) (|:| -2404 (-568)) (|:| -4409 (-568)) (|:| |reste| (-568)) (|:| -2221 (-3 "left" "center" "right" "vertical" "horizontal")))) (-5 *1 (-772 *4 *5 *6 *7)))) (-3355 (*1 *2 *3 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *2 (-2 (|:| -2963 (-568)) (|:| -2404 (-568)) (|:| -4409 (-568)) (|:| |reste| (-568)) (|:| -2221 (-3 "left" "center" "right" "vertical" "horizontal")))) (-5 *1 (-772 *4 *3 *5 *6)) (-4 *3 (-324 *4 *5)))) (-2263 (*1 *2 *3 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-324 *4 *5)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-4 *4 (-1047)) (-5 *1 (-772 *4 *3 *5 *6)))) (-1470 (*1 *2 *3) (-12 (-5 *3 (-634 (-634 *5))) (-4 *5 (-324 *4 *6)) (-4 *6 (-230 *7 *2)) (-14 *7 *2) (-4 *4 (-1047)) (-5 *2 (-763)) (-5 *1 (-772 *4 *5 *6 *7)))) (-3727 (*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-568)) (-5 *5 (-3 "left" "center" "right" "vertical" "horizontal")) (-4 *6 (-1047)) (-4 *7 (-230 *8 (-763))) (-14 *8 (-763)) (-5 *2 (-634 (-634 *3))) (-5 *1 (-772 *6 *3 *7 *8)) (-4 *3 (-324 *6 *7))))) 
+(-10 -7 (-15 -3727 ((-634 (-634 |#2|)) |#2| (-568) (-568) (-3 "left" "center" "right" "vertical" "horizontal"))) (-15 -1470 ((-763) (-634 (-634 |#2|)))) (-15 -2263 ((-634 (-634 |#2|)) |#2| (-634 (-634 |#2|)))) (-15 -3355 ((-2 (|:| -2963 (-568)) (|:| -2404 (-568)) (|:| -4409 (-568)) (|:| |reste| (-568)) (|:| -2221 (-3 "left" "center" "right" "vertical" "horizontal"))) |#2| |#2|)) (-15 -3355 ((-2 (|:| -2963 (-568)) (|:| -2404 (-568)) (|:| -4409 (-568)) (|:| |reste| (-568)) (|:| -2221 (-3 "left" "center" "right" "vertical" "horizontal"))) (-634 |#2|)))) 
+((-3896 (((-634 (-2 (|:| |outval| |#1|) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 |#1|))))) (-679 (-409 (-568))) |#1|) 27)) (-2479 (((-634 |#1|) (-679 (-409 (-568))) |#1|) 19)) (-1295 (((-953 (-409 (-568))) (-679 (-409 (-568))) (-1161)) 16) (((-953 (-409 (-568))) (-679 (-409 (-568)))) 15))) 
+(((-773 |#1|) (-10 -7 (-15 -1295 ((-953 (-409 (-568))) (-679 (-409 (-568))))) (-15 -1295 ((-953 (-409 (-568))) (-679 (-409 (-568))) (-1161))) (-15 -2479 ((-634 |#1|) (-679 (-409 (-568))) |#1|)) (-15 -3896 ((-634 (-2 (|:| |outval| |#1|) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 |#1|))))) (-679 (-409 (-568))) |#1|))) (-13 (-365) (-840))) (T -773)) 
+((-3896 (*1 *2 *3 *4) (-12 (-5 *3 (-679 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| |outval| *4) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 *4)))))) (-5 *1 (-773 *4)) (-4 *4 (-13 (-365) (-840))))) (-2479 (*1 *2 *3 *4) (-12 (-5 *3 (-679 (-409 (-568)))) (-5 *2 (-634 *4)) (-5 *1 (-773 *4)) (-4 *4 (-13 (-365) (-840))))) (-1295 (*1 *2 *3 *4) (-12 (-5 *3 (-679 (-409 (-568)))) (-5 *4 (-1161)) (-5 *2 (-953 (-409 (-568)))) (-5 *1 (-773 *5)) (-4 *5 (-13 (-365) (-840))))) (-1295 (*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-568)))) (-5 *2 (-953 (-409 (-568)))) (-5 *1 (-773 *4)) (-4 *4 (-13 (-365) (-840)))))) 
+(-10 -7 (-15 -1295 ((-953 (-409 (-568))) (-679 (-409 (-568))))) (-15 -1295 ((-953 (-409 (-568))) (-679 (-409 (-568))) (-1161))) (-15 -2479 ((-634 |#1|) (-679 (-409 (-568))) |#1|)) (-15 -3896 ((-634 (-2 (|:| |outval| |#1|) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 |#1|))))) (-679 (-409 (-568))) |#1|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 10)) (-2057 (((-634 (-1075)) $) NIL)) (-3325 (((-1161) $) NIL)) (-2852 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-4179 (($ $ (-568) (-568)) NIL) (($ $ (-568)) NIL)) (-2237 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $) NIL)) (-2013 (((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL)) (-3623 (($ $) NIL)) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2121 (($ $ (-568)) NIL (|has| $ (-6 -4522)))) (-2589 (((-121) $ $) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-1872 (($ $ (-568)) 36)) (-3370 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4522)))) (-1958 (($ $ $) NIL (|has| $ (-6 -4522)))) (-2257 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4522)))) (-1706 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4522)))) (-2438 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-568) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4522))) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-1210 (-568)) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4522))) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ "last" (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4522))) (($ $ "rest" $) NIL (|has| $ (-6 -4522))) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ "first" (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4522))) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ "value" (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) NIL (|has| $ (-6 -4522)))) (-2512 (($ (-568) |#1| $) 41)) (-2803 (($ (-1 (-121) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL)) (-1681 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $) NIL)) (-4461 (($ $ $) 51)) (-4490 (($) NIL T CONST)) (-2584 (($ $) 21)) (-3936 (($ $ (-763)) NIL) (($ $) 14)) (-2232 (($ (-568) $) 78) (($ $) 31)) (-3297 (($ $) 35)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090))))) (-4330 (($ (-1 (-121) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL) (($ (-2 (|:| |k| (-568)) (|:| |c| |#1|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090))))) (-2403 (($ $ $) NIL)) (-2116 (($ $) NIL)) (-3094 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1 (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $ (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090)))) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1 (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $ (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4521))) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1 (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4521)))) (-2902 (((-3 $ "failed") $) 38)) (-2414 (($ $ $) NIL)) (-1292 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-568) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4522)))) (-2069 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-568)) NIL)) (-1277 (((-121) (-121)) 30) (((-121)) 29)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-1340 (((-121) $) NIL)) (-2379 (($ $) 22)) (-1302 (((-121) $) NIL)) (-3317 (((-634 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4521)))) (-2545 (((-3 (-568) "failed") $) 16)) (-1844 (((-568) $ (-568)) NIL) (((-568) $) 19) (((-568) $) 19)) (-1598 (((-121) $) NIL)) (-1841 (((-763) $) NIL)) (-3534 (((-634 $) $) NIL)) (-3606 (((-121) $ $) NIL (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090)))) (-1851 (($ (-763) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL)) (-4168 (($ $ (-917)) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3791 (((-121) $ (-763)) NIL)) (-2171 (((-121) $) NIL)) (-4444 (($ (-634 $) (-634 (-763)) (-568)) 85)) (-2049 (($ $ (-634 (-1075)) (-634 (-568))) NIL) (($ $ (-1075) (-568)) NIL) (($ |#1| (-568)) NIL)) (-2539 (((-568) $) NIL (|has| (-568) (-842)))) (-4406 (((-634 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) (-2 (|:| |k| (-568)) (|:| |c| |#1|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090))))) (-3631 (((-568) $) NIL (|has| (-568) (-842)))) (-2253 (($ (-1 (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $ $) NIL) (($ (-1 (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-4081 (((-634 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL)) (-3319 (((-121) $) NIL)) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-2798 (($ $) NIL)) (-1898 (((-121) $) NIL)) (-1893 (((-1143) $) NIL)) (-4164 (($ $ (-763)) NIL) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $) NIL)) (-2083 (($ $) 39)) (-4124 (($ (-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-2616 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $) 12)) (-3877 (($ $ (-763)) NIL) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $) NIL)) (-3512 (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-568)) 24)) (-4438 ((|#1| $ (-568)) 25)) (-2712 (((-3 (-2 (|:| |k| (-568)) (|:| |c| |#1|)) "failed") (-1 (-121) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL)) (-2938 (($ $ (-568)) 89)) (-2490 (($ $ (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4522)))) (-3850 (((-420 $) $) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2168 (($ $ (-568)) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-4049 (((-121) $) NIL)) (-3817 (((-121) $) NIL)) (-2818 (((-121) $) NIL)) (-3951 (((-121) (-1 (-121) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4521)))) (-1339 (((-1141 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-568))))) (($ $ (-634 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) (-634 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) NIL (-12 (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-303 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090)))) (($ $ (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (-12 (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-303 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090)))) (($ $ (-288 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) NIL (-12 (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-303 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090)))) (($ $ (-634 (-288 (-2 (|:| |k| (-568)) (|:| |c| |#1|))))) NIL (-12 (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-303 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090))))) (-1466 (((-763) $) NIL)) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) (-2 (|:| |k| (-568)) (|:| |c| |#1|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090))))) (-1480 (((-634 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL)) (-2436 (((-121) $) 23)) (-1990 (($) 94)) (-2781 (($ $ $) NIL (|has| (-568) (-1102))) ((|#1| $ (-568)) NIL) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-568) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-568)) NIL) (($ $ (-1210 (-568))) NIL) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ "last") NIL) (($ $ "rest") NIL) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ "first") NIL) (((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ "value") NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-1665 (((-568) $ $) NIL)) (-4191 (($ $) NIL (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (-2828 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-1922 (($ (-1 $)) 34)) (-1836 (((-568) $) NIL)) (-2763 (((-121) $) NIL)) (-3903 (($ $) NIL)) (-1499 (($ $) NIL (|has| $ (-6 -4522)))) (-3535 (((-763) $) NIL)) (-4424 (($ $) NIL)) (-4170 (((-763) (-2 (|:| |k| (-568)) (|:| |c| |#1|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090)))) (((-763) (-1 (-121) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4521)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-609 (-541))))) (-4289 (($ (-634 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) 95)) (-1876 (($ $ (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL (|has| $ (-6 -4522))) (($ $ $) NIL (|has| $ (-6 -4522)))) (-2770 (($ $ (-2 (|:| |k| (-568)) (|:| |c| |#1|))) NIL) (($ (-634 $)) NIL) (($ (-2 (|:| |k| (-568)) (|:| |c| |#1|)) $) 32) (($ $ $) NIL)) (-2188 (($ $) NIL)) (-2747 (((-850) $) 65) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ |#1|) NIL (|has| |#1| (-172))) (($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) 27) (((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) 26)) (-2079 ((|#1| $ (-568)) NIL)) (-1691 ((|#1| $) 86)) (-3180 (((-634 $) $) NIL)) (-3873 (((-121) $ $) NIL (|has| (-2 (|:| |k| (-568)) (|:| |c| |#1|)) (-1090)))) (-3385 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-3425 (((-763)) NIL)) (-1374 ((|#1| $) NIL)) (-2273 (((-121) $ $) NIL)) (-3999 ((|#1| $ (-568)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-568)))) (|has| |#1| (-15 -2747 (|#1| (-1161))))))) (-3437 (((-121) (-1 (-121) (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL (|has| $ (-6 -4521)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) 17 T CONST)) (-1557 (($) 74 T CONST)) (-3192 (($ $) NIL (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ $) NIL) (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1775 (($ $) 47) (($ $ $) 43)) (-1769 (($ $ $) 53)) (** (($ $ (-917)) NIL) (($ $ (-763)) 79) (($ $ (-568)) 52)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 42) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ |#1| $) 46) (($ $ |#1|) 100)) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-774 |#1|) (-13 (-641 |#1|) (-665 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) (-10 -8 (-15 -3512 ((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-568))))) (-365)) (T -774)) 
+((-3512 (*1 *2 *1 *3) (-12 (-5 *2 (-2 (|:| |k| (-568)) (|:| |c| *4))) (-5 *1 (-774 *4)) (-4 *4 (-365)) (-5 *3 (-568))))) 
+(-13 (-641 |#1|) (-665 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) (-10 -8 (-15 -3512 ((-2 (|:| |k| (-568)) (|:| |c| |#1|)) $ (-568))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 34)) (-2057 (((-634 |#2|) $) NIL)) (-3840 (((-1157 $) $ |#2|) NIL) (((-1157 |#1|) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-3528 (((-763) $) NIL) (((-763) $ (-634 |#2|)) NIL)) (-3623 (($ $) 28)) (-3266 (((-121) $ $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-1736 (($ $ $) 92 (|has| |#1| (-558)))) (-2115 (((-634 $) $ $) 105 (|has| |#1| (-558)))) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3045 (($ $) NIL (|has| |#1| (-453)))) (-3498 (((-420 $) $) NIL (|has| |#1| (-453)))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 |#2| "failed") $) NIL) (((-3 $ "failed") (-953 (-409 (-568)))) NIL (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#2| (-609 (-1161))))) (((-3 $ "failed") (-953 (-568))) NIL (-2199 (-12 (|has| |#1| (-43 (-568))) (|has| |#2| (-609 (-1161))) (-3046 (|has| |#1| (-43 (-409 (-568)))))) (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#2| (-609 (-1161)))))) (((-3 $ "failed") (-953 |#1|)) NIL (-2199 (-12 (|has| |#2| (-609 (-1161))) (-3046 (|has| |#1| (-43 (-409 (-568))))) (-3046 (|has| |#1| (-43 (-568))))) (-12 (|has| |#1| (-43 (-568))) (|has| |#2| (-609 (-1161))) (-3046 (|has| |#1| (-43 (-409 (-568))))) (-3046 (|has| |#1| (-550)))) (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#2| (-609 (-1161))) (-3046 (|has| |#1| (-993 (-568))))))) (((-3 (-1113 |#1| |#2|) "failed") $) 18)) (-2857 ((|#1| $) NIL) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#1| (-1037 (-568)))) ((|#2| $) NIL) (($ (-953 (-409 (-568)))) NIL (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#2| (-609 (-1161))))) (($ (-953 (-568))) NIL (-2199 (-12 (|has| |#1| (-43 (-568))) (|has| |#2| (-609 (-1161))) (-3046 (|has| |#1| (-43 (-409 (-568)))))) (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#2| (-609 (-1161)))))) (($ (-953 |#1|)) NIL (-2199 (-12 (|has| |#2| (-609 (-1161))) (-3046 (|has| |#1| (-43 (-409 (-568))))) (-3046 (|has| |#1| (-43 (-568))))) (-12 (|has| |#1| (-43 (-568))) (|has| |#2| (-609 (-1161))) (-3046 (|has| |#1| (-43 (-409 (-568))))) (-3046 (|has| |#1| (-550)))) (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#2| (-609 (-1161))) (-3046 (|has| |#1| (-993 (-568))))))) (((-1113 |#1| |#2|) $) NIL)) (-2910 (($ $ $ |#2|) NIL (|has| |#1| (-172))) (($ $ $) 103 (|has| |#1| (-558)))) (-2116 (($ $) NIL) (($ $ |#2|) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-1359 (((-121) $ $) NIL) (((-121) $ (-634 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1593 (((-121) $) NIL)) (-3777 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 69)) (-1537 (($ $) 118 (|has| |#1| (-453)))) (-1998 (($ $) NIL (|has| |#1| (-453))) (($ $ |#2|) NIL (|has| |#1| (-453)))) (-2110 (((-634 $) $) NIL)) (-2197 (((-121) $) NIL (|has| |#1| (-904)))) (-2354 (($ $) NIL (|has| |#1| (-558)))) (-3424 (($ $) NIL (|has| |#1| (-558)))) (-3002 (($ $ $) 64) (($ $ $ |#2|) NIL)) (-4117 (($ $ $) 67) (($ $ $ |#2|) NIL)) (-2453 (($ $ |#1| (-534 |#2|) $) NIL)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| |#1| (-881 (-381))) (|has| |#2| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| |#1| (-881 (-568))) (|has| |#2| (-881 (-568)))))) (-1598 (((-121) $) NIL)) (-3971 (((-763) $) NIL)) (-3764 (((-121) $ $) NIL) (((-121) $ (-634 $)) NIL)) (-1443 (($ $ $ $ $) 89 (|has| |#1| (-558)))) (-4001 ((|#2| $) 19)) (-2053 (($ (-1157 |#1|) |#2|) NIL) (($ (-1157 $) |#2|) NIL)) (-3062 (((-634 $) $) NIL)) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| (-534 |#2|)) NIL) (($ $ |#2| (-763)) 36) (($ $ (-634 |#2|) (-634 (-763))) NIL)) (-1653 (($ $ $) 60)) (-1438 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $ |#2|) NIL)) (-3463 (((-121) $) NIL)) (-3524 (((-534 |#2|) $) NIL) (((-763) $ |#2|) NIL) (((-634 (-763)) $ (-634 |#2|)) NIL)) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-1850 (((-763) $) 20)) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-1865 (($ (-1 (-534 |#2|) (-534 |#2|)) $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-2817 (((-3 |#2| "failed") $) NIL)) (-2135 (($ $) NIL (|has| |#1| (-453)))) (-3607 (($ $) NIL (|has| |#1| (-453)))) (-3509 (((-634 $) $) NIL)) (-2417 (($ $) 37)) (-3274 (($ $) NIL (|has| |#1| (-453)))) (-2174 (((-634 $) $) 41)) (-3226 (($ $) 39)) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL) (($ $ |#2|) 45)) (-2498 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-3481 (((-2 (|:| |polnum| $) (|:| |polden| $) (|:| -2567 (-763))) $ $) 81)) (-2802 (((-2 (|:| -2350 $) (|:| |gap| (-763)) (|:| -4409 $) (|:| -2607 $)) $ $) 66) (((-2 (|:| -2350 $) (|:| |gap| (-763)) (|:| -4409 $) (|:| -2607 $)) $ $ |#2|) NIL)) (-2322 (((-2 (|:| -2350 $) (|:| |gap| (-763)) (|:| -2607 $)) $ $) NIL) (((-2 (|:| -2350 $) (|:| |gap| (-763)) (|:| -2607 $)) $ $ |#2|) NIL)) (-1604 (($ $ $) 71) (($ $ $ |#2|) NIL)) (-2708 (($ $ $) 74) (($ $ $ |#2|) NIL)) (-1893 (((-1143) $) NIL)) (-3137 (($ $ $) 107 (|has| |#1| (-558)))) (-2631 (((-634 $) $) 30)) (-4362 (((-3 (-634 $) "failed") $) NIL)) (-2112 (((-3 (-634 $) "failed") $) NIL)) (-2617 (((-3 (-2 (|:| |var| |#2|) (|:| -3483 (-763))) "failed") $) NIL)) (-2157 (((-121) $ $) NIL) (((-121) $ (-634 $)) NIL)) (-1315 (($ $ $) NIL)) (-4436 (($ $) 21)) (-4342 (((-121) $ $) NIL)) (-3236 (((-121) $ $) NIL) (((-121) $ (-634 $)) NIL)) (-1452 (($ $ $) NIL)) (-3763 (($ $) 23)) (-4025 (((-1108) $) NIL)) (-4146 (((-2 (|:| -2723 $) (|:| |coef2| $)) $ $) 98 (|has| |#1| (-558)))) (-1832 (((-2 (|:| -2723 $) (|:| |coef1| $)) $ $) 95 (|has| |#1| (-558)))) (-2088 (((-121) $) 52)) (-2093 ((|#1| $) 55)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-453)))) (-2723 ((|#1| |#1| $) 115 (|has| |#1| (-453))) (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3850 (((-420 $) $) NIL (|has| |#1| (-904)))) (-3261 (((-2 (|:| -2723 $) (|:| |coef1| $) (|:| |coef2| $)) $ $) 101 (|has| |#1| (-558)))) (-2597 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558))) (((-3 $ "failed") $ $) 83 (|has| |#1| (-558)))) (-2295 (($ $ |#1|) 111 (|has| |#1| (-558))) (($ $ $) NIL (|has| |#1| (-558)))) (-1574 (($ $ |#1|) 110 (|has| |#1| (-558))) (($ $ $) NIL (|has| |#1| (-558)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ |#2| |#1|) NIL) (($ $ (-634 |#2|) (-634 |#1|)) NIL) (($ $ |#2| $) NIL) (($ $ (-634 |#2|) (-634 $)) NIL)) (-3440 (($ $ |#2|) NIL (|has| |#1| (-172)))) (-4191 (($ $ |#2|) NIL) (($ $ (-634 |#2|)) NIL) (($ $ |#2| (-763)) NIL) (($ $ (-634 |#2|) (-634 (-763))) NIL)) (-1836 (((-534 |#2|) $) NIL) (((-763) $ |#2|) 43) (((-634 (-763)) $ (-634 |#2|)) NIL)) (-1303 (($ $) NIL)) (-1595 (($ $) 33)) (-4280 (((-887 (-381)) $) NIL (-12 (|has| |#1| (-609 (-887 (-381)))) (|has| |#2| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| |#1| (-609 (-887 (-568)))) (|has| |#2| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| |#1| (-609 (-541))) (|has| |#2| (-609 (-541))))) (($ (-953 (-409 (-568)))) NIL (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#2| (-609 (-1161))))) (($ (-953 (-568))) NIL (-2199 (-12 (|has| |#1| (-43 (-568))) (|has| |#2| (-609 (-1161))) (-3046 (|has| |#1| (-43 (-409 (-568)))))) (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#2| (-609 (-1161)))))) (($ (-953 |#1|)) NIL (|has| |#2| (-609 (-1161)))) (((-1143) $) NIL (-12 (|has| |#1| (-1037 (-568))) (|has| |#2| (-609 (-1161))))) (((-953 |#1|) $) NIL (|has| |#2| (-609 (-1161))))) (-1364 ((|#1| $) 114 (|has| |#1| (-453))) (($ $ |#2|) NIL (|has| |#1| (-453)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#1| (-904))))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL) (($ |#2|) NIL) (((-953 |#1|) $) NIL (|has| |#2| (-609 (-1161)))) (((-1113 |#1| |#2|) $) 15) (($ (-1113 |#1| |#2|)) 16) (($ (-409 (-568))) NIL (-2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#1| (-558)))) (-3304 (((-634 |#1|) $) NIL)) (-2079 ((|#1| $ (-534 |#2|)) NIL) (($ $ |#2| (-763)) 44) (($ $ (-634 |#2|) (-634 (-763))) NIL)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-3425 (((-763)) NIL)) (-3925 (($ $ $ (-763)) NIL (|has| |#1| (-172)))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 13 T CONST)) (-3011 (((-3 (-121) "failed") $ $) NIL)) (-1557 (($) 35 T CONST)) (-4038 (($ $ $ $ (-763)) 87 (|has| |#1| (-558)))) (-3611 (($ $ $ (-763)) 86 (|has| |#1| (-558)))) (-3192 (($ $ |#2|) NIL) (($ $ (-634 |#2|)) NIL) (($ $ |#2| (-763)) NIL) (($ $ (-634 |#2|) (-634 (-763))) NIL)) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) 54)) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) 63)) (-1769 (($ $ $) 73)) (** (($ $ (-917)) NIL) (($ $ (-763)) 61)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 59) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) 58) (($ $ |#1|) NIL))) 
 (((-775 |#1| |#2|) (-13 (-1061 |#1| (-534 |#2|) |#2|) (-608 (-1113 |#1| |#2|)) (-1037 (-1113 |#1| |#2|))) (-1047) (-842)) (T -775)) 
 NIL 
 (-13 (-1061 |#1| (-534 |#2|) |#2|) (-608 (-1113 |#1| |#2|)) (-1037 (-1113 |#1| |#2|))) 
-((-2795 (((-777 |#2|) (-1 |#2| |#1|) (-777 |#1|)) 13))) 
-(((-776 |#1| |#2|) (-10 -7 (-15 -2795 ((-777 |#2|) (-1 |#2| |#1|) (-777 |#1|)))) (-1047) (-1047)) (T -776)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-777 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-5 *2 (-777 *6)) (-5 *1 (-776 *5 *6))))) 
-(-10 -7 (-15 -2795 ((-777 |#2|) (-1 |#2| |#1|) (-777 |#1|)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 12)) (-2572 (((-1244 |#1|) $ (-763)) NIL)) (-2055 (((-634 (-1075)) $) NIL)) (-3197 (($ (-1157 |#1|)) NIL)) (-3839 (((-1157 $) $ (-1075)) NIL) (((-1157 |#1|) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-2773 (((-763) $) NIL) (((-763) $ (-634 (-1075))) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2249 (((-634 $) $ $) 39 (|has| |#1| (-558)))) (-3809 (($ $ $) 35 (|has| |#1| (-558)))) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-4305 (($ $) NIL (|has| |#1| (-453)))) (-1678 (((-420 $) $) NIL (|has| |#1| (-453)))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-1497 (((-121) $ $) NIL (|has| |#1| (-365)))) (-3151 (($ $ (-763)) NIL)) (-3772 (($ $ (-763)) NIL)) (-1619 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#1| (-453)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-1075) "failed") $) NIL) (((-3 (-1157 |#1|) "failed") $) 10)) (-2854 ((|#1| $) NIL) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-1075) $) NIL) (((-1157 |#1|) $) NIL)) (-4265 (($ $ $ (-1075)) NIL (|has| |#1| (-172))) ((|#1| $ $) 43 (|has| |#1| (-172)))) (-2401 (($ $ $) NIL (|has| |#1| (-365)))) (-2114 (($ $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-2412 (($ $ $) NIL (|has| |#1| (-365)))) (-3002 (($ $ $) NIL)) (-3581 (($ $ $) 71 (|has| |#1| (-558)))) (-4144 (((-2 (|:| -2348 |#1|) (|:| -3961 $) (|:| -1500 $)) $ $) 70 (|has| |#1| (-558)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-3250 (($ $) NIL (|has| |#1| (-453))) (($ $ (-1075)) NIL (|has| |#1| (-453)))) (-2108 (((-634 $) $) NIL)) (-3927 (((-121) $) NIL (|has| |#1| (-904)))) (-3088 (($ $ |#1| (-763) $) NIL)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-1075) (-881 (-381))) (|has| |#1| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-1075) (-881 (-568))) (|has| |#1| (-881 (-568)))))) (-4477 (((-763) $ $) NIL (|has| |#1| (-558)))) (-2735 (((-121) $) NIL)) (-4178 (((-763) $) NIL)) (-3038 (((-3 $ "failed") $) NIL (|has| |#1| (-1136)))) (-2051 (($ (-1157 |#1|) (-1075)) NIL) (($ (-1157 $) (-1075)) NIL)) (-3536 (($ $ (-763)) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-2976 (((-634 $) $) NIL)) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| (-763)) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-2507 (($ $ $) 20)) (-3379 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $ (-1075)) NIL) (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-2144 (((-763) $) NIL) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-3842 (($ (-1 (-763) (-763)) $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-3764 (((-1157 |#1|) $) NIL)) (-2244 (((-3 (-1075) "failed") $) NIL)) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-2495 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-2280 (((-2 (|:| |polnum| $) (|:| |polden| |#1|) (|:| -3741 (-763))) $ $) 26)) (-4418 (($ $ $) 29)) (-1948 (($ $ $) 32)) (-3547 (((-2 (|:| -2348 |#1|) (|:| |gap| (-763)) (|:| -3961 $) (|:| -1500 $)) $ $) 31)) (-4487 (((-1143) $) NIL)) (-4330 (($ $ $) 41 (|has| |#1| (-558)))) (-1643 (((-2 (|:| -3961 $) (|:| -1500 $)) $ (-763)) NIL)) (-3324 (((-3 (-634 $) "failed") $) NIL)) (-1794 (((-3 (-634 $) "failed") $) NIL)) (-3751 (((-3 (-2 (|:| |var| (-1075)) (|:| -3438 (-763))) "failed") $) NIL)) (-3837 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4434 (($) NIL (|has| |#1| (-1136)) CONST)) (-4022 (((-1108) $) NIL)) (-2879 (((-2 (|:| -2721 $) (|:| |coef2| $)) $ $) 67 (|has| |#1| (-558)))) (-3203 (((-2 (|:| -2721 $) (|:| |coef1| $)) $ $) 63 (|has| |#1| (-558)))) (-3620 (((-2 (|:| -4265 |#1|) (|:| |coef2| $)) $ $) 55 (|has| |#1| (-558)))) (-1607 (((-2 (|:| -4265 |#1|) (|:| |coef1| $)) $ $) 51 (|has| |#1| (-558)))) (-2086 (((-121) $) 13)) (-2091 ((|#1| $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-453)))) (-2721 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-4285 (($ $ (-763) |#1| $) 19)) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3848 (((-420 $) $) NIL (|has| |#1| (-904)))) (-1297 (((-2 (|:| -2721 $) (|:| |coef1| $) (|:| |coef2| $)) $ $) 59 (|has| |#1| (-558)))) (-2379 (((-2 (|:| -4265 |#1|) (|:| |coef1| $) (|:| |coef2| $)) $ $) 47 (|has| |#1| (-558)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-365)))) (-2595 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-1075) |#1|) NIL) (($ $ (-634 (-1075)) (-634 |#1|)) NIL) (($ $ (-1075) $) NIL) (($ $ (-634 (-1075)) (-634 $)) NIL)) (-2709 (((-763) $) NIL (|has| |#1| (-365)))) (-2779 ((|#1| $ |#1|) NIL) (($ $ $) NIL) (((-409 $) (-409 $) (-409 $)) NIL (|has| |#1| (-558))) ((|#1| (-409 $) |#1|) NIL (|has| |#1| (-365))) (((-409 $) $ (-409 $)) NIL (|has| |#1| (-558)))) (-2167 (((-3 $ "failed") $ (-763)) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-365)))) (-2217 (($ $ (-1075)) NIL (|has| |#1| (-172))) ((|#1| $) NIL (|has| |#1| (-172)))) (-4189 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-1 |#1| |#1|) $) NIL)) (-3206 (((-763) $) NIL) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-4278 (((-887 (-381)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-1075) (-609 (-541))) (|has| |#1| (-609 (-541)))))) (-3367 ((|#1| $) NIL (|has| |#1| (-453))) (($ $ (-1075)) NIL (|has| |#1| (-453)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#1| (-904))))) (-3950 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558))) (((-3 (-409 $) "failed") (-409 $) $) NIL (|has| |#1| (-558)))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL) (($ (-1075)) NIL) (((-1157 |#1|) $) 7) (($ (-1157 |#1|)) 8) (($ (-409 (-568))) NIL (-2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#1| (-558)))) (-1302 (((-634 |#1|) $) NIL)) (-2604 ((|#1| $ (-763)) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-4078 (((-763)) NIL)) (-4171 (($ $ $ (-763)) NIL (|has| |#1| (-172)))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 21 T CONST)) (-1556 (($) 24 T CONST)) (-3190 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1773 (($ $) 28) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) 23) (($ $ |#1|) NIL))) 
-(((-777 |#1|) (-13 (-1219 |#1|) (-608 (-1157 |#1|)) (-1037 (-1157 |#1|)) (-10 -8 (-15 -4285 ($ $ (-763) |#1| $)) (-15 -2507 ($ $ $)) (-15 -2280 ((-2 (|:| |polnum| $) (|:| |polden| |#1|) (|:| -3741 (-763))) $ $)) (-15 -4418 ($ $ $)) (-15 -3547 ((-2 (|:| -2348 |#1|) (|:| |gap| (-763)) (|:| -3961 $) (|:| -1500 $)) $ $)) (-15 -1948 ($ $ $)) (IF (|has| |#1| (-558)) (PROGN (-15 -2249 ((-634 $) $ $)) (-15 -4330 ($ $ $)) (-15 -1297 ((-2 (|:| -2721 $) (|:| |coef1| $) (|:| |coef2| $)) $ $)) (-15 -3203 ((-2 (|:| -2721 $) (|:| |coef1| $)) $ $)) (-15 -2879 ((-2 (|:| -2721 $) (|:| |coef2| $)) $ $)) (-15 -2379 ((-2 (|:| -4265 |#1|) (|:| |coef1| $) (|:| |coef2| $)) $ $)) (-15 -1607 ((-2 (|:| -4265 |#1|) (|:| |coef1| $)) $ $)) (-15 -3620 ((-2 (|:| -4265 |#1|) (|:| |coef2| $)) $ $))) |noBranch|))) (-1047)) (T -777)) 
-((-4285 (*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-763)) (-5 *1 (-777 *3)) (-4 *3 (-1047)))) (-2507 (*1 *1 *1 *1) (-12 (-5 *1 (-777 *2)) (-4 *2 (-1047)))) (-2280 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |polnum| (-777 *3)) (|:| |polden| *3) (|:| -3741 (-763)))) (-5 *1 (-777 *3)) (-4 *3 (-1047)))) (-4418 (*1 *1 *1 *1) (-12 (-5 *1 (-777 *2)) (-4 *2 (-1047)))) (-3547 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2348 *3) (|:| |gap| (-763)) (|:| -3961 (-777 *3)) (|:| -1500 (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-1047)))) (-1948 (*1 *1 *1 *1) (-12 (-5 *1 (-777 *2)) (-4 *2 (-1047)))) (-2249 (*1 *2 *1 *1) (-12 (-5 *2 (-634 (-777 *3))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047)))) (-4330 (*1 *1 *1 *1) (-12 (-5 *1 (-777 *2)) (-4 *2 (-558)) (-4 *2 (-1047)))) (-1297 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2721 (-777 *3)) (|:| |coef1| (-777 *3)) (|:| |coef2| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047)))) (-3203 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2721 (-777 *3)) (|:| |coef1| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047)))) (-2879 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2721 (-777 *3)) (|:| |coef2| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047)))) (-2379 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -4265 *3) (|:| |coef1| (-777 *3)) (|:| |coef2| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047)))) (-1607 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -4265 *3) (|:| |coef1| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047)))) (-3620 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -4265 *3) (|:| |coef2| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047))))) 
-(-13 (-1219 |#1|) (-608 (-1157 |#1|)) (-1037 (-1157 |#1|)) (-10 -8 (-15 -4285 ($ $ (-763) |#1| $)) (-15 -2507 ($ $ $)) (-15 -2280 ((-2 (|:| |polnum| $) (|:| |polden| |#1|) (|:| -3741 (-763))) $ $)) (-15 -4418 ($ $ $)) (-15 -3547 ((-2 (|:| -2348 |#1|) (|:| |gap| (-763)) (|:| -3961 $) (|:| -1500 $)) $ $)) (-15 -1948 ($ $ $)) (IF (|has| |#1| (-558)) (PROGN (-15 -2249 ((-634 $) $ $)) (-15 -4330 ($ $ $)) (-15 -1297 ((-2 (|:| -2721 $) (|:| |coef1| $) (|:| |coef2| $)) $ $)) (-15 -3203 ((-2 (|:| -2721 $) (|:| |coef1| $)) $ $)) (-15 -2879 ((-2 (|:| -2721 $) (|:| |coef2| $)) $ $)) (-15 -2379 ((-2 (|:| -4265 |#1|) (|:| |coef1| $) (|:| |coef2| $)) $ $)) (-15 -1607 ((-2 (|:| -4265 |#1|) (|:| |coef1| $)) $ $)) (-15 -3620 ((-2 (|:| -4265 |#1|) (|:| |coef2| $)) $ $))) |noBranch|))) 
-((-2541 ((|#1| (-763) |#1|) 32 (|has| |#1| (-43 (-409 (-568)))))) (-4411 ((|#1| (-763) |#1|) 22)) (-4317 ((|#1| (-763) |#1|) 34 (|has| |#1| (-43 (-409 (-568))))))) 
-(((-778 |#1|) (-10 -7 (-15 -4411 (|#1| (-763) |#1|)) (IF (|has| |#1| (-43 (-409 (-568)))) (PROGN (-15 -4317 (|#1| (-763) |#1|)) (-15 -2541 (|#1| (-763) |#1|))) |noBranch|)) (-172)) (T -778)) 
-((-2541 (*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-778 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-172)))) (-4317 (*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-778 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-172)))) (-4411 (*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-778 *2)) (-4 *2 (-172))))) 
-(-10 -7 (-15 -4411 (|#1| (-763) |#1|)) (IF (|has| |#1| (-43 (-409 (-568)))) (PROGN (-15 -4317 (|#1| (-763) |#1|)) (-15 -2541 (|#1| (-763) |#1|))) |noBranch|)) 
-((-2447 (((-121) $ $) 7)) (-2387 (((-634 (-2 (|:| -4092 $) (|:| -1798 (-634 |#4|)))) (-634 |#4|)) 78)) (-2415 (((-634 $) (-634 |#4|)) 79) (((-634 $) (-634 |#4|) (-121)) 104)) (-2055 (((-634 |#3|) $) 32)) (-4211 (((-121) $) 25)) (-3824 (((-121) $) 16 (|has| |#1| (-558)))) (-3300 (((-121) |#4| $) 94) (((-121) $) 90)) (-2819 ((|#4| |#4| $) 85)) (-4305 (((-634 (-2 (|:| |val| |#4|) (|:| -3001 $))) |#4| $) 119)) (-3644 (((-2 (|:| |under| $) (|:| -1519 $) (|:| |upper| $)) $ |#3|) 26)) (-2510 (((-121) $ (-763)) 43)) (-2801 (($ (-1 (-121) |#4|) $) 64 (|has| $ (-6 -4519))) (((-3 |#4| "failed") $ |#3|) 72)) (-2671 (($) 44 T CONST)) (-1565 (((-121) $) 21 (|has| |#1| (-558)))) (-3846 (((-121) $ $) 23 (|has| |#1| (-558)))) (-3106 (((-121) $ $) 22 (|has| |#1| (-558)))) (-3695 (((-121) $) 24 (|has| |#1| (-558)))) (-4275 (((-634 |#4|) (-634 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 86)) (-2355 (((-634 |#4|) (-634 |#4|) $) 17 (|has| |#1| (-558)))) (-2492 (((-634 |#4|) (-634 |#4|) $) 18 (|has| |#1| (-558)))) (-3666 (((-3 $ "failed") (-634 |#4|)) 35)) (-2854 (($ (-634 |#4|)) 34)) (-3935 (((-3 $ "failed") $) 75)) (-2062 ((|#4| |#4| $) 82)) (-3924 (($ $) 67 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519))))) (-4328 (($ |#4| $) 66 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) |#4|) $) 63 (|has| $ (-6 -4519)))) (-1500 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-558)))) (-1281 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) 95)) (-4079 ((|#4| |#4| $) 80)) (-3092 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4519))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4519))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 87)) (-3635 (((-2 (|:| -4092 (-634 |#4|)) (|:| -1798 (-634 |#4|))) $) 98)) (-1862 (((-121) |#4| $) 129)) (-4286 (((-121) |#4| $) 126)) (-3193 (((-121) |#4| $) 130) (((-121) $) 127)) (-4360 (((-634 |#4|) $) 51 (|has| $ (-6 -4519)))) (-1362 (((-121) |#4| $) 97) (((-121) $) 96)) (-2356 ((|#3| $) 33)) (-1737 (((-121) $ (-763)) 42)) (-1979 (((-634 |#4|) $) 52 (|has| $ (-6 -4519)))) (-3109 (((-121) |#4| $) 54 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#4| |#4|) $) 46)) (-1432 (((-634 |#3|) $) 31)) (-3392 (((-121) |#3| $) 30)) (-2166 (((-121) $ (-763)) 41)) (-4487 (((-1143) $) 9)) (-2717 (((-3 |#4| (-634 $)) |#4| |#4| $) 121)) (-4330 (((-634 (-2 (|:| |val| |#4|) (|:| -3001 $))) |#4| |#4| $) 120)) (-4162 (((-3 |#4| "failed") $) 76)) (-2335 (((-634 $) |#4| $) 122)) (-1719 (((-3 (-121) (-634 $)) |#4| $) 125)) (-2632 (((-634 (-2 (|:| |val| (-121)) (|:| -3001 $))) |#4| $) 124) (((-121) |#4| $) 123)) (-3212 (((-634 $) |#4| $) 118) (((-634 $) (-634 |#4|) $) 117) (((-634 $) (-634 |#4|) (-634 $)) 116) (((-634 $) |#4| (-634 $)) 115)) (-3473 (($ |#4| $) 110) (($ (-634 |#4|) $) 109)) (-1377 (((-634 |#4|) $) 100)) (-1415 (((-121) |#4| $) 92) (((-121) $) 88)) (-2682 ((|#4| |#4| $) 83)) (-2644 (((-121) $ $) 103)) (-2705 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-558)))) (-4347 (((-121) |#4| $) 93) (((-121) $) 89)) (-4025 ((|#4| |#4| $) 84)) (-4022 (((-1108) $) 10)) (-3876 (((-3 |#4| "failed") $) 77)) (-3775 (((-3 |#4| "failed") (-1 (-121) |#4|) $) 60)) (-1665 (((-3 $ "failed") $ |#4|) 71)) (-1807 (($ $ |#4|) 70) (((-634 $) |#4| $) 108) (((-634 $) |#4| (-634 $)) 107) (((-634 $) (-634 |#4|) $) 106) (((-634 $) (-634 |#4|) (-634 $)) 105)) (-1387 (((-121) (-1 (-121) |#4|) $) 49 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 |#4|) (-634 |#4|)) 58 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) 56 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 (-288 |#4|))) 55 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-3171 (((-121) $ $) 37)) (-3084 (((-121) $) 40)) (-3248 (($) 39)) (-3206 (((-763) $) 99)) (-4168 (((-763) |#4| $) 53 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519)))) (((-763) (-1 (-121) |#4|) $) 50 (|has| $ (-6 -4519)))) (-3863 (($ $) 38)) (-4278 (((-541) $) 68 (|has| |#4| (-609 (-541))))) (-4287 (($ (-634 |#4|)) 59)) (-1290 (($ $ |#3|) 27)) (-3732 (($ $ |#3|) 29)) (-1567 (($ $) 81)) (-3944 (($ $ |#3|) 28)) (-2745 (((-850) $) 11) (((-634 |#4|) $) 36)) (-1878 (((-763) $) 69 (|has| |#3| (-370)))) (-3556 (((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4| |#4|)) 102) (((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) 101)) (-3292 (((-121) $ (-1 (-121) |#4| (-634 |#4|))) 91)) (-2574 (((-634 $) |#4| $) 114) (((-634 $) |#4| (-634 $)) 113) (((-634 $) (-634 |#4|) $) 112) (((-634 $) (-634 |#4|) (-634 $)) 111)) (-1319 (((-121) (-1 (-121) |#4|) $) 48 (|has| $ (-6 -4519)))) (-2739 (((-634 |#3|) $) 74)) (-2288 (((-121) |#4| $) 128)) (-4390 (((-121) |#3| $) 73)) (-1717 (((-121) $ $) 6)) (-1697 (((-763) $) 45 (|has| $ (-6 -4519))))) 
+((-2797 (((-777 |#2|) (-1 |#2| |#1|) (-777 |#1|)) 13))) 
+(((-776 |#1| |#2|) (-10 -7 (-15 -2797 ((-777 |#2|) (-1 |#2| |#1|) (-777 |#1|)))) (-1047) (-1047)) (T -776)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-777 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-5 *2 (-777 *6)) (-5 *1 (-776 *5 *6))))) 
+(-10 -7 (-15 -2797 ((-777 |#2|) (-1 |#2| |#1|) (-777 |#1|)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 12)) (-1969 (((-1244 |#1|) $ (-763)) NIL)) (-2057 (((-634 (-1075)) $) NIL)) (-1807 (($ (-1157 |#1|)) NIL)) (-3840 (((-1157 $) $ (-1075)) NIL) (((-1157 |#1|) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-3528 (((-763) $) NIL) (((-763) $ (-634 (-1075))) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-2888 (((-634 $) $ $) 39 (|has| |#1| (-558)))) (-1736 (($ $ $) 35 (|has| |#1| (-558)))) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3045 (($ $) NIL (|has| |#1| (-453)))) (-3498 (((-420 $) $) NIL (|has| |#1| (-453)))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-2589 (((-121) $ $) NIL (|has| |#1| (-365)))) (-2752 (($ $ (-763)) NIL)) (-2699 (($ $ (-763)) NIL)) (-1448 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#1| (-453)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-1075) "failed") $) NIL) (((-3 (-1157 |#1|) "failed") $) 10)) (-2857 ((|#1| $) NIL) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-1075) $) NIL) (((-1157 |#1|) $) NIL)) (-2910 (($ $ $ (-1075)) NIL (|has| |#1| (-172))) ((|#1| $ $) 43 (|has| |#1| (-172)))) (-2403 (($ $ $) NIL (|has| |#1| (-365)))) (-2116 (($ $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-2414 (($ $ $) NIL (|has| |#1| (-365)))) (-3152 (($ $ $) NIL)) (-2929 (($ $ $) 71 (|has| |#1| (-558)))) (-3777 (((-2 (|:| -2350 |#1|) (|:| -4409 $) (|:| -2607 $)) $ $) 70 (|has| |#1| (-558)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-1998 (($ $) NIL (|has| |#1| (-453))) (($ $ (-1075)) NIL (|has| |#1| (-453)))) (-2110 (((-634 $) $) NIL)) (-2197 (((-121) $) NIL (|has| |#1| (-904)))) (-2453 (($ $ |#1| (-763) $) NIL)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-1075) (-881 (-381))) (|has| |#1| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-1075) (-881 (-568))) (|has| |#1| (-881 (-568)))))) (-1844 (((-763) $ $) NIL (|has| |#1| (-558)))) (-1598 (((-121) $) NIL)) (-3971 (((-763) $) NIL)) (-2214 (((-3 $ "failed") $) NIL (|has| |#1| (-1136)))) (-2053 (($ (-1157 |#1|) (-1075)) NIL) (($ (-1157 $) (-1075)) NIL)) (-4168 (($ $ (-763)) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-3062 (((-634 $) $) NIL)) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| (-763)) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-1653 (($ $ $) 20)) (-1438 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $ (-1075)) NIL) (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-3524 (((-763) $) NIL) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-1865 (($ (-1 (-763) (-763)) $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-2671 (((-1157 |#1|) $) NIL)) (-2817 (((-3 (-1075) "failed") $) NIL)) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-2498 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-3481 (((-2 (|:| |polnum| $) (|:| |polden| |#1|) (|:| -2567 (-763))) $ $) 26)) (-1560 (($ $ $) 29)) (-4265 (($ $ $) 32)) (-2802 (((-2 (|:| -2350 |#1|) (|:| |gap| (-763)) (|:| -4409 $) (|:| -2607 $)) $ $) 31)) (-1893 (((-1143) $) NIL)) (-3137 (($ $ $) 41 (|has| |#1| (-558)))) (-3262 (((-2 (|:| -4409 $) (|:| -2607 $)) $ (-763)) NIL)) (-4362 (((-3 (-634 $) "failed") $) NIL)) (-2112 (((-3 (-634 $) "failed") $) NIL)) (-2617 (((-3 (-2 (|:| |var| (-1075)) (|:| -3483 (-763))) "failed") $) NIL)) (-1845 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4436 (($) NIL (|has| |#1| (-1136)) CONST)) (-4025 (((-1108) $) NIL)) (-4146 (((-2 (|:| -2723 $) (|:| |coef2| $)) $ $) 67 (|has| |#1| (-558)))) (-1832 (((-2 (|:| -2723 $) (|:| |coef1| $)) $ $) 63 (|has| |#1| (-558)))) (-3082 (((-2 (|:| -2910 |#1|) (|:| |coef2| $)) $ $) 55 (|has| |#1| (-558)))) (-1380 (((-2 (|:| -2910 |#1|) (|:| |coef1| $)) $ $) 51 (|has| |#1| (-558)))) (-2088 (((-121) $) 13)) (-2093 ((|#1| $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-453)))) (-2723 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-2973 (($ $ (-763) |#1| $) 19)) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3850 (((-420 $) $) NIL (|has| |#1| (-904)))) (-3261 (((-2 (|:| -2723 $) (|:| |coef1| $) (|:| |coef2| $)) $ $) 59 (|has| |#1| (-558)))) (-2169 (((-2 (|:| -2910 |#1|) (|:| |coef1| $) (|:| |coef2| $)) $ $) 47 (|has| |#1| (-558)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-365)))) (-2597 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-1075) |#1|) NIL) (($ $ (-634 (-1075)) (-634 |#1|)) NIL) (($ $ (-1075) $) NIL) (($ $ (-634 (-1075)) (-634 $)) NIL)) (-1466 (((-763) $) NIL (|has| |#1| (-365)))) (-2781 ((|#1| $ |#1|) NIL) (($ $ $) NIL) (((-409 $) (-409 $) (-409 $)) NIL (|has| |#1| (-558))) ((|#1| (-409 $) |#1|) NIL (|has| |#1| (-365))) (((-409 $) $ (-409 $)) NIL (|has| |#1| (-558)))) (-3805 (((-3 $ "failed") $ (-763)) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-365)))) (-3440 (($ $ (-1075)) NIL (|has| |#1| (-172))) ((|#1| $) NIL (|has| |#1| (-172)))) (-4191 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-1 |#1| |#1|) $) NIL)) (-1836 (((-763) $) NIL) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-4280 (((-887 (-381)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-1075) (-609 (-541))) (|has| |#1| (-609 (-541)))))) (-1364 ((|#1| $) NIL (|has| |#1| (-453))) (($ $ (-1075)) NIL (|has| |#1| (-453)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#1| (-904))))) (-4363 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558))) (((-3 (-409 $) "failed") (-409 $) $) NIL (|has| |#1| (-558)))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL) (($ (-1075)) NIL) (((-1157 |#1|) $) 7) (($ (-1157 |#1|)) 8) (($ (-409 (-568))) NIL (-2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#1| (-558)))) (-3304 (((-634 |#1|) $) NIL)) (-2079 ((|#1| $ (-763)) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-3425 (((-763)) NIL)) (-3925 (($ $ $ (-763)) NIL (|has| |#1| (-172)))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 21 T CONST)) (-1557 (($) 24 T CONST)) (-3192 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1775 (($ $) 28) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) 23) (($ $ |#1|) NIL))) 
+(((-777 |#1|) (-13 (-1219 |#1|) (-608 (-1157 |#1|)) (-1037 (-1157 |#1|)) (-10 -8 (-15 -2973 ($ $ (-763) |#1| $)) (-15 -1653 ($ $ $)) (-15 -3481 ((-2 (|:| |polnum| $) (|:| |polden| |#1|) (|:| -2567 (-763))) $ $)) (-15 -1560 ($ $ $)) (-15 -2802 ((-2 (|:| -2350 |#1|) (|:| |gap| (-763)) (|:| -4409 $) (|:| -2607 $)) $ $)) (-15 -4265 ($ $ $)) (IF (|has| |#1| (-558)) (PROGN (-15 -2888 ((-634 $) $ $)) (-15 -3137 ($ $ $)) (-15 -3261 ((-2 (|:| -2723 $) (|:| |coef1| $) (|:| |coef2| $)) $ $)) (-15 -1832 ((-2 (|:| -2723 $) (|:| |coef1| $)) $ $)) (-15 -4146 ((-2 (|:| -2723 $) (|:| |coef2| $)) $ $)) (-15 -2169 ((-2 (|:| -2910 |#1|) (|:| |coef1| $) (|:| |coef2| $)) $ $)) (-15 -1380 ((-2 (|:| -2910 |#1|) (|:| |coef1| $)) $ $)) (-15 -3082 ((-2 (|:| -2910 |#1|) (|:| |coef2| $)) $ $))) |noBranch|))) (-1047)) (T -777)) 
+((-2973 (*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-763)) (-5 *1 (-777 *3)) (-4 *3 (-1047)))) (-1653 (*1 *1 *1 *1) (-12 (-5 *1 (-777 *2)) (-4 *2 (-1047)))) (-3481 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |polnum| (-777 *3)) (|:| |polden| *3) (|:| -2567 (-763)))) (-5 *1 (-777 *3)) (-4 *3 (-1047)))) (-1560 (*1 *1 *1 *1) (-12 (-5 *1 (-777 *2)) (-4 *2 (-1047)))) (-2802 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2350 *3) (|:| |gap| (-763)) (|:| -4409 (-777 *3)) (|:| -2607 (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-1047)))) (-4265 (*1 *1 *1 *1) (-12 (-5 *1 (-777 *2)) (-4 *2 (-1047)))) (-2888 (*1 *2 *1 *1) (-12 (-5 *2 (-634 (-777 *3))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047)))) (-3137 (*1 *1 *1 *1) (-12 (-5 *1 (-777 *2)) (-4 *2 (-558)) (-4 *2 (-1047)))) (-3261 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2723 (-777 *3)) (|:| |coef1| (-777 *3)) (|:| |coef2| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047)))) (-1832 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2723 (-777 *3)) (|:| |coef1| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047)))) (-4146 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2723 (-777 *3)) (|:| |coef2| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047)))) (-2169 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2910 *3) (|:| |coef1| (-777 *3)) (|:| |coef2| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047)))) (-1380 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2910 *3) (|:| |coef1| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047)))) (-3082 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2910 *3) (|:| |coef2| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047))))) 
+(-13 (-1219 |#1|) (-608 (-1157 |#1|)) (-1037 (-1157 |#1|)) (-10 -8 (-15 -2973 ($ $ (-763) |#1| $)) (-15 -1653 ($ $ $)) (-15 -3481 ((-2 (|:| |polnum| $) (|:| |polden| |#1|) (|:| -2567 (-763))) $ $)) (-15 -1560 ($ $ $)) (-15 -2802 ((-2 (|:| -2350 |#1|) (|:| |gap| (-763)) (|:| -4409 $) (|:| -2607 $)) $ $)) (-15 -4265 ($ $ $)) (IF (|has| |#1| (-558)) (PROGN (-15 -2888 ((-634 $) $ $)) (-15 -3137 ($ $ $)) (-15 -3261 ((-2 (|:| -2723 $) (|:| |coef1| $) (|:| |coef2| $)) $ $)) (-15 -1832 ((-2 (|:| -2723 $) (|:| |coef1| $)) $ $)) (-15 -4146 ((-2 (|:| -2723 $) (|:| |coef2| $)) $ $)) (-15 -2169 ((-2 (|:| -2910 |#1|) (|:| |coef1| $) (|:| |coef2| $)) $ $)) (-15 -1380 ((-2 (|:| -2910 |#1|) (|:| |coef1| $)) $ $)) (-15 -3082 ((-2 (|:| -2910 |#1|) (|:| |coef2| $)) $ $))) |noBranch|))) 
+((-1835 ((|#1| (-763) |#1|) 32 (|has| |#1| (-43 (-409 (-568)))))) (-1526 ((|#1| (-763) |#1|) 22)) (-3090 ((|#1| (-763) |#1|) 34 (|has| |#1| (-43 (-409 (-568))))))) 
+(((-778 |#1|) (-10 -7 (-15 -1526 (|#1| (-763) |#1|)) (IF (|has| |#1| (-43 (-409 (-568)))) (PROGN (-15 -3090 (|#1| (-763) |#1|)) (-15 -1835 (|#1| (-763) |#1|))) |noBranch|)) (-172)) (T -778)) 
+((-1835 (*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-778 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-172)))) (-3090 (*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-778 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-172)))) (-1526 (*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-778 *2)) (-4 *2 (-172))))) 
+(-10 -7 (-15 -1526 (|#1| (-763) |#1|)) (IF (|has| |#1| (-43 (-409 (-568)))) (PROGN (-15 -3090 (|#1| (-763) |#1|)) (-15 -1835 (|#1| (-763) |#1|))) |noBranch|)) 
+((-2449 (((-121) $ $) 7)) (-2213 (((-634 (-2 (|:| -4094 $) (|:| -2133 (-634 |#4|)))) (-634 |#4|)) 78)) (-2353 (((-634 $) (-634 |#4|)) 79) (((-634 $) (-634 |#4|) (-121)) 104)) (-2057 (((-634 |#3|) $) 32)) (-4141 (((-121) $) 25)) (-1794 (((-121) $) 16 (|has| |#1| (-558)))) (-4231 (((-121) |#4| $) 94) (((-121) $) 90)) (-3767 ((|#4| |#4| $) 85)) (-3045 (((-634 (-2 (|:| |val| |#4|) (|:| -3145 $))) |#4| $) 119)) (-3647 (((-2 (|:| |under| $) (|:| -4115 $) (|:| |upper| $)) $ |#3|) 26)) (-1667 (((-121) $ (-763)) 43)) (-2803 (($ (-1 (-121) |#4|) $) 64 (|has| $ (-6 -4521))) (((-3 |#4| "failed") $ |#3|) 72)) (-4490 (($) 44 T CONST)) (-4382 (((-121) $) 21 (|has| |#1| (-558)))) (-1880 (((-121) $ $) 23 (|has| |#1| (-558)))) (-2536 (((-121) $ $) 22 (|has| |#1| (-558)))) (-2343 (((-121) $) 24 (|has| |#1| (-558)))) (-2941 (((-634 |#4|) (-634 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 86)) (-3993 (((-634 |#4|) (-634 |#4|) $) 17 (|has| |#1| (-558)))) (-2727 (((-634 |#4|) (-634 |#4|) $) 18 (|has| |#1| (-558)))) (-3668 (((-3 $ "failed") (-634 |#4|)) 35)) (-2857 (($ (-634 |#4|)) 34)) (-3936 (((-3 $ "failed") $) 75)) (-3255 ((|#4| |#4| $) 82)) (-3926 (($ $) 67 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521))))) (-4330 (($ |#4| $) 66 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) |#4|) $) 63 (|has| $ (-6 -4521)))) (-2607 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-558)))) (-1359 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) 95)) (-3434 ((|#4| |#4| $) 80)) (-3094 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4521))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4521))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 87)) (-3158 (((-2 (|:| -4094 (-634 |#4|)) (|:| -2133 (-634 |#4|))) $) 98)) (-2451 (((-121) |#4| $) 129)) (-2978 (((-121) |#4| $) 126)) (-1792 (((-121) |#4| $) 130) (((-121) $) 127)) (-3317 (((-634 |#4|) $) 51 (|has| $ (-6 -4521)))) (-3764 (((-121) |#4| $) 97) (((-121) $) 96)) (-4001 ((|#3| $) 33)) (-3791 (((-121) $ (-763)) 42)) (-4406 (((-634 |#4|) $) 52 (|has| $ (-6 -4521)))) (-2551 (((-121) |#4| $) 54 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#4| |#4|) $) 46)) (-2249 (((-634 |#3|) $) 31)) (-1495 (((-121) |#3| $) 30)) (-3796 (((-121) $ (-763)) 41)) (-1893 (((-1143) $) 9)) (-1516 (((-3 |#4| (-634 $)) |#4| |#4| $) 121)) (-3137 (((-634 (-2 (|:| |val| |#4|) (|:| -3145 $))) |#4| |#4| $) 120)) (-4164 (((-3 |#4| "failed") $) 76)) (-3878 (((-634 $) |#4| $) 122)) (-3712 (((-3 (-121) (-634 $)) |#4| $) 125)) (-4266 (((-634 (-2 (|:| |val| (-121)) (|:| -3145 $))) |#4| $) 124) (((-121) |#4| $) 123)) (-1864 (((-634 $) |#4| $) 118) (((-634 $) (-634 |#4|) $) 117) (((-634 $) (-634 |#4|) (-634 $)) 116) (((-634 $) |#4| (-634 $)) 115)) (-3736 (($ |#4| $) 110) (($ (-634 |#4|) $) 109)) (-3882 (((-634 |#4|) $) 100)) (-2157 (((-121) |#4| $) 92) (((-121) $) 88)) (-1315 ((|#4| |#4| $) 83)) (-4342 (((-121) $ $) 103)) (-1440 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-558)))) (-3236 (((-121) |#4| $) 93) (((-121) $) 89)) (-1452 ((|#4| |#4| $) 84)) (-4025 (((-1108) $) 10)) (-3877 (((-3 |#4| "failed") $) 77)) (-2712 (((-3 |#4| "failed") (-1 (-121) |#4|) $) 60)) (-3413 (((-3 $ "failed") $ |#4|) 71)) (-2168 (($ $ |#4|) 70) (((-634 $) |#4| $) 108) (((-634 $) |#4| (-634 $)) 107) (((-634 $) (-634 |#4|) $) 106) (((-634 $) (-634 |#4|) (-634 $)) 105)) (-3951 (((-121) (-1 (-121) |#4|) $) 49 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 |#4|) (-634 |#4|)) 58 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) 56 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 (-288 |#4|))) 55 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-1702 (((-121) $ $) 37)) (-2436 (((-121) $) 40)) (-1990 (($) 39)) (-1836 (((-763) $) 99)) (-4170 (((-763) |#4| $) 53 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521)))) (((-763) (-1 (-121) |#4|) $) 50 (|has| $ (-6 -4521)))) (-3865 (($ $) 38)) (-4280 (((-541) $) 68 (|has| |#4| (-609 (-541))))) (-4289 (($ (-634 |#4|)) 59)) (-3206 (($ $ |#3|) 27)) (-2527 (($ $ |#3|) 29)) (-4392 (($ $) 81)) (-4332 (($ $ |#3|) 28)) (-2747 (((-850) $) 11) (((-634 |#4|) $) 36)) (-2524 (((-763) $) 69 (|has| |#3| (-370)))) (-2835 (((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4| |#4|)) 102) (((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) 101)) (-2145 (((-121) $ (-1 (-121) |#4| (-634 |#4|))) 91)) (-1977 (((-634 $) |#4| $) 114) (((-634 $) |#4| (-634 $)) 113) (((-634 $) (-634 |#4|) $) 112) (((-634 $) (-634 |#4|) (-634 $)) 111)) (-3437 (((-121) (-1 (-121) |#4|) $) 48 (|has| $ (-6 -4521)))) (-3321 (((-634 |#3|) $) 74)) (-3541 (((-121) |#4| $) 128)) (-1413 (((-121) |#3| $) 73)) (-1719 (((-121) $ $) 6)) (-1699 (((-763) $) 45 (|has| $ (-6 -4521))))) 
 (((-779 |#1| |#2| |#3| |#4|) (-1275) (-453) (-788) (-842) (-1061 |t#1| |t#2| |t#3|)) (T -779)) 
 NIL 
 (-13 (-1066 |t#1| |t#2| |t#3| |t#4|)) 
 (((-39) . T) ((-105) . T) ((-608 (-634 |#4|)) . T) ((-608 (-850)) . T) ((-154 |#4|) . T) ((-609 (-541)) |has| |#4| (-609 (-541))) ((-303 |#4|) -12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))) ((-499 |#4|) . T) ((-523 |#4| |#4|) -12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))) ((-977 |#1| |#2| |#3| |#4|) . T) ((-1066 |#1| |#2| |#3| |#4|) . T) ((-1090) . T) ((-1189 |#1| |#2| |#3| |#4|) . T) ((-1195) . T)) 
-((-3717 (((-3 (-381) "failed") (-310 |#1|) (-917)) 60 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-3 (-381) "failed") (-310 |#1|)) 52 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-3 (-381) "failed") (-409 (-953 |#1|)) (-917)) 39 (|has| |#1| (-558))) (((-3 (-381) "failed") (-409 (-953 |#1|))) 35 (|has| |#1| (-558))) (((-3 (-381) "failed") (-953 |#1|) (-917)) 30 (|has| |#1| (-1047))) (((-3 (-381) "failed") (-953 |#1|)) 24 (|has| |#1| (-1047)))) (-2942 (((-381) (-310 |#1|) (-917)) 92 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-381) (-310 |#1|)) 87 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-381) (-409 (-953 |#1|)) (-917)) 84 (|has| |#1| (-558))) (((-381) (-409 (-953 |#1|))) 81 (|has| |#1| (-558))) (((-381) (-953 |#1|) (-917)) 80 (|has| |#1| (-1047))) (((-381) (-953 |#1|)) 77 (|has| |#1| (-1047))) (((-381) |#1| (-917)) 73) (((-381) |#1|) 22)) (-3297 (((-3 (-169 (-381)) "failed") (-310 (-169 |#1|)) (-917)) 68 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-3 (-169 (-381)) "failed") (-310 (-169 |#1|))) 58 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-3 (-169 (-381)) "failed") (-310 |#1|) (-917)) 61 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-3 (-169 (-381)) "failed") (-310 |#1|)) 59 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-3 (-169 (-381)) "failed") (-409 (-953 (-169 |#1|))) (-917)) 44 (|has| |#1| (-558))) (((-3 (-169 (-381)) "failed") (-409 (-953 (-169 |#1|)))) 43 (|has| |#1| (-558))) (((-3 (-169 (-381)) "failed") (-409 (-953 |#1|)) (-917)) 38 (|has| |#1| (-558))) (((-3 (-169 (-381)) "failed") (-409 (-953 |#1|))) 37 (|has| |#1| (-558))) (((-3 (-169 (-381)) "failed") (-953 |#1|) (-917)) 28 (|has| |#1| (-1047))) (((-3 (-169 (-381)) "failed") (-953 |#1|)) 26 (|has| |#1| (-1047))) (((-3 (-169 (-381)) "failed") (-953 (-169 |#1|)) (-917)) 17 (|has| |#1| (-172))) (((-3 (-169 (-381)) "failed") (-953 (-169 |#1|))) 14 (|has| |#1| (-172)))) (-3819 (((-169 (-381)) (-310 (-169 |#1|)) (-917)) 95 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-169 (-381)) (-310 (-169 |#1|))) 94 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-169 (-381)) (-310 |#1|) (-917)) 93 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-169 (-381)) (-310 |#1|)) 91 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-169 (-381)) (-409 (-953 (-169 |#1|))) (-917)) 86 (|has| |#1| (-558))) (((-169 (-381)) (-409 (-953 (-169 |#1|)))) 85 (|has| |#1| (-558))) (((-169 (-381)) (-409 (-953 |#1|)) (-917)) 83 (|has| |#1| (-558))) (((-169 (-381)) (-409 (-953 |#1|))) 82 (|has| |#1| (-558))) (((-169 (-381)) (-953 |#1|) (-917)) 79 (|has| |#1| (-1047))) (((-169 (-381)) (-953 |#1|)) 78 (|has| |#1| (-1047))) (((-169 (-381)) (-953 (-169 |#1|)) (-917)) 75 (|has| |#1| (-172))) (((-169 (-381)) (-953 (-169 |#1|))) 74 (|has| |#1| (-172))) (((-169 (-381)) (-169 |#1|) (-917)) 16 (|has| |#1| (-172))) (((-169 (-381)) (-169 |#1|)) 12 (|has| |#1| (-172))) (((-169 (-381)) |#1| (-917)) 27) (((-169 (-381)) |#1|) 25))) 
-(((-780 |#1|) (-10 -7 (-15 -2942 ((-381) |#1|)) (-15 -2942 ((-381) |#1| (-917))) (-15 -3819 ((-169 (-381)) |#1|)) (-15 -3819 ((-169 (-381)) |#1| (-917))) (IF (|has| |#1| (-172)) (PROGN (-15 -3819 ((-169 (-381)) (-169 |#1|))) (-15 -3819 ((-169 (-381)) (-169 |#1|) (-917))) (-15 -3819 ((-169 (-381)) (-953 (-169 |#1|)))) (-15 -3819 ((-169 (-381)) (-953 (-169 |#1|)) (-917)))) |noBranch|) (IF (|has| |#1| (-1047)) (PROGN (-15 -2942 ((-381) (-953 |#1|))) (-15 -2942 ((-381) (-953 |#1|) (-917))) (-15 -3819 ((-169 (-381)) (-953 |#1|))) (-15 -3819 ((-169 (-381)) (-953 |#1|) (-917)))) |noBranch|) (IF (|has| |#1| (-558)) (PROGN (-15 -2942 ((-381) (-409 (-953 |#1|)))) (-15 -2942 ((-381) (-409 (-953 |#1|)) (-917))) (-15 -3819 ((-169 (-381)) (-409 (-953 |#1|)))) (-15 -3819 ((-169 (-381)) (-409 (-953 |#1|)) (-917))) (-15 -3819 ((-169 (-381)) (-409 (-953 (-169 |#1|))))) (-15 -3819 ((-169 (-381)) (-409 (-953 (-169 |#1|))) (-917))) (IF (|has| |#1| (-842)) (PROGN (-15 -2942 ((-381) (-310 |#1|))) (-15 -2942 ((-381) (-310 |#1|) (-917))) (-15 -3819 ((-169 (-381)) (-310 |#1|))) (-15 -3819 ((-169 (-381)) (-310 |#1|) (-917))) (-15 -3819 ((-169 (-381)) (-310 (-169 |#1|)))) (-15 -3819 ((-169 (-381)) (-310 (-169 |#1|)) (-917)))) |noBranch|)) |noBranch|) (IF (|has| |#1| (-172)) (PROGN (-15 -3297 ((-3 (-169 (-381)) "failed") (-953 (-169 |#1|)))) (-15 -3297 ((-3 (-169 (-381)) "failed") (-953 (-169 |#1|)) (-917)))) |noBranch|) (IF (|has| |#1| (-1047)) (PROGN (-15 -3717 ((-3 (-381) "failed") (-953 |#1|))) (-15 -3717 ((-3 (-381) "failed") (-953 |#1|) (-917))) (-15 -3297 ((-3 (-169 (-381)) "failed") (-953 |#1|))) (-15 -3297 ((-3 (-169 (-381)) "failed") (-953 |#1|) (-917)))) |noBranch|) (IF (|has| |#1| (-558)) (PROGN (-15 -3717 ((-3 (-381) "failed") (-409 (-953 |#1|)))) (-15 -3717 ((-3 (-381) "failed") (-409 (-953 |#1|)) (-917))) (-15 -3297 ((-3 (-169 (-381)) "failed") (-409 (-953 |#1|)))) (-15 -3297 ((-3 (-169 (-381)) "failed") (-409 (-953 |#1|)) (-917))) (-15 -3297 ((-3 (-169 (-381)) "failed") (-409 (-953 (-169 |#1|))))) (-15 -3297 ((-3 (-169 (-381)) "failed") (-409 (-953 (-169 |#1|))) (-917))) (IF (|has| |#1| (-842)) (PROGN (-15 -3717 ((-3 (-381) "failed") (-310 |#1|))) (-15 -3717 ((-3 (-381) "failed") (-310 |#1|) (-917))) (-15 -3297 ((-3 (-169 (-381)) "failed") (-310 |#1|))) (-15 -3297 ((-3 (-169 (-381)) "failed") (-310 |#1|) (-917))) (-15 -3297 ((-3 (-169 (-381)) "failed") (-310 (-169 |#1|)))) (-15 -3297 ((-3 (-169 (-381)) "failed") (-310 (-169 |#1|)) (-917)))) |noBranch|)) |noBranch|)) (-609 (-381))) (T -780)) 
-((-3297 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-310 (-169 *5))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-842)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-3297 (*1 *2 *3) (|partial| -12 (-5 *3 (-310 (-169 *4))) (-4 *4 (-558)) (-4 *4 (-842)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-3297 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-310 *5)) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-842)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-3297 (*1 *2 *3) (|partial| -12 (-5 *3 (-310 *4)) (-4 *4 (-558)) (-4 *4 (-842)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-3717 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-310 *5)) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-842)) (-4 *5 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *5)))) (-3717 (*1 *2 *3) (|partial| -12 (-5 *3 (-310 *4)) (-4 *4 (-558)) (-4 *4 (-842)) (-4 *4 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *4)))) (-3297 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 (-953 (-169 *5)))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-3297 (*1 *2 *3) (|partial| -12 (-5 *3 (-409 (-953 (-169 *4)))) (-4 *4 (-558)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-3297 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-3297 (*1 *2 *3) (|partial| -12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-558)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-3717 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *5)))) (-3717 (*1 *2 *3) (|partial| -12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-558)) (-4 *4 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *4)))) (-3297 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-953 *5)) (-5 *4 (-917)) (-4 *5 (-1047)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-3297 (*1 *2 *3) (|partial| -12 (-5 *3 (-953 *4)) (-4 *4 (-1047)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-3717 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-953 *5)) (-5 *4 (-917)) (-4 *5 (-1047)) (-4 *5 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *5)))) (-3717 (*1 *2 *3) (|partial| -12 (-5 *3 (-953 *4)) (-4 *4 (-1047)) (-4 *4 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *4)))) (-3297 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-953 (-169 *5))) (-5 *4 (-917)) (-4 *5 (-172)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-3297 (*1 *2 *3) (|partial| -12 (-5 *3 (-953 (-169 *4))) (-4 *4 (-172)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-3819 (*1 *2 *3 *4) (-12 (-5 *3 (-310 (-169 *5))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-842)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-3819 (*1 *2 *3) (-12 (-5 *3 (-310 (-169 *4))) (-4 *4 (-558)) (-4 *4 (-842)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-3819 (*1 *2 *3 *4) (-12 (-5 *3 (-310 *5)) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-842)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-3819 (*1 *2 *3) (-12 (-5 *3 (-310 *4)) (-4 *4 (-558)) (-4 *4 (-842)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-2942 (*1 *2 *3 *4) (-12 (-5 *3 (-310 *5)) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-842)) (-4 *5 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *5)))) (-2942 (*1 *2 *3) (-12 (-5 *3 (-310 *4)) (-4 *4 (-558)) (-4 *4 (-842)) (-4 *4 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *4)))) (-3819 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 (-169 *5)))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-3819 (*1 *2 *3) (-12 (-5 *3 (-409 (-953 (-169 *4)))) (-4 *4 (-558)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-3819 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-3819 (*1 *2 *3) (-12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-558)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-2942 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *5)))) (-2942 (*1 *2 *3) (-12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-558)) (-4 *4 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *4)))) (-3819 (*1 *2 *3 *4) (-12 (-5 *3 (-953 *5)) (-5 *4 (-917)) (-4 *5 (-1047)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-3819 (*1 *2 *3) (-12 (-5 *3 (-953 *4)) (-4 *4 (-1047)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-2942 (*1 *2 *3 *4) (-12 (-5 *3 (-953 *5)) (-5 *4 (-917)) (-4 *5 (-1047)) (-4 *5 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *5)))) (-2942 (*1 *2 *3) (-12 (-5 *3 (-953 *4)) (-4 *4 (-1047)) (-4 *4 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *4)))) (-3819 (*1 *2 *3 *4) (-12 (-5 *3 (-953 (-169 *5))) (-5 *4 (-917)) (-4 *5 (-172)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-3819 (*1 *2 *3) (-12 (-5 *3 (-953 (-169 *4))) (-4 *4 (-172)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-3819 (*1 *2 *3 *4) (-12 (-5 *3 (-169 *5)) (-5 *4 (-917)) (-4 *5 (-172)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-3819 (*1 *2 *3) (-12 (-5 *3 (-169 *4)) (-4 *4 (-172)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-3819 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-5 *2 (-169 (-381))) (-5 *1 (-780 *3)) (-4 *3 (-609 (-381))))) (-3819 (*1 *2 *3) (-12 (-5 *2 (-169 (-381))) (-5 *1 (-780 *3)) (-4 *3 (-609 (-381))))) (-2942 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-5 *2 (-381)) (-5 *1 (-780 *3)) (-4 *3 (-609 *2)))) (-2942 (*1 *2 *3) (-12 (-5 *2 (-381)) (-5 *1 (-780 *3)) (-4 *3 (-609 *2))))) 
-(-10 -7 (-15 -2942 ((-381) |#1|)) (-15 -2942 ((-381) |#1| (-917))) (-15 -3819 ((-169 (-381)) |#1|)) (-15 -3819 ((-169 (-381)) |#1| (-917))) (IF (|has| |#1| (-172)) (PROGN (-15 -3819 ((-169 (-381)) (-169 |#1|))) (-15 -3819 ((-169 (-381)) (-169 |#1|) (-917))) (-15 -3819 ((-169 (-381)) (-953 (-169 |#1|)))) (-15 -3819 ((-169 (-381)) (-953 (-169 |#1|)) (-917)))) |noBranch|) (IF (|has| |#1| (-1047)) (PROGN (-15 -2942 ((-381) (-953 |#1|))) (-15 -2942 ((-381) (-953 |#1|) (-917))) (-15 -3819 ((-169 (-381)) (-953 |#1|))) (-15 -3819 ((-169 (-381)) (-953 |#1|) (-917)))) |noBranch|) (IF (|has| |#1| (-558)) (PROGN (-15 -2942 ((-381) (-409 (-953 |#1|)))) (-15 -2942 ((-381) (-409 (-953 |#1|)) (-917))) (-15 -3819 ((-169 (-381)) (-409 (-953 |#1|)))) (-15 -3819 ((-169 (-381)) (-409 (-953 |#1|)) (-917))) (-15 -3819 ((-169 (-381)) (-409 (-953 (-169 |#1|))))) (-15 -3819 ((-169 (-381)) (-409 (-953 (-169 |#1|))) (-917))) (IF (|has| |#1| (-842)) (PROGN (-15 -2942 ((-381) (-310 |#1|))) (-15 -2942 ((-381) (-310 |#1|) (-917))) (-15 -3819 ((-169 (-381)) (-310 |#1|))) (-15 -3819 ((-169 (-381)) (-310 |#1|) (-917))) (-15 -3819 ((-169 (-381)) (-310 (-169 |#1|)))) (-15 -3819 ((-169 (-381)) (-310 (-169 |#1|)) (-917)))) |noBranch|)) |noBranch|) (IF (|has| |#1| (-172)) (PROGN (-15 -3297 ((-3 (-169 (-381)) "failed") (-953 (-169 |#1|)))) (-15 -3297 ((-3 (-169 (-381)) "failed") (-953 (-169 |#1|)) (-917)))) |noBranch|) (IF (|has| |#1| (-1047)) (PROGN (-15 -3717 ((-3 (-381) "failed") (-953 |#1|))) (-15 -3717 ((-3 (-381) "failed") (-953 |#1|) (-917))) (-15 -3297 ((-3 (-169 (-381)) "failed") (-953 |#1|))) (-15 -3297 ((-3 (-169 (-381)) "failed") (-953 |#1|) (-917)))) |noBranch|) (IF (|has| |#1| (-558)) (PROGN (-15 -3717 ((-3 (-381) "failed") (-409 (-953 |#1|)))) (-15 -3717 ((-3 (-381) "failed") (-409 (-953 |#1|)) (-917))) (-15 -3297 ((-3 (-169 (-381)) "failed") (-409 (-953 |#1|)))) (-15 -3297 ((-3 (-169 (-381)) "failed") (-409 (-953 |#1|)) (-917))) (-15 -3297 ((-3 (-169 (-381)) "failed") (-409 (-953 (-169 |#1|))))) (-15 -3297 ((-3 (-169 (-381)) "failed") (-409 (-953 (-169 |#1|))) (-917))) (IF (|has| |#1| (-842)) (PROGN (-15 -3717 ((-3 (-381) "failed") (-310 |#1|))) (-15 -3717 ((-3 (-381) "failed") (-310 |#1|) (-917))) (-15 -3297 ((-3 (-169 (-381)) "failed") (-310 |#1|))) (-15 -3297 ((-3 (-169 (-381)) "failed") (-310 |#1|) (-917))) (-15 -3297 ((-3 (-169 (-381)) "failed") (-310 (-169 |#1|)))) (-15 -3297 ((-3 (-169 (-381)) "failed") (-310 (-169 |#1|)) (-917)))) |noBranch|)) |noBranch|)) 
-((-1518 (((-917) (-1143)) 63)) (-2900 (((-3 (-381) "failed") (-1143)) 32)) (-3985 (((-381) (-1143)) 30)) (-2306 (((-917) (-1143)) 53)) (-3592 (((-1143) (-917)) 54)) (-1938 (((-1143) (-917)) 52))) 
-(((-781) (-10 -7 (-15 -1938 ((-1143) (-917))) (-15 -2306 ((-917) (-1143))) (-15 -3592 ((-1143) (-917))) (-15 -1518 ((-917) (-1143))) (-15 -3985 ((-381) (-1143))) (-15 -2900 ((-3 (-381) "failed") (-1143))))) (T -781)) 
-((-2900 (*1 *2 *3) (|partial| -12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-781)))) (-3985 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-781)))) (-1518 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-917)) (-5 *1 (-781)))) (-3592 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1143)) (-5 *1 (-781)))) (-2306 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-917)) (-5 *1 (-781)))) (-1938 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1143)) (-5 *1 (-781))))) 
-(-10 -7 (-15 -1938 ((-1143) (-917))) (-15 -2306 ((-917) (-1143))) (-15 -3592 ((-1143) (-917))) (-15 -1518 ((-917) (-1143))) (-15 -3985 ((-381) (-1143))) (-15 -2900 ((-3 (-381) "failed") (-1143)))) 
-((-2447 (((-121) $ $) 7)) (-1304 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 14) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 12)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 15) (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 13)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-1717 (((-121) $ $) 6))) 
+((-2454 (((-3 (-381) "failed") (-310 |#1|) (-917)) 60 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-3 (-381) "failed") (-310 |#1|)) 52 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-3 (-381) "failed") (-409 (-953 |#1|)) (-917)) 39 (|has| |#1| (-558))) (((-3 (-381) "failed") (-409 (-953 |#1|))) 35 (|has| |#1| (-558))) (((-3 (-381) "failed") (-953 |#1|) (-917)) 30 (|has| |#1| (-1047))) (((-3 (-381) "failed") (-953 |#1|)) 24 (|has| |#1| (-1047)))) (-2951 (((-381) (-310 |#1|) (-917)) 92 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-381) (-310 |#1|)) 87 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-381) (-409 (-953 |#1|)) (-917)) 84 (|has| |#1| (-558))) (((-381) (-409 (-953 |#1|))) 81 (|has| |#1| (-558))) (((-381) (-953 |#1|) (-917)) 80 (|has| |#1| (-1047))) (((-381) (-953 |#1|)) 77 (|has| |#1| (-1047))) (((-381) |#1| (-917)) 73) (((-381) |#1|) 22)) (-2165 (((-3 (-169 (-381)) "failed") (-310 (-169 |#1|)) (-917)) 68 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-3 (-169 (-381)) "failed") (-310 (-169 |#1|))) 58 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-3 (-169 (-381)) "failed") (-310 |#1|) (-917)) 61 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-3 (-169 (-381)) "failed") (-310 |#1|)) 59 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-3 (-169 (-381)) "failed") (-409 (-953 (-169 |#1|))) (-917)) 44 (|has| |#1| (-558))) (((-3 (-169 (-381)) "failed") (-409 (-953 (-169 |#1|)))) 43 (|has| |#1| (-558))) (((-3 (-169 (-381)) "failed") (-409 (-953 |#1|)) (-917)) 38 (|has| |#1| (-558))) (((-3 (-169 (-381)) "failed") (-409 (-953 |#1|))) 37 (|has| |#1| (-558))) (((-3 (-169 (-381)) "failed") (-953 |#1|) (-917)) 28 (|has| |#1| (-1047))) (((-3 (-169 (-381)) "failed") (-953 |#1|)) 26 (|has| |#1| (-1047))) (((-3 (-169 (-381)) "failed") (-953 (-169 |#1|)) (-917)) 17 (|has| |#1| (-172))) (((-3 (-169 (-381)) "failed") (-953 (-169 |#1|))) 14 (|has| |#1| (-172)))) (-3823 (((-169 (-381)) (-310 (-169 |#1|)) (-917)) 95 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-169 (-381)) (-310 (-169 |#1|))) 94 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-169 (-381)) (-310 |#1|) (-917)) 93 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-169 (-381)) (-310 |#1|)) 91 (-12 (|has| |#1| (-558)) (|has| |#1| (-842)))) (((-169 (-381)) (-409 (-953 (-169 |#1|))) (-917)) 86 (|has| |#1| (-558))) (((-169 (-381)) (-409 (-953 (-169 |#1|)))) 85 (|has| |#1| (-558))) (((-169 (-381)) (-409 (-953 |#1|)) (-917)) 83 (|has| |#1| (-558))) (((-169 (-381)) (-409 (-953 |#1|))) 82 (|has| |#1| (-558))) (((-169 (-381)) (-953 |#1|) (-917)) 79 (|has| |#1| (-1047))) (((-169 (-381)) (-953 |#1|)) 78 (|has| |#1| (-1047))) (((-169 (-381)) (-953 (-169 |#1|)) (-917)) 75 (|has| |#1| (-172))) (((-169 (-381)) (-953 (-169 |#1|))) 74 (|has| |#1| (-172))) (((-169 (-381)) (-169 |#1|) (-917)) 16 (|has| |#1| (-172))) (((-169 (-381)) (-169 |#1|)) 12 (|has| |#1| (-172))) (((-169 (-381)) |#1| (-917)) 27) (((-169 (-381)) |#1|) 25))) 
+(((-780 |#1|) (-10 -7 (-15 -2951 ((-381) |#1|)) (-15 -2951 ((-381) |#1| (-917))) (-15 -3823 ((-169 (-381)) |#1|)) (-15 -3823 ((-169 (-381)) |#1| (-917))) (IF (|has| |#1| (-172)) (PROGN (-15 -3823 ((-169 (-381)) (-169 |#1|))) (-15 -3823 ((-169 (-381)) (-169 |#1|) (-917))) (-15 -3823 ((-169 (-381)) (-953 (-169 |#1|)))) (-15 -3823 ((-169 (-381)) (-953 (-169 |#1|)) (-917)))) |noBranch|) (IF (|has| |#1| (-1047)) (PROGN (-15 -2951 ((-381) (-953 |#1|))) (-15 -2951 ((-381) (-953 |#1|) (-917))) (-15 -3823 ((-169 (-381)) (-953 |#1|))) (-15 -3823 ((-169 (-381)) (-953 |#1|) (-917)))) |noBranch|) (IF (|has| |#1| (-558)) (PROGN (-15 -2951 ((-381) (-409 (-953 |#1|)))) (-15 -2951 ((-381) (-409 (-953 |#1|)) (-917))) (-15 -3823 ((-169 (-381)) (-409 (-953 |#1|)))) (-15 -3823 ((-169 (-381)) (-409 (-953 |#1|)) (-917))) (-15 -3823 ((-169 (-381)) (-409 (-953 (-169 |#1|))))) (-15 -3823 ((-169 (-381)) (-409 (-953 (-169 |#1|))) (-917))) (IF (|has| |#1| (-842)) (PROGN (-15 -2951 ((-381) (-310 |#1|))) (-15 -2951 ((-381) (-310 |#1|) (-917))) (-15 -3823 ((-169 (-381)) (-310 |#1|))) (-15 -3823 ((-169 (-381)) (-310 |#1|) (-917))) (-15 -3823 ((-169 (-381)) (-310 (-169 |#1|)))) (-15 -3823 ((-169 (-381)) (-310 (-169 |#1|)) (-917)))) |noBranch|)) |noBranch|) (IF (|has| |#1| (-172)) (PROGN (-15 -2165 ((-3 (-169 (-381)) "failed") (-953 (-169 |#1|)))) (-15 -2165 ((-3 (-169 (-381)) "failed") (-953 (-169 |#1|)) (-917)))) |noBranch|) (IF (|has| |#1| (-1047)) (PROGN (-15 -2454 ((-3 (-381) "failed") (-953 |#1|))) (-15 -2454 ((-3 (-381) "failed") (-953 |#1|) (-917))) (-15 -2165 ((-3 (-169 (-381)) "failed") (-953 |#1|))) (-15 -2165 ((-3 (-169 (-381)) "failed") (-953 |#1|) (-917)))) |noBranch|) (IF (|has| |#1| (-558)) (PROGN (-15 -2454 ((-3 (-381) "failed") (-409 (-953 |#1|)))) (-15 -2454 ((-3 (-381) "failed") (-409 (-953 |#1|)) (-917))) (-15 -2165 ((-3 (-169 (-381)) "failed") (-409 (-953 |#1|)))) (-15 -2165 ((-3 (-169 (-381)) "failed") (-409 (-953 |#1|)) (-917))) (-15 -2165 ((-3 (-169 (-381)) "failed") (-409 (-953 (-169 |#1|))))) (-15 -2165 ((-3 (-169 (-381)) "failed") (-409 (-953 (-169 |#1|))) (-917))) (IF (|has| |#1| (-842)) (PROGN (-15 -2454 ((-3 (-381) "failed") (-310 |#1|))) (-15 -2454 ((-3 (-381) "failed") (-310 |#1|) (-917))) (-15 -2165 ((-3 (-169 (-381)) "failed") (-310 |#1|))) (-15 -2165 ((-3 (-169 (-381)) "failed") (-310 |#1|) (-917))) (-15 -2165 ((-3 (-169 (-381)) "failed") (-310 (-169 |#1|)))) (-15 -2165 ((-3 (-169 (-381)) "failed") (-310 (-169 |#1|)) (-917)))) |noBranch|)) |noBranch|)) (-609 (-381))) (T -780)) 
+((-2165 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-310 (-169 *5))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-842)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-2165 (*1 *2 *3) (|partial| -12 (-5 *3 (-310 (-169 *4))) (-4 *4 (-558)) (-4 *4 (-842)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-2165 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-310 *5)) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-842)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-2165 (*1 *2 *3) (|partial| -12 (-5 *3 (-310 *4)) (-4 *4 (-558)) (-4 *4 (-842)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-2454 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-310 *5)) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-842)) (-4 *5 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *5)))) (-2454 (*1 *2 *3) (|partial| -12 (-5 *3 (-310 *4)) (-4 *4 (-558)) (-4 *4 (-842)) (-4 *4 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *4)))) (-2165 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 (-953 (-169 *5)))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-2165 (*1 *2 *3) (|partial| -12 (-5 *3 (-409 (-953 (-169 *4)))) (-4 *4 (-558)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-2165 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-2165 (*1 *2 *3) (|partial| -12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-558)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-2454 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *5)))) (-2454 (*1 *2 *3) (|partial| -12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-558)) (-4 *4 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *4)))) (-2165 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-953 *5)) (-5 *4 (-917)) (-4 *5 (-1047)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-2165 (*1 *2 *3) (|partial| -12 (-5 *3 (-953 *4)) (-4 *4 (-1047)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-2454 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-953 *5)) (-5 *4 (-917)) (-4 *5 (-1047)) (-4 *5 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *5)))) (-2454 (*1 *2 *3) (|partial| -12 (-5 *3 (-953 *4)) (-4 *4 (-1047)) (-4 *4 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *4)))) (-2165 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-953 (-169 *5))) (-5 *4 (-917)) (-4 *5 (-172)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-2165 (*1 *2 *3) (|partial| -12 (-5 *3 (-953 (-169 *4))) (-4 *4 (-172)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-3823 (*1 *2 *3 *4) (-12 (-5 *3 (-310 (-169 *5))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-842)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-3823 (*1 *2 *3) (-12 (-5 *3 (-310 (-169 *4))) (-4 *4 (-558)) (-4 *4 (-842)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-3823 (*1 *2 *3 *4) (-12 (-5 *3 (-310 *5)) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-842)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-3823 (*1 *2 *3) (-12 (-5 *3 (-310 *4)) (-4 *4 (-558)) (-4 *4 (-842)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-2951 (*1 *2 *3 *4) (-12 (-5 *3 (-310 *5)) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-842)) (-4 *5 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *5)))) (-2951 (*1 *2 *3) (-12 (-5 *3 (-310 *4)) (-4 *4 (-558)) (-4 *4 (-842)) (-4 *4 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *4)))) (-3823 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 (-169 *5)))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-3823 (*1 *2 *3) (-12 (-5 *3 (-409 (-953 (-169 *4)))) (-4 *4 (-558)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-3823 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-3823 (*1 *2 *3) (-12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-558)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-2951 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *5)))) (-2951 (*1 *2 *3) (-12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-558)) (-4 *4 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *4)))) (-3823 (*1 *2 *3 *4) (-12 (-5 *3 (-953 *5)) (-5 *4 (-917)) (-4 *5 (-1047)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-3823 (*1 *2 *3) (-12 (-5 *3 (-953 *4)) (-4 *4 (-1047)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-2951 (*1 *2 *3 *4) (-12 (-5 *3 (-953 *5)) (-5 *4 (-917)) (-4 *5 (-1047)) (-4 *5 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *5)))) (-2951 (*1 *2 *3) (-12 (-5 *3 (-953 *4)) (-4 *4 (-1047)) (-4 *4 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *4)))) (-3823 (*1 *2 *3 *4) (-12 (-5 *3 (-953 (-169 *5))) (-5 *4 (-917)) (-4 *5 (-172)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-3823 (*1 *2 *3) (-12 (-5 *3 (-953 (-169 *4))) (-4 *4 (-172)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-3823 (*1 *2 *3 *4) (-12 (-5 *3 (-169 *5)) (-5 *4 (-917)) (-4 *5 (-172)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) (-3823 (*1 *2 *3) (-12 (-5 *3 (-169 *4)) (-4 *4 (-172)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) (-3823 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-5 *2 (-169 (-381))) (-5 *1 (-780 *3)) (-4 *3 (-609 (-381))))) (-3823 (*1 *2 *3) (-12 (-5 *2 (-169 (-381))) (-5 *1 (-780 *3)) (-4 *3 (-609 (-381))))) (-2951 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-5 *2 (-381)) (-5 *1 (-780 *3)) (-4 *3 (-609 *2)))) (-2951 (*1 *2 *3) (-12 (-5 *2 (-381)) (-5 *1 (-780 *3)) (-4 *3 (-609 *2))))) 
+(-10 -7 (-15 -2951 ((-381) |#1|)) (-15 -2951 ((-381) |#1| (-917))) (-15 -3823 ((-169 (-381)) |#1|)) (-15 -3823 ((-169 (-381)) |#1| (-917))) (IF (|has| |#1| (-172)) (PROGN (-15 -3823 ((-169 (-381)) (-169 |#1|))) (-15 -3823 ((-169 (-381)) (-169 |#1|) (-917))) (-15 -3823 ((-169 (-381)) (-953 (-169 |#1|)))) (-15 -3823 ((-169 (-381)) (-953 (-169 |#1|)) (-917)))) |noBranch|) (IF (|has| |#1| (-1047)) (PROGN (-15 -2951 ((-381) (-953 |#1|))) (-15 -2951 ((-381) (-953 |#1|) (-917))) (-15 -3823 ((-169 (-381)) (-953 |#1|))) (-15 -3823 ((-169 (-381)) (-953 |#1|) (-917)))) |noBranch|) (IF (|has| |#1| (-558)) (PROGN (-15 -2951 ((-381) (-409 (-953 |#1|)))) (-15 -2951 ((-381) (-409 (-953 |#1|)) (-917))) (-15 -3823 ((-169 (-381)) (-409 (-953 |#1|)))) (-15 -3823 ((-169 (-381)) (-409 (-953 |#1|)) (-917))) (-15 -3823 ((-169 (-381)) (-409 (-953 (-169 |#1|))))) (-15 -3823 ((-169 (-381)) (-409 (-953 (-169 |#1|))) (-917))) (IF (|has| |#1| (-842)) (PROGN (-15 -2951 ((-381) (-310 |#1|))) (-15 -2951 ((-381) (-310 |#1|) (-917))) (-15 -3823 ((-169 (-381)) (-310 |#1|))) (-15 -3823 ((-169 (-381)) (-310 |#1|) (-917))) (-15 -3823 ((-169 (-381)) (-310 (-169 |#1|)))) (-15 -3823 ((-169 (-381)) (-310 (-169 |#1|)) (-917)))) |noBranch|)) |noBranch|) (IF (|has| |#1| (-172)) (PROGN (-15 -2165 ((-3 (-169 (-381)) "failed") (-953 (-169 |#1|)))) (-15 -2165 ((-3 (-169 (-381)) "failed") (-953 (-169 |#1|)) (-917)))) |noBranch|) (IF (|has| |#1| (-1047)) (PROGN (-15 -2454 ((-3 (-381) "failed") (-953 |#1|))) (-15 -2454 ((-3 (-381) "failed") (-953 |#1|) (-917))) (-15 -2165 ((-3 (-169 (-381)) "failed") (-953 |#1|))) (-15 -2165 ((-3 (-169 (-381)) "failed") (-953 |#1|) (-917)))) |noBranch|) (IF (|has| |#1| (-558)) (PROGN (-15 -2454 ((-3 (-381) "failed") (-409 (-953 |#1|)))) (-15 -2454 ((-3 (-381) "failed") (-409 (-953 |#1|)) (-917))) (-15 -2165 ((-3 (-169 (-381)) "failed") (-409 (-953 |#1|)))) (-15 -2165 ((-3 (-169 (-381)) "failed") (-409 (-953 |#1|)) (-917))) (-15 -2165 ((-3 (-169 (-381)) "failed") (-409 (-953 (-169 |#1|))))) (-15 -2165 ((-3 (-169 (-381)) "failed") (-409 (-953 (-169 |#1|))) (-917))) (IF (|has| |#1| (-842)) (PROGN (-15 -2454 ((-3 (-381) "failed") (-310 |#1|))) (-15 -2454 ((-3 (-381) "failed") (-310 |#1|) (-917))) (-15 -2165 ((-3 (-169 (-381)) "failed") (-310 |#1|))) (-15 -2165 ((-3 (-169 (-381)) "failed") (-310 |#1|) (-917))) (-15 -2165 ((-3 (-169 (-381)) "failed") (-310 (-169 |#1|)))) (-15 -2165 ((-3 (-169 (-381)) "failed") (-310 (-169 |#1|)) (-917)))) |noBranch|)) |noBranch|)) 
+((-4108 (((-917) (-1143)) 63)) (-2822 (((-3 (-381) "failed") (-1143)) 32)) (-1276 (((-381) (-1143)) 30)) (-3678 (((-917) (-1143)) 53)) (-2972 (((-1143) (-917)) 54)) (-4218 (((-1143) (-917)) 52))) 
+(((-781) (-10 -7 (-15 -4218 ((-1143) (-917))) (-15 -3678 ((-917) (-1143))) (-15 -2972 ((-1143) (-917))) (-15 -4108 ((-917) (-1143))) (-15 -1276 ((-381) (-1143))) (-15 -2822 ((-3 (-381) "failed") (-1143))))) (T -781)) 
+((-2822 (*1 *2 *3) (|partial| -12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-781)))) (-1276 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-781)))) (-4108 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-917)) (-5 *1 (-781)))) (-2972 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1143)) (-5 *1 (-781)))) (-3678 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-917)) (-5 *1 (-781)))) (-4218 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1143)) (-5 *1 (-781))))) 
+(-10 -7 (-15 -4218 ((-1143) (-917))) (-15 -3678 ((-917) (-1143))) (-15 -2972 ((-1143) (-917))) (-15 -4108 ((-917) (-1143))) (-15 -1276 ((-381) (-1143))) (-15 -2822 ((-3 (-381) "failed") (-1143)))) 
+((-2449 (((-121) $ $) 7)) (-3318 (((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 14) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035)) 12)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 15) (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 13)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-1719 (((-121) $ $) 6))) 
 (((-782) (-1275)) (T -782)) 
-((-3029 (*1 *2 *3 *4) (-12 (-4 *1 (-782)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035)))))) (-1304 (*1 *2 *3 *2) (-12 (-4 *1 (-782)) (-5 *2 (-1035)) (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))))) (-3029 (*1 *2 *3 *4) (-12 (-4 *1 (-782)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035)))))) (-1304 (*1 *2 *3 *2) (-12 (-4 *1 (-782)) (-5 *2 (-1035)) (-5 *3 (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))))) 
-(-13 (-1090) (-10 -7 (-15 -3029 ((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -1304 ((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035))) (-15 -3029 ((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -1304 ((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035))))) 
+((-3031 (*1 *2 *3 *4) (-12 (-4 *1 (-782)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035)))))) (-3318 (*1 *2 *3 *2) (-12 (-4 *1 (-782)) (-5 *2 (-1035)) (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))))) (-3031 (*1 *2 *3 *4) (-12 (-4 *1 (-782)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035)))))) (-3318 (*1 *2 *3 *2) (-12 (-4 *1 (-782)) (-5 *2 (-1035)) (-5 *3 (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))))) 
+(-13 (-1090) (-10 -7 (-15 -3031 ((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -3318 ((-1035) (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035))) (-15 -3031 ((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -3318 ((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) (-1035))))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-2806 (((-1249) (-1244 (-381)) (-568) (-381) (-2 (|:| |try| (-381)) (|:| |did| (-381)) (|:| -3650 (-381))) (-381) (-1244 (-381)) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381))) 44) (((-1249) (-1244 (-381)) (-568) (-381) (-2 (|:| |try| (-381)) (|:| |did| (-381)) (|:| -3650 (-381))) (-381) (-1244 (-381)) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381))) 43)) (-1307 (((-1249) (-1244 (-381)) (-568) (-381) (-381) (-568) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381))) 50)) (-2120 (((-1249) (-1244 (-381)) (-568) (-381) (-381) (-381) (-381) (-568) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381))) 41)) (-3283 (((-1249) (-1244 (-381)) (-568) (-381) (-381) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381))) 52) (((-1249) (-1244 (-381)) (-568) (-381) (-381) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381))) 51))) 
-(((-783) (-10 -7 (-15 -3283 ((-1249) (-1244 (-381)) (-568) (-381) (-381) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)))) (-15 -3283 ((-1249) (-1244 (-381)) (-568) (-381) (-381) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)))) (-15 -2120 ((-1249) (-1244 (-381)) (-568) (-381) (-381) (-381) (-381) (-568) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)))) (-15 -2806 ((-1249) (-1244 (-381)) (-568) (-381) (-2 (|:| |try| (-381)) (|:| |did| (-381)) (|:| -3650 (-381))) (-381) (-1244 (-381)) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)))) (-15 -2806 ((-1249) (-1244 (-381)) (-568) (-381) (-2 (|:| |try| (-381)) (|:| |did| (-381)) (|:| -3650 (-381))) (-381) (-1244 (-381)) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)))) (-15 -1307 ((-1249) (-1244 (-381)) (-568) (-381) (-381) (-568) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)))))) (T -783)) 
-((-1307 (*1 *2 *3 *4 *5 *5 *4 *6) (-12 (-5 *4 (-568)) (-5 *6 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783)))) (-2806 (*1 *2 *3 *4 *5 *6 *5 *3 *7 *3 *3 *3 *3 *3 *3 *3) (-12 (-5 *4 (-568)) (-5 *6 (-2 (|:| |try| (-381)) (|:| |did| (-381)) (|:| -3650 (-381)))) (-5 *7 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783)))) (-2806 (*1 *2 *3 *4 *5 *6 *5 *3 *7) (-12 (-5 *4 (-568)) (-5 *6 (-2 (|:| |try| (-381)) (|:| |did| (-381)) (|:| -3650 (-381)))) (-5 *7 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783)))) (-2120 (*1 *2 *3 *4 *5 *5 *5 *5 *4 *6) (-12 (-5 *4 (-568)) (-5 *6 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783)))) (-3283 (*1 *2 *3 *4 *5 *5 *6 *3 *3 *3 *3) (-12 (-5 *4 (-568)) (-5 *6 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783)))) (-3283 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *4 (-568)) (-5 *6 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783))))) 
-(-10 -7 (-15 -3283 ((-1249) (-1244 (-381)) (-568) (-381) (-381) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)))) (-15 -3283 ((-1249) (-1244 (-381)) (-568) (-381) (-381) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)))) (-15 -2120 ((-1249) (-1244 (-381)) (-568) (-381) (-381) (-381) (-381) (-568) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)))) (-15 -2806 ((-1249) (-1244 (-381)) (-568) (-381) (-2 (|:| |try| (-381)) (|:| |did| (-381)) (|:| -3650 (-381))) (-381) (-1244 (-381)) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)))) (-15 -2806 ((-1249) (-1244 (-381)) (-568) (-381) (-2 (|:| |try| (-381)) (|:| |did| (-381)) (|:| -3650 (-381))) (-381) (-1244 (-381)) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)))) (-15 -1307 ((-1249) (-1244 (-381)) (-568) (-381) (-381) (-568) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381))))) 
-((-4236 (((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568)) 53)) (-3294 (((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568)) 30)) (-3304 (((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568)) 52)) (-4399 (((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568)) 28)) (-3402 (((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568)) 51)) (-1452 (((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568)) 18)) (-2530 (((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568) (-568)) 31)) (-1549 (((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568) (-568)) 29)) (-3899 (((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568) (-568)) 27))) 
-(((-784) (-10 -7 (-15 -3899 ((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568) (-568))) (-15 -1549 ((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568) (-568))) (-15 -2530 ((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568) (-568))) (-15 -1452 ((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568))) (-15 -4399 ((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568))) (-15 -3294 ((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568))) (-15 -3402 ((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568))) (-15 -3304 ((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568))) (-15 -4236 ((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568))))) (T -784)) 
-((-4236 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2850 *4) (|:| -2183 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568)))) (-3304 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2850 *4) (|:| -2183 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568)))) (-3402 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2850 *4) (|:| -2183 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568)))) (-3294 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2850 *4) (|:| -2183 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568)))) (-4399 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2850 *4) (|:| -2183 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568)))) (-1452 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2850 *4) (|:| -2183 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568)))) (-2530 (*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2850 *4) (|:| -2183 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568)))) (-1549 (*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2850 *4) (|:| -2183 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568)))) (-3899 (*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2850 *4) (|:| -2183 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568))))) 
-(-10 -7 (-15 -3899 ((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568) (-568))) (-15 -1549 ((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568) (-568))) (-15 -2530 ((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568) (-568))) (-15 -1452 ((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568))) (-15 -4399 ((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568))) (-15 -3294 ((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568))) (-15 -3402 ((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568))) (-15 -3304 ((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568))) (-15 -4236 ((-2 (|:| -2850 (-381)) (|:| -2183 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568)))) 
-((-3368 (((-1191 |#1|) |#1| (-215) (-568)) 45))) 
-(((-785 |#1|) (-10 -7 (-15 -3368 ((-1191 |#1|) |#1| (-215) (-568)))) (-975)) (T -785)) 
-((-3368 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-215)) (-5 *5 (-568)) (-5 *2 (-1191 *3)) (-5 *1 (-785 *3)) (-4 *3 (-975))))) 
-(-10 -7 (-15 -3368 ((-1191 |#1|) |#1| (-215) (-568)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 23)) (-3134 (((-3 $ "failed") $ $) 25)) (-2671 (($) 22 T CONST)) (-2521 (($ $ $) 12)) (-3268 (($ $ $) 13)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-3056 (($) 21 T CONST)) (-1751 (((-121) $ $) 15)) (-1738 (((-121) $ $) 16)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 14)) (-1732 (((-121) $ $) 17)) (-1773 (($ $ $) 27) (($ $) 26)) (-1767 (($ $ $) 19)) (* (($ (-763) $) 24) (($ (-917) $) 20) (($ (-568) $) 28))) 
+((-3682 (((-1249) (-1244 (-381)) (-568) (-381) (-2 (|:| |try| (-381)) (|:| |did| (-381)) (|:| -3652 (-381))) (-381) (-1244 (-381)) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381))) 44) (((-1249) (-1244 (-381)) (-568) (-381) (-2 (|:| |try| (-381)) (|:| |did| (-381)) (|:| -3652 (-381))) (-381) (-1244 (-381)) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381))) 43)) (-3339 (((-1249) (-1244 (-381)) (-568) (-381) (-381) (-568) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381))) 50)) (-3336 (((-1249) (-1244 (-381)) (-568) (-381) (-381) (-381) (-381) (-568) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381))) 41)) (-2114 (((-1249) (-1244 (-381)) (-568) (-381) (-381) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381))) 52) (((-1249) (-1244 (-381)) (-568) (-381) (-381) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381))) 51))) 
+(((-783) (-10 -7 (-15 -2114 ((-1249) (-1244 (-381)) (-568) (-381) (-381) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)))) (-15 -2114 ((-1249) (-1244 (-381)) (-568) (-381) (-381) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)))) (-15 -3336 ((-1249) (-1244 (-381)) (-568) (-381) (-381) (-381) (-381) (-568) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)))) (-15 -3682 ((-1249) (-1244 (-381)) (-568) (-381) (-2 (|:| |try| (-381)) (|:| |did| (-381)) (|:| -3652 (-381))) (-381) (-1244 (-381)) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)))) (-15 -3682 ((-1249) (-1244 (-381)) (-568) (-381) (-2 (|:| |try| (-381)) (|:| |did| (-381)) (|:| -3652 (-381))) (-381) (-1244 (-381)) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)))) (-15 -3339 ((-1249) (-1244 (-381)) (-568) (-381) (-381) (-568) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)))))) (T -783)) 
+((-3339 (*1 *2 *3 *4 *5 *5 *4 *6) (-12 (-5 *4 (-568)) (-5 *6 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783)))) (-3682 (*1 *2 *3 *4 *5 *6 *5 *3 *7 *3 *3 *3 *3 *3 *3 *3) (-12 (-5 *4 (-568)) (-5 *6 (-2 (|:| |try| (-381)) (|:| |did| (-381)) (|:| -3652 (-381)))) (-5 *7 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783)))) (-3682 (*1 *2 *3 *4 *5 *6 *5 *3 *7) (-12 (-5 *4 (-568)) (-5 *6 (-2 (|:| |try| (-381)) (|:| |did| (-381)) (|:| -3652 (-381)))) (-5 *7 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783)))) (-3336 (*1 *2 *3 *4 *5 *5 *5 *5 *4 *6) (-12 (-5 *4 (-568)) (-5 *6 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783)))) (-2114 (*1 *2 *3 *4 *5 *5 *6 *3 *3 *3 *3) (-12 (-5 *4 (-568)) (-5 *6 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783)))) (-2114 (*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *4 (-568)) (-5 *6 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783))))) 
+(-10 -7 (-15 -2114 ((-1249) (-1244 (-381)) (-568) (-381) (-381) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)))) (-15 -2114 ((-1249) (-1244 (-381)) (-568) (-381) (-381) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)))) (-15 -3336 ((-1249) (-1244 (-381)) (-568) (-381) (-381) (-381) (-381) (-568) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)))) (-15 -3682 ((-1249) (-1244 (-381)) (-568) (-381) (-2 (|:| |try| (-381)) (|:| |did| (-381)) (|:| -3652 (-381))) (-381) (-1244 (-381)) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)))) (-15 -3682 ((-1249) (-1244 (-381)) (-568) (-381) (-2 (|:| |try| (-381)) (|:| |did| (-381)) (|:| -3652 (-381))) (-381) (-1244 (-381)) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)) (-1244 (-381)))) (-15 -3339 ((-1249) (-1244 (-381)) (-568) (-381) (-381) (-568) (-1 (-1249) (-1244 (-381)) (-1244 (-381)) (-381))))) 
+((-2824 (((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568)) 53)) (-2150 (((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568)) 30)) (-4243 (((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568)) 52)) (-1462 (((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568)) 28)) (-1549 (((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568)) 51)) (-2357 (((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568)) 18)) (-1786 (((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568) (-568)) 31)) (-4297 (((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568) (-568)) 29)) (-2063 (((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568) (-568)) 27))) 
+(((-784) (-10 -7 (-15 -2063 ((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568) (-568))) (-15 -4297 ((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568) (-568))) (-15 -1786 ((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568) (-568))) (-15 -2357 ((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568))) (-15 -1462 ((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568))) (-15 -2150 ((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568))) (-15 -1549 ((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568))) (-15 -4243 ((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568))) (-15 -2824 ((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568))))) (T -784)) 
+((-2824 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2852 *4) (|:| -2185 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568)))) (-4243 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2852 *4) (|:| -2185 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568)))) (-1549 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2852 *4) (|:| -2185 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568)))) (-2150 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2852 *4) (|:| -2185 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568)))) (-1462 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2852 *4) (|:| -2185 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568)))) (-2357 (*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2852 *4) (|:| -2185 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568)))) (-1786 (*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2852 *4) (|:| -2185 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568)))) (-4297 (*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2852 *4) (|:| -2185 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568)))) (-2063 (*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2852 *4) (|:| -2185 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568))))) 
+(-10 -7 (-15 -2063 ((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568) (-568))) (-15 -4297 ((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568) (-568))) (-15 -1786 ((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568) (-568))) (-15 -2357 ((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568))) (-15 -1462 ((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568))) (-15 -2150 ((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568))) (-15 -1549 ((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568))) (-15 -4243 ((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568))) (-15 -2824 ((-2 (|:| -2852 (-381)) (|:| -2185 (-381)) (|:| |totalpts| (-568)) (|:| |success| (-121))) (-1 (-381) (-381)) (-381) (-381) (-381) (-381) (-568) (-568)))) 
+((-1370 (((-1191 |#1|) |#1| (-215) (-568)) 45))) 
+(((-785 |#1|) (-10 -7 (-15 -1370 ((-1191 |#1|) |#1| (-215) (-568)))) (-975)) (T -785)) 
+((-1370 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-215)) (-5 *5 (-568)) (-5 *2 (-1191 *3)) (-5 *1 (-785 *3)) (-4 *3 (-975))))) 
+(-10 -7 (-15 -1370 ((-1191 |#1|) |#1| (-215) (-568)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 23)) (-2689 (((-3 $ "failed") $ $) 25)) (-4490 (($) 22 T CONST)) (-1732 (($ $ $) 12)) (-2047 (($ $ $) 13)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-3058 (($) 21 T CONST)) (-1753 (((-121) $ $) 15)) (-1740 (((-121) $ $) 16)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 14)) (-1734 (((-121) $ $) 17)) (-1775 (($ $ $) 27) (($ $) 26)) (-1769 (($ $ $) 19)) (* (($ (-763) $) 24) (($ (-917) $) 20) (($ (-568) $) 28))) 
 (((-786) (-1275)) (T -786)) 
 NIL 
 (-13 (-790) (-21)) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-137) . T) ((-608 (-850)) . T) ((-787) . T) ((-789) . T) ((-790) . T) ((-842) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 23)) (-2671 (($) 22 T CONST)) (-2521 (($ $ $) 12)) (-3268 (($ $ $) 13)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-3056 (($) 21 T CONST)) (-1751 (((-121) $ $) 15)) (-1738 (((-121) $ $) 16)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 14)) (-1732 (((-121) $ $) 17)) (-1767 (($ $ $) 19)) (* (($ (-763) $) 24) (($ (-917) $) 20))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 23)) (-4490 (($) 22 T CONST)) (-1732 (($ $ $) 12)) (-2047 (($ $ $) 13)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-3058 (($) 21 T CONST)) (-1753 (((-121) $ $) 15)) (-1740 (((-121) $ $) 16)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 14)) (-1734 (((-121) $ $) 17)) (-1769 (($ $ $) 19)) (* (($ (-763) $) 24) (($ (-917) $) 20))) 
 (((-787) (-1275)) (T -787)) 
 NIL 
 (-13 (-789) (-23)) 
 (((-23) . T) ((-25) . T) ((-105) . T) ((-608 (-850)) . T) ((-789) . T) ((-842) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 23)) (-1462 (($ $ $) 26)) (-3134 (((-3 $ "failed") $ $) 25)) (-2671 (($) 22 T CONST)) (-2521 (($ $ $) 12)) (-3268 (($ $ $) 13)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-3056 (($) 21 T CONST)) (-1751 (((-121) $ $) 15)) (-1738 (((-121) $ $) 16)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 14)) (-1732 (((-121) $ $) 17)) (-1767 (($ $ $) 19)) (* (($ (-763) $) 24) (($ (-917) $) 20))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 23)) (-2409 (($ $ $) 26)) (-2689 (((-3 $ "failed") $ $) 25)) (-4490 (($) 22 T CONST)) (-1732 (($ $ $) 12)) (-2047 (($ $ $) 13)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-3058 (($) 21 T CONST)) (-1753 (((-121) $ $) 15)) (-1740 (((-121) $ $) 16)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 14)) (-1734 (((-121) $ $) 17)) (-1769 (($ $ $) 19)) (* (($ (-763) $) 24) (($ (-917) $) 20))) 
 (((-788) (-1275)) (T -788)) 
-((-1462 (*1 *1 *1 *1) (-4 *1 (-788)))) 
-(-13 (-790) (-10 -8 (-15 -1462 ($ $ $)))) 
+((-2409 (*1 *1 *1 *1) (-4 *1 (-788)))) 
+(-13 (-790) (-10 -8 (-15 -2409 ($ $ $)))) 
 (((-23) . T) ((-25) . T) ((-105) . T) ((-137) . T) ((-608 (-850)) . T) ((-787) . T) ((-789) . T) ((-790) . T) ((-842) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 23)) (-2671 (($) 22 T CONST)) (-2521 (($ $ $) 12)) (-3268 (($ $ $) 13)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-3056 (($) 21 T CONST)) (-1751 (((-121) $ $) 15)) (-1738 (((-121) $ $) 16)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 14)) (-1732 (((-121) $ $) 17)) (-1767 (($ $ $) 19)) (* (($ (-763) $) 24) (($ (-917) $) 20))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 23)) (-4490 (($) 22 T CONST)) (-1732 (($ $ $) 12)) (-2047 (($ $ $) 13)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-3058 (($) 21 T CONST)) (-1753 (((-121) $ $) 15)) (-1740 (((-121) $ $) 16)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 14)) (-1734 (((-121) $ $) 17)) (-1769 (($ $ $) 19)) (* (($ (-763) $) 24) (($ (-917) $) 20))) 
 (((-789) (-1275)) (T -789)) 
 NIL 
 (-13 (-842) (-23)) 
 (((-23) . T) ((-25) . T) ((-105) . T) ((-608 (-850)) . T) ((-842) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 23)) (-3134 (((-3 $ "failed") $ $) 25)) (-2671 (($) 22 T CONST)) (-2521 (($ $ $) 12)) (-3268 (($ $ $) 13)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-3056 (($) 21 T CONST)) (-1751 (((-121) $ $) 15)) (-1738 (((-121) $ $) 16)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 14)) (-1732 (((-121) $ $) 17)) (-1767 (($ $ $) 19)) (* (($ (-763) $) 24) (($ (-917) $) 20))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 23)) (-2689 (((-3 $ "failed") $ $) 25)) (-4490 (($) 22 T CONST)) (-1732 (($ $ $) 12)) (-2047 (($ $ $) 13)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-3058 (($) 21 T CONST)) (-1753 (((-121) $ $) 15)) (-1740 (((-121) $ $) 16)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 14)) (-1734 (((-121) $ $) 17)) (-1769 (($ $ $) 19)) (* (($ (-763) $) 24) (($ (-917) $) 20))) 
 (((-790) (-1275)) (T -790)) 
 NIL 
 (-13 (-787) (-137)) 
 (((-23) . T) ((-25) . T) ((-105) . T) ((-137) . T) ((-608 (-850)) . T) ((-787) . T) ((-789) . T) ((-842) . T) ((-1090) . T)) 
-((-2537 (((-121) $) 41)) (-3666 (((-3 (-568) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 |#2| "failed") $) 44)) (-2854 (((-568) $) NIL) (((-409 (-568)) $) NIL) ((|#2| $) 42)) (-1642 (((-3 (-409 (-568)) "failed") $) 78)) (-2688 (((-121) $) 72)) (-2425 (((-409 (-568)) $) 76)) (-2657 ((|#2| $) 26)) (-2795 (($ (-1 |#2| |#2|) $) 23)) (-2081 (($ $) 61)) (-4278 (((-541) $) 67)) (-1458 (($ $) 21)) (-2745 (((-850) $) 56) (($ (-568)) 39) (($ |#2|) 37) (($ (-409 (-568))) NIL)) (-4078 (((-763)) 10)) (-2897 ((|#2| $) 71)) (-1717 (((-121) $ $) 29)) (-1732 (((-121) $ $) 69)) (-1773 (($ $) 31) (($ $ $) NIL)) (-1767 (($ $ $) 30)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 35) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) 32))) 
-(((-791 |#1| |#2|) (-10 -8 (-15 -1732 ((-121) |#1| |#1|)) (-15 -4278 ((-541) |#1|)) (-15 -2081 (|#1| |#1|)) (-15 -1642 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2425 ((-409 (-568)) |#1|)) (-15 -2688 ((-121) |#1|)) (-15 -2897 (|#2| |#1|)) (-15 -2657 (|#2| |#1|)) (-15 -1458 (|#1| |#1|)) (-15 -2795 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2854 (|#2| |#1|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2854 ((-568) |#1|)) (-15 -2745 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -2745 (|#1| (-568))) (-15 -4078 ((-763))) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 -1773 (|#1| |#1| |#1|)) (-15 -1773 (|#1| |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 -2537 ((-121) |#1|)) (-15 * (|#1| (-917) |#1|)) (-15 -1767 (|#1| |#1| |#1|)) (-15 -2745 ((-850) |#1|)) (-15 -1717 ((-121) |#1| |#1|))) (-792 |#2|) (-172)) (T -791)) 
-((-4078 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-763)) (-5 *1 (-791 *3 *4)) (-4 *3 (-792 *4))))) 
-(-10 -8 (-15 -1732 ((-121) |#1| |#1|)) (-15 -4278 ((-541) |#1|)) (-15 -2081 (|#1| |#1|)) (-15 -1642 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2425 ((-409 (-568)) |#1|)) (-15 -2688 ((-121) |#1|)) (-15 -2897 (|#2| |#1|)) (-15 -2657 (|#2| |#1|)) (-15 -1458 (|#1| |#1|)) (-15 -2795 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2854 (|#2| |#1|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2854 ((-568) |#1|)) (-15 -2745 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -2745 (|#1| (-568))) (-15 -4078 ((-763))) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 -1773 (|#1| |#1| |#1|)) (-15 -1773 (|#1| |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 -2537 ((-121) |#1|)) (-15 * (|#1| (-917) |#1|)) (-15 -1767 (|#1| |#1| |#1|)) (-15 -2745 ((-850) |#1|)) (-15 -1717 ((-121) |#1| |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-3983 (((-763)) 51 (|has| |#1| (-370)))) (-2671 (($) 16 T CONST)) (-3666 (((-3 (-568) "failed") $) 92 (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) 90 (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 88)) (-2854 (((-568) $) 93 (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) 91 (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) 87)) (-2925 (((-3 $ "failed") $) 33)) (-3857 ((|#1| $) 77)) (-1642 (((-3 (-409 (-568)) "failed") $) 64 (|has| |#1| (-550)))) (-2688 (((-121) $) 66 (|has| |#1| (-550)))) (-2425 (((-409 (-568)) $) 65 (|has| |#1| (-550)))) (-1731 (($) 54 (|has| |#1| (-370)))) (-2735 (((-121) $) 30)) (-3739 (($ |#1| |#1| |#1| |#1| |#1| |#1| |#1| |#1|) 68)) (-2657 ((|#1| $) 69)) (-2521 (($ $ $) 60 (|has| |#1| (-842)))) (-3268 (($ $ $) 59 (|has| |#1| (-842)))) (-2795 (($ (-1 |#1| |#1|) $) 79)) (-3683 (((-917) $) 53 (|has| |#1| (-370)))) (-4487 (((-1143) $) 9)) (-2081 (($ $) 63 (|has| |#1| (-365)))) (-4355 (($ (-917)) 52 (|has| |#1| (-370)))) (-3117 ((|#1| $) 74)) (-3915 ((|#1| $) 75)) (-4341 ((|#1| $) 76)) (-1927 ((|#1| $) 70)) (-3312 ((|#1| $) 71)) (-4184 ((|#1| $) 72)) (-3817 ((|#1| $) 73)) (-4022 (((-1108) $) 10)) (-1339 (($ $ (-634 |#1|) (-634 |#1|)) 85 (|has| |#1| (-303 |#1|))) (($ $ |#1| |#1|) 84 (|has| |#1| (-303 |#1|))) (($ $ (-288 |#1|)) 83 (|has| |#1| (-303 |#1|))) (($ $ (-634 (-288 |#1|))) 82 (|has| |#1| (-303 |#1|))) (($ $ (-634 (-1161)) (-634 |#1|)) 81 (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-1161) |#1|) 80 (|has| |#1| (-523 (-1161) |#1|)))) (-2779 (($ $ |#1|) 86 (|has| |#1| (-281 |#1| |#1|)))) (-4278 (((-541) $) 61 (|has| |#1| (-609 (-541))))) (-1458 (($ $) 78)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 36) (($ (-409 (-568))) 89 (|has| |#1| (-1037 (-409 (-568)))))) (-4371 (((-3 $ "failed") $) 62 (|has| |#1| (-148)))) (-4078 (((-763)) 28)) (-2897 ((|#1| $) 67 (|has| |#1| (-1056)))) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1751 (((-121) $ $) 57 (|has| |#1| (-842)))) (-1738 (((-121) $ $) 56 (|has| |#1| (-842)))) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 58 (|has| |#1| (-842)))) (-1732 (((-121) $ $) 55 (|has| |#1| (-842)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37))) 
+((-1819 (((-121) $) 41)) (-3668 (((-3 (-568) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 |#2| "failed") $) 44)) (-2857 (((-568) $) NIL) (((-409 (-568)) $) NIL) ((|#2| $) 42)) (-3254 (((-3 (-409 (-568)) "failed") $) 78)) (-1338 (((-121) $) 72)) (-2394 (((-409 (-568)) $) 76)) (-4417 ((|#2| $) 26)) (-2797 (($ (-1 |#2| |#2|) $) 23)) (-2083 (($ $) 61)) (-4280 (((-541) $) 67)) (-2387 (($ $) 21)) (-2747 (((-850) $) 56) (($ (-568)) 39) (($ |#2|) 37) (($ (-409 (-568))) NIL)) (-3425 (((-763)) 10)) (-2811 ((|#2| $) 71)) (-1719 (((-121) $ $) 29)) (-1734 (((-121) $ $) 69)) (-1775 (($ $) 31) (($ $ $) NIL)) (-1769 (($ $ $) 30)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 35) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) 32))) 
+(((-791 |#1| |#2|) (-10 -8 (-15 -1734 ((-121) |#1| |#1|)) (-15 -4280 ((-541) |#1|)) (-15 -2083 (|#1| |#1|)) (-15 -3254 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2394 ((-409 (-568)) |#1|)) (-15 -1338 ((-121) |#1|)) (-15 -2811 (|#2| |#1|)) (-15 -4417 (|#2| |#1|)) (-15 -2387 (|#1| |#1|)) (-15 -2797 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2857 (|#2| |#1|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2857 ((-568) |#1|)) (-15 -2747 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -2747 (|#1| (-568))) (-15 -3425 ((-763))) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 -1775 (|#1| |#1| |#1|)) (-15 -1775 (|#1| |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 -1819 ((-121) |#1|)) (-15 * (|#1| (-917) |#1|)) (-15 -1769 (|#1| |#1| |#1|)) (-15 -2747 ((-850) |#1|)) (-15 -1719 ((-121) |#1| |#1|))) (-792 |#2|) (-172)) (T -791)) 
+((-3425 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-763)) (-5 *1 (-791 *3 *4)) (-4 *3 (-792 *4))))) 
+(-10 -8 (-15 -1734 ((-121) |#1| |#1|)) (-15 -4280 ((-541) |#1|)) (-15 -2083 (|#1| |#1|)) (-15 -3254 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2394 ((-409 (-568)) |#1|)) (-15 -1338 ((-121) |#1|)) (-15 -2811 (|#2| |#1|)) (-15 -4417 (|#2| |#1|)) (-15 -2387 (|#1| |#1|)) (-15 -2797 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2857 (|#2| |#1|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2857 ((-568) |#1|)) (-15 -2747 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -2747 (|#1| (-568))) (-15 -3425 ((-763))) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 -1775 (|#1| |#1| |#1|)) (-15 -1775 (|#1| |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 -1819 ((-121) |#1|)) (-15 * (|#1| (-917) |#1|)) (-15 -1769 (|#1| |#1| |#1|)) (-15 -2747 ((-850) |#1|)) (-15 -1719 ((-121) |#1| |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-3986 (((-763)) 51 (|has| |#1| (-370)))) (-4490 (($) 16 T CONST)) (-3668 (((-3 (-568) "failed") $) 92 (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) 90 (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 88)) (-2857 (((-568) $) 93 (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) 91 (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) 87)) (-2902 (((-3 $ "failed") $) 33)) (-3859 ((|#1| $) 77)) (-3254 (((-3 (-409 (-568)) "failed") $) 64 (|has| |#1| (-550)))) (-1338 (((-121) $) 66 (|has| |#1| (-550)))) (-2394 (((-409 (-568)) $) 65 (|has| |#1| (-550)))) (-1733 (($) 54 (|has| |#1| (-370)))) (-1598 (((-121) $) 30)) (-2557 (($ |#1| |#1| |#1| |#1| |#1| |#1| |#1| |#1|) 68)) (-4417 ((|#1| $) 69)) (-1732 (($ $ $) 60 (|has| |#1| (-842)))) (-2047 (($ $ $) 59 (|has| |#1| (-842)))) (-2797 (($ (-1 |#1| |#1|) $) 79)) (-2291 (((-917) $) 53 (|has| |#1| (-370)))) (-1893 (((-1143) $) 9)) (-2083 (($ $) 63 (|has| |#1| (-365)))) (-4357 (($ (-917)) 52 (|has| |#1| (-370)))) (-2592 ((|#1| $) 74)) (-2140 ((|#1| $) 75)) (-3195 ((|#1| $) 76)) (-4173 ((|#1| $) 70)) (-4287 ((|#1| $) 71)) (-4004 ((|#1| $) 72)) (-1767 ((|#1| $) 73)) (-4025 (((-1108) $) 10)) (-1339 (($ $ (-634 |#1|) (-634 |#1|)) 85 (|has| |#1| (-303 |#1|))) (($ $ |#1| |#1|) 84 (|has| |#1| (-303 |#1|))) (($ $ (-288 |#1|)) 83 (|has| |#1| (-303 |#1|))) (($ $ (-634 (-288 |#1|))) 82 (|has| |#1| (-303 |#1|))) (($ $ (-634 (-1161)) (-634 |#1|)) 81 (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-1161) |#1|) 80 (|has| |#1| (-523 (-1161) |#1|)))) (-2781 (($ $ |#1|) 86 (|has| |#1| (-281 |#1| |#1|)))) (-4280 (((-541) $) 61 (|has| |#1| (-609 (-541))))) (-2387 (($ $) 78)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 36) (($ (-409 (-568))) 89 (|has| |#1| (-1037 (-409 (-568)))))) (-3385 (((-3 $ "failed") $) 62 (|has| |#1| (-148)))) (-3425 (((-763)) 28)) (-2811 ((|#1| $) 67 (|has| |#1| (-1056)))) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1753 (((-121) $ $) 57 (|has| |#1| (-842)))) (-1740 (((-121) $ $) 56 (|has| |#1| (-842)))) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 58 (|has| |#1| (-842)))) (-1734 (((-121) $ $) 55 (|has| |#1| (-842)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37))) 
 (((-792 |#1|) (-1275) (-172)) (T -792)) 
-((-1458 (*1 *1 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) (-3857 (*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) (-4341 (*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) (-3915 (*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) (-3117 (*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) (-3817 (*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) (-4184 (*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) (-3312 (*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) (-1927 (*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) (-2657 (*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) (-3739 (*1 *1 *2 *2 *2 *2 *2 *2 *2 *2) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) (-2897 (*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)) (-4 *2 (-1056)))) (-2688 (*1 *2 *1) (-12 (-4 *1 (-792 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-121)))) (-2425 (*1 *2 *1) (-12 (-4 *1 (-792 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-409 (-568))))) (-1642 (*1 *2 *1) (|partial| -12 (-4 *1 (-792 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-409 (-568))))) (-2081 (*1 *1 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)) (-4 *2 (-365))))) 
-(-13 (-43 |t#1|) (-413 |t#1|) (-336 |t#1|) (-10 -8 (-15 -1458 ($ $)) (-15 -3857 (|t#1| $)) (-15 -4341 (|t#1| $)) (-15 -3915 (|t#1| $)) (-15 -3117 (|t#1| $)) (-15 -3817 (|t#1| $)) (-15 -4184 (|t#1| $)) (-15 -3312 (|t#1| $)) (-15 -1927 (|t#1| $)) (-15 -2657 (|t#1| $)) (-15 -3739 ($ |t#1| |t#1| |t#1| |t#1| |t#1| |t#1| |t#1| |t#1|)) (IF (|has| |t#1| (-370)) (-6 (-370)) |noBranch|) (IF (|has| |t#1| (-842)) (-6 (-842)) |noBranch|) (IF (|has| |t#1| (-609 (-541))) (-6 (-609 (-541))) |noBranch|) (IF (|has| |t#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |t#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |t#1| (-1056)) (-15 -2897 (|t#1| $)) |noBranch|) (IF (|has| |t#1| (-550)) (PROGN (-15 -2688 ((-121) $)) (-15 -2425 ((-409 (-568)) $)) (-15 -1642 ((-3 (-409 (-568)) "failed") $))) |noBranch|) (IF (|has| |t#1| (-365)) (-15 -2081 ($ $)) |noBranch|))) 
+((-2387 (*1 *1 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) (-3859 (*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) (-3195 (*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) (-2140 (*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) (-2592 (*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) (-1767 (*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) (-4004 (*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) (-4287 (*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) (-4173 (*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) (-4417 (*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) (-2557 (*1 *1 *2 *2 *2 *2 *2 *2 *2 *2) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) (-2811 (*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)) (-4 *2 (-1056)))) (-1338 (*1 *2 *1) (-12 (-4 *1 (-792 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-121)))) (-2394 (*1 *2 *1) (-12 (-4 *1 (-792 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-409 (-568))))) (-3254 (*1 *2 *1) (|partial| -12 (-4 *1 (-792 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-409 (-568))))) (-2083 (*1 *1 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)) (-4 *2 (-365))))) 
+(-13 (-43 |t#1|) (-413 |t#1|) (-336 |t#1|) (-10 -8 (-15 -2387 ($ $)) (-15 -3859 (|t#1| $)) (-15 -3195 (|t#1| $)) (-15 -2140 (|t#1| $)) (-15 -2592 (|t#1| $)) (-15 -1767 (|t#1| $)) (-15 -4004 (|t#1| $)) (-15 -4287 (|t#1| $)) (-15 -4173 (|t#1| $)) (-15 -4417 (|t#1| $)) (-15 -2557 ($ |t#1| |t#1| |t#1| |t#1| |t#1| |t#1| |t#1| |t#1|)) (IF (|has| |t#1| (-370)) (-6 (-370)) |noBranch|) (IF (|has| |t#1| (-842)) (-6 (-842)) |noBranch|) (IF (|has| |t#1| (-609 (-541))) (-6 (-609 (-541))) |noBranch|) (IF (|has| |t#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |t#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |t#1| (-1056)) (-15 -2811 (|t#1| $)) |noBranch|) (IF (|has| |t#1| (-550)) (PROGN (-15 -1338 ((-121) $)) (-15 -2394 ((-409 (-568)) $)) (-15 -3254 ((-3 (-409 (-568)) "failed") $))) |noBranch|) (IF (|has| |t#1| (-365)) (-15 -2083 ($ $)) |noBranch|))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#1|) . T) ((-105) . T) ((-120 |#1| |#1|) . T) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-281 |#1| $) |has| |#1| (-281 |#1| |#1|)) ((-303 |#1|) |has| |#1| (-303 |#1|)) ((-370) |has| |#1| (-370)) ((-336 |#1|) . T) ((-413 |#1|) . T) ((-523 (-1161) |#1|) |has| |#1| (-523 (-1161) |#1|)) ((-523 |#1| |#1|) |has| |#1| (-303 |#1|)) ((-637 |#1|) . T) ((-637 $) . T) ((-707 |#1|) . T) ((-716) . T) ((-842) |has| |#1| (-842)) ((-1037 (-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 |#1|) . T) ((-1053 |#1|) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-2795 ((|#3| (-1 |#4| |#2|) |#1|) 20))) 
-(((-793 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2795 (|#3| (-1 |#4| |#2|) |#1|))) (-792 |#2|) (-172) (-792 |#4|) (-172)) (T -793)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-172)) (-4 *6 (-172)) (-4 *2 (-792 *6)) (-5 *1 (-793 *4 *5 *2 *6)) (-4 *4 (-792 *5))))) 
-(-10 -7 (-15 -2795 (|#3| (-1 |#4| |#2|) |#1|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-3983 (((-763)) NIL (|has| |#1| (-370)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) NIL) (((-3 (-999 |#1|) "failed") $) 35) (((-3 (-568) "failed") $) NIL (-2198 (|has| (-999 |#1|) (-1037 (-568))) (|has| |#1| (-1037 (-568))))) (((-3 (-409 (-568)) "failed") $) NIL (-2198 (|has| (-999 |#1|) (-1037 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568))))))) (-2854 ((|#1| $) NIL) (((-999 |#1|) $) 33) (((-568) $) NIL (-2198 (|has| (-999 |#1|) (-1037 (-568))) (|has| |#1| (-1037 (-568))))) (((-409 (-568)) $) NIL (-2198 (|has| (-999 |#1|) (-1037 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568))))))) (-2925 (((-3 $ "failed") $) NIL)) (-3857 ((|#1| $) 16)) (-1642 (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-550)))) (-2688 (((-121) $) NIL (|has| |#1| (-550)))) (-2425 (((-409 (-568)) $) NIL (|has| |#1| (-550)))) (-1731 (($) NIL (|has| |#1| (-370)))) (-2735 (((-121) $) NIL)) (-3739 (($ |#1| |#1| |#1| |#1| |#1| |#1| |#1| |#1|) 28) (($ (-999 |#1|) (-999 |#1|)) 29)) (-2657 ((|#1| $) NIL)) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-3683 (((-917) $) NIL (|has| |#1| (-370)))) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL (|has| |#1| (-365)))) (-4355 (($ (-917)) NIL (|has| |#1| (-370)))) (-3117 ((|#1| $) 22)) (-3915 ((|#1| $) 20)) (-4341 ((|#1| $) 18)) (-1927 ((|#1| $) 26)) (-3312 ((|#1| $) 25)) (-4184 ((|#1| $) 24)) (-3817 ((|#1| $) 23)) (-4022 (((-1108) $) NIL)) (-1339 (($ $ (-634 |#1|) (-634 |#1|)) NIL (|has| |#1| (-303 |#1|))) (($ $ |#1| |#1|) NIL (|has| |#1| (-303 |#1|))) (($ $ (-288 |#1|)) NIL (|has| |#1| (-303 |#1|))) (($ $ (-634 (-288 |#1|))) NIL (|has| |#1| (-303 |#1|))) (($ $ (-634 (-1161)) (-634 |#1|)) NIL (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-1161) |#1|) NIL (|has| |#1| (-523 (-1161) |#1|)))) (-2779 (($ $ |#1|) NIL (|has| |#1| (-281 |#1| |#1|)))) (-4278 (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-1458 (($ $) NIL)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL) (($ (-999 |#1|)) 30) (($ (-409 (-568))) NIL (-2198 (|has| (-999 |#1|) (-1037 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568))))))) (-4371 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-4078 (((-763)) NIL)) (-2897 ((|#1| $) NIL (|has| |#1| (-1056)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 8 T CONST)) (-1556 (($) 12 T CONST)) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 40) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
-(((-794 |#1|) (-13 (-792 |#1|) (-413 (-999 |#1|)) (-10 -8 (-15 -3739 ($ (-999 |#1|) (-999 |#1|))))) (-172)) (T -794)) 
-((-3739 (*1 *1 *2 *2) (-12 (-5 *2 (-999 *3)) (-4 *3 (-172)) (-5 *1 (-794 *3))))) 
-(-13 (-792 |#1|) (-413 (-999 |#1|)) (-10 -8 (-15 -3739 ($ (-999 |#1|) (-999 |#1|))))) 
-((-2447 (((-121) $ $) 7)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 13)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-4110 (((-1035) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 12)) (-1717 (((-121) $ $) 6))) 
+((-2797 ((|#3| (-1 |#4| |#2|) |#1|) 20))) 
+(((-793 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2797 (|#3| (-1 |#4| |#2|) |#1|))) (-792 |#2|) (-172) (-792 |#4|) (-172)) (T -793)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-172)) (-4 *6 (-172)) (-4 *2 (-792 *6)) (-5 *1 (-793 *4 *5 *2 *6)) (-4 *4 (-792 *5))))) 
+(-10 -7 (-15 -2797 (|#3| (-1 |#4| |#2|) |#1|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3986 (((-763)) NIL (|has| |#1| (-370)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) NIL) (((-3 (-999 |#1|) "failed") $) 35) (((-3 (-568) "failed") $) NIL (-2199 (|has| (-999 |#1|) (-1037 (-568))) (|has| |#1| (-1037 (-568))))) (((-3 (-409 (-568)) "failed") $) NIL (-2199 (|has| (-999 |#1|) (-1037 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568))))))) (-2857 ((|#1| $) NIL) (((-999 |#1|) $) 33) (((-568) $) NIL (-2199 (|has| (-999 |#1|) (-1037 (-568))) (|has| |#1| (-1037 (-568))))) (((-409 (-568)) $) NIL (-2199 (|has| (-999 |#1|) (-1037 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568))))))) (-2902 (((-3 $ "failed") $) NIL)) (-3859 ((|#1| $) 16)) (-3254 (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-550)))) (-1338 (((-121) $) NIL (|has| |#1| (-550)))) (-2394 (((-409 (-568)) $) NIL (|has| |#1| (-550)))) (-1733 (($) NIL (|has| |#1| (-370)))) (-1598 (((-121) $) NIL)) (-2557 (($ |#1| |#1| |#1| |#1| |#1| |#1| |#1| |#1|) 28) (($ (-999 |#1|) (-999 |#1|)) 29)) (-4417 ((|#1| $) NIL)) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-2291 (((-917) $) NIL (|has| |#1| (-370)))) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL (|has| |#1| (-365)))) (-4357 (($ (-917)) NIL (|has| |#1| (-370)))) (-2592 ((|#1| $) 22)) (-2140 ((|#1| $) 20)) (-3195 ((|#1| $) 18)) (-4173 ((|#1| $) 26)) (-4287 ((|#1| $) 25)) (-4004 ((|#1| $) 24)) (-1767 ((|#1| $) 23)) (-4025 (((-1108) $) NIL)) (-1339 (($ $ (-634 |#1|) (-634 |#1|)) NIL (|has| |#1| (-303 |#1|))) (($ $ |#1| |#1|) NIL (|has| |#1| (-303 |#1|))) (($ $ (-288 |#1|)) NIL (|has| |#1| (-303 |#1|))) (($ $ (-634 (-288 |#1|))) NIL (|has| |#1| (-303 |#1|))) (($ $ (-634 (-1161)) (-634 |#1|)) NIL (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-1161) |#1|) NIL (|has| |#1| (-523 (-1161) |#1|)))) (-2781 (($ $ |#1|) NIL (|has| |#1| (-281 |#1| |#1|)))) (-4280 (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-2387 (($ $) NIL)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL) (($ (-999 |#1|)) 30) (($ (-409 (-568))) NIL (-2199 (|has| (-999 |#1|) (-1037 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568))))))) (-3385 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-3425 (((-763)) NIL)) (-2811 ((|#1| $) NIL (|has| |#1| (-1056)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 8 T CONST)) (-1557 (($) 12 T CONST)) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 40) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
+(((-794 |#1|) (-13 (-792 |#1|) (-413 (-999 |#1|)) (-10 -8 (-15 -2557 ($ (-999 |#1|) (-999 |#1|))))) (-172)) (T -794)) 
+((-2557 (*1 *1 *2 *2) (-12 (-5 *2 (-999 *3)) (-4 *3 (-172)) (-5 *1 (-794 *3))))) 
+(-13 (-792 |#1|) (-413 (-999 |#1|)) (-10 -8 (-15 -2557 ($ (-999 |#1|) (-999 |#1|))))) 
+((-2449 (((-121) $ $) 7)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 13)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-3602 (((-1035) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 12)) (-1719 (((-121) $ $) 6))) 
 (((-795) (-1275)) (T -795)) 
-((-3029 (*1 *2 *3 *4) (-12 (-4 *1 (-795)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)))))) (-4110 (*1 *2 *3) (-12 (-4 *1 (-795)) (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-1035))))) 
-(-13 (-1090) (-10 -7 (-15 -3029 ((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -4110 ((-1035) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))))) 
+((-3031 (*1 *2 *3 *4) (-12 (-4 *1 (-795)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)))))) (-3602 (*1 *2 *3) (-12 (-4 *1 (-795)) (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-1035))))) 
+(-13 (-1090) (-10 -7 (-15 -3031 ((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -3602 ((-1035) (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-4146 (((-2 (|:| |particular| |#2|) (|:| -3746 (-634 |#2|))) |#3| |#2| (-1161)) 19))) 
-(((-796 |#1| |#2| |#3|) (-10 -7 (-15 -4146 ((-2 (|:| |particular| |#2|) (|:| -3746 (-634 |#2|))) |#3| |#2| (-1161)))) (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150)) (-13 (-29 |#1|) (-1181) (-959)) (-646 |#2|)) (T -796)) 
-((-4146 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-1161)) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-4 *4 (-13 (-29 *6) (-1181) (-959))) (-5 *2 (-2 (|:| |particular| *4) (|:| -3746 (-634 *4)))) (-5 *1 (-796 *6 *4 *3)) (-4 *3 (-646 *4))))) 
-(-10 -7 (-15 -4146 ((-2 (|:| |particular| |#2|) (|:| -3746 (-634 |#2|))) |#3| |#2| (-1161)))) 
-((-4351 (((-3 |#2| "failed") |#2| (-123) (-288 |#2|) (-634 |#2|)) 26) (((-3 |#2| "failed") (-288 |#2|) (-123) (-288 |#2|) (-634 |#2|)) 27) (((-3 (-2 (|:| |particular| |#2|) (|:| -3746 (-634 |#2|))) |#2| "failed") |#2| (-123) (-1161)) 16) (((-3 (-2 (|:| |particular| |#2|) (|:| -3746 (-634 |#2|))) |#2| "failed") (-288 |#2|) (-123) (-1161)) 17) (((-3 (-2 (|:| |particular| (-1244 |#2|)) (|:| -3746 (-634 (-1244 |#2|)))) "failed") (-634 |#2|) (-634 (-123)) (-1161)) 22) (((-3 (-2 (|:| |particular| (-1244 |#2|)) (|:| -3746 (-634 (-1244 |#2|)))) "failed") (-634 (-288 |#2|)) (-634 (-123)) (-1161)) 24) (((-3 (-634 (-1244 |#2|)) "failed") (-679 |#2|) (-1161)) 36) (((-3 (-2 (|:| |particular| (-1244 |#2|)) (|:| -3746 (-634 (-1244 |#2|)))) "failed") (-679 |#2|) (-1244 |#2|) (-1161)) 34))) 
-(((-797 |#1| |#2|) (-10 -7 (-15 -4351 ((-3 (-2 (|:| |particular| (-1244 |#2|)) (|:| -3746 (-634 (-1244 |#2|)))) "failed") (-679 |#2|) (-1244 |#2|) (-1161))) (-15 -4351 ((-3 (-634 (-1244 |#2|)) "failed") (-679 |#2|) (-1161))) (-15 -4351 ((-3 (-2 (|:| |particular| (-1244 |#2|)) (|:| -3746 (-634 (-1244 |#2|)))) "failed") (-634 (-288 |#2|)) (-634 (-123)) (-1161))) (-15 -4351 ((-3 (-2 (|:| |particular| (-1244 |#2|)) (|:| -3746 (-634 (-1244 |#2|)))) "failed") (-634 |#2|) (-634 (-123)) (-1161))) (-15 -4351 ((-3 (-2 (|:| |particular| |#2|) (|:| -3746 (-634 |#2|))) |#2| "failed") (-288 |#2|) (-123) (-1161))) (-15 -4351 ((-3 (-2 (|:| |particular| |#2|) (|:| -3746 (-634 |#2|))) |#2| "failed") |#2| (-123) (-1161))) (-15 -4351 ((-3 |#2| "failed") (-288 |#2|) (-123) (-288 |#2|) (-634 |#2|))) (-15 -4351 ((-3 |#2| "failed") |#2| (-123) (-288 |#2|) (-634 |#2|)))) (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150)) (-13 (-29 |#1|) (-1181) (-959))) (T -797)) 
-((-4351 (*1 *2 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-288 *2)) (-5 *5 (-634 *2)) (-4 *2 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *1 (-797 *6 *2)))) (-4351 (*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *3 (-288 *2)) (-5 *4 (-123)) (-5 *5 (-634 *2)) (-4 *2 (-13 (-29 *6) (-1181) (-959))) (-5 *1 (-797 *6 *2)) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))))) (-4351 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-123)) (-5 *5 (-1161)) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-3 (-2 (|:| |particular| *3) (|:| -3746 (-634 *3))) *3 "failed")) (-5 *1 (-797 *6 *3)) (-4 *3 (-13 (-29 *6) (-1181) (-959))))) (-4351 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-288 *7)) (-5 *4 (-123)) (-5 *5 (-1161)) (-4 *7 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-3 (-2 (|:| |particular| *7) (|:| -3746 (-634 *7))) *7 "failed")) (-5 *1 (-797 *6 *7)))) (-4351 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-634 *7)) (-5 *4 (-634 (-123))) (-5 *5 (-1161)) (-4 *7 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-2 (|:| |particular| (-1244 *7)) (|:| -3746 (-634 (-1244 *7))))) (-5 *1 (-797 *6 *7)))) (-4351 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-634 (-288 *7))) (-5 *4 (-634 (-123))) (-5 *5 (-1161)) (-4 *7 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-2 (|:| |particular| (-1244 *7)) (|:| -3746 (-634 (-1244 *7))))) (-5 *1 (-797 *6 *7)))) (-4351 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-679 *6)) (-5 *4 (-1161)) (-4 *6 (-13 (-29 *5) (-1181) (-959))) (-4 *5 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-1244 *6))) (-5 *1 (-797 *5 *6)))) (-4351 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-679 *7)) (-5 *5 (-1161)) (-4 *7 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-2 (|:| |particular| (-1244 *7)) (|:| -3746 (-634 (-1244 *7))))) (-5 *1 (-797 *6 *7)) (-5 *4 (-1244 *7))))) 
-(-10 -7 (-15 -4351 ((-3 (-2 (|:| |particular| (-1244 |#2|)) (|:| -3746 (-634 (-1244 |#2|)))) "failed") (-679 |#2|) (-1244 |#2|) (-1161))) (-15 -4351 ((-3 (-634 (-1244 |#2|)) "failed") (-679 |#2|) (-1161))) (-15 -4351 ((-3 (-2 (|:| |particular| (-1244 |#2|)) (|:| -3746 (-634 (-1244 |#2|)))) "failed") (-634 (-288 |#2|)) (-634 (-123)) (-1161))) (-15 -4351 ((-3 (-2 (|:| |particular| (-1244 |#2|)) (|:| -3746 (-634 (-1244 |#2|)))) "failed") (-634 |#2|) (-634 (-123)) (-1161))) (-15 -4351 ((-3 (-2 (|:| |particular| |#2|) (|:| -3746 (-634 |#2|))) |#2| "failed") (-288 |#2|) (-123) (-1161))) (-15 -4351 ((-3 (-2 (|:| |particular| |#2|) (|:| -3746 (-634 |#2|))) |#2| "failed") |#2| (-123) (-1161))) (-15 -4351 ((-3 |#2| "failed") (-288 |#2|) (-123) (-288 |#2|) (-634 |#2|))) (-15 -4351 ((-3 |#2| "failed") |#2| (-123) (-288 |#2|) (-634 |#2|)))) 
-((-2641 (($) 9)) (-2727 (((-3 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381))) "failed") (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 26)) (-1946 (((-634 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) $) 23)) (-4450 (($ (-2 (|:| -3649 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381)))))) 20)) (-4176 (($ (-634 (-2 (|:| -3649 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381))))))) 18)) (-2327 (((-1249)) 12))) 
-(((-798) (-10 -8 (-15 -2641 ($)) (-15 -2327 ((-1249))) (-15 -1946 ((-634 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) $)) (-15 -4176 ($ (-634 (-2 (|:| -3649 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381)))))))) (-15 -4450 ($ (-2 (|:| -3649 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381))))))) (-15 -2727 ((-3 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381))) "failed") (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))))) (T -798)) 
-((-2727 (*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381)))) (-5 *1 (-798)))) (-4450 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| -3649 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381)))))) (-5 *1 (-798)))) (-4176 (*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3649 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381))))))) (-5 *1 (-798)))) (-1946 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-5 *1 (-798)))) (-2327 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-798)))) (-2641 (*1 *1) (-5 *1 (-798)))) 
-(-10 -8 (-15 -2641 ($)) (-15 -2327 ((-1249))) (-15 -1946 ((-634 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) $)) (-15 -4176 ($ (-634 (-2 (|:| -3649 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381)))))))) (-15 -4450 ($ (-2 (|:| -3649 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381))))))) (-15 -2727 ((-3 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381))) "failed") (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))))) 
-((-2178 ((|#2| |#2| (-1161)) 15)) (-2675 ((|#2| |#2| (-1161)) 47)) (-2060 (((-1 |#2| |#2|) (-1161)) 11))) 
-(((-799 |#1| |#2|) (-10 -7 (-15 -2178 (|#2| |#2| (-1161))) (-15 -2675 (|#2| |#2| (-1161))) (-15 -2060 ((-1 |#2| |#2|) (-1161)))) (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150)) (-13 (-29 |#1|) (-1181) (-959))) (T -799)) 
-((-2060 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-1 *5 *5)) (-5 *1 (-799 *4 *5)) (-4 *5 (-13 (-29 *4) (-1181) (-959))))) (-2675 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *1 (-799 *4 *2)) (-4 *2 (-13 (-29 *4) (-1181) (-959))))) (-2178 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *1 (-799 *4 *2)) (-4 *2 (-13 (-29 *4) (-1181) (-959)))))) 
-(-10 -7 (-15 -2178 (|#2| |#2| (-1161))) (-15 -2675 (|#2| |#2| (-1161))) (-15 -2060 ((-1 |#2| |#2|) (-1161)))) 
-((-4351 (((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-310 (-381)) (-634 (-381)) (-381) (-381)) 114) (((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-310 (-381)) (-634 (-381)) (-381)) 115) (((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-634 (-381)) (-381)) 117) (((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-310 (-381)) (-381)) 118) (((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-381)) 119) (((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381))) 120) (((-1035) (-803) (-1059)) 105) (((-1035) (-803)) 106)) (-3029 (((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143)))) (-803) (-1059)) 71) (((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143)))) (-803)) 73))) 
-(((-800) (-10 -7 (-15 -4351 ((-1035) (-803))) (-15 -4351 ((-1035) (-803) (-1059))) (-15 -4351 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)))) (-15 -4351 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-381))) (-15 -4351 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-310 (-381)) (-381))) (-15 -4351 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-634 (-381)) (-381))) (-15 -4351 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-310 (-381)) (-634 (-381)) (-381))) (-15 -4351 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-310 (-381)) (-634 (-381)) (-381) (-381))) (-15 -3029 ((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143)))) (-803))) (-15 -3029 ((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143)))) (-803) (-1059))))) (T -800)) 
-((-3029 (*1 *2 *3 *4) (-12 (-5 *3 (-803)) (-5 *4 (-1059)) (-5 *2 (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-800)))) (-3029 (*1 *2 *3) (-12 (-5 *3 (-803)) (-5 *2 (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-800)))) (-4351 (*1 *2 *3 *4 *4 *5 *6 *5 *4 *4) (-12 (-5 *3 (-1244 (-310 *4))) (-5 *5 (-634 (-381))) (-5 *6 (-310 (-381))) (-5 *4 (-381)) (-5 *2 (-1035)) (-5 *1 (-800)))) (-4351 (*1 *2 *3 *4 *4 *5 *6 *5 *4) (-12 (-5 *3 (-1244 (-310 *4))) (-5 *5 (-634 (-381))) (-5 *6 (-310 (-381))) (-5 *4 (-381)) (-5 *2 (-1035)) (-5 *1 (-800)))) (-4351 (*1 *2 *3 *4 *4 *5 *5 *4) (-12 (-5 *3 (-1244 (-310 (-381)))) (-5 *4 (-381)) (-5 *5 (-634 *4)) (-5 *2 (-1035)) (-5 *1 (-800)))) (-4351 (*1 *2 *3 *4 *4 *5 *6 *4) (-12 (-5 *3 (-1244 (-310 *4))) (-5 *5 (-634 (-381))) (-5 *6 (-310 (-381))) (-5 *4 (-381)) (-5 *2 (-1035)) (-5 *1 (-800)))) (-4351 (*1 *2 *3 *4 *4 *5 *4) (-12 (-5 *3 (-1244 (-310 (-381)))) (-5 *4 (-381)) (-5 *5 (-634 *4)) (-5 *2 (-1035)) (-5 *1 (-800)))) (-4351 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1244 (-310 (-381)))) (-5 *4 (-381)) (-5 *5 (-634 *4)) (-5 *2 (-1035)) (-5 *1 (-800)))) (-4351 (*1 *2 *3 *4) (-12 (-5 *3 (-803)) (-5 *4 (-1059)) (-5 *2 (-1035)) (-5 *1 (-800)))) (-4351 (*1 *2 *3) (-12 (-5 *3 (-803)) (-5 *2 (-1035)) (-5 *1 (-800))))) 
-(-10 -7 (-15 -4351 ((-1035) (-803))) (-15 -4351 ((-1035) (-803) (-1059))) (-15 -4351 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)))) (-15 -4351 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-381))) (-15 -4351 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-310 (-381)) (-381))) (-15 -4351 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-634 (-381)) (-381))) (-15 -4351 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-310 (-381)) (-634 (-381)) (-381))) (-15 -4351 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-310 (-381)) (-634 (-381)) (-381) (-381))) (-15 -3029 ((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143)))) (-803))) (-15 -3029 ((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143)))) (-803) (-1059)))) 
-((-1349 (((-2 (|:| |particular| (-3 |#4| "failed")) (|:| -3746 (-634 |#4|))) (-643 |#4|) |#4|) 32))) 
-(((-801 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1349 ((-2 (|:| |particular| (-3 |#4| "failed")) (|:| -3746 (-634 |#4|))) (-643 |#4|) |#4|))) (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568)))) (-1219 |#1|) (-1219 (-409 |#2|)) (-340 |#1| |#2| |#3|)) (T -801)) 
-((-1349 (*1 *2 *3 *4) (-12 (-5 *3 (-643 *4)) (-4 *4 (-340 *5 *6 *7)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -3746 (-634 *4)))) (-5 *1 (-801 *5 *6 *7 *4))))) 
-(-10 -7 (-15 -1349 ((-2 (|:| |particular| (-3 |#4| "failed")) (|:| -3746 (-634 |#4|))) (-643 |#4|) |#4|))) 
-((-4114 (((-2 (|:| -1853 |#3|) (|:| |rh| (-634 (-409 |#2|)))) |#4| (-634 (-409 |#2|))) 51)) (-4157 (((-634 (-2 (|:| -1374 |#2|) (|:| -2783 |#2|))) |#4| |#2|) 59) (((-634 (-2 (|:| -1374 |#2|) (|:| -2783 |#2|))) |#4|) 58) (((-634 (-2 (|:| -1374 |#2|) (|:| -2783 |#2|))) |#3| |#2|) 20) (((-634 (-2 (|:| -1374 |#2|) (|:| -2783 |#2|))) |#3|) 21)) (-2969 ((|#2| |#4| |#1|) 60) ((|#2| |#3| |#1|) 27)) (-2522 ((|#2| |#3| (-634 (-409 |#2|))) 93) (((-3 |#2| "failed") |#3| (-409 |#2|)) 90))) 
-(((-802 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2522 ((-3 |#2| "failed") |#3| (-409 |#2|))) (-15 -2522 (|#2| |#3| (-634 (-409 |#2|)))) (-15 -4157 ((-634 (-2 (|:| -1374 |#2|) (|:| -2783 |#2|))) |#3|)) (-15 -4157 ((-634 (-2 (|:| -1374 |#2|) (|:| -2783 |#2|))) |#3| |#2|)) (-15 -2969 (|#2| |#3| |#1|)) (-15 -4157 ((-634 (-2 (|:| -1374 |#2|) (|:| -2783 |#2|))) |#4|)) (-15 -4157 ((-634 (-2 (|:| -1374 |#2|) (|:| -2783 |#2|))) |#4| |#2|)) (-15 -2969 (|#2| |#4| |#1|)) (-15 -4114 ((-2 (|:| -1853 |#3|) (|:| |rh| (-634 (-409 |#2|)))) |#4| (-634 (-409 |#2|))))) (-13 (-365) (-150) (-1037 (-409 (-568)))) (-1219 |#1|) (-646 |#2|) (-646 (-409 |#2|))) (T -802)) 
-((-4114 (*1 *2 *3 *4) (-12 (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-2 (|:| -1853 *7) (|:| |rh| (-634 (-409 *6))))) (-5 *1 (-802 *5 *6 *7 *3)) (-5 *4 (-634 (-409 *6))) (-4 *7 (-646 *6)) (-4 *3 (-646 (-409 *6))))) (-2969 (*1 *2 *3 *4) (-12 (-4 *2 (-1219 *4)) (-5 *1 (-802 *4 *2 *5 *3)) (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *5 (-646 *2)) (-4 *3 (-646 (-409 *2))))) (-4157 (*1 *2 *3 *4) (-12 (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *4 (-1219 *5)) (-5 *2 (-634 (-2 (|:| -1374 *4) (|:| -2783 *4)))) (-5 *1 (-802 *5 *4 *6 *3)) (-4 *6 (-646 *4)) (-4 *3 (-646 (-409 *4))))) (-4157 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-2 (|:| -1374 *5) (|:| -2783 *5)))) (-5 *1 (-802 *4 *5 *6 *3)) (-4 *6 (-646 *5)) (-4 *3 (-646 (-409 *5))))) (-2969 (*1 *2 *3 *4) (-12 (-4 *2 (-1219 *4)) (-5 *1 (-802 *4 *2 *3 *5)) (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *3 (-646 *2)) (-4 *5 (-646 (-409 *2))))) (-4157 (*1 *2 *3 *4) (-12 (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *4 (-1219 *5)) (-5 *2 (-634 (-2 (|:| -1374 *4) (|:| -2783 *4)))) (-5 *1 (-802 *5 *4 *3 *6)) (-4 *3 (-646 *4)) (-4 *6 (-646 (-409 *4))))) (-4157 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-2 (|:| -1374 *5) (|:| -2783 *5)))) (-5 *1 (-802 *4 *5 *3 *6)) (-4 *3 (-646 *5)) (-4 *6 (-646 (-409 *5))))) (-2522 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-409 *2))) (-4 *2 (-1219 *5)) (-5 *1 (-802 *5 *2 *3 *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *3 (-646 *2)) (-4 *6 (-646 (-409 *2))))) (-2522 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-409 *2)) (-4 *2 (-1219 *5)) (-5 *1 (-802 *5 *2 *3 *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *3 (-646 *2)) (-4 *6 (-646 *4))))) 
-(-10 -7 (-15 -2522 ((-3 |#2| "failed") |#3| (-409 |#2|))) (-15 -2522 (|#2| |#3| (-634 (-409 |#2|)))) (-15 -4157 ((-634 (-2 (|:| -1374 |#2|) (|:| -2783 |#2|))) |#3|)) (-15 -4157 ((-634 (-2 (|:| -1374 |#2|) (|:| -2783 |#2|))) |#3| |#2|)) (-15 -2969 (|#2| |#3| |#1|)) (-15 -4157 ((-634 (-2 (|:| -1374 |#2|) (|:| -2783 |#2|))) |#4|)) (-15 -4157 ((-634 (-2 (|:| -1374 |#2|) (|:| -2783 |#2|))) |#4| |#2|)) (-15 -2969 (|#2| |#4| |#1|)) (-15 -4114 ((-2 (|:| -1853 |#3|) (|:| |rh| (-634 (-409 |#2|)))) |#4| (-634 (-409 |#2|))))) 
-((-2447 (((-121) $ $) NIL)) (-2854 (((-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) $) 9)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 11) (($ (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 8)) (-1717 (((-121) $ $) NIL))) 
-(((-803) (-13 (-1090) (-10 -8 (-15 -2745 ($ (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2745 ((-850) $)) (-15 -2854 ((-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) $))))) (T -803)) 
-((-2745 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-803)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *1 (-803)))) (-2854 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *1 (-803))))) 
-(-13 (-1090) (-10 -8 (-15 -2745 ($ (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2745 ((-850) $)) (-15 -2854 ((-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) $)))) 
-((-3757 (((-634 (-2 (|:| |frac| (-409 |#2|)) (|:| -1853 |#3|))) |#3| (-1 (-634 |#2|) |#2| (-1157 |#2|)) (-1 (-420 |#2|) |#2|)) 118)) (-4482 (((-634 (-2 (|:| |poly| |#2|) (|:| -1853 |#3|))) |#3| (-1 (-634 |#1|) |#2|)) 45)) (-3889 (((-634 (-2 (|:| |deg| (-763)) (|:| -1853 |#2|))) |#3|) 95)) (-3612 ((|#2| |#3|) 37)) (-1486 (((-634 (-2 (|:| -3495 |#1|) (|:| -1853 |#3|))) |#3| (-1 (-634 |#1|) |#2|)) 82)) (-4200 ((|#3| |#3| (-409 |#2|)) 63) ((|#3| |#3| |#2|) 79))) 
-(((-804 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3612 (|#2| |#3|)) (-15 -3889 ((-634 (-2 (|:| |deg| (-763)) (|:| -1853 |#2|))) |#3|)) (-15 -1486 ((-634 (-2 (|:| -3495 |#1|) (|:| -1853 |#3|))) |#3| (-1 (-634 |#1|) |#2|))) (-15 -4482 ((-634 (-2 (|:| |poly| |#2|) (|:| -1853 |#3|))) |#3| (-1 (-634 |#1|) |#2|))) (-15 -3757 ((-634 (-2 (|:| |frac| (-409 |#2|)) (|:| -1853 |#3|))) |#3| (-1 (-634 |#2|) |#2| (-1157 |#2|)) (-1 (-420 |#2|) |#2|))) (-15 -4200 (|#3| |#3| |#2|)) (-15 -4200 (|#3| |#3| (-409 |#2|)))) (-13 (-365) (-150) (-1037 (-409 (-568)))) (-1219 |#1|) (-646 |#2|) (-646 (-409 |#2|))) (T -804)) 
-((-4200 (*1 *2 *2 *3) (-12 (-5 *3 (-409 *5)) (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *1 (-804 *4 *5 *2 *6)) (-4 *2 (-646 *5)) (-4 *6 (-646 *3)))) (-4200 (*1 *2 *2 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *3 (-1219 *4)) (-5 *1 (-804 *4 *3 *2 *5)) (-4 *2 (-646 *3)) (-4 *5 (-646 (-409 *3))))) (-3757 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 (-634 *7) *7 (-1157 *7))) (-5 *5 (-1 (-420 *7) *7)) (-4 *7 (-1219 *6)) (-4 *6 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-5 *2 (-634 (-2 (|:| |frac| (-409 *7)) (|:| -1853 *3)))) (-5 *1 (-804 *6 *7 *3 *8)) (-4 *3 (-646 *7)) (-4 *8 (-646 (-409 *7))))) (-4482 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-2 (|:| |poly| *6) (|:| -1853 *3)))) (-5 *1 (-804 *5 *6 *3 *7)) (-4 *3 (-646 *6)) (-4 *7 (-646 (-409 *6))))) (-1486 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-2 (|:| -3495 *5) (|:| -1853 *3)))) (-5 *1 (-804 *5 *6 *3 *7)) (-4 *3 (-646 *6)) (-4 *7 (-646 (-409 *6))))) (-3889 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-2 (|:| |deg| (-763)) (|:| -1853 *5)))) (-5 *1 (-804 *4 *5 *3 *6)) (-4 *3 (-646 *5)) (-4 *6 (-646 (-409 *5))))) (-3612 (*1 *2 *3) (-12 (-4 *2 (-1219 *4)) (-5 *1 (-804 *4 *2 *3 *5)) (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *3 (-646 *2)) (-4 *5 (-646 (-409 *2)))))) 
-(-10 -7 (-15 -3612 (|#2| |#3|)) (-15 -3889 ((-634 (-2 (|:| |deg| (-763)) (|:| -1853 |#2|))) |#3|)) (-15 -1486 ((-634 (-2 (|:| -3495 |#1|) (|:| -1853 |#3|))) |#3| (-1 (-634 |#1|) |#2|))) (-15 -4482 ((-634 (-2 (|:| |poly| |#2|) (|:| -1853 |#3|))) |#3| (-1 (-634 |#1|) |#2|))) (-15 -3757 ((-634 (-2 (|:| |frac| (-409 |#2|)) (|:| -1853 |#3|))) |#3| (-1 (-634 |#2|) |#2| (-1157 |#2|)) (-1 (-420 |#2|) |#2|))) (-15 -4200 (|#3| |#3| |#2|)) (-15 -4200 (|#3| |#3| (-409 |#2|)))) 
-((-1590 (((-2 (|:| -3746 (-634 (-409 |#2|))) (|:| -2928 (-679 |#1|))) (-644 |#2| (-409 |#2|)) (-634 (-409 |#2|))) 117) (((-2 (|:| |particular| (-3 (-409 |#2|) "failed")) (|:| -3746 (-634 (-409 |#2|)))) (-644 |#2| (-409 |#2|)) (-409 |#2|)) 116) (((-2 (|:| -3746 (-634 (-409 |#2|))) (|:| -2928 (-679 |#1|))) (-643 (-409 |#2|)) (-634 (-409 |#2|))) 111) (((-2 (|:| |particular| (-3 (-409 |#2|) "failed")) (|:| -3746 (-634 (-409 |#2|)))) (-643 (-409 |#2|)) (-409 |#2|)) 109)) (-4338 ((|#2| (-644 |#2| (-409 |#2|))) 77) ((|#2| (-643 (-409 |#2|))) 81))) 
-(((-805 |#1| |#2|) (-10 -7 (-15 -1590 ((-2 (|:| |particular| (-3 (-409 |#2|) "failed")) (|:| -3746 (-634 (-409 |#2|)))) (-643 (-409 |#2|)) (-409 |#2|))) (-15 -1590 ((-2 (|:| -3746 (-634 (-409 |#2|))) (|:| -2928 (-679 |#1|))) (-643 (-409 |#2|)) (-634 (-409 |#2|)))) (-15 -1590 ((-2 (|:| |particular| (-3 (-409 |#2|) "failed")) (|:| -3746 (-634 (-409 |#2|)))) (-644 |#2| (-409 |#2|)) (-409 |#2|))) (-15 -1590 ((-2 (|:| -3746 (-634 (-409 |#2|))) (|:| -2928 (-679 |#1|))) (-644 |#2| (-409 |#2|)) (-634 (-409 |#2|)))) (-15 -4338 (|#2| (-643 (-409 |#2|)))) (-15 -4338 (|#2| (-644 |#2| (-409 |#2|))))) (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568)))) (-1219 |#1|)) (T -805)) 
-((-4338 (*1 *2 *3) (-12 (-5 *3 (-644 *2 (-409 *2))) (-4 *2 (-1219 *4)) (-5 *1 (-805 *4 *2)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))))) (-4338 (*1 *2 *3) (-12 (-5 *3 (-643 (-409 *2))) (-4 *2 (-1219 *4)) (-5 *1 (-805 *4 *2)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))))) (-1590 (*1 *2 *3 *4) (-12 (-5 *3 (-644 *6 (-409 *6))) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-2 (|:| -3746 (-634 (-409 *6))) (|:| -2928 (-679 *5)))) (-5 *1 (-805 *5 *6)) (-5 *4 (-634 (-409 *6))))) (-1590 (*1 *2 *3 *4) (-12 (-5 *3 (-644 *6 (-409 *6))) (-5 *4 (-409 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -3746 (-634 *4)))) (-5 *1 (-805 *5 *6)))) (-1590 (*1 *2 *3 *4) (-12 (-5 *3 (-643 (-409 *6))) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-2 (|:| -3746 (-634 (-409 *6))) (|:| -2928 (-679 *5)))) (-5 *1 (-805 *5 *6)) (-5 *4 (-634 (-409 *6))))) (-1590 (*1 *2 *3 *4) (-12 (-5 *3 (-643 (-409 *6))) (-5 *4 (-409 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -3746 (-634 *4)))) (-5 *1 (-805 *5 *6))))) 
-(-10 -7 (-15 -1590 ((-2 (|:| |particular| (-3 (-409 |#2|) "failed")) (|:| -3746 (-634 (-409 |#2|)))) (-643 (-409 |#2|)) (-409 |#2|))) (-15 -1590 ((-2 (|:| -3746 (-634 (-409 |#2|))) (|:| -2928 (-679 |#1|))) (-643 (-409 |#2|)) (-634 (-409 |#2|)))) (-15 -1590 ((-2 (|:| |particular| (-3 (-409 |#2|) "failed")) (|:| -3746 (-634 (-409 |#2|)))) (-644 |#2| (-409 |#2|)) (-409 |#2|))) (-15 -1590 ((-2 (|:| -3746 (-634 (-409 |#2|))) (|:| -2928 (-679 |#1|))) (-644 |#2| (-409 |#2|)) (-634 (-409 |#2|)))) (-15 -4338 (|#2| (-643 (-409 |#2|)))) (-15 -4338 (|#2| (-644 |#2| (-409 |#2|))))) 
-((-3421 (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#1|))) |#5| |#4|) 47))) 
-(((-806 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3421 ((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#1|))) |#5| |#4|))) (-365) (-646 |#1|) (-1219 |#1|) (-714 |#1| |#3|) (-646 |#4|)) (T -806)) 
-((-3421 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *7 (-1219 *5)) (-4 *4 (-714 *5 *7)) (-5 *2 (-2 (|:| -2928 (-679 *6)) (|:| |vec| (-1244 *5)))) (-5 *1 (-806 *5 *6 *7 *4 *3)) (-4 *6 (-646 *5)) (-4 *3 (-646 *4))))) 
-(-10 -7 (-15 -3421 ((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#1|))) |#5| |#4|))) 
-((-3757 (((-634 (-2 (|:| |frac| (-409 |#2|)) (|:| -1853 (-644 |#2| (-409 |#2|))))) (-644 |#2| (-409 |#2|)) (-1 (-420 |#2|) |#2|)) 43)) (-4412 (((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|)) (-1 (-420 |#2|) |#2|)) 133 (|has| |#1| (-27))) (((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|))) 134 (|has| |#1| (-27))) (((-634 (-409 |#2|)) (-643 (-409 |#2|)) (-1 (-420 |#2|) |#2|)) 135 (|has| |#1| (-27))) (((-634 (-409 |#2|)) (-643 (-409 |#2|))) 136 (|has| |#1| (-27))) (((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|)) (-1 (-634 |#1|) |#2|) (-1 (-420 |#2|) |#2|)) 36) (((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|)) (-1 (-634 |#1|) |#2|)) 37) (((-634 (-409 |#2|)) (-643 (-409 |#2|)) (-1 (-634 |#1|) |#2|) (-1 (-420 |#2|) |#2|)) 34) (((-634 (-409 |#2|)) (-643 (-409 |#2|)) (-1 (-634 |#1|) |#2|)) 35)) (-4482 (((-634 (-2 (|:| |poly| |#2|) (|:| -1853 (-644 |#2| (-409 |#2|))))) (-644 |#2| (-409 |#2|)) (-1 (-634 |#1|) |#2|)) 80))) 
-(((-807 |#1| |#2|) (-10 -7 (-15 -4412 ((-634 (-409 |#2|)) (-643 (-409 |#2|)) (-1 (-634 |#1|) |#2|))) (-15 -4412 ((-634 (-409 |#2|)) (-643 (-409 |#2|)) (-1 (-634 |#1|) |#2|) (-1 (-420 |#2|) |#2|))) (-15 -4412 ((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|)) (-1 (-634 |#1|) |#2|))) (-15 -4412 ((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|)) (-1 (-634 |#1|) |#2|) (-1 (-420 |#2|) |#2|))) (-15 -3757 ((-634 (-2 (|:| |frac| (-409 |#2|)) (|:| -1853 (-644 |#2| (-409 |#2|))))) (-644 |#2| (-409 |#2|)) (-1 (-420 |#2|) |#2|))) (-15 -4482 ((-634 (-2 (|:| |poly| |#2|) (|:| -1853 (-644 |#2| (-409 |#2|))))) (-644 |#2| (-409 |#2|)) (-1 (-634 |#1|) |#2|))) (IF (|has| |#1| (-27)) (PROGN (-15 -4412 ((-634 (-409 |#2|)) (-643 (-409 |#2|)))) (-15 -4412 ((-634 (-409 |#2|)) (-643 (-409 |#2|)) (-1 (-420 |#2|) |#2|))) (-15 -4412 ((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|)))) (-15 -4412 ((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|)) (-1 (-420 |#2|) |#2|)))) |noBranch|)) (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568)))) (-1219 |#1|)) (T -807)) 
-((-4412 (*1 *2 *3 *4) (-12 (-5 *3 (-644 *6 (-409 *6))) (-5 *4 (-1 (-420 *6) *6)) (-4 *6 (-1219 *5)) (-4 *5 (-27)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-634 (-409 *6))) (-5 *1 (-807 *5 *6)))) (-4412 (*1 *2 *3) (-12 (-5 *3 (-644 *5 (-409 *5))) (-4 *5 (-1219 *4)) (-4 *4 (-27)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-634 (-409 *5))) (-5 *1 (-807 *4 *5)))) (-4412 (*1 *2 *3 *4) (-12 (-5 *3 (-643 (-409 *6))) (-5 *4 (-1 (-420 *6) *6)) (-4 *6 (-1219 *5)) (-4 *5 (-27)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-634 (-409 *6))) (-5 *1 (-807 *5 *6)))) (-4412 (*1 *2 *3) (-12 (-5 *3 (-643 (-409 *5))) (-4 *5 (-1219 *4)) (-4 *4 (-27)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-634 (-409 *5))) (-5 *1 (-807 *4 *5)))) (-4482 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-2 (|:| |poly| *6) (|:| -1853 (-644 *6 (-409 *6)))))) (-5 *1 (-807 *5 *6)) (-5 *3 (-644 *6 (-409 *6))))) (-3757 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-420 *6) *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-634 (-2 (|:| |frac| (-409 *6)) (|:| -1853 (-644 *6 (-409 *6)))))) (-5 *1 (-807 *5 *6)) (-5 *3 (-644 *6 (-409 *6))))) (-4412 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-644 *7 (-409 *7))) (-5 *4 (-1 (-634 *6) *7)) (-5 *5 (-1 (-420 *7) *7)) (-4 *6 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *7 (-1219 *6)) (-5 *2 (-634 (-409 *7))) (-5 *1 (-807 *6 *7)))) (-4412 (*1 *2 *3 *4) (-12 (-5 *3 (-644 *6 (-409 *6))) (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-409 *6))) (-5 *1 (-807 *5 *6)))) (-4412 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-643 (-409 *7))) (-5 *4 (-1 (-634 *6) *7)) (-5 *5 (-1 (-420 *7) *7)) (-4 *6 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *7 (-1219 *6)) (-5 *2 (-634 (-409 *7))) (-5 *1 (-807 *6 *7)))) (-4412 (*1 *2 *3 *4) (-12 (-5 *3 (-643 (-409 *6))) (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-409 *6))) (-5 *1 (-807 *5 *6))))) 
-(-10 -7 (-15 -4412 ((-634 (-409 |#2|)) (-643 (-409 |#2|)) (-1 (-634 |#1|) |#2|))) (-15 -4412 ((-634 (-409 |#2|)) (-643 (-409 |#2|)) (-1 (-634 |#1|) |#2|) (-1 (-420 |#2|) |#2|))) (-15 -4412 ((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|)) (-1 (-634 |#1|) |#2|))) (-15 -4412 ((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|)) (-1 (-634 |#1|) |#2|) (-1 (-420 |#2|) |#2|))) (-15 -3757 ((-634 (-2 (|:| |frac| (-409 |#2|)) (|:| -1853 (-644 |#2| (-409 |#2|))))) (-644 |#2| (-409 |#2|)) (-1 (-420 |#2|) |#2|))) (-15 -4482 ((-634 (-2 (|:| |poly| |#2|) (|:| -1853 (-644 |#2| (-409 |#2|))))) (-644 |#2| (-409 |#2|)) (-1 (-634 |#1|) |#2|))) (IF (|has| |#1| (-27)) (PROGN (-15 -4412 ((-634 (-409 |#2|)) (-643 (-409 |#2|)))) (-15 -4412 ((-634 (-409 |#2|)) (-643 (-409 |#2|)) (-1 (-420 |#2|) |#2|))) (-15 -4412 ((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|)))) (-15 -4412 ((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|)) (-1 (-420 |#2|) |#2|)))) |noBranch|)) 
-((-3990 (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#1|))) (-679 |#2|) (-1244 |#1|)) 86) (((-2 (|:| A (-679 |#1|)) (|:| |eqs| (-634 (-2 (|:| C (-679 |#1|)) (|:| |g| (-1244 |#1|)) (|:| -1853 |#2|) (|:| |rh| |#1|))))) (-679 |#1|) (-1244 |#1|)) 14)) (-2578 (((-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -3746 (-634 (-1244 |#1|)))) (-679 |#2|) (-1244 |#1|) (-1 (-2 (|:| |particular| (-3 |#1| "failed")) (|:| -3746 (-634 |#1|))) |#2| |#1|)) 92)) (-4351 (((-3 (-2 (|:| |particular| (-1244 |#1|)) (|:| -3746 (-679 |#1|))) "failed") (-679 |#1|) (-1244 |#1|) (-1 (-3 (-2 (|:| |particular| |#1|) (|:| -3746 (-634 |#1|))) "failed") |#2| |#1|)) 45))) 
-(((-808 |#1| |#2|) (-10 -7 (-15 -3990 ((-2 (|:| A (-679 |#1|)) (|:| |eqs| (-634 (-2 (|:| C (-679 |#1|)) (|:| |g| (-1244 |#1|)) (|:| -1853 |#2|) (|:| |rh| |#1|))))) (-679 |#1|) (-1244 |#1|))) (-15 -3990 ((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#1|))) (-679 |#2|) (-1244 |#1|))) (-15 -4351 ((-3 (-2 (|:| |particular| (-1244 |#1|)) (|:| -3746 (-679 |#1|))) "failed") (-679 |#1|) (-1244 |#1|) (-1 (-3 (-2 (|:| |particular| |#1|) (|:| -3746 (-634 |#1|))) "failed") |#2| |#1|))) (-15 -2578 ((-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -3746 (-634 (-1244 |#1|)))) (-679 |#2|) (-1244 |#1|) (-1 (-2 (|:| |particular| (-3 |#1| "failed")) (|:| -3746 (-634 |#1|))) |#2| |#1|)))) (-365) (-646 |#1|)) (T -808)) 
-((-2578 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *7)) (-5 *5 (-1 (-2 (|:| |particular| (-3 *6 "failed")) (|:| -3746 (-634 *6))) *7 *6)) (-4 *6 (-365)) (-4 *7 (-646 *6)) (-5 *2 (-2 (|:| |particular| (-3 (-1244 *6) "failed")) (|:| -3746 (-634 (-1244 *6))))) (-5 *1 (-808 *6 *7)) (-5 *4 (-1244 *6)))) (-4351 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1 (-3 (-2 (|:| |particular| *6) (|:| -3746 (-634 *6))) "failed") *7 *6)) (-4 *6 (-365)) (-4 *7 (-646 *6)) (-5 *2 (-2 (|:| |particular| (-1244 *6)) (|:| -3746 (-679 *6)))) (-5 *1 (-808 *6 *7)) (-5 *3 (-679 *6)) (-5 *4 (-1244 *6)))) (-3990 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-646 *5)) (-5 *2 (-2 (|:| -2928 (-679 *6)) (|:| |vec| (-1244 *5)))) (-5 *1 (-808 *5 *6)) (-5 *3 (-679 *6)) (-5 *4 (-1244 *5)))) (-3990 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-5 *2 (-2 (|:| A (-679 *5)) (|:| |eqs| (-634 (-2 (|:| C (-679 *5)) (|:| |g| (-1244 *5)) (|:| -1853 *6) (|:| |rh| *5)))))) (-5 *1 (-808 *5 *6)) (-5 *3 (-679 *5)) (-5 *4 (-1244 *5)) (-4 *6 (-646 *5))))) 
-(-10 -7 (-15 -3990 ((-2 (|:| A (-679 |#1|)) (|:| |eqs| (-634 (-2 (|:| C (-679 |#1|)) (|:| |g| (-1244 |#1|)) (|:| -1853 |#2|) (|:| |rh| |#1|))))) (-679 |#1|) (-1244 |#1|))) (-15 -3990 ((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#1|))) (-679 |#2|) (-1244 |#1|))) (-15 -4351 ((-3 (-2 (|:| |particular| (-1244 |#1|)) (|:| -3746 (-679 |#1|))) "failed") (-679 |#1|) (-1244 |#1|) (-1 (-3 (-2 (|:| |particular| |#1|) (|:| -3746 (-634 |#1|))) "failed") |#2| |#1|))) (-15 -2578 ((-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -3746 (-634 (-1244 |#1|)))) (-679 |#2|) (-1244 |#1|) (-1 (-2 (|:| |particular| (-3 |#1| "failed")) (|:| -3746 (-634 |#1|))) |#2| |#1|)))) 
-((-3600 (((-679 |#1|) (-634 |#1|) (-763)) 13) (((-679 |#1|) (-634 |#1|)) 14)) (-2057 (((-3 (-1244 |#1|) "failed") |#2| |#1| (-634 |#1|)) 34)) (-4314 (((-3 |#1| "failed") |#2| |#1| (-634 |#1|) (-1 |#1| |#1|)) 42))) 
-(((-809 |#1| |#2|) (-10 -7 (-15 -3600 ((-679 |#1|) (-634 |#1|))) (-15 -3600 ((-679 |#1|) (-634 |#1|) (-763))) (-15 -2057 ((-3 (-1244 |#1|) "failed") |#2| |#1| (-634 |#1|))) (-15 -4314 ((-3 |#1| "failed") |#2| |#1| (-634 |#1|) (-1 |#1| |#1|)))) (-365) (-646 |#1|)) (T -809)) 
-((-4314 (*1 *2 *3 *2 *4 *5) (|partial| -12 (-5 *4 (-634 *2)) (-5 *5 (-1 *2 *2)) (-4 *2 (-365)) (-5 *1 (-809 *2 *3)) (-4 *3 (-646 *2)))) (-2057 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-634 *4)) (-4 *4 (-365)) (-5 *2 (-1244 *4)) (-5 *1 (-809 *4 *3)) (-4 *3 (-646 *4)))) (-3600 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-763)) (-4 *5 (-365)) (-5 *2 (-679 *5)) (-5 *1 (-809 *5 *6)) (-4 *6 (-646 *5)))) (-3600 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-5 *2 (-679 *4)) (-5 *1 (-809 *4 *5)) (-4 *5 (-646 *4))))) 
-(-10 -7 (-15 -3600 ((-679 |#1|) (-634 |#1|))) (-15 -3600 ((-679 |#1|) (-634 |#1|) (-763))) (-15 -2057 ((-3 (-1244 |#1|) "failed") |#2| |#1| (-634 |#1|))) (-15 -4314 ((-3 |#1| "failed") |#2| |#1| (-634 |#1|) (-1 |#1| |#1|)))) 
-((-2447 (((-121) $ $) NIL (|has| |#2| (-1090)))) (-2537 (((-121) $) NIL (|has| |#2| (-137)))) (-1394 (($ (-917)) NIL (|has| |#2| (-1047)))) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-1462 (($ $ $) NIL (|has| |#2| (-788)))) (-3134 (((-3 $ "failed") $ $) NIL (|has| |#2| (-137)))) (-2510 (((-121) $ (-763)) NIL)) (-3983 (((-763)) NIL (|has| |#2| (-370)))) (-3662 (((-568) $) NIL (|has| |#2| (-840)))) (-2436 ((|#2| $ (-568) |#2|) NIL (|has| $ (-6 -4520)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) NIL (-12 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090)))) (((-3 (-409 (-568)) "failed") $) NIL (-12 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) (((-3 |#2| "failed") $) NIL (|has| |#2| (-1090)))) (-2854 (((-568) $) NIL (-12 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090)))) (((-409 (-568)) $) NIL (-12 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) ((|#2| $) NIL (|has| |#2| (-1090)))) (-3164 (((-679 (-568)) (-679 $)) NIL (-12 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (-12 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047)))) (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL (|has| |#2| (-1047))) (((-679 |#2|) (-679 $)) NIL (|has| |#2| (-1047)))) (-2925 (((-3 $ "failed") $) NIL (|has| |#2| (-716)))) (-1731 (($) NIL (|has| |#2| (-370)))) (-3989 ((|#2| $ (-568) |#2|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#2| $ (-568)) NIL)) (-2033 (((-121) $) NIL (|has| |#2| (-840)))) (-4360 (((-634 |#2|) $) NIL (|has| $ (-6 -4519)))) (-2735 (((-121) $) NIL (|has| |#2| (-716)))) (-2245 (((-121) $) NIL (|has| |#2| (-840)))) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) NIL (|has| (-568) (-842)))) (-2521 (($ $ $) NIL (-2198 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1979 (((-634 |#2|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-2223 (((-568) $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (-2198 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-3674 (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#2| |#2|) $) NIL)) (-3683 (((-917) $) NIL (|has| |#2| (-370)))) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (|has| |#2| (-1090)))) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4355 (($ (-917)) NIL (|has| |#2| (-370)))) (-4022 (((-1108) $) NIL (|has| |#2| (-1090)))) (-3876 ((|#2| $) NIL (|has| (-568) (-842)))) (-3724 (($ $ |#2|) NIL (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-2041 (((-634 |#2|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#2| $ (-568) |#2|) NIL) ((|#2| $ (-568)) NIL)) (-3682 ((|#2| $ $) NIL (|has| |#2| (-1047)))) (-2039 (($ (-1244 |#2|)) NIL)) (-4321 (((-139)) NIL (|has| |#2| (-365)))) (-4189 (($ $) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1 |#2| |#2|) (-763)) NIL (|has| |#2| (-1047))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1047)))) (-4168 (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-3863 (($ $) NIL)) (-2745 (((-1244 |#2|) $) NIL) (((-850) $) NIL (|has| |#2| (-1090))) (($ (-568)) NIL (-2198 (-12 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090))) (|has| |#2| (-1047)))) (($ (-409 (-568))) NIL (-12 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) (($ |#2|) NIL (|has| |#2| (-1090)))) (-4078 (((-763)) NIL (|has| |#2| (-1047)))) (-1319 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-2897 (($ $) NIL (|has| |#2| (-840)))) (-1887 (($ $ (-763)) NIL (|has| |#2| (-716))) (($ $ (-917)) NIL (|has| |#2| (-716)))) (-3056 (($) NIL (|has| |#2| (-137)) CONST)) (-1556 (($) NIL (|has| |#2| (-716)) CONST)) (-3190 (($ $) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1 |#2| |#2|) (-763)) NIL (|has| |#2| (-1047))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1047)))) (-1751 (((-121) $ $) NIL (-2198 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1738 (((-121) $ $) NIL (-2198 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1717 (((-121) $ $) NIL (|has| |#2| (-1090)))) (-1745 (((-121) $ $) NIL (-2198 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1732 (((-121) $ $) 11 (-2198 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1779 (($ $ |#2|) NIL (|has| |#2| (-365)))) (-1773 (($ $ $) NIL (|has| |#2| (-1047))) (($ $) NIL (|has| |#2| (-1047)))) (-1767 (($ $ $) NIL (|has| |#2| (-25)))) (** (($ $ (-763)) NIL (|has| |#2| (-716))) (($ $ (-917)) NIL (|has| |#2| (-716)))) (* (($ (-568) $) NIL (|has| |#2| (-1047))) (($ $ $) NIL (|has| |#2| (-716))) (($ $ |#2|) NIL (|has| |#2| (-1047))) (($ |#2| $) NIL (|has| |#2| (-1047))) (($ (-763) $) NIL (|has| |#2| (-137))) (($ (-917) $) NIL (|has| |#2| (-25)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
+((-3795 (((-2 (|:| |particular| |#2|) (|:| -2588 (-634 |#2|))) |#3| |#2| (-1161)) 19))) 
+(((-796 |#1| |#2| |#3|) (-10 -7 (-15 -3795 ((-2 (|:| |particular| |#2|) (|:| -2588 (-634 |#2|))) |#3| |#2| (-1161)))) (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150)) (-13 (-29 |#1|) (-1181) (-959)) (-646 |#2|)) (T -796)) 
+((-3795 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-1161)) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-4 *4 (-13 (-29 *6) (-1181) (-959))) (-5 *2 (-2 (|:| |particular| *4) (|:| -2588 (-634 *4)))) (-5 *1 (-796 *6 *4 *3)) (-4 *3 (-646 *4))))) 
+(-10 -7 (-15 -3795 ((-2 (|:| |particular| |#2|) (|:| -2588 (-634 |#2|))) |#3| |#2| (-1161)))) 
+((-3259 (((-3 |#2| "failed") |#2| (-123) (-288 |#2|) (-634 |#2|)) 26) (((-3 |#2| "failed") (-288 |#2|) (-123) (-288 |#2|) (-634 |#2|)) 27) (((-3 (-2 (|:| |particular| |#2|) (|:| -2588 (-634 |#2|))) |#2| "failed") |#2| (-123) (-1161)) 16) (((-3 (-2 (|:| |particular| |#2|) (|:| -2588 (-634 |#2|))) |#2| "failed") (-288 |#2|) (-123) (-1161)) 17) (((-3 (-2 (|:| |particular| (-1244 |#2|)) (|:| -2588 (-634 (-1244 |#2|)))) "failed") (-634 |#2|) (-634 (-123)) (-1161)) 22) (((-3 (-2 (|:| |particular| (-1244 |#2|)) (|:| -2588 (-634 (-1244 |#2|)))) "failed") (-634 (-288 |#2|)) (-634 (-123)) (-1161)) 24) (((-3 (-634 (-1244 |#2|)) "failed") (-679 |#2|) (-1161)) 36) (((-3 (-2 (|:| |particular| (-1244 |#2|)) (|:| -2588 (-634 (-1244 |#2|)))) "failed") (-679 |#2|) (-1244 |#2|) (-1161)) 34))) 
+(((-797 |#1| |#2|) (-10 -7 (-15 -3259 ((-3 (-2 (|:| |particular| (-1244 |#2|)) (|:| -2588 (-634 (-1244 |#2|)))) "failed") (-679 |#2|) (-1244 |#2|) (-1161))) (-15 -3259 ((-3 (-634 (-1244 |#2|)) "failed") (-679 |#2|) (-1161))) (-15 -3259 ((-3 (-2 (|:| |particular| (-1244 |#2|)) (|:| -2588 (-634 (-1244 |#2|)))) "failed") (-634 (-288 |#2|)) (-634 (-123)) (-1161))) (-15 -3259 ((-3 (-2 (|:| |particular| (-1244 |#2|)) (|:| -2588 (-634 (-1244 |#2|)))) "failed") (-634 |#2|) (-634 (-123)) (-1161))) (-15 -3259 ((-3 (-2 (|:| |particular| |#2|) (|:| -2588 (-634 |#2|))) |#2| "failed") (-288 |#2|) (-123) (-1161))) (-15 -3259 ((-3 (-2 (|:| |particular| |#2|) (|:| -2588 (-634 |#2|))) |#2| "failed") |#2| (-123) (-1161))) (-15 -3259 ((-3 |#2| "failed") (-288 |#2|) (-123) (-288 |#2|) (-634 |#2|))) (-15 -3259 ((-3 |#2| "failed") |#2| (-123) (-288 |#2|) (-634 |#2|)))) (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150)) (-13 (-29 |#1|) (-1181) (-959))) (T -797)) 
+((-3259 (*1 *2 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-288 *2)) (-5 *5 (-634 *2)) (-4 *2 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *1 (-797 *6 *2)))) (-3259 (*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *3 (-288 *2)) (-5 *4 (-123)) (-5 *5 (-634 *2)) (-4 *2 (-13 (-29 *6) (-1181) (-959))) (-5 *1 (-797 *6 *2)) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))))) (-3259 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-123)) (-5 *5 (-1161)) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-3 (-2 (|:| |particular| *3) (|:| -2588 (-634 *3))) *3 "failed")) (-5 *1 (-797 *6 *3)) (-4 *3 (-13 (-29 *6) (-1181) (-959))))) (-3259 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-288 *7)) (-5 *4 (-123)) (-5 *5 (-1161)) (-4 *7 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-3 (-2 (|:| |particular| *7) (|:| -2588 (-634 *7))) *7 "failed")) (-5 *1 (-797 *6 *7)))) (-3259 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-634 *7)) (-5 *4 (-634 (-123))) (-5 *5 (-1161)) (-4 *7 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-2 (|:| |particular| (-1244 *7)) (|:| -2588 (-634 (-1244 *7))))) (-5 *1 (-797 *6 *7)))) (-3259 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-634 (-288 *7))) (-5 *4 (-634 (-123))) (-5 *5 (-1161)) (-4 *7 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-2 (|:| |particular| (-1244 *7)) (|:| -2588 (-634 (-1244 *7))))) (-5 *1 (-797 *6 *7)))) (-3259 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-679 *6)) (-5 *4 (-1161)) (-4 *6 (-13 (-29 *5) (-1181) (-959))) (-4 *5 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-1244 *6))) (-5 *1 (-797 *5 *6)))) (-3259 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-679 *7)) (-5 *5 (-1161)) (-4 *7 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-2 (|:| |particular| (-1244 *7)) (|:| -2588 (-634 (-1244 *7))))) (-5 *1 (-797 *6 *7)) (-5 *4 (-1244 *7))))) 
+(-10 -7 (-15 -3259 ((-3 (-2 (|:| |particular| (-1244 |#2|)) (|:| -2588 (-634 (-1244 |#2|)))) "failed") (-679 |#2|) (-1244 |#2|) (-1161))) (-15 -3259 ((-3 (-634 (-1244 |#2|)) "failed") (-679 |#2|) (-1161))) (-15 -3259 ((-3 (-2 (|:| |particular| (-1244 |#2|)) (|:| -2588 (-634 (-1244 |#2|)))) "failed") (-634 (-288 |#2|)) (-634 (-123)) (-1161))) (-15 -3259 ((-3 (-2 (|:| |particular| (-1244 |#2|)) (|:| -2588 (-634 (-1244 |#2|)))) "failed") (-634 |#2|) (-634 (-123)) (-1161))) (-15 -3259 ((-3 (-2 (|:| |particular| |#2|) (|:| -2588 (-634 |#2|))) |#2| "failed") (-288 |#2|) (-123) (-1161))) (-15 -3259 ((-3 (-2 (|:| |particular| |#2|) (|:| -2588 (-634 |#2|))) |#2| "failed") |#2| (-123) (-1161))) (-15 -3259 ((-3 |#2| "failed") (-288 |#2|) (-123) (-288 |#2|) (-634 |#2|))) (-15 -3259 ((-3 |#2| "failed") |#2| (-123) (-288 |#2|) (-634 |#2|)))) 
+((-4323 (($) 9)) (-1567 (((-3 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381))) "failed") (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 26)) (-4253 (((-634 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) $) 23)) (-1708 (($ (-2 (|:| -3651 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381)))))) 20)) (-3956 (($ (-634 (-2 (|:| -3651 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381))))))) 18)) (-3819 (((-1249)) 12))) 
+(((-798) (-10 -8 (-15 -4323 ($)) (-15 -3819 ((-1249))) (-15 -4253 ((-634 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) $)) (-15 -3956 ($ (-634 (-2 (|:| -3651 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381)))))))) (-15 -1708 ($ (-2 (|:| -3651 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381))))))) (-15 -1567 ((-3 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381))) "failed") (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))))) (T -798)) 
+((-1567 (*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381)))) (-5 *1 (-798)))) (-1708 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| -3651 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381)))))) (-5 *1 (-798)))) (-3956 (*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3651 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381))))))) (-5 *1 (-798)))) (-4253 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-5 *1 (-798)))) (-3819 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-798)))) (-4323 (*1 *1) (-5 *1 (-798)))) 
+(-10 -8 (-15 -4323 ($)) (-15 -3819 ((-1249))) (-15 -4253 ((-634 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) $)) (-15 -3956 ($ (-634 (-2 (|:| -3651 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381)))))))) (-15 -1708 ($ (-2 (|:| -3651 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381))))))) (-15 -1567 ((-3 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381))) "failed") (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))))) 
+((-2473 ((|#2| |#2| (-1161)) 15)) (-1280 ((|#2| |#2| (-1161)) 47)) (-1571 (((-1 |#2| |#2|) (-1161)) 11))) 
+(((-799 |#1| |#2|) (-10 -7 (-15 -2473 (|#2| |#2| (-1161))) (-15 -1280 (|#2| |#2| (-1161))) (-15 -1571 ((-1 |#2| |#2|) (-1161)))) (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150)) (-13 (-29 |#1|) (-1181) (-959))) (T -799)) 
+((-1571 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-1 *5 *5)) (-5 *1 (-799 *4 *5)) (-4 *5 (-13 (-29 *4) (-1181) (-959))))) (-1280 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *1 (-799 *4 *2)) (-4 *2 (-13 (-29 *4) (-1181) (-959))))) (-2473 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *1 (-799 *4 *2)) (-4 *2 (-13 (-29 *4) (-1181) (-959)))))) 
+(-10 -7 (-15 -2473 (|#2| |#2| (-1161))) (-15 -1280 (|#2| |#2| (-1161))) (-15 -1571 ((-1 |#2| |#2|) (-1161)))) 
+((-3259 (((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-310 (-381)) (-634 (-381)) (-381) (-381)) 114) (((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-310 (-381)) (-634 (-381)) (-381)) 115) (((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-634 (-381)) (-381)) 117) (((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-310 (-381)) (-381)) 118) (((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-381)) 119) (((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381))) 120) (((-1035) (-803) (-1059)) 105) (((-1035) (-803)) 106)) (-3031 (((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143)))) (-803) (-1059)) 71) (((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143)))) (-803)) 73))) 
+(((-800) (-10 -7 (-15 -3259 ((-1035) (-803))) (-15 -3259 ((-1035) (-803) (-1059))) (-15 -3259 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)))) (-15 -3259 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-381))) (-15 -3259 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-310 (-381)) (-381))) (-15 -3259 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-634 (-381)) (-381))) (-15 -3259 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-310 (-381)) (-634 (-381)) (-381))) (-15 -3259 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-310 (-381)) (-634 (-381)) (-381) (-381))) (-15 -3031 ((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143)))) (-803))) (-15 -3031 ((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143)))) (-803) (-1059))))) (T -800)) 
+((-3031 (*1 *2 *3 *4) (-12 (-5 *3 (-803)) (-5 *4 (-1059)) (-5 *2 (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-800)))) (-3031 (*1 *2 *3) (-12 (-5 *3 (-803)) (-5 *2 (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-800)))) (-3259 (*1 *2 *3 *4 *4 *5 *6 *5 *4 *4) (-12 (-5 *3 (-1244 (-310 *4))) (-5 *5 (-634 (-381))) (-5 *6 (-310 (-381))) (-5 *4 (-381)) (-5 *2 (-1035)) (-5 *1 (-800)))) (-3259 (*1 *2 *3 *4 *4 *5 *6 *5 *4) (-12 (-5 *3 (-1244 (-310 *4))) (-5 *5 (-634 (-381))) (-5 *6 (-310 (-381))) (-5 *4 (-381)) (-5 *2 (-1035)) (-5 *1 (-800)))) (-3259 (*1 *2 *3 *4 *4 *5 *5 *4) (-12 (-5 *3 (-1244 (-310 (-381)))) (-5 *4 (-381)) (-5 *5 (-634 *4)) (-5 *2 (-1035)) (-5 *1 (-800)))) (-3259 (*1 *2 *3 *4 *4 *5 *6 *4) (-12 (-5 *3 (-1244 (-310 *4))) (-5 *5 (-634 (-381))) (-5 *6 (-310 (-381))) (-5 *4 (-381)) (-5 *2 (-1035)) (-5 *1 (-800)))) (-3259 (*1 *2 *3 *4 *4 *5 *4) (-12 (-5 *3 (-1244 (-310 (-381)))) (-5 *4 (-381)) (-5 *5 (-634 *4)) (-5 *2 (-1035)) (-5 *1 (-800)))) (-3259 (*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1244 (-310 (-381)))) (-5 *4 (-381)) (-5 *5 (-634 *4)) (-5 *2 (-1035)) (-5 *1 (-800)))) (-3259 (*1 *2 *3 *4) (-12 (-5 *3 (-803)) (-5 *4 (-1059)) (-5 *2 (-1035)) (-5 *1 (-800)))) (-3259 (*1 *2 *3) (-12 (-5 *3 (-803)) (-5 *2 (-1035)) (-5 *1 (-800))))) 
+(-10 -7 (-15 -3259 ((-1035) (-803))) (-15 -3259 ((-1035) (-803) (-1059))) (-15 -3259 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)))) (-15 -3259 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-381))) (-15 -3259 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-310 (-381)) (-381))) (-15 -3259 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-634 (-381)) (-381))) (-15 -3259 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-310 (-381)) (-634 (-381)) (-381))) (-15 -3259 ((-1035) (-1244 (-310 (-381))) (-381) (-381) (-634 (-381)) (-310 (-381)) (-634 (-381)) (-381) (-381))) (-15 -3031 ((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143)))) (-803))) (-15 -3031 ((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143)))) (-803) (-1059)))) 
+((-3662 (((-2 (|:| |particular| (-3 |#4| "failed")) (|:| -2588 (-634 |#4|))) (-643 |#4|) |#4|) 32))) 
+(((-801 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3662 ((-2 (|:| |particular| (-3 |#4| "failed")) (|:| -2588 (-634 |#4|))) (-643 |#4|) |#4|))) (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568)))) (-1219 |#1|) (-1219 (-409 |#2|)) (-340 |#1| |#2| |#3|)) (T -801)) 
+((-3662 (*1 *2 *3 *4) (-12 (-5 *3 (-643 *4)) (-4 *4 (-340 *5 *6 *7)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2588 (-634 *4)))) (-5 *1 (-801 *5 *6 *7 *4))))) 
+(-10 -7 (-15 -3662 ((-2 (|:| |particular| (-3 |#4| "failed")) (|:| -2588 (-634 |#4|))) (-643 |#4|) |#4|))) 
+((-3618 (((-2 (|:| -2410 |#3|) (|:| |rh| (-634 (-409 |#2|)))) |#4| (-634 (-409 |#2|))) 51)) (-3857 (((-634 (-2 (|:| -1374 |#2|) (|:| -2785 |#2|))) |#4| |#2|) 59) (((-634 (-2 (|:| -1374 |#2|) (|:| -2785 |#2|))) |#4|) 58) (((-634 (-2 (|:| -1374 |#2|) (|:| -2785 |#2|))) |#3| |#2|) 20) (((-634 (-2 (|:| -1374 |#2|) (|:| -2785 |#2|))) |#3|) 21)) (-3036 ((|#2| |#4| |#1|) 60) ((|#2| |#3| |#1|) 27)) (-1739 ((|#2| |#3| (-634 (-409 |#2|))) 93) (((-3 |#2| "failed") |#3| (-409 |#2|)) 90))) 
+(((-802 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1739 ((-3 |#2| "failed") |#3| (-409 |#2|))) (-15 -1739 (|#2| |#3| (-634 (-409 |#2|)))) (-15 -3857 ((-634 (-2 (|:| -1374 |#2|) (|:| -2785 |#2|))) |#3|)) (-15 -3857 ((-634 (-2 (|:| -1374 |#2|) (|:| -2785 |#2|))) |#3| |#2|)) (-15 -3036 (|#2| |#3| |#1|)) (-15 -3857 ((-634 (-2 (|:| -1374 |#2|) (|:| -2785 |#2|))) |#4|)) (-15 -3857 ((-634 (-2 (|:| -1374 |#2|) (|:| -2785 |#2|))) |#4| |#2|)) (-15 -3036 (|#2| |#4| |#1|)) (-15 -3618 ((-2 (|:| -2410 |#3|) (|:| |rh| (-634 (-409 |#2|)))) |#4| (-634 (-409 |#2|))))) (-13 (-365) (-150) (-1037 (-409 (-568)))) (-1219 |#1|) (-646 |#2|) (-646 (-409 |#2|))) (T -802)) 
+((-3618 (*1 *2 *3 *4) (-12 (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-2 (|:| -2410 *7) (|:| |rh| (-634 (-409 *6))))) (-5 *1 (-802 *5 *6 *7 *3)) (-5 *4 (-634 (-409 *6))) (-4 *7 (-646 *6)) (-4 *3 (-646 (-409 *6))))) (-3036 (*1 *2 *3 *4) (-12 (-4 *2 (-1219 *4)) (-5 *1 (-802 *4 *2 *5 *3)) (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *5 (-646 *2)) (-4 *3 (-646 (-409 *2))))) (-3857 (*1 *2 *3 *4) (-12 (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *4 (-1219 *5)) (-5 *2 (-634 (-2 (|:| -1374 *4) (|:| -2785 *4)))) (-5 *1 (-802 *5 *4 *6 *3)) (-4 *6 (-646 *4)) (-4 *3 (-646 (-409 *4))))) (-3857 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-2 (|:| -1374 *5) (|:| -2785 *5)))) (-5 *1 (-802 *4 *5 *6 *3)) (-4 *6 (-646 *5)) (-4 *3 (-646 (-409 *5))))) (-3036 (*1 *2 *3 *4) (-12 (-4 *2 (-1219 *4)) (-5 *1 (-802 *4 *2 *3 *5)) (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *3 (-646 *2)) (-4 *5 (-646 (-409 *2))))) (-3857 (*1 *2 *3 *4) (-12 (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *4 (-1219 *5)) (-5 *2 (-634 (-2 (|:| -1374 *4) (|:| -2785 *4)))) (-5 *1 (-802 *5 *4 *3 *6)) (-4 *3 (-646 *4)) (-4 *6 (-646 (-409 *4))))) (-3857 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-2 (|:| -1374 *5) (|:| -2785 *5)))) (-5 *1 (-802 *4 *5 *3 *6)) (-4 *3 (-646 *5)) (-4 *6 (-646 (-409 *5))))) (-1739 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-409 *2))) (-4 *2 (-1219 *5)) (-5 *1 (-802 *5 *2 *3 *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *3 (-646 *2)) (-4 *6 (-646 (-409 *2))))) (-1739 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-409 *2)) (-4 *2 (-1219 *5)) (-5 *1 (-802 *5 *2 *3 *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *3 (-646 *2)) (-4 *6 (-646 *4))))) 
+(-10 -7 (-15 -1739 ((-3 |#2| "failed") |#3| (-409 |#2|))) (-15 -1739 (|#2| |#3| (-634 (-409 |#2|)))) (-15 -3857 ((-634 (-2 (|:| -1374 |#2|) (|:| -2785 |#2|))) |#3|)) (-15 -3857 ((-634 (-2 (|:| -1374 |#2|) (|:| -2785 |#2|))) |#3| |#2|)) (-15 -3036 (|#2| |#3| |#1|)) (-15 -3857 ((-634 (-2 (|:| -1374 |#2|) (|:| -2785 |#2|))) |#4|)) (-15 -3857 ((-634 (-2 (|:| -1374 |#2|) (|:| -2785 |#2|))) |#4| |#2|)) (-15 -3036 (|#2| |#4| |#1|)) (-15 -3618 ((-2 (|:| -2410 |#3|) (|:| |rh| (-634 (-409 |#2|)))) |#4| (-634 (-409 |#2|))))) 
+((-2449 (((-121) $ $) NIL)) (-2857 (((-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) $) 9)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 11) (($ (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) 8)) (-1719 (((-121) $ $) NIL))) 
+(((-803) (-13 (-1090) (-10 -8 (-15 -2747 ($ (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2747 ((-850) $)) (-15 -2857 ((-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) $))))) (T -803)) 
+((-2747 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-803)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *1 (-803)))) (-2857 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *1 (-803))))) 
+(-13 (-1090) (-10 -8 (-15 -2747 ($ (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-15 -2747 ((-850) $)) (-15 -2857 ((-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))) $)))) 
+((-2645 (((-634 (-2 (|:| |frac| (-409 |#2|)) (|:| -2410 |#3|))) |#3| (-1 (-634 |#2|) |#2| (-1157 |#2|)) (-1 (-420 |#2|) |#2|)) 118)) (-1869 (((-634 (-2 (|:| |poly| |#2|) (|:| -2410 |#3|))) |#3| (-1 (-634 |#1|) |#2|)) 45)) (-2031 (((-634 (-2 (|:| |deg| (-763)) (|:| -2410 |#2|))) |#3|) 95)) (-3050 ((|#2| |#3|) 37)) (-2533 (((-634 (-2 (|:| -3497 |#1|) (|:| -2410 |#3|))) |#3| (-1 (-634 |#1|) |#2|)) 82)) (-4083 ((|#3| |#3| (-409 |#2|)) 63) ((|#3| |#3| |#2|) 79))) 
+(((-804 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3050 (|#2| |#3|)) (-15 -2031 ((-634 (-2 (|:| |deg| (-763)) (|:| -2410 |#2|))) |#3|)) (-15 -2533 ((-634 (-2 (|:| -3497 |#1|) (|:| -2410 |#3|))) |#3| (-1 (-634 |#1|) |#2|))) (-15 -1869 ((-634 (-2 (|:| |poly| |#2|) (|:| -2410 |#3|))) |#3| (-1 (-634 |#1|) |#2|))) (-15 -2645 ((-634 (-2 (|:| |frac| (-409 |#2|)) (|:| -2410 |#3|))) |#3| (-1 (-634 |#2|) |#2| (-1157 |#2|)) (-1 (-420 |#2|) |#2|))) (-15 -4083 (|#3| |#3| |#2|)) (-15 -4083 (|#3| |#3| (-409 |#2|)))) (-13 (-365) (-150) (-1037 (-409 (-568)))) (-1219 |#1|) (-646 |#2|) (-646 (-409 |#2|))) (T -804)) 
+((-4083 (*1 *2 *2 *3) (-12 (-5 *3 (-409 *5)) (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *1 (-804 *4 *5 *2 *6)) (-4 *2 (-646 *5)) (-4 *6 (-646 *3)))) (-4083 (*1 *2 *2 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *3 (-1219 *4)) (-5 *1 (-804 *4 *3 *2 *5)) (-4 *2 (-646 *3)) (-4 *5 (-646 (-409 *3))))) (-2645 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 (-634 *7) *7 (-1157 *7))) (-5 *5 (-1 (-420 *7) *7)) (-4 *7 (-1219 *6)) (-4 *6 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-5 *2 (-634 (-2 (|:| |frac| (-409 *7)) (|:| -2410 *3)))) (-5 *1 (-804 *6 *7 *3 *8)) (-4 *3 (-646 *7)) (-4 *8 (-646 (-409 *7))))) (-1869 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-2 (|:| |poly| *6) (|:| -2410 *3)))) (-5 *1 (-804 *5 *6 *3 *7)) (-4 *3 (-646 *6)) (-4 *7 (-646 (-409 *6))))) (-2533 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-2 (|:| -3497 *5) (|:| -2410 *3)))) (-5 *1 (-804 *5 *6 *3 *7)) (-4 *3 (-646 *6)) (-4 *7 (-646 (-409 *6))))) (-2031 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-2 (|:| |deg| (-763)) (|:| -2410 *5)))) (-5 *1 (-804 *4 *5 *3 *6)) (-4 *3 (-646 *5)) (-4 *6 (-646 (-409 *5))))) (-3050 (*1 *2 *3) (-12 (-4 *2 (-1219 *4)) (-5 *1 (-804 *4 *2 *3 *5)) (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *3 (-646 *2)) (-4 *5 (-646 (-409 *2)))))) 
+(-10 -7 (-15 -3050 (|#2| |#3|)) (-15 -2031 ((-634 (-2 (|:| |deg| (-763)) (|:| -2410 |#2|))) |#3|)) (-15 -2533 ((-634 (-2 (|:| -3497 |#1|) (|:| -2410 |#3|))) |#3| (-1 (-634 |#1|) |#2|))) (-15 -1869 ((-634 (-2 (|:| |poly| |#2|) (|:| -2410 |#3|))) |#3| (-1 (-634 |#1|) |#2|))) (-15 -2645 ((-634 (-2 (|:| |frac| (-409 |#2|)) (|:| -2410 |#3|))) |#3| (-1 (-634 |#2|) |#2| (-1157 |#2|)) (-1 (-420 |#2|) |#2|))) (-15 -4083 (|#3| |#3| |#2|)) (-15 -4083 (|#3| |#3| (-409 |#2|)))) 
+((-1278 (((-2 (|:| -2588 (-634 (-409 |#2|))) (|:| -2908 (-679 |#1|))) (-644 |#2| (-409 |#2|)) (-634 (-409 |#2|))) 117) (((-2 (|:| |particular| (-3 (-409 |#2|) "failed")) (|:| -2588 (-634 (-409 |#2|)))) (-644 |#2| (-409 |#2|)) (-409 |#2|)) 116) (((-2 (|:| -2588 (-634 (-409 |#2|))) (|:| -2908 (-679 |#1|))) (-643 (-409 |#2|)) (-634 (-409 |#2|))) 111) (((-2 (|:| |particular| (-3 (-409 |#2|) "failed")) (|:| -2588 (-634 (-409 |#2|)))) (-643 (-409 |#2|)) (-409 |#2|)) 109)) (-3172 ((|#2| (-644 |#2| (-409 |#2|))) 77) ((|#2| (-643 (-409 |#2|))) 81))) 
+(((-805 |#1| |#2|) (-10 -7 (-15 -1278 ((-2 (|:| |particular| (-3 (-409 |#2|) "failed")) (|:| -2588 (-634 (-409 |#2|)))) (-643 (-409 |#2|)) (-409 |#2|))) (-15 -1278 ((-2 (|:| -2588 (-634 (-409 |#2|))) (|:| -2908 (-679 |#1|))) (-643 (-409 |#2|)) (-634 (-409 |#2|)))) (-15 -1278 ((-2 (|:| |particular| (-3 (-409 |#2|) "failed")) (|:| -2588 (-634 (-409 |#2|)))) (-644 |#2| (-409 |#2|)) (-409 |#2|))) (-15 -1278 ((-2 (|:| -2588 (-634 (-409 |#2|))) (|:| -2908 (-679 |#1|))) (-644 |#2| (-409 |#2|)) (-634 (-409 |#2|)))) (-15 -3172 (|#2| (-643 (-409 |#2|)))) (-15 -3172 (|#2| (-644 |#2| (-409 |#2|))))) (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568)))) (-1219 |#1|)) (T -805)) 
+((-3172 (*1 *2 *3) (-12 (-5 *3 (-644 *2 (-409 *2))) (-4 *2 (-1219 *4)) (-5 *1 (-805 *4 *2)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))))) (-3172 (*1 *2 *3) (-12 (-5 *3 (-643 (-409 *2))) (-4 *2 (-1219 *4)) (-5 *1 (-805 *4 *2)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))))) (-1278 (*1 *2 *3 *4) (-12 (-5 *3 (-644 *6 (-409 *6))) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-2 (|:| -2588 (-634 (-409 *6))) (|:| -2908 (-679 *5)))) (-5 *1 (-805 *5 *6)) (-5 *4 (-634 (-409 *6))))) (-1278 (*1 *2 *3 *4) (-12 (-5 *3 (-644 *6 (-409 *6))) (-5 *4 (-409 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2588 (-634 *4)))) (-5 *1 (-805 *5 *6)))) (-1278 (*1 *2 *3 *4) (-12 (-5 *3 (-643 (-409 *6))) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-2 (|:| -2588 (-634 (-409 *6))) (|:| -2908 (-679 *5)))) (-5 *1 (-805 *5 *6)) (-5 *4 (-634 (-409 *6))))) (-1278 (*1 *2 *3 *4) (-12 (-5 *3 (-643 (-409 *6))) (-5 *4 (-409 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2588 (-634 *4)))) (-5 *1 (-805 *5 *6))))) 
+(-10 -7 (-15 -1278 ((-2 (|:| |particular| (-3 (-409 |#2|) "failed")) (|:| -2588 (-634 (-409 |#2|)))) (-643 (-409 |#2|)) (-409 |#2|))) (-15 -1278 ((-2 (|:| -2588 (-634 (-409 |#2|))) (|:| -2908 (-679 |#1|))) (-643 (-409 |#2|)) (-634 (-409 |#2|)))) (-15 -1278 ((-2 (|:| |particular| (-3 (-409 |#2|) "failed")) (|:| -2588 (-634 (-409 |#2|)))) (-644 |#2| (-409 |#2|)) (-409 |#2|))) (-15 -1278 ((-2 (|:| -2588 (-634 (-409 |#2|))) (|:| -2908 (-679 |#1|))) (-644 |#2| (-409 |#2|)) (-634 (-409 |#2|)))) (-15 -3172 (|#2| (-643 (-409 |#2|)))) (-15 -3172 (|#2| (-644 |#2| (-409 |#2|))))) 
+((-1633 (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#1|))) |#5| |#4|) 47))) 
+(((-806 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1633 ((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#1|))) |#5| |#4|))) (-365) (-646 |#1|) (-1219 |#1|) (-714 |#1| |#3|) (-646 |#4|)) (T -806)) 
+((-1633 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *7 (-1219 *5)) (-4 *4 (-714 *5 *7)) (-5 *2 (-2 (|:| -2908 (-679 *6)) (|:| |vec| (-1244 *5)))) (-5 *1 (-806 *5 *6 *7 *4 *3)) (-4 *6 (-646 *5)) (-4 *3 (-646 *4))))) 
+(-10 -7 (-15 -1633 ((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#1|))) |#5| |#4|))) 
+((-2645 (((-634 (-2 (|:| |frac| (-409 |#2|)) (|:| -2410 (-644 |#2| (-409 |#2|))))) (-644 |#2| (-409 |#2|)) (-1 (-420 |#2|) |#2|)) 43)) (-1532 (((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|)) (-1 (-420 |#2|) |#2|)) 133 (|has| |#1| (-27))) (((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|))) 134 (|has| |#1| (-27))) (((-634 (-409 |#2|)) (-643 (-409 |#2|)) (-1 (-420 |#2|) |#2|)) 135 (|has| |#1| (-27))) (((-634 (-409 |#2|)) (-643 (-409 |#2|))) 136 (|has| |#1| (-27))) (((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|)) (-1 (-634 |#1|) |#2|) (-1 (-420 |#2|) |#2|)) 36) (((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|)) (-1 (-634 |#1|) |#2|)) 37) (((-634 (-409 |#2|)) (-643 (-409 |#2|)) (-1 (-634 |#1|) |#2|) (-1 (-420 |#2|) |#2|)) 34) (((-634 (-409 |#2|)) (-643 (-409 |#2|)) (-1 (-634 |#1|) |#2|)) 35)) (-1869 (((-634 (-2 (|:| |poly| |#2|) (|:| -2410 (-644 |#2| (-409 |#2|))))) (-644 |#2| (-409 |#2|)) (-1 (-634 |#1|) |#2|)) 80))) 
+(((-807 |#1| |#2|) (-10 -7 (-15 -1532 ((-634 (-409 |#2|)) (-643 (-409 |#2|)) (-1 (-634 |#1|) |#2|))) (-15 -1532 ((-634 (-409 |#2|)) (-643 (-409 |#2|)) (-1 (-634 |#1|) |#2|) (-1 (-420 |#2|) |#2|))) (-15 -1532 ((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|)) (-1 (-634 |#1|) |#2|))) (-15 -1532 ((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|)) (-1 (-634 |#1|) |#2|) (-1 (-420 |#2|) |#2|))) (-15 -2645 ((-634 (-2 (|:| |frac| (-409 |#2|)) (|:| -2410 (-644 |#2| (-409 |#2|))))) (-644 |#2| (-409 |#2|)) (-1 (-420 |#2|) |#2|))) (-15 -1869 ((-634 (-2 (|:| |poly| |#2|) (|:| -2410 (-644 |#2| (-409 |#2|))))) (-644 |#2| (-409 |#2|)) (-1 (-634 |#1|) |#2|))) (IF (|has| |#1| (-27)) (PROGN (-15 -1532 ((-634 (-409 |#2|)) (-643 (-409 |#2|)))) (-15 -1532 ((-634 (-409 |#2|)) (-643 (-409 |#2|)) (-1 (-420 |#2|) |#2|))) (-15 -1532 ((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|)))) (-15 -1532 ((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|)) (-1 (-420 |#2|) |#2|)))) |noBranch|)) (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568)))) (-1219 |#1|)) (T -807)) 
+((-1532 (*1 *2 *3 *4) (-12 (-5 *3 (-644 *6 (-409 *6))) (-5 *4 (-1 (-420 *6) *6)) (-4 *6 (-1219 *5)) (-4 *5 (-27)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-634 (-409 *6))) (-5 *1 (-807 *5 *6)))) (-1532 (*1 *2 *3) (-12 (-5 *3 (-644 *5 (-409 *5))) (-4 *5 (-1219 *4)) (-4 *4 (-27)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-634 (-409 *5))) (-5 *1 (-807 *4 *5)))) (-1532 (*1 *2 *3 *4) (-12 (-5 *3 (-643 (-409 *6))) (-5 *4 (-1 (-420 *6) *6)) (-4 *6 (-1219 *5)) (-4 *5 (-27)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-634 (-409 *6))) (-5 *1 (-807 *5 *6)))) (-1532 (*1 *2 *3) (-12 (-5 *3 (-643 (-409 *5))) (-4 *5 (-1219 *4)) (-4 *4 (-27)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-634 (-409 *5))) (-5 *1 (-807 *4 *5)))) (-1869 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-2 (|:| |poly| *6) (|:| -2410 (-644 *6 (-409 *6)))))) (-5 *1 (-807 *5 *6)) (-5 *3 (-644 *6 (-409 *6))))) (-2645 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-420 *6) *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-634 (-2 (|:| |frac| (-409 *6)) (|:| -2410 (-644 *6 (-409 *6)))))) (-5 *1 (-807 *5 *6)) (-5 *3 (-644 *6 (-409 *6))))) (-1532 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-644 *7 (-409 *7))) (-5 *4 (-1 (-634 *6) *7)) (-5 *5 (-1 (-420 *7) *7)) (-4 *6 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *7 (-1219 *6)) (-5 *2 (-634 (-409 *7))) (-5 *1 (-807 *6 *7)))) (-1532 (*1 *2 *3 *4) (-12 (-5 *3 (-644 *6 (-409 *6))) (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-409 *6))) (-5 *1 (-807 *5 *6)))) (-1532 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-643 (-409 *7))) (-5 *4 (-1 (-634 *6) *7)) (-5 *5 (-1 (-420 *7) *7)) (-4 *6 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *7 (-1219 *6)) (-5 *2 (-634 (-409 *7))) (-5 *1 (-807 *6 *7)))) (-1532 (*1 *2 *3 *4) (-12 (-5 *3 (-643 (-409 *6))) (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-409 *6))) (-5 *1 (-807 *5 *6))))) 
+(-10 -7 (-15 -1532 ((-634 (-409 |#2|)) (-643 (-409 |#2|)) (-1 (-634 |#1|) |#2|))) (-15 -1532 ((-634 (-409 |#2|)) (-643 (-409 |#2|)) (-1 (-634 |#1|) |#2|) (-1 (-420 |#2|) |#2|))) (-15 -1532 ((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|)) (-1 (-634 |#1|) |#2|))) (-15 -1532 ((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|)) (-1 (-634 |#1|) |#2|) (-1 (-420 |#2|) |#2|))) (-15 -2645 ((-634 (-2 (|:| |frac| (-409 |#2|)) (|:| -2410 (-644 |#2| (-409 |#2|))))) (-644 |#2| (-409 |#2|)) (-1 (-420 |#2|) |#2|))) (-15 -1869 ((-634 (-2 (|:| |poly| |#2|) (|:| -2410 (-644 |#2| (-409 |#2|))))) (-644 |#2| (-409 |#2|)) (-1 (-634 |#1|) |#2|))) (IF (|has| |#1| (-27)) (PROGN (-15 -1532 ((-634 (-409 |#2|)) (-643 (-409 |#2|)))) (-15 -1532 ((-634 (-409 |#2|)) (-643 (-409 |#2|)) (-1 (-420 |#2|) |#2|))) (-15 -1532 ((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|)))) (-15 -1532 ((-634 (-409 |#2|)) (-644 |#2| (-409 |#2|)) (-1 (-420 |#2|) |#2|)))) |noBranch|)) 
+((-1297 (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#1|))) (-679 |#2|) (-1244 |#1|)) 86) (((-2 (|:| A (-679 |#1|)) (|:| |eqs| (-634 (-2 (|:| C (-679 |#1|)) (|:| |g| (-1244 |#1|)) (|:| -2410 |#2|) (|:| |rh| |#1|))))) (-679 |#1|) (-1244 |#1|)) 14)) (-1993 (((-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -2588 (-634 (-1244 |#1|)))) (-679 |#2|) (-1244 |#1|) (-1 (-2 (|:| |particular| (-3 |#1| "failed")) (|:| -2588 (-634 |#1|))) |#2| |#1|)) 92)) (-3259 (((-3 (-2 (|:| |particular| (-1244 |#1|)) (|:| -2588 (-679 |#1|))) "failed") (-679 |#1|) (-1244 |#1|) (-1 (-3 (-2 (|:| |particular| |#1|) (|:| -2588 (-634 |#1|))) "failed") |#2| |#1|)) 45))) 
+(((-808 |#1| |#2|) (-10 -7 (-15 -1297 ((-2 (|:| A (-679 |#1|)) (|:| |eqs| (-634 (-2 (|:| C (-679 |#1|)) (|:| |g| (-1244 |#1|)) (|:| -2410 |#2|) (|:| |rh| |#1|))))) (-679 |#1|) (-1244 |#1|))) (-15 -1297 ((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#1|))) (-679 |#2|) (-1244 |#1|))) (-15 -3259 ((-3 (-2 (|:| |particular| (-1244 |#1|)) (|:| -2588 (-679 |#1|))) "failed") (-679 |#1|) (-1244 |#1|) (-1 (-3 (-2 (|:| |particular| |#1|) (|:| -2588 (-634 |#1|))) "failed") |#2| |#1|))) (-15 -1993 ((-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -2588 (-634 (-1244 |#1|)))) (-679 |#2|) (-1244 |#1|) (-1 (-2 (|:| |particular| (-3 |#1| "failed")) (|:| -2588 (-634 |#1|))) |#2| |#1|)))) (-365) (-646 |#1|)) (T -808)) 
+((-1993 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *7)) (-5 *5 (-1 (-2 (|:| |particular| (-3 *6 "failed")) (|:| -2588 (-634 *6))) *7 *6)) (-4 *6 (-365)) (-4 *7 (-646 *6)) (-5 *2 (-2 (|:| |particular| (-3 (-1244 *6) "failed")) (|:| -2588 (-634 (-1244 *6))))) (-5 *1 (-808 *6 *7)) (-5 *4 (-1244 *6)))) (-3259 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1 (-3 (-2 (|:| |particular| *6) (|:| -2588 (-634 *6))) "failed") *7 *6)) (-4 *6 (-365)) (-4 *7 (-646 *6)) (-5 *2 (-2 (|:| |particular| (-1244 *6)) (|:| -2588 (-679 *6)))) (-5 *1 (-808 *6 *7)) (-5 *3 (-679 *6)) (-5 *4 (-1244 *6)))) (-1297 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-646 *5)) (-5 *2 (-2 (|:| -2908 (-679 *6)) (|:| |vec| (-1244 *5)))) (-5 *1 (-808 *5 *6)) (-5 *3 (-679 *6)) (-5 *4 (-1244 *5)))) (-1297 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-5 *2 (-2 (|:| A (-679 *5)) (|:| |eqs| (-634 (-2 (|:| C (-679 *5)) (|:| |g| (-1244 *5)) (|:| -2410 *6) (|:| |rh| *5)))))) (-5 *1 (-808 *5 *6)) (-5 *3 (-679 *5)) (-5 *4 (-1244 *5)) (-4 *6 (-646 *5))))) 
+(-10 -7 (-15 -1297 ((-2 (|:| A (-679 |#1|)) (|:| |eqs| (-634 (-2 (|:| C (-679 |#1|)) (|:| |g| (-1244 |#1|)) (|:| -2410 |#2|) (|:| |rh| |#1|))))) (-679 |#1|) (-1244 |#1|))) (-15 -1297 ((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#1|))) (-679 |#2|) (-1244 |#1|))) (-15 -3259 ((-3 (-2 (|:| |particular| (-1244 |#1|)) (|:| -2588 (-679 |#1|))) "failed") (-679 |#1|) (-1244 |#1|) (-1 (-3 (-2 (|:| |particular| |#1|) (|:| -2588 (-634 |#1|))) "failed") |#2| |#1|))) (-15 -1993 ((-2 (|:| |particular| (-3 (-1244 |#1|) "failed")) (|:| -2588 (-634 (-1244 |#1|)))) (-679 |#2|) (-1244 |#1|) (-1 (-2 (|:| |particular| (-3 |#1| "failed")) (|:| -2588 (-634 |#1|))) |#2| |#1|)))) 
+((-3005 (((-679 |#1|) (-634 |#1|) (-763)) 13) (((-679 |#1|) (-634 |#1|)) 14)) (-1552 (((-3 (-1244 |#1|) "failed") |#2| |#1| (-634 |#1|)) 34)) (-3075 (((-3 |#1| "failed") |#2| |#1| (-634 |#1|) (-1 |#1| |#1|)) 42))) 
+(((-809 |#1| |#2|) (-10 -7 (-15 -3005 ((-679 |#1|) (-634 |#1|))) (-15 -3005 ((-679 |#1|) (-634 |#1|) (-763))) (-15 -1552 ((-3 (-1244 |#1|) "failed") |#2| |#1| (-634 |#1|))) (-15 -3075 ((-3 |#1| "failed") |#2| |#1| (-634 |#1|) (-1 |#1| |#1|)))) (-365) (-646 |#1|)) (T -809)) 
+((-3075 (*1 *2 *3 *2 *4 *5) (|partial| -12 (-5 *4 (-634 *2)) (-5 *5 (-1 *2 *2)) (-4 *2 (-365)) (-5 *1 (-809 *2 *3)) (-4 *3 (-646 *2)))) (-1552 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-634 *4)) (-4 *4 (-365)) (-5 *2 (-1244 *4)) (-5 *1 (-809 *4 *3)) (-4 *3 (-646 *4)))) (-3005 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-763)) (-4 *5 (-365)) (-5 *2 (-679 *5)) (-5 *1 (-809 *5 *6)) (-4 *6 (-646 *5)))) (-3005 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-5 *2 (-679 *4)) (-5 *1 (-809 *4 *5)) (-4 *5 (-646 *4))))) 
+(-10 -7 (-15 -3005 ((-679 |#1|) (-634 |#1|))) (-15 -3005 ((-679 |#1|) (-634 |#1|) (-763))) (-15 -1552 ((-3 (-1244 |#1|) "failed") |#2| |#1| (-634 |#1|))) (-15 -3075 ((-3 |#1| "failed") |#2| |#1| (-634 |#1|) (-1 |#1| |#1|)))) 
+((-2449 (((-121) $ $) NIL (|has| |#2| (-1090)))) (-1819 (((-121) $) NIL (|has| |#2| (-137)))) (-4007 (($ (-917)) NIL (|has| |#2| (-1047)))) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-2409 (($ $ $) NIL (|has| |#2| (-788)))) (-2689 (((-3 $ "failed") $ $) NIL (|has| |#2| (-137)))) (-1667 (((-121) $ (-763)) NIL)) (-3986 (((-763)) NIL (|has| |#2| (-370)))) (-3337 (((-568) $) NIL (|has| |#2| (-840)))) (-2438 ((|#2| $ (-568) |#2|) NIL (|has| $ (-6 -4522)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) NIL (-12 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090)))) (((-3 (-409 (-568)) "failed") $) NIL (-12 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) (((-3 |#2| "failed") $) NIL (|has| |#2| (-1090)))) (-2857 (((-568) $) NIL (-12 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090)))) (((-409 (-568)) $) NIL (-12 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) ((|#2| $) NIL (|has| |#2| (-1090)))) (-1668 (((-679 (-568)) (-679 $)) NIL (-12 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (-12 (|has| |#2| (-630 (-568))) (|has| |#2| (-1047)))) (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL (|has| |#2| (-1047))) (((-679 |#2|) (-679 $)) NIL (|has| |#2| (-1047)))) (-2902 (((-3 $ "failed") $) NIL (|has| |#2| (-716)))) (-1733 (($) NIL (|has| |#2| (-370)))) (-1292 ((|#2| $ (-568) |#2|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#2| $ (-568)) NIL)) (-1436 (((-121) $) NIL (|has| |#2| (-840)))) (-3317 (((-634 |#2|) $) NIL (|has| $ (-6 -4521)))) (-1598 (((-121) $) NIL (|has| |#2| (-716)))) (-2859 (((-121) $) NIL (|has| |#2| (-840)))) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) NIL (|has| (-568) (-842)))) (-1732 (($ $ $) NIL (-2199 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-4406 (((-634 |#2|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-3631 (((-568) $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (-2199 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-2253 (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#2| |#2|) $) NIL)) (-2291 (((-917) $) NIL (|has| |#2| (-370)))) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (|has| |#2| (-1090)))) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4357 (($ (-917)) NIL (|has| |#2| (-370)))) (-4025 (((-1108) $) NIL (|has| |#2| (-1090)))) (-3877 ((|#2| $) NIL (|has| (-568) (-842)))) (-2490 (($ $ |#2|) NIL (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-1480 (((-634 |#2|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#2| $ (-568) |#2|) NIL) ((|#2| $ (-568)) NIL)) (-2286 ((|#2| $ $) NIL (|has| |#2| (-1047)))) (-2041 (($ (-1244 |#2|)) NIL)) (-3108 (((-139)) NIL (|has| |#2| (-365)))) (-4191 (($ $) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1 |#2| |#2|) (-763)) NIL (|has| |#2| (-1047))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1047)))) (-4170 (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-3865 (($ $) NIL)) (-2747 (((-1244 |#2|) $) NIL) (((-850) $) NIL (|has| |#2| (-1090))) (($ (-568)) NIL (-2199 (-12 (|has| |#2| (-1037 (-568))) (|has| |#2| (-1090))) (|has| |#2| (-1047)))) (($ (-409 (-568))) NIL (-12 (|has| |#2| (-1037 (-409 (-568)))) (|has| |#2| (-1090)))) (($ |#2|) NIL (|has| |#2| (-1090)))) (-3425 (((-763)) NIL (|has| |#2| (-1047)))) (-3437 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-2811 (($ $) NIL (|has| |#2| (-840)))) (-1889 (($ $ (-763)) NIL (|has| |#2| (-716))) (($ $ (-917)) NIL (|has| |#2| (-716)))) (-3058 (($) NIL (|has| |#2| (-137)) CONST)) (-1557 (($) NIL (|has| |#2| (-716)) CONST)) (-3192 (($ $) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#2| (-225)) (|has| |#2| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#2| (-895 (-1161))) (|has| |#2| (-1047)))) (($ $ (-1 |#2| |#2|) (-763)) NIL (|has| |#2| (-1047))) (($ $ (-1 |#2| |#2|)) NIL (|has| |#2| (-1047)))) (-1753 (((-121) $ $) NIL (-2199 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1740 (((-121) $ $) NIL (-2199 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1719 (((-121) $ $) NIL (|has| |#2| (-1090)))) (-1747 (((-121) $ $) NIL (-2199 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1734 (((-121) $ $) 11 (-2199 (|has| |#2| (-788)) (|has| |#2| (-840))))) (-1781 (($ $ |#2|) NIL (|has| |#2| (-365)))) (-1775 (($ $ $) NIL (|has| |#2| (-1047))) (($ $) NIL (|has| |#2| (-1047)))) (-1769 (($ $ $) NIL (|has| |#2| (-25)))) (** (($ $ (-763)) NIL (|has| |#2| (-716))) (($ $ (-917)) NIL (|has| |#2| (-716)))) (* (($ (-568) $) NIL (|has| |#2| (-1047))) (($ $ $) NIL (|has| |#2| (-716))) (($ $ |#2|) NIL (|has| |#2| (-1047))) (($ |#2| $) NIL (|has| |#2| (-1047))) (($ (-763) $) NIL (|has| |#2| (-137))) (($ (-917) $) NIL (|has| |#2| (-25)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
 (((-810 |#1| |#2| |#3|) (-230 |#1| |#2|) (-763) (-788) (-1 (-121) (-1244 |#2|) (-1244 |#2|))) (T -810)) 
 NIL 
 (-230 |#1| |#2|) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3902 (((-634 (-763)) $) NIL) (((-634 (-763)) $ (-1161)) NIL)) (-1551 (((-763) $) NIL) (((-763) $ (-1161)) NIL)) (-2055 (((-634 (-813 (-1161))) $) NIL)) (-3839 (((-1157 $) $ (-813 (-1161))) NIL) (((-1157 |#1|) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-2773 (((-763) $) NIL) (((-763) $ (-634 (-813 (-1161)))) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-4305 (($ $) NIL (|has| |#1| (-453)))) (-1678 (((-420 $) $) NIL (|has| |#1| (-453)))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-4180 (($ $) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-813 (-1161)) "failed") $) NIL) (((-3 (-1161) "failed") $) NIL) (((-3 (-1113 |#1| (-1161)) "failed") $) NIL)) (-2854 ((|#1| $) NIL) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-813 (-1161)) $) NIL) (((-1161) $) NIL) (((-1113 |#1| (-1161)) $) NIL)) (-4265 (($ $ $ (-813 (-1161))) NIL (|has| |#1| (-172)))) (-2114 (($ $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3250 (($ $) NIL (|has| |#1| (-453))) (($ $ (-813 (-1161))) NIL (|has| |#1| (-453)))) (-2108 (((-634 $) $) NIL)) (-3927 (((-121) $) NIL (|has| |#1| (-904)))) (-3088 (($ $ |#1| (-534 (-813 (-1161))) $) NIL)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-813 (-1161)) (-881 (-381))) (|has| |#1| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-813 (-1161)) (-881 (-568))) (|has| |#1| (-881 (-568)))))) (-4477 (((-763) $ (-1161)) NIL) (((-763) $) NIL)) (-2735 (((-121) $) NIL)) (-4178 (((-763) $) NIL)) (-2051 (($ (-1157 |#1|) (-813 (-1161))) NIL) (($ (-1157 $) (-813 (-1161))) NIL)) (-2976 (((-634 $) $) NIL)) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| (-534 (-813 (-1161)))) NIL) (($ $ (-813 (-1161)) (-763)) NIL) (($ $ (-634 (-813 (-1161))) (-634 (-763))) NIL)) (-3379 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $ (-813 (-1161))) NIL)) (-2144 (((-534 (-813 (-1161))) $) NIL) (((-763) $ (-813 (-1161))) NIL) (((-634 (-763)) $ (-634 (-813 (-1161)))) NIL)) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-3842 (($ (-1 (-534 (-813 (-1161))) (-534 (-813 (-1161)))) $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-4300 (((-1 $ (-763)) (-1161)) NIL) (((-1 $ (-763)) $) NIL (|has| |#1| (-225)))) (-2244 (((-3 (-813 (-1161)) "failed") $) NIL)) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-1690 (((-813 (-1161)) $) NIL)) (-2495 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-4487 (((-1143) $) NIL)) (-1989 (((-121) $) NIL)) (-3324 (((-3 (-634 $) "failed") $) NIL)) (-1794 (((-3 (-634 $) "failed") $) NIL)) (-3751 (((-3 (-2 (|:| |var| (-813 (-1161))) (|:| -3438 (-763))) "failed") $) NIL)) (-1484 (($ $) NIL)) (-4022 (((-1108) $) NIL)) (-2086 (((-121) $) NIL)) (-2091 ((|#1| $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-453)))) (-2721 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3848 (((-420 $) $) NIL (|has| |#1| (-904)))) (-2595 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-813 (-1161)) |#1|) NIL) (($ $ (-634 (-813 (-1161))) (-634 |#1|)) NIL) (($ $ (-813 (-1161)) $) NIL) (($ $ (-634 (-813 (-1161))) (-634 $)) NIL) (($ $ (-1161) $) NIL (|has| |#1| (-225))) (($ $ (-634 (-1161)) (-634 $)) NIL (|has| |#1| (-225))) (($ $ (-1161) |#1|) NIL (|has| |#1| (-225))) (($ $ (-634 (-1161)) (-634 |#1|)) NIL (|has| |#1| (-225)))) (-2217 (($ $ (-813 (-1161))) NIL (|has| |#1| (-172)))) (-4189 (($ $ (-813 (-1161))) NIL) (($ $ (-634 (-813 (-1161)))) NIL) (($ $ (-813 (-1161)) (-763)) NIL) (($ $ (-634 (-813 (-1161))) (-634 (-763))) NIL) (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-3795 (((-634 (-1161)) $) NIL)) (-3206 (((-534 (-813 (-1161))) $) NIL) (((-763) $ (-813 (-1161))) NIL) (((-634 (-763)) $ (-634 (-813 (-1161)))) NIL) (((-763) $ (-1161)) NIL)) (-4278 (((-887 (-381)) $) NIL (-12 (|has| (-813 (-1161)) (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-813 (-1161)) (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-813 (-1161)) (-609 (-541))) (|has| |#1| (-609 (-541)))))) (-3367 ((|#1| $) NIL (|has| |#1| (-453))) (($ $ (-813 (-1161))) NIL (|has| |#1| (-453)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#1| (-904))))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL) (($ (-813 (-1161))) NIL) (($ (-1161)) NIL) (($ (-1113 |#1| (-1161))) NIL) (($ (-409 (-568))) NIL (-2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#1| (-558)))) (-1302 (((-634 |#1|) $) NIL)) (-2604 ((|#1| $ (-534 (-813 (-1161)))) NIL) (($ $ (-813 (-1161)) (-763)) NIL) (($ $ (-634 (-813 (-1161))) (-634 (-763))) NIL)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-4078 (((-763)) NIL)) (-4171 (($ $ $ (-763)) NIL (|has| |#1| (-172)))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $ (-813 (-1161))) NIL) (($ $ (-634 (-813 (-1161)))) NIL) (($ $ (-813 (-1161)) (-763)) NIL) (($ $ (-634 (-813 (-1161))) (-634 (-763))) NIL) (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2076 (((-634 (-763)) $) NIL) (((-634 (-763)) $ (-1161)) NIL)) (-4308 (((-763) $) NIL) (((-763) $ (-1161)) NIL)) (-2057 (((-634 (-813 (-1161))) $) NIL)) (-3840 (((-1157 $) $ (-813 (-1161))) NIL) (((-1157 |#1|) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-3528 (((-763) $) NIL) (((-763) $ (-634 (-813 (-1161)))) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3045 (($ $) NIL (|has| |#1| (-453)))) (-3498 (((-420 $) $) NIL (|has| |#1| (-453)))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3988 (($ $) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-813 (-1161)) "failed") $) NIL) (((-3 (-1161) "failed") $) NIL) (((-3 (-1113 |#1| (-1161)) "failed") $) NIL)) (-2857 ((|#1| $) NIL) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-813 (-1161)) $) NIL) (((-1161) $) NIL) (((-1113 |#1| (-1161)) $) NIL)) (-2910 (($ $ $ (-813 (-1161))) NIL (|has| |#1| (-172)))) (-2116 (($ $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1998 (($ $) NIL (|has| |#1| (-453))) (($ $ (-813 (-1161))) NIL (|has| |#1| (-453)))) (-2110 (((-634 $) $) NIL)) (-2197 (((-121) $) NIL (|has| |#1| (-904)))) (-2453 (($ $ |#1| (-534 (-813 (-1161))) $) NIL)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-813 (-1161)) (-881 (-381))) (|has| |#1| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-813 (-1161)) (-881 (-568))) (|has| |#1| (-881 (-568)))))) (-1844 (((-763) $ (-1161)) NIL) (((-763) $) NIL)) (-1598 (((-121) $) NIL)) (-3971 (((-763) $) NIL)) (-2053 (($ (-1157 |#1|) (-813 (-1161))) NIL) (($ (-1157 $) (-813 (-1161))) NIL)) (-3062 (((-634 $) $) NIL)) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| (-534 (-813 (-1161)))) NIL) (($ $ (-813 (-1161)) (-763)) NIL) (($ $ (-634 (-813 (-1161))) (-634 (-763))) NIL)) (-1438 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $ (-813 (-1161))) NIL)) (-3524 (((-534 (-813 (-1161))) $) NIL) (((-763) $ (-813 (-1161))) NIL) (((-634 (-763)) $ (-634 (-813 (-1161)))) NIL)) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-1865 (($ (-1 (-534 (-813 (-1161))) (-534 (-813 (-1161)))) $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-3029 (((-1 $ (-763)) (-1161)) NIL) (((-1 $ (-763)) $) NIL (|has| |#1| (-225)))) (-2817 (((-3 (-813 (-1161)) "failed") $) NIL)) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-1692 (((-813 (-1161)) $) NIL)) (-2498 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-1893 (((-1143) $) NIL)) (-4448 (((-121) $) NIL)) (-4362 (((-3 (-634 $) "failed") $) NIL)) (-2112 (((-3 (-634 $) "failed") $) NIL)) (-2617 (((-3 (-2 (|:| |var| (-813 (-1161))) (|:| -3483 (-763))) "failed") $) NIL)) (-1484 (($ $) NIL)) (-4025 (((-1108) $) NIL)) (-2088 (((-121) $) NIL)) (-2093 ((|#1| $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-453)))) (-2723 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3850 (((-420 $) $) NIL (|has| |#1| (-904)))) (-2597 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-813 (-1161)) |#1|) NIL) (($ $ (-634 (-813 (-1161))) (-634 |#1|)) NIL) (($ $ (-813 (-1161)) $) NIL) (($ $ (-634 (-813 (-1161))) (-634 $)) NIL) (($ $ (-1161) $) NIL (|has| |#1| (-225))) (($ $ (-634 (-1161)) (-634 $)) NIL (|has| |#1| (-225))) (($ $ (-1161) |#1|) NIL (|has| |#1| (-225))) (($ $ (-634 (-1161)) (-634 |#1|)) NIL (|has| |#1| (-225)))) (-3440 (($ $ (-813 (-1161))) NIL (|has| |#1| (-172)))) (-4191 (($ $ (-813 (-1161))) NIL) (($ $ (-634 (-813 (-1161)))) NIL) (($ $ (-813 (-1161)) (-763)) NIL) (($ $ (-634 (-813 (-1161))) (-634 (-763))) NIL) (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-2775 (((-634 (-1161)) $) NIL)) (-1836 (((-534 (-813 (-1161))) $) NIL) (((-763) $ (-813 (-1161))) NIL) (((-634 (-763)) $ (-634 (-813 (-1161)))) NIL) (((-763) $ (-1161)) NIL)) (-4280 (((-887 (-381)) $) NIL (-12 (|has| (-813 (-1161)) (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-813 (-1161)) (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-813 (-1161)) (-609 (-541))) (|has| |#1| (-609 (-541)))))) (-1364 ((|#1| $) NIL (|has| |#1| (-453))) (($ $ (-813 (-1161))) NIL (|has| |#1| (-453)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#1| (-904))))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL) (($ (-813 (-1161))) NIL) (($ (-1161)) NIL) (($ (-1113 |#1| (-1161))) NIL) (($ (-409 (-568))) NIL (-2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#1| (-558)))) (-3304 (((-634 |#1|) $) NIL)) (-2079 ((|#1| $ (-534 (-813 (-1161)))) NIL) (($ $ (-813 (-1161)) (-763)) NIL) (($ $ (-634 (-813 (-1161))) (-634 (-763))) NIL)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-3425 (((-763)) NIL)) (-3925 (($ $ $ (-763)) NIL (|has| |#1| (-172)))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $ (-813 (-1161))) NIL) (($ $ (-634 (-813 (-1161)))) NIL) (($ $ (-813 (-1161)) (-763)) NIL) (($ $ (-634 (-813 (-1161))) (-634 (-763))) NIL) (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
 (((-811 |#1|) (-13 (-246 |#1| (-1161) (-813 (-1161)) (-534 (-813 (-1161)))) (-1037 (-1113 |#1| (-1161)))) (-1047)) (T -811)) 
 NIL 
 (-13 (-246 |#1| (-1161) (-813 (-1161)) (-534 (-813 (-1161)))) (-1037 (-1113 |#1| (-1161)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#2| (-365)))) (-2227 (($ $) NIL (|has| |#2| (-365)))) (-1573 (((-121) $) NIL (|has| |#2| (-365)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL (|has| |#2| (-365)))) (-1678 (((-420 $) $) NIL (|has| |#2| (-365)))) (-1497 (((-121) $ $) NIL (|has| |#2| (-365)))) (-2671 (($) NIL T CONST)) (-2401 (($ $ $) NIL (|has| |#2| (-365)))) (-2925 (((-3 $ "failed") $) NIL)) (-2412 (($ $ $) NIL (|has| |#2| (-365)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| |#2| (-365)))) (-3927 (((-121) $) NIL (|has| |#2| (-365)))) (-2735 (((-121) $) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#2| (-365)))) (-2495 (($ (-634 $)) NIL (|has| |#2| (-365))) (($ $ $) NIL (|has| |#2| (-365)))) (-4487 (((-1143) $) NIL)) (-2081 (($ $) 20 (|has| |#2| (-365)))) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#2| (-365)))) (-2721 (($ (-634 $)) NIL (|has| |#2| (-365))) (($ $ $) NIL (|has| |#2| (-365)))) (-3848 (((-420 $) $) NIL (|has| |#2| (-365)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#2| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#2| (-365)))) (-2595 (((-3 $ "failed") $ $) NIL (|has| |#2| (-365)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#2| (-365)))) (-2709 (((-763) $) NIL (|has| |#2| (-365)))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#2| (-365)))) (-4189 (($ $ (-763)) NIL) (($ $) 13)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#2|) 10) ((|#2| $) 11) (($ (-409 (-568))) NIL (|has| |#2| (-365))) (($ $) NIL (|has| |#2| (-365)))) (-4078 (((-763)) NIL)) (-1826 (((-121) $ $) NIL (|has| |#2| (-365)))) (-1887 (($ $ (-763)) NIL) (($ $ (-917)) NIL) (($ $ (-568)) NIL (|has| |#2| (-365)))) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $ (-763)) NIL) (($ $) NIL)) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ $) 15 (|has| |#2| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-763)) NIL) (($ $ (-917)) NIL) (($ $ (-568)) 18 (|has| |#2| (-365)))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ $) NIL) (($ (-409 (-568)) $) NIL (|has| |#2| (-365))) (($ $ (-409 (-568))) NIL (|has| |#2| (-365))))) 
-(((-812 |#1| |#2| |#3|) (-13 (-120 $ $) (-225) (-10 -8 (IF (|has| |#2| (-365)) (-6 (-365)) |noBranch|) (-15 -2745 ($ |#2|)) (-15 -2745 (|#2| $)))) (-1090) (-895 |#1|) |#1|) (T -812)) 
-((-2745 (*1 *1 *2) (-12 (-4 *3 (-1090)) (-14 *4 *3) (-5 *1 (-812 *3 *2 *4)) (-4 *2 (-895 *3)))) (-2745 (*1 *2 *1) (-12 (-4 *2 (-895 *3)) (-5 *1 (-812 *3 *2 *4)) (-4 *3 (-1090)) (-14 *4 *3)))) 
-(-13 (-120 $ $) (-225) (-10 -8 (IF (|has| |#2| (-365)) (-6 (-365)) |noBranch|) (-15 -2745 ($ |#2|)) (-15 -2745 (|#2| $)))) 
-((-2447 (((-121) $ $) NIL)) (-1551 (((-763) $) NIL)) (-1305 ((|#1| $) 10)) (-3666 (((-3 |#1| "failed") $) NIL)) (-2854 ((|#1| $) NIL)) (-4477 (((-763) $) 11)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-4300 (($ |#1| (-763)) 9)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-4189 (($ $) NIL) (($ $ (-763)) NIL)) (-2745 (((-850) $) NIL) (($ |#1|) NIL)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#2| (-365)))) (-3661 (($ $) NIL (|has| |#2| (-365)))) (-4426 (((-121) $) NIL (|has| |#2| (-365)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL (|has| |#2| (-365)))) (-3498 (((-420 $) $) NIL (|has| |#2| (-365)))) (-2589 (((-121) $ $) NIL (|has| |#2| (-365)))) (-4490 (($) NIL T CONST)) (-2403 (($ $ $) NIL (|has| |#2| (-365)))) (-2902 (((-3 $ "failed") $) NIL)) (-2414 (($ $ $) NIL (|has| |#2| (-365)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| |#2| (-365)))) (-2197 (((-121) $) NIL (|has| |#2| (-365)))) (-1598 (((-121) $) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#2| (-365)))) (-2498 (($ (-634 $)) NIL (|has| |#2| (-365))) (($ $ $) NIL (|has| |#2| (-365)))) (-1893 (((-1143) $) NIL)) (-2083 (($ $) 20 (|has| |#2| (-365)))) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#2| (-365)))) (-2723 (($ (-634 $)) NIL (|has| |#2| (-365))) (($ $ $) NIL (|has| |#2| (-365)))) (-3850 (((-420 $) $) NIL (|has| |#2| (-365)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#2| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#2| (-365)))) (-2597 (((-3 $ "failed") $ $) NIL (|has| |#2| (-365)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#2| (-365)))) (-1466 (((-763) $) NIL (|has| |#2| (-365)))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#2| (-365)))) (-4191 (($ $ (-763)) NIL) (($ $) 13)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#2|) 10) ((|#2| $) 11) (($ (-409 (-568))) NIL (|has| |#2| (-365))) (($ $) NIL (|has| |#2| (-365)))) (-3425 (((-763)) NIL)) (-2273 (((-121) $ $) NIL (|has| |#2| (-365)))) (-1889 (($ $ (-763)) NIL) (($ $ (-917)) NIL) (($ $ (-568)) NIL (|has| |#2| (-365)))) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $ (-763)) NIL) (($ $) NIL)) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ $) 15 (|has| |#2| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-763)) NIL) (($ $ (-917)) NIL) (($ $ (-568)) 18 (|has| |#2| (-365)))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ $) NIL) (($ (-409 (-568)) $) NIL (|has| |#2| (-365))) (($ $ (-409 (-568))) NIL (|has| |#2| (-365))))) 
+(((-812 |#1| |#2| |#3|) (-13 (-120 $ $) (-225) (-10 -8 (IF (|has| |#2| (-365)) (-6 (-365)) |noBranch|) (-15 -2747 ($ |#2|)) (-15 -2747 (|#2| $)))) (-1090) (-895 |#1|) |#1|) (T -812)) 
+((-2747 (*1 *1 *2) (-12 (-4 *3 (-1090)) (-14 *4 *3) (-5 *1 (-812 *3 *2 *4)) (-4 *2 (-895 *3)))) (-2747 (*1 *2 *1) (-12 (-4 *2 (-895 *3)) (-5 *1 (-812 *3 *2 *4)) (-4 *3 (-1090)) (-14 *4 *3)))) 
+(-13 (-120 $ $) (-225) (-10 -8 (IF (|has| |#2| (-365)) (-6 (-365)) |noBranch|) (-15 -2747 ($ |#2|)) (-15 -2747 (|#2| $)))) 
+((-2449 (((-121) $ $) NIL)) (-4308 (((-763) $) NIL)) (-3325 ((|#1| $) 10)) (-3668 (((-3 |#1| "failed") $) NIL)) (-2857 ((|#1| $) NIL)) (-1844 (((-763) $) 11)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-3029 (($ |#1| (-763)) 9)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-4191 (($ $) NIL) (($ $ (-763)) NIL)) (-2747 (((-850) $) NIL) (($ |#1|) NIL)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) NIL))) 
 (((-813 |#1|) (-262 |#1|) (-842)) (T -813)) 
 NIL 
 (-262 |#1|) 
-((-2447 (((-121) $ $) NIL)) (-3595 (((-634 |#1|) $) 34)) (-3983 (((-763) $) NIL)) (-2671 (($) NIL T CONST)) (-2628 (((-3 $ "failed") $ $) 21) (((-3 $ "failed") $ |#1|) 19)) (-3666 (((-3 |#1| "failed") $) NIL)) (-2854 ((|#1| $) NIL)) (-3935 (($ $) 36)) (-2925 (((-3 $ "failed") $) NIL)) (-1715 (((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $) NIL)) (-2735 (((-121) $) NIL)) (-2882 ((|#1| $ (-568)) NIL)) (-2408 (((-763) $ (-568)) NIL)) (-2407 (($ $) 40)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-2532 (((-3 $ "failed") $ $) 20) (((-3 $ "failed") $ |#1|) 16)) (-4081 (((-121) $ $) 38)) (-3678 (((-763) $) 30)) (-4487 (((-1143) $) NIL)) (-2403 (($ $ $) NIL)) (-3078 (($ $ $) NIL)) (-4022 (((-1108) $) NIL)) (-3876 ((|#1| $) 35)) (-3276 (((-634 (-2 (|:| |gen| |#1|) (|:| -1892 (-763)))) $) NIL)) (-3210 (((-3 (-2 (|:| |lm| (-3 $ "failed")) (|:| |rm| (-3 $ "failed"))) "failed") $ $) 24)) (-2745 (((-850) $) NIL) (($ |#1|) NIL)) (-1887 (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (-1556 (($) 14 T CONST)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 39)) (** (($ $ (-763)) NIL) (($ $ (-917)) NIL) (($ |#1| (-763)) NIL)) (* (($ $ $) NIL) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
-(((-814 |#1|) (-13 (-838) (-1037 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-763))) (-15 -3876 (|#1| $)) (-15 -3935 ($ $)) (-15 -2407 ($ $)) (-15 -4081 ((-121) $ $)) (-15 -3078 ($ $ $)) (-15 -2403 ($ $ $)) (-15 -2532 ((-3 $ "failed") $ $)) (-15 -2628 ((-3 $ "failed") $ $)) (-15 -2532 ((-3 $ "failed") $ |#1|)) (-15 -2628 ((-3 $ "failed") $ |#1|)) (-15 -3210 ((-3 (-2 (|:| |lm| (-3 $ "failed")) (|:| |rm| (-3 $ "failed"))) "failed") $ $)) (-15 -1715 ((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $)) (-15 -3983 ((-763) $)) (-15 -2408 ((-763) $ (-568))) (-15 -2882 (|#1| $ (-568))) (-15 -3276 ((-634 (-2 (|:| |gen| |#1|) (|:| -1892 (-763)))) $)) (-15 -3678 ((-763) $)) (-15 -3595 ((-634 |#1|) $)))) (-842)) (T -814)) 
-((* (*1 *1 *2 *1) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) (* (*1 *1 *1 *2) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) (** (*1 *1 *2 *3) (-12 (-5 *3 (-763)) (-5 *1 (-814 *2)) (-4 *2 (-842)))) (-3876 (*1 *2 *1) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) (-3935 (*1 *1 *1) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) (-2407 (*1 *1 *1) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) (-4081 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-814 *3)) (-4 *3 (-842)))) (-3078 (*1 *1 *1 *1) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) (-2403 (*1 *1 *1 *1) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) (-2532 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) (-2628 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) (-2532 (*1 *1 *1 *2) (|partial| -12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) (-2628 (*1 *1 *1 *2) (|partial| -12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) (-3210 (*1 *2 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |lm| (-3 (-814 *3) "failed")) (|:| |rm| (-3 (-814 *3) "failed")))) (-5 *1 (-814 *3)) (-4 *3 (-842)))) (-1715 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |lm| (-814 *3)) (|:| |mm| (-814 *3)) (|:| |rm| (-814 *3)))) (-5 *1 (-814 *3)) (-4 *3 (-842)))) (-3983 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-814 *3)) (-4 *3 (-842)))) (-2408 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-763)) (-5 *1 (-814 *4)) (-4 *4 (-842)))) (-2882 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-814 *2)) (-4 *2 (-842)))) (-3276 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1892 (-763))))) (-5 *1 (-814 *3)) (-4 *3 (-842)))) (-3678 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-814 *3)) (-4 *3 (-842)))) (-3595 (*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-814 *3)) (-4 *3 (-842))))) 
-(-13 (-838) (-1037 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-763))) (-15 -3876 (|#1| $)) (-15 -3935 ($ $)) (-15 -2407 ($ $)) (-15 -4081 ((-121) $ $)) (-15 -3078 ($ $ $)) (-15 -2403 ($ $ $)) (-15 -2532 ((-3 $ "failed") $ $)) (-15 -2628 ((-3 $ "failed") $ $)) (-15 -2532 ((-3 $ "failed") $ |#1|)) (-15 -2628 ((-3 $ "failed") $ |#1|)) (-15 -3210 ((-3 (-2 (|:| |lm| (-3 $ "failed")) (|:| |rm| (-3 $ "failed"))) "failed") $ $)) (-15 -1715 ((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $)) (-15 -3983 ((-763) $)) (-15 -2408 ((-763) $ (-568))) (-15 -2882 (|#1| $ (-568))) (-15 -3276 ((-634 (-2 (|:| |gen| |#1|) (|:| -1892 (-763)))) $)) (-15 -3678 ((-763) $)) (-15 -3595 ((-634 |#1|) $)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-3134 (((-3 $ "failed") $ $) 18)) (-3662 (((-568) $) 52)) (-2671 (($) 16 T CONST)) (-2925 (((-3 $ "failed") $) 33)) (-2033 (((-121) $) 50)) (-2735 (((-121) $) 30)) (-2245 (((-121) $) 51)) (-2521 (($ $ $) 49)) (-3268 (($ $ $) 48)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2595 (((-3 $ "failed") $ $) 41)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42)) (-4078 (((-763)) 28)) (-1826 (((-121) $ $) 38)) (-2897 (($ $) 53)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1751 (((-121) $ $) 46)) (-1738 (((-121) $ $) 45)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 47)) (-1732 (((-121) $ $) 44)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
+((-2449 (((-121) $ $) NIL)) (-2981 (((-634 |#1|) $) 34)) (-3986 (((-763) $) NIL)) (-4490 (($) NIL T CONST)) (-4242 (((-3 $ "failed") $ $) 21) (((-3 $ "failed") $ |#1|) 19)) (-3668 (((-3 |#1| "failed") $) NIL)) (-2857 ((|#1| $) NIL)) (-3936 (($ $) 36)) (-2902 (((-3 $ "failed") $) NIL)) (-3690 (((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $) NIL)) (-1598 (((-121) $) NIL)) (-4167 ((|#1| $ (-568)) NIL)) (-2315 (((-763) $ (-568)) NIL)) (-2310 (($ $) 40)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-1797 (((-3 $ "failed") $ $) 20) (((-3 $ "failed") $ |#1|) 16)) (-3451 (((-121) $ $) 38)) (-3680 (((-763) $) 30)) (-1893 (((-1143) $) NIL)) (-2289 (($ $ $) NIL)) (-2400 (($ $ $) NIL)) (-4025 (((-1108) $) NIL)) (-3877 ((|#1| $) 35)) (-2075 (((-634 (-2 (|:| |gen| |#1|) (|:| -1894 (-763)))) $) NIL)) (-1854 (((-3 (-2 (|:| |lm| (-3 $ "failed")) (|:| |rm| (-3 $ "failed"))) "failed") $ $) 24)) (-2747 (((-850) $) NIL) (($ |#1|) NIL)) (-1889 (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (-1557 (($) 14 T CONST)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 39)) (** (($ $ (-763)) NIL) (($ $ (-917)) NIL) (($ |#1| (-763)) NIL)) (* (($ $ $) NIL) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
+(((-814 |#1|) (-13 (-838) (-1037 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-763))) (-15 -3877 (|#1| $)) (-15 -3936 ($ $)) (-15 -2310 ($ $)) (-15 -3451 ((-121) $ $)) (-15 -2400 ($ $ $)) (-15 -2289 ($ $ $)) (-15 -1797 ((-3 $ "failed") $ $)) (-15 -4242 ((-3 $ "failed") $ $)) (-15 -1797 ((-3 $ "failed") $ |#1|)) (-15 -4242 ((-3 $ "failed") $ |#1|)) (-15 -1854 ((-3 (-2 (|:| |lm| (-3 $ "failed")) (|:| |rm| (-3 $ "failed"))) "failed") $ $)) (-15 -3690 ((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $)) (-15 -3986 ((-763) $)) (-15 -2315 ((-763) $ (-568))) (-15 -4167 (|#1| $ (-568))) (-15 -2075 ((-634 (-2 (|:| |gen| |#1|) (|:| -1894 (-763)))) $)) (-15 -3680 ((-763) $)) (-15 -2981 ((-634 |#1|) $)))) (-842)) (T -814)) 
+((* (*1 *1 *2 *1) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) (* (*1 *1 *1 *2) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) (** (*1 *1 *2 *3) (-12 (-5 *3 (-763)) (-5 *1 (-814 *2)) (-4 *2 (-842)))) (-3877 (*1 *2 *1) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) (-3936 (*1 *1 *1) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) (-2310 (*1 *1 *1) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) (-3451 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-814 *3)) (-4 *3 (-842)))) (-2400 (*1 *1 *1 *1) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) (-2289 (*1 *1 *1 *1) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) (-1797 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) (-4242 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) (-1797 (*1 *1 *1 *2) (|partial| -12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) (-4242 (*1 *1 *1 *2) (|partial| -12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) (-1854 (*1 *2 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |lm| (-3 (-814 *3) "failed")) (|:| |rm| (-3 (-814 *3) "failed")))) (-5 *1 (-814 *3)) (-4 *3 (-842)))) (-3690 (*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |lm| (-814 *3)) (|:| |mm| (-814 *3)) (|:| |rm| (-814 *3)))) (-5 *1 (-814 *3)) (-4 *3 (-842)))) (-3986 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-814 *3)) (-4 *3 (-842)))) (-2315 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-763)) (-5 *1 (-814 *4)) (-4 *4 (-842)))) (-4167 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-814 *2)) (-4 *2 (-842)))) (-2075 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1894 (-763))))) (-5 *1 (-814 *3)) (-4 *3 (-842)))) (-3680 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-814 *3)) (-4 *3 (-842)))) (-2981 (*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-814 *3)) (-4 *3 (-842))))) 
+(-13 (-838) (-1037 |#1|) (-10 -8 (-15 * ($ |#1| $)) (-15 * ($ $ |#1|)) (-15 ** ($ |#1| (-763))) (-15 -3877 (|#1| $)) (-15 -3936 ($ $)) (-15 -2310 ($ $)) (-15 -3451 ((-121) $ $)) (-15 -2400 ($ $ $)) (-15 -2289 ($ $ $)) (-15 -1797 ((-3 $ "failed") $ $)) (-15 -4242 ((-3 $ "failed") $ $)) (-15 -1797 ((-3 $ "failed") $ |#1|)) (-15 -4242 ((-3 $ "failed") $ |#1|)) (-15 -1854 ((-3 (-2 (|:| |lm| (-3 $ "failed")) (|:| |rm| (-3 $ "failed"))) "failed") $ $)) (-15 -3690 ((-2 (|:| |lm| $) (|:| |mm| $) (|:| |rm| $)) $ $)) (-15 -3986 ((-763) $)) (-15 -2315 ((-763) $ (-568))) (-15 -4167 (|#1| $ (-568))) (-15 -2075 ((-634 (-2 (|:| |gen| |#1|) (|:| -1894 (-763)))) $)) (-15 -3680 ((-763) $)) (-15 -2981 ((-634 |#1|) $)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-2689 (((-3 $ "failed") $ $) 18)) (-3337 (((-568) $) 52)) (-4490 (($) 16 T CONST)) (-2902 (((-3 $ "failed") $) 33)) (-1436 (((-121) $) 50)) (-1598 (((-121) $) 30)) (-2859 (((-121) $) 51)) (-1732 (($ $ $) 49)) (-2047 (($ $ $) 48)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2597 (((-3 $ "failed") $ $) 41)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42)) (-3425 (((-763)) 28)) (-2273 (((-121) $ $) 38)) (-2811 (($ $) 53)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1753 (((-121) $ $) 46)) (-1740 (((-121) $ $) 45)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 47)) (-1734 (((-121) $ $) 44)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
 (((-815) (-1275)) (T -815)) 
 NIL 
 (-13 (-558) (-840)) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-105) . T) ((-120 $ $) . T) ((-137) . T) ((-608 (-850)) . T) ((-172) . T) ((-285) . T) ((-558) . T) ((-637 $) . T) ((-707 $) . T) ((-716) . T) ((-786) . T) ((-787) . T) ((-789) . T) ((-790) . T) ((-840) . T) ((-842) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-2941 (($ (-1108)) 7)) (-2263 (((-121) $ (-1143) (-1108)) 15)) (-2461 (((-817) $) 12)) (-2728 (((-817) $) 11)) (-2885 (((-1249) $) 9)) (-1460 (((-121) $ (-1108)) 16))) 
-(((-816) (-10 -8 (-15 -2941 ($ (-1108))) (-15 -2885 ((-1249) $)) (-15 -2728 ((-817) $)) (-15 -2461 ((-817) $)) (-15 -2263 ((-121) $ (-1143) (-1108))) (-15 -1460 ((-121) $ (-1108))))) (T -816)) 
-((-1460 (*1 *2 *1 *3) (-12 (-5 *3 (-1108)) (-5 *2 (-121)) (-5 *1 (-816)))) (-2263 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-1108)) (-5 *2 (-121)) (-5 *1 (-816)))) (-2461 (*1 *2 *1) (-12 (-5 *2 (-817)) (-5 *1 (-816)))) (-2728 (*1 *2 *1) (-12 (-5 *2 (-817)) (-5 *1 (-816)))) (-2885 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-816)))) (-2941 (*1 *1 *2) (-12 (-5 *2 (-1108)) (-5 *1 (-816))))) 
-(-10 -8 (-15 -2941 ($ (-1108))) (-15 -2885 ((-1249) $)) (-15 -2728 ((-817) $)) (-15 -2461 ((-817) $)) (-15 -2263 ((-121) $ (-1143) (-1108))) (-15 -1460 ((-121) $ (-1108)))) 
-((-2755 (((-1249) $ (-818)) 12)) (-3540 (((-1249) $ (-1161)) 32)) (-4212 (((-1249) $ (-1143) (-1143)) 34)) (-4141 (((-1249) $ (-1143)) 33)) (-4426 (((-1249) $) 19)) (-1381 (((-1249) $ (-568)) 28)) (-3954 (((-1249) $ (-215)) 30)) (-2370 (((-1249) $) 18)) (-2123 (((-1249) $) 26)) (-2859 (((-1249) $) 25)) (-3120 (((-1249) $) 23)) (-1464 (((-1249) $) 24)) (-1333 (((-1249) $) 22)) (-2013 (((-1249) $) 21)) (-3469 (((-1249) $) 20)) (-3587 (((-1249) $) 16)) (-2647 (((-1249) $) 17)) (-3098 (((-1249) $) 15)) (-2546 (((-1249) $) 14)) (-2350 (((-1249) $) 13)) (-3711 (($ (-1143) (-818)) 9)) (-2399 (($ (-1143) (-1143) (-818)) 8)) (-2575 (((-1161) $) 51)) (-2084 (((-1161) $) 55)) (-3784 (((-2 (|:| |cd| (-1143)) (|:| -3391 (-1143))) $) 54)) (-3045 (((-1143) $) 52)) (-2089 (((-1249) $) 41)) (-2964 (((-568) $) 49)) (-4438 (((-215) $) 50)) (-3072 (((-1249) $) 40)) (-3070 (((-1249) $) 48)) (-2206 (((-1249) $) 47)) (-3719 (((-1249) $) 45)) (-2308 (((-1249) $) 46)) (-2098 (((-1249) $) 44)) (-1605 (((-1249) $) 43)) (-3515 (((-1249) $) 42)) (-4254 (((-1249) $) 38)) (-2305 (((-1249) $) 39)) (-3479 (((-1249) $) 37)) (-3315 (((-1249) $) 36)) (-1906 (((-1249) $) 35)) (-2050 (((-1249) $) 11))) 
-(((-817) (-10 -8 (-15 -2399 ($ (-1143) (-1143) (-818))) (-15 -3711 ($ (-1143) (-818))) (-15 -2050 ((-1249) $)) (-15 -2755 ((-1249) $ (-818))) (-15 -2350 ((-1249) $)) (-15 -2546 ((-1249) $)) (-15 -3098 ((-1249) $)) (-15 -3587 ((-1249) $)) (-15 -2647 ((-1249) $)) (-15 -2370 ((-1249) $)) (-15 -4426 ((-1249) $)) (-15 -3469 ((-1249) $)) (-15 -2013 ((-1249) $)) (-15 -1333 ((-1249) $)) (-15 -3120 ((-1249) $)) (-15 -1464 ((-1249) $)) (-15 -2859 ((-1249) $)) (-15 -2123 ((-1249) $)) (-15 -1381 ((-1249) $ (-568))) (-15 -3954 ((-1249) $ (-215))) (-15 -3540 ((-1249) $ (-1161))) (-15 -4141 ((-1249) $ (-1143))) (-15 -4212 ((-1249) $ (-1143) (-1143))) (-15 -1906 ((-1249) $)) (-15 -3315 ((-1249) $)) (-15 -3479 ((-1249) $)) (-15 -4254 ((-1249) $)) (-15 -2305 ((-1249) $)) (-15 -3072 ((-1249) $)) (-15 -2089 ((-1249) $)) (-15 -3515 ((-1249) $)) (-15 -1605 ((-1249) $)) (-15 -2098 ((-1249) $)) (-15 -3719 ((-1249) $)) (-15 -2308 ((-1249) $)) (-15 -2206 ((-1249) $)) (-15 -3070 ((-1249) $)) (-15 -2964 ((-568) $)) (-15 -4438 ((-215) $)) (-15 -2575 ((-1161) $)) (-15 -3045 ((-1143) $)) (-15 -3784 ((-2 (|:| |cd| (-1143)) (|:| -3391 (-1143))) $)) (-15 -2084 ((-1161) $)))) (T -817)) 
-((-2084 (*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-817)))) (-3784 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |cd| (-1143)) (|:| -3391 (-1143)))) (-5 *1 (-817)))) (-3045 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-817)))) (-2575 (*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-817)))) (-4438 (*1 *2 *1) (-12 (-5 *2 (-215)) (-5 *1 (-817)))) (-2964 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-817)))) (-3070 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-2206 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-2308 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-3719 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-2098 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-1605 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-3515 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-2089 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-3072 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-2305 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-4254 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-3479 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-3315 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-1906 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-4212 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-817)))) (-4141 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-817)))) (-3540 (*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-817)))) (-3954 (*1 *2 *1 *3) (-12 (-5 *3 (-215)) (-5 *2 (-1249)) (-5 *1 (-817)))) (-1381 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-817)))) (-2123 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-2859 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-1464 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-3120 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-1333 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-2013 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-3469 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-4426 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-2370 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-2647 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-3587 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-3098 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-2546 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-2350 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-2755 (*1 *2 *1 *3) (-12 (-5 *3 (-818)) (-5 *2 (-1249)) (-5 *1 (-817)))) (-2050 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-3711 (*1 *1 *2 *3) (-12 (-5 *2 (-1143)) (-5 *3 (-818)) (-5 *1 (-817)))) (-2399 (*1 *1 *2 *2 *3) (-12 (-5 *2 (-1143)) (-5 *3 (-818)) (-5 *1 (-817))))) 
-(-10 -8 (-15 -2399 ($ (-1143) (-1143) (-818))) (-15 -3711 ($ (-1143) (-818))) (-15 -2050 ((-1249) $)) (-15 -2755 ((-1249) $ (-818))) (-15 -2350 ((-1249) $)) (-15 -2546 ((-1249) $)) (-15 -3098 ((-1249) $)) (-15 -3587 ((-1249) $)) (-15 -2647 ((-1249) $)) (-15 -2370 ((-1249) $)) (-15 -4426 ((-1249) $)) (-15 -3469 ((-1249) $)) (-15 -2013 ((-1249) $)) (-15 -1333 ((-1249) $)) (-15 -3120 ((-1249) $)) (-15 -1464 ((-1249) $)) (-15 -2859 ((-1249) $)) (-15 -2123 ((-1249) $)) (-15 -1381 ((-1249) $ (-568))) (-15 -3954 ((-1249) $ (-215))) (-15 -3540 ((-1249) $ (-1161))) (-15 -4141 ((-1249) $ (-1143))) (-15 -4212 ((-1249) $ (-1143) (-1143))) (-15 -1906 ((-1249) $)) (-15 -3315 ((-1249) $)) (-15 -3479 ((-1249) $)) (-15 -4254 ((-1249) $)) (-15 -2305 ((-1249) $)) (-15 -3072 ((-1249) $)) (-15 -2089 ((-1249) $)) (-15 -3515 ((-1249) $)) (-15 -1605 ((-1249) $)) (-15 -2098 ((-1249) $)) (-15 -3719 ((-1249) $)) (-15 -2308 ((-1249) $)) (-15 -2206 ((-1249) $)) (-15 -3070 ((-1249) $)) (-15 -2964 ((-568) $)) (-15 -4438 ((-215) $)) (-15 -2575 ((-1161) $)) (-15 -3045 ((-1143) $)) (-15 -3784 ((-2 (|:| |cd| (-1143)) (|:| -3391 (-1143))) $)) (-15 -2084 ((-1161) $))) 
-((-2447 (((-121) $ $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 12)) (-1356 (($) 15)) (-1954 (($) 13)) (-1570 (($) 16)) (-2095 (($) 14)) (-1717 (((-121) $ $) 8))) 
-(((-818) (-13 (-1090) (-10 -8 (-15 -1954 ($)) (-15 -1356 ($)) (-15 -1570 ($)) (-15 -2095 ($))))) (T -818)) 
-((-1954 (*1 *1) (-5 *1 (-818))) (-1356 (*1 *1) (-5 *1 (-818))) (-1570 (*1 *1) (-5 *1 (-818))) (-2095 (*1 *1) (-5 *1 (-818)))) 
-(-13 (-1090) (-10 -8 (-15 -1954 ($)) (-15 -1356 ($)) (-15 -1570 ($)) (-15 -2095 ($)))) 
-((-2447 (((-121) $ $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 21) (($ (-1161)) 17)) (-1312 (((-121) $) 10)) (-1762 (((-121) $) 9)) (-3186 (((-121) $) 11)) (-4489 (((-121) $) 8)) (-1717 (((-121) $ $) 19))) 
-(((-819) (-13 (-1090) (-10 -8 (-15 -2745 ($ (-1161))) (-15 -4489 ((-121) $)) (-15 -1762 ((-121) $)) (-15 -1312 ((-121) $)) (-15 -3186 ((-121) $))))) (T -819)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-819)))) (-4489 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-819)))) (-1762 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-819)))) (-1312 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-819)))) (-3186 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-819))))) 
-(-13 (-1090) (-10 -8 (-15 -2745 ($ (-1161))) (-15 -4489 ((-121) $)) (-15 -1762 ((-121) $)) (-15 -1312 ((-121) $)) (-15 -3186 ((-121) $)))) 
-((-2447 (((-121) $ $) NIL)) (-3023 (($ (-819) (-634 (-1161))) 24)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-1574 (((-819) $) 25)) (-4374 (((-634 (-1161)) $) 26)) (-2745 (((-850) $) 23)) (-1717 (((-121) $ $) NIL))) 
-(((-820) (-13 (-1090) (-10 -8 (-15 -1574 ((-819) $)) (-15 -4374 ((-634 (-1161)) $)) (-15 -3023 ($ (-819) (-634 (-1161))))))) (T -820)) 
-((-1574 (*1 *2 *1) (-12 (-5 *2 (-819)) (-5 *1 (-820)))) (-4374 (*1 *2 *1) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-820)))) (-3023 (*1 *1 *2 *3) (-12 (-5 *2 (-819)) (-5 *3 (-634 (-1161))) (-5 *1 (-820))))) 
-(-13 (-1090) (-10 -8 (-15 -1574 ((-819) $)) (-15 -4374 ((-634 (-1161)) $)) (-15 -3023 ($ (-819) (-634 (-1161)))))) 
-((-3754 (((-1249) (-817) (-310 |#1|) (-121)) 22) (((-1249) (-817) (-310 |#1|)) 76) (((-1143) (-310 |#1|) (-121)) 75) (((-1143) (-310 |#1|)) 74))) 
-(((-821 |#1|) (-10 -7 (-15 -3754 ((-1143) (-310 |#1|))) (-15 -3754 ((-1143) (-310 |#1|) (-121))) (-15 -3754 ((-1249) (-817) (-310 |#1|))) (-15 -3754 ((-1249) (-817) (-310 |#1|) (-121)))) (-13 (-823) (-842) (-1047))) (T -821)) 
-((-3754 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-817)) (-5 *4 (-310 *6)) (-5 *5 (-121)) (-4 *6 (-13 (-823) (-842) (-1047))) (-5 *2 (-1249)) (-5 *1 (-821 *6)))) (-3754 (*1 *2 *3 *4) (-12 (-5 *3 (-817)) (-5 *4 (-310 *5)) (-4 *5 (-13 (-823) (-842) (-1047))) (-5 *2 (-1249)) (-5 *1 (-821 *5)))) (-3754 (*1 *2 *3 *4) (-12 (-5 *3 (-310 *5)) (-5 *4 (-121)) (-4 *5 (-13 (-823) (-842) (-1047))) (-5 *2 (-1143)) (-5 *1 (-821 *5)))) (-3754 (*1 *2 *3) (-12 (-5 *3 (-310 *4)) (-4 *4 (-13 (-823) (-842) (-1047))) (-5 *2 (-1143)) (-5 *1 (-821 *4))))) 
-(-10 -7 (-15 -3754 ((-1143) (-310 |#1|))) (-15 -3754 ((-1143) (-310 |#1|) (-121))) (-15 -3754 ((-1249) (-817) (-310 |#1|))) (-15 -3754 ((-1249) (-817) (-310 |#1|) (-121)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-2114 (($ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3506 ((|#1| $) 10)) (-4192 (($ |#1|) 9)) (-2735 (((-121) $) NIL)) (-2047 (($ |#2| (-763)) NIL)) (-2144 (((-763) $) NIL)) (-2102 ((|#2| $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-4189 (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $) NIL (|has| |#1| (-225)))) (-3206 (((-763) $) NIL)) (-2745 (((-850) $) 17) (($ (-568)) NIL) (($ |#2|) NIL (|has| |#2| (-172)))) (-2604 ((|#2| $ (-763)) NIL)) (-4078 (((-763)) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $) NIL (|has| |#1| (-225)))) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 12) (($ $ |#2|) NIL) (($ |#2| $) NIL))) 
-(((-822 |#1| |#2|) (-13 (-698 |#2|) (-10 -8 (IF (|has| |#1| (-225)) (-6 (-225)) |noBranch|) (-15 -4192 ($ |#1|)) (-15 -3506 (|#1| $)))) (-698 |#2|) (-1047)) (T -822)) 
-((-4192 (*1 *1 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-822 *2 *3)) (-4 *2 (-698 *3)))) (-3506 (*1 *2 *1) (-12 (-4 *2 (-698 *3)) (-5 *1 (-822 *2 *3)) (-4 *3 (-1047))))) 
-(-13 (-698 |#2|) (-10 -8 (IF (|has| |#1| (-225)) (-6 (-225)) |noBranch|) (-15 -4192 ($ |#1|)) (-15 -3506 (|#1| $)))) 
-((-3754 (((-1249) (-817) $ (-121)) 9) (((-1249) (-817) $) 8) (((-1143) $ (-121)) 7) (((-1143) $) 6))) 
+((-2947 (($ (-1108)) 7)) (-3348 (((-121) $ (-1143) (-1108)) 15)) (-2576 (((-817) $) 12)) (-1572 (((-817) $) 11)) (-2774 (((-1249) $) 9)) (-2397 (((-121) $ (-1108)) 16))) 
+(((-816) (-10 -8 (-15 -2947 ($ (-1108))) (-15 -2774 ((-1249) $)) (-15 -1572 ((-817) $)) (-15 -2576 ((-817) $)) (-15 -3348 ((-121) $ (-1143) (-1108))) (-15 -2397 ((-121) $ (-1108))))) (T -816)) 
+((-2397 (*1 *2 *1 *3) (-12 (-5 *3 (-1108)) (-5 *2 (-121)) (-5 *1 (-816)))) (-3348 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-1108)) (-5 *2 (-121)) (-5 *1 (-816)))) (-2576 (*1 *2 *1) (-12 (-5 *2 (-817)) (-5 *1 (-816)))) (-1572 (*1 *2 *1) (-12 (-5 *2 (-817)) (-5 *1 (-816)))) (-2774 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-816)))) (-2947 (*1 *1 *2) (-12 (-5 *2 (-1108)) (-5 *1 (-816))))) 
+(-10 -8 (-15 -2947 ($ (-1108))) (-15 -2774 ((-1249) $)) (-15 -1572 ((-817) $)) (-15 -2576 ((-817) $)) (-15 -3348 ((-121) $ (-1143) (-1108))) (-15 -2397 ((-121) $ (-1108)))) 
+((-3404 (((-1249) $ (-818)) 12)) (-4195 (((-1249) $ (-1161)) 32)) (-4148 (((-1249) $ (-1143) (-1143)) 34)) (-3760 (((-1249) $ (-1143)) 33)) (-1599 (((-1249) $) 19)) (-3907 (((-1249) $ (-568)) 28)) (-4380 (((-1249) $ (-215)) 30)) (-4095 (((-1249) $) 18)) (-3360 (((-1249) $) 26)) (-4027 (((-1249) $) 25)) (-2610 (((-1249) $) 23)) (-2421 (((-1249) $) 24)) (-3546 (((-1249) $) 22)) (-1314 (((-1249) $) 21)) (-3708 (((-1249) $) 20)) (-2948 (((-1249) $) 16)) (-4361 (((-1249) $) 17)) (-2501 (((-1249) $) 15)) (-1858 (((-1249) $) 14)) (-3961 (((-1249) $) 13)) (-2425 (($ (-1143) (-818)) 9)) (-2279 (($ (-1143) (-1143) (-818)) 8)) (-1981 (((-1161) $) 51)) (-3131 (((-1161) $) 55)) (-2744 (((-2 (|:| |cd| (-1143)) (|:| -3393 (-1143))) $) 54)) (-2247 (((-1143) $) 52)) (-3148 (((-1249) $) 41)) (-3023 (((-568) $) 49)) (-1646 (((-215) $) 50)) (-2370 (((-1249) $) 40)) (-2360 (((-1249) $) 48)) (-3184 (((-1249) $) 47)) (-2464 (((-1249) $) 45)) (-3699 (((-1249) $) 46)) (-3187 (((-1249) $) 44)) (-1367 (((-1249) $) 43)) (-4028 (((-1249) $) 42)) (-2880 (((-1249) $) 38)) (-3673 (((-1249) $) 39)) (-3776 (((-1249) $) 37)) (-4306 (((-1249) $) 36)) (-2653 (((-1249) $) 35)) (-1525 (((-1249) $) 11))) 
+(((-817) (-10 -8 (-15 -2279 ($ (-1143) (-1143) (-818))) (-15 -2425 ($ (-1143) (-818))) (-15 -1525 ((-1249) $)) (-15 -3404 ((-1249) $ (-818))) (-15 -3961 ((-1249) $)) (-15 -1858 ((-1249) $)) (-15 -2501 ((-1249) $)) (-15 -2948 ((-1249) $)) (-15 -4361 ((-1249) $)) (-15 -4095 ((-1249) $)) (-15 -1599 ((-1249) $)) (-15 -3708 ((-1249) $)) (-15 -1314 ((-1249) $)) (-15 -3546 ((-1249) $)) (-15 -2610 ((-1249) $)) (-15 -2421 ((-1249) $)) (-15 -4027 ((-1249) $)) (-15 -3360 ((-1249) $)) (-15 -3907 ((-1249) $ (-568))) (-15 -4380 ((-1249) $ (-215))) (-15 -4195 ((-1249) $ (-1161))) (-15 -3760 ((-1249) $ (-1143))) (-15 -4148 ((-1249) $ (-1143) (-1143))) (-15 -2653 ((-1249) $)) (-15 -4306 ((-1249) $)) (-15 -3776 ((-1249) $)) (-15 -2880 ((-1249) $)) (-15 -3673 ((-1249) $)) (-15 -2370 ((-1249) $)) (-15 -3148 ((-1249) $)) (-15 -4028 ((-1249) $)) (-15 -1367 ((-1249) $)) (-15 -3187 ((-1249) $)) (-15 -2464 ((-1249) $)) (-15 -3699 ((-1249) $)) (-15 -3184 ((-1249) $)) (-15 -2360 ((-1249) $)) (-15 -3023 ((-568) $)) (-15 -1646 ((-215) $)) (-15 -1981 ((-1161) $)) (-15 -2247 ((-1143) $)) (-15 -2744 ((-2 (|:| |cd| (-1143)) (|:| -3393 (-1143))) $)) (-15 -3131 ((-1161) $)))) (T -817)) 
+((-3131 (*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-817)))) (-2744 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |cd| (-1143)) (|:| -3393 (-1143)))) (-5 *1 (-817)))) (-2247 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-817)))) (-1981 (*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-817)))) (-1646 (*1 *2 *1) (-12 (-5 *2 (-215)) (-5 *1 (-817)))) (-3023 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-817)))) (-2360 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-3184 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-3699 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-2464 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-3187 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-1367 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-4028 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-3148 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-2370 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-3673 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-2880 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-3776 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-4306 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-2653 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-4148 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-817)))) (-3760 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-817)))) (-4195 (*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-817)))) (-4380 (*1 *2 *1 *3) (-12 (-5 *3 (-215)) (-5 *2 (-1249)) (-5 *1 (-817)))) (-3907 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-817)))) (-3360 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-4027 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-2421 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-2610 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-3546 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-1314 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-3708 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-1599 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-4095 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-4361 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-2948 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-2501 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-1858 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-3961 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-3404 (*1 *2 *1 *3) (-12 (-5 *3 (-818)) (-5 *2 (-1249)) (-5 *1 (-817)))) (-1525 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817)))) (-2425 (*1 *1 *2 *3) (-12 (-5 *2 (-1143)) (-5 *3 (-818)) (-5 *1 (-817)))) (-2279 (*1 *1 *2 *2 *3) (-12 (-5 *2 (-1143)) (-5 *3 (-818)) (-5 *1 (-817))))) 
+(-10 -8 (-15 -2279 ($ (-1143) (-1143) (-818))) (-15 -2425 ($ (-1143) (-818))) (-15 -1525 ((-1249) $)) (-15 -3404 ((-1249) $ (-818))) (-15 -3961 ((-1249) $)) (-15 -1858 ((-1249) $)) (-15 -2501 ((-1249) $)) (-15 -2948 ((-1249) $)) (-15 -4361 ((-1249) $)) (-15 -4095 ((-1249) $)) (-15 -1599 ((-1249) $)) (-15 -3708 ((-1249) $)) (-15 -1314 ((-1249) $)) (-15 -3546 ((-1249) $)) (-15 -2610 ((-1249) $)) (-15 -2421 ((-1249) $)) (-15 -4027 ((-1249) $)) (-15 -3360 ((-1249) $)) (-15 -3907 ((-1249) $ (-568))) (-15 -4380 ((-1249) $ (-215))) (-15 -4195 ((-1249) $ (-1161))) (-15 -3760 ((-1249) $ (-1143))) (-15 -4148 ((-1249) $ (-1143) (-1143))) (-15 -2653 ((-1249) $)) (-15 -4306 ((-1249) $)) (-15 -3776 ((-1249) $)) (-15 -2880 ((-1249) $)) (-15 -3673 ((-1249) $)) (-15 -2370 ((-1249) $)) (-15 -3148 ((-1249) $)) (-15 -4028 ((-1249) $)) (-15 -1367 ((-1249) $)) (-15 -3187 ((-1249) $)) (-15 -2464 ((-1249) $)) (-15 -3699 ((-1249) $)) (-15 -3184 ((-1249) $)) (-15 -2360 ((-1249) $)) (-15 -3023 ((-568) $)) (-15 -1646 ((-215) $)) (-15 -1981 ((-1161) $)) (-15 -2247 ((-1143) $)) (-15 -2744 ((-2 (|:| |cd| (-1143)) (|:| -3393 (-1143))) $)) (-15 -3131 ((-1161) $))) 
+((-2449 (((-121) $ $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 12)) (-3718 (($) 15)) (-4292 (($) 13)) (-4410 (($) 16)) (-3173 (($) 14)) (-1719 (((-121) $ $) 8))) 
+(((-818) (-13 (-1090) (-10 -8 (-15 -4292 ($)) (-15 -3718 ($)) (-15 -4410 ($)) (-15 -3173 ($))))) (T -818)) 
+((-4292 (*1 *1) (-5 *1 (-818))) (-3718 (*1 *1) (-5 *1 (-818))) (-4410 (*1 *1) (-5 *1 (-818))) (-3173 (*1 *1) (-5 *1 (-818)))) 
+(-13 (-1090) (-10 -8 (-15 -4292 ($)) (-15 -3718 ($)) (-15 -4410 ($)) (-15 -3173 ($)))) 
+((-2449 (((-121) $ $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 21) (($ (-1161)) 17)) (-3378 (((-121) $) 10)) (-3921 (((-121) $) 9)) (-1770 (((-121) $) 11)) (-1903 (((-121) $) 8)) (-1719 (((-121) $ $) 19))) 
+(((-819) (-13 (-1090) (-10 -8 (-15 -2747 ($ (-1161))) (-15 -1903 ((-121) $)) (-15 -3921 ((-121) $)) (-15 -3378 ((-121) $)) (-15 -1770 ((-121) $))))) (T -819)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-819)))) (-1903 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-819)))) (-3921 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-819)))) (-3378 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-819)))) (-1770 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-819))))) 
+(-13 (-1090) (-10 -8 (-15 -2747 ($ (-1161))) (-15 -1903 ((-121) $)) (-15 -3921 ((-121) $)) (-15 -3378 ((-121) $)) (-15 -1770 ((-121) $)))) 
+((-2449 (((-121) $ $) NIL)) (-3273 (($ (-819) (-634 (-1161))) 24)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-4431 (((-819) $) 25)) (-3410 (((-634 (-1161)) $) 26)) (-2747 (((-850) $) 23)) (-1719 (((-121) $ $) NIL))) 
+(((-820) (-13 (-1090) (-10 -8 (-15 -4431 ((-819) $)) (-15 -3410 ((-634 (-1161)) $)) (-15 -3273 ($ (-819) (-634 (-1161))))))) (T -820)) 
+((-4431 (*1 *2 *1) (-12 (-5 *2 (-819)) (-5 *1 (-820)))) (-3410 (*1 *2 *1) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-820)))) (-3273 (*1 *1 *2 *3) (-12 (-5 *2 (-819)) (-5 *3 (-634 (-1161))) (-5 *1 (-820))))) 
+(-13 (-1090) (-10 -8 (-15 -4431 ((-819) $)) (-15 -3410 ((-634 (-1161)) $)) (-15 -3273 ($ (-819) (-634 (-1161)))))) 
+((-2628 (((-1249) (-817) (-310 |#1|) (-121)) 22) (((-1249) (-817) (-310 |#1|)) 76) (((-1143) (-310 |#1|) (-121)) 75) (((-1143) (-310 |#1|)) 74))) 
+(((-821 |#1|) (-10 -7 (-15 -2628 ((-1143) (-310 |#1|))) (-15 -2628 ((-1143) (-310 |#1|) (-121))) (-15 -2628 ((-1249) (-817) (-310 |#1|))) (-15 -2628 ((-1249) (-817) (-310 |#1|) (-121)))) (-13 (-823) (-842) (-1047))) (T -821)) 
+((-2628 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-817)) (-5 *4 (-310 *6)) (-5 *5 (-121)) (-4 *6 (-13 (-823) (-842) (-1047))) (-5 *2 (-1249)) (-5 *1 (-821 *6)))) (-2628 (*1 *2 *3 *4) (-12 (-5 *3 (-817)) (-5 *4 (-310 *5)) (-4 *5 (-13 (-823) (-842) (-1047))) (-5 *2 (-1249)) (-5 *1 (-821 *5)))) (-2628 (*1 *2 *3 *4) (-12 (-5 *3 (-310 *5)) (-5 *4 (-121)) (-4 *5 (-13 (-823) (-842) (-1047))) (-5 *2 (-1143)) (-5 *1 (-821 *5)))) (-2628 (*1 *2 *3) (-12 (-5 *3 (-310 *4)) (-4 *4 (-13 (-823) (-842) (-1047))) (-5 *2 (-1143)) (-5 *1 (-821 *4))))) 
+(-10 -7 (-15 -2628 ((-1143) (-310 |#1|))) (-15 -2628 ((-1143) (-310 |#1|) (-121))) (-15 -2628 ((-1249) (-817) (-310 |#1|))) (-15 -2628 ((-1249) (-817) (-310 |#1|) (-121)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-2116 (($ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-3955 ((|#1| $) 10)) (-4194 (($ |#1|) 9)) (-1598 (((-121) $) NIL)) (-2049 (($ |#2| (-763)) NIL)) (-3524 (((-763) $) NIL)) (-2104 ((|#2| $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-4191 (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $) NIL (|has| |#1| (-225)))) (-1836 (((-763) $) NIL)) (-2747 (((-850) $) 17) (($ (-568)) NIL) (($ |#2|) NIL (|has| |#2| (-172)))) (-2079 ((|#2| $ (-763)) NIL)) (-3425 (((-763)) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $) NIL (|has| |#1| (-225)))) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 12) (($ $ |#2|) NIL) (($ |#2| $) NIL))) 
+(((-822 |#1| |#2|) (-13 (-698 |#2|) (-10 -8 (IF (|has| |#1| (-225)) (-6 (-225)) |noBranch|) (-15 -4194 ($ |#1|)) (-15 -3955 (|#1| $)))) (-698 |#2|) (-1047)) (T -822)) 
+((-4194 (*1 *1 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-822 *2 *3)) (-4 *2 (-698 *3)))) (-3955 (*1 *2 *1) (-12 (-4 *2 (-698 *3)) (-5 *1 (-822 *2 *3)) (-4 *3 (-1047))))) 
+(-13 (-698 |#2|) (-10 -8 (IF (|has| |#1| (-225)) (-6 (-225)) |noBranch|) (-15 -4194 ($ |#1|)) (-15 -3955 (|#1| $)))) 
+((-2628 (((-1249) (-817) $ (-121)) 9) (((-1249) (-817) $) 8) (((-1143) $ (-121)) 7) (((-1143) $) 6))) 
 (((-823) (-1275)) (T -823)) 
-((-3754 (*1 *2 *3 *1 *4) (-12 (-4 *1 (-823)) (-5 *3 (-817)) (-5 *4 (-121)) (-5 *2 (-1249)))) (-3754 (*1 *2 *3 *1) (-12 (-4 *1 (-823)) (-5 *3 (-817)) (-5 *2 (-1249)))) (-3754 (*1 *2 *1 *3) (-12 (-4 *1 (-823)) (-5 *3 (-121)) (-5 *2 (-1143)))) (-3754 (*1 *2 *1) (-12 (-4 *1 (-823)) (-5 *2 (-1143))))) 
-(-13 (-10 -8 (-15 -3754 ((-1143) $)) (-15 -3754 ((-1143) $ (-121))) (-15 -3754 ((-1249) (-817) $)) (-15 -3754 ((-1249) (-817) $ (-121))))) 
-((-2913 (((-305) (-1143) (-1143)) 12)) (-2272 (((-121) (-1143) (-1143)) 33)) (-2614 (((-121) (-1143)) 32)) (-2666 (((-57) (-1143)) 25)) (-3263 (((-57) (-1143)) 23)) (-4263 (((-57) (-817)) 17)) (-3314 (((-634 (-1143)) (-1143)) 28)) (-2119 (((-634 (-1143))) 27))) 
-(((-824) (-10 -7 (-15 -4263 ((-57) (-817))) (-15 -3263 ((-57) (-1143))) (-15 -2666 ((-57) (-1143))) (-15 -2119 ((-634 (-1143)))) (-15 -3314 ((-634 (-1143)) (-1143))) (-15 -2614 ((-121) (-1143))) (-15 -2272 ((-121) (-1143) (-1143))) (-15 -2913 ((-305) (-1143) (-1143))))) (T -824)) 
-((-2913 (*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-305)) (-5 *1 (-824)))) (-2272 (*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-121)) (-5 *1 (-824)))) (-2614 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-121)) (-5 *1 (-824)))) (-3314 (*1 *2 *3) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-824)) (-5 *3 (-1143)))) (-2119 (*1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-824)))) (-2666 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-57)) (-5 *1 (-824)))) (-3263 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-57)) (-5 *1 (-824)))) (-4263 (*1 *2 *3) (-12 (-5 *3 (-817)) (-5 *2 (-57)) (-5 *1 (-824))))) 
-(-10 -7 (-15 -4263 ((-57) (-817))) (-15 -3263 ((-57) (-1143))) (-15 -2666 ((-57) (-1143))) (-15 -2119 ((-634 (-1143)))) (-15 -3314 ((-634 (-1143)) (-1143))) (-15 -2614 ((-121) (-1143))) (-15 -2272 ((-121) (-1143) (-1143))) (-15 -2913 ((-305) (-1143) (-1143)))) 
-((-2447 (((-121) $ $) 18)) (-1791 (($ |#1| $) 72) (($ $ |#1|) 71) (($ $ $) 70)) (-1536 (($ $ $) 68)) (-2032 (((-121) $ $) 69)) (-2510 (((-121) $ (-763)) 8)) (-2749 (($ (-634 |#1|)) 64) (($) 63)) (-3507 (($ (-1 (-121) |#1|) $) 42 (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) |#1|) $) 52 (|has| $ (-6 -4519)))) (-2671 (($) 7 T CONST)) (-3369 (($ $) 58)) (-3924 (($ $) 55 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3405 (($ |#1| $) 44 (|has| $ (-6 -4519))) (($ (-1 (-121) |#1|) $) 43 (|has| $ (-6 -4519)))) (-4328 (($ |#1| $) 54 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) |#1|) $) 51 (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4519)))) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) 9)) (-2521 ((|#1| $) 74)) (-3349 (($ $ $) 77)) (-1347 (($ $ $) 76)) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3268 ((|#1| $) 75)) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35)) (-2166 (((-121) $ (-763)) 10)) (-4487 (((-1143) $) 22)) (-3212 (($ $ $) 65)) (-1890 ((|#1| $) 36)) (-4450 (($ |#1| $) 37) (($ |#1| $ (-763)) 59)) (-4022 (((-1108) $) 21)) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 48)) (-1315 ((|#1| $) 38)) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-1799 (((-634 (-2 (|:| -4083 |#1|) (|:| -4168 (-763)))) $) 57)) (-4382 (($ $ |#1|) 67) (($ $ $) 66)) (-2085 (($) 46) (($ (-634 |#1|)) 45)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-4278 (((-541) $) 56 (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) 47)) (-2745 (((-850) $) 20)) (-3844 (($ (-634 |#1|)) 62) (($) 61)) (-2367 (($ (-634 |#1|)) 39)) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19)) (-1732 (((-121) $ $) 60)) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-2628 (*1 *2 *3 *1 *4) (-12 (-4 *1 (-823)) (-5 *3 (-817)) (-5 *4 (-121)) (-5 *2 (-1249)))) (-2628 (*1 *2 *3 *1) (-12 (-4 *1 (-823)) (-5 *3 (-817)) (-5 *2 (-1249)))) (-2628 (*1 *2 *1 *3) (-12 (-4 *1 (-823)) (-5 *3 (-121)) (-5 *2 (-1143)))) (-2628 (*1 *2 *1) (-12 (-4 *1 (-823)) (-5 *2 (-1143))))) 
+(-13 (-10 -8 (-15 -2628 ((-1143) $)) (-15 -2628 ((-1143) $ (-121))) (-15 -2628 ((-1249) (-817) $)) (-15 -2628 ((-1249) (-817) $ (-121))))) 
+((-2871 (((-305) (-1143) (-1143)) 12)) (-3414 (((-121) (-1143) (-1143)) 33)) (-2129 (((-121) (-1143)) 32)) (-4465 (((-57) (-1143)) 25)) (-2033 (((-57) (-1143)) 23)) (-2904 (((-57) (-817)) 17)) (-4300 (((-634 (-1143)) (-1143)) 28)) (-3331 (((-634 (-1143))) 27))) 
+(((-824) (-10 -7 (-15 -2904 ((-57) (-817))) (-15 -2033 ((-57) (-1143))) (-15 -4465 ((-57) (-1143))) (-15 -3331 ((-634 (-1143)))) (-15 -4300 ((-634 (-1143)) (-1143))) (-15 -2129 ((-121) (-1143))) (-15 -3414 ((-121) (-1143) (-1143))) (-15 -2871 ((-305) (-1143) (-1143))))) (T -824)) 
+((-2871 (*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-305)) (-5 *1 (-824)))) (-3414 (*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-121)) (-5 *1 (-824)))) (-2129 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-121)) (-5 *1 (-824)))) (-4300 (*1 *2 *3) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-824)) (-5 *3 (-1143)))) (-3331 (*1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-824)))) (-4465 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-57)) (-5 *1 (-824)))) (-2033 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-57)) (-5 *1 (-824)))) (-2904 (*1 *2 *3) (-12 (-5 *3 (-817)) (-5 *2 (-57)) (-5 *1 (-824))))) 
+(-10 -7 (-15 -2904 ((-57) (-817))) (-15 -2033 ((-57) (-1143))) (-15 -4465 ((-57) (-1143))) (-15 -3331 ((-634 (-1143)))) (-15 -4300 ((-634 (-1143)) (-1143))) (-15 -2129 ((-121) (-1143))) (-15 -3414 ((-121) (-1143) (-1143))) (-15 -2871 ((-305) (-1143) (-1143)))) 
+((-2449 (((-121) $ $) 18)) (-1793 (($ |#1| $) 72) (($ $ |#1|) 71) (($ $ $) 70)) (-4217 (($ $ $) 68)) (-1430 (((-121) $ $) 69)) (-1667 (((-121) $ (-763)) 8)) (-2751 (($ (-634 |#1|)) 64) (($) 63)) (-3963 (($ (-1 (-121) |#1|) $) 42 (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) |#1|) $) 52 (|has| $ (-6 -4521)))) (-4490 (($) 7 T CONST)) (-1377 (($ $) 58)) (-3926 (($ $) 55 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-1568 (($ |#1| $) 44 (|has| $ (-6 -4521))) (($ (-1 (-121) |#1|) $) 43 (|has| $ (-6 -4521)))) (-4330 (($ |#1| $) 54 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) |#1|) $) 51 (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 53 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 50 (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) 49 (|has| $ (-6 -4521)))) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) 9)) (-1732 ((|#1| $) 74)) (-4496 (($ $ $) 77)) (-3645 (($ $ $) 76)) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-2047 ((|#1| $) 75)) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35)) (-3796 (((-121) $ (-763)) 10)) (-1893 (((-1143) $) 22)) (-1864 (($ $ $) 65)) (-2580 ((|#1| $) 36)) (-1708 (($ |#1| $) 37) (($ |#1| $ (-763)) 59)) (-4025 (((-1108) $) 21)) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 48)) (-3403 ((|#1| $) 38)) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2138 (((-634 (-2 (|:| -4085 |#1|) (|:| -4170 (-763)))) $) 57)) (-1363 (($ $ |#1|) 67) (($ $ $) 66)) (-3132 (($) 46) (($ (-634 |#1|)) 45)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-4280 (((-541) $) 56 (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) 47)) (-2747 (((-850) $) 20)) (-3846 (($ (-634 |#1|)) 62) (($) 61)) (-4074 (($ (-634 |#1|)) 39)) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19)) (-1734 (((-121) $ $) 60)) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-825 |#1|) (-1275) (-842)) (T -825)) 
-((-2521 (*1 *2 *1) (-12 (-4 *1 (-825 *2)) (-4 *2 (-842))))) 
-(-13 (-726 |t#1|) (-969 |t#1|) (-10 -8 (-15 -2521 (|t#1| $)))) 
+((-1732 (*1 *2 *1) (-12 (-4 *1 (-825 *2)) (-4 *2 (-842))))) 
+(-13 (-726 |t#1|) (-969 |t#1|) (-10 -8 (-15 -1732 (|t#1| $)))) 
 (((-39) . T) ((-111 |#1|) . T) ((-105) . T) ((-608 (-850)) . T) ((-154 |#1|) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-227 |#1|) . T) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-684 |#1|) . T) ((-726 |#1|) . T) ((-969 |#1|) . T) ((-1087 |#1|) . T) ((-1090) . T) ((-1195) . T)) 
-((-2135 (((-1249) (-1108) (-1108)) 47)) (-3350 (((-1249) (-816) (-57)) 44)) (-1746 (((-57) (-816)) 16))) 
-(((-826) (-10 -7 (-15 -1746 ((-57) (-816))) (-15 -3350 ((-1249) (-816) (-57))) (-15 -2135 ((-1249) (-1108) (-1108))))) (T -826)) 
-((-2135 (*1 *2 *3 *3) (-12 (-5 *3 (-1108)) (-5 *2 (-1249)) (-5 *1 (-826)))) (-3350 (*1 *2 *3 *4) (-12 (-5 *3 (-816)) (-5 *4 (-57)) (-5 *2 (-1249)) (-5 *1 (-826)))) (-1746 (*1 *2 *3) (-12 (-5 *3 (-816)) (-5 *2 (-57)) (-5 *1 (-826))))) 
-(-10 -7 (-15 -1746 ((-57) (-816))) (-15 -3350 ((-1249) (-816) (-57))) (-15 -2135 ((-1249) (-1108) (-1108)))) 
-((-2795 (((-828 |#2|) (-1 |#2| |#1|) (-828 |#1|) (-828 |#2|)) 12) (((-828 |#2|) (-1 |#2| |#1|) (-828 |#1|)) 13))) 
-(((-827 |#1| |#2|) (-10 -7 (-15 -2795 ((-828 |#2|) (-1 |#2| |#1|) (-828 |#1|))) (-15 -2795 ((-828 |#2|) (-1 |#2| |#1|) (-828 |#1|) (-828 |#2|)))) (-1090) (-1090)) (T -827)) 
-((-2795 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-828 *6)) (-5 *3 (-1 *6 *5)) (-5 *4 (-828 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *1 (-827 *5 *6)))) (-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-828 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-828 *6)) (-5 *1 (-827 *5 *6))))) 
-(-10 -7 (-15 -2795 ((-828 |#2|) (-1 |#2| |#1|) (-828 |#1|))) (-15 -2795 ((-828 |#2|) (-1 |#2| |#1|) (-828 |#1|) (-828 |#2|)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL (|has| |#1| (-21)))) (-3134 (((-3 $ "failed") $ $) NIL (|has| |#1| (-21)))) (-3662 (((-568) $) NIL (|has| |#1| (-840)))) (-2671 (($) NIL (|has| |#1| (-21)) CONST)) (-3666 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 15)) (-2854 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) 9)) (-2925 (((-3 $ "failed") $) 40 (|has| |#1| (-840)))) (-1642 (((-3 (-409 (-568)) "failed") $) 48 (|has| |#1| (-550)))) (-2688 (((-121) $) 43 (|has| |#1| (-550)))) (-2425 (((-409 (-568)) $) 45 (|has| |#1| (-550)))) (-2033 (((-121) $) NIL (|has| |#1| (-840)))) (-2735 (((-121) $) NIL (|has| |#1| (-840)))) (-2245 (((-121) $) NIL (|has| |#1| (-840)))) (-2521 (($ $ $) NIL (|has| |#1| (-840)))) (-3268 (($ $ $) NIL (|has| |#1| (-840)))) (-4487 (((-1143) $) NIL)) (-3059 (($) 13)) (-3794 (((-121) $) 12)) (-4022 (((-1108) $) NIL)) (-3449 (((-121) $) 11)) (-2745 (((-850) $) 18) (($ (-409 (-568))) NIL (|has| |#1| (-1037 (-409 (-568))))) (($ |#1|) 8) (($ (-568)) NIL (-2198 (|has| |#1| (-840)) (|has| |#1| (-1037 (-568)))))) (-4078 (((-763)) 34 (|has| |#1| (-840)))) (-2897 (($ $) NIL (|has| |#1| (-840)))) (-1887 (($ $ (-917)) NIL (|has| |#1| (-840))) (($ $ (-763)) NIL (|has| |#1| (-840)))) (-3056 (($) 22 (|has| |#1| (-21)) CONST)) (-1556 (($) 31 (|has| |#1| (-840)) CONST)) (-1751 (((-121) $ $) NIL (|has| |#1| (-840)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-840)))) (-1717 (((-121) $ $) 20)) (-1745 (((-121) $ $) NIL (|has| |#1| (-840)))) (-1732 (((-121) $ $) 42 (|has| |#1| (-840)))) (-1773 (($ $ $) NIL (|has| |#1| (-21))) (($ $) 27 (|has| |#1| (-21)))) (-1767 (($ $ $) 29 (|has| |#1| (-21)))) (** (($ $ (-917)) NIL (|has| |#1| (-840))) (($ $ (-763)) NIL (|has| |#1| (-840)))) (* (($ $ $) 37 (|has| |#1| (-840))) (($ (-568) $) 25 (|has| |#1| (-21))) (($ (-763) $) NIL (|has| |#1| (-21))) (($ (-917) $) NIL (|has| |#1| (-21))))) 
-(((-828 |#1|) (-13 (-1090) (-413 |#1|) (-10 -8 (-15 -3059 ($)) (-15 -3449 ((-121) $)) (-15 -3794 ((-121) $)) (IF (|has| |#1| (-21)) (-6 (-21)) |noBranch|) (IF (|has| |#1| (-840)) (-6 (-840)) |noBranch|) (IF (|has| |#1| (-550)) (PROGN (-15 -2688 ((-121) $)) (-15 -2425 ((-409 (-568)) $)) (-15 -1642 ((-3 (-409 (-568)) "failed") $))) |noBranch|))) (-1090)) (T -828)) 
-((-3059 (*1 *1) (-12 (-5 *1 (-828 *2)) (-4 *2 (-1090)))) (-3449 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-828 *3)) (-4 *3 (-1090)))) (-3794 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-828 *3)) (-4 *3 (-1090)))) (-2688 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-828 *3)) (-4 *3 (-550)) (-4 *3 (-1090)))) (-2425 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-828 *3)) (-4 *3 (-550)) (-4 *3 (-1090)))) (-1642 (*1 *2 *1) (|partial| -12 (-5 *2 (-409 (-568))) (-5 *1 (-828 *3)) (-4 *3 (-550)) (-4 *3 (-1090))))) 
-(-13 (-1090) (-413 |#1|) (-10 -8 (-15 -3059 ($)) (-15 -3449 ((-121) $)) (-15 -3794 ((-121) $)) (IF (|has| |#1| (-21)) (-6 (-21)) |noBranch|) (IF (|has| |#1| (-840)) (-6 (-840)) |noBranch|) (IF (|has| |#1| (-550)) (PROGN (-15 -2688 ((-121) $)) (-15 -2425 ((-409 (-568)) $)) (-15 -1642 ((-3 (-409 (-568)) "failed") $))) |noBranch|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) NIL) (((-3 (-123) "failed") $) NIL)) (-2854 ((|#1| $) NIL) (((-123) $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-4432 ((|#1| (-123) |#1|) NIL)) (-2735 (((-121) $) NIL)) (-2276 (($ |#1| (-363 (-123))) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2082 (($ $ (-1 |#1| |#1|)) NIL)) (-1481 (($ $ (-1 |#1| |#1|)) NIL)) (-2779 ((|#1| $ |#1|) NIL)) (-1730 ((|#1| |#1|) NIL (|has| |#1| (-172)))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL) (($ (-123)) NIL)) (-4371 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-4078 (((-763)) NIL)) (-4391 (($ $) NIL (|has| |#1| (-172))) (($ $ $) NIL (|has| |#1| (-172)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ (-123) (-568)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ |#1| $) NIL (|has| |#1| (-172))) (($ $ |#1|) NIL (|has| |#1| (-172))))) 
-(((-829 |#1|) (-13 (-1047) (-1037 |#1|) (-1037 (-123)) (-281 |#1| |#1|) (-10 -8 (IF (|has| |#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |#1| (-172)) (PROGN (-6 (-43 |#1|)) (-15 -4391 ($ $)) (-15 -4391 ($ $ $)) (-15 -1730 (|#1| |#1|))) |noBranch|) (-15 -1481 ($ $ (-1 |#1| |#1|))) (-15 -2082 ($ $ (-1 |#1| |#1|))) (-15 ** ($ (-123) (-568))) (-15 ** ($ $ (-568))) (-15 -4432 (|#1| (-123) |#1|)) (-15 -2276 ($ |#1| (-363 (-123)))))) (-1047)) (T -829)) 
-((-4391 (*1 *1 *1) (-12 (-5 *1 (-829 *2)) (-4 *2 (-172)) (-4 *2 (-1047)))) (-4391 (*1 *1 *1 *1) (-12 (-5 *1 (-829 *2)) (-4 *2 (-172)) (-4 *2 (-1047)))) (-1730 (*1 *2 *2) (-12 (-5 *1 (-829 *2)) (-4 *2 (-172)) (-4 *2 (-1047)))) (-1481 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-829 *3)))) (-2082 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-829 *3)))) (** (*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-568)) (-5 *1 (-829 *4)) (-4 *4 (-1047)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-829 *3)) (-4 *3 (-1047)))) (-4432 (*1 *2 *3 *2) (-12 (-5 *3 (-123)) (-5 *1 (-829 *2)) (-4 *2 (-1047)))) (-2276 (*1 *1 *2 *3) (-12 (-5 *3 (-363 (-123))) (-5 *1 (-829 *2)) (-4 *2 (-1047))))) 
-(-13 (-1047) (-1037 |#1|) (-1037 (-123)) (-281 |#1| |#1|) (-10 -8 (IF (|has| |#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |#1| (-172)) (PROGN (-6 (-43 |#1|)) (-15 -4391 ($ $)) (-15 -4391 ($ $ $)) (-15 -1730 (|#1| |#1|))) |noBranch|) (-15 -1481 ($ $ (-1 |#1| |#1|))) (-15 -2082 ($ $ (-1 |#1| |#1|))) (-15 ** ($ (-123) (-568))) (-15 ** ($ $ (-568))) (-15 -4432 (|#1| (-123) |#1|)) (-15 -2276 ($ |#1| (-363 (-123)))))) 
-((-3457 (((-205 (-511)) (-1143)) 8))) 
-(((-830) (-10 -7 (-15 -3457 ((-205 (-511)) (-1143))))) (T -830)) 
-((-3457 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-205 (-511))) (-5 *1 (-830))))) 
-(-10 -7 (-15 -3457 ((-205 (-511)) (-1143)))) 
-((-2447 (((-121) $ $) 7)) (-2855 (((-1035) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) 13) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 12)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 15) (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) 14)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-1717 (((-121) $ $) 6))) 
+((-3460 (((-1249) (-1108) (-1108)) 47)) (-4501 (((-1249) (-816) (-57)) 44)) (-3836 (((-57) (-816)) 16))) 
+(((-826) (-10 -7 (-15 -3836 ((-57) (-816))) (-15 -4501 ((-1249) (-816) (-57))) (-15 -3460 ((-1249) (-1108) (-1108))))) (T -826)) 
+((-3460 (*1 *2 *3 *3) (-12 (-5 *3 (-1108)) (-5 *2 (-1249)) (-5 *1 (-826)))) (-4501 (*1 *2 *3 *4) (-12 (-5 *3 (-816)) (-5 *4 (-57)) (-5 *2 (-1249)) (-5 *1 (-826)))) (-3836 (*1 *2 *3) (-12 (-5 *3 (-816)) (-5 *2 (-57)) (-5 *1 (-826))))) 
+(-10 -7 (-15 -3836 ((-57) (-816))) (-15 -4501 ((-1249) (-816) (-57))) (-15 -3460 ((-1249) (-1108) (-1108)))) 
+((-2797 (((-828 |#2|) (-1 |#2| |#1|) (-828 |#1|) (-828 |#2|)) 12) (((-828 |#2|) (-1 |#2| |#1|) (-828 |#1|)) 13))) 
+(((-827 |#1| |#2|) (-10 -7 (-15 -2797 ((-828 |#2|) (-1 |#2| |#1|) (-828 |#1|))) (-15 -2797 ((-828 |#2|) (-1 |#2| |#1|) (-828 |#1|) (-828 |#2|)))) (-1090) (-1090)) (T -827)) 
+((-2797 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-828 *6)) (-5 *3 (-1 *6 *5)) (-5 *4 (-828 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *1 (-827 *5 *6)))) (-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-828 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-828 *6)) (-5 *1 (-827 *5 *6))))) 
+(-10 -7 (-15 -2797 ((-828 |#2|) (-1 |#2| |#1|) (-828 |#1|))) (-15 -2797 ((-828 |#2|) (-1 |#2| |#1|) (-828 |#1|) (-828 |#2|)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL (|has| |#1| (-21)))) (-2689 (((-3 $ "failed") $ $) NIL (|has| |#1| (-21)))) (-3337 (((-568) $) NIL (|has| |#1| (-840)))) (-4490 (($) NIL (|has| |#1| (-21)) CONST)) (-3668 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 15)) (-2857 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) 9)) (-2902 (((-3 $ "failed") $) 40 (|has| |#1| (-840)))) (-3254 (((-3 (-409 (-568)) "failed") $) 48 (|has| |#1| (-550)))) (-1338 (((-121) $) 43 (|has| |#1| (-550)))) (-2394 (((-409 (-568)) $) 45 (|has| |#1| (-550)))) (-1436 (((-121) $) NIL (|has| |#1| (-840)))) (-1598 (((-121) $) NIL (|has| |#1| (-840)))) (-2859 (((-121) $) NIL (|has| |#1| (-840)))) (-1732 (($ $ $) NIL (|has| |#1| (-840)))) (-2047 (($ $ $) NIL (|has| |#1| (-840)))) (-1893 (((-1143) $) NIL)) (-3061 (($) 13)) (-2773 (((-121) $) 12)) (-4025 (((-1108) $) NIL)) (-3557 (((-121) $) 11)) (-2747 (((-850) $) 18) (($ (-409 (-568))) NIL (|has| |#1| (-1037 (-409 (-568))))) (($ |#1|) 8) (($ (-568)) NIL (-2199 (|has| |#1| (-840)) (|has| |#1| (-1037 (-568)))))) (-3425 (((-763)) 34 (|has| |#1| (-840)))) (-2811 (($ $) NIL (|has| |#1| (-840)))) (-1889 (($ $ (-917)) NIL (|has| |#1| (-840))) (($ $ (-763)) NIL (|has| |#1| (-840)))) (-3058 (($) 22 (|has| |#1| (-21)) CONST)) (-1557 (($) 31 (|has| |#1| (-840)) CONST)) (-1753 (((-121) $ $) NIL (|has| |#1| (-840)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-840)))) (-1719 (((-121) $ $) 20)) (-1747 (((-121) $ $) NIL (|has| |#1| (-840)))) (-1734 (((-121) $ $) 42 (|has| |#1| (-840)))) (-1775 (($ $ $) NIL (|has| |#1| (-21))) (($ $) 27 (|has| |#1| (-21)))) (-1769 (($ $ $) 29 (|has| |#1| (-21)))) (** (($ $ (-917)) NIL (|has| |#1| (-840))) (($ $ (-763)) NIL (|has| |#1| (-840)))) (* (($ $ $) 37 (|has| |#1| (-840))) (($ (-568) $) 25 (|has| |#1| (-21))) (($ (-763) $) NIL (|has| |#1| (-21))) (($ (-917) $) NIL (|has| |#1| (-21))))) 
+(((-828 |#1|) (-13 (-1090) (-413 |#1|) (-10 -8 (-15 -3061 ($)) (-15 -3557 ((-121) $)) (-15 -2773 ((-121) $)) (IF (|has| |#1| (-21)) (-6 (-21)) |noBranch|) (IF (|has| |#1| (-840)) (-6 (-840)) |noBranch|) (IF (|has| |#1| (-550)) (PROGN (-15 -1338 ((-121) $)) (-15 -2394 ((-409 (-568)) $)) (-15 -3254 ((-3 (-409 (-568)) "failed") $))) |noBranch|))) (-1090)) (T -828)) 
+((-3061 (*1 *1) (-12 (-5 *1 (-828 *2)) (-4 *2 (-1090)))) (-3557 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-828 *3)) (-4 *3 (-1090)))) (-2773 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-828 *3)) (-4 *3 (-1090)))) (-1338 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-828 *3)) (-4 *3 (-550)) (-4 *3 (-1090)))) (-2394 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-828 *3)) (-4 *3 (-550)) (-4 *3 (-1090)))) (-3254 (*1 *2 *1) (|partial| -12 (-5 *2 (-409 (-568))) (-5 *1 (-828 *3)) (-4 *3 (-550)) (-4 *3 (-1090))))) 
+(-13 (-1090) (-413 |#1|) (-10 -8 (-15 -3061 ($)) (-15 -3557 ((-121) $)) (-15 -2773 ((-121) $)) (IF (|has| |#1| (-21)) (-6 (-21)) |noBranch|) (IF (|has| |#1| (-840)) (-6 (-840)) |noBranch|) (IF (|has| |#1| (-550)) (PROGN (-15 -1338 ((-121) $)) (-15 -2394 ((-409 (-568)) $)) (-15 -3254 ((-3 (-409 (-568)) "failed") $))) |noBranch|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) NIL) (((-3 (-123) "failed") $) NIL)) (-2857 ((|#1| $) NIL) (((-123) $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1624 ((|#1| (-123) |#1|) NIL)) (-1598 (((-121) $) NIL)) (-3448 (($ |#1| (-363 (-123))) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-3122 (($ $ (-1 |#1| |#1|)) NIL)) (-2513 (($ $ (-1 |#1| |#1|)) NIL)) (-2781 ((|#1| $ |#1|) NIL)) (-3756 ((|#1| |#1|) NIL (|has| |#1| (-172)))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL) (($ (-123)) NIL)) (-3385 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-3425 (((-763)) NIL)) (-1419 (($ $) NIL (|has| |#1| (-172))) (($ $ $) NIL (|has| |#1| (-172)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ (-123) (-568)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ |#1| $) NIL (|has| |#1| (-172))) (($ $ |#1|) NIL (|has| |#1| (-172))))) 
+(((-829 |#1|) (-13 (-1047) (-1037 |#1|) (-1037 (-123)) (-281 |#1| |#1|) (-10 -8 (IF (|has| |#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |#1| (-172)) (PROGN (-6 (-43 |#1|)) (-15 -1419 ($ $)) (-15 -1419 ($ $ $)) (-15 -3756 (|#1| |#1|))) |noBranch|) (-15 -2513 ($ $ (-1 |#1| |#1|))) (-15 -3122 ($ $ (-1 |#1| |#1|))) (-15 ** ($ (-123) (-568))) (-15 ** ($ $ (-568))) (-15 -1624 (|#1| (-123) |#1|)) (-15 -3448 ($ |#1| (-363 (-123)))))) (-1047)) (T -829)) 
+((-1419 (*1 *1 *1) (-12 (-5 *1 (-829 *2)) (-4 *2 (-172)) (-4 *2 (-1047)))) (-1419 (*1 *1 *1 *1) (-12 (-5 *1 (-829 *2)) (-4 *2 (-172)) (-4 *2 (-1047)))) (-3756 (*1 *2 *2) (-12 (-5 *1 (-829 *2)) (-4 *2 (-172)) (-4 *2 (-1047)))) (-2513 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-829 *3)))) (-3122 (*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-829 *3)))) (** (*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-568)) (-5 *1 (-829 *4)) (-4 *4 (-1047)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-829 *3)) (-4 *3 (-1047)))) (-1624 (*1 *2 *3 *2) (-12 (-5 *3 (-123)) (-5 *1 (-829 *2)) (-4 *2 (-1047)))) (-3448 (*1 *1 *2 *3) (-12 (-5 *3 (-363 (-123))) (-5 *1 (-829 *2)) (-4 *2 (-1047))))) 
+(-13 (-1047) (-1037 |#1|) (-1037 (-123)) (-281 |#1| |#1|) (-10 -8 (IF (|has| |#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |#1| (-172)) (PROGN (-6 (-43 |#1|)) (-15 -1419 ($ $)) (-15 -1419 ($ $ $)) (-15 -3756 (|#1| |#1|))) |noBranch|) (-15 -2513 ($ $ (-1 |#1| |#1|))) (-15 -3122 ($ $ (-1 |#1| |#1|))) (-15 ** ($ (-123) (-568))) (-15 ** ($ $ (-568))) (-15 -1624 (|#1| (-123) |#1|)) (-15 -3448 ($ |#1| (-363 (-123)))))) 
+((-3617 (((-205 (-511)) (-1143)) 8))) 
+(((-830) (-10 -7 (-15 -3617 ((-205 (-511)) (-1143))))) (T -830)) 
+((-3617 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-205 (-511))) (-5 *1 (-830))))) 
+(-10 -7 (-15 -3617 ((-205 (-511)) (-1143)))) 
+((-2449 (((-121) $ $) 7)) (-3994 (((-1035) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) 13) (((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 12)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 15) (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) 14)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-1719 (((-121) $ $) 6))) 
 (((-831) (-1275)) (T -831)) 
-((-3029 (*1 *2 *3 *4) (-12 (-4 *1 (-831)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (-5 *2 (-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)))))) (-3029 (*1 *2 *3 *4) (-12 (-4 *1 (-831)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) (-5 *2 (-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)))))) (-2855 (*1 *2 *3) (-12 (-4 *1 (-831)) (-5 *3 (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) (-5 *2 (-1035)))) (-2855 (*1 *2 *3) (-12 (-4 *1 (-831)) (-5 *3 (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (-5 *2 (-1035))))) 
-(-13 (-1090) (-10 -7 (-15 -3029 ((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215))))))) (-15 -3029 ((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215)))))) (-15 -2855 ((-1035) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215)))))) (-15 -2855 ((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215))))))))) 
+((-3031 (*1 *2 *3 *4) (-12 (-4 *1 (-831)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (-5 *2 (-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)))))) (-3031 (*1 *2 *3 *4) (-12 (-4 *1 (-831)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) (-5 *2 (-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)))))) (-3994 (*1 *2 *3) (-12 (-4 *1 (-831)) (-5 *3 (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) (-5 *2 (-1035)))) (-3994 (*1 *2 *3) (-12 (-4 *1 (-831)) (-5 *3 (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (-5 *2 (-1035))))) 
+(-13 (-1090) (-10 -7 (-15 -3031 ((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215))))))) (-15 -3031 ((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215)))))) (-15 -3994 ((-1035) (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215)))))) (-15 -3994 ((-1035) (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215))))))))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-4086 (((-1035) (-634 (-310 (-381))) (-634 (-381))) 143) (((-1035) (-310 (-381)) (-634 (-381))) 141) (((-1035) (-310 (-381)) (-634 (-381)) (-634 (-835 (-381))) (-634 (-835 (-381)))) 140) (((-1035) (-310 (-381)) (-634 (-381)) (-634 (-835 (-381))) (-634 (-310 (-381))) (-634 (-835 (-381)))) 139) (((-1035) (-833)) 112) (((-1035) (-833) (-1059)) 111)) (-3029 (((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143)))) (-833) (-1059)) 76) (((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143)))) (-833)) 78)) (-2642 (((-1035) (-634 (-310 (-381))) (-634 (-381))) 144) (((-1035) (-833)) 128))) 
-(((-832) (-10 -7 (-15 -3029 ((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143)))) (-833))) (-15 -3029 ((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143)))) (-833) (-1059))) (-15 -4086 ((-1035) (-833) (-1059))) (-15 -4086 ((-1035) (-833))) (-15 -2642 ((-1035) (-833))) (-15 -4086 ((-1035) (-310 (-381)) (-634 (-381)) (-634 (-835 (-381))) (-634 (-310 (-381))) (-634 (-835 (-381))))) (-15 -4086 ((-1035) (-310 (-381)) (-634 (-381)) (-634 (-835 (-381))) (-634 (-835 (-381))))) (-15 -4086 ((-1035) (-310 (-381)) (-634 (-381)))) (-15 -4086 ((-1035) (-634 (-310 (-381))) (-634 (-381)))) (-15 -2642 ((-1035) (-634 (-310 (-381))) (-634 (-381)))))) (T -832)) 
-((-2642 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-310 (-381)))) (-5 *4 (-634 (-381))) (-5 *2 (-1035)) (-5 *1 (-832)))) (-4086 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-310 (-381)))) (-5 *4 (-634 (-381))) (-5 *2 (-1035)) (-5 *1 (-832)))) (-4086 (*1 *2 *3 *4) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-634 (-381))) (-5 *2 (-1035)) (-5 *1 (-832)))) (-4086 (*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-634 (-381))) (-5 *5 (-634 (-835 (-381)))) (-5 *2 (-1035)) (-5 *1 (-832)))) (-4086 (*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-634 (-381))) (-5 *5 (-634 (-835 (-381)))) (-5 *6 (-634 (-310 (-381)))) (-5 *3 (-310 (-381))) (-5 *2 (-1035)) (-5 *1 (-832)))) (-2642 (*1 *2 *3) (-12 (-5 *3 (-833)) (-5 *2 (-1035)) (-5 *1 (-832)))) (-4086 (*1 *2 *3) (-12 (-5 *3 (-833)) (-5 *2 (-1035)) (-5 *1 (-832)))) (-4086 (*1 *2 *3 *4) (-12 (-5 *3 (-833)) (-5 *4 (-1059)) (-5 *2 (-1035)) (-5 *1 (-832)))) (-3029 (*1 *2 *3 *4) (-12 (-5 *3 (-833)) (-5 *4 (-1059)) (-5 *2 (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-832)))) (-3029 (*1 *2 *3) (-12 (-5 *3 (-833)) (-5 *2 (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-832))))) 
-(-10 -7 (-15 -3029 ((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143)))) (-833))) (-15 -3029 ((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143)))) (-833) (-1059))) (-15 -4086 ((-1035) (-833) (-1059))) (-15 -4086 ((-1035) (-833))) (-15 -2642 ((-1035) (-833))) (-15 -4086 ((-1035) (-310 (-381)) (-634 (-381)) (-634 (-835 (-381))) (-634 (-310 (-381))) (-634 (-835 (-381))))) (-15 -4086 ((-1035) (-310 (-381)) (-634 (-381)) (-634 (-835 (-381))) (-634 (-835 (-381))))) (-15 -4086 ((-1035) (-310 (-381)) (-634 (-381)))) (-15 -4086 ((-1035) (-634 (-310 (-381))) (-634 (-381)))) (-15 -2642 ((-1035) (-634 (-310 (-381))) (-634 (-381))))) 
-((-2447 (((-121) $ $) NIL)) (-2854 (((-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215)))))) $) 15)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 14) (($ (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 8) (($ (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) 10) (($ (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))))) 12)) (-1717 (((-121) $ $) NIL))) 
-(((-833) (-13 (-1090) (-10 -8 (-15 -2745 ($ (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215))))))) (-15 -2745 ($ (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215)))))) (-15 -2745 ($ (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215)))))))) (-15 -2745 ((-850) $)) (-15 -2854 ((-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215)))))) $))))) (T -833)) 
-((-2745 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-833)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (-5 *1 (-833)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) (-5 *1 (-833)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))))) (-5 *1 (-833)))) (-2854 (*1 *2 *1) (-12 (-5 *2 (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))))) (-5 *1 (-833))))) 
-(-13 (-1090) (-10 -8 (-15 -2745 ($ (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215))))))) (-15 -2745 ($ (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215)))))) (-15 -2745 ($ (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215)))))))) (-15 -2745 ((-850) $)) (-15 -2854 ((-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215)))))) $)))) 
-((-2795 (((-835 |#2|) (-1 |#2| |#1|) (-835 |#1|) (-835 |#2|) (-835 |#2|)) 13) (((-835 |#2|) (-1 |#2| |#1|) (-835 |#1|)) 14))) 
-(((-834 |#1| |#2|) (-10 -7 (-15 -2795 ((-835 |#2|) (-1 |#2| |#1|) (-835 |#1|))) (-15 -2795 ((-835 |#2|) (-1 |#2| |#1|) (-835 |#1|) (-835 |#2|) (-835 |#2|)))) (-1090) (-1090)) (T -834)) 
-((-2795 (*1 *2 *3 *4 *2 *2) (-12 (-5 *2 (-835 *6)) (-5 *3 (-1 *6 *5)) (-5 *4 (-835 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *1 (-834 *5 *6)))) (-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-835 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-835 *6)) (-5 *1 (-834 *5 *6))))) 
-(-10 -7 (-15 -2795 ((-835 |#2|) (-1 |#2| |#1|) (-835 |#1|))) (-15 -2795 ((-835 |#2|) (-1 |#2| |#1|) (-835 |#1|) (-835 |#2|) (-835 |#2|)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL (|has| |#1| (-21)))) (-2698 (((-1108) $) 24)) (-3134 (((-3 $ "failed") $ $) NIL (|has| |#1| (-21)))) (-3662 (((-568) $) NIL (|has| |#1| (-840)))) (-2671 (($) NIL (|has| |#1| (-21)) CONST)) (-3666 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 16)) (-2854 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) 9)) (-2925 (((-3 $ "failed") $) 46 (|has| |#1| (-840)))) (-1642 (((-3 (-409 (-568)) "failed") $) 53 (|has| |#1| (-550)))) (-2688 (((-121) $) 48 (|has| |#1| (-550)))) (-2425 (((-409 (-568)) $) 51 (|has| |#1| (-550)))) (-2033 (((-121) $) NIL (|has| |#1| (-840)))) (-3602 (($) 13)) (-2735 (((-121) $) NIL (|has| |#1| (-840)))) (-2245 (((-121) $) NIL (|has| |#1| (-840)))) (-3594 (($) 14)) (-2521 (($ $ $) NIL (|has| |#1| (-840)))) (-3268 (($ $ $) NIL (|has| |#1| (-840)))) (-4487 (((-1143) $) NIL)) (-3794 (((-121) $) 12)) (-4022 (((-1108) $) NIL)) (-3449 (((-121) $) 11)) (-2745 (((-850) $) 22) (($ (-409 (-568))) NIL (|has| |#1| (-1037 (-409 (-568))))) (($ |#1|) 8) (($ (-568)) NIL (-2198 (|has| |#1| (-840)) (|has| |#1| (-1037 (-568)))))) (-4078 (((-763)) 40 (|has| |#1| (-840)))) (-2897 (($ $) NIL (|has| |#1| (-840)))) (-1887 (($ $ (-917)) NIL (|has| |#1| (-840))) (($ $ (-763)) NIL (|has| |#1| (-840)))) (-3056 (($) 28 (|has| |#1| (-21)) CONST)) (-1556 (($) 37 (|has| |#1| (-840)) CONST)) (-1751 (((-121) $ $) NIL (|has| |#1| (-840)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-840)))) (-1717 (((-121) $ $) 26)) (-1745 (((-121) $ $) NIL (|has| |#1| (-840)))) (-1732 (((-121) $ $) 47 (|has| |#1| (-840)))) (-1773 (($ $ $) NIL (|has| |#1| (-21))) (($ $) 33 (|has| |#1| (-21)))) (-1767 (($ $ $) 35 (|has| |#1| (-21)))) (** (($ $ (-917)) NIL (|has| |#1| (-840))) (($ $ (-763)) NIL (|has| |#1| (-840)))) (* (($ $ $) 43 (|has| |#1| (-840))) (($ (-568) $) 31 (|has| |#1| (-21))) (($ (-763) $) NIL (|has| |#1| (-21))) (($ (-917) $) NIL (|has| |#1| (-21))))) 
-(((-835 |#1|) (-13 (-1090) (-413 |#1|) (-10 -8 (-15 -3602 ($)) (-15 -3594 ($)) (-15 -3449 ((-121) $)) (-15 -3794 ((-121) $)) (-15 -2698 ((-1108) $)) (IF (|has| |#1| (-21)) (-6 (-21)) |noBranch|) (IF (|has| |#1| (-840)) (-6 (-840)) |noBranch|) (IF (|has| |#1| (-550)) (PROGN (-15 -2688 ((-121) $)) (-15 -2425 ((-409 (-568)) $)) (-15 -1642 ((-3 (-409 (-568)) "failed") $))) |noBranch|))) (-1090)) (T -835)) 
-((-3602 (*1 *1) (-12 (-5 *1 (-835 *2)) (-4 *2 (-1090)))) (-3594 (*1 *1) (-12 (-5 *1 (-835 *2)) (-4 *2 (-1090)))) (-3449 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-835 *3)) (-4 *3 (-1090)))) (-3794 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-835 *3)) (-4 *3 (-1090)))) (-2698 (*1 *2 *1) (-12 (-5 *2 (-1108)) (-5 *1 (-835 *3)) (-4 *3 (-1090)))) (-2688 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-835 *3)) (-4 *3 (-550)) (-4 *3 (-1090)))) (-2425 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-835 *3)) (-4 *3 (-550)) (-4 *3 (-1090)))) (-1642 (*1 *2 *1) (|partial| -12 (-5 *2 (-409 (-568))) (-5 *1 (-835 *3)) (-4 *3 (-550)) (-4 *3 (-1090))))) 
-(-13 (-1090) (-413 |#1|) (-10 -8 (-15 -3602 ($)) (-15 -3594 ($)) (-15 -3449 ((-121) $)) (-15 -3794 ((-121) $)) (-15 -2698 ((-1108) $)) (IF (|has| |#1| (-21)) (-6 (-21)) |noBranch|) (IF (|has| |#1| (-840)) (-6 (-840)) |noBranch|) (IF (|has| |#1| (-550)) (PROGN (-15 -2688 ((-121) $)) (-15 -2425 ((-409 (-568)) $)) (-15 -1642 ((-3 (-409 (-568)) "failed") $))) |noBranch|))) 
-((-2447 (((-121) $ $) 7)) (-3983 (((-763)) 19)) (-1731 (($) 22)) (-2521 (($ $ $) 12)) (-3268 (($ $ $) 13)) (-3683 (((-917) $) 21)) (-4487 (((-1143) $) 9)) (-4355 (($ (-917)) 20)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-1751 (((-121) $ $) 15)) (-1738 (((-121) $ $) 16)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 14)) (-1732 (((-121) $ $) 17))) 
+((-4088 (((-1035) (-634 (-310 (-381))) (-634 (-381))) 143) (((-1035) (-310 (-381)) (-634 (-381))) 141) (((-1035) (-310 (-381)) (-634 (-381)) (-634 (-835 (-381))) (-634 (-835 (-381)))) 140) (((-1035) (-310 (-381)) (-634 (-381)) (-634 (-835 (-381))) (-634 (-310 (-381))) (-634 (-835 (-381)))) 139) (((-1035) (-833)) 112) (((-1035) (-833) (-1059)) 111)) (-3031 (((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143)))) (-833) (-1059)) 76) (((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143)))) (-833)) 78)) (-4329 (((-1035) (-634 (-310 (-381))) (-634 (-381))) 144) (((-1035) (-833)) 128))) 
+(((-832) (-10 -7 (-15 -3031 ((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143)))) (-833))) (-15 -3031 ((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143)))) (-833) (-1059))) (-15 -4088 ((-1035) (-833) (-1059))) (-15 -4088 ((-1035) (-833))) (-15 -4329 ((-1035) (-833))) (-15 -4088 ((-1035) (-310 (-381)) (-634 (-381)) (-634 (-835 (-381))) (-634 (-310 (-381))) (-634 (-835 (-381))))) (-15 -4088 ((-1035) (-310 (-381)) (-634 (-381)) (-634 (-835 (-381))) (-634 (-835 (-381))))) (-15 -4088 ((-1035) (-310 (-381)) (-634 (-381)))) (-15 -4088 ((-1035) (-634 (-310 (-381))) (-634 (-381)))) (-15 -4329 ((-1035) (-634 (-310 (-381))) (-634 (-381)))))) (T -832)) 
+((-4329 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-310 (-381)))) (-5 *4 (-634 (-381))) (-5 *2 (-1035)) (-5 *1 (-832)))) (-4088 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-310 (-381)))) (-5 *4 (-634 (-381))) (-5 *2 (-1035)) (-5 *1 (-832)))) (-4088 (*1 *2 *3 *4) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-634 (-381))) (-5 *2 (-1035)) (-5 *1 (-832)))) (-4088 (*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-634 (-381))) (-5 *5 (-634 (-835 (-381)))) (-5 *2 (-1035)) (-5 *1 (-832)))) (-4088 (*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-634 (-381))) (-5 *5 (-634 (-835 (-381)))) (-5 *6 (-634 (-310 (-381)))) (-5 *3 (-310 (-381))) (-5 *2 (-1035)) (-5 *1 (-832)))) (-4329 (*1 *2 *3) (-12 (-5 *3 (-833)) (-5 *2 (-1035)) (-5 *1 (-832)))) (-4088 (*1 *2 *3) (-12 (-5 *3 (-833)) (-5 *2 (-1035)) (-5 *1 (-832)))) (-4088 (*1 *2 *3 *4) (-12 (-5 *3 (-833)) (-5 *4 (-1059)) (-5 *2 (-1035)) (-5 *1 (-832)))) (-3031 (*1 *2 *3 *4) (-12 (-5 *3 (-833)) (-5 *4 (-1059)) (-5 *2 (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-832)))) (-3031 (*1 *2 *3) (-12 (-5 *3 (-833)) (-5 *2 (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-832))))) 
+(-10 -7 (-15 -3031 ((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143)))) (-833))) (-15 -3031 ((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143)))) (-833) (-1059))) (-15 -4088 ((-1035) (-833) (-1059))) (-15 -4088 ((-1035) (-833))) (-15 -4329 ((-1035) (-833))) (-15 -4088 ((-1035) (-310 (-381)) (-634 (-381)) (-634 (-835 (-381))) (-634 (-310 (-381))) (-634 (-835 (-381))))) (-15 -4088 ((-1035) (-310 (-381)) (-634 (-381)) (-634 (-835 (-381))) (-634 (-835 (-381))))) (-15 -4088 ((-1035) (-310 (-381)) (-634 (-381)))) (-15 -4088 ((-1035) (-634 (-310 (-381))) (-634 (-381)))) (-15 -4329 ((-1035) (-634 (-310 (-381))) (-634 (-381))))) 
+((-2449 (((-121) $ $) NIL)) (-2857 (((-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215)))))) $) 15)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 14) (($ (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) 8) (($ (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) 10) (($ (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))))) 12)) (-1719 (((-121) $ $) NIL))) 
+(((-833) (-13 (-1090) (-10 -8 (-15 -2747 ($ (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215))))))) (-15 -2747 ($ (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215)))))) (-15 -2747 ($ (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215)))))))) (-15 -2747 ((-850) $)) (-15 -2857 ((-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215)))))) $))))) (T -833)) 
+((-2747 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-833)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (-5 *1 (-833)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) (-5 *1 (-833)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))))) (-5 *1 (-833)))) (-2857 (*1 *2 *1) (-12 (-5 *2 (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))))) (-5 *1 (-833))))) 
+(-13 (-1090) (-10 -8 (-15 -2747 ($ (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215))))))) (-15 -2747 ($ (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215)))))) (-15 -2747 ($ (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215)))))))) (-15 -2747 ((-850) $)) (-15 -2857 ((-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215)))))) $)))) 
+((-2797 (((-835 |#2|) (-1 |#2| |#1|) (-835 |#1|) (-835 |#2|) (-835 |#2|)) 13) (((-835 |#2|) (-1 |#2| |#1|) (-835 |#1|)) 14))) 
+(((-834 |#1| |#2|) (-10 -7 (-15 -2797 ((-835 |#2|) (-1 |#2| |#1|) (-835 |#1|))) (-15 -2797 ((-835 |#2|) (-1 |#2| |#1|) (-835 |#1|) (-835 |#2|) (-835 |#2|)))) (-1090) (-1090)) (T -834)) 
+((-2797 (*1 *2 *3 *4 *2 *2) (-12 (-5 *2 (-835 *6)) (-5 *3 (-1 *6 *5)) (-5 *4 (-835 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *1 (-834 *5 *6)))) (-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-835 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-835 *6)) (-5 *1 (-834 *5 *6))))) 
+(-10 -7 (-15 -2797 ((-835 |#2|) (-1 |#2| |#1|) (-835 |#1|))) (-15 -2797 ((-835 |#2|) (-1 |#2| |#1|) (-835 |#1|) (-835 |#2|) (-835 |#2|)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL (|has| |#1| (-21)))) (-1406 (((-1108) $) 24)) (-2689 (((-3 $ "failed") $ $) NIL (|has| |#1| (-21)))) (-3337 (((-568) $) NIL (|has| |#1| (-840)))) (-4490 (($) NIL (|has| |#1| (-21)) CONST)) (-3668 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 16)) (-2857 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) 9)) (-2902 (((-3 $ "failed") $) 46 (|has| |#1| (-840)))) (-3254 (((-3 (-409 (-568)) "failed") $) 53 (|has| |#1| (-550)))) (-1338 (((-121) $) 48 (|has| |#1| (-550)))) (-2394 (((-409 (-568)) $) 51 (|has| |#1| (-550)))) (-1436 (((-121) $) NIL (|has| |#1| (-840)))) (-3604 (($) 13)) (-1598 (((-121) $) NIL (|has| |#1| (-840)))) (-2859 (((-121) $) NIL (|has| |#1| (-840)))) (-3596 (($) 14)) (-1732 (($ $ $) NIL (|has| |#1| (-840)))) (-2047 (($ $ $) NIL (|has| |#1| (-840)))) (-1893 (((-1143) $) NIL)) (-2773 (((-121) $) 12)) (-4025 (((-1108) $) NIL)) (-3557 (((-121) $) 11)) (-2747 (((-850) $) 22) (($ (-409 (-568))) NIL (|has| |#1| (-1037 (-409 (-568))))) (($ |#1|) 8) (($ (-568)) NIL (-2199 (|has| |#1| (-840)) (|has| |#1| (-1037 (-568)))))) (-3425 (((-763)) 40 (|has| |#1| (-840)))) (-2811 (($ $) NIL (|has| |#1| (-840)))) (-1889 (($ $ (-917)) NIL (|has| |#1| (-840))) (($ $ (-763)) NIL (|has| |#1| (-840)))) (-3058 (($) 28 (|has| |#1| (-21)) CONST)) (-1557 (($) 37 (|has| |#1| (-840)) CONST)) (-1753 (((-121) $ $) NIL (|has| |#1| (-840)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-840)))) (-1719 (((-121) $ $) 26)) (-1747 (((-121) $ $) NIL (|has| |#1| (-840)))) (-1734 (((-121) $ $) 47 (|has| |#1| (-840)))) (-1775 (($ $ $) NIL (|has| |#1| (-21))) (($ $) 33 (|has| |#1| (-21)))) (-1769 (($ $ $) 35 (|has| |#1| (-21)))) (** (($ $ (-917)) NIL (|has| |#1| (-840))) (($ $ (-763)) NIL (|has| |#1| (-840)))) (* (($ $ $) 43 (|has| |#1| (-840))) (($ (-568) $) 31 (|has| |#1| (-21))) (($ (-763) $) NIL (|has| |#1| (-21))) (($ (-917) $) NIL (|has| |#1| (-21))))) 
+(((-835 |#1|) (-13 (-1090) (-413 |#1|) (-10 -8 (-15 -3604 ($)) (-15 -3596 ($)) (-15 -3557 ((-121) $)) (-15 -2773 ((-121) $)) (-15 -1406 ((-1108) $)) (IF (|has| |#1| (-21)) (-6 (-21)) |noBranch|) (IF (|has| |#1| (-840)) (-6 (-840)) |noBranch|) (IF (|has| |#1| (-550)) (PROGN (-15 -1338 ((-121) $)) (-15 -2394 ((-409 (-568)) $)) (-15 -3254 ((-3 (-409 (-568)) "failed") $))) |noBranch|))) (-1090)) (T -835)) 
+((-3604 (*1 *1) (-12 (-5 *1 (-835 *2)) (-4 *2 (-1090)))) (-3596 (*1 *1) (-12 (-5 *1 (-835 *2)) (-4 *2 (-1090)))) (-3557 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-835 *3)) (-4 *3 (-1090)))) (-2773 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-835 *3)) (-4 *3 (-1090)))) (-1406 (*1 *2 *1) (-12 (-5 *2 (-1108)) (-5 *1 (-835 *3)) (-4 *3 (-1090)))) (-1338 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-835 *3)) (-4 *3 (-550)) (-4 *3 (-1090)))) (-2394 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-835 *3)) (-4 *3 (-550)) (-4 *3 (-1090)))) (-3254 (*1 *2 *1) (|partial| -12 (-5 *2 (-409 (-568))) (-5 *1 (-835 *3)) (-4 *3 (-550)) (-4 *3 (-1090))))) 
+(-13 (-1090) (-413 |#1|) (-10 -8 (-15 -3604 ($)) (-15 -3596 ($)) (-15 -3557 ((-121) $)) (-15 -2773 ((-121) $)) (-15 -1406 ((-1108) $)) (IF (|has| |#1| (-21)) (-6 (-21)) |noBranch|) (IF (|has| |#1| (-840)) (-6 (-840)) |noBranch|) (IF (|has| |#1| (-550)) (PROGN (-15 -1338 ((-121) $)) (-15 -2394 ((-409 (-568)) $)) (-15 -3254 ((-3 (-409 (-568)) "failed") $))) |noBranch|))) 
+((-2449 (((-121) $ $) 7)) (-3986 (((-763)) 19)) (-1733 (($) 22)) (-1732 (($ $ $) 12)) (-2047 (($ $ $) 13)) (-2291 (((-917) $) 21)) (-1893 (((-1143) $) 9)) (-4357 (($ (-917)) 20)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-1753 (((-121) $ $) 15)) (-1740 (((-121) $ $) 16)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 14)) (-1734 (((-121) $ $) 17))) 
 (((-836) (-1275)) (T -836)) 
 NIL 
 (-13 (-842) (-370)) 
 (((-105) . T) ((-608 (-850)) . T) ((-370) . T) ((-842) . T) ((-1090) . T)) 
-((-3128 (((-121) (-1244 |#2|) (-1244 |#2|)) 17)) (-1810 (((-121) (-1244 |#2|) (-1244 |#2|)) 18)) (-1831 (((-121) (-1244 |#2|) (-1244 |#2|)) 14))) 
-(((-837 |#1| |#2|) (-10 -7 (-15 -1831 ((-121) (-1244 |#2|) (-1244 |#2|))) (-15 -3128 ((-121) (-1244 |#2|) (-1244 |#2|))) (-15 -1810 ((-121) (-1244 |#2|) (-1244 |#2|)))) (-763) (-787)) (T -837)) 
-((-1810 (*1 *2 *3 *3) (-12 (-5 *3 (-1244 *5)) (-4 *5 (-787)) (-5 *2 (-121)) (-5 *1 (-837 *4 *5)) (-14 *4 (-763)))) (-3128 (*1 *2 *3 *3) (-12 (-5 *3 (-1244 *5)) (-4 *5 (-787)) (-5 *2 (-121)) (-5 *1 (-837 *4 *5)) (-14 *4 (-763)))) (-1831 (*1 *2 *3 *3) (-12 (-5 *3 (-1244 *5)) (-4 *5 (-787)) (-5 *2 (-121)) (-5 *1 (-837 *4 *5)) (-14 *4 (-763))))) 
-(-10 -7 (-15 -1831 ((-121) (-1244 |#2|) (-1244 |#2|))) (-15 -3128 ((-121) (-1244 |#2|) (-1244 |#2|))) (-15 -1810 ((-121) (-1244 |#2|) (-1244 |#2|)))) 
-((-2447 (((-121) $ $) 7)) (-2671 (($) 23 T CONST)) (-2925 (((-3 $ "failed") $) 27)) (-2735 (((-121) $) 24)) (-2521 (($ $ $) 12)) (-3268 (($ $ $) 13)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-1887 (($ $ (-763)) 26) (($ $ (-917)) 21)) (-1556 (($) 22 T CONST)) (-1751 (((-121) $ $) 15)) (-1738 (((-121) $ $) 16)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 14)) (-1732 (((-121) $ $) 17)) (** (($ $ (-763)) 25) (($ $ (-917)) 20)) (* (($ $ $) 19))) 
+((-2655 (((-121) (-1244 |#2|) (-1244 |#2|)) 17)) (-2182 (((-121) (-1244 |#2|) (-1244 |#2|)) 18)) (-2298 (((-121) (-1244 |#2|) (-1244 |#2|)) 14))) 
+(((-837 |#1| |#2|) (-10 -7 (-15 -2298 ((-121) (-1244 |#2|) (-1244 |#2|))) (-15 -2655 ((-121) (-1244 |#2|) (-1244 |#2|))) (-15 -2182 ((-121) (-1244 |#2|) (-1244 |#2|)))) (-763) (-787)) (T -837)) 
+((-2182 (*1 *2 *3 *3) (-12 (-5 *3 (-1244 *5)) (-4 *5 (-787)) (-5 *2 (-121)) (-5 *1 (-837 *4 *5)) (-14 *4 (-763)))) (-2655 (*1 *2 *3 *3) (-12 (-5 *3 (-1244 *5)) (-4 *5 (-787)) (-5 *2 (-121)) (-5 *1 (-837 *4 *5)) (-14 *4 (-763)))) (-2298 (*1 *2 *3 *3) (-12 (-5 *3 (-1244 *5)) (-4 *5 (-787)) (-5 *2 (-121)) (-5 *1 (-837 *4 *5)) (-14 *4 (-763))))) 
+(-10 -7 (-15 -2298 ((-121) (-1244 |#2|) (-1244 |#2|))) (-15 -2655 ((-121) (-1244 |#2|) (-1244 |#2|))) (-15 -2182 ((-121) (-1244 |#2|) (-1244 |#2|)))) 
+((-2449 (((-121) $ $) 7)) (-4490 (($) 23 T CONST)) (-2902 (((-3 $ "failed") $) 27)) (-1598 (((-121) $) 24)) (-1732 (($ $ $) 12)) (-2047 (($ $ $) 13)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-1889 (($ $ (-763)) 26) (($ $ (-917)) 21)) (-1557 (($) 22 T CONST)) (-1753 (((-121) $ $) 15)) (-1740 (((-121) $ $) 16)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 14)) (-1734 (((-121) $ $) 17)) (** (($ $ (-763)) 25) (($ $ (-917)) 20)) (* (($ $ $) 19))) 
 (((-838) (-1275)) (T -838)) 
 NIL 
 (-13 (-842) (-716)) 
 (((-105) . T) ((-608 (-850)) . T) ((-716) . T) ((-842) . T) ((-1102) . T) ((-1090) . T)) 
-((-3662 (((-568) $) 17)) (-2033 (((-121) $) 10)) (-2245 (((-121) $) 11)) (-2897 (($ $) 19))) 
-(((-839 |#1|) (-10 -8 (-15 -2897 (|#1| |#1|)) (-15 -3662 ((-568) |#1|)) (-15 -2245 ((-121) |#1|)) (-15 -2033 ((-121) |#1|))) (-840)) (T -839)) 
+((-3337 (((-568) $) 17)) (-1436 (((-121) $) 10)) (-2859 (((-121) $) 11)) (-2811 (($ $) 19))) 
+(((-839 |#1|) (-10 -8 (-15 -2811 (|#1| |#1|)) (-15 -3337 ((-568) |#1|)) (-15 -2859 ((-121) |#1|)) (-15 -1436 ((-121) |#1|))) (-840)) (T -839)) 
 NIL 
-(-10 -8 (-15 -2897 (|#1| |#1|)) (-15 -3662 ((-568) |#1|)) (-15 -2245 ((-121) |#1|)) (-15 -2033 ((-121) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 23)) (-3134 (((-3 $ "failed") $ $) 25)) (-3662 (((-568) $) 32)) (-2671 (($) 22 T CONST)) (-2925 (((-3 $ "failed") $) 38)) (-2033 (((-121) $) 34)) (-2735 (((-121) $) 41)) (-2245 (((-121) $) 33)) (-2521 (($ $ $) 12)) (-3268 (($ $ $) 13)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11) (($ (-568)) 44)) (-4078 (((-763)) 43)) (-2897 (($ $) 31)) (-1887 (($ $ (-763)) 39) (($ $ (-917)) 35)) (-3056 (($) 21 T CONST)) (-1556 (($) 42 T CONST)) (-1751 (((-121) $ $) 15)) (-1738 (((-121) $ $) 16)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 14)) (-1732 (((-121) $ $) 17)) (-1773 (($ $ $) 27) (($ $) 26)) (-1767 (($ $ $) 19)) (** (($ $ (-763)) 40) (($ $ (-917)) 36)) (* (($ (-763) $) 24) (($ (-917) $) 20) (($ (-568) $) 28) (($ $ $) 37))) 
+(-10 -8 (-15 -2811 (|#1| |#1|)) (-15 -3337 ((-568) |#1|)) (-15 -2859 ((-121) |#1|)) (-15 -1436 ((-121) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 23)) (-2689 (((-3 $ "failed") $ $) 25)) (-3337 (((-568) $) 32)) (-4490 (($) 22 T CONST)) (-2902 (((-3 $ "failed") $) 38)) (-1436 (((-121) $) 34)) (-1598 (((-121) $) 41)) (-2859 (((-121) $) 33)) (-1732 (($ $ $) 12)) (-2047 (($ $ $) 13)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11) (($ (-568)) 44)) (-3425 (((-763)) 43)) (-2811 (($ $) 31)) (-1889 (($ $ (-763)) 39) (($ $ (-917)) 35)) (-3058 (($) 21 T CONST)) (-1557 (($) 42 T CONST)) (-1753 (((-121) $ $) 15)) (-1740 (((-121) $ $) 16)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 14)) (-1734 (((-121) $ $) 17)) (-1775 (($ $ $) 27) (($ $) 26)) (-1769 (($ $ $) 19)) (** (($ $ (-763)) 40) (($ $ (-917)) 36)) (* (($ (-763) $) 24) (($ (-917) $) 20) (($ (-568) $) 28) (($ $ $) 37))) 
 (((-840) (-1275)) (T -840)) 
-((-2033 (*1 *2 *1) (-12 (-4 *1 (-840)) (-5 *2 (-121)))) (-2245 (*1 *2 *1) (-12 (-4 *1 (-840)) (-5 *2 (-121)))) (-3662 (*1 *2 *1) (-12 (-4 *1 (-840)) (-5 *2 (-568)))) (-2897 (*1 *1 *1) (-4 *1 (-840)))) 
-(-13 (-786) (-1047) (-716) (-10 -8 (-15 -2033 ((-121) $)) (-15 -2245 ((-121) $)) (-15 -3662 ((-568) $)) (-15 -2897 ($ $)))) 
+((-1436 (*1 *2 *1) (-12 (-4 *1 (-840)) (-5 *2 (-121)))) (-2859 (*1 *2 *1) (-12 (-4 *1 (-840)) (-5 *2 (-121)))) (-3337 (*1 *2 *1) (-12 (-4 *1 (-840)) (-5 *2 (-568)))) (-2811 (*1 *1 *1) (-4 *1 (-840)))) 
+(-13 (-786) (-1047) (-716) (-10 -8 (-15 -1436 ((-121) $)) (-15 -2859 ((-121) $)) (-15 -3337 ((-568) $)) (-15 -2811 ($ $)))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 $) . T) ((-716) . T) ((-786) . T) ((-787) . T) ((-789) . T) ((-790) . T) ((-842) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-2521 (($ $ $) 10)) (-3268 (($ $ $) 9)) (-1751 (((-121) $ $) 12)) (-1738 (((-121) $ $) 11)) (-1745 (((-121) $ $) 13))) 
-(((-841 |#1|) (-10 -8 (-15 -2521 (|#1| |#1| |#1|)) (-15 -3268 (|#1| |#1| |#1|)) (-15 -1745 ((-121) |#1| |#1|)) (-15 -1751 ((-121) |#1| |#1|)) (-15 -1738 ((-121) |#1| |#1|))) (-842)) (T -841)) 
+((-1732 (($ $ $) 10)) (-2047 (($ $ $) 9)) (-1753 (((-121) $ $) 12)) (-1740 (((-121) $ $) 11)) (-1747 (((-121) $ $) 13))) 
+(((-841 |#1|) (-10 -8 (-15 -1732 (|#1| |#1| |#1|)) (-15 -2047 (|#1| |#1| |#1|)) (-15 -1747 ((-121) |#1| |#1|)) (-15 -1753 ((-121) |#1| |#1|)) (-15 -1740 ((-121) |#1| |#1|))) (-842)) (T -841)) 
 NIL 
-(-10 -8 (-15 -2521 (|#1| |#1| |#1|)) (-15 -3268 (|#1| |#1| |#1|)) (-15 -1745 ((-121) |#1| |#1|)) (-15 -1751 ((-121) |#1| |#1|)) (-15 -1738 ((-121) |#1| |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2521 (($ $ $) 12)) (-3268 (($ $ $) 13)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-1751 (((-121) $ $) 15)) (-1738 (((-121) $ $) 16)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 14)) (-1732 (((-121) $ $) 17))) 
+(-10 -8 (-15 -1732 (|#1| |#1| |#1|)) (-15 -2047 (|#1| |#1| |#1|)) (-15 -1747 ((-121) |#1| |#1|)) (-15 -1753 ((-121) |#1| |#1|)) (-15 -1740 ((-121) |#1| |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1732 (($ $ $) 12)) (-2047 (($ $ $) 13)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-1753 (((-121) $ $) 15)) (-1740 (((-121) $ $) 16)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 14)) (-1734 (((-121) $ $) 17))) 
 (((-842) (-1275)) (T -842)) 
-((-1732 (*1 *2 *1 *1) (-12 (-4 *1 (-842)) (-5 *2 (-121)))) (-1738 (*1 *2 *1 *1) (-12 (-4 *1 (-842)) (-5 *2 (-121)))) (-1751 (*1 *2 *1 *1) (-12 (-4 *1 (-842)) (-5 *2 (-121)))) (-1745 (*1 *2 *1 *1) (-12 (-4 *1 (-842)) (-5 *2 (-121)))) (-3268 (*1 *1 *1 *1) (-4 *1 (-842))) (-2521 (*1 *1 *1 *1) (-4 *1 (-842)))) 
-(-13 (-1090) (-10 -8 (-15 -1732 ((-121) $ $)) (-15 -1738 ((-121) $ $)) (-15 -1751 ((-121) $ $)) (-15 -1745 ((-121) $ $)) (-15 -3268 ($ $ $)) (-15 -2521 ($ $ $)))) 
+((-1734 (*1 *2 *1 *1) (-12 (-4 *1 (-842)) (-5 *2 (-121)))) (-1740 (*1 *2 *1 *1) (-12 (-4 *1 (-842)) (-5 *2 (-121)))) (-1753 (*1 *2 *1 *1) (-12 (-4 *1 (-842)) (-5 *2 (-121)))) (-1747 (*1 *2 *1 *1) (-12 (-4 *1 (-842)) (-5 *2 (-121)))) (-2047 (*1 *1 *1 *1) (-4 *1 (-842))) (-1732 (*1 *1 *1 *1) (-4 *1 (-842)))) 
+(-13 (-1090) (-10 -8 (-15 -1734 ((-121) $ $)) (-15 -1740 ((-121) $ $)) (-15 -1753 ((-121) $ $)) (-15 -1747 ((-121) $ $)) (-15 -2047 ($ $ $)) (-15 -1732 ($ $ $)))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-2012 (($ $ $) 45)) (-2607 (($ $ $) 44)) (-2420 (($ $ $) 42)) (-2681 (($ $ $) 51)) (-1523 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 46)) (-1884 (((-3 $ "failed") $ $) 49)) (-3666 (((-3 (-568) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 |#2| "failed") $) 25)) (-3250 (($ $) 35)) (-3748 (($ $ $) 39)) (-1382 (($ $ $) 38)) (-1525 (($ $ $) 47)) (-2450 (($ $ $) 53)) (-3758 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 41)) (-2260 (((-3 $ "failed") $ $) 48)) (-2595 (((-3 $ "failed") $ |#2|) 28)) (-3367 ((|#2| $) 32)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ (-409 (-568))) NIL) (($ |#2|) 12)) (-1302 (((-634 |#2|) $) 18)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) 22))) 
-(((-843 |#1| |#2|) (-10 -8 (-15 -1525 (|#1| |#1| |#1|)) (-15 -1523 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2704 |#1|)) |#1| |#1|)) (-15 -2681 (|#1| |#1| |#1|)) (-15 -1884 ((-3 |#1| "failed") |#1| |#1|)) (-15 -2012 (|#1| |#1| |#1|)) (-15 -2607 (|#1| |#1| |#1|)) (-15 -2420 (|#1| |#1| |#1|)) (-15 -3758 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2704 |#1|)) |#1| |#1|)) (-15 -2450 (|#1| |#1| |#1|)) (-15 -2260 ((-3 |#1| "failed") |#1| |#1|)) (-15 -3748 (|#1| |#1| |#1|)) (-15 -1382 (|#1| |#1| |#1|)) (-15 -3250 (|#1| |#1|)) (-15 -3367 (|#2| |#1|)) (-15 -2595 ((-3 |#1| "failed") |#1| |#2|)) (-15 -1302 ((-634 |#2|) |#1|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -2745 (|#1| |#2|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -2745 (|#1| (-568))) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|)) (-15 -2745 ((-850) |#1|))) (-844 |#2|) (-1047)) (T -843)) 
+((-1309 (($ $ $) 45)) (-2096 (($ $ $) 44)) (-2374 (($ $ $) 42)) (-1310 (($ $ $) 51)) (-4137 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 46)) (-2554 (((-3 $ "failed") $ $) 49)) (-3668 (((-3 (-568) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 |#2| "failed") $) 25)) (-1998 (($ $) 35)) (-2600 (($ $ $) 39)) (-3914 (($ $ $) 38)) (-4150 (($ $ $) 47)) (-2520 (($ $ $) 53)) (-2651 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 41)) (-3327 (((-3 $ "failed") $ $) 48)) (-2597 (((-3 $ "failed") $ |#2|) 28)) (-1364 ((|#2| $) 32)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ (-409 (-568))) NIL) (($ |#2|) 12)) (-3304 (((-634 |#2|) $) 18)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) 22))) 
+(((-843 |#1| |#2|) (-10 -8 (-15 -4150 (|#1| |#1| |#1|)) (-15 -4137 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2707 |#1|)) |#1| |#1|)) (-15 -1310 (|#1| |#1| |#1|)) (-15 -2554 ((-3 |#1| "failed") |#1| |#1|)) (-15 -1309 (|#1| |#1| |#1|)) (-15 -2096 (|#1| |#1| |#1|)) (-15 -2374 (|#1| |#1| |#1|)) (-15 -2651 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2707 |#1|)) |#1| |#1|)) (-15 -2520 (|#1| |#1| |#1|)) (-15 -3327 ((-3 |#1| "failed") |#1| |#1|)) (-15 -2600 (|#1| |#1| |#1|)) (-15 -3914 (|#1| |#1| |#1|)) (-15 -1998 (|#1| |#1|)) (-15 -1364 (|#2| |#1|)) (-15 -2597 ((-3 |#1| "failed") |#1| |#2|)) (-15 -3304 ((-634 |#2|) |#1|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -2747 (|#1| |#2|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -2747 (|#1| (-568))) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|)) (-15 -2747 ((-850) |#1|))) (-844 |#2|) (-1047)) (T -843)) 
 NIL 
-(-10 -8 (-15 -1525 (|#1| |#1| |#1|)) (-15 -1523 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2704 |#1|)) |#1| |#1|)) (-15 -2681 (|#1| |#1| |#1|)) (-15 -1884 ((-3 |#1| "failed") |#1| |#1|)) (-15 -2012 (|#1| |#1| |#1|)) (-15 -2607 (|#1| |#1| |#1|)) (-15 -2420 (|#1| |#1| |#1|)) (-15 -3758 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2704 |#1|)) |#1| |#1|)) (-15 -2450 (|#1| |#1| |#1|)) (-15 -2260 ((-3 |#1| "failed") |#1| |#1|)) (-15 -3748 (|#1| |#1| |#1|)) (-15 -1382 (|#1| |#1| |#1|)) (-15 -3250 (|#1| |#1|)) (-15 -3367 (|#2| |#1|)) (-15 -2595 ((-3 |#1| "failed") |#1| |#2|)) (-15 -1302 ((-634 |#2|) |#1|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -2745 (|#1| |#2|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -2745 (|#1| (-568))) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|)) (-15 -2745 ((-850) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-2012 (($ $ $) 44 (|has| |#1| (-365)))) (-2607 (($ $ $) 45 (|has| |#1| (-365)))) (-2420 (($ $ $) 47 (|has| |#1| (-365)))) (-2681 (($ $ $) 42 (|has| |#1| (-365)))) (-1523 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 41 (|has| |#1| (-365)))) (-1884 (((-3 $ "failed") $ $) 43 (|has| |#1| (-365)))) (-1653 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 46 (|has| |#1| (-365)))) (-3666 (((-3 (-568) "failed") $) 73 (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) 71 (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 68)) (-2854 (((-568) $) 74 (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) 72 (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) 67)) (-2114 (($ $) 63)) (-2925 (((-3 $ "failed") $) 33)) (-3250 (($ $) 54 (|has| |#1| (-453)))) (-2735 (((-121) $) 30)) (-2047 (($ |#1| (-763)) 61)) (-4123 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 56 (|has| |#1| (-558)))) (-3937 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 57 (|has| |#1| (-558)))) (-2144 (((-763) $) 65)) (-3748 (($ $ $) 51 (|has| |#1| (-365)))) (-1382 (($ $ $) 52 (|has| |#1| (-365)))) (-1525 (($ $ $) 40 (|has| |#1| (-365)))) (-2450 (($ $ $) 49 (|has| |#1| (-365)))) (-3758 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 48 (|has| |#1| (-365)))) (-2260 (((-3 $ "failed") $ $) 50 (|has| |#1| (-365)))) (-1293 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 53 (|has| |#1| (-365)))) (-2102 ((|#1| $) 64)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2595 (((-3 $ "failed") $ |#1|) 58 (|has| |#1| (-558)))) (-3206 (((-763) $) 66)) (-3367 ((|#1| $) 55 (|has| |#1| (-453)))) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ (-409 (-568))) 70 (|has| |#1| (-1037 (-409 (-568))))) (($ |#1|) 69)) (-1302 (((-634 |#1|) $) 60)) (-2604 ((|#1| $ (-763)) 62)) (-4078 (((-763)) 28)) (-3823 ((|#1| $ |#1| |#1|) 59)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 76) (($ |#1| $) 75))) 
+(-10 -8 (-15 -4150 (|#1| |#1| |#1|)) (-15 -4137 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2707 |#1|)) |#1| |#1|)) (-15 -1310 (|#1| |#1| |#1|)) (-15 -2554 ((-3 |#1| "failed") |#1| |#1|)) (-15 -1309 (|#1| |#1| |#1|)) (-15 -2096 (|#1| |#1| |#1|)) (-15 -2374 (|#1| |#1| |#1|)) (-15 -2651 ((-2 (|:| |coef1| |#1|) (|:| |coef2| |#1|) (|:| -2707 |#1|)) |#1| |#1|)) (-15 -2520 (|#1| |#1| |#1|)) (-15 -3327 ((-3 |#1| "failed") |#1| |#1|)) (-15 -2600 (|#1| |#1| |#1|)) (-15 -3914 (|#1| |#1| |#1|)) (-15 -1998 (|#1| |#1|)) (-15 -1364 (|#2| |#1|)) (-15 -2597 ((-3 |#1| "failed") |#1| |#2|)) (-15 -3304 ((-634 |#2|) |#1|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -2747 (|#1| |#2|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -2747 (|#1| (-568))) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|)) (-15 -2747 ((-850) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-1309 (($ $ $) 44 (|has| |#1| (-365)))) (-2096 (($ $ $) 45 (|has| |#1| (-365)))) (-2374 (($ $ $) 47 (|has| |#1| (-365)))) (-1310 (($ $ $) 42 (|has| |#1| (-365)))) (-4137 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 41 (|has| |#1| (-365)))) (-2554 (((-3 $ "failed") $ $) 43 (|has| |#1| (-365)))) (-3333 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 46 (|has| |#1| (-365)))) (-3668 (((-3 (-568) "failed") $) 73 (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) 71 (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 68)) (-2857 (((-568) $) 74 (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) 72 (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) 67)) (-2116 (($ $) 63)) (-2902 (((-3 $ "failed") $) 33)) (-1998 (($ $) 54 (|has| |#1| (-453)))) (-1598 (((-121) $) 30)) (-2049 (($ |#1| (-763)) 61)) (-3667 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 56 (|has| |#1| (-558)))) (-4301 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 57 (|has| |#1| (-558)))) (-3524 (((-763) $) 65)) (-2600 (($ $ $) 51 (|has| |#1| (-365)))) (-3914 (($ $ $) 52 (|has| |#1| (-365)))) (-4150 (($ $ $) 40 (|has| |#1| (-365)))) (-2520 (($ $ $) 49 (|has| |#1| (-365)))) (-2651 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 48 (|has| |#1| (-365)))) (-3327 (((-3 $ "failed") $ $) 50 (|has| |#1| (-365)))) (-3229 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 53 (|has| |#1| (-365)))) (-2104 ((|#1| $) 64)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2597 (((-3 $ "failed") $ |#1|) 58 (|has| |#1| (-558)))) (-1836 (((-763) $) 66)) (-1364 ((|#1| $) 55 (|has| |#1| (-453)))) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ (-409 (-568))) 70 (|has| |#1| (-1037 (-409 (-568))))) (($ |#1|) 69)) (-3304 (((-634 |#1|) $) 60)) (-2079 ((|#1| $ (-763)) 62)) (-3425 (((-763)) 28)) (-3828 ((|#1| $ |#1| |#1|) 59)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 76) (($ |#1| $) 75))) 
 (((-844 |#1|) (-1275) (-1047)) (T -844)) 
-((-3206 (*1 *2 *1) (-12 (-4 *1 (-844 *3)) (-4 *3 (-1047)) (-5 *2 (-763)))) (-2144 (*1 *2 *1) (-12 (-4 *1 (-844 *3)) (-4 *3 (-1047)) (-5 *2 (-763)))) (-2102 (*1 *2 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)))) (-2114 (*1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)))) (-2604 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-844 *2)) (-4 *2 (-1047)))) (-2047 (*1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-844 *2)) (-4 *2 (-1047)))) (-1302 (*1 *2 *1) (-12 (-4 *1 (-844 *3)) (-4 *3 (-1047)) (-5 *2 (-634 *3)))) (-3823 (*1 *2 *1 *2 *2) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)))) (-2595 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-558)))) (-3937 (*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-844 *3)))) (-4123 (*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-844 *3)))) (-3367 (*1 *2 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-453)))) (-3250 (*1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-453)))) (-1293 (*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-844 *3)))) (-1382 (*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-3748 (*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-2260 (*1 *1 *1 *1) (|partial| -12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-2450 (*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-3758 (*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2704 *1))) (-4 *1 (-844 *3)))) (-2420 (*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-1653 (*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-844 *3)))) (-2607 (*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-2012 (*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-1884 (*1 *1 *1 *1) (|partial| -12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-2681 (*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-1523 (*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2704 *1))) (-4 *1 (-844 *3)))) (-1525 (*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
-(-13 (-1047) (-120 |t#1| |t#1|) (-413 |t#1|) (-10 -8 (-15 -3206 ((-763) $)) (-15 -2144 ((-763) $)) (-15 -2102 (|t#1| $)) (-15 -2114 ($ $)) (-15 -2604 (|t#1| $ (-763))) (-15 -2047 ($ |t#1| (-763))) (-15 -1302 ((-634 |t#1|) $)) (-15 -3823 (|t#1| $ |t#1| |t#1|)) (IF (|has| |t#1| (-172)) (-6 (-43 |t#1|)) |noBranch|) (IF (|has| |t#1| (-558)) (PROGN (-15 -2595 ((-3 $ "failed") $ |t#1|)) (-15 -3937 ((-2 (|:| -3961 $) (|:| -1500 $)) $ $)) (-15 -4123 ((-2 (|:| -3961 $) (|:| -1500 $)) $ $))) |noBranch|) (IF (|has| |t#1| (-453)) (PROGN (-15 -3367 (|t#1| $)) (-15 -3250 ($ $))) |noBranch|) (IF (|has| |t#1| (-365)) (PROGN (-15 -1293 ((-2 (|:| -3961 $) (|:| -1500 $)) $ $)) (-15 -1382 ($ $ $)) (-15 -3748 ($ $ $)) (-15 -2260 ((-3 $ "failed") $ $)) (-15 -2450 ($ $ $)) (-15 -3758 ((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $)) (-15 -2420 ($ $ $)) (-15 -1653 ((-2 (|:| -3961 $) (|:| -1500 $)) $ $)) (-15 -2607 ($ $ $)) (-15 -2012 ($ $ $)) (-15 -1884 ((-3 $ "failed") $ $)) (-15 -2681 ($ $ $)) (-15 -1523 ((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $)) (-15 -1525 ($ $ $))) |noBranch|))) 
+((-1836 (*1 *2 *1) (-12 (-4 *1 (-844 *3)) (-4 *3 (-1047)) (-5 *2 (-763)))) (-3524 (*1 *2 *1) (-12 (-4 *1 (-844 *3)) (-4 *3 (-1047)) (-5 *2 (-763)))) (-2104 (*1 *2 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)))) (-2116 (*1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)))) (-2079 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-844 *2)) (-4 *2 (-1047)))) (-2049 (*1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-844 *2)) (-4 *2 (-1047)))) (-3304 (*1 *2 *1) (-12 (-4 *1 (-844 *3)) (-4 *3 (-1047)) (-5 *2 (-634 *3)))) (-3828 (*1 *2 *1 *2 *2) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)))) (-2597 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-558)))) (-4301 (*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-844 *3)))) (-3667 (*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-844 *3)))) (-1364 (*1 *2 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-453)))) (-1998 (*1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-453)))) (-3229 (*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-844 *3)))) (-3914 (*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-2600 (*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-3327 (*1 *1 *1 *1) (|partial| -12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-2520 (*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-2651 (*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2707 *1))) (-4 *1 (-844 *3)))) (-2374 (*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-3333 (*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-844 *3)))) (-2096 (*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-1309 (*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-2554 (*1 *1 *1 *1) (|partial| -12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-1310 (*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-4137 (*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2707 *1))) (-4 *1 (-844 *3)))) (-4150 (*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
+(-13 (-1047) (-120 |t#1| |t#1|) (-413 |t#1|) (-10 -8 (-15 -1836 ((-763) $)) (-15 -3524 ((-763) $)) (-15 -2104 (|t#1| $)) (-15 -2116 ($ $)) (-15 -2079 (|t#1| $ (-763))) (-15 -2049 ($ |t#1| (-763))) (-15 -3304 ((-634 |t#1|) $)) (-15 -3828 (|t#1| $ |t#1| |t#1|)) (IF (|has| |t#1| (-172)) (-6 (-43 |t#1|)) |noBranch|) (IF (|has| |t#1| (-558)) (PROGN (-15 -2597 ((-3 $ "failed") $ |t#1|)) (-15 -4301 ((-2 (|:| -4409 $) (|:| -2607 $)) $ $)) (-15 -3667 ((-2 (|:| -4409 $) (|:| -2607 $)) $ $))) |noBranch|) (IF (|has| |t#1| (-453)) (PROGN (-15 -1364 (|t#1| $)) (-15 -1998 ($ $))) |noBranch|) (IF (|has| |t#1| (-365)) (PROGN (-15 -3229 ((-2 (|:| -4409 $) (|:| -2607 $)) $ $)) (-15 -3914 ($ $ $)) (-15 -2600 ($ $ $)) (-15 -3327 ((-3 $ "failed") $ $)) (-15 -2520 ($ $ $)) (-15 -2651 ((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $)) (-15 -2374 ($ $ $)) (-15 -3333 ((-2 (|:| -4409 $) (|:| -2607 $)) $ $)) (-15 -2096 ($ $ $)) (-15 -1309 ($ $ $)) (-15 -2554 ((-3 $ "failed") $ $)) (-15 -1310 ($ $ $)) (-15 -4137 ((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $)) (-15 -4150 ($ $ $))) |noBranch|))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#1|) |has| |#1| (-172)) ((-105) . T) ((-120 |#1| |#1|) . T) ((-137) . T) ((-608 (-850)) . T) ((-413 |#1|) . T) ((-637 |#1|) . T) ((-637 $) . T) ((-707 |#1|) |has| |#1| (-172)) ((-716) . T) ((-1037 (-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 |#1|) . T) ((-1053 |#1|) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-1384 ((|#2| |#2| |#2| (-101 |#1|) (-1 |#1| |#1|)) 20)) (-1653 (((-2 (|:| -3961 |#2|) (|:| -1500 |#2|)) |#2| |#2| (-101 |#1|)) 43 (|has| |#1| (-365)))) (-4123 (((-2 (|:| -3961 |#2|) (|:| -1500 |#2|)) |#2| |#2| (-101 |#1|)) 40 (|has| |#1| (-558)))) (-3937 (((-2 (|:| -3961 |#2|) (|:| -1500 |#2|)) |#2| |#2| (-101 |#1|)) 39 (|has| |#1| (-558)))) (-1293 (((-2 (|:| -3961 |#2|) (|:| -1500 |#2|)) |#2| |#2| (-101 |#1|)) 42 (|has| |#1| (-365)))) (-3823 ((|#1| |#2| |#1| |#1| (-101 |#1|) (-1 |#1| |#1|)) 31))) 
-(((-845 |#1| |#2|) (-10 -7 (-15 -1384 (|#2| |#2| |#2| (-101 |#1|) (-1 |#1| |#1|))) (-15 -3823 (|#1| |#2| |#1| |#1| (-101 |#1|) (-1 |#1| |#1|))) (IF (|has| |#1| (-558)) (PROGN (-15 -3937 ((-2 (|:| -3961 |#2|) (|:| -1500 |#2|)) |#2| |#2| (-101 |#1|))) (-15 -4123 ((-2 (|:| -3961 |#2|) (|:| -1500 |#2|)) |#2| |#2| (-101 |#1|)))) |noBranch|) (IF (|has| |#1| (-365)) (PROGN (-15 -1293 ((-2 (|:| -3961 |#2|) (|:| -1500 |#2|)) |#2| |#2| (-101 |#1|))) (-15 -1653 ((-2 (|:| -3961 |#2|) (|:| -1500 |#2|)) |#2| |#2| (-101 |#1|)))) |noBranch|)) (-1047) (-844 |#1|)) (T -845)) 
-((-1653 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-365)) (-4 *5 (-1047)) (-5 *2 (-2 (|:| -3961 *3) (|:| -1500 *3))) (-5 *1 (-845 *5 *3)) (-4 *3 (-844 *5)))) (-1293 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-365)) (-4 *5 (-1047)) (-5 *2 (-2 (|:| -3961 *3) (|:| -1500 *3))) (-5 *1 (-845 *5 *3)) (-4 *3 (-844 *5)))) (-4123 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-558)) (-4 *5 (-1047)) (-5 *2 (-2 (|:| -3961 *3) (|:| -1500 *3))) (-5 *1 (-845 *5 *3)) (-4 *3 (-844 *5)))) (-3937 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-558)) (-4 *5 (-1047)) (-5 *2 (-2 (|:| -3961 *3) (|:| -1500 *3))) (-5 *1 (-845 *5 *3)) (-4 *3 (-844 *5)))) (-3823 (*1 *2 *3 *2 *2 *4 *5) (-12 (-5 *4 (-101 *2)) (-5 *5 (-1 *2 *2)) (-4 *2 (-1047)) (-5 *1 (-845 *2 *3)) (-4 *3 (-844 *2)))) (-1384 (*1 *2 *2 *2 *3 *4) (-12 (-5 *3 (-101 *5)) (-5 *4 (-1 *5 *5)) (-4 *5 (-1047)) (-5 *1 (-845 *5 *2)) (-4 *2 (-844 *5))))) 
-(-10 -7 (-15 -1384 (|#2| |#2| |#2| (-101 |#1|) (-1 |#1| |#1|))) (-15 -3823 (|#1| |#2| |#1| |#1| (-101 |#1|) (-1 |#1| |#1|))) (IF (|has| |#1| (-558)) (PROGN (-15 -3937 ((-2 (|:| -3961 |#2|) (|:| -1500 |#2|)) |#2| |#2| (-101 |#1|))) (-15 -4123 ((-2 (|:| -3961 |#2|) (|:| -1500 |#2|)) |#2| |#2| (-101 |#1|)))) |noBranch|) (IF (|has| |#1| (-365)) (PROGN (-15 -1293 ((-2 (|:| -3961 |#2|) (|:| -1500 |#2|)) |#2| |#2| (-101 |#1|))) (-15 -1653 ((-2 (|:| -3961 |#2|) (|:| -1500 |#2|)) |#2| |#2| (-101 |#1|)))) |noBranch|)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-2012 (($ $ $) NIL (|has| |#1| (-365)))) (-2607 (($ $ $) NIL (|has| |#1| (-365)))) (-2420 (($ $ $) NIL (|has| |#1| (-365)))) (-2681 (($ $ $) NIL (|has| |#1| (-365)))) (-1523 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-365)))) (-1884 (((-3 $ "failed") $ $) NIL (|has| |#1| (-365)))) (-1653 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 25 (|has| |#1| (-365)))) (-3666 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) NIL)) (-2854 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) NIL)) (-2114 (($ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3250 (($ $) NIL (|has| |#1| (-453)))) (-3680 (((-850) $ (-850)) NIL)) (-2735 (((-121) $) NIL)) (-2047 (($ |#1| (-763)) NIL)) (-4123 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 21 (|has| |#1| (-558)))) (-3937 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 19 (|has| |#1| (-558)))) (-2144 (((-763) $) NIL)) (-3748 (($ $ $) NIL (|has| |#1| (-365)))) (-1382 (($ $ $) NIL (|has| |#1| (-365)))) (-1525 (($ $ $) NIL (|has| |#1| (-365)))) (-2450 (($ $ $) NIL (|has| |#1| (-365)))) (-3758 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-365)))) (-2260 (((-3 $ "failed") $ $) NIL (|has| |#1| (-365)))) (-1293 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 23 (|has| |#1| (-365)))) (-2102 ((|#1| $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2595 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558)))) (-3206 (((-763) $) NIL)) (-3367 ((|#1| $) NIL (|has| |#1| (-453)))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ (-409 (-568))) NIL (|has| |#1| (-1037 (-409 (-568))))) (($ |#1|) NIL)) (-1302 (((-634 |#1|) $) NIL)) (-2604 ((|#1| $ (-763)) NIL)) (-4078 (((-763)) NIL)) (-3823 ((|#1| $ |#1| |#1|) 15)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 13) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
-(((-846 |#1| |#2| |#3|) (-13 (-844 |#1|) (-10 -8 (-15 -3680 ((-850) $ (-850))))) (-1047) (-101 |#1|) (-1 |#1| |#1|)) (T -846)) 
-((-3680 (*1 *2 *1 *2) (-12 (-5 *2 (-850)) (-5 *1 (-846 *3 *4 *5)) (-4 *3 (-1047)) (-14 *4 (-101 *3)) (-14 *5 (-1 *3 *3))))) 
-(-13 (-844 |#1|) (-10 -8 (-15 -3680 ((-850) $ (-850))))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-2012 (($ $ $) NIL (|has| |#2| (-365)))) (-2607 (($ $ $) NIL (|has| |#2| (-365)))) (-2420 (($ $ $) NIL (|has| |#2| (-365)))) (-2681 (($ $ $) NIL (|has| |#2| (-365)))) (-1523 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#2| (-365)))) (-1884 (((-3 $ "failed") $ $) NIL (|has| |#2| (-365)))) (-1653 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#2| (-365)))) (-3666 (((-3 (-568) "failed") $) NIL (|has| |#2| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-3 |#2| "failed") $) NIL)) (-2854 (((-568) $) NIL (|has| |#2| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#2| (-1037 (-409 (-568))))) ((|#2| $) NIL)) (-2114 (($ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3250 (($ $) NIL (|has| |#2| (-453)))) (-2735 (((-121) $) NIL)) (-2047 (($ |#2| (-763)) 16)) (-4123 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#2| (-558)))) (-3937 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#2| (-558)))) (-2144 (((-763) $) NIL)) (-3748 (($ $ $) NIL (|has| |#2| (-365)))) (-1382 (($ $ $) NIL (|has| |#2| (-365)))) (-1525 (($ $ $) NIL (|has| |#2| (-365)))) (-2450 (($ $ $) NIL (|has| |#2| (-365)))) (-3758 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#2| (-365)))) (-2260 (((-3 $ "failed") $ $) NIL (|has| |#2| (-365)))) (-1293 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#2| (-365)))) (-2102 ((|#2| $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2595 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-558)))) (-3206 (((-763) $) NIL)) (-3367 ((|#2| $) NIL (|has| |#2| (-453)))) (-2745 (((-850) $) 23) (($ (-568)) NIL) (($ (-409 (-568))) NIL (|has| |#2| (-1037 (-409 (-568))))) (($ |#2|) NIL) (($ (-1240 |#1|)) 18)) (-1302 (((-634 |#2|) $) NIL)) (-2604 ((|#2| $ (-763)) NIL)) (-4078 (((-763)) NIL)) (-3823 ((|#2| $ |#2| |#2|) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) 13 T CONST)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) NIL))) 
-(((-847 |#1| |#2| |#3| |#4|) (-13 (-844 |#2|) (-10 -8 (-15 -2745 ($ (-1240 |#1|))))) (-1161) (-1047) (-101 |#2|) (-1 |#2| |#2|)) (T -847)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1240 *3)) (-14 *3 (-1161)) (-5 *1 (-847 *3 *4 *5 *6)) (-4 *4 (-1047)) (-14 *5 (-101 *4)) (-14 *6 (-1 *4 *4))))) 
-(-13 (-844 |#2|) (-10 -8 (-15 -2745 ($ (-1240 |#1|))))) 
-((-4043 ((|#1| (-763) |#1|) 35 (|has| |#1| (-43 (-409 (-568)))))) (-2566 ((|#1| (-763) (-763) |#1|) 27) ((|#1| (-763) |#1|) 20)) (-2808 ((|#1| (-763) |#1|) 31)) (-3753 ((|#1| (-763) |#1|) 29)) (-3978 ((|#1| (-763) |#1|) 28))) 
-(((-848 |#1|) (-10 -7 (-15 -3978 (|#1| (-763) |#1|)) (-15 -3753 (|#1| (-763) |#1|)) (-15 -2808 (|#1| (-763) |#1|)) (-15 -2566 (|#1| (-763) |#1|)) (-15 -2566 (|#1| (-763) (-763) |#1|)) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -4043 (|#1| (-763) |#1|)) |noBranch|)) (-172)) (T -848)) 
-((-4043 (*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-172)))) (-2566 (*1 *2 *3 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-172)))) (-2566 (*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-172)))) (-2808 (*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-172)))) (-3753 (*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-172)))) (-3978 (*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-172))))) 
-(-10 -7 (-15 -3978 (|#1| (-763) |#1|)) (-15 -3753 (|#1| (-763) |#1|)) (-15 -2808 (|#1| (-763) |#1|)) (-15 -2566 (|#1| (-763) |#1|)) (-15 -2566 (|#1| (-763) (-763) |#1|)) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -4043 (|#1| (-763) |#1|)) |noBranch|)) 
-((-2447 (((-121) $ $) NIL)) (-2850 (((-568) $) 12)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 18) (($ (-568)) 11)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 8)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 9))) 
-(((-849) (-13 (-842) (-10 -8 (-15 -2745 ($ (-568))) (-15 -2850 ((-568) $))))) (T -849)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-849)))) (-2850 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-849))))) 
-(-13 (-842) (-10 -8 (-15 -2745 ($ (-568))) (-15 -2850 ((-568) $)))) 
-((-2447 (((-121) $ $) NIL)) (-1725 (($ $ $) 115)) (-3877 (((-568) $) 30) (((-568)) 35)) (-2780 (($ (-568)) 44)) (-2473 (($ $ $) 45) (($ (-634 $)) 76)) (-2999 (($ $ (-634 $)) 74)) (-2564 (((-568) $) 33)) (-3527 (($ $ $) 63)) (-2627 (($ $) 128) (($ $ $) 129) (($ $ $ $) 130)) (-1602 (((-568) $) 32)) (-2553 (($ $ $) 62)) (-1742 (($ $) 105)) (-3546 (($ $ $) 119)) (-1495 (($ (-634 $)) 52)) (-3687 (($ $ (-634 $)) 69)) (-1670 (($ (-568) (-568)) 46)) (-2143 (($ $) 116) (($ $ $) 117)) (-3284 (($ $ (-568)) 40) (($ $) 43)) (-2401 (($ $ $) 89)) (-2906 (($ $ $) 122)) (-2539 (($ $) 106)) (-2412 (($ $ $) 90)) (-4435 (($ $) 131) (($ $ $) 132) (($ $ $ $) 133)) (-3417 (((-1249) $) 8)) (-4068 (($ $) 109) (($ $ (-763)) 112)) (-3812 (($ $ $) 65)) (-3785 (($ $ $) 64)) (-3390 (($ $ (-634 $)) 100)) (-2140 (($ $ $) 104)) (-1800 (($ (-634 $)) 50)) (-4499 (($ $) 60) (($ (-634 $)) 61)) (-4047 (($ $ $) 113)) (-1837 (($ $) 107)) (-4038 (($ $ $) 118)) (-3680 (($ (-568)) 20) (($ (-1161)) 22) (($ (-1143)) 29) (($ (-215)) 24)) (-3104 (($ $ $) 93)) (-3044 (($ $) 94)) (-2554 (((-1249) (-1143)) 14)) (-3770 (($ (-1143)) 13)) (-2269 (($ (-634 (-634 $))) 48)) (-3028 (($ $ (-568)) 39) (($ $) 42)) (-4487 (((-1143) $) NIL)) (-3306 (($ $ $) 121)) (-2178 (($ $) 134) (($ $ $) 135) (($ $ $ $) 136)) (-1696 (((-121) $) 98)) (-2294 (($ $ (-634 $)) 102) (($ $ $ $) 103)) (-3829 (($ (-568)) 36)) (-2961 (((-568) $) 31) (((-568)) 34)) (-1838 (($ $ $) 37) (($ (-634 $)) 75)) (-4022 (((-1108) $) NIL)) (-2595 (($ $ $) 91)) (-3248 (($) 12)) (-2779 (($ $ (-634 $)) 99)) (-3682 (($ $) 108) (($ $ (-763)) 111)) (-2601 (($ $ $) 88)) (-4189 (($ $ (-763)) 127)) (-2199 (($ (-634 $)) 51)) (-2745 (((-850) $) 18)) (-1374 (($ $ (-568)) 38) (($ $) 41)) (-2466 (($ $) 58) (($ (-634 $)) 59)) (-3844 (($ $) 56) (($ (-634 $)) 57)) (-2092 (($ $) 114)) (-3081 (($ (-634 $)) 55)) (-2787 (($ $ $) 97)) (-3870 (($ $ $) 120)) (-2139 (($ $ $) 92)) (-2612 (($ $ $) 77)) (-4253 (($ $ $) 95) (($ $) 96)) (-1751 (($ $ $) 81)) (-1738 (($ $ $) 79)) (-1717 (((-121) $ $) 15) (($ $ $) 16)) (-1745 (($ $ $) 80)) (-1732 (($ $ $) 78)) (-1779 (($ $ $) 86)) (-1773 (($ $ $) 83) (($ $) 84)) (-1767 (($ $ $) 82)) (** (($ $ $) 87)) (* (($ $ $) 85))) 
-(((-850) (-13 (-1090) (-10 -8 (-15 -3417 ((-1249) $)) (-15 -3770 ($ (-1143))) (-15 -2554 ((-1249) (-1143))) (-15 -3680 ($ (-568))) (-15 -3680 ($ (-1161))) (-15 -3680 ($ (-1143))) (-15 -3680 ($ (-215))) (-15 -3248 ($)) (-15 -3877 ((-568) $)) (-15 -2961 ((-568) $)) (-15 -3877 ((-568))) (-15 -2961 ((-568))) (-15 -1602 ((-568) $)) (-15 -2564 ((-568) $)) (-15 -3829 ($ (-568))) (-15 -2780 ($ (-568))) (-15 -1670 ($ (-568) (-568))) (-15 -3028 ($ $ (-568))) (-15 -3284 ($ $ (-568))) (-15 -1374 ($ $ (-568))) (-15 -3028 ($ $)) (-15 -3284 ($ $)) (-15 -1374 ($ $)) (-15 -1838 ($ $ $)) (-15 -2473 ($ $ $)) (-15 -1838 ($ (-634 $))) (-15 -2473 ($ (-634 $))) (-15 -3390 ($ $ (-634 $))) (-15 -2294 ($ $ (-634 $))) (-15 -2294 ($ $ $ $)) (-15 -2140 ($ $ $)) (-15 -1696 ((-121) $)) (-15 -2779 ($ $ (-634 $))) (-15 -1742 ($ $)) (-15 -3306 ($ $ $)) (-15 -2092 ($ $)) (-15 -2269 ($ (-634 (-634 $)))) (-15 -1725 ($ $ $)) (-15 -2143 ($ $)) (-15 -2143 ($ $ $)) (-15 -4038 ($ $ $)) (-15 -3546 ($ $ $)) (-15 -3870 ($ $ $)) (-15 -2906 ($ $ $)) (-15 -4189 ($ $ (-763))) (-15 -2787 ($ $ $)) (-15 -2553 ($ $ $)) (-15 -3527 ($ $ $)) (-15 -3785 ($ $ $)) (-15 -3812 ($ $ $)) (-15 -3687 ($ $ (-634 $))) (-15 -2999 ($ $ (-634 $))) (-15 -2539 ($ $)) (-15 -3682 ($ $)) (-15 -3682 ($ $ (-763))) (-15 -4068 ($ $)) (-15 -4068 ($ $ (-763))) (-15 -1837 ($ $)) (-15 -4047 ($ $ $)) (-15 -2627 ($ $)) (-15 -2627 ($ $ $)) (-15 -2627 ($ $ $ $)) (-15 -4435 ($ $)) (-15 -4435 ($ $ $)) (-15 -4435 ($ $ $ $)) (-15 -2178 ($ $)) (-15 -2178 ($ $ $)) (-15 -2178 ($ $ $ $)) (-15 -3844 ($ $)) (-15 -3844 ($ (-634 $))) (-15 -2466 ($ $)) (-15 -2466 ($ (-634 $))) (-15 -4499 ($ $)) (-15 -4499 ($ (-634 $))) (-15 -1800 ($ (-634 $))) (-15 -2199 ($ (-634 $))) (-15 -1495 ($ (-634 $))) (-15 -3081 ($ (-634 $))) (-15 -1717 ($ $ $)) (-15 -2612 ($ $ $)) (-15 -1732 ($ $ $)) (-15 -1738 ($ $ $)) (-15 -1745 ($ $ $)) (-15 -1751 ($ $ $)) (-15 -1767 ($ $ $)) (-15 -1773 ($ $ $)) (-15 -1773 ($ $)) (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -2601 ($ $ $)) (-15 -2401 ($ $ $)) (-15 -2412 ($ $ $)) (-15 -2595 ($ $ $)) (-15 -2139 ($ $ $)) (-15 -3104 ($ $ $)) (-15 -3044 ($ $)) (-15 -4253 ($ $ $)) (-15 -4253 ($ $))))) (T -850)) 
-((-3417 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-850)))) (-3770 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-850)))) (-2554 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-850)))) (-3680 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-3680 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-850)))) (-3680 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-850)))) (-3680 (*1 *1 *2) (-12 (-5 *2 (-215)) (-5 *1 (-850)))) (-3248 (*1 *1) (-5 *1 (-850))) (-3877 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-2961 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-3877 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-2961 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-1602 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-2564 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-3829 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-2780 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-1670 (*1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-3028 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-3284 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-1374 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-3028 (*1 *1 *1) (-5 *1 (-850))) (-3284 (*1 *1 *1) (-5 *1 (-850))) (-1374 (*1 *1 *1) (-5 *1 (-850))) (-1838 (*1 *1 *1 *1) (-5 *1 (-850))) (-2473 (*1 *1 *1 *1) (-5 *1 (-850))) (-1838 (*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-2473 (*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-3390 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-2294 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-2294 (*1 *1 *1 *1 *1) (-5 *1 (-850))) (-2140 (*1 *1 *1 *1) (-5 *1 (-850))) (-1696 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-850)))) (-2779 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-1742 (*1 *1 *1) (-5 *1 (-850))) (-3306 (*1 *1 *1 *1) (-5 *1 (-850))) (-2092 (*1 *1 *1) (-5 *1 (-850))) (-2269 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 (-850)))) (-5 *1 (-850)))) (-1725 (*1 *1 *1 *1) (-5 *1 (-850))) (-2143 (*1 *1 *1) (-5 *1 (-850))) (-2143 (*1 *1 *1 *1) (-5 *1 (-850))) (-4038 (*1 *1 *1 *1) (-5 *1 (-850))) (-3546 (*1 *1 *1 *1) (-5 *1 (-850))) (-3870 (*1 *1 *1 *1) (-5 *1 (-850))) (-2906 (*1 *1 *1 *1) (-5 *1 (-850))) (-4189 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-850)))) (-2787 (*1 *1 *1 *1) (-5 *1 (-850))) (-2553 (*1 *1 *1 *1) (-5 *1 (-850))) (-3527 (*1 *1 *1 *1) (-5 *1 (-850))) (-3785 (*1 *1 *1 *1) (-5 *1 (-850))) (-3812 (*1 *1 *1 *1) (-5 *1 (-850))) (-3687 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-2999 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-2539 (*1 *1 *1) (-5 *1 (-850))) (-3682 (*1 *1 *1) (-5 *1 (-850))) (-3682 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-850)))) (-4068 (*1 *1 *1) (-5 *1 (-850))) (-4068 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-850)))) (-1837 (*1 *1 *1) (-5 *1 (-850))) (-4047 (*1 *1 *1 *1) (-5 *1 (-850))) (-2627 (*1 *1 *1) (-5 *1 (-850))) (-2627 (*1 *1 *1 *1) (-5 *1 (-850))) (-2627 (*1 *1 *1 *1 *1) (-5 *1 (-850))) (-4435 (*1 *1 *1) (-5 *1 (-850))) (-4435 (*1 *1 *1 *1) (-5 *1 (-850))) (-4435 (*1 *1 *1 *1 *1) (-5 *1 (-850))) (-2178 (*1 *1 *1) (-5 *1 (-850))) (-2178 (*1 *1 *1 *1) (-5 *1 (-850))) (-2178 (*1 *1 *1 *1 *1) (-5 *1 (-850))) (-3844 (*1 *1 *1) (-5 *1 (-850))) (-3844 (*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-2466 (*1 *1 *1) (-5 *1 (-850))) (-2466 (*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-4499 (*1 *1 *1) (-5 *1 (-850))) (-4499 (*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-1800 (*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-2199 (*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-1495 (*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-3081 (*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-1717 (*1 *1 *1 *1) (-5 *1 (-850))) (-2612 (*1 *1 *1 *1) (-5 *1 (-850))) (-1732 (*1 *1 *1 *1) (-5 *1 (-850))) (-1738 (*1 *1 *1 *1) (-5 *1 (-850))) (-1745 (*1 *1 *1 *1) (-5 *1 (-850))) (-1751 (*1 *1 *1 *1) (-5 *1 (-850))) (-1767 (*1 *1 *1 *1) (-5 *1 (-850))) (-1773 (*1 *1 *1 *1) (-5 *1 (-850))) (-1773 (*1 *1 *1) (-5 *1 (-850))) (* (*1 *1 *1 *1) (-5 *1 (-850))) (-1779 (*1 *1 *1 *1) (-5 *1 (-850))) (** (*1 *1 *1 *1) (-5 *1 (-850))) (-2601 (*1 *1 *1 *1) (-5 *1 (-850))) (-2401 (*1 *1 *1 *1) (-5 *1 (-850))) (-2412 (*1 *1 *1 *1) (-5 *1 (-850))) (-2595 (*1 *1 *1 *1) (-5 *1 (-850))) (-2139 (*1 *1 *1 *1) (-5 *1 (-850))) (-3104 (*1 *1 *1 *1) (-5 *1 (-850))) (-3044 (*1 *1 *1) (-5 *1 (-850))) (-4253 (*1 *1 *1 *1) (-5 *1 (-850))) (-4253 (*1 *1 *1) (-5 *1 (-850)))) 
-(-13 (-1090) (-10 -8 (-15 -3417 ((-1249) $)) (-15 -3770 ($ (-1143))) (-15 -2554 ((-1249) (-1143))) (-15 -3680 ($ (-568))) (-15 -3680 ($ (-1161))) (-15 -3680 ($ (-1143))) (-15 -3680 ($ (-215))) (-15 -3248 ($)) (-15 -3877 ((-568) $)) (-15 -2961 ((-568) $)) (-15 -3877 ((-568))) (-15 -2961 ((-568))) (-15 -1602 ((-568) $)) (-15 -2564 ((-568) $)) (-15 -3829 ($ (-568))) (-15 -2780 ($ (-568))) (-15 -1670 ($ (-568) (-568))) (-15 -3028 ($ $ (-568))) (-15 -3284 ($ $ (-568))) (-15 -1374 ($ $ (-568))) (-15 -3028 ($ $)) (-15 -3284 ($ $)) (-15 -1374 ($ $)) (-15 -1838 ($ $ $)) (-15 -2473 ($ $ $)) (-15 -1838 ($ (-634 $))) (-15 -2473 ($ (-634 $))) (-15 -3390 ($ $ (-634 $))) (-15 -2294 ($ $ (-634 $))) (-15 -2294 ($ $ $ $)) (-15 -2140 ($ $ $)) (-15 -1696 ((-121) $)) (-15 -2779 ($ $ (-634 $))) (-15 -1742 ($ $)) (-15 -3306 ($ $ $)) (-15 -2092 ($ $)) (-15 -2269 ($ (-634 (-634 $)))) (-15 -1725 ($ $ $)) (-15 -2143 ($ $)) (-15 -2143 ($ $ $)) (-15 -4038 ($ $ $)) (-15 -3546 ($ $ $)) (-15 -3870 ($ $ $)) (-15 -2906 ($ $ $)) (-15 -4189 ($ $ (-763))) (-15 -2787 ($ $ $)) (-15 -2553 ($ $ $)) (-15 -3527 ($ $ $)) (-15 -3785 ($ $ $)) (-15 -3812 ($ $ $)) (-15 -3687 ($ $ (-634 $))) (-15 -2999 ($ $ (-634 $))) (-15 -2539 ($ $)) (-15 -3682 ($ $)) (-15 -3682 ($ $ (-763))) (-15 -4068 ($ $)) (-15 -4068 ($ $ (-763))) (-15 -1837 ($ $)) (-15 -4047 ($ $ $)) (-15 -2627 ($ $)) (-15 -2627 ($ $ $)) (-15 -2627 ($ $ $ $)) (-15 -4435 ($ $)) (-15 -4435 ($ $ $)) (-15 -4435 ($ $ $ $)) (-15 -2178 ($ $)) (-15 -2178 ($ $ $)) (-15 -2178 ($ $ $ $)) (-15 -3844 ($ $)) (-15 -3844 ($ (-634 $))) (-15 -2466 ($ $)) (-15 -2466 ($ (-634 $))) (-15 -4499 ($ $)) (-15 -4499 ($ (-634 $))) (-15 -1800 ($ (-634 $))) (-15 -2199 ($ (-634 $))) (-15 -1495 ($ (-634 $))) (-15 -3081 ($ (-634 $))) (-15 -1717 ($ $ $)) (-15 -2612 ($ $ $)) (-15 -1732 ($ $ $)) (-15 -1738 ($ $ $)) (-15 -1745 ($ $ $)) (-15 -1751 ($ $ $)) (-15 -1767 ($ $ $)) (-15 -1773 ($ $ $)) (-15 -1773 ($ $)) (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -2601 ($ $ $)) (-15 -2401 ($ $ $)) (-15 -2412 ($ $ $)) (-15 -2595 ($ $ $)) (-15 -2139 ($ $ $)) (-15 -3104 ($ $ $)) (-15 -3044 ($ $)) (-15 -4253 ($ $ $)) (-15 -4253 ($ $)))) 
-((-4264 (((-1249) (-634 (-57))) 24)) (-3494 (((-1249) (-1143) (-850)) 14) (((-1249) (-850)) 9) (((-1249) (-1143)) 11))) 
-(((-851) (-10 -7 (-15 -3494 ((-1249) (-1143))) (-15 -3494 ((-1249) (-850))) (-15 -3494 ((-1249) (-1143) (-850))) (-15 -4264 ((-1249) (-634 (-57)))))) (T -851)) 
-((-4264 (*1 *2 *3) (-12 (-5 *3 (-634 (-57))) (-5 *2 (-1249)) (-5 *1 (-851)))) (-3494 (*1 *2 *3 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-850)) (-5 *2 (-1249)) (-5 *1 (-851)))) (-3494 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1249)) (-5 *1 (-851)))) (-3494 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-851))))) 
-(-10 -7 (-15 -3494 ((-1249) (-1143))) (-15 -3494 ((-1249) (-850))) (-15 -3494 ((-1249) (-1143) (-850))) (-15 -4264 ((-1249) (-634 (-57))))) 
-((-2447 (((-121) $ $) NIL)) (-1305 (((-3 $ "failed") (-1161)) 32)) (-3983 (((-763)) 30)) (-1731 (($) NIL)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-3683 (((-917) $) 28)) (-4487 (((-1143) $) 38)) (-4355 (($ (-917)) 27)) (-4022 (((-1108) $) NIL)) (-4278 (((-1161) $) 13) (((-541) $) 19) (((-887 (-381)) $) 25) (((-887 (-568)) $) 22)) (-2745 (((-850) $) 16)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 35)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 34))) 
-(((-852 |#1|) (-13 (-836) (-609 (-1161)) (-609 (-541)) (-609 (-887 (-381))) (-609 (-887 (-568))) (-10 -8 (-15 -1305 ((-3 $ "failed") (-1161))))) (-634 (-1161))) (T -852)) 
-((-1305 (*1 *1 *2) (|partial| -12 (-5 *2 (-1161)) (-5 *1 (-852 *3)) (-14 *3 (-634 *2))))) 
-(-13 (-836) (-609 (-1161)) (-609 (-541)) (-609 (-887 (-381))) (-609 (-887 (-568))) (-10 -8 (-15 -1305 ((-3 $ "failed") (-1161))))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-2925 (((-3 $ "failed") $) NIL)) (-2735 (((-121) $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (((-953 |#1|) $) NIL) (($ (-953 |#1|)) NIL) (($ |#1|) NIL (|has| |#1| (-172)))) (-4078 (((-763)) NIL)) (-4366 (((-1249) (-763)) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-1717 (((-121) $ $) NIL)) (-1779 (((-3 $ "failed") $ $) NIL (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ |#1| $) NIL (|has| |#1| (-172))) (($ $ |#1|) NIL (|has| |#1| (-172))))) 
-(((-853 |#1| |#2| |#3| |#4|) (-13 (-1047) (-10 -8 (IF (|has| |#1| (-172)) (-6 (-43 |#1|)) |noBranch|) (-15 -2745 ((-953 |#1|) $)) (-15 -2745 ($ (-953 |#1|))) (IF (|has| |#1| (-365)) (-15 -1779 ((-3 $ "failed") $ $)) |noBranch|) (-15 -4366 ((-1249) (-763))))) (-1047) (-634 (-1161)) (-634 (-763)) (-763)) (T -853)) 
-((-2745 (*1 *2 *1) (-12 (-5 *2 (-953 *3)) (-5 *1 (-853 *3 *4 *5 *6)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))) (-14 *5 (-634 (-763))) (-14 *6 (-763)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-953 *3)) (-4 *3 (-1047)) (-5 *1 (-853 *3 *4 *5 *6)) (-14 *4 (-634 (-1161))) (-14 *5 (-634 (-763))) (-14 *6 (-763)))) (-1779 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-853 *2 *3 *4 *5)) (-4 *2 (-365)) (-4 *2 (-1047)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-763))) (-14 *5 (-763)))) (-4366 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-853 *4 *5 *6 *7)) (-4 *4 (-1047)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 *3)) (-14 *7 *3)))) 
-(-13 (-1047) (-10 -8 (IF (|has| |#1| (-172)) (-6 (-43 |#1|)) |noBranch|) (-15 -2745 ((-953 |#1|) $)) (-15 -2745 ($ (-953 |#1|))) (IF (|has| |#1| (-365)) (-15 -1779 ((-3 $ "failed") $ $)) |noBranch|) (-15 -4366 ((-1249) (-763))))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-2572 (((-1244 $) $ $) 78)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-2615 (((-121) $) 111)) (-1739 (((-763)) 115)) (-3134 (((-3 $ "failed") $ $) 18)) (-4305 (($ $) 71)) (-1678 (((-420 $) $) 70)) (-1497 (((-121) $ $) 57)) (-1285 (((-1249) $) 74)) (-2671 (($) 16 T CONST)) (-3666 (((-3 (-568) "failed") $) 122) (((-3 (-409 (-568)) "failed") $) 119) (((-3 (-409 (-568)) "failed") $) 104) (((-3 (-860) "failed") $) 136) (((-3 (-860) "failed") $) 130)) (-2854 (((-568) $) 121) (((-409 (-568)) $) 118) (((-409 (-568)) $) 105) (((-860) $) 135) (((-860) $) 131)) (-2401 (($ $ $) 53)) (-3092 (($ (-1157 $)) 84)) (-2925 (((-3 $ "failed") $) 33)) (-2412 (($ $ $) 54)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 49)) (-3218 (($ $ (-763)) 102 (-2198 (|has| (-860) (-148)) (|has| (-860) (-370)) (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370)))) (($ $) 101 (-2198 (|has| (-860) (-148)) (|has| (-860) (-370)) (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-3927 (((-121) $) 69)) (-1473 (($ $) 79)) (-4477 (((-828 (-917)) $) 99 (-2198 (|has| (-860) (-148)) (|has| (-860) (-370)) (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-2735 (((-121) $) 30)) (-3355 (($ (-1157 $) $ (-1161)) 76) (($ (-1157 $) (-1161)) 75)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-3614 (($ (-634 $)) 81)) (-3085 (((-1157 $) $) 86) (((-1157 $) $ $) 85)) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-2081 (($ $) 68)) (-2864 (((-121) $) 112)) (-4022 (((-1108) $) 10)) (-2086 (((-121) $) 82)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-3936 (((-850) $) 73)) (-3848 (((-420 $) $) 72)) (-1553 (((-828 (-917))) 114)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2842 (((-917) $) 80)) (-2595 (((-3 $ "failed") $ $) 41)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-2709 (((-763) $) 56)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 55)) (-3598 (((-634 $) (-1157 $) $) 83)) (-3143 (((-3 (-763) "failed") $ $) 100 (-2198 (|has| (-860) (-148)) (|has| (-860) (-370)) (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-4321 (((-139)) 106)) (-3206 (((-828 (-917)) $) 113)) (-1626 (((-1157 $)) 88) (((-1157 $) $) 87)) (-1458 (($ $) 77)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63) (($ (-568)) 123) (($ (-409 (-568))) 120) (($ (-409 (-568))) 103) (($ (-860)) 137) (($ (-860)) 129)) (-4371 (((-3 $ "failed") $) 98 (-2198 (|has| (-860) (-148)) (|has| (-860) (-370)) (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-4078 (((-763)) 28)) (-1826 (((-121) $ $) 38)) (-4390 (((-121) $) 110)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1316 (($ $ (-763)) 117 (-2198 (|has| (-860) (-370)) (|has| (-409 (-568)) (-370)))) (($ $) 116 (-2198 (|has| (-860) (-370)) (|has| (-409 (-568)) (-370))))) (-1717 (((-121) $ $) 6)) (-1779 (($ $ $) 62) (($ $ (-409 (-568))) 107) (($ $ (-860)) 132)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64) (($ (-409 (-568)) $) 109) (($ $ (-409 (-568))) 108) (($ (-860) $) 134) (($ $ (-860)) 133))) 
+((-3927 ((|#2| |#2| |#2| (-101 |#1|) (-1 |#1| |#1|)) 20)) (-3333 (((-2 (|:| -4409 |#2|) (|:| -2607 |#2|)) |#2| |#2| (-101 |#1|)) 43 (|has| |#1| (-365)))) (-3667 (((-2 (|:| -4409 |#2|) (|:| -2607 |#2|)) |#2| |#2| (-101 |#1|)) 40 (|has| |#1| (-558)))) (-4301 (((-2 (|:| -4409 |#2|) (|:| -2607 |#2|)) |#2| |#2| (-101 |#1|)) 39 (|has| |#1| (-558)))) (-3229 (((-2 (|:| -4409 |#2|) (|:| -2607 |#2|)) |#2| |#2| (-101 |#1|)) 42 (|has| |#1| (-365)))) (-3828 ((|#1| |#2| |#1| |#1| (-101 |#1|) (-1 |#1| |#1|)) 31))) 
+(((-845 |#1| |#2|) (-10 -7 (-15 -3927 (|#2| |#2| |#2| (-101 |#1|) (-1 |#1| |#1|))) (-15 -3828 (|#1| |#2| |#1| |#1| (-101 |#1|) (-1 |#1| |#1|))) (IF (|has| |#1| (-558)) (PROGN (-15 -4301 ((-2 (|:| -4409 |#2|) (|:| -2607 |#2|)) |#2| |#2| (-101 |#1|))) (-15 -3667 ((-2 (|:| -4409 |#2|) (|:| -2607 |#2|)) |#2| |#2| (-101 |#1|)))) |noBranch|) (IF (|has| |#1| (-365)) (PROGN (-15 -3229 ((-2 (|:| -4409 |#2|) (|:| -2607 |#2|)) |#2| |#2| (-101 |#1|))) (-15 -3333 ((-2 (|:| -4409 |#2|) (|:| -2607 |#2|)) |#2| |#2| (-101 |#1|)))) |noBranch|)) (-1047) (-844 |#1|)) (T -845)) 
+((-3333 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-365)) (-4 *5 (-1047)) (-5 *2 (-2 (|:| -4409 *3) (|:| -2607 *3))) (-5 *1 (-845 *5 *3)) (-4 *3 (-844 *5)))) (-3229 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-365)) (-4 *5 (-1047)) (-5 *2 (-2 (|:| -4409 *3) (|:| -2607 *3))) (-5 *1 (-845 *5 *3)) (-4 *3 (-844 *5)))) (-3667 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-558)) (-4 *5 (-1047)) (-5 *2 (-2 (|:| -4409 *3) (|:| -2607 *3))) (-5 *1 (-845 *5 *3)) (-4 *3 (-844 *5)))) (-4301 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-558)) (-4 *5 (-1047)) (-5 *2 (-2 (|:| -4409 *3) (|:| -2607 *3))) (-5 *1 (-845 *5 *3)) (-4 *3 (-844 *5)))) (-3828 (*1 *2 *3 *2 *2 *4 *5) (-12 (-5 *4 (-101 *2)) (-5 *5 (-1 *2 *2)) (-4 *2 (-1047)) (-5 *1 (-845 *2 *3)) (-4 *3 (-844 *2)))) (-3927 (*1 *2 *2 *2 *3 *4) (-12 (-5 *3 (-101 *5)) (-5 *4 (-1 *5 *5)) (-4 *5 (-1047)) (-5 *1 (-845 *5 *2)) (-4 *2 (-844 *5))))) 
+(-10 -7 (-15 -3927 (|#2| |#2| |#2| (-101 |#1|) (-1 |#1| |#1|))) (-15 -3828 (|#1| |#2| |#1| |#1| (-101 |#1|) (-1 |#1| |#1|))) (IF (|has| |#1| (-558)) (PROGN (-15 -4301 ((-2 (|:| -4409 |#2|) (|:| -2607 |#2|)) |#2| |#2| (-101 |#1|))) (-15 -3667 ((-2 (|:| -4409 |#2|) (|:| -2607 |#2|)) |#2| |#2| (-101 |#1|)))) |noBranch|) (IF (|has| |#1| (-365)) (PROGN (-15 -3229 ((-2 (|:| -4409 |#2|) (|:| -2607 |#2|)) |#2| |#2| (-101 |#1|))) (-15 -3333 ((-2 (|:| -4409 |#2|) (|:| -2607 |#2|)) |#2| |#2| (-101 |#1|)))) |noBranch|)) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-1309 (($ $ $) NIL (|has| |#1| (-365)))) (-2096 (($ $ $) NIL (|has| |#1| (-365)))) (-2374 (($ $ $) NIL (|has| |#1| (-365)))) (-1310 (($ $ $) NIL (|has| |#1| (-365)))) (-4137 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-365)))) (-2554 (((-3 $ "failed") $ $) NIL (|has| |#1| (-365)))) (-3333 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 25 (|has| |#1| (-365)))) (-3668 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) NIL)) (-2857 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) NIL)) (-2116 (($ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1998 (($ $) NIL (|has| |#1| (-453)))) (-2276 (((-850) $ (-850)) NIL)) (-1598 (((-121) $) NIL)) (-2049 (($ |#1| (-763)) NIL)) (-3667 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 21 (|has| |#1| (-558)))) (-4301 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 19 (|has| |#1| (-558)))) (-3524 (((-763) $) NIL)) (-2600 (($ $ $) NIL (|has| |#1| (-365)))) (-3914 (($ $ $) NIL (|has| |#1| (-365)))) (-4150 (($ $ $) NIL (|has| |#1| (-365)))) (-2520 (($ $ $) NIL (|has| |#1| (-365)))) (-2651 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-365)))) (-3327 (((-3 $ "failed") $ $) NIL (|has| |#1| (-365)))) (-3229 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 23 (|has| |#1| (-365)))) (-2104 ((|#1| $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2597 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558)))) (-1836 (((-763) $) NIL)) (-1364 ((|#1| $) NIL (|has| |#1| (-453)))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ (-409 (-568))) NIL (|has| |#1| (-1037 (-409 (-568))))) (($ |#1|) NIL)) (-3304 (((-634 |#1|) $) NIL)) (-2079 ((|#1| $ (-763)) NIL)) (-3425 (((-763)) NIL)) (-3828 ((|#1| $ |#1| |#1|) 15)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 13) (($ $ |#1|) NIL) (($ |#1| $) NIL))) 
+(((-846 |#1| |#2| |#3|) (-13 (-844 |#1|) (-10 -8 (-15 -2276 ((-850) $ (-850))))) (-1047) (-101 |#1|) (-1 |#1| |#1|)) (T -846)) 
+((-2276 (*1 *2 *1 *2) (-12 (-5 *2 (-850)) (-5 *1 (-846 *3 *4 *5)) (-4 *3 (-1047)) (-14 *4 (-101 *3)) (-14 *5 (-1 *3 *3))))) 
+(-13 (-844 |#1|) (-10 -8 (-15 -2276 ((-850) $ (-850))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-1309 (($ $ $) NIL (|has| |#2| (-365)))) (-2096 (($ $ $) NIL (|has| |#2| (-365)))) (-2374 (($ $ $) NIL (|has| |#2| (-365)))) (-1310 (($ $ $) NIL (|has| |#2| (-365)))) (-4137 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#2| (-365)))) (-2554 (((-3 $ "failed") $ $) NIL (|has| |#2| (-365)))) (-3333 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#2| (-365)))) (-3668 (((-3 (-568) "failed") $) NIL (|has| |#2| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-3 |#2| "failed") $) NIL)) (-2857 (((-568) $) NIL (|has| |#2| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#2| (-1037 (-409 (-568))))) ((|#2| $) NIL)) (-2116 (($ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1998 (($ $) NIL (|has| |#2| (-453)))) (-1598 (((-121) $) NIL)) (-2049 (($ |#2| (-763)) 16)) (-3667 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#2| (-558)))) (-4301 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#2| (-558)))) (-3524 (((-763) $) NIL)) (-2600 (($ $ $) NIL (|has| |#2| (-365)))) (-3914 (($ $ $) NIL (|has| |#2| (-365)))) (-4150 (($ $ $) NIL (|has| |#2| (-365)))) (-2520 (($ $ $) NIL (|has| |#2| (-365)))) (-2651 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#2| (-365)))) (-3327 (((-3 $ "failed") $ $) NIL (|has| |#2| (-365)))) (-3229 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#2| (-365)))) (-2104 ((|#2| $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2597 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-558)))) (-1836 (((-763) $) NIL)) (-1364 ((|#2| $) NIL (|has| |#2| (-453)))) (-2747 (((-850) $) 23) (($ (-568)) NIL) (($ (-409 (-568))) NIL (|has| |#2| (-1037 (-409 (-568))))) (($ |#2|) NIL) (($ (-1240 |#1|)) 18)) (-3304 (((-634 |#2|) $) NIL)) (-2079 ((|#2| $ (-763)) NIL)) (-3425 (((-763)) NIL)) (-3828 ((|#2| $ |#2| |#2|) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) 13 T CONST)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) NIL))) 
+(((-847 |#1| |#2| |#3| |#4|) (-13 (-844 |#2|) (-10 -8 (-15 -2747 ($ (-1240 |#1|))))) (-1161) (-1047) (-101 |#2|) (-1 |#2| |#2|)) (T -847)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1240 *3)) (-14 *3 (-1161)) (-5 *1 (-847 *3 *4 *5 *6)) (-4 *4 (-1047)) (-14 *5 (-101 *4)) (-14 *6 (-1 *4 *4))))) 
+(-13 (-844 |#2|) (-10 -8 (-15 -2747 ($ (-1240 |#1|))))) 
+((-1545 ((|#1| (-763) |#1|) 35 (|has| |#1| (-43 (-409 (-568)))))) (-1948 ((|#1| (-763) (-763) |#1|) 27) ((|#1| (-763) |#1|) 20)) (-3700 ((|#1| (-763) |#1|) 31)) (-2623 ((|#1| (-763) |#1|) 29)) (-4477 ((|#1| (-763) |#1|) 28))) 
+(((-848 |#1|) (-10 -7 (-15 -4477 (|#1| (-763) |#1|)) (-15 -2623 (|#1| (-763) |#1|)) (-15 -3700 (|#1| (-763) |#1|)) (-15 -1948 (|#1| (-763) |#1|)) (-15 -1948 (|#1| (-763) (-763) |#1|)) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -1545 (|#1| (-763) |#1|)) |noBranch|)) (-172)) (T -848)) 
+((-1545 (*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-172)))) (-1948 (*1 *2 *3 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-172)))) (-1948 (*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-172)))) (-3700 (*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-172)))) (-2623 (*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-172)))) (-4477 (*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-172))))) 
+(-10 -7 (-15 -4477 (|#1| (-763) |#1|)) (-15 -2623 (|#1| (-763) |#1|)) (-15 -3700 (|#1| (-763) |#1|)) (-15 -1948 (|#1| (-763) |#1|)) (-15 -1948 (|#1| (-763) (-763) |#1|)) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -1545 (|#1| (-763) |#1|)) |noBranch|)) 
+((-2449 (((-121) $ $) NIL)) (-2852 (((-568) $) 12)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 18) (($ (-568)) 11)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 8)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 9))) 
+(((-849) (-13 (-842) (-10 -8 (-15 -2747 ($ (-568))) (-15 -2852 ((-568) $))))) (T -849)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-849)))) (-2852 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-849))))) 
+(-13 (-842) (-10 -8 (-15 -2747 ($ (-568))) (-15 -2852 ((-568) $)))) 
+((-2449 (((-121) $ $) NIL)) (-3733 (($ $ $) 115)) (-1987 (((-568) $) 30) (((-568)) 35)) (-3563 (($ (-568)) 44)) (-2632 (($ $ $) 45) (($ (-634 $)) 76)) (-3136 (($ $ (-634 $)) 74)) (-1940 (((-568) $) 33)) (-4104 (($ $ $) 63)) (-2630 (($ $) 128) (($ $ $) 129) (($ $ $ $) 130)) (-1347 (((-568) $) 32)) (-1891 (($ $ $) 62)) (-1744 (($ $) 105)) (-2799 (($ $ $) 119)) (-2579 (($ (-634 $)) 52)) (-3689 (($ $ (-634 $)) 69)) (-3447 (($ (-568) (-568)) 46)) (-3517 (($ $) 116) (($ $ $) 117)) (-3286 (($ $ (-568)) 40) (($ $) 43)) (-2403 (($ $ $) 89)) (-2844 (($ $ $) 122)) (-1827 (($ $) 106)) (-2414 (($ $ $) 90)) (-1632 (($ $) 131) (($ $ $) 132) (($ $ $ $) 133)) (-3419 (((-1249) $) 8)) (-1638 (($ $) 109) (($ $ (-763)) 112)) (-1755 (($ $ $) 65)) (-2749 (($ $ $) 64)) (-3392 (($ $ (-634 $)) 100)) (-3495 (($ $ $) 104)) (-2143 (($ (-634 $)) 50)) (-3855 (($ $) 60) (($ (-634 $)) 61)) (-1562 (($ $ $) 113)) (-2334 (($ $) 107)) (-1521 (($ $ $) 118)) (-2276 (($ (-568)) 20) (($ (-1161)) 22) (($ (-1143)) 29) (($ (-215)) 24)) (-3107 (($ $ $) 93)) (-3046 (($ $) 94)) (-1896 (((-1249) (-1143)) 14)) (-2690 (($ (-1143)) 13)) (-2271 (($ (-634 (-634 $))) 48)) (-3030 (($ $ (-568)) 39) (($ $) 42)) (-1893 (((-1143) $) NIL)) (-4256 (($ $ $) 121)) (-2473 (($ $) 134) (($ $ $) 135) (($ $ $ $) 136)) (-1698 (((-121) $) 98)) (-3583 (($ $ (-634 $)) 102) (($ $ $ $) 103)) (-1817 (($ (-568)) 36)) (-2963 (((-568) $) 31) (((-568)) 34)) (-2340 (($ $ $) 37) (($ (-634 $)) 75)) (-4025 (((-1108) $) NIL)) (-2597 (($ $ $) 91)) (-1990 (($) 12)) (-2781 (($ $ (-634 $)) 99)) (-2286 (($ $) 108) (($ $ (-763)) 111)) (-2602 (($ $ $) 88)) (-4191 (($ $ (-763)) 127)) (-3098 (($ (-634 $)) 51)) (-2747 (((-850) $) 18)) (-1374 (($ $ (-568)) 38) (($ $) 41)) (-2598 (($ $) 58) (($ (-634 $)) 59)) (-3846 (($ $) 56) (($ (-634 $)) 57)) (-3159 (($ $) 114)) (-2418 (($ (-634 $)) 55)) (-3584 (($ $ $) 97)) (-1963 (($ $ $) 120)) (-2141 (($ $ $) 92)) (-2614 (($ $ $) 77)) (-4255 (($ $ $) 95) (($ $) 96)) (-1753 (($ $ $) 81)) (-1740 (($ $ $) 79)) (-1719 (((-121) $ $) 15) (($ $ $) 16)) (-1747 (($ $ $) 80)) (-1734 (($ $ $) 78)) (-1781 (($ $ $) 86)) (-1775 (($ $ $) 83) (($ $) 84)) (-1769 (($ $ $) 82)) (** (($ $ $) 87)) (* (($ $ $) 85))) 
+(((-850) (-13 (-1090) (-10 -8 (-15 -3419 ((-1249) $)) (-15 -2690 ($ (-1143))) (-15 -1896 ((-1249) (-1143))) (-15 -2276 ($ (-568))) (-15 -2276 ($ (-1161))) (-15 -2276 ($ (-1143))) (-15 -2276 ($ (-215))) (-15 -1990 ($)) (-15 -1987 ((-568) $)) (-15 -2963 ((-568) $)) (-15 -1987 ((-568))) (-15 -2963 ((-568))) (-15 -1347 ((-568) $)) (-15 -1940 ((-568) $)) (-15 -1817 ($ (-568))) (-15 -3563 ($ (-568))) (-15 -3447 ($ (-568) (-568))) (-15 -3030 ($ $ (-568))) (-15 -3286 ($ $ (-568))) (-15 -1374 ($ $ (-568))) (-15 -3030 ($ $)) (-15 -3286 ($ $)) (-15 -1374 ($ $)) (-15 -2340 ($ $ $)) (-15 -2632 ($ $ $)) (-15 -2340 ($ (-634 $))) (-15 -2632 ($ (-634 $))) (-15 -3392 ($ $ (-634 $))) (-15 -3583 ($ $ (-634 $))) (-15 -3583 ($ $ $ $)) (-15 -3495 ($ $ $)) (-15 -1698 ((-121) $)) (-15 -2781 ($ $ (-634 $))) (-15 -1744 ($ $)) (-15 -4256 ($ $ $)) (-15 -3159 ($ $)) (-15 -2271 ($ (-634 (-634 $)))) (-15 -3733 ($ $ $)) (-15 -3517 ($ $)) (-15 -3517 ($ $ $)) (-15 -1521 ($ $ $)) (-15 -2799 ($ $ $)) (-15 -1963 ($ $ $)) (-15 -2844 ($ $ $)) (-15 -4191 ($ $ (-763))) (-15 -3584 ($ $ $)) (-15 -1891 ($ $ $)) (-15 -4104 ($ $ $)) (-15 -2749 ($ $ $)) (-15 -1755 ($ $ $)) (-15 -3689 ($ $ (-634 $))) (-15 -3136 ($ $ (-634 $))) (-15 -1827 ($ $)) (-15 -2286 ($ $)) (-15 -2286 ($ $ (-763))) (-15 -1638 ($ $)) (-15 -1638 ($ $ (-763))) (-15 -2334 ($ $)) (-15 -1562 ($ $ $)) (-15 -2630 ($ $)) (-15 -2630 ($ $ $)) (-15 -2630 ($ $ $ $)) (-15 -1632 ($ $)) (-15 -1632 ($ $ $)) (-15 -1632 ($ $ $ $)) (-15 -2473 ($ $)) (-15 -2473 ($ $ $)) (-15 -2473 ($ $ $ $)) (-15 -3846 ($ $)) (-15 -3846 ($ (-634 $))) (-15 -2598 ($ $)) (-15 -2598 ($ (-634 $))) (-15 -3855 ($ $)) (-15 -3855 ($ (-634 $))) (-15 -2143 ($ (-634 $))) (-15 -3098 ($ (-634 $))) (-15 -2579 ($ (-634 $))) (-15 -2418 ($ (-634 $))) (-15 -1719 ($ $ $)) (-15 -2614 ($ $ $)) (-15 -1734 ($ $ $)) (-15 -1740 ($ $ $)) (-15 -1747 ($ $ $)) (-15 -1753 ($ $ $)) (-15 -1769 ($ $ $)) (-15 -1775 ($ $ $)) (-15 -1775 ($ $)) (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -2602 ($ $ $)) (-15 -2403 ($ $ $)) (-15 -2414 ($ $ $)) (-15 -2597 ($ $ $)) (-15 -2141 ($ $ $)) (-15 -3107 ($ $ $)) (-15 -3046 ($ $)) (-15 -4255 ($ $ $)) (-15 -4255 ($ $))))) (T -850)) 
+((-3419 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-850)))) (-2690 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-850)))) (-1896 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-850)))) (-2276 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-2276 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-850)))) (-2276 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-850)))) (-2276 (*1 *1 *2) (-12 (-5 *2 (-215)) (-5 *1 (-850)))) (-1990 (*1 *1) (-5 *1 (-850))) (-1987 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-2963 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-1987 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-2963 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-1347 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-1940 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-1817 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-3563 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-3447 (*1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-3030 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-3286 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-1374 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) (-3030 (*1 *1 *1) (-5 *1 (-850))) (-3286 (*1 *1 *1) (-5 *1 (-850))) (-1374 (*1 *1 *1) (-5 *1 (-850))) (-2340 (*1 *1 *1 *1) (-5 *1 (-850))) (-2632 (*1 *1 *1 *1) (-5 *1 (-850))) (-2340 (*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-2632 (*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-3392 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-3583 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-3583 (*1 *1 *1 *1 *1) (-5 *1 (-850))) (-3495 (*1 *1 *1 *1) (-5 *1 (-850))) (-1698 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-850)))) (-2781 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-1744 (*1 *1 *1) (-5 *1 (-850))) (-4256 (*1 *1 *1 *1) (-5 *1 (-850))) (-3159 (*1 *1 *1) (-5 *1 (-850))) (-2271 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 (-850)))) (-5 *1 (-850)))) (-3733 (*1 *1 *1 *1) (-5 *1 (-850))) (-3517 (*1 *1 *1) (-5 *1 (-850))) (-3517 (*1 *1 *1 *1) (-5 *1 (-850))) (-1521 (*1 *1 *1 *1) (-5 *1 (-850))) (-2799 (*1 *1 *1 *1) (-5 *1 (-850))) (-1963 (*1 *1 *1 *1) (-5 *1 (-850))) (-2844 (*1 *1 *1 *1) (-5 *1 (-850))) (-4191 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-850)))) (-3584 (*1 *1 *1 *1) (-5 *1 (-850))) (-1891 (*1 *1 *1 *1) (-5 *1 (-850))) (-4104 (*1 *1 *1 *1) (-5 *1 (-850))) (-2749 (*1 *1 *1 *1) (-5 *1 (-850))) (-1755 (*1 *1 *1 *1) (-5 *1 (-850))) (-3689 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-3136 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-1827 (*1 *1 *1) (-5 *1 (-850))) (-2286 (*1 *1 *1) (-5 *1 (-850))) (-2286 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-850)))) (-1638 (*1 *1 *1) (-5 *1 (-850))) (-1638 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-850)))) (-2334 (*1 *1 *1) (-5 *1 (-850))) (-1562 (*1 *1 *1 *1) (-5 *1 (-850))) (-2630 (*1 *1 *1) (-5 *1 (-850))) (-2630 (*1 *1 *1 *1) (-5 *1 (-850))) (-2630 (*1 *1 *1 *1 *1) (-5 *1 (-850))) (-1632 (*1 *1 *1) (-5 *1 (-850))) (-1632 (*1 *1 *1 *1) (-5 *1 (-850))) (-1632 (*1 *1 *1 *1 *1) (-5 *1 (-850))) (-2473 (*1 *1 *1) (-5 *1 (-850))) (-2473 (*1 *1 *1 *1) (-5 *1 (-850))) (-2473 (*1 *1 *1 *1 *1) (-5 *1 (-850))) (-3846 (*1 *1 *1) (-5 *1 (-850))) (-3846 (*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-2598 (*1 *1 *1) (-5 *1 (-850))) (-2598 (*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-3855 (*1 *1 *1) (-5 *1 (-850))) (-3855 (*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-2143 (*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-3098 (*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-2579 (*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-2418 (*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) (-1719 (*1 *1 *1 *1) (-5 *1 (-850))) (-2614 (*1 *1 *1 *1) (-5 *1 (-850))) (-1734 (*1 *1 *1 *1) (-5 *1 (-850))) (-1740 (*1 *1 *1 *1) (-5 *1 (-850))) (-1747 (*1 *1 *1 *1) (-5 *1 (-850))) (-1753 (*1 *1 *1 *1) (-5 *1 (-850))) (-1769 (*1 *1 *1 *1) (-5 *1 (-850))) (-1775 (*1 *1 *1 *1) (-5 *1 (-850))) (-1775 (*1 *1 *1) (-5 *1 (-850))) (* (*1 *1 *1 *1) (-5 *1 (-850))) (-1781 (*1 *1 *1 *1) (-5 *1 (-850))) (** (*1 *1 *1 *1) (-5 *1 (-850))) (-2602 (*1 *1 *1 *1) (-5 *1 (-850))) (-2403 (*1 *1 *1 *1) (-5 *1 (-850))) (-2414 (*1 *1 *1 *1) (-5 *1 (-850))) (-2597 (*1 *1 *1 *1) (-5 *1 (-850))) (-2141 (*1 *1 *1 *1) (-5 *1 (-850))) (-3107 (*1 *1 *1 *1) (-5 *1 (-850))) (-3046 (*1 *1 *1) (-5 *1 (-850))) (-4255 (*1 *1 *1 *1) (-5 *1 (-850))) (-4255 (*1 *1 *1) (-5 *1 (-850)))) 
+(-13 (-1090) (-10 -8 (-15 -3419 ((-1249) $)) (-15 -2690 ($ (-1143))) (-15 -1896 ((-1249) (-1143))) (-15 -2276 ($ (-568))) (-15 -2276 ($ (-1161))) (-15 -2276 ($ (-1143))) (-15 -2276 ($ (-215))) (-15 -1990 ($)) (-15 -1987 ((-568) $)) (-15 -2963 ((-568) $)) (-15 -1987 ((-568))) (-15 -2963 ((-568))) (-15 -1347 ((-568) $)) (-15 -1940 ((-568) $)) (-15 -1817 ($ (-568))) (-15 -3563 ($ (-568))) (-15 -3447 ($ (-568) (-568))) (-15 -3030 ($ $ (-568))) (-15 -3286 ($ $ (-568))) (-15 -1374 ($ $ (-568))) (-15 -3030 ($ $)) (-15 -3286 ($ $)) (-15 -1374 ($ $)) (-15 -2340 ($ $ $)) (-15 -2632 ($ $ $)) (-15 -2340 ($ (-634 $))) (-15 -2632 ($ (-634 $))) (-15 -3392 ($ $ (-634 $))) (-15 -3583 ($ $ (-634 $))) (-15 -3583 ($ $ $ $)) (-15 -3495 ($ $ $)) (-15 -1698 ((-121) $)) (-15 -2781 ($ $ (-634 $))) (-15 -1744 ($ $)) (-15 -4256 ($ $ $)) (-15 -3159 ($ $)) (-15 -2271 ($ (-634 (-634 $)))) (-15 -3733 ($ $ $)) (-15 -3517 ($ $)) (-15 -3517 ($ $ $)) (-15 -1521 ($ $ $)) (-15 -2799 ($ $ $)) (-15 -1963 ($ $ $)) (-15 -2844 ($ $ $)) (-15 -4191 ($ $ (-763))) (-15 -3584 ($ $ $)) (-15 -1891 ($ $ $)) (-15 -4104 ($ $ $)) (-15 -2749 ($ $ $)) (-15 -1755 ($ $ $)) (-15 -3689 ($ $ (-634 $))) (-15 -3136 ($ $ (-634 $))) (-15 -1827 ($ $)) (-15 -2286 ($ $)) (-15 -2286 ($ $ (-763))) (-15 -1638 ($ $)) (-15 -1638 ($ $ (-763))) (-15 -2334 ($ $)) (-15 -1562 ($ $ $)) (-15 -2630 ($ $)) (-15 -2630 ($ $ $)) (-15 -2630 ($ $ $ $)) (-15 -1632 ($ $)) (-15 -1632 ($ $ $)) (-15 -1632 ($ $ $ $)) (-15 -2473 ($ $)) (-15 -2473 ($ $ $)) (-15 -2473 ($ $ $ $)) (-15 -3846 ($ $)) (-15 -3846 ($ (-634 $))) (-15 -2598 ($ $)) (-15 -2598 ($ (-634 $))) (-15 -3855 ($ $)) (-15 -3855 ($ (-634 $))) (-15 -2143 ($ (-634 $))) (-15 -3098 ($ (-634 $))) (-15 -2579 ($ (-634 $))) (-15 -2418 ($ (-634 $))) (-15 -1719 ($ $ $)) (-15 -2614 ($ $ $)) (-15 -1734 ($ $ $)) (-15 -1740 ($ $ $)) (-15 -1747 ($ $ $)) (-15 -1753 ($ $ $)) (-15 -1769 ($ $ $)) (-15 -1775 ($ $ $)) (-15 -1775 ($ $)) (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -2602 ($ $ $)) (-15 -2403 ($ $ $)) (-15 -2414 ($ $ $)) (-15 -2597 ($ $ $)) (-15 -2141 ($ $ $)) (-15 -3107 ($ $ $)) (-15 -3046 ($ $)) (-15 -4255 ($ $ $)) (-15 -4255 ($ $)))) 
+((-2907 (((-1249) (-634 (-57))) 24)) (-3496 (((-1249) (-1143) (-850)) 14) (((-1249) (-850)) 9) (((-1249) (-1143)) 11))) 
+(((-851) (-10 -7 (-15 -3496 ((-1249) (-1143))) (-15 -3496 ((-1249) (-850))) (-15 -3496 ((-1249) (-1143) (-850))) (-15 -2907 ((-1249) (-634 (-57)))))) (T -851)) 
+((-2907 (*1 *2 *3) (-12 (-5 *3 (-634 (-57))) (-5 *2 (-1249)) (-5 *1 (-851)))) (-3496 (*1 *2 *3 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-850)) (-5 *2 (-1249)) (-5 *1 (-851)))) (-3496 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1249)) (-5 *1 (-851)))) (-3496 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-851))))) 
+(-10 -7 (-15 -3496 ((-1249) (-1143))) (-15 -3496 ((-1249) (-850))) (-15 -3496 ((-1249) (-1143) (-850))) (-15 -2907 ((-1249) (-634 (-57))))) 
+((-2449 (((-121) $ $) NIL)) (-3325 (((-3 $ "failed") (-1161)) 32)) (-3986 (((-763)) 30)) (-1733 (($) NIL)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-2291 (((-917) $) 28)) (-1893 (((-1143) $) 38)) (-4357 (($ (-917)) 27)) (-4025 (((-1108) $) NIL)) (-4280 (((-1161) $) 13) (((-541) $) 19) (((-887 (-381)) $) 25) (((-887 (-568)) $) 22)) (-2747 (((-850) $) 16)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 35)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 34))) 
+(((-852 |#1|) (-13 (-836) (-609 (-1161)) (-609 (-541)) (-609 (-887 (-381))) (-609 (-887 (-568))) (-10 -8 (-15 -3325 ((-3 $ "failed") (-1161))))) (-634 (-1161))) (T -852)) 
+((-3325 (*1 *1 *2) (|partial| -12 (-5 *2 (-1161)) (-5 *1 (-852 *3)) (-14 *3 (-634 *2))))) 
+(-13 (-836) (-609 (-1161)) (-609 (-541)) (-609 (-887 (-381))) (-609 (-887 (-568))) (-10 -8 (-15 -3325 ((-3 $ "failed") (-1161))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-2902 (((-3 $ "failed") $) NIL)) (-1598 (((-121) $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (((-953 |#1|) $) NIL) (($ (-953 |#1|)) NIL) (($ |#1|) NIL (|has| |#1| (-172)))) (-3425 (((-763)) NIL)) (-3352 (((-1249) (-763)) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-1719 (((-121) $ $) NIL)) (-1781 (((-3 $ "failed") $ $) NIL (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ |#1| $) NIL (|has| |#1| (-172))) (($ $ |#1|) NIL (|has| |#1| (-172))))) 
+(((-853 |#1| |#2| |#3| |#4|) (-13 (-1047) (-10 -8 (IF (|has| |#1| (-172)) (-6 (-43 |#1|)) |noBranch|) (-15 -2747 ((-953 |#1|) $)) (-15 -2747 ($ (-953 |#1|))) (IF (|has| |#1| (-365)) (-15 -1781 ((-3 $ "failed") $ $)) |noBranch|) (-15 -3352 ((-1249) (-763))))) (-1047) (-634 (-1161)) (-634 (-763)) (-763)) (T -853)) 
+((-2747 (*1 *2 *1) (-12 (-5 *2 (-953 *3)) (-5 *1 (-853 *3 *4 *5 *6)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))) (-14 *5 (-634 (-763))) (-14 *6 (-763)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-953 *3)) (-4 *3 (-1047)) (-5 *1 (-853 *3 *4 *5 *6)) (-14 *4 (-634 (-1161))) (-14 *5 (-634 (-763))) (-14 *6 (-763)))) (-1781 (*1 *1 *1 *1) (|partial| -12 (-5 *1 (-853 *2 *3 *4 *5)) (-4 *2 (-365)) (-4 *2 (-1047)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-763))) (-14 *5 (-763)))) (-3352 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-853 *4 *5 *6 *7)) (-4 *4 (-1047)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 *3)) (-14 *7 *3)))) 
+(-13 (-1047) (-10 -8 (IF (|has| |#1| (-172)) (-6 (-43 |#1|)) |noBranch|) (-15 -2747 ((-953 |#1|) $)) (-15 -2747 ($ (-953 |#1|))) (IF (|has| |#1| (-365)) (-15 -1781 ((-3 $ "failed") $ $)) |noBranch|) (-15 -3352 ((-1249) (-763))))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-1969 (((-1244 $) $ $) 78)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-2134 (((-121) $) 111)) (-3800 (((-763)) 115)) (-2689 (((-3 $ "failed") $ $) 18)) (-3045 (($ $) 71)) (-3498 (((-420 $) $) 70)) (-2589 (((-121) $ $) 57)) (-3168 (((-1249) $) 74)) (-4490 (($) 16 T CONST)) (-3668 (((-3 (-568) "failed") $) 122) (((-3 (-409 (-568)) "failed") $) 119) (((-3 (-409 (-568)) "failed") $) 104) (((-3 (-860) "failed") $) 136) (((-3 (-860) "failed") $) 130)) (-2857 (((-568) $) 121) (((-409 (-568)) $) 118) (((-409 (-568)) $) 105) (((-860) $) 135) (((-860) $) 131)) (-2403 (($ $ $) 53)) (-3094 (($ (-1157 $)) 84)) (-2902 (((-3 $ "failed") $) 33)) (-2414 (($ $ $) 54)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 49)) (-1887 (($ $ (-763)) 102 (-2199 (|has| (-860) (-148)) (|has| (-860) (-370)) (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370)))) (($ $) 101 (-2199 (|has| (-860) (-148)) (|has| (-860) (-370)) (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-2197 (((-121) $) 69)) (-2474 (($ $) 79)) (-1844 (((-828 (-917)) $) 99 (-2199 (|has| (-860) (-148)) (|has| (-860) (-370)) (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-1598 (((-121) $) 30)) (-1301 (($ (-1157 $) $ (-1161)) 76) (($ (-1157 $) (-1161)) 75)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-3057 (($ (-634 $)) 81)) (-3087 (((-1157 $) $) 86) (((-1157 $) $ $) 85)) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-2083 (($ $) 68)) (-4051 (((-121) $) 112)) (-4025 (((-1108) $) 10)) (-2088 (((-121) $) 82)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-4295 (((-850) $) 73)) (-3850 (((-420 $) $) 72)) (-4321 (((-828 (-917))) 114)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-3917 (((-917) $) 80)) (-2597 (((-3 $ "failed") $ $) 41)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-1466 (((-763) $) 56)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 55)) (-2997 (((-634 $) (-1157 $) $) 83)) (-2721 (((-3 (-763) "failed") $ $) 100 (-2199 (|has| (-860) (-148)) (|has| (-860) (-370)) (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-3108 (((-139)) 106)) (-1836 (((-828 (-917)) $) 113)) (-1492 (((-1157 $)) 88) (((-1157 $) $) 87)) (-2387 (($ $) 77)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63) (($ (-568)) 123) (($ (-409 (-568))) 120) (($ (-409 (-568))) 103) (($ (-860)) 137) (($ (-860)) 129)) (-3385 (((-3 $ "failed") $) 98 (-2199 (|has| (-860) (-148)) (|has| (-860) (-370)) (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-3425 (((-763)) 28)) (-2273 (((-121) $ $) 38)) (-1413 (((-121) $) 110)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3412 (($ $ (-763)) 117 (-2199 (|has| (-860) (-370)) (|has| (-409 (-568)) (-370)))) (($ $) 116 (-2199 (|has| (-860) (-370)) (|has| (-409 (-568)) (-370))))) (-1719 (((-121) $ $) 6)) (-1781 (($ $ $) 62) (($ $ (-409 (-568))) 107) (($ $ (-860)) 132)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64) (($ (-409 (-568)) $) 109) (($ $ (-409 (-568))) 108) (($ (-860) $) 134) (($ $ (-860)) 133))) 
 (((-854) (-1275)) (T -854)) 
 NIL 
 (-13 (-859) (-1037 (-860)) (-1261 (-860))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 (-860) (-860)) . T) ((-120 $ $) . T) ((-137) . T) ((-148) -2198 (|has| (-860) (-370)) (|has| (-860) (-148)) (|has| (-409 (-568)) (-370)) (|has| (-409 (-568)) (-148))) ((-150) . T) ((-608 (-850)) . T) ((-172) . T) ((-238) . T) ((-285) . T) ((-301) . T) ((-1261 (-409 (-568))) . T) ((-1261 (-860)) . T) ((-365) . T) ((-404) -2198 (|has| (-860) (-370)) (|has| (-860) (-148)) (|has| (-409 (-568)) (-370)) (|has| (-409 (-568)) (-148))) ((-453) . T) ((-558) . T) ((-637 (-409 (-568))) . T) ((-637 (-860)) . T) ((-637 $) . T) ((-707 (-409 (-568))) . T) ((-707 (-860)) . T) ((-707 $) . T) ((-716) . T) ((-916) . T) ((-858) . T) ((-859) . T) ((-1037 (-409 (-568))) . T) ((-1037 (-568)) . T) ((-1037 (-860)) . T) ((-1053 (-409 (-568))) . T) ((-1053 (-860)) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1199) . T) ((-1251 (-409 (-568))) . T) ((-1251 (-860)) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 47)) (-2572 (((-1244 $) $ $) 69)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-2615 (((-121) $) NIL)) (-1739 (((-763)) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1497 (((-121) $ $) NIL)) (-1285 (((-1249) $) 78)) (-2671 (($) NIL T CONST)) (-2713 (((-860) $) 17)) (-3666 (((-3 (-568) "failed") $) 75) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 (-860) "failed") $) 72) (((-3 (-860) "failed") $) 72)) (-2854 (((-568) $) NIL) (((-409 (-568)) $) NIL) (((-409 (-568)) $) NIL) (((-860) $) 111) (((-860) $) 111)) (-2401 (($ $ $) NIL)) (-3092 (($ (-1157 $)) 59)) (-2925 (((-3 $ "failed") $) NIL)) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3218 (($ $ (-763)) NIL (-2198 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370)) (|has| (-860) (-148)) (|has| (-860) (-370)))) (($ $) NIL (-2198 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370)) (|has| (-860) (-148)) (|has| (-860) (-370))))) (-3927 (((-121) $) NIL)) (-1473 (($ $) 63)) (-4477 (((-828 (-917)) $) NIL (-2198 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370)) (|has| (-860) (-148)) (|has| (-860) (-370))))) (-2735 (((-121) $) 117)) (-3355 (($ (-1157 $) $ (-1161)) 41) (($ (-1157 $) (-1161)) 94)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3614 (($ (-634 $)) 61)) (-3085 (((-1157 $) $) 55) (((-1157 $) $ $) 56)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) 101)) (-2864 (((-121) $) NIL)) (-4022 (((-1108) $) NIL)) (-2086 (((-121) $) 62)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3936 (((-850) $) 124)) (-3848 (((-420 $) $) NIL)) (-1553 (((-828 (-917))) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2842 (((-917) $) 37)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3598 (((-634 $) (-1157 $) $) 96)) (-3143 (((-3 (-763) "failed") $ $) NIL (-2198 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370)) (|has| (-860) (-148)) (|has| (-860) (-370))))) (-4321 (((-139)) NIL)) (-3206 (((-828 (-917)) $) NIL)) (-1626 (((-1157 $)) 79) (((-1157 $) $) 64)) (-1458 (($ $) NIL)) (-2745 (((-850) $) 123) (($ (-568)) 44) (($ $) NIL) (($ (-409 (-568))) NIL) (($ (-568)) 44) (($ (-409 (-568))) NIL) (($ (-409 (-568))) NIL) (($ (-860)) 118) (($ (-860)) 118)) (-4371 (((-3 $ "failed") $) NIL (-2198 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370)) (|has| (-860) (-148)) (|has| (-860) (-370))))) (-4078 (((-763)) 126)) (-1826 (((-121) $ $) NIL)) (-4390 (((-121) $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) 48 T CONST)) (-1556 (($) 38 T CONST)) (-1316 (($ $ (-763)) NIL (-2198 (|has| (-409 (-568)) (-370)) (|has| (-860) (-370)))) (($ $) NIL (-2198 (|has| (-409 (-568)) (-370)) (|has| (-860) (-370))))) (-1717 (((-121) $ $) 114)) (-1779 (($ $ $) 102) (($ $ (-409 (-568))) NIL) (($ $ (-860)) NIL)) (-1773 (($ $) 35) (($ $ $) 105)) (-1767 (($ $ $) 81)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 53) (($ $ $) 31) (($ $ (-409 (-568))) 109) (($ (-409 (-568)) $) NIL) (($ (-409 (-568)) $) NIL) (($ $ (-409 (-568))) 109) (($ (-860) $) 103) (($ $ (-860)) 104))) 
-(((-855 |#1|) (-13 (-854) (-10 -8 (-15 -3936 ((-850) $)) (-15 -2713 ((-860) $)))) (-860)) (T -855)) 
-((-3936 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-855 *3)) (-14 *3 (-860)))) (-2713 (*1 *2 *1) (-12 (-5 *2 (-860)) (-5 *1 (-855 *3)) (-14 *3 *2)))) 
-(-13 (-854) (-10 -8 (-15 -3936 ((-850) $)) (-15 -2713 ((-860) $)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-2572 (((-1244 $) $ $) 113)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-3211 (((-1169 (-917) (-763)) (-568)) 88)) (-3134 (((-3 $ "failed") $ $) 18)) (-4305 (($ $) 71)) (-1678 (((-420 $) $) 70)) (-1497 (((-121) $ $) 57)) (-3983 (((-763)) 98)) (-1285 (((-1249) $) 117)) (-2671 (($) 16 T CONST)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) 82)) (-2401 (($ $ $) 53)) (-3092 (($ (-1157 $)) 107)) (-2925 (((-3 $ "failed") $) 33)) (-1731 (($) 101)) (-2412 (($ $ $) 54)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 49)) (-4220 (($) 86)) (-4456 (((-121) $) 85)) (-3218 (($ $) 75) (($ $ (-763)) 74)) (-3927 (((-121) $) 69)) (-1473 (($ $) 112)) (-4477 (((-828 (-917)) $) 77) (((-917) $) 83)) (-2735 (((-121) $) 30)) (-3038 (((-3 $ "failed") $) 97)) (-3355 (($ (-1157 $) (-1161)) 116) (($ (-1157 $) $ (-1161)) 115)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-3614 (($ (-634 $)) 110)) (-3683 (((-917) $) 100)) (-3085 (((-1157 $) $ $) 106) (((-1157 $) $) 105)) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-2081 (($ $) 68)) (-4434 (($) 96 T CONST)) (-4355 (($ (-917)) 99)) (-4022 (((-1108) $) 10)) (-2086 (((-121) $) 109)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-3936 (((-850) $) 118)) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) 89)) (-3848 (((-420 $) $) 72)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2842 (((-917) $) 111)) (-2595 (((-3 $ "failed") $ $) 41)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-2709 (((-763) $) 56)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 55)) (-3598 (((-634 $) (-1157 $) $) 108)) (-3143 (((-3 (-763) "failed") $ $) 76) (((-763) $) 84)) (-4189 (($ $ (-763)) 94) (($ $) 92)) (-1626 (((-1157 $) $) 104) (((-1157 $)) 103)) (-3065 (($) 87)) (-1458 (($ $) 114)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) 90)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63)) (-4371 (((-3 $ "failed") $) 78) (($ $) 91)) (-4078 (((-763)) 28)) (-1826 (((-121) $ $) 38)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $ (-763)) 95) (($ $) 93)) (-1717 (((-121) $ $) 6)) (-1779 (($ $ $) 62)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 (-860) (-860)) . T) ((-120 $ $) . T) ((-137) . T) ((-148) -2199 (|has| (-860) (-370)) (|has| (-860) (-148)) (|has| (-409 (-568)) (-370)) (|has| (-409 (-568)) (-148))) ((-150) . T) ((-608 (-850)) . T) ((-172) . T) ((-238) . T) ((-285) . T) ((-301) . T) ((-1261 (-409 (-568))) . T) ((-1261 (-860)) . T) ((-365) . T) ((-404) -2199 (|has| (-860) (-370)) (|has| (-860) (-148)) (|has| (-409 (-568)) (-370)) (|has| (-409 (-568)) (-148))) ((-453) . T) ((-558) . T) ((-637 (-409 (-568))) . T) ((-637 (-860)) . T) ((-637 $) . T) ((-707 (-409 (-568))) . T) ((-707 (-860)) . T) ((-707 $) . T) ((-716) . T) ((-916) . T) ((-858) . T) ((-859) . T) ((-1037 (-409 (-568))) . T) ((-1037 (-568)) . T) ((-1037 (-860)) . T) ((-1053 (-409 (-568))) . T) ((-1053 (-860)) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1199) . T) ((-1251 (-409 (-568))) . T) ((-1251 (-860)) . T)) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 47)) (-1969 (((-1244 $) $ $) 69)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2134 (((-121) $) NIL)) (-3800 (((-763)) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2589 (((-121) $ $) NIL)) (-3168 (((-1249) $) 78)) (-4490 (($) NIL T CONST)) (-1494 (((-860) $) 17)) (-3668 (((-3 (-568) "failed") $) 75) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 (-860) "failed") $) 72) (((-3 (-860) "failed") $) 72)) (-2857 (((-568) $) NIL) (((-409 (-568)) $) NIL) (((-409 (-568)) $) NIL) (((-860) $) 111) (((-860) $) 111)) (-2403 (($ $ $) NIL)) (-3094 (($ (-1157 $)) 59)) (-2902 (((-3 $ "failed") $) NIL)) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-1887 (($ $ (-763)) NIL (-2199 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370)) (|has| (-860) (-148)) (|has| (-860) (-370)))) (($ $) NIL (-2199 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370)) (|has| (-860) (-148)) (|has| (-860) (-370))))) (-2197 (((-121) $) NIL)) (-2474 (($ $) 63)) (-1844 (((-828 (-917)) $) NIL (-2199 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370)) (|has| (-860) (-148)) (|has| (-860) (-370))))) (-1598 (((-121) $) 117)) (-1301 (($ (-1157 $) $ (-1161)) 41) (($ (-1157 $) (-1161)) 94)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3057 (($ (-634 $)) 61)) (-3087 (((-1157 $) $) 55) (((-1157 $) $ $) 56)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) 101)) (-4051 (((-121) $) NIL)) (-4025 (((-1108) $) NIL)) (-2088 (((-121) $) 62)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4295 (((-850) $) 124)) (-3850 (((-420 $) $) NIL)) (-4321 (((-828 (-917))) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3917 (((-917) $) 37)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-2997 (((-634 $) (-1157 $) $) 96)) (-2721 (((-3 (-763) "failed") $ $) NIL (-2199 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370)) (|has| (-860) (-148)) (|has| (-860) (-370))))) (-3108 (((-139)) NIL)) (-1836 (((-828 (-917)) $) NIL)) (-1492 (((-1157 $)) 79) (((-1157 $) $) 64)) (-2387 (($ $) NIL)) (-2747 (((-850) $) 123) (($ (-568)) 44) (($ $) NIL) (($ (-409 (-568))) NIL) (($ (-568)) 44) (($ (-409 (-568))) NIL) (($ (-409 (-568))) NIL) (($ (-860)) 118) (($ (-860)) 118)) (-3385 (((-3 $ "failed") $) NIL (-2199 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370)) (|has| (-860) (-148)) (|has| (-860) (-370))))) (-3425 (((-763)) 126)) (-2273 (((-121) $ $) NIL)) (-1413 (((-121) $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) 48 T CONST)) (-1557 (($) 38 T CONST)) (-3412 (($ $ (-763)) NIL (-2199 (|has| (-409 (-568)) (-370)) (|has| (-860) (-370)))) (($ $) NIL (-2199 (|has| (-409 (-568)) (-370)) (|has| (-860) (-370))))) (-1719 (((-121) $ $) 114)) (-1781 (($ $ $) 102) (($ $ (-409 (-568))) NIL) (($ $ (-860)) NIL)) (-1775 (($ $) 35) (($ $ $) 105)) (-1769 (($ $ $) 81)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 53) (($ $ $) 31) (($ $ (-409 (-568))) 109) (($ (-409 (-568)) $) NIL) (($ (-409 (-568)) $) NIL) (($ $ (-409 (-568))) 109) (($ (-860) $) 103) (($ $ (-860)) 104))) 
+(((-855 |#1|) (-13 (-854) (-10 -8 (-15 -4295 ((-850) $)) (-15 -1494 ((-860) $)))) (-860)) (T -855)) 
+((-4295 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-855 *3)) (-14 *3 (-860)))) (-1494 (*1 *2 *1) (-12 (-5 *2 (-860)) (-5 *1 (-855 *3)) (-14 *3 *2)))) 
+(-13 (-854) (-10 -8 (-15 -4295 ((-850) $)) (-15 -1494 ((-860) $)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-1969 (((-1244 $) $ $) 113)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-1856 (((-1169 (-917) (-763)) (-568)) 88)) (-2689 (((-3 $ "failed") $ $) 18)) (-3045 (($ $) 71)) (-3498 (((-420 $) $) 70)) (-2589 (((-121) $ $) 57)) (-3986 (((-763)) 98)) (-3168 (((-1249) $) 117)) (-4490 (($) 16 T CONST)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) 82)) (-2403 (($ $ $) 53)) (-3094 (($ (-1157 $)) 107)) (-2902 (((-3 $ "failed") $) 33)) (-1733 (($) 101)) (-2414 (($ $ $) 54)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 49)) (-4188 (($) 86)) (-1748 (((-121) $) 85)) (-1887 (($ $) 75) (($ $ (-763)) 74)) (-2197 (((-121) $) 69)) (-2474 (($ $) 112)) (-1844 (((-828 (-917)) $) 77) (((-917) $) 83)) (-1598 (((-121) $) 30)) (-2214 (((-3 $ "failed") $) 97)) (-1301 (($ (-1157 $) (-1161)) 116) (($ (-1157 $) $ (-1161)) 115)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-3057 (($ (-634 $)) 110)) (-2291 (((-917) $) 100)) (-3087 (((-1157 $) $ $) 106) (((-1157 $) $) 105)) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-2083 (($ $) 68)) (-4436 (($) 96 T CONST)) (-4357 (($ (-917)) 99)) (-4025 (((-1108) $) 10)) (-2088 (((-121) $) 109)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-4295 (((-850) $) 118)) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) 89)) (-3850 (((-420 $) $) 72)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-3917 (((-917) $) 111)) (-2597 (((-3 $ "failed") $ $) 41)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-1466 (((-763) $) 56)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 55)) (-2997 (((-634 $) (-1157 $) $) 108)) (-2721 (((-3 (-763) "failed") $ $) 76) (((-763) $) 84)) (-4191 (($ $ (-763)) 94) (($ $) 92)) (-1492 (((-1157 $) $) 104) (((-1157 $)) 103)) (-2330 (($) 87)) (-2387 (($ $) 114)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) 90)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63)) (-3385 (((-3 $ "failed") $) 78) (($ $) 91)) (-3425 (((-763)) 28)) (-2273 (((-121) $ $) 38)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $ (-763)) 95) (($ $) 93)) (-1719 (((-121) $ $) 6)) (-1781 (($ $ $) 62)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64))) 
 (((-856) (-1275)) (T -856)) 
 NIL 
 (-13 (-350) (-858)) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 $ $) . T) ((-137) . T) ((-148) . T) ((-608 (-850)) . T) ((-172) . T) ((-225) . T) ((-238) . T) ((-285) . T) ((-301) . T) ((-365) . T) ((-404) . T) ((-370) . T) ((-350) . T) ((-453) . T) ((-558) . T) ((-637 (-409 (-568))) . T) ((-637 $) . T) ((-707 (-409 (-568))) . T) ((-707 $) . T) ((-716) . T) ((-916) . T) ((-858) . T) ((-1053 (-409 (-568))) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1136) . T) ((-1199) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 29)) (-2572 (((-1244 $) $ $) 48)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 39)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-2615 (((-121) $) NIL)) (-1739 (((-763)) NIL)) (-3211 (((-1169 (-917) (-763)) (-568)) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1497 (((-121) $ $) NIL)) (-3983 (((-763)) 52)) (-1285 (((-1249) $) 56)) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) 126)) (-2854 ((|#1| $) 85)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) 139)) (-2401 (($ $ $) NIL)) (-3092 (($ (-1157 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1731 (($) 82)) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-4220 (($) NIL)) (-4456 (((-121) $) NIL)) (-3218 (($ $) NIL) (($ $ (-763)) NIL)) (-3927 (((-121) $) NIL)) (-1473 (($ $) 41)) (-4477 (((-828 (-917)) $) NIL) (((-917) $) NIL)) (-2735 (((-121) $) 123)) (-3038 (((-3 $ "failed") $) NIL)) (-3355 (($ (-1157 $) (-1161)) 79) (($ (-1157 $) $ (-1161)) 99)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3614 (($ (-634 $)) 104)) (-3683 (((-917) $) 134)) (-3085 (((-1157 $) $ $) NIL) (((-1157 $) $) NIL)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) 27)) (-4434 (($) NIL T CONST)) (-4355 (($ (-917)) 136)) (-2864 (((-121) $) NIL)) (-4022 (((-1108) $) NIL)) (-2086 (((-121) $) 40)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3936 (((-850) $) 132)) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) NIL)) (-3848 (((-420 $) $) NIL)) (-1553 (((-828 (-917))) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2842 (((-917) $) 14)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3598 (((-634 $) (-1157 $) $) 81)) (-3143 (((-3 (-763) "failed") $ $) NIL) (((-763) $) NIL)) (-4321 (((-139)) NIL)) (-4189 (($ $ (-763)) NIL) (($ $) NIL)) (-3206 (((-828 (-917)) $) 17)) (-1626 (((-1157 $) $) 20) (((-1157 $)) NIL)) (-3065 (($) NIL)) (-1458 (($ $) 90)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL)) (-2745 (((-850) $) 131) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ |#1|) 124)) (-4371 (((-3 $ "failed") $) NIL) (($ $) 89)) (-4078 (((-763)) 140)) (-1826 (((-121) $ $) NIL)) (-4390 (((-121) $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) 30 T CONST)) (-1556 (($) 21 T CONST)) (-1316 (($ $ (-763)) NIL (|has| |#1| (-370))) (($ $) NIL (|has| |#1| (-370)))) (-3190 (($ $ (-763)) NIL) (($ $) NIL)) (-1717 (((-121) $ $) 120)) (-1779 (($ $ $) 96) (($ $ |#1|) NIL)) (-1773 (($ $) 97) (($ $ $) 107)) (-1767 (($ $ $) 63)) (** (($ $ (-917)) 33) (($ $ (-763)) 34) (($ $ (-568)) 37)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 111) (($ $ $) 65) (($ $ (-409 (-568))) 112) (($ (-409 (-568)) $) NIL) (($ |#1| $) 105) (($ $ |#1|) 106))) 
-(((-857 |#1|) (-13 (-856) (-1261 |#1|) (-10 -8 (-15 -3936 ((-850) $)))) (-350)) (T -857)) 
-((-3936 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-857 *3)) (-4 *3 (-350))))) 
-(-13 (-856) (-1261 |#1|) (-10 -8 (-15 -3936 ((-850) $)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-2572 (((-1244 $) $ $) 78)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-3134 (((-3 $ "failed") $ $) 18)) (-4305 (($ $) 71)) (-1678 (((-420 $) $) 70)) (-1497 (((-121) $ $) 57)) (-1285 (((-1249) $) 74)) (-2671 (($) 16 T CONST)) (-2401 (($ $ $) 53)) (-3092 (($ (-1157 $)) 84)) (-2925 (((-3 $ "failed") $) 33)) (-2412 (($ $ $) 54)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 49)) (-3927 (((-121) $) 69)) (-1473 (($ $) 79)) (-2735 (((-121) $) 30)) (-3355 (($ (-1157 $) $ (-1161)) 76) (($ (-1157 $) (-1161)) 75)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-3614 (($ (-634 $)) 81)) (-3085 (((-1157 $) $) 86) (((-1157 $) $ $) 85)) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-2081 (($ $) 68)) (-4022 (((-1108) $) 10)) (-2086 (((-121) $) 82)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-3936 (((-850) $) 73)) (-3848 (((-420 $) $) 72)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2842 (((-917) $) 80)) (-2595 (((-3 $ "failed") $ $) 41)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-2709 (((-763) $) 56)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 55)) (-3598 (((-634 $) (-1157 $) $) 83)) (-1626 (((-1157 $)) 88) (((-1157 $) $) 87)) (-1458 (($ $) 77)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63)) (-4078 (((-763)) 28)) (-1826 (((-121) $ $) 38)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1779 (($ $ $) 62)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 29)) (-1969 (((-1244 $) $ $) 48)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 39)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2134 (((-121) $) NIL)) (-3800 (((-763)) NIL)) (-1856 (((-1169 (-917) (-763)) (-568)) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2589 (((-121) $ $) NIL)) (-3986 (((-763)) 52)) (-3168 (((-1249) $) 56)) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) 126)) (-2857 ((|#1| $) 85)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) 139)) (-2403 (($ $ $) NIL)) (-3094 (($ (-1157 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1733 (($) 82)) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-4188 (($) NIL)) (-1748 (((-121) $) NIL)) (-1887 (($ $) NIL) (($ $ (-763)) NIL)) (-2197 (((-121) $) NIL)) (-2474 (($ $) 41)) (-1844 (((-828 (-917)) $) NIL) (((-917) $) NIL)) (-1598 (((-121) $) 123)) (-2214 (((-3 $ "failed") $) NIL)) (-1301 (($ (-1157 $) (-1161)) 79) (($ (-1157 $) $ (-1161)) 99)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3057 (($ (-634 $)) 104)) (-2291 (((-917) $) 134)) (-3087 (((-1157 $) $ $) NIL) (((-1157 $) $) NIL)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) 27)) (-4436 (($) NIL T CONST)) (-4357 (($ (-917)) 136)) (-4051 (((-121) $) NIL)) (-4025 (((-1108) $) NIL)) (-2088 (((-121) $) 40)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4295 (((-850) $) 132)) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) NIL)) (-3850 (((-420 $) $) NIL)) (-4321 (((-828 (-917))) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3917 (((-917) $) 14)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-2997 (((-634 $) (-1157 $) $) 81)) (-2721 (((-3 (-763) "failed") $ $) NIL) (((-763) $) NIL)) (-3108 (((-139)) NIL)) (-4191 (($ $ (-763)) NIL) (($ $) NIL)) (-1836 (((-828 (-917)) $) 17)) (-1492 (((-1157 $) $) 20) (((-1157 $)) NIL)) (-2330 (($) NIL)) (-2387 (($ $) 90)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL)) (-2747 (((-850) $) 131) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ |#1|) 124)) (-3385 (((-3 $ "failed") $) NIL) (($ $) 89)) (-3425 (((-763)) 140)) (-2273 (((-121) $ $) NIL)) (-1413 (((-121) $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) 30 T CONST)) (-1557 (($) 21 T CONST)) (-3412 (($ $ (-763)) NIL (|has| |#1| (-370))) (($ $) NIL (|has| |#1| (-370)))) (-3192 (($ $ (-763)) NIL) (($ $) NIL)) (-1719 (((-121) $ $) 120)) (-1781 (($ $ $) 96) (($ $ |#1|) NIL)) (-1775 (($ $) 97) (($ $ $) 107)) (-1769 (($ $ $) 63)) (** (($ $ (-917)) 33) (($ $ (-763)) 34) (($ $ (-568)) 37)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 111) (($ $ $) 65) (($ $ (-409 (-568))) 112) (($ (-409 (-568)) $) NIL) (($ |#1| $) 105) (($ $ |#1|) 106))) 
+(((-857 |#1|) (-13 (-856) (-1261 |#1|) (-10 -8 (-15 -4295 ((-850) $)))) (-350)) (T -857)) 
+((-4295 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-857 *3)) (-4 *3 (-350))))) 
+(-13 (-856) (-1261 |#1|) (-10 -8 (-15 -4295 ((-850) $)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-1969 (((-1244 $) $ $) 78)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-2689 (((-3 $ "failed") $ $) 18)) (-3045 (($ $) 71)) (-3498 (((-420 $) $) 70)) (-2589 (((-121) $ $) 57)) (-3168 (((-1249) $) 74)) (-4490 (($) 16 T CONST)) (-2403 (($ $ $) 53)) (-3094 (($ (-1157 $)) 84)) (-2902 (((-3 $ "failed") $) 33)) (-2414 (($ $ $) 54)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 49)) (-2197 (((-121) $) 69)) (-2474 (($ $) 79)) (-1598 (((-121) $) 30)) (-1301 (($ (-1157 $) $ (-1161)) 76) (($ (-1157 $) (-1161)) 75)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-3057 (($ (-634 $)) 81)) (-3087 (((-1157 $) $) 86) (((-1157 $) $ $) 85)) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-2083 (($ $) 68)) (-4025 (((-1108) $) 10)) (-2088 (((-121) $) 82)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-4295 (((-850) $) 73)) (-3850 (((-420 $) $) 72)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-3917 (((-917) $) 80)) (-2597 (((-3 $ "failed") $ $) 41)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-1466 (((-763) $) 56)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 55)) (-2997 (((-634 $) (-1157 $) $) 83)) (-1492 (((-1157 $)) 88) (((-1157 $) $) 87)) (-2387 (($ $) 77)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63)) (-3425 (((-763)) 28)) (-2273 (((-121) $ $) 38)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1781 (($ $ $) 62)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64))) 
 (((-858) (-1275)) (T -858)) 
-((-1626 (*1 *2) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-858)))) (-1626 (*1 *2 *1) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-858)))) (-3085 (*1 *2 *1) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-858)))) (-3085 (*1 *2 *1 *1) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-858)))) (-3092 (*1 *1 *2) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-858)))) (-3598 (*1 *2 *3 *1) (-12 (-5 *3 (-1157 *1)) (-4 *1 (-858)) (-5 *2 (-634 *1)))) (-2086 (*1 *2 *1) (-12 (-4 *1 (-858)) (-5 *2 (-121)))) (-3614 (*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-858)))) (-2842 (*1 *2 *1) (-12 (-4 *1 (-858)) (-5 *2 (-917)))) (-1473 (*1 *1 *1) (-4 *1 (-858))) (-2572 (*1 *2 *1 *1) (-12 (-5 *2 (-1244 *1)) (-4 *1 (-858)))) (-1458 (*1 *1 *1) (-4 *1 (-858))) (-3355 (*1 *1 *2 *1 *3) (-12 (-5 *2 (-1157 *1)) (-5 *3 (-1161)) (-4 *1 (-858)))) (-3355 (*1 *1 *2 *3) (-12 (-5 *2 (-1157 *1)) (-5 *3 (-1161)) (-4 *1 (-858)))) (-1285 (*1 *2 *1) (-12 (-4 *1 (-858)) (-5 *2 (-1249)))) (-3936 (*1 *2 *1) (-12 (-4 *1 (-858)) (-5 *2 (-850))))) 
-(-13 (-365) (-10 -8 (-15 -1626 ((-1157 $))) (-15 -1626 ((-1157 $) $)) (-15 -3085 ((-1157 $) $)) (-15 -3085 ((-1157 $) $ $)) (-15 -3092 ($ (-1157 $))) (-15 -3598 ((-634 $) (-1157 $) $)) (-15 -2086 ((-121) $)) (-15 -3614 ($ (-634 $))) (-15 -2842 ((-917) $)) (-15 -1473 ($ $)) (-15 -2572 ((-1244 $) $ $)) (-15 -1458 ($ $)) (-15 -3355 ($ (-1157 $) $ (-1161))) (-15 -3355 ($ (-1157 $) (-1161))) (-15 -1285 ((-1249) $)) (-15 -3936 ((-850) $)))) 
+((-1492 (*1 *2) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-858)))) (-1492 (*1 *2 *1) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-858)))) (-3087 (*1 *2 *1) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-858)))) (-3087 (*1 *2 *1 *1) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-858)))) (-3094 (*1 *1 *2) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-858)))) (-2997 (*1 *2 *3 *1) (-12 (-5 *3 (-1157 *1)) (-4 *1 (-858)) (-5 *2 (-634 *1)))) (-2088 (*1 *2 *1) (-12 (-4 *1 (-858)) (-5 *2 (-121)))) (-3057 (*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-858)))) (-3917 (*1 *2 *1) (-12 (-4 *1 (-858)) (-5 *2 (-917)))) (-2474 (*1 *1 *1) (-4 *1 (-858))) (-1969 (*1 *2 *1 *1) (-12 (-5 *2 (-1244 *1)) (-4 *1 (-858)))) (-2387 (*1 *1 *1) (-4 *1 (-858))) (-1301 (*1 *1 *2 *1 *3) (-12 (-5 *2 (-1157 *1)) (-5 *3 (-1161)) (-4 *1 (-858)))) (-1301 (*1 *1 *2 *3) (-12 (-5 *2 (-1157 *1)) (-5 *3 (-1161)) (-4 *1 (-858)))) (-3168 (*1 *2 *1) (-12 (-4 *1 (-858)) (-5 *2 (-1249)))) (-4295 (*1 *2 *1) (-12 (-4 *1 (-858)) (-5 *2 (-850))))) 
+(-13 (-365) (-10 -8 (-15 -1492 ((-1157 $))) (-15 -1492 ((-1157 $) $)) (-15 -3087 ((-1157 $) $)) (-15 -3087 ((-1157 $) $ $)) (-15 -3094 ($ (-1157 $))) (-15 -2997 ((-634 $) (-1157 $) $)) (-15 -2088 ((-121) $)) (-15 -3057 ($ (-634 $))) (-15 -3917 ((-917) $)) (-15 -2474 ($ $)) (-15 -1969 ((-1244 $) $ $)) (-15 -2387 ($ $)) (-15 -1301 ($ (-1157 $) $ (-1161))) (-15 -1301 ($ (-1157 $) (-1161))) (-15 -3168 ((-1249) $)) (-15 -4295 ((-850) $)))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 $ $) . T) ((-137) . T) ((-608 (-850)) . T) ((-172) . T) ((-238) . T) ((-285) . T) ((-301) . T) ((-365) . T) ((-453) . T) ((-558) . T) ((-637 (-409 (-568))) . T) ((-637 $) . T) ((-707 (-409 (-568))) . T) ((-707 $) . T) ((-716) . T) ((-916) . T) ((-1053 (-409 (-568))) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1199) . T)) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-2572 (((-1244 $) $ $) 78)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-2615 (((-121) $) 111)) (-1739 (((-763)) 115)) (-3134 (((-3 $ "failed") $ $) 18)) (-4305 (($ $) 71)) (-1678 (((-420 $) $) 70)) (-1497 (((-121) $ $) 57)) (-1285 (((-1249) $) 74)) (-2671 (($) 16 T CONST)) (-3666 (((-3 (-568) "failed") $) 122) (((-3 (-409 (-568)) "failed") $) 119) (((-3 (-409 (-568)) "failed") $) 104)) (-2854 (((-568) $) 121) (((-409 (-568)) $) 118) (((-409 (-568)) $) 105)) (-2401 (($ $ $) 53)) (-3092 (($ (-1157 $)) 84)) (-2925 (((-3 $ "failed") $) 33)) (-2412 (($ $ $) 54)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 49)) (-3218 (($ $ (-763)) 102 (-2198 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370)))) (($ $) 101 (-2198 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-3927 (((-121) $) 69)) (-1473 (($ $) 79)) (-4477 (((-828 (-917)) $) 99 (-2198 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-2735 (((-121) $) 30)) (-3355 (($ (-1157 $) $ (-1161)) 76) (($ (-1157 $) (-1161)) 75)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-3614 (($ (-634 $)) 81)) (-3085 (((-1157 $) $) 86) (((-1157 $) $ $) 85)) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-2081 (($ $) 68)) (-2864 (((-121) $) 112)) (-4022 (((-1108) $) 10)) (-2086 (((-121) $) 82)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-3936 (((-850) $) 73)) (-3848 (((-420 $) $) 72)) (-1553 (((-828 (-917))) 114)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2842 (((-917) $) 80)) (-2595 (((-3 $ "failed") $ $) 41)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-2709 (((-763) $) 56)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 55)) (-3598 (((-634 $) (-1157 $) $) 83)) (-3143 (((-3 (-763) "failed") $ $) 100 (-2198 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-4321 (((-139)) 106)) (-3206 (((-828 (-917)) $) 113)) (-1626 (((-1157 $)) 88) (((-1157 $) $) 87)) (-1458 (($ $) 77)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63) (($ (-568)) 123) (($ (-409 (-568))) 120) (($ (-409 (-568))) 103)) (-4371 (((-3 $ "failed") $) 98 (-2198 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-4078 (((-763)) 28)) (-1826 (((-121) $ $) 38)) (-4390 (((-121) $) 110)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1316 (($ $ (-763)) 117 (|has| (-409 (-568)) (-370))) (($ $) 116 (|has| (-409 (-568)) (-370)))) (-1717 (((-121) $ $) 6)) (-1779 (($ $ $) 62) (($ $ (-409 (-568))) 107)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64) (($ (-409 (-568)) $) 109) (($ $ (-409 (-568))) 108))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-1969 (((-1244 $) $ $) 78)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-2134 (((-121) $) 111)) (-3800 (((-763)) 115)) (-2689 (((-3 $ "failed") $ $) 18)) (-3045 (($ $) 71)) (-3498 (((-420 $) $) 70)) (-2589 (((-121) $ $) 57)) (-3168 (((-1249) $) 74)) (-4490 (($) 16 T CONST)) (-3668 (((-3 (-568) "failed") $) 122) (((-3 (-409 (-568)) "failed") $) 119) (((-3 (-409 (-568)) "failed") $) 104)) (-2857 (((-568) $) 121) (((-409 (-568)) $) 118) (((-409 (-568)) $) 105)) (-2403 (($ $ $) 53)) (-3094 (($ (-1157 $)) 84)) (-2902 (((-3 $ "failed") $) 33)) (-2414 (($ $ $) 54)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 49)) (-1887 (($ $ (-763)) 102 (-2199 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370)))) (($ $) 101 (-2199 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-2197 (((-121) $) 69)) (-2474 (($ $) 79)) (-1844 (((-828 (-917)) $) 99 (-2199 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-1598 (((-121) $) 30)) (-1301 (($ (-1157 $) $ (-1161)) 76) (($ (-1157 $) (-1161)) 75)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-3057 (($ (-634 $)) 81)) (-3087 (((-1157 $) $) 86) (((-1157 $) $ $) 85)) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-2083 (($ $) 68)) (-4051 (((-121) $) 112)) (-4025 (((-1108) $) 10)) (-2088 (((-121) $) 82)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-4295 (((-850) $) 73)) (-3850 (((-420 $) $) 72)) (-4321 (((-828 (-917))) 114)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-3917 (((-917) $) 80)) (-2597 (((-3 $ "failed") $ $) 41)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-1466 (((-763) $) 56)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 55)) (-2997 (((-634 $) (-1157 $) $) 83)) (-2721 (((-3 (-763) "failed") $ $) 100 (-2199 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-3108 (((-139)) 106)) (-1836 (((-828 (-917)) $) 113)) (-1492 (((-1157 $)) 88) (((-1157 $) $) 87)) (-2387 (($ $) 77)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63) (($ (-568)) 123) (($ (-409 (-568))) 120) (($ (-409 (-568))) 103)) (-3385 (((-3 $ "failed") $) 98 (-2199 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-3425 (((-763)) 28)) (-2273 (((-121) $ $) 38)) (-1413 (((-121) $) 110)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3412 (($ $ (-763)) 117 (|has| (-409 (-568)) (-370))) (($ $) 116 (|has| (-409 (-568)) (-370)))) (-1719 (((-121) $ $) 6)) (-1781 (($ $ $) 62) (($ $ (-409 (-568))) 107)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64) (($ (-409 (-568)) $) 109) (($ $ (-409 (-568))) 108))) 
 (((-859) (-1275)) (T -859)) 
 NIL 
 (-13 (-858) (-150) (-1037 (-568)) (-1037 (-409 (-568))) (-1261 (-409 (-568)))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 $ $) . T) ((-137) . T) ((-148) -2198 (|has| (-409 (-568)) (-370)) (|has| (-409 (-568)) (-148))) ((-150) . T) ((-608 (-850)) . T) ((-172) . T) ((-238) . T) ((-285) . T) ((-301) . T) ((-1261 (-409 (-568))) . T) ((-365) . T) ((-404) -2198 (|has| (-409 (-568)) (-370)) (|has| (-409 (-568)) (-148))) ((-453) . T) ((-558) . T) ((-637 (-409 (-568))) . T) ((-637 $) . T) ((-707 (-409 (-568))) . T) ((-707 $) . T) ((-716) . T) ((-916) . T) ((-858) . T) ((-1037 (-409 (-568))) . T) ((-1037 (-568)) . T) ((-1053 (-409 (-568))) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1199) . T) ((-1251 (-409 (-568))) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 16)) (-2572 (((-1244 $) $ $) 47)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-2615 (((-121) $) NIL)) (-1739 (((-763)) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1497 (((-121) $ $) NIL)) (-1285 (((-1249) $) 51)) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) 104) (((-3 (-409 (-568)) "failed") $) 106) (((-3 (-409 (-568)) "failed") $) 106)) (-2854 (((-568) $) NIL) (((-409 (-568)) $) 94) (((-409 (-568)) $) 94)) (-2401 (($ $ $) NIL)) (-3092 (($ (-1157 $)) 34)) (-2925 (((-3 $ "failed") $) NIL)) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3218 (($ $ (-763)) NIL (-2198 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370)))) (($ $) NIL (-2198 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-3927 (((-121) $) NIL)) (-1473 (($ $) 40)) (-4477 (((-828 (-917)) $) NIL (-2198 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-2735 (((-121) $) 100)) (-3355 (($ (-1157 $) $ (-1161)) 79) (($ (-1157 $) (-1161)) 70) (($ (-1157 $) (-1157 $) (-917) $ (-1161)) 80)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3614 (($ (-634 $)) 38)) (-3085 (((-1157 $) $) 29) (((-1157 $) $ $) 31)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) 86)) (-2864 (((-121) $) NIL)) (-4022 (((-1108) $) NIL)) (-2086 (((-121) $) 39)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3936 (((-850) $) 112)) (-3848 (((-420 $) $) NIL)) (-1553 (((-828 (-917))) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2842 (((-917) $) 30)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3598 (((-634 $) (-1157 $) $) 72)) (-3143 (((-3 (-763) "failed") $ $) NIL (-2198 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-4321 (((-139)) NIL)) (-3206 (((-828 (-917)) $) NIL)) (-1626 (((-1157 $)) 52) (((-1157 $) $) 41)) (-1458 (($ $) NIL)) (-2745 (((-850) $) 111) (($ (-568)) 14) (($ $) NIL) (($ (-409 (-568))) 101) (($ (-568)) 14) (($ (-409 (-568))) 101) (($ (-409 (-568))) 101)) (-4371 (((-3 $ "failed") $) NIL (-2198 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-4078 (((-763)) 114)) (-1826 (((-121) $ $) NIL)) (-4390 (((-121) $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) 17 T CONST)) (-1556 (($) 73 T CONST)) (-1316 (($ $ (-763)) NIL (|has| (-409 (-568)) (-370))) (($ $) NIL (|has| (-409 (-568)) (-370)))) (-1717 (((-121) $ $) 97)) (-1779 (($ $ $) 78) (($ $ (-409 (-568))) NIL)) (-1773 (($ $) 19) (($ $ $) 89)) (-1767 (($ $ $) 54)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 18) (($ $ $) 57) (($ $ (-409 (-568))) 88) (($ (-409 (-568)) $) 87) (($ (-409 (-568)) $) 87) (($ $ (-409 (-568))) 88))) 
-(((-860) (-13 (-859) (-10 -8 (-15 -3936 ((-850) $)) (-15 -3355 ($ (-1157 $) (-1157 $) (-917) $ (-1161)))))) (T -860)) 
-((-3936 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-860)))) (-3355 (*1 *1 *2 *2 *3 *1 *4) (-12 (-5 *2 (-1157 (-860))) (-5 *3 (-917)) (-5 *4 (-1161)) (-5 *1 (-860))))) 
-(-13 (-859) (-10 -8 (-15 -3936 ((-850) $)) (-15 -3355 ($ (-1157 $) (-1157 $) (-917) $ (-1161))))) 
-((-3638 (((-3 (-173 |#3|) "failed") (-763) (-763) |#2| |#2|) 31)) (-1822 (((-3 (-409 |#3|) "failed") (-763) (-763) |#2| |#2|) 24))) 
-(((-861 |#1| |#2| |#3|) (-10 -7 (-15 -1822 ((-3 (-409 |#3|) "failed") (-763) (-763) |#2| |#2|)) (-15 -3638 ((-3 (-173 |#3|) "failed") (-763) (-763) |#2| |#2|))) (-365) (-1234 |#1|) (-1219 |#1|)) (T -861)) 
-((-3638 (*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-763)) (-4 *5 (-365)) (-5 *2 (-173 *6)) (-5 *1 (-861 *5 *4 *6)) (-4 *4 (-1234 *5)) (-4 *6 (-1219 *5)))) (-1822 (*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-763)) (-4 *5 (-365)) (-5 *2 (-409 *6)) (-5 *1 (-861 *5 *4 *6)) (-4 *4 (-1234 *5)) (-4 *6 (-1219 *5))))) 
-(-10 -7 (-15 -1822 ((-3 (-409 |#3|) "failed") (-763) (-763) |#2| |#2|)) (-15 -3638 ((-3 (-173 |#3|) "failed") (-763) (-763) |#2| |#2|))) 
-((-1822 (((-3 (-409 (-1216 |#2| |#1|)) "failed") (-763) (-763) (-1235 |#1| |#2| |#3|)) 28) (((-3 (-409 (-1216 |#2| |#1|)) "failed") (-763) (-763) (-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|)) 26))) 
-(((-862 |#1| |#2| |#3|) (-10 -7 (-15 -1822 ((-3 (-409 (-1216 |#2| |#1|)) "failed") (-763) (-763) (-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|))) (-15 -1822 ((-3 (-409 (-1216 |#2| |#1|)) "failed") (-763) (-763) (-1235 |#1| |#2| |#3|)))) (-365) (-1161) |#1|) (T -862)) 
-((-1822 (*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-763)) (-5 *4 (-1235 *5 *6 *7)) (-4 *5 (-365)) (-14 *6 (-1161)) (-14 *7 *5) (-5 *2 (-409 (-1216 *6 *5))) (-5 *1 (-862 *5 *6 *7)))) (-1822 (*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-763)) (-5 *4 (-1235 *5 *6 *7)) (-4 *5 (-365)) (-14 *6 (-1161)) (-14 *7 *5) (-5 *2 (-409 (-1216 *6 *5))) (-5 *1 (-862 *5 *6 *7))))) 
-(-10 -7 (-15 -1822 ((-3 (-409 (-1216 |#2| |#1|)) "failed") (-763) (-763) (-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|))) (-15 -1822 ((-3 (-409 (-1216 |#2| |#1|)) "failed") (-763) (-763) (-1235 |#1| |#2| |#3|)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-3134 (((-3 $ "failed") $ $) 18)) (-1902 (($ $ (-568)) 60)) (-1497 (((-121) $ $) 57)) (-2671 (($) 16 T CONST)) (-2143 (($ (-1157 (-568)) (-568)) 59)) (-2401 (($ $ $) 53)) (-2925 (((-3 $ "failed") $) 33)) (-3974 (($ $) 62)) (-2412 (($ $ $) 54)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 49)) (-4477 (((-763) $) 67)) (-2735 (((-121) $) 30)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-3094 (((-568)) 64)) (-1914 (((-568) $) 63)) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-1807 (($ $ (-568)) 66)) (-2595 (((-3 $ "failed") $ $) 41)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-2709 (((-763) $) 56)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 55)) (-3396 (((-1141 (-568)) $) 68)) (-1811 (($ $) 65)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42)) (-4078 (((-763)) 28)) (-1826 (((-121) $ $) 38)) (-3996 (((-568) $ (-568)) 61)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 $ $) . T) ((-137) . T) ((-148) -2199 (|has| (-409 (-568)) (-370)) (|has| (-409 (-568)) (-148))) ((-150) . T) ((-608 (-850)) . T) ((-172) . T) ((-238) . T) ((-285) . T) ((-301) . T) ((-1261 (-409 (-568))) . T) ((-365) . T) ((-404) -2199 (|has| (-409 (-568)) (-370)) (|has| (-409 (-568)) (-148))) ((-453) . T) ((-558) . T) ((-637 (-409 (-568))) . T) ((-637 $) . T) ((-707 (-409 (-568))) . T) ((-707 $) . T) ((-716) . T) ((-916) . T) ((-858) . T) ((-1037 (-409 (-568))) . T) ((-1037 (-568)) . T) ((-1053 (-409 (-568))) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1199) . T) ((-1251 (-409 (-568))) . T)) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 16)) (-1969 (((-1244 $) $ $) 47)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2134 (((-121) $) NIL)) (-3800 (((-763)) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2589 (((-121) $ $) NIL)) (-3168 (((-1249) $) 51)) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) 104) (((-3 (-409 (-568)) "failed") $) 106) (((-3 (-409 (-568)) "failed") $) 106)) (-2857 (((-568) $) NIL) (((-409 (-568)) $) 94) (((-409 (-568)) $) 94)) (-2403 (($ $ $) NIL)) (-3094 (($ (-1157 $)) 34)) (-2902 (((-3 $ "failed") $) NIL)) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-1887 (($ $ (-763)) NIL (-2199 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370)))) (($ $) NIL (-2199 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-2197 (((-121) $) NIL)) (-2474 (($ $) 40)) (-1844 (((-828 (-917)) $) NIL (-2199 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-1598 (((-121) $) 100)) (-1301 (($ (-1157 $) $ (-1161)) 79) (($ (-1157 $) (-1161)) 70) (($ (-1157 $) (-1157 $) (-917) $ (-1161)) 80)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3057 (($ (-634 $)) 38)) (-3087 (((-1157 $) $) 29) (((-1157 $) $ $) 31)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) 86)) (-4051 (((-121) $) NIL)) (-4025 (((-1108) $) NIL)) (-2088 (((-121) $) 39)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4295 (((-850) $) 112)) (-3850 (((-420 $) $) NIL)) (-4321 (((-828 (-917))) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-3917 (((-917) $) 30)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-2997 (((-634 $) (-1157 $) $) 72)) (-2721 (((-3 (-763) "failed") $ $) NIL (-2199 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-3108 (((-139)) NIL)) (-1836 (((-828 (-917)) $) NIL)) (-1492 (((-1157 $)) 52) (((-1157 $) $) 41)) (-2387 (($ $) NIL)) (-2747 (((-850) $) 111) (($ (-568)) 14) (($ $) NIL) (($ (-409 (-568))) 101) (($ (-568)) 14) (($ (-409 (-568))) 101) (($ (-409 (-568))) 101)) (-3385 (((-3 $ "failed") $) NIL (-2199 (|has| (-409 (-568)) (-148)) (|has| (-409 (-568)) (-370))))) (-3425 (((-763)) 114)) (-2273 (((-121) $ $) NIL)) (-1413 (((-121) $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) 17 T CONST)) (-1557 (($) 73 T CONST)) (-3412 (($ $ (-763)) NIL (|has| (-409 (-568)) (-370))) (($ $) NIL (|has| (-409 (-568)) (-370)))) (-1719 (((-121) $ $) 97)) (-1781 (($ $ $) 78) (($ $ (-409 (-568))) NIL)) (-1775 (($ $) 19) (($ $ $) 89)) (-1769 (($ $ $) 54)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 18) (($ $ $) 57) (($ $ (-409 (-568))) 88) (($ (-409 (-568)) $) 87) (($ (-409 (-568)) $) 87) (($ $ (-409 (-568))) 88))) 
+(((-860) (-13 (-859) (-10 -8 (-15 -4295 ((-850) $)) (-15 -1301 ($ (-1157 $) (-1157 $) (-917) $ (-1161)))))) (T -860)) 
+((-4295 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-860)))) (-1301 (*1 *1 *2 *2 *3 *1 *4) (-12 (-5 *2 (-1157 (-860))) (-5 *3 (-917)) (-5 *4 (-1161)) (-5 *1 (-860))))) 
+(-13 (-859) (-10 -8 (-15 -4295 ((-850) $)) (-15 -1301 ($ (-1157 $) (-1157 $) (-917) $ (-1161))))) 
+((-3179 (((-3 (-173 |#3|) "failed") (-763) (-763) |#2| |#2|) 31)) (-2250 (((-3 (-409 |#3|) "failed") (-763) (-763) |#2| |#2|) 24))) 
+(((-861 |#1| |#2| |#3|) (-10 -7 (-15 -2250 ((-3 (-409 |#3|) "failed") (-763) (-763) |#2| |#2|)) (-15 -3179 ((-3 (-173 |#3|) "failed") (-763) (-763) |#2| |#2|))) (-365) (-1234 |#1|) (-1219 |#1|)) (T -861)) 
+((-3179 (*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-763)) (-4 *5 (-365)) (-5 *2 (-173 *6)) (-5 *1 (-861 *5 *4 *6)) (-4 *4 (-1234 *5)) (-4 *6 (-1219 *5)))) (-2250 (*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-763)) (-4 *5 (-365)) (-5 *2 (-409 *6)) (-5 *1 (-861 *5 *4 *6)) (-4 *4 (-1234 *5)) (-4 *6 (-1219 *5))))) 
+(-10 -7 (-15 -2250 ((-3 (-409 |#3|) "failed") (-763) (-763) |#2| |#2|)) (-15 -3179 ((-3 (-173 |#3|) "failed") (-763) (-763) |#2| |#2|))) 
+((-2250 (((-3 (-409 (-1216 |#2| |#1|)) "failed") (-763) (-763) (-1235 |#1| |#2| |#3|)) 28) (((-3 (-409 (-1216 |#2| |#1|)) "failed") (-763) (-763) (-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|)) 26))) 
+(((-862 |#1| |#2| |#3|) (-10 -7 (-15 -2250 ((-3 (-409 (-1216 |#2| |#1|)) "failed") (-763) (-763) (-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|))) (-15 -2250 ((-3 (-409 (-1216 |#2| |#1|)) "failed") (-763) (-763) (-1235 |#1| |#2| |#3|)))) (-365) (-1161) |#1|) (T -862)) 
+((-2250 (*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-763)) (-5 *4 (-1235 *5 *6 *7)) (-4 *5 (-365)) (-14 *6 (-1161)) (-14 *7 *5) (-5 *2 (-409 (-1216 *6 *5))) (-5 *1 (-862 *5 *6 *7)))) (-2250 (*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-763)) (-5 *4 (-1235 *5 *6 *7)) (-4 *5 (-365)) (-14 *6 (-1161)) (-14 *7 *5) (-5 *2 (-409 (-1216 *6 *5))) (-5 *1 (-862 *5 *6 *7))))) 
+(-10 -7 (-15 -2250 ((-3 (-409 (-1216 |#2| |#1|)) "failed") (-763) (-763) (-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|))) (-15 -2250 ((-3 (-409 (-1216 |#2| |#1|)) "failed") (-763) (-763) (-1235 |#1| |#2| |#3|)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-2689 (((-3 $ "failed") $ $) 18)) (-1904 (($ $ (-568)) 60)) (-2589 (((-121) $ $) 57)) (-4490 (($) 16 T CONST)) (-3517 (($ (-1157 (-568)) (-568)) 59)) (-2403 (($ $ $) 53)) (-2902 (((-3 $ "failed") $) 33)) (-4456 (($ $) 62)) (-2414 (($ $ $) 54)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 49)) (-1844 (((-763) $) 67)) (-1598 (((-121) $) 30)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-2477 (((-568)) 64)) (-2691 (((-568) $) 63)) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2168 (($ $ (-568)) 66)) (-2597 (((-3 $ "failed") $ $) 41)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-1466 (((-763) $) 56)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 55)) (-1513 (((-1141 (-568)) $) 68)) (-2188 (($ $) 65)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42)) (-3425 (((-763)) 28)) (-2273 (((-121) $ $) 38)) (-3999 (((-568) $ (-568)) 61)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
 (((-863 |#1|) (-1275) (-568)) (T -863)) 
-((-3396 (*1 *2 *1) (-12 (-4 *1 (-863 *3)) (-5 *2 (-1141 (-568))))) (-4477 (*1 *2 *1) (-12 (-4 *1 (-863 *3)) (-5 *2 (-763)))) (-1807 (*1 *1 *1 *2) (-12 (-4 *1 (-863 *3)) (-5 *2 (-568)))) (-1811 (*1 *1 *1) (-4 *1 (-863 *2))) (-3094 (*1 *2) (-12 (-4 *1 (-863 *3)) (-5 *2 (-568)))) (-1914 (*1 *2 *1) (-12 (-4 *1 (-863 *3)) (-5 *2 (-568)))) (-3974 (*1 *1 *1) (-4 *1 (-863 *2))) (-3996 (*1 *2 *1 *2) (-12 (-4 *1 (-863 *3)) (-5 *2 (-568)))) (-1902 (*1 *1 *1 *2) (-12 (-4 *1 (-863 *3)) (-5 *2 (-568)))) (-2143 (*1 *1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *3 (-568)) (-4 *1 (-863 *4))))) 
-(-13 (-301) (-150) (-10 -8 (-15 -3396 ((-1141 (-568)) $)) (-15 -4477 ((-763) $)) (-15 -1807 ($ $ (-568))) (-15 -1811 ($ $)) (-15 -3094 ((-568))) (-15 -1914 ((-568) $)) (-15 -3974 ($ $)) (-15 -3996 ((-568) $ (-568))) (-15 -1902 ($ $ (-568))) (-15 -2143 ($ (-1157 (-568)) (-568))))) 
+((-1513 (*1 *2 *1) (-12 (-4 *1 (-863 *3)) (-5 *2 (-1141 (-568))))) (-1844 (*1 *2 *1) (-12 (-4 *1 (-863 *3)) (-5 *2 (-763)))) (-2168 (*1 *1 *1 *2) (-12 (-4 *1 (-863 *3)) (-5 *2 (-568)))) (-2188 (*1 *1 *1) (-4 *1 (-863 *2))) (-2477 (*1 *2) (-12 (-4 *1 (-863 *3)) (-5 *2 (-568)))) (-2691 (*1 *2 *1) (-12 (-4 *1 (-863 *3)) (-5 *2 (-568)))) (-4456 (*1 *1 *1) (-4 *1 (-863 *2))) (-3999 (*1 *2 *1 *2) (-12 (-4 *1 (-863 *3)) (-5 *2 (-568)))) (-1904 (*1 *1 *1 *2) (-12 (-4 *1 (-863 *3)) (-5 *2 (-568)))) (-3517 (*1 *1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *3 (-568)) (-4 *1 (-863 *4))))) 
+(-13 (-301) (-150) (-10 -8 (-15 -1513 ((-1141 (-568)) $)) (-15 -1844 ((-763) $)) (-15 -2168 ($ $ (-568))) (-15 -2188 ($ $)) (-15 -2477 ((-568))) (-15 -2691 ((-568) $)) (-15 -4456 ($ $)) (-15 -3999 ((-568) $ (-568))) (-15 -1904 ($ $ (-568))) (-15 -3517 ($ (-1157 (-568)) (-568))))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-105) . T) ((-120 $ $) . T) ((-137) . T) ((-150) . T) ((-608 (-850)) . T) ((-172) . T) ((-285) . T) ((-301) . T) ((-453) . T) ((-558) . T) ((-637 $) . T) ((-707 $) . T) ((-716) . T) ((-916) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1902 (($ $ (-568)) NIL)) (-1497 (((-121) $ $) NIL)) (-2671 (($) NIL T CONST)) (-2143 (($ (-1157 (-568)) (-568)) NIL)) (-2401 (($ $ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3974 (($ $) NIL)) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-4477 (((-763) $) NIL)) (-2735 (((-121) $) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3094 (((-568)) NIL)) (-1914 (((-568) $) NIL)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-1807 (($ $ (-568)) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3396 (((-1141 (-568)) $) NIL)) (-1811 (($ $) NIL)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL)) (-4078 (((-763)) NIL)) (-1826 (((-121) $ $) NIL)) (-3996 (((-568) $ (-568)) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-1904 (($ $ (-568)) NIL)) (-2589 (((-121) $ $) NIL)) (-4490 (($) NIL T CONST)) (-3517 (($ (-1157 (-568)) (-568)) NIL)) (-2403 (($ $ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-4456 (($ $) NIL)) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-1844 (((-763) $) NIL)) (-1598 (((-121) $) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2477 (((-568)) NIL)) (-2691 (((-568) $) NIL)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2168 (($ $ (-568)) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-1513 (((-1141 (-568)) $) NIL)) (-2188 (($ $) NIL)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL)) (-3425 (((-763)) NIL)) (-2273 (((-121) $ $) NIL)) (-3999 (((-568) $ (-568)) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL))) 
 (((-864 |#1|) (-863 |#1|) (-568)) (T -864)) 
 NIL 
 (-863 |#1|) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-1492 (((-864 |#1|) $) NIL (|has| (-864 |#1|) (-301)))) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-864 |#1|) (-904)))) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| (-864 |#1|) (-904)))) (-1497 (((-121) $ $) NIL)) (-3662 (((-568) $) NIL (|has| (-864 |#1|) (-815)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-864 |#1|) "failed") $) NIL) (((-3 (-1161) "failed") $) NIL (|has| (-864 |#1|) (-1037 (-1161)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| (-864 |#1|) (-1037 (-568)))) (((-3 (-568) "failed") $) NIL (|has| (-864 |#1|) (-1037 (-568))))) (-2854 (((-864 |#1|) $) NIL) (((-1161) $) NIL (|has| (-864 |#1|) (-1037 (-1161)))) (((-409 (-568)) $) NIL (|has| (-864 |#1|) (-1037 (-568)))) (((-568) $) NIL (|has| (-864 |#1|) (-1037 (-568))))) (-1429 (($ $) NIL) (($ (-568) $) NIL)) (-2401 (($ $ $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| (-864 |#1|) (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| (-864 |#1|) (-630 (-568)))) (((-2 (|:| -2928 (-679 (-864 |#1|))) (|:| |vec| (-1244 (-864 |#1|)))) (-679 $) (-1244 $)) NIL) (((-679 (-864 |#1|)) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1731 (($) NIL (|has| (-864 |#1|) (-550)))) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-2033 (((-121) $) NIL (|has| (-864 |#1|) (-815)))) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| (-864 |#1|) (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| (-864 |#1|) (-881 (-381))))) (-2735 (((-121) $) NIL)) (-1332 (($ $) NIL)) (-2317 (((-864 |#1|) $) NIL)) (-3038 (((-3 $ "failed") $) NIL (|has| (-864 |#1|) (-1136)))) (-2245 (((-121) $) NIL (|has| (-864 |#1|) (-815)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2521 (($ $ $) NIL (|has| (-864 |#1|) (-842)))) (-3268 (($ $ $) NIL (|has| (-864 |#1|) (-842)))) (-2795 (($ (-1 (-864 |#1|) (-864 |#1|)) $) NIL)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4434 (($) NIL (|has| (-864 |#1|) (-1136)) CONST)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3880 (($ $) NIL (|has| (-864 |#1|) (-301)))) (-1519 (((-864 |#1|) $) NIL (|has| (-864 |#1|) (-550)))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-864 |#1|) (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-864 |#1|) (-904)))) (-3848 (((-420 $) $) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1339 (($ $ (-634 (-864 |#1|)) (-634 (-864 |#1|))) NIL (|has| (-864 |#1|) (-303 (-864 |#1|)))) (($ $ (-864 |#1|) (-864 |#1|)) NIL (|has| (-864 |#1|) (-303 (-864 |#1|)))) (($ $ (-288 (-864 |#1|))) NIL (|has| (-864 |#1|) (-303 (-864 |#1|)))) (($ $ (-634 (-288 (-864 |#1|)))) NIL (|has| (-864 |#1|) (-303 (-864 |#1|)))) (($ $ (-634 (-1161)) (-634 (-864 |#1|))) NIL (|has| (-864 |#1|) (-523 (-1161) (-864 |#1|)))) (($ $ (-1161) (-864 |#1|)) NIL (|has| (-864 |#1|) (-523 (-1161) (-864 |#1|))))) (-2709 (((-763) $) NIL)) (-2779 (($ $ (-864 |#1|)) NIL (|has| (-864 |#1|) (-281 (-864 |#1|) (-864 |#1|))))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-4189 (($ $) NIL (|has| (-864 |#1|) (-225))) (($ $ (-763)) NIL (|has| (-864 |#1|) (-225))) (($ $ (-1161)) NIL (|has| (-864 |#1|) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-864 |#1|) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-864 |#1|) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-864 |#1|) (-895 (-1161)))) (($ $ (-1 (-864 |#1|) (-864 |#1|)) (-763)) NIL) (($ $ (-1 (-864 |#1|) (-864 |#1|))) NIL)) (-3013 (($ $) NIL)) (-2324 (((-864 |#1|) $) NIL)) (-4278 (((-887 (-568)) $) NIL (|has| (-864 |#1|) (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| (-864 |#1|) (-609 (-887 (-381))))) (((-541) $) NIL (|has| (-864 |#1|) (-609 (-541)))) (((-381) $) NIL (|has| (-864 |#1|) (-1021))) (((-215) $) NIL (|has| (-864 |#1|) (-1021)))) (-3878 (((-173 (-409 (-568))) $) NIL)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| (-864 |#1|) (-904))))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ (-864 |#1|)) NIL) (($ (-1161)) NIL (|has| (-864 |#1|) (-1037 (-1161))))) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| (-864 |#1|) (-904))) (|has| (-864 |#1|) (-148))))) (-4078 (((-763)) NIL)) (-2285 (((-864 |#1|) $) NIL (|has| (-864 |#1|) (-550)))) (-1826 (((-121) $ $) NIL)) (-3996 (((-409 (-568)) $ (-568)) NIL)) (-2897 (($ $) NIL (|has| (-864 |#1|) (-815)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $) NIL (|has| (-864 |#1|) (-225))) (($ $ (-763)) NIL (|has| (-864 |#1|) (-225))) (($ $ (-1161)) NIL (|has| (-864 |#1|) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-864 |#1|) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-864 |#1|) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-864 |#1|) (-895 (-1161)))) (($ $ (-1 (-864 |#1|) (-864 |#1|)) (-763)) NIL) (($ $ (-1 (-864 |#1|) (-864 |#1|))) NIL)) (-1751 (((-121) $ $) NIL (|has| (-864 |#1|) (-842)))) (-1738 (((-121) $ $) NIL (|has| (-864 |#1|) (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| (-864 |#1|) (-842)))) (-1732 (((-121) $ $) NIL (|has| (-864 |#1|) (-842)))) (-1779 (($ $ $) NIL) (($ (-864 |#1|) (-864 |#1|)) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ (-864 |#1|) $) NIL) (($ $ (-864 |#1|)) NIL))) 
-(((-865 |#1|) (-13 (-993 (-864 |#1|)) (-10 -8 (-15 -3996 ((-409 (-568)) $ (-568))) (-15 -3878 ((-173 (-409 (-568))) $)) (-15 -1429 ($ $)) (-15 -1429 ($ (-568) $)))) (-568)) (T -865)) 
-((-3996 (*1 *2 *1 *3) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-865 *4)) (-14 *4 *3) (-5 *3 (-568)))) (-3878 (*1 *2 *1) (-12 (-5 *2 (-173 (-409 (-568)))) (-5 *1 (-865 *3)) (-14 *3 (-568)))) (-1429 (*1 *1 *1) (-12 (-5 *1 (-865 *2)) (-14 *2 (-568)))) (-1429 (*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-865 *3)) (-14 *3 *2)))) 
-(-13 (-993 (-864 |#1|)) (-10 -8 (-15 -3996 ((-409 (-568)) $ (-568))) (-15 -3878 ((-173 (-409 (-568))) $)) (-15 -1429 ($ $)) (-15 -1429 ($ (-568) $)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-1492 ((|#2| $) NIL (|has| |#2| (-301)))) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-1497 (((-121) $ $) NIL)) (-3662 (((-568) $) NIL (|has| |#2| (-815)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#2| "failed") $) NIL) (((-3 (-1161) "failed") $) NIL (|has| |#2| (-1037 (-1161)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#2| (-1037 (-568)))) (((-3 (-568) "failed") $) NIL (|has| |#2| (-1037 (-568))))) (-2854 ((|#2| $) NIL) (((-1161) $) NIL (|has| |#2| (-1037 (-1161)))) (((-409 (-568)) $) NIL (|has| |#2| (-1037 (-568)))) (((-568) $) NIL (|has| |#2| (-1037 (-568))))) (-1429 (($ $) 31) (($ (-568) $) 32)) (-2401 (($ $ $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL) (((-679 |#2|) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) 53)) (-1731 (($) NIL (|has| |#2| (-550)))) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-2033 (((-121) $) NIL (|has| |#2| (-815)))) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| |#2| (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| |#2| (-881 (-381))))) (-2735 (((-121) $) NIL)) (-1332 (($ $) NIL)) (-2317 ((|#2| $) NIL)) (-3038 (((-3 $ "failed") $) NIL (|has| |#2| (-1136)))) (-2245 (((-121) $) NIL (|has| |#2| (-815)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2521 (($ $ $) NIL (|has| |#2| (-842)))) (-3268 (($ $ $) NIL (|has| |#2| (-842)))) (-2795 (($ (-1 |#2| |#2|) $) NIL)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) 49)) (-4434 (($) NIL (|has| |#2| (-1136)) CONST)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3880 (($ $) NIL (|has| |#2| (-301)))) (-1519 ((|#2| $) NIL (|has| |#2| (-550)))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3848 (((-420 $) $) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1339 (($ $ (-634 |#2|) (-634 |#2|)) NIL (|has| |#2| (-303 |#2|))) (($ $ |#2| |#2|) NIL (|has| |#2| (-303 |#2|))) (($ $ (-288 |#2|)) NIL (|has| |#2| (-303 |#2|))) (($ $ (-634 (-288 |#2|))) NIL (|has| |#2| (-303 |#2|))) (($ $ (-634 (-1161)) (-634 |#2|)) NIL (|has| |#2| (-523 (-1161) |#2|))) (($ $ (-1161) |#2|) NIL (|has| |#2| (-523 (-1161) |#2|)))) (-2709 (((-763) $) NIL)) (-2779 (($ $ |#2|) NIL (|has| |#2| (-281 |#2| |#2|)))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-4189 (($ $) NIL (|has| |#2| (-225))) (($ $ (-763)) NIL (|has| |#2| (-225))) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) NIL)) (-3013 (($ $) NIL)) (-2324 ((|#2| $) NIL)) (-4278 (((-887 (-568)) $) NIL (|has| |#2| (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| |#2| (-609 (-887 (-381))))) (((-541) $) NIL (|has| |#2| (-609 (-541)))) (((-381) $) NIL (|has| |#2| (-1021))) (((-215) $) NIL (|has| |#2| (-1021)))) (-3878 (((-173 (-409 (-568))) $) 68)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#2| (-904))))) (-2745 (((-850) $) 85) (($ (-568)) 19) (($ $) NIL) (($ (-409 (-568))) 24) (($ |#2|) 18) (($ (-1161)) NIL (|has| |#2| (-1037 (-1161))))) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| |#2| (-904))) (|has| |#2| (-148))))) (-4078 (((-763)) NIL)) (-2285 ((|#2| $) NIL (|has| |#2| (-550)))) (-1826 (((-121) $ $) NIL)) (-3996 (((-409 (-568)) $ (-568)) 60)) (-2897 (($ $) NIL (|has| |#2| (-815)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) 14 T CONST)) (-1556 (($) 16 T CONST)) (-3190 (($ $) NIL (|has| |#2| (-225))) (($ $ (-763)) NIL (|has| |#2| (-225))) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) NIL)) (-1751 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1717 (((-121) $ $) 35)) (-1745 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1779 (($ $ $) 23) (($ |#2| |#2|) 54)) (-1773 (($ $) 39) (($ $ $) 41)) (-1767 (($ $ $) 37)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) 50)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 42) (($ $ $) 44) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ |#2| $) 55) (($ $ |#2|) NIL))) 
-(((-866 |#1| |#2|) (-13 (-993 |#2|) (-10 -8 (-15 -3996 ((-409 (-568)) $ (-568))) (-15 -3878 ((-173 (-409 (-568))) $)) (-15 -1429 ($ $)) (-15 -1429 ($ (-568) $)))) (-568) (-863 |#1|)) (T -866)) 
-((-3996 (*1 *2 *1 *3) (-12 (-14 *4 *3) (-5 *2 (-409 (-568))) (-5 *1 (-866 *4 *5)) (-5 *3 (-568)) (-4 *5 (-863 *4)))) (-3878 (*1 *2 *1) (-12 (-14 *3 (-568)) (-5 *2 (-173 (-409 (-568)))) (-5 *1 (-866 *3 *4)) (-4 *4 (-863 *3)))) (-1429 (*1 *1 *1) (-12 (-14 *2 (-568)) (-5 *1 (-866 *2 *3)) (-4 *3 (-863 *2)))) (-1429 (*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-14 *3 *2) (-5 *1 (-866 *3 *4)) (-4 *4 (-863 *3))))) 
-(-13 (-993 |#2|) (-10 -8 (-15 -3996 ((-409 (-568)) $ (-568))) (-15 -3878 ((-173 (-409 (-568))) $)) (-15 -1429 ($ $)) (-15 -1429 ($ (-568) $)))) 
-((-3481 (((-242 |#2| (-857 |#1|)) (-242 |#2| |#1|) (-967 |#1|)) NIL)) (-2606 (((-242 |#2| |#1|)) 107)) (-1846 (((-634 (-967 |#1|))) 116)) (-4149 (((-634 (-967 |#1|)) (-634 (-967 |#1|))) 27)) (-4276 (((-242 |#2| |#1|) (-242 |#2| |#1|)) 35)) (-1895 (((-634 (-967 |#1|))) 60)) (-4397 (((-634 (-922 |#1|))) 58)) (-3534 (((-967 |#1|) (-634 (-857 |#1|))) 17)) (-1279 (((-967 |#1|) (-922 |#1|)) 21)) (-1375 (((-634 (-922 |#1|)) (-917)) 45 (|has| (-857 |#1|) (-370)))) (-1547 (((-634 (-922 |#1|)) (-967 |#1|)) 24)) (-2215 (((-774 (-857 |#1|)) (-242 |#2| |#1|) (-922 |#1|)) 119)) (-3354 (((-568) (-917)) 47 (|has| (-857 |#1|) (-370)))) (-3114 (((-568) (-917) (-917)) 49 (|has| (-857 |#1|) (-370)))) (-3281 (((-568) (-917)) 43 (|has| (-857 |#1|) (-370)))) (-2246 (((-2 (|:| |num| (-634 (-242 |#2| |#1|))) (|:| |den| (-242 |#2| |#1|))) (-236 (-922 |#1|))) 62) (((-634 (-409 (-242 |#2| |#1|))) (-236 (-922 |#1|)) (-763)) NIL)) (-2411 (((-236 (-922 |#1|)) (-242 |#2| |#1|)) 135)) (-2525 (((-634 (-242 |#2| (-857 |#1|))) (-236 (-922 |#1|)) (-634 (-242 |#2| |#1|))) 125)) (-2664 (((-634 (-242 |#2| |#1|)) (-236 (-922 |#1|)) (-763)) 123)) (-3039 (((-242 |#2| |#1|) (-242 |#2| |#1|) (-568)) 13)) (-2766 (((-679 |#1|) (-236 (-922 |#1|)) (-634 (-922 |#1|))) 67) (((-679 |#1|) (-236 (-922 |#1|)) (-236 (-922 |#1|))) 69)) (-1801 (((-568)) 105)) (-2126 (((-763)) 103)) (-1896 (((-1249)) 144)) (-1944 (((-1249)) 140)) (-1640 (((-2 (|:| -1379 (-568)) (|:| |num| (-242 |#2| |#1|)) (|:| |den| (-242 |#2| |#1|)) (|:| |upTo| (-568))) (-236 (-922 |#1|)) (-568) (-568)) 32)) (-3781 (((-3 |#1| "failed") (-409 (-242 |#2| |#1|)) (-922 |#1|)) 132) (((-3 |#1| "failed") (-242 |#2| |#1|) (-242 |#2| |#1|) (-922 |#1|)) 127) (((-3 |#1| "failed") (-242 |#2| |#1|) (-922 |#1|)) 96)) (-1339 ((|#1| (-409 (-242 |#2| |#1|)) (-922 |#1|)) 133) ((|#1| (-242 |#2| |#1|) (-242 |#2| |#1|) (-922 |#1|)) 63) ((|#1| (-242 |#2| |#1|) (-922 |#1|)) 98)) (-4007 (((-634 (-259 (-537 |#1| |#2| |#3|)))) 112)) (-2176 (((-634 (-259 (-537 |#1| |#2| |#3|)))) 110)) (-2277 (((-568)) 56 (|has| (-857 |#1|) (-370)))) (-2480 (((-236 (-922 |#1|))) 114)) (-2596 (((-1239 (-568) -3492) (-917)) 41 (|has| (-857 |#1|) (-370))) (((-1239 (-568) -3492)) 38 (|has| (-857 |#1|) (-370)))) (-1637 (((-1157 (-568)) (-917)) 54 (|has| (-857 |#1|) (-370))) (((-1157 (-568))) 52 (|has| (-857 |#1|) (-370))))) 
-(((-867 |#1| |#2| |#3|) (-10 -7 (-15 -3039 ((-242 |#2| |#1|) (-242 |#2| |#1|) (-568))) (-15 -1944 ((-1249))) (-15 -1896 ((-1249))) (-15 -4276 ((-242 |#2| |#1|) (-242 |#2| |#1|))) (-15 -3481 ((-242 |#2| (-857 |#1|)) (-242 |#2| |#1|) (-967 |#1|))) (-15 -2766 ((-679 |#1|) (-236 (-922 |#1|)) (-236 (-922 |#1|)))) (-15 -2766 ((-679 |#1|) (-236 (-922 |#1|)) (-634 (-922 |#1|)))) (-15 -1279 ((-967 |#1|) (-922 |#1|))) (-15 -1547 ((-634 (-922 |#1|)) (-967 |#1|))) (-15 -3534 ((-967 |#1|) (-634 (-857 |#1|)))) (-15 -4149 ((-634 (-967 |#1|)) (-634 (-967 |#1|)))) (-15 -4397 ((-634 (-922 |#1|)))) (-15 -2606 ((-242 |#2| |#1|))) (-15 -2126 ((-763))) (-15 -1801 ((-568))) (-15 -4007 ((-634 (-259 (-537 |#1| |#2| |#3|))))) (-15 -2176 ((-634 (-259 (-537 |#1| |#2| |#3|))))) (-15 -1895 ((-634 (-967 |#1|)))) (-15 -1846 ((-634 (-967 |#1|)))) (-15 -2215 ((-774 (-857 |#1|)) (-242 |#2| |#1|) (-922 |#1|))) (-15 -2246 ((-634 (-409 (-242 |#2| |#1|))) (-236 (-922 |#1|)) (-763))) (-15 -2246 ((-2 (|:| |num| (-634 (-242 |#2| |#1|))) (|:| |den| (-242 |#2| |#1|))) (-236 (-922 |#1|)))) (-15 -1640 ((-2 (|:| -1379 (-568)) (|:| |num| (-242 |#2| |#1|)) (|:| |den| (-242 |#2| |#1|)) (|:| |upTo| (-568))) (-236 (-922 |#1|)) (-568) (-568))) (-15 -2525 ((-634 (-242 |#2| (-857 |#1|))) (-236 (-922 |#1|)) (-634 (-242 |#2| |#1|)))) (-15 -2664 ((-634 (-242 |#2| |#1|)) (-236 (-922 |#1|)) (-763))) (-15 -1339 (|#1| (-242 |#2| |#1|) (-922 |#1|))) (-15 -1339 (|#1| (-242 |#2| |#1|) (-242 |#2| |#1|) (-922 |#1|))) (-15 -1339 (|#1| (-409 (-242 |#2| |#1|)) (-922 |#1|))) (-15 -3781 ((-3 |#1| "failed") (-242 |#2| |#1|) (-922 |#1|))) (-15 -3781 ((-3 |#1| "failed") (-242 |#2| |#1|) (-242 |#2| |#1|) (-922 |#1|))) (-15 -3781 ((-3 |#1| "failed") (-409 (-242 |#2| |#1|)) (-922 |#1|))) (-15 -2411 ((-236 (-922 |#1|)) (-242 |#2| |#1|))) (-15 -2480 ((-236 (-922 |#1|)))) (IF (|has| (-857 |#1|) (-370)) (PROGN (-15 -1637 ((-1157 (-568)))) (-15 -1637 ((-1157 (-568)) (-917))) (-15 -2277 ((-568))) (-15 -1375 ((-634 (-922 |#1|)) (-917))) (-15 -3281 ((-568) (-917))) (-15 -3354 ((-568) (-917))) (-15 -3114 ((-568) (-917) (-917))) (-15 -2596 ((-1239 (-568) -3492))) (-15 -2596 ((-1239 (-568) -3492) (-917)))) |noBranch|)) (-350) (-634 (-1161)) (-117)) (T -867)) 
-((-2596 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1239 (-568) -3492)) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-2596 (*1 *2) (-12 (-5 *2 (-1239 (-568) -3492)) (-5 *1 (-867 *3 *4 *5)) (-4 (-857 *3) (-370)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-3114 (*1 *2 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-3354 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-3281 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-1375 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-634 (-922 *4))) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-2277 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-867 *3 *4 *5)) (-4 (-857 *3) (-370)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-1637 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 (-568))) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-1637 (*1 *2) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-867 *3 *4 *5)) (-4 (-857 *3) (-370)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2480 (*1 *2) (-12 (-5 *2 (-236 (-922 *3))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2411 (*1 *2 *3) (-12 (-5 *3 (-242 *5 *4)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-5 *2 (-236 (-922 *4))) (-5 *1 (-867 *4 *5 *6)) (-4 *6 (-117)))) (-3781 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 (-242 *5 *2))) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) (-3781 (*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-242 *5 *2)) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) (-3781 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-242 *5 *2)) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) (-1339 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-242 *5 *2))) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) (-1339 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-242 *5 *2)) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) (-1339 (*1 *2 *3 *4) (-12 (-5 *3 (-242 *5 *2)) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) (-2664 (*1 *2 *3 *4) (-12 (-5 *3 (-236 (-922 *5))) (-5 *4 (-763)) (-4 *5 (-350)) (-5 *2 (-634 (-242 *6 *5))) (-5 *1 (-867 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) (-2525 (*1 *2 *3 *4) (-12 (-5 *3 (-236 (-922 *5))) (-5 *4 (-634 (-242 *6 *5))) (-4 *5 (-350)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-242 *6 (-857 *5)))) (-5 *1 (-867 *5 *6 *7)) (-4 *7 (-117)))) (-1640 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-236 (-922 *5))) (-4 *5 (-350)) (-5 *2 (-2 (|:| -1379 (-568)) (|:| |num| (-242 *6 *5)) (|:| |den| (-242 *6 *5)) (|:| |upTo| (-568)))) (-5 *1 (-867 *5 *6 *7)) (-5 *4 (-568)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) (-2246 (*1 *2 *3) (-12 (-5 *3 (-236 (-922 *4))) (-4 *4 (-350)) (-5 *2 (-2 (|:| |num| (-634 (-242 *5 *4))) (|:| |den| (-242 *5 *4)))) (-5 *1 (-867 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-2246 (*1 *2 *3 *4) (-12 (-5 *3 (-236 (-922 *5))) (-5 *4 (-763)) (-4 *5 (-350)) (-5 *2 (-634 (-409 (-242 *6 *5)))) (-5 *1 (-867 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) (-2215 (*1 *2 *3 *4) (-12 (-5 *3 (-242 *6 *5)) (-5 *4 (-922 *5)) (-4 *5 (-350)) (-14 *6 (-634 (-1161))) (-5 *2 (-774 (-857 *5))) (-5 *1 (-867 *5 *6 *7)) (-4 *7 (-117)))) (-1846 (*1 *2) (-12 (-5 *2 (-634 (-967 *3))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-1895 (*1 *2) (-12 (-5 *2 (-634 (-967 *3))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2176 (*1 *2) (-12 (-5 *2 (-634 (-259 (-537 *3 *4 *5)))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-4007 (*1 *2) (-12 (-5 *2 (-634 (-259 (-537 *3 *4 *5)))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-1801 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2126 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2606 (*1 *2) (-12 (-5 *2 (-242 *4 *3)) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-4397 (*1 *2) (-12 (-5 *2 (-634 (-922 *3))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-4149 (*1 *2 *2) (-12 (-5 *2 (-634 (-967 *3))) (-4 *3 (-350)) (-5 *1 (-867 *3 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-3534 (*1 *2 *3) (-12 (-5 *3 (-634 (-857 *4))) (-4 *4 (-350)) (-5 *2 (-967 *4)) (-5 *1 (-867 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-1547 (*1 *2 *3) (-12 (-5 *3 (-967 *4)) (-4 *4 (-350)) (-5 *2 (-634 (-922 *4))) (-5 *1 (-867 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-1279 (*1 *2 *3) (-12 (-5 *3 (-922 *4)) (-4 *4 (-350)) (-5 *2 (-967 *4)) (-5 *1 (-867 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-2766 (*1 *2 *3 *4) (-12 (-5 *3 (-236 (-922 *5))) (-5 *4 (-634 (-922 *5))) (-4 *5 (-350)) (-5 *2 (-679 *5)) (-5 *1 (-867 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) (-2766 (*1 *2 *3 *3) (-12 (-5 *3 (-236 (-922 *4))) (-4 *4 (-350)) (-5 *2 (-679 *4)) (-5 *1 (-867 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-3481 (*1 *2 *3 *4) (-12 (-5 *3 (-242 *6 *5)) (-5 *4 (-967 *5)) (-4 *5 (-350)) (-14 *6 (-634 (-1161))) (-5 *2 (-242 *6 (-857 *5))) (-5 *1 (-867 *5 *6 *7)) (-4 *7 (-117)))) (-4276 (*1 *2 *2) (-12 (-5 *2 (-242 *4 *3)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-5 *1 (-867 *3 *4 *5)) (-4 *5 (-117)))) (-1896 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-1944 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-3039 (*1 *2 *2 *3) (-12 (-5 *2 (-242 *5 *4)) (-5 *3 (-568)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-5 *1 (-867 *4 *5 *6)) (-4 *6 (-117))))) 
-(-10 -7 (-15 -3039 ((-242 |#2| |#1|) (-242 |#2| |#1|) (-568))) (-15 -1944 ((-1249))) (-15 -1896 ((-1249))) (-15 -4276 ((-242 |#2| |#1|) (-242 |#2| |#1|))) (-15 -3481 ((-242 |#2| (-857 |#1|)) (-242 |#2| |#1|) (-967 |#1|))) (-15 -2766 ((-679 |#1|) (-236 (-922 |#1|)) (-236 (-922 |#1|)))) (-15 -2766 ((-679 |#1|) (-236 (-922 |#1|)) (-634 (-922 |#1|)))) (-15 -1279 ((-967 |#1|) (-922 |#1|))) (-15 -1547 ((-634 (-922 |#1|)) (-967 |#1|))) (-15 -3534 ((-967 |#1|) (-634 (-857 |#1|)))) (-15 -4149 ((-634 (-967 |#1|)) (-634 (-967 |#1|)))) (-15 -4397 ((-634 (-922 |#1|)))) (-15 -2606 ((-242 |#2| |#1|))) (-15 -2126 ((-763))) (-15 -1801 ((-568))) (-15 -4007 ((-634 (-259 (-537 |#1| |#2| |#3|))))) (-15 -2176 ((-634 (-259 (-537 |#1| |#2| |#3|))))) (-15 -1895 ((-634 (-967 |#1|)))) (-15 -1846 ((-634 (-967 |#1|)))) (-15 -2215 ((-774 (-857 |#1|)) (-242 |#2| |#1|) (-922 |#1|))) (-15 -2246 ((-634 (-409 (-242 |#2| |#1|))) (-236 (-922 |#1|)) (-763))) (-15 -2246 ((-2 (|:| |num| (-634 (-242 |#2| |#1|))) (|:| |den| (-242 |#2| |#1|))) (-236 (-922 |#1|)))) (-15 -1640 ((-2 (|:| -1379 (-568)) (|:| |num| (-242 |#2| |#1|)) (|:| |den| (-242 |#2| |#1|)) (|:| |upTo| (-568))) (-236 (-922 |#1|)) (-568) (-568))) (-15 -2525 ((-634 (-242 |#2| (-857 |#1|))) (-236 (-922 |#1|)) (-634 (-242 |#2| |#1|)))) (-15 -2664 ((-634 (-242 |#2| |#1|)) (-236 (-922 |#1|)) (-763))) (-15 -1339 (|#1| (-242 |#2| |#1|) (-922 |#1|))) (-15 -1339 (|#1| (-242 |#2| |#1|) (-242 |#2| |#1|) (-922 |#1|))) (-15 -1339 (|#1| (-409 (-242 |#2| |#1|)) (-922 |#1|))) (-15 -3781 ((-3 |#1| "failed") (-242 |#2| |#1|) (-922 |#1|))) (-15 -3781 ((-3 |#1| "failed") (-242 |#2| |#1|) (-242 |#2| |#1|) (-922 |#1|))) (-15 -3781 ((-3 |#1| "failed") (-409 (-242 |#2| |#1|)) (-922 |#1|))) (-15 -2411 ((-236 (-922 |#1|)) (-242 |#2| |#1|))) (-15 -2480 ((-236 (-922 |#1|)))) (IF (|has| (-857 |#1|) (-370)) (PROGN (-15 -1637 ((-1157 (-568)))) (-15 -1637 ((-1157 (-568)) (-917))) (-15 -2277 ((-568))) (-15 -1375 ((-634 (-922 |#1|)) (-917))) (-15 -3281 ((-568) (-917))) (-15 -3354 ((-568) (-917))) (-15 -3114 ((-568) (-917) (-917))) (-15 -2596 ((-1239 (-568) -3492))) (-15 -2596 ((-1239 (-568) -3492) (-917)))) |noBranch|)) 
-((-2606 (((-242 |#2| |#1|)) 83)) (-1846 (((-634 (-966 |#1|))) 92)) (-4149 (((-634 (-966 |#1|)) (-634 (-966 |#1|))) 24)) (-4276 (((-242 |#2| |#1|) (-242 |#2| |#1|)) 75)) (-1895 (((-634 (-966 |#1|))) 65)) (-4397 (((-634 (-921 |#1|))) 63)) (-3534 (((-966 |#1|) (-634 |#1|)) 27)) (-1279 (((-966 |#1|) (-921 |#1|)) 18)) (-1375 (((-634 (-921 |#1|)) (-917)) 50 (|has| |#1| (-370)))) (-1547 (((-634 (-921 |#1|)) (-966 |#1|)) 21)) (-2215 (((-774 |#1|) (-242 |#2| |#1|) (-921 |#1|)) 95)) (-3354 (((-568) (-917)) 52 (|has| |#1| (-370)))) (-3114 (((-568) (-917) (-917)) 54 (|has| |#1| (-370)))) (-3281 (((-568) (-917)) 48 (|has| |#1| (-370)))) (-2246 (((-2 (|:| |num| (-634 (-242 |#2| |#1|))) (|:| |den| (-242 |#2| |#1|))) (-236 (-921 |#1|))) 33) (((-634 (-409 (-242 |#2| |#1|))) (-236 (-921 |#1|)) (-763)) NIL)) (-2411 (((-236 (-921 |#1|)) (-242 |#2| |#1|)) 107)) (-2525 (((-634 (-242 |#2| |#1|)) (-236 (-921 |#1|)) (-634 (-242 |#2| |#1|))) 31)) (-2664 (((-634 (-242 |#2| |#1|)) (-236 (-921 |#1|)) (-763)) 97)) (-3039 (((-242 |#2| |#1|) (-242 |#2| |#1|) (-568)) 13)) (-2766 (((-679 |#1|) (-236 (-921 |#1|)) (-634 (-921 |#1|))) 38) (((-679 |#1|) (-236 (-921 |#1|)) (-236 (-921 |#1|))) 40)) (-1801 (((-568)) 81)) (-2126 (((-763)) 79)) (-1896 (((-1249)) 116)) (-1944 (((-1249)) 112)) (-1640 (((-2 (|:| -1379 (-568)) (|:| |num| (-242 |#2| |#1|)) (|:| |den| (-242 |#2| |#1|)) (|:| |upTo| (-568))) (-236 (-921 |#1|)) (-568) (-568)) NIL)) (-3781 (((-3 |#1| "failed") (-409 (-242 |#2| |#1|)) (-921 |#1|)) 105) (((-3 |#1| "failed") (-242 |#2| |#1|) (-242 |#2| |#1|) (-921 |#1|)) 104) (((-3 |#1| "failed") (-242 |#2| |#1|) (-921 |#1|)) 73)) (-1339 ((|#1| (-409 (-242 |#2| |#1|)) (-921 |#1|)) 102) ((|#1| (-242 |#2| |#1|) (-242 |#2| |#1|) (-921 |#1|)) 34) ((|#1| (-242 |#2| |#1|) (-921 |#1|)) 70)) (-4007 (((-634 (-259 (-513 |#1| |#2| |#3|)))) 88)) (-2176 (((-634 (-259 (-513 |#1| |#2| |#3|)))) 86)) (-2277 (((-568)) 61 (|has| |#1| (-370)))) (-2480 (((-236 (-921 |#1|))) 90)) (-2596 (((-1239 (-568) -3492) (-917)) 46 (|has| |#1| (-370))) (((-1239 (-568) -3492)) 43 (|has| |#1| (-370)))) (-1637 (((-1157 (-568)) (-917)) 59 (|has| |#1| (-370))) (((-1157 (-568))) 57 (|has| |#1| (-370))))) 
-(((-868 |#1| |#2| |#3|) (-10 -7 (-15 -3039 ((-242 |#2| |#1|) (-242 |#2| |#1|) (-568))) (-15 -2525 ((-634 (-242 |#2| |#1|)) (-236 (-921 |#1|)) (-634 (-242 |#2| |#1|)))) (-15 -1944 ((-1249))) (-15 -1896 ((-1249))) (-15 -4276 ((-242 |#2| |#1|) (-242 |#2| |#1|))) (-15 -3534 ((-966 |#1|) (-634 |#1|))) (-15 -1279 ((-966 |#1|) (-921 |#1|))) (-15 -1547 ((-634 (-921 |#1|)) (-966 |#1|))) (-15 -4149 ((-634 (-966 |#1|)) (-634 (-966 |#1|)))) (-15 -2766 ((-679 |#1|) (-236 (-921 |#1|)) (-236 (-921 |#1|)))) (-15 -2766 ((-679 |#1|) (-236 (-921 |#1|)) (-634 (-921 |#1|)))) (-15 -4397 ((-634 (-921 |#1|)))) (-15 -2606 ((-242 |#2| |#1|))) (-15 -2126 ((-763))) (-15 -1801 ((-568))) (-15 -4007 ((-634 (-259 (-513 |#1| |#2| |#3|))))) (-15 -2176 ((-634 (-259 (-513 |#1| |#2| |#3|))))) (-15 -1895 ((-634 (-966 |#1|)))) (-15 -1846 ((-634 (-966 |#1|)))) (-15 -2215 ((-774 |#1|) (-242 |#2| |#1|) (-921 |#1|))) (-15 -2246 ((-634 (-409 (-242 |#2| |#1|))) (-236 (-921 |#1|)) (-763))) (-15 -2246 ((-2 (|:| |num| (-634 (-242 |#2| |#1|))) (|:| |den| (-242 |#2| |#1|))) (-236 (-921 |#1|)))) (-15 -1640 ((-2 (|:| -1379 (-568)) (|:| |num| (-242 |#2| |#1|)) (|:| |den| (-242 |#2| |#1|)) (|:| |upTo| (-568))) (-236 (-921 |#1|)) (-568) (-568))) (-15 -2664 ((-634 (-242 |#2| |#1|)) (-236 (-921 |#1|)) (-763))) (-15 -1339 (|#1| (-242 |#2| |#1|) (-921 |#1|))) (-15 -1339 (|#1| (-242 |#2| |#1|) (-242 |#2| |#1|) (-921 |#1|))) (-15 -1339 (|#1| (-409 (-242 |#2| |#1|)) (-921 |#1|))) (-15 -3781 ((-3 |#1| "failed") (-242 |#2| |#1|) (-921 |#1|))) (-15 -3781 ((-3 |#1| "failed") (-242 |#2| |#1|) (-242 |#2| |#1|) (-921 |#1|))) (-15 -3781 ((-3 |#1| "failed") (-409 (-242 |#2| |#1|)) (-921 |#1|))) (-15 -2411 ((-236 (-921 |#1|)) (-242 |#2| |#1|))) (-15 -2480 ((-236 (-921 |#1|)))) (IF (|has| |#1| (-370)) (PROGN (-15 -1637 ((-1157 (-568)))) (-15 -1637 ((-1157 (-568)) (-917))) (-15 -2277 ((-568))) (-15 -1375 ((-634 (-921 |#1|)) (-917))) (-15 -3281 ((-568) (-917))) (-15 -3354 ((-568) (-917))) (-15 -3114 ((-568) (-917) (-917))) (-15 -2596 ((-1239 (-568) -3492))) (-15 -2596 ((-1239 (-568) -3492) (-917)))) |noBranch|)) (-365) (-634 (-1161)) (-117)) (T -868)) 
-((-2596 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1239 (-568) -3492)) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-2596 (*1 *2) (-12 (-5 *2 (-1239 (-568) -3492)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-3114 (*1 *2 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-3354 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-3281 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-1375 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-634 (-921 *4))) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-2277 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-1637 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 (-568))) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-1637 (*1 *2) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2480 (*1 *2) (-12 (-5 *2 (-236 (-921 *3))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2411 (*1 *2 *3) (-12 (-5 *3 (-242 *5 *4)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *2 (-236 (-921 *4))) (-5 *1 (-868 *4 *5 *6)) (-4 *6 (-117)))) (-3781 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 (-242 *5 *2))) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117)))) (-3781 (*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-242 *5 *2)) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117)))) (-3781 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-242 *5 *2)) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117)))) (-1339 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-242 *5 *2))) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117)))) (-1339 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-242 *5 *2)) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117)))) (-1339 (*1 *2 *3 *4) (-12 (-5 *3 (-242 *5 *2)) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117)))) (-2664 (*1 *2 *3 *4) (-12 (-5 *3 (-236 (-921 *5))) (-5 *4 (-763)) (-4 *5 (-365)) (-5 *2 (-634 (-242 *6 *5))) (-5 *1 (-868 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) (-1640 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-236 (-921 *5))) (-4 *5 (-365)) (-5 *2 (-2 (|:| -1379 (-568)) (|:| |num| (-242 *6 *5)) (|:| |den| (-242 *6 *5)) (|:| |upTo| (-568)))) (-5 *1 (-868 *5 *6 *7)) (-5 *4 (-568)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) (-2246 (*1 *2 *3) (-12 (-5 *3 (-236 (-921 *4))) (-4 *4 (-365)) (-5 *2 (-2 (|:| |num| (-634 (-242 *5 *4))) (|:| |den| (-242 *5 *4)))) (-5 *1 (-868 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-2246 (*1 *2 *3 *4) (-12 (-5 *3 (-236 (-921 *5))) (-5 *4 (-763)) (-4 *5 (-365)) (-5 *2 (-634 (-409 (-242 *6 *5)))) (-5 *1 (-868 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) (-2215 (*1 *2 *3 *4) (-12 (-5 *3 (-242 *6 *5)) (-5 *4 (-921 *5)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-5 *2 (-774 *5)) (-5 *1 (-868 *5 *6 *7)) (-4 *7 (-117)))) (-1846 (*1 *2) (-12 (-5 *2 (-634 (-966 *3))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-1895 (*1 *2) (-12 (-5 *2 (-634 (-966 *3))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2176 (*1 *2) (-12 (-5 *2 (-634 (-259 (-513 *3 *4 *5)))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-4007 (*1 *2) (-12 (-5 *2 (-634 (-259 (-513 *3 *4 *5)))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-1801 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2126 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2606 (*1 *2) (-12 (-5 *2 (-242 *4 *3)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-4397 (*1 *2) (-12 (-5 *2 (-634 (-921 *3))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2766 (*1 *2 *3 *4) (-12 (-5 *3 (-236 (-921 *5))) (-5 *4 (-634 (-921 *5))) (-4 *5 (-365)) (-5 *2 (-679 *5)) (-5 *1 (-868 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) (-2766 (*1 *2 *3 *3) (-12 (-5 *3 (-236 (-921 *4))) (-4 *4 (-365)) (-5 *2 (-679 *4)) (-5 *1 (-868 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-4149 (*1 *2 *2) (-12 (-5 *2 (-634 (-966 *3))) (-4 *3 (-365)) (-5 *1 (-868 *3 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-1547 (*1 *2 *3) (-12 (-5 *3 (-966 *4)) (-4 *4 (-365)) (-5 *2 (-634 (-921 *4))) (-5 *1 (-868 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-1279 (*1 *2 *3) (-12 (-5 *3 (-921 *4)) (-4 *4 (-365)) (-5 *2 (-966 *4)) (-5 *1 (-868 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-3534 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-5 *2 (-966 *4)) (-5 *1 (-868 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-4276 (*1 *2 *2) (-12 (-5 *2 (-242 *4 *3)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-5 *1 (-868 *3 *4 *5)) (-4 *5 (-117)))) (-1896 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-1944 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2525 (*1 *2 *3 *2) (-12 (-5 *2 (-634 (-242 *5 *4))) (-5 *3 (-236 (-921 *4))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *1 (-868 *4 *5 *6)) (-4 *6 (-117)))) (-3039 (*1 *2 *2 *3) (-12 (-5 *2 (-242 *5 *4)) (-5 *3 (-568)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *1 (-868 *4 *5 *6)) (-4 *6 (-117))))) 
-(-10 -7 (-15 -3039 ((-242 |#2| |#1|) (-242 |#2| |#1|) (-568))) (-15 -2525 ((-634 (-242 |#2| |#1|)) (-236 (-921 |#1|)) (-634 (-242 |#2| |#1|)))) (-15 -1944 ((-1249))) (-15 -1896 ((-1249))) (-15 -4276 ((-242 |#2| |#1|) (-242 |#2| |#1|))) (-15 -3534 ((-966 |#1|) (-634 |#1|))) (-15 -1279 ((-966 |#1|) (-921 |#1|))) (-15 -1547 ((-634 (-921 |#1|)) (-966 |#1|))) (-15 -4149 ((-634 (-966 |#1|)) (-634 (-966 |#1|)))) (-15 -2766 ((-679 |#1|) (-236 (-921 |#1|)) (-236 (-921 |#1|)))) (-15 -2766 ((-679 |#1|) (-236 (-921 |#1|)) (-634 (-921 |#1|)))) (-15 -4397 ((-634 (-921 |#1|)))) (-15 -2606 ((-242 |#2| |#1|))) (-15 -2126 ((-763))) (-15 -1801 ((-568))) (-15 -4007 ((-634 (-259 (-513 |#1| |#2| |#3|))))) (-15 -2176 ((-634 (-259 (-513 |#1| |#2| |#3|))))) (-15 -1895 ((-634 (-966 |#1|)))) (-15 -1846 ((-634 (-966 |#1|)))) (-15 -2215 ((-774 |#1|) (-242 |#2| |#1|) (-921 |#1|))) (-15 -2246 ((-634 (-409 (-242 |#2| |#1|))) (-236 (-921 |#1|)) (-763))) (-15 -2246 ((-2 (|:| |num| (-634 (-242 |#2| |#1|))) (|:| |den| (-242 |#2| |#1|))) (-236 (-921 |#1|)))) (-15 -1640 ((-2 (|:| -1379 (-568)) (|:| |num| (-242 |#2| |#1|)) (|:| |den| (-242 |#2| |#1|)) (|:| |upTo| (-568))) (-236 (-921 |#1|)) (-568) (-568))) (-15 -2664 ((-634 (-242 |#2| |#1|)) (-236 (-921 |#1|)) (-763))) (-15 -1339 (|#1| (-242 |#2| |#1|) (-921 |#1|))) (-15 -1339 (|#1| (-242 |#2| |#1|) (-242 |#2| |#1|) (-921 |#1|))) (-15 -1339 (|#1| (-409 (-242 |#2| |#1|)) (-921 |#1|))) (-15 -3781 ((-3 |#1| "failed") (-242 |#2| |#1|) (-921 |#1|))) (-15 -3781 ((-3 |#1| "failed") (-242 |#2| |#1|) (-242 |#2| |#1|) (-921 |#1|))) (-15 -3781 ((-3 |#1| "failed") (-409 (-242 |#2| |#1|)) (-921 |#1|))) (-15 -2411 ((-236 (-921 |#1|)) (-242 |#2| |#1|))) (-15 -2480 ((-236 (-921 |#1|)))) (IF (|has| |#1| (-370)) (PROGN (-15 -1637 ((-1157 (-568)))) (-15 -1637 ((-1157 (-568)) (-917))) (-15 -2277 ((-568))) (-15 -1375 ((-634 (-921 |#1|)) (-917))) (-15 -3281 ((-568) (-917))) (-15 -3354 ((-568) (-917))) (-15 -3114 ((-568) (-917) (-917))) (-15 -2596 ((-1239 (-568) -3492))) (-15 -2596 ((-1239 (-568) -3492) (-917)))) |noBranch|)) 
-((-2447 (((-121) $ $) NIL)) (-4386 (((-568) $) 15)) (-4342 (($ (-158)) 11)) (-2807 (($ (-158)) 12)) (-4487 (((-1143) $) NIL)) (-1819 (((-158) $) 13)) (-4022 (((-1108) $) NIL)) (-2570 (($ (-158)) 9)) (-2459 (($ (-158)) 8)) (-2745 (((-850) $) 23) (($ (-158)) 16)) (-3474 (($ (-158)) 10)) (-1717 (((-121) $ $) NIL))) 
-(((-869) (-13 (-1090) (-10 -8 (-15 -2459 ($ (-158))) (-15 -2570 ($ (-158))) (-15 -3474 ($ (-158))) (-15 -4342 ($ (-158))) (-15 -2807 ($ (-158))) (-15 -1819 ((-158) $)) (-15 -4386 ((-568) $)) (-15 -2745 ($ (-158)))))) (T -869)) 
-((-2459 (*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869)))) (-2570 (*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869)))) (-3474 (*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869)))) (-4342 (*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869)))) (-2807 (*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869)))) (-1819 (*1 *2 *1) (-12 (-5 *2 (-158)) (-5 *1 (-869)))) (-4386 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-869)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869))))) 
-(-13 (-1090) (-10 -8 (-15 -2459 ($ (-158))) (-15 -2570 ($ (-158))) (-15 -3474 ($ (-158))) (-15 -4342 ($ (-158))) (-15 -2807 ($ (-158))) (-15 -1819 ((-158) $)) (-15 -4386 ((-568) $)) (-15 -2745 ($ (-158))))) 
-((-2745 (((-310 (-568)) (-409 (-953 (-53)))) 21) (((-310 (-568)) (-953 (-53))) 16))) 
-(((-870) (-10 -7 (-15 -2745 ((-310 (-568)) (-953 (-53)))) (-15 -2745 ((-310 (-568)) (-409 (-953 (-53))))))) (T -870)) 
-((-2745 (*1 *2 *3) (-12 (-5 *3 (-409 (-953 (-53)))) (-5 *2 (-310 (-568))) (-5 *1 (-870)))) (-2745 (*1 *2 *3) (-12 (-5 *3 (-953 (-53))) (-5 *2 (-310 (-568))) (-5 *1 (-870))))) 
-(-10 -7 (-15 -2745 ((-310 (-568)) (-953 (-53)))) (-15 -2745 ((-310 (-568)) (-409 (-953 (-53)))))) 
-((-2215 ((|#6| |#3| |#7| (-568)) 36) ((|#6| |#3| |#3| |#7|) 33) ((|#6| |#3| |#7|) 31) ((|#6| |#3| (-634 |#6|)) 28))) 
-(((-871 |#1| |#2| |#3| |#4| |#5| |#6| |#7|) (-10 -7 (-15 -2215 (|#6| |#3| (-634 |#6|))) (-15 -2215 (|#6| |#3| |#7|)) (-15 -2215 (|#6| |#3| |#3| |#7|)) (-15 -2215 (|#6| |#3| |#7| (-568)))) (-365) (-634 (-1161)) (-950 |#1| |#4| (-852 |#2|)) (-230 (-1697 |#2|) (-763)) (-971 |#1|) (-641 |#1|) (-920 |#1| |#6|)) (T -871)) 
-((-2215 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-568)) (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *8 (-230 (-1697 *7) (-763))) (-4 *2 (-641 *6)) (-5 *1 (-871 *6 *7 *3 *8 *9 *2 *4)) (-4 *3 (-950 *6 *8 (-852 *7))) (-4 *9 (-971 *6)) (-4 *4 (-920 *6 *2)))) (-2215 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1697 *6) (-763))) (-4 *2 (-641 *5)) (-5 *1 (-871 *5 *6 *3 *7 *8 *2 *4)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5)) (-4 *4 (-920 *5 *2)))) (-2215 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1697 *6) (-763))) (-4 *2 (-641 *5)) (-5 *1 (-871 *5 *6 *3 *7 *8 *2 *4)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5)) (-4 *4 (-920 *5 *2)))) (-2215 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *2)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1697 *6) (-763))) (-4 *2 (-641 *5)) (-5 *1 (-871 *5 *6 *3 *7 *8 *2 *9)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5)) (-4 *9 (-920 *5 *2))))) 
-(-10 -7 (-15 -2215 (|#6| |#3| (-634 |#6|))) (-15 -2215 (|#6| |#3| |#7|)) (-15 -2215 (|#6| |#3| |#3| |#7|)) (-15 -2215 (|#6| |#3| |#7| (-568)))) 
-((-2795 (((-873 |#2|) (-1 |#2| |#1|) (-873 |#1|)) 14))) 
-(((-872 |#1| |#2|) (-10 -7 (-15 -2795 ((-873 |#2|) (-1 |#2| |#1|) (-873 |#1|)))) (-1195) (-1195)) (T -872)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-873 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-873 *6)) (-5 *1 (-872 *5 *6))))) 
-(-10 -7 (-15 -2795 ((-873 |#2|) (-1 |#2| |#1|) (-873 |#1|)))) 
-((-4430 (($ |#1| |#1|) 8)) (-2100 ((|#1| $ (-763)) 10))) 
-(((-873 |#1|) (-10 -8 (-15 -4430 ($ |#1| |#1|)) (-15 -2100 (|#1| $ (-763)))) (-1195)) (T -873)) 
-((-2100 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *1 (-873 *2)) (-4 *2 (-1195)))) (-4430 (*1 *1 *2 *2) (-12 (-5 *1 (-873 *2)) (-4 *2 (-1195))))) 
-(-10 -8 (-15 -4430 ($ |#1| |#1|)) (-15 -2100 (|#1| $ (-763)))) 
-((-2795 (((-875 |#2|) (-1 |#2| |#1|) (-875 |#1|)) 14))) 
-(((-874 |#1| |#2|) (-10 -7 (-15 -2795 ((-875 |#2|) (-1 |#2| |#1|) (-875 |#1|)))) (-1195) (-1195)) (T -874)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-875 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-875 *6)) (-5 *1 (-874 *5 *6))))) 
-(-10 -7 (-15 -2795 ((-875 |#2|) (-1 |#2| |#1|) (-875 |#1|)))) 
-((-4430 (($ |#1| |#1| |#1|) 8)) (-2100 ((|#1| $ (-763)) 10))) 
-(((-875 |#1|) (-10 -8 (-15 -4430 ($ |#1| |#1| |#1|)) (-15 -2100 (|#1| $ (-763)))) (-1195)) (T -875)) 
-((-2100 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *1 (-875 *2)) (-4 *2 (-1195)))) (-4430 (*1 *1 *2 *2 *2) (-12 (-5 *1 (-875 *2)) (-4 *2 (-1195))))) 
-(-10 -8 (-15 -4430 ($ |#1| |#1| |#1|)) (-15 -2100 (|#1| $ (-763)))) 
-((-2795 (((-877 |#2|) (-1 |#2| |#1|) (-877 |#1|)) 14))) 
-(((-876 |#1| |#2|) (-10 -7 (-15 -2795 ((-877 |#2|) (-1 |#2| |#1|) (-877 |#1|)))) (-1195) (-1195)) (T -876)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-877 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-877 *6)) (-5 *1 (-876 *5 *6))))) 
-(-10 -7 (-15 -2795 ((-877 |#2|) (-1 |#2| |#1|) (-877 |#1|)))) 
-((-1437 (($ |#1| |#1| |#1|) 8)) (-2100 ((|#1| $ (-763)) 10))) 
-(((-877 |#1|) (-10 -8 (-15 -1437 ($ |#1| |#1| |#1|)) (-15 -2100 (|#1| $ (-763)))) (-1195)) (T -877)) 
-((-2100 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *1 (-877 *2)) (-4 *2 (-1195)))) (-1437 (*1 *1 *2 *2 *2) (-12 (-5 *1 (-877 *2)) (-4 *2 (-1195))))) 
-(-10 -8 (-15 -1437 ($ |#1| |#1| |#1|)) (-15 -2100 (|#1| $ (-763)))) 
-((-2904 (((-1141 (-634 (-568))) (-634 (-568)) (-1141 (-634 (-568)))) 30)) (-3605 (((-1141 (-634 (-568))) (-634 (-568)) (-634 (-568))) 26)) (-2125 (((-1141 (-634 (-568))) (-634 (-568))) 39) (((-1141 (-634 (-568))) (-634 (-568)) (-634 (-568))) 38)) (-3307 (((-1141 (-634 (-568))) (-568)) 40)) (-1929 (((-1141 (-634 (-568))) (-568) (-568)) 22) (((-1141 (-634 (-568))) (-568)) 16) (((-1141 (-634 (-568))) (-568) (-568) (-568)) 12)) (-1930 (((-1141 (-634 (-568))) (-1141 (-634 (-568)))) 24)) (-1458 (((-634 (-568)) (-634 (-568))) 23))) 
-(((-878) (-10 -7 (-15 -1929 ((-1141 (-634 (-568))) (-568) (-568) (-568))) (-15 -1929 ((-1141 (-634 (-568))) (-568))) (-15 -1929 ((-1141 (-634 (-568))) (-568) (-568))) (-15 -1458 ((-634 (-568)) (-634 (-568)))) (-15 -1930 ((-1141 (-634 (-568))) (-1141 (-634 (-568))))) (-15 -3605 ((-1141 (-634 (-568))) (-634 (-568)) (-634 (-568)))) (-15 -2904 ((-1141 (-634 (-568))) (-634 (-568)) (-1141 (-634 (-568))))) (-15 -2125 ((-1141 (-634 (-568))) (-634 (-568)) (-634 (-568)))) (-15 -2125 ((-1141 (-634 (-568))) (-634 (-568)))) (-15 -3307 ((-1141 (-634 (-568))) (-568))))) (T -878)) 
-((-3307 (*1 *2 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-568)))) (-2125 (*1 *2 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-634 (-568))))) (-2125 (*1 *2 *3 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-634 (-568))))) (-2904 (*1 *2 *3 *2) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *3 (-634 (-568))) (-5 *1 (-878)))) (-3605 (*1 *2 *3 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-634 (-568))))) (-1930 (*1 *2 *2) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)))) (-1458 (*1 *2 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-878)))) (-1929 (*1 *2 *3 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-568)))) (-1929 (*1 *2 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-568)))) (-1929 (*1 *2 *3 *3 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-568))))) 
-(-10 -7 (-15 -1929 ((-1141 (-634 (-568))) (-568) (-568) (-568))) (-15 -1929 ((-1141 (-634 (-568))) (-568))) (-15 -1929 ((-1141 (-634 (-568))) (-568) (-568))) (-15 -1458 ((-634 (-568)) (-634 (-568)))) (-15 -1930 ((-1141 (-634 (-568))) (-1141 (-634 (-568))))) (-15 -3605 ((-1141 (-634 (-568))) (-634 (-568)) (-634 (-568)))) (-15 -2904 ((-1141 (-634 (-568))) (-634 (-568)) (-1141 (-634 (-568))))) (-15 -2125 ((-1141 (-634 (-568))) (-634 (-568)) (-634 (-568)))) (-15 -2125 ((-1141 (-634 (-568))) (-634 (-568)))) (-15 -3307 ((-1141 (-634 (-568))) (-568)))) 
-((-4278 (((-887 (-381)) $) 9 (|has| |#1| (-609 (-887 (-381))))) (((-887 (-568)) $) 8 (|has| |#1| (-609 (-887 (-568))))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2563 (((-864 |#1|) $) NIL (|has| (-864 |#1|) (-301)))) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-864 |#1|) (-904)))) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| (-864 |#1|) (-904)))) (-2589 (((-121) $ $) NIL)) (-3337 (((-568) $) NIL (|has| (-864 |#1|) (-815)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-864 |#1|) "failed") $) NIL) (((-3 (-1161) "failed") $) NIL (|has| (-864 |#1|) (-1037 (-1161)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| (-864 |#1|) (-1037 (-568)))) (((-3 (-568) "failed") $) NIL (|has| (-864 |#1|) (-1037 (-568))))) (-2857 (((-864 |#1|) $) NIL) (((-1161) $) NIL (|has| (-864 |#1|) (-1037 (-1161)))) (((-409 (-568)) $) NIL (|has| (-864 |#1|) (-1037 (-568)))) (((-568) $) NIL (|has| (-864 |#1|) (-1037 (-568))))) (-2232 (($ $) NIL) (($ (-568) $) NIL)) (-2403 (($ $ $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| (-864 |#1|) (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| (-864 |#1|) (-630 (-568)))) (((-2 (|:| -2908 (-679 (-864 |#1|))) (|:| |vec| (-1244 (-864 |#1|)))) (-679 $) (-1244 $)) NIL) (((-679 (-864 |#1|)) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1733 (($) NIL (|has| (-864 |#1|) (-550)))) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-1436 (((-121) $) NIL (|has| (-864 |#1|) (-815)))) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| (-864 |#1|) (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| (-864 |#1|) (-881 (-381))))) (-1598 (((-121) $) NIL)) (-3539 (($ $) NIL)) (-2319 (((-864 |#1|) $) NIL)) (-2214 (((-3 $ "failed") $) NIL (|has| (-864 |#1|) (-1136)))) (-2859 (((-121) $) NIL (|has| (-864 |#1|) (-815)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1732 (($ $ $) NIL (|has| (-864 |#1|) (-842)))) (-2047 (($ $ $) NIL (|has| (-864 |#1|) (-842)))) (-2797 (($ (-1 (-864 |#1|) (-864 |#1|)) $) NIL)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4436 (($) NIL (|has| (-864 |#1|) (-1136)) CONST)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1999 (($ $) NIL (|has| (-864 |#1|) (-301)))) (-4115 (((-864 |#1|) $) NIL (|has| (-864 |#1|) (-550)))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-864 |#1|) (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-864 |#1|) (-904)))) (-3850 (((-420 $) $) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1339 (($ $ (-634 (-864 |#1|)) (-634 (-864 |#1|))) NIL (|has| (-864 |#1|) (-303 (-864 |#1|)))) (($ $ (-864 |#1|) (-864 |#1|)) NIL (|has| (-864 |#1|) (-303 (-864 |#1|)))) (($ $ (-288 (-864 |#1|))) NIL (|has| (-864 |#1|) (-303 (-864 |#1|)))) (($ $ (-634 (-288 (-864 |#1|)))) NIL (|has| (-864 |#1|) (-303 (-864 |#1|)))) (($ $ (-634 (-1161)) (-634 (-864 |#1|))) NIL (|has| (-864 |#1|) (-523 (-1161) (-864 |#1|)))) (($ $ (-1161) (-864 |#1|)) NIL (|has| (-864 |#1|) (-523 (-1161) (-864 |#1|))))) (-1466 (((-763) $) NIL)) (-2781 (($ $ (-864 |#1|)) NIL (|has| (-864 |#1|) (-281 (-864 |#1|) (-864 |#1|))))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-4191 (($ $) NIL (|has| (-864 |#1|) (-225))) (($ $ (-763)) NIL (|has| (-864 |#1|) (-225))) (($ $ (-1161)) NIL (|has| (-864 |#1|) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-864 |#1|) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-864 |#1|) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-864 |#1|) (-895 (-1161)))) (($ $ (-1 (-864 |#1|) (-864 |#1|)) (-763)) NIL) (($ $ (-1 (-864 |#1|) (-864 |#1|))) NIL)) (-3210 (($ $) NIL)) (-2326 (((-864 |#1|) $) NIL)) (-4280 (((-887 (-568)) $) NIL (|has| (-864 |#1|) (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| (-864 |#1|) (-609 (-887 (-381))))) (((-541) $) NIL (|has| (-864 |#1|) (-609 (-541)))) (((-381) $) NIL (|has| (-864 |#1|) (-1021))) (((-215) $) NIL (|has| (-864 |#1|) (-1021)))) (-1991 (((-173 (-409 (-568))) $) NIL)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| (-864 |#1|) (-904))))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL) (($ (-864 |#1|)) NIL) (($ (-1161)) NIL (|has| (-864 |#1|) (-1037 (-1161))))) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| (-864 |#1|) (-904))) (|has| (-864 |#1|) (-148))))) (-3425 (((-763)) NIL)) (-3520 (((-864 |#1|) $) NIL (|has| (-864 |#1|) (-550)))) (-2273 (((-121) $ $) NIL)) (-3999 (((-409 (-568)) $ (-568)) NIL)) (-2811 (($ $) NIL (|has| (-864 |#1|) (-815)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $) NIL (|has| (-864 |#1|) (-225))) (($ $ (-763)) NIL (|has| (-864 |#1|) (-225))) (($ $ (-1161)) NIL (|has| (-864 |#1|) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-864 |#1|) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-864 |#1|) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-864 |#1|) (-895 (-1161)))) (($ $ (-1 (-864 |#1|) (-864 |#1|)) (-763)) NIL) (($ $ (-1 (-864 |#1|) (-864 |#1|))) NIL)) (-1753 (((-121) $ $) NIL (|has| (-864 |#1|) (-842)))) (-1740 (((-121) $ $) NIL (|has| (-864 |#1|) (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| (-864 |#1|) (-842)))) (-1734 (((-121) $ $) NIL (|has| (-864 |#1|) (-842)))) (-1781 (($ $ $) NIL) (($ (-864 |#1|) (-864 |#1|)) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ (-864 |#1|) $) NIL) (($ $ (-864 |#1|)) NIL))) 
+(((-865 |#1|) (-13 (-993 (-864 |#1|)) (-10 -8 (-15 -3999 ((-409 (-568)) $ (-568))) (-15 -1991 ((-173 (-409 (-568))) $)) (-15 -2232 ($ $)) (-15 -2232 ($ (-568) $)))) (-568)) (T -865)) 
+((-3999 (*1 *2 *1 *3) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-865 *4)) (-14 *4 *3) (-5 *3 (-568)))) (-1991 (*1 *2 *1) (-12 (-5 *2 (-173 (-409 (-568)))) (-5 *1 (-865 *3)) (-14 *3 (-568)))) (-2232 (*1 *1 *1) (-12 (-5 *1 (-865 *2)) (-14 *2 (-568)))) (-2232 (*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-865 *3)) (-14 *3 *2)))) 
+(-13 (-993 (-864 |#1|)) (-10 -8 (-15 -3999 ((-409 (-568)) $ (-568))) (-15 -1991 ((-173 (-409 (-568))) $)) (-15 -2232 ($ $)) (-15 -2232 ($ (-568) $)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2563 ((|#2| $) NIL (|has| |#2| (-301)))) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-2589 (((-121) $ $) NIL)) (-3337 (((-568) $) NIL (|has| |#2| (-815)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#2| "failed") $) NIL) (((-3 (-1161) "failed") $) NIL (|has| |#2| (-1037 (-1161)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#2| (-1037 (-568)))) (((-3 (-568) "failed") $) NIL (|has| |#2| (-1037 (-568))))) (-2857 ((|#2| $) NIL) (((-1161) $) NIL (|has| |#2| (-1037 (-1161)))) (((-409 (-568)) $) NIL (|has| |#2| (-1037 (-568)))) (((-568) $) NIL (|has| |#2| (-1037 (-568))))) (-2232 (($ $) 31) (($ (-568) $) 32)) (-2403 (($ $ $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL) (((-679 |#2|) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) 53)) (-1733 (($) NIL (|has| |#2| (-550)))) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-1436 (((-121) $) NIL (|has| |#2| (-815)))) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| |#2| (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| |#2| (-881 (-381))))) (-1598 (((-121) $) NIL)) (-3539 (($ $) NIL)) (-2319 ((|#2| $) NIL)) (-2214 (((-3 $ "failed") $) NIL (|has| |#2| (-1136)))) (-2859 (((-121) $) NIL (|has| |#2| (-815)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1732 (($ $ $) NIL (|has| |#2| (-842)))) (-2047 (($ $ $) NIL (|has| |#2| (-842)))) (-2797 (($ (-1 |#2| |#2|) $) NIL)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) 49)) (-4436 (($) NIL (|has| |#2| (-1136)) CONST)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1999 (($ $) NIL (|has| |#2| (-301)))) (-4115 ((|#2| $) NIL (|has| |#2| (-550)))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3850 (((-420 $) $) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1339 (($ $ (-634 |#2|) (-634 |#2|)) NIL (|has| |#2| (-303 |#2|))) (($ $ |#2| |#2|) NIL (|has| |#2| (-303 |#2|))) (($ $ (-288 |#2|)) NIL (|has| |#2| (-303 |#2|))) (($ $ (-634 (-288 |#2|))) NIL (|has| |#2| (-303 |#2|))) (($ $ (-634 (-1161)) (-634 |#2|)) NIL (|has| |#2| (-523 (-1161) |#2|))) (($ $ (-1161) |#2|) NIL (|has| |#2| (-523 (-1161) |#2|)))) (-1466 (((-763) $) NIL)) (-2781 (($ $ |#2|) NIL (|has| |#2| (-281 |#2| |#2|)))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-4191 (($ $) NIL (|has| |#2| (-225))) (($ $ (-763)) NIL (|has| |#2| (-225))) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) NIL)) (-3210 (($ $) NIL)) (-2326 ((|#2| $) NIL)) (-4280 (((-887 (-568)) $) NIL (|has| |#2| (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| |#2| (-609 (-887 (-381))))) (((-541) $) NIL (|has| |#2| (-609 (-541)))) (((-381) $) NIL (|has| |#2| (-1021))) (((-215) $) NIL (|has| |#2| (-1021)))) (-1991 (((-173 (-409 (-568))) $) 68)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#2| (-904))))) (-2747 (((-850) $) 85) (($ (-568)) 19) (($ $) NIL) (($ (-409 (-568))) 24) (($ |#2|) 18) (($ (-1161)) NIL (|has| |#2| (-1037 (-1161))))) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| |#2| (-904))) (|has| |#2| (-148))))) (-3425 (((-763)) NIL)) (-3520 ((|#2| $) NIL (|has| |#2| (-550)))) (-2273 (((-121) $ $) NIL)) (-3999 (((-409 (-568)) $ (-568)) 60)) (-2811 (($ $) NIL (|has| |#2| (-815)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) 14 T CONST)) (-1557 (($) 16 T CONST)) (-3192 (($ $) NIL (|has| |#2| (-225))) (($ $ (-763)) NIL (|has| |#2| (-225))) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) NIL)) (-1753 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1719 (((-121) $ $) 35)) (-1747 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1781 (($ $ $) 23) (($ |#2| |#2|) 54)) (-1775 (($ $) 39) (($ $ $) 41)) (-1769 (($ $ $) 37)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) 50)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 42) (($ $ $) 44) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ |#2| $) 55) (($ $ |#2|) NIL))) 
+(((-866 |#1| |#2|) (-13 (-993 |#2|) (-10 -8 (-15 -3999 ((-409 (-568)) $ (-568))) (-15 -1991 ((-173 (-409 (-568))) $)) (-15 -2232 ($ $)) (-15 -2232 ($ (-568) $)))) (-568) (-863 |#1|)) (T -866)) 
+((-3999 (*1 *2 *1 *3) (-12 (-14 *4 *3) (-5 *2 (-409 (-568))) (-5 *1 (-866 *4 *5)) (-5 *3 (-568)) (-4 *5 (-863 *4)))) (-1991 (*1 *2 *1) (-12 (-14 *3 (-568)) (-5 *2 (-173 (-409 (-568)))) (-5 *1 (-866 *3 *4)) (-4 *4 (-863 *3)))) (-2232 (*1 *1 *1) (-12 (-14 *2 (-568)) (-5 *1 (-866 *2 *3)) (-4 *3 (-863 *2)))) (-2232 (*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-14 *3 *2) (-5 *1 (-866 *3 *4)) (-4 *4 (-863 *3))))) 
+(-13 (-993 |#2|) (-10 -8 (-15 -3999 ((-409 (-568)) $ (-568))) (-15 -1991 ((-173 (-409 (-568))) $)) (-15 -2232 ($ $)) (-15 -2232 ($ (-568) $)))) 
+((-3794 (((-242 |#2| (-857 |#1|)) (-242 |#2| |#1|) (-967 |#1|)) NIL)) (-2090 (((-242 |#2| |#1|)) 107)) (-2378 (((-634 (-967 |#1|))) 116)) (-3813 (((-634 (-967 |#1|)) (-634 (-967 |#1|))) 27)) (-2945 (((-242 |#2| |#1|) (-242 |#2| |#1|)) 35)) (-2603 (((-634 (-967 |#1|))) 60)) (-1450 (((-634 (-922 |#1|))) 58)) (-4154 (((-967 |#1|) (-634 (-857 |#1|))) 17)) (-1345 (((-967 |#1|) (-922 |#1|)) 21)) (-3869 (((-634 (-922 |#1|)) (-917)) 45 (|has| (-857 |#1|) (-370)))) (-4284 (((-634 (-922 |#1|)) (-967 |#1|)) 24)) (-3423 (((-774 (-857 |#1|)) (-242 |#2| |#1|) (-922 |#1|)) 119)) (-1296 (((-568) (-917)) 47 (|has| (-857 |#1|) (-370)))) (-2577 (((-568) (-917) (-917)) 49 (|has| (-857 |#1|) (-370)))) (-2102 (((-568) (-917)) 43 (|has| (-857 |#1|) (-370)))) (-2865 (((-2 (|:| |num| (-634 (-242 |#2| |#1|))) (|:| |den| (-242 |#2| |#1|))) (-236 (-922 |#1|))) 62) (((-634 (-409 (-242 |#2| |#1|))) (-236 (-922 |#1|)) (-763)) NIL)) (-2335 (((-236 (-922 |#1|)) (-242 |#2| |#1|)) 135)) (-1758 (((-634 (-242 |#2| (-857 |#1|))) (-236 (-922 |#1|)) (-634 (-242 |#2| |#1|))) 125)) (-4454 (((-634 (-242 |#2| |#1|)) (-236 (-922 |#1|)) (-763)) 123)) (-2219 (((-242 |#2| |#1|) (-242 |#2| |#1|) (-568)) 13)) (-3479 (((-679 |#1|) (-236 (-922 |#1|)) (-634 (-922 |#1|))) 67) (((-679 |#1|) (-236 (-922 |#1|)) (-236 (-922 |#1|))) 69)) (-2148 (((-568)) 105)) (-3383 (((-763)) 103)) (-2608 (((-1249)) 144)) (-4247 (((-1249)) 140)) (-3246 (((-2 (|:| -3894 (-568)) (|:| |num| (-242 |#2| |#1|)) (|:| |den| (-242 |#2| |#1|)) (|:| |upTo| (-568))) (-236 (-922 |#1|)) (-568) (-568)) 32)) (-2733 (((-3 |#1| "failed") (-409 (-242 |#2| |#1|)) (-922 |#1|)) 132) (((-3 |#1| "failed") (-242 |#2| |#1|) (-242 |#2| |#1|) (-922 |#1|)) 127) (((-3 |#1| "failed") (-242 |#2| |#1|) (-922 |#1|)) 96)) (-1339 ((|#1| (-409 (-242 |#2| |#1|)) (-922 |#1|)) 133) ((|#1| (-242 |#2| |#1|) (-242 |#2| |#1|) (-922 |#1|)) 63) ((|#1| (-242 |#2| |#1|) (-922 |#1|)) 98)) (-1371 (((-634 (-259 (-537 |#1| |#2| |#3|)))) 112)) (-3012 (((-634 (-259 (-537 |#1| |#2| |#3|)))) 110)) (-3456 (((-568)) 56 (|has| (-857 |#1|) (-370)))) (-2669 (((-236 (-922 |#1|))) 114)) (-2054 (((-1239 (-568) -3494) (-917)) 41 (|has| (-857 |#1|) (-370))) (((-1239 (-568) -3494)) 38 (|has| (-857 |#1|) (-370)))) (-3223 (((-1157 (-568)) (-917)) 54 (|has| (-857 |#1|) (-370))) (((-1157 (-568))) 52 (|has| (-857 |#1|) (-370))))) 
+(((-867 |#1| |#2| |#3|) (-10 -7 (-15 -2219 ((-242 |#2| |#1|) (-242 |#2| |#1|) (-568))) (-15 -4247 ((-1249))) (-15 -2608 ((-1249))) (-15 -2945 ((-242 |#2| |#1|) (-242 |#2| |#1|))) (-15 -3794 ((-242 |#2| (-857 |#1|)) (-242 |#2| |#1|) (-967 |#1|))) (-15 -3479 ((-679 |#1|) (-236 (-922 |#1|)) (-236 (-922 |#1|)))) (-15 -3479 ((-679 |#1|) (-236 (-922 |#1|)) (-634 (-922 |#1|)))) (-15 -1345 ((-967 |#1|) (-922 |#1|))) (-15 -4284 ((-634 (-922 |#1|)) (-967 |#1|))) (-15 -4154 ((-967 |#1|) (-634 (-857 |#1|)))) (-15 -3813 ((-634 (-967 |#1|)) (-634 (-967 |#1|)))) (-15 -1450 ((-634 (-922 |#1|)))) (-15 -2090 ((-242 |#2| |#1|))) (-15 -3383 ((-763))) (-15 -2148 ((-568))) (-15 -1371 ((-634 (-259 (-537 |#1| |#2| |#3|))))) (-15 -3012 ((-634 (-259 (-537 |#1| |#2| |#3|))))) (-15 -2603 ((-634 (-967 |#1|)))) (-15 -2378 ((-634 (-967 |#1|)))) (-15 -3423 ((-774 (-857 |#1|)) (-242 |#2| |#1|) (-922 |#1|))) (-15 -2865 ((-634 (-409 (-242 |#2| |#1|))) (-236 (-922 |#1|)) (-763))) (-15 -2865 ((-2 (|:| |num| (-634 (-242 |#2| |#1|))) (|:| |den| (-242 |#2| |#1|))) (-236 (-922 |#1|)))) (-15 -3246 ((-2 (|:| -3894 (-568)) (|:| |num| (-242 |#2| |#1|)) (|:| |den| (-242 |#2| |#1|)) (|:| |upTo| (-568))) (-236 (-922 |#1|)) (-568) (-568))) (-15 -1758 ((-634 (-242 |#2| (-857 |#1|))) (-236 (-922 |#1|)) (-634 (-242 |#2| |#1|)))) (-15 -4454 ((-634 (-242 |#2| |#1|)) (-236 (-922 |#1|)) (-763))) (-15 -1339 (|#1| (-242 |#2| |#1|) (-922 |#1|))) (-15 -1339 (|#1| (-242 |#2| |#1|) (-242 |#2| |#1|) (-922 |#1|))) (-15 -1339 (|#1| (-409 (-242 |#2| |#1|)) (-922 |#1|))) (-15 -2733 ((-3 |#1| "failed") (-242 |#2| |#1|) (-922 |#1|))) (-15 -2733 ((-3 |#1| "failed") (-242 |#2| |#1|) (-242 |#2| |#1|) (-922 |#1|))) (-15 -2733 ((-3 |#1| "failed") (-409 (-242 |#2| |#1|)) (-922 |#1|))) (-15 -2335 ((-236 (-922 |#1|)) (-242 |#2| |#1|))) (-15 -2669 ((-236 (-922 |#1|)))) (IF (|has| (-857 |#1|) (-370)) (PROGN (-15 -3223 ((-1157 (-568)))) (-15 -3223 ((-1157 (-568)) (-917))) (-15 -3456 ((-568))) (-15 -3869 ((-634 (-922 |#1|)) (-917))) (-15 -2102 ((-568) (-917))) (-15 -1296 ((-568) (-917))) (-15 -2577 ((-568) (-917) (-917))) (-15 -2054 ((-1239 (-568) -3494))) (-15 -2054 ((-1239 (-568) -3494) (-917)))) |noBranch|)) (-350) (-634 (-1161)) (-117)) (T -867)) 
+((-2054 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1239 (-568) -3494)) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-2054 (*1 *2) (-12 (-5 *2 (-1239 (-568) -3494)) (-5 *1 (-867 *3 *4 *5)) (-4 (-857 *3) (-370)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2577 (*1 *2 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-1296 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-2102 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-3869 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-634 (-922 *4))) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-3456 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-867 *3 *4 *5)) (-4 (-857 *3) (-370)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-3223 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 (-568))) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-3223 (*1 *2) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-867 *3 *4 *5)) (-4 (-857 *3) (-370)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2669 (*1 *2) (-12 (-5 *2 (-236 (-922 *3))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2335 (*1 *2 *3) (-12 (-5 *3 (-242 *5 *4)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-5 *2 (-236 (-922 *4))) (-5 *1 (-867 *4 *5 *6)) (-4 *6 (-117)))) (-2733 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 (-242 *5 *2))) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) (-2733 (*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-242 *5 *2)) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) (-2733 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-242 *5 *2)) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) (-1339 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-242 *5 *2))) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) (-1339 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-242 *5 *2)) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) (-1339 (*1 *2 *3 *4) (-12 (-5 *3 (-242 *5 *2)) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) (-4454 (*1 *2 *3 *4) (-12 (-5 *3 (-236 (-922 *5))) (-5 *4 (-763)) (-4 *5 (-350)) (-5 *2 (-634 (-242 *6 *5))) (-5 *1 (-867 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) (-1758 (*1 *2 *3 *4) (-12 (-5 *3 (-236 (-922 *5))) (-5 *4 (-634 (-242 *6 *5))) (-4 *5 (-350)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-242 *6 (-857 *5)))) (-5 *1 (-867 *5 *6 *7)) (-4 *7 (-117)))) (-3246 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-236 (-922 *5))) (-4 *5 (-350)) (-5 *2 (-2 (|:| -3894 (-568)) (|:| |num| (-242 *6 *5)) (|:| |den| (-242 *6 *5)) (|:| |upTo| (-568)))) (-5 *1 (-867 *5 *6 *7)) (-5 *4 (-568)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) (-2865 (*1 *2 *3) (-12 (-5 *3 (-236 (-922 *4))) (-4 *4 (-350)) (-5 *2 (-2 (|:| |num| (-634 (-242 *5 *4))) (|:| |den| (-242 *5 *4)))) (-5 *1 (-867 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-2865 (*1 *2 *3 *4) (-12 (-5 *3 (-236 (-922 *5))) (-5 *4 (-763)) (-4 *5 (-350)) (-5 *2 (-634 (-409 (-242 *6 *5)))) (-5 *1 (-867 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) (-3423 (*1 *2 *3 *4) (-12 (-5 *3 (-242 *6 *5)) (-5 *4 (-922 *5)) (-4 *5 (-350)) (-14 *6 (-634 (-1161))) (-5 *2 (-774 (-857 *5))) (-5 *1 (-867 *5 *6 *7)) (-4 *7 (-117)))) (-2378 (*1 *2) (-12 (-5 *2 (-634 (-967 *3))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2603 (*1 *2) (-12 (-5 *2 (-634 (-967 *3))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-3012 (*1 *2) (-12 (-5 *2 (-634 (-259 (-537 *3 *4 *5)))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-1371 (*1 *2) (-12 (-5 *2 (-634 (-259 (-537 *3 *4 *5)))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2148 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-3383 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2090 (*1 *2) (-12 (-5 *2 (-242 *4 *3)) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-1450 (*1 *2) (-12 (-5 *2 (-634 (-922 *3))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-3813 (*1 *2 *2) (-12 (-5 *2 (-634 (-967 *3))) (-4 *3 (-350)) (-5 *1 (-867 *3 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-4154 (*1 *2 *3) (-12 (-5 *3 (-634 (-857 *4))) (-4 *4 (-350)) (-5 *2 (-967 *4)) (-5 *1 (-867 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-4284 (*1 *2 *3) (-12 (-5 *3 (-967 *4)) (-4 *4 (-350)) (-5 *2 (-634 (-922 *4))) (-5 *1 (-867 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-1345 (*1 *2 *3) (-12 (-5 *3 (-922 *4)) (-4 *4 (-350)) (-5 *2 (-967 *4)) (-5 *1 (-867 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-3479 (*1 *2 *3 *4) (-12 (-5 *3 (-236 (-922 *5))) (-5 *4 (-634 (-922 *5))) (-4 *5 (-350)) (-5 *2 (-679 *5)) (-5 *1 (-867 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) (-3479 (*1 *2 *3 *3) (-12 (-5 *3 (-236 (-922 *4))) (-4 *4 (-350)) (-5 *2 (-679 *4)) (-5 *1 (-867 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-3794 (*1 *2 *3 *4) (-12 (-5 *3 (-242 *6 *5)) (-5 *4 (-967 *5)) (-4 *5 (-350)) (-14 *6 (-634 (-1161))) (-5 *2 (-242 *6 (-857 *5))) (-5 *1 (-867 *5 *6 *7)) (-4 *7 (-117)))) (-2945 (*1 *2 *2) (-12 (-5 *2 (-242 *4 *3)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-5 *1 (-867 *3 *4 *5)) (-4 *5 (-117)))) (-2608 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-4247 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2219 (*1 *2 *2 *3) (-12 (-5 *2 (-242 *5 *4)) (-5 *3 (-568)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-5 *1 (-867 *4 *5 *6)) (-4 *6 (-117))))) 
+(-10 -7 (-15 -2219 ((-242 |#2| |#1|) (-242 |#2| |#1|) (-568))) (-15 -4247 ((-1249))) (-15 -2608 ((-1249))) (-15 -2945 ((-242 |#2| |#1|) (-242 |#2| |#1|))) (-15 -3794 ((-242 |#2| (-857 |#1|)) (-242 |#2| |#1|) (-967 |#1|))) (-15 -3479 ((-679 |#1|) (-236 (-922 |#1|)) (-236 (-922 |#1|)))) (-15 -3479 ((-679 |#1|) (-236 (-922 |#1|)) (-634 (-922 |#1|)))) (-15 -1345 ((-967 |#1|) (-922 |#1|))) (-15 -4284 ((-634 (-922 |#1|)) (-967 |#1|))) (-15 -4154 ((-967 |#1|) (-634 (-857 |#1|)))) (-15 -3813 ((-634 (-967 |#1|)) (-634 (-967 |#1|)))) (-15 -1450 ((-634 (-922 |#1|)))) (-15 -2090 ((-242 |#2| |#1|))) (-15 -3383 ((-763))) (-15 -2148 ((-568))) (-15 -1371 ((-634 (-259 (-537 |#1| |#2| |#3|))))) (-15 -3012 ((-634 (-259 (-537 |#1| |#2| |#3|))))) (-15 -2603 ((-634 (-967 |#1|)))) (-15 -2378 ((-634 (-967 |#1|)))) (-15 -3423 ((-774 (-857 |#1|)) (-242 |#2| |#1|) (-922 |#1|))) (-15 -2865 ((-634 (-409 (-242 |#2| |#1|))) (-236 (-922 |#1|)) (-763))) (-15 -2865 ((-2 (|:| |num| (-634 (-242 |#2| |#1|))) (|:| |den| (-242 |#2| |#1|))) (-236 (-922 |#1|)))) (-15 -3246 ((-2 (|:| -3894 (-568)) (|:| |num| (-242 |#2| |#1|)) (|:| |den| (-242 |#2| |#1|)) (|:| |upTo| (-568))) (-236 (-922 |#1|)) (-568) (-568))) (-15 -1758 ((-634 (-242 |#2| (-857 |#1|))) (-236 (-922 |#1|)) (-634 (-242 |#2| |#1|)))) (-15 -4454 ((-634 (-242 |#2| |#1|)) (-236 (-922 |#1|)) (-763))) (-15 -1339 (|#1| (-242 |#2| |#1|) (-922 |#1|))) (-15 -1339 (|#1| (-242 |#2| |#1|) (-242 |#2| |#1|) (-922 |#1|))) (-15 -1339 (|#1| (-409 (-242 |#2| |#1|)) (-922 |#1|))) (-15 -2733 ((-3 |#1| "failed") (-242 |#2| |#1|) (-922 |#1|))) (-15 -2733 ((-3 |#1| "failed") (-242 |#2| |#1|) (-242 |#2| |#1|) (-922 |#1|))) (-15 -2733 ((-3 |#1| "failed") (-409 (-242 |#2| |#1|)) (-922 |#1|))) (-15 -2335 ((-236 (-922 |#1|)) (-242 |#2| |#1|))) (-15 -2669 ((-236 (-922 |#1|)))) (IF (|has| (-857 |#1|) (-370)) (PROGN (-15 -3223 ((-1157 (-568)))) (-15 -3223 ((-1157 (-568)) (-917))) (-15 -3456 ((-568))) (-15 -3869 ((-634 (-922 |#1|)) (-917))) (-15 -2102 ((-568) (-917))) (-15 -1296 ((-568) (-917))) (-15 -2577 ((-568) (-917) (-917))) (-15 -2054 ((-1239 (-568) -3494))) (-15 -2054 ((-1239 (-568) -3494) (-917)))) |noBranch|)) 
+((-2090 (((-242 |#2| |#1|)) 83)) (-2378 (((-634 (-966 |#1|))) 92)) (-3813 (((-634 (-966 |#1|)) (-634 (-966 |#1|))) 24)) (-2945 (((-242 |#2| |#1|) (-242 |#2| |#1|)) 75)) (-2603 (((-634 (-966 |#1|))) 65)) (-1450 (((-634 (-921 |#1|))) 63)) (-4154 (((-966 |#1|) (-634 |#1|)) 27)) (-1345 (((-966 |#1|) (-921 |#1|)) 18)) (-3869 (((-634 (-921 |#1|)) (-917)) 50 (|has| |#1| (-370)))) (-4284 (((-634 (-921 |#1|)) (-966 |#1|)) 21)) (-3423 (((-774 |#1|) (-242 |#2| |#1|) (-921 |#1|)) 95)) (-1296 (((-568) (-917)) 52 (|has| |#1| (-370)))) (-2577 (((-568) (-917) (-917)) 54 (|has| |#1| (-370)))) (-2102 (((-568) (-917)) 48 (|has| |#1| (-370)))) (-2865 (((-2 (|:| |num| (-634 (-242 |#2| |#1|))) (|:| |den| (-242 |#2| |#1|))) (-236 (-921 |#1|))) 33) (((-634 (-409 (-242 |#2| |#1|))) (-236 (-921 |#1|)) (-763)) NIL)) (-2335 (((-236 (-921 |#1|)) (-242 |#2| |#1|)) 107)) (-1758 (((-634 (-242 |#2| |#1|)) (-236 (-921 |#1|)) (-634 (-242 |#2| |#1|))) 31)) (-4454 (((-634 (-242 |#2| |#1|)) (-236 (-921 |#1|)) (-763)) 97)) (-2219 (((-242 |#2| |#1|) (-242 |#2| |#1|) (-568)) 13)) (-3479 (((-679 |#1|) (-236 (-921 |#1|)) (-634 (-921 |#1|))) 38) (((-679 |#1|) (-236 (-921 |#1|)) (-236 (-921 |#1|))) 40)) (-2148 (((-568)) 81)) (-3383 (((-763)) 79)) (-2608 (((-1249)) 116)) (-4247 (((-1249)) 112)) (-3246 (((-2 (|:| -3894 (-568)) (|:| |num| (-242 |#2| |#1|)) (|:| |den| (-242 |#2| |#1|)) (|:| |upTo| (-568))) (-236 (-921 |#1|)) (-568) (-568)) NIL)) (-2733 (((-3 |#1| "failed") (-409 (-242 |#2| |#1|)) (-921 |#1|)) 105) (((-3 |#1| "failed") (-242 |#2| |#1|) (-242 |#2| |#1|) (-921 |#1|)) 104) (((-3 |#1| "failed") (-242 |#2| |#1|) (-921 |#1|)) 73)) (-1339 ((|#1| (-409 (-242 |#2| |#1|)) (-921 |#1|)) 102) ((|#1| (-242 |#2| |#1|) (-242 |#2| |#1|) (-921 |#1|)) 34) ((|#1| (-242 |#2| |#1|) (-921 |#1|)) 70)) (-1371 (((-634 (-259 (-513 |#1| |#2| |#3|)))) 88)) (-3012 (((-634 (-259 (-513 |#1| |#2| |#3|)))) 86)) (-3456 (((-568)) 61 (|has| |#1| (-370)))) (-2669 (((-236 (-921 |#1|))) 90)) (-2054 (((-1239 (-568) -3494) (-917)) 46 (|has| |#1| (-370))) (((-1239 (-568) -3494)) 43 (|has| |#1| (-370)))) (-3223 (((-1157 (-568)) (-917)) 59 (|has| |#1| (-370))) (((-1157 (-568))) 57 (|has| |#1| (-370))))) 
+(((-868 |#1| |#2| |#3|) (-10 -7 (-15 -2219 ((-242 |#2| |#1|) (-242 |#2| |#1|) (-568))) (-15 -1758 ((-634 (-242 |#2| |#1|)) (-236 (-921 |#1|)) (-634 (-242 |#2| |#1|)))) (-15 -4247 ((-1249))) (-15 -2608 ((-1249))) (-15 -2945 ((-242 |#2| |#1|) (-242 |#2| |#1|))) (-15 -4154 ((-966 |#1|) (-634 |#1|))) (-15 -1345 ((-966 |#1|) (-921 |#1|))) (-15 -4284 ((-634 (-921 |#1|)) (-966 |#1|))) (-15 -3813 ((-634 (-966 |#1|)) (-634 (-966 |#1|)))) (-15 -3479 ((-679 |#1|) (-236 (-921 |#1|)) (-236 (-921 |#1|)))) (-15 -3479 ((-679 |#1|) (-236 (-921 |#1|)) (-634 (-921 |#1|)))) (-15 -1450 ((-634 (-921 |#1|)))) (-15 -2090 ((-242 |#2| |#1|))) (-15 -3383 ((-763))) (-15 -2148 ((-568))) (-15 -1371 ((-634 (-259 (-513 |#1| |#2| |#3|))))) (-15 -3012 ((-634 (-259 (-513 |#1| |#2| |#3|))))) (-15 -2603 ((-634 (-966 |#1|)))) (-15 -2378 ((-634 (-966 |#1|)))) (-15 -3423 ((-774 |#1|) (-242 |#2| |#1|) (-921 |#1|))) (-15 -2865 ((-634 (-409 (-242 |#2| |#1|))) (-236 (-921 |#1|)) (-763))) (-15 -2865 ((-2 (|:| |num| (-634 (-242 |#2| |#1|))) (|:| |den| (-242 |#2| |#1|))) (-236 (-921 |#1|)))) (-15 -3246 ((-2 (|:| -3894 (-568)) (|:| |num| (-242 |#2| |#1|)) (|:| |den| (-242 |#2| |#1|)) (|:| |upTo| (-568))) (-236 (-921 |#1|)) (-568) (-568))) (-15 -4454 ((-634 (-242 |#2| |#1|)) (-236 (-921 |#1|)) (-763))) (-15 -1339 (|#1| (-242 |#2| |#1|) (-921 |#1|))) (-15 -1339 (|#1| (-242 |#2| |#1|) (-242 |#2| |#1|) (-921 |#1|))) (-15 -1339 (|#1| (-409 (-242 |#2| |#1|)) (-921 |#1|))) (-15 -2733 ((-3 |#1| "failed") (-242 |#2| |#1|) (-921 |#1|))) (-15 -2733 ((-3 |#1| "failed") (-242 |#2| |#1|) (-242 |#2| |#1|) (-921 |#1|))) (-15 -2733 ((-3 |#1| "failed") (-409 (-242 |#2| |#1|)) (-921 |#1|))) (-15 -2335 ((-236 (-921 |#1|)) (-242 |#2| |#1|))) (-15 -2669 ((-236 (-921 |#1|)))) (IF (|has| |#1| (-370)) (PROGN (-15 -3223 ((-1157 (-568)))) (-15 -3223 ((-1157 (-568)) (-917))) (-15 -3456 ((-568))) (-15 -3869 ((-634 (-921 |#1|)) (-917))) (-15 -2102 ((-568) (-917))) (-15 -1296 ((-568) (-917))) (-15 -2577 ((-568) (-917) (-917))) (-15 -2054 ((-1239 (-568) -3494))) (-15 -2054 ((-1239 (-568) -3494) (-917)))) |noBranch|)) (-365) (-634 (-1161)) (-117)) (T -868)) 
+((-2054 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1239 (-568) -3494)) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-2054 (*1 *2) (-12 (-5 *2 (-1239 (-568) -3494)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2577 (*1 *2 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-1296 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-2102 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-3869 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-634 (-921 *4))) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-3456 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-3223 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 (-568))) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-3223 (*1 *2) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2669 (*1 *2) (-12 (-5 *2 (-236 (-921 *3))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2335 (*1 *2 *3) (-12 (-5 *3 (-242 *5 *4)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *2 (-236 (-921 *4))) (-5 *1 (-868 *4 *5 *6)) (-4 *6 (-117)))) (-2733 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 (-242 *5 *2))) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117)))) (-2733 (*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-242 *5 *2)) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117)))) (-2733 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-242 *5 *2)) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117)))) (-1339 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-242 *5 *2))) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117)))) (-1339 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-242 *5 *2)) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117)))) (-1339 (*1 *2 *3 *4) (-12 (-5 *3 (-242 *5 *2)) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117)))) (-4454 (*1 *2 *3 *4) (-12 (-5 *3 (-236 (-921 *5))) (-5 *4 (-763)) (-4 *5 (-365)) (-5 *2 (-634 (-242 *6 *5))) (-5 *1 (-868 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) (-3246 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-236 (-921 *5))) (-4 *5 (-365)) (-5 *2 (-2 (|:| -3894 (-568)) (|:| |num| (-242 *6 *5)) (|:| |den| (-242 *6 *5)) (|:| |upTo| (-568)))) (-5 *1 (-868 *5 *6 *7)) (-5 *4 (-568)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) (-2865 (*1 *2 *3) (-12 (-5 *3 (-236 (-921 *4))) (-4 *4 (-365)) (-5 *2 (-2 (|:| |num| (-634 (-242 *5 *4))) (|:| |den| (-242 *5 *4)))) (-5 *1 (-868 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-2865 (*1 *2 *3 *4) (-12 (-5 *3 (-236 (-921 *5))) (-5 *4 (-763)) (-4 *5 (-365)) (-5 *2 (-634 (-409 (-242 *6 *5)))) (-5 *1 (-868 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) (-3423 (*1 *2 *3 *4) (-12 (-5 *3 (-242 *6 *5)) (-5 *4 (-921 *5)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-5 *2 (-774 *5)) (-5 *1 (-868 *5 *6 *7)) (-4 *7 (-117)))) (-2378 (*1 *2) (-12 (-5 *2 (-634 (-966 *3))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2603 (*1 *2) (-12 (-5 *2 (-634 (-966 *3))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-3012 (*1 *2) (-12 (-5 *2 (-634 (-259 (-513 *3 *4 *5)))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-1371 (*1 *2) (-12 (-5 *2 (-634 (-259 (-513 *3 *4 *5)))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2148 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-3383 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-2090 (*1 *2) (-12 (-5 *2 (-242 *4 *3)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-1450 (*1 *2) (-12 (-5 *2 (-634 (-921 *3))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-3479 (*1 *2 *3 *4) (-12 (-5 *3 (-236 (-921 *5))) (-5 *4 (-634 (-921 *5))) (-4 *5 (-365)) (-5 *2 (-679 *5)) (-5 *1 (-868 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) (-3479 (*1 *2 *3 *3) (-12 (-5 *3 (-236 (-921 *4))) (-4 *4 (-365)) (-5 *2 (-679 *4)) (-5 *1 (-868 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-3813 (*1 *2 *2) (-12 (-5 *2 (-634 (-966 *3))) (-4 *3 (-365)) (-5 *1 (-868 *3 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-4284 (*1 *2 *3) (-12 (-5 *3 (-966 *4)) (-4 *4 (-365)) (-5 *2 (-634 (-921 *4))) (-5 *1 (-868 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-1345 (*1 *2 *3) (-12 (-5 *3 (-921 *4)) (-4 *4 (-365)) (-5 *2 (-966 *4)) (-5 *1 (-868 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-4154 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-5 *2 (-966 *4)) (-5 *1 (-868 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) (-2945 (*1 *2 *2) (-12 (-5 *2 (-242 *4 *3)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-5 *1 (-868 *3 *4 *5)) (-4 *5 (-117)))) (-2608 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-4247 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) (-1758 (*1 *2 *3 *2) (-12 (-5 *2 (-634 (-242 *5 *4))) (-5 *3 (-236 (-921 *4))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *1 (-868 *4 *5 *6)) (-4 *6 (-117)))) (-2219 (*1 *2 *2 *3) (-12 (-5 *2 (-242 *5 *4)) (-5 *3 (-568)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *1 (-868 *4 *5 *6)) (-4 *6 (-117))))) 
+(-10 -7 (-15 -2219 ((-242 |#2| |#1|) (-242 |#2| |#1|) (-568))) (-15 -1758 ((-634 (-242 |#2| |#1|)) (-236 (-921 |#1|)) (-634 (-242 |#2| |#1|)))) (-15 -4247 ((-1249))) (-15 -2608 ((-1249))) (-15 -2945 ((-242 |#2| |#1|) (-242 |#2| |#1|))) (-15 -4154 ((-966 |#1|) (-634 |#1|))) (-15 -1345 ((-966 |#1|) (-921 |#1|))) (-15 -4284 ((-634 (-921 |#1|)) (-966 |#1|))) (-15 -3813 ((-634 (-966 |#1|)) (-634 (-966 |#1|)))) (-15 -3479 ((-679 |#1|) (-236 (-921 |#1|)) (-236 (-921 |#1|)))) (-15 -3479 ((-679 |#1|) (-236 (-921 |#1|)) (-634 (-921 |#1|)))) (-15 -1450 ((-634 (-921 |#1|)))) (-15 -2090 ((-242 |#2| |#1|))) (-15 -3383 ((-763))) (-15 -2148 ((-568))) (-15 -1371 ((-634 (-259 (-513 |#1| |#2| |#3|))))) (-15 -3012 ((-634 (-259 (-513 |#1| |#2| |#3|))))) (-15 -2603 ((-634 (-966 |#1|)))) (-15 -2378 ((-634 (-966 |#1|)))) (-15 -3423 ((-774 |#1|) (-242 |#2| |#1|) (-921 |#1|))) (-15 -2865 ((-634 (-409 (-242 |#2| |#1|))) (-236 (-921 |#1|)) (-763))) (-15 -2865 ((-2 (|:| |num| (-634 (-242 |#2| |#1|))) (|:| |den| (-242 |#2| |#1|))) (-236 (-921 |#1|)))) (-15 -3246 ((-2 (|:| -3894 (-568)) (|:| |num| (-242 |#2| |#1|)) (|:| |den| (-242 |#2| |#1|)) (|:| |upTo| (-568))) (-236 (-921 |#1|)) (-568) (-568))) (-15 -4454 ((-634 (-242 |#2| |#1|)) (-236 (-921 |#1|)) (-763))) (-15 -1339 (|#1| (-242 |#2| |#1|) (-921 |#1|))) (-15 -1339 (|#1| (-242 |#2| |#1|) (-242 |#2| |#1|) (-921 |#1|))) (-15 -1339 (|#1| (-409 (-242 |#2| |#1|)) (-921 |#1|))) (-15 -2733 ((-3 |#1| "failed") (-242 |#2| |#1|) (-921 |#1|))) (-15 -2733 ((-3 |#1| "failed") (-242 |#2| |#1|) (-242 |#2| |#1|) (-921 |#1|))) (-15 -2733 ((-3 |#1| "failed") (-409 (-242 |#2| |#1|)) (-921 |#1|))) (-15 -2335 ((-236 (-921 |#1|)) (-242 |#2| |#1|))) (-15 -2669 ((-236 (-921 |#1|)))) (IF (|has| |#1| (-370)) (PROGN (-15 -3223 ((-1157 (-568)))) (-15 -3223 ((-1157 (-568)) (-917))) (-15 -3456 ((-568))) (-15 -3869 ((-634 (-921 |#1|)) (-917))) (-15 -2102 ((-568) (-917))) (-15 -1296 ((-568) (-917))) (-15 -2577 ((-568) (-917) (-917))) (-15 -2054 ((-1239 (-568) -3494))) (-15 -2054 ((-1239 (-568) -3494) (-917)))) |noBranch|)) 
+((-2449 (((-121) $ $) NIL)) (-1388 (((-568) $) 15)) (-3205 (($ (-158)) 11)) (-3692 (($ (-158)) 12)) (-1893 (((-1143) $) NIL)) (-2233 (((-158) $) 13)) (-4025 (((-1108) $) NIL)) (-1965 (($ (-158)) 9)) (-2565 (($ (-158)) 8)) (-2747 (((-850) $) 23) (($ (-158)) 16)) (-3476 (($ (-158)) 10)) (-1719 (((-121) $ $) NIL))) 
+(((-869) (-13 (-1090) (-10 -8 (-15 -2565 ($ (-158))) (-15 -1965 ($ (-158))) (-15 -3476 ($ (-158))) (-15 -3205 ($ (-158))) (-15 -3692 ($ (-158))) (-15 -2233 ((-158) $)) (-15 -1388 ((-568) $)) (-15 -2747 ($ (-158)))))) (T -869)) 
+((-2565 (*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869)))) (-1965 (*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869)))) (-3476 (*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869)))) (-3205 (*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869)))) (-3692 (*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869)))) (-2233 (*1 *2 *1) (-12 (-5 *2 (-158)) (-5 *1 (-869)))) (-1388 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-869)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869))))) 
+(-13 (-1090) (-10 -8 (-15 -2565 ($ (-158))) (-15 -1965 ($ (-158))) (-15 -3476 ($ (-158))) (-15 -3205 ($ (-158))) (-15 -3692 ($ (-158))) (-15 -2233 ((-158) $)) (-15 -1388 ((-568) $)) (-15 -2747 ($ (-158))))) 
+((-2747 (((-310 (-568)) (-409 (-953 (-53)))) 21) (((-310 (-568)) (-953 (-53))) 16))) 
+(((-870) (-10 -7 (-15 -2747 ((-310 (-568)) (-953 (-53)))) (-15 -2747 ((-310 (-568)) (-409 (-953 (-53))))))) (T -870)) 
+((-2747 (*1 *2 *3) (-12 (-5 *3 (-409 (-953 (-53)))) (-5 *2 (-310 (-568))) (-5 *1 (-870)))) (-2747 (*1 *2 *3) (-12 (-5 *3 (-953 (-53))) (-5 *2 (-310 (-568))) (-5 *1 (-870))))) 
+(-10 -7 (-15 -2747 ((-310 (-568)) (-953 (-53)))) (-15 -2747 ((-310 (-568)) (-409 (-953 (-53)))))) 
+((-3423 ((|#6| |#3| |#7| (-568)) 36) ((|#6| |#3| |#3| |#7|) 33) ((|#6| |#3| |#7|) 31) ((|#6| |#3| (-634 |#6|)) 28))) 
+(((-871 |#1| |#2| |#3| |#4| |#5| |#6| |#7|) (-10 -7 (-15 -3423 (|#6| |#3| (-634 |#6|))) (-15 -3423 (|#6| |#3| |#7|)) (-15 -3423 (|#6| |#3| |#3| |#7|)) (-15 -3423 (|#6| |#3| |#7| (-568)))) (-365) (-634 (-1161)) (-950 |#1| |#4| (-852 |#2|)) (-230 (-1699 |#2|) (-763)) (-971 |#1|) (-641 |#1|) (-920 |#1| |#6|)) (T -871)) 
+((-3423 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-568)) (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *8 (-230 (-1699 *7) (-763))) (-4 *2 (-641 *6)) (-5 *1 (-871 *6 *7 *3 *8 *9 *2 *4)) (-4 *3 (-950 *6 *8 (-852 *7))) (-4 *9 (-971 *6)) (-4 *4 (-920 *6 *2)))) (-3423 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1699 *6) (-763))) (-4 *2 (-641 *5)) (-5 *1 (-871 *5 *6 *3 *7 *8 *2 *4)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5)) (-4 *4 (-920 *5 *2)))) (-3423 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1699 *6) (-763))) (-4 *2 (-641 *5)) (-5 *1 (-871 *5 *6 *3 *7 *8 *2 *4)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5)) (-4 *4 (-920 *5 *2)))) (-3423 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *2)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1699 *6) (-763))) (-4 *2 (-641 *5)) (-5 *1 (-871 *5 *6 *3 *7 *8 *2 *9)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5)) (-4 *9 (-920 *5 *2))))) 
+(-10 -7 (-15 -3423 (|#6| |#3| (-634 |#6|))) (-15 -3423 (|#6| |#3| |#7|)) (-15 -3423 (|#6| |#3| |#3| |#7|)) (-15 -3423 (|#6| |#3| |#7| (-568)))) 
+((-2797 (((-873 |#2|) (-1 |#2| |#1|) (-873 |#1|)) 14))) 
+(((-872 |#1| |#2|) (-10 -7 (-15 -2797 ((-873 |#2|) (-1 |#2| |#1|) (-873 |#1|)))) (-1195) (-1195)) (T -872)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-873 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-873 *6)) (-5 *1 (-872 *5 *6))))) 
+(-10 -7 (-15 -2797 ((-873 |#2|) (-1 |#2| |#1|) (-873 |#1|)))) 
+((-1615 (($ |#1| |#1|) 8)) (-3204 ((|#1| $ (-763)) 10))) 
+(((-873 |#1|) (-10 -8 (-15 -1615 ($ |#1| |#1|)) (-15 -3204 (|#1| $ (-763)))) (-1195)) (T -873)) 
+((-3204 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *1 (-873 *2)) (-4 *2 (-1195)))) (-1615 (*1 *1 *2 *2) (-12 (-5 *1 (-873 *2)) (-4 *2 (-1195))))) 
+(-10 -8 (-15 -1615 ($ |#1| |#1|)) (-15 -3204 (|#1| $ (-763)))) 
+((-2797 (((-875 |#2|) (-1 |#2| |#1|) (-875 |#1|)) 14))) 
+(((-874 |#1| |#2|) (-10 -7 (-15 -2797 ((-875 |#2|) (-1 |#2| |#1|) (-875 |#1|)))) (-1195) (-1195)) (T -874)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-875 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-875 *6)) (-5 *1 (-874 *5 *6))))) 
+(-10 -7 (-15 -2797 ((-875 |#2|) (-1 |#2| |#1|) (-875 |#1|)))) 
+((-1615 (($ |#1| |#1| |#1|) 8)) (-3204 ((|#1| $ (-763)) 10))) 
+(((-875 |#1|) (-10 -8 (-15 -1615 ($ |#1| |#1| |#1|)) (-15 -3204 (|#1| $ (-763)))) (-1195)) (T -875)) 
+((-3204 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *1 (-875 *2)) (-4 *2 (-1195)))) (-1615 (*1 *1 *2 *2 *2) (-12 (-5 *1 (-875 *2)) (-4 *2 (-1195))))) 
+(-10 -8 (-15 -1615 ($ |#1| |#1| |#1|)) (-15 -3204 (|#1| $ (-763)))) 
+((-2797 (((-877 |#2|) (-1 |#2| |#1|) (-877 |#1|)) 14))) 
+(((-876 |#1| |#2|) (-10 -7 (-15 -2797 ((-877 |#2|) (-1 |#2| |#1|) (-877 |#1|)))) (-1195) (-1195)) (T -876)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-877 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-877 *6)) (-5 *1 (-876 *5 *6))))) 
+(-10 -7 (-15 -2797 ((-877 |#2|) (-1 |#2| |#1|) (-877 |#1|)))) 
+((-2277 (($ |#1| |#1| |#1|) 8)) (-3204 ((|#1| $ (-763)) 10))) 
+(((-877 |#1|) (-10 -8 (-15 -2277 ($ |#1| |#1| |#1|)) (-15 -3204 (|#1| $ (-763)))) (-1195)) (T -877)) 
+((-3204 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *1 (-877 *2)) (-4 *2 (-1195)))) (-2277 (*1 *1 *2 *2 *2) (-12 (-5 *1 (-877 *2)) (-4 *2 (-1195))))) 
+(-10 -8 (-15 -2277 ($ |#1| |#1| |#1|)) (-15 -3204 (|#1| $ (-763)))) 
+((-2837 (((-1141 (-634 (-568))) (-634 (-568)) (-1141 (-634 (-568)))) 30)) (-3024 (((-1141 (-634 (-568))) (-634 (-568)) (-634 (-568))) 26)) (-3376 (((-1141 (-634 (-568))) (-634 (-568))) 39) (((-1141 (-634 (-568))) (-634 (-568)) (-634 (-568))) 38)) (-4262 (((-1141 (-634 (-568))) (-568)) 40)) (-4178 (((-1141 (-634 (-568))) (-568) (-568)) 22) (((-1141 (-634 (-568))) (-568)) 16) (((-1141 (-634 (-568))) (-568) (-568) (-568)) 12)) (-4185 (((-1141 (-634 (-568))) (-1141 (-634 (-568)))) 24)) (-2387 (((-634 (-568)) (-634 (-568))) 23))) 
+(((-878) (-10 -7 (-15 -4178 ((-1141 (-634 (-568))) (-568) (-568) (-568))) (-15 -4178 ((-1141 (-634 (-568))) (-568))) (-15 -4178 ((-1141 (-634 (-568))) (-568) (-568))) (-15 -2387 ((-634 (-568)) (-634 (-568)))) (-15 -4185 ((-1141 (-634 (-568))) (-1141 (-634 (-568))))) (-15 -3024 ((-1141 (-634 (-568))) (-634 (-568)) (-634 (-568)))) (-15 -2837 ((-1141 (-634 (-568))) (-634 (-568)) (-1141 (-634 (-568))))) (-15 -3376 ((-1141 (-634 (-568))) (-634 (-568)) (-634 (-568)))) (-15 -3376 ((-1141 (-634 (-568))) (-634 (-568)))) (-15 -4262 ((-1141 (-634 (-568))) (-568))))) (T -878)) 
+((-4262 (*1 *2 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-568)))) (-3376 (*1 *2 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-634 (-568))))) (-3376 (*1 *2 *3 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-634 (-568))))) (-2837 (*1 *2 *3 *2) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *3 (-634 (-568))) (-5 *1 (-878)))) (-3024 (*1 *2 *3 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-634 (-568))))) (-4185 (*1 *2 *2) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)))) (-2387 (*1 *2 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-878)))) (-4178 (*1 *2 *3 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-568)))) (-4178 (*1 *2 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-568)))) (-4178 (*1 *2 *3 *3 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-568))))) 
+(-10 -7 (-15 -4178 ((-1141 (-634 (-568))) (-568) (-568) (-568))) (-15 -4178 ((-1141 (-634 (-568))) (-568))) (-15 -4178 ((-1141 (-634 (-568))) (-568) (-568))) (-15 -2387 ((-634 (-568)) (-634 (-568)))) (-15 -4185 ((-1141 (-634 (-568))) (-1141 (-634 (-568))))) (-15 -3024 ((-1141 (-634 (-568))) (-634 (-568)) (-634 (-568)))) (-15 -2837 ((-1141 (-634 (-568))) (-634 (-568)) (-1141 (-634 (-568))))) (-15 -3376 ((-1141 (-634 (-568))) (-634 (-568)) (-634 (-568)))) (-15 -3376 ((-1141 (-634 (-568))) (-634 (-568)))) (-15 -4262 ((-1141 (-634 (-568))) (-568)))) 
+((-4280 (((-887 (-381)) $) 9 (|has| |#1| (-609 (-887 (-381))))) (((-887 (-568)) $) 8 (|has| |#1| (-609 (-887 (-568))))))) 
 (((-879 |#1|) (-1275) (-1195)) (T -879)) 
 NIL 
 (-13 (-10 -7 (IF (|has| |t#1| (-609 (-887 (-568)))) (-6 (-609 (-887 (-568)))) |noBranch|) (IF (|has| |t#1| (-609 (-887 (-381)))) (-6 (-609 (-887 (-381)))) |noBranch|))) 
 (((-609 (-887 (-381))) |has| |#1| (-609 (-887 (-381)))) ((-609 (-887 (-568))) |has| |#1| (-609 (-887 (-568))))) 
-((-2447 (((-121) $ $) NIL)) (-1849 (($) 14)) (-2839 (($ (-884 |#1| |#2|) (-884 |#1| |#3|)) 27)) (-2233 (((-884 |#1| |#3|) $) 16)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-1940 (((-121) $) 22)) (-3483 (($) 19)) (-2745 (((-850) $) 30)) (-2934 (((-884 |#1| |#2|) $) 15)) (-1717 (((-121) $ $) 25))) 
-(((-880 |#1| |#2| |#3|) (-13 (-1090) (-10 -8 (-15 -1940 ((-121) $)) (-15 -3483 ($)) (-15 -1849 ($)) (-15 -2839 ($ (-884 |#1| |#2|) (-884 |#1| |#3|))) (-15 -2934 ((-884 |#1| |#2|) $)) (-15 -2233 ((-884 |#1| |#3|) $)))) (-1090) (-1090) (-658 |#2|)) (T -880)) 
-((-1940 (*1 *2 *1) (-12 (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-880 *3 *4 *5)) (-4 *3 (-1090)) (-4 *5 (-658 *4)))) (-3483 (*1 *1) (-12 (-4 *3 (-1090)) (-5 *1 (-880 *2 *3 *4)) (-4 *2 (-1090)) (-4 *4 (-658 *3)))) (-1849 (*1 *1) (-12 (-4 *3 (-1090)) (-5 *1 (-880 *2 *3 *4)) (-4 *2 (-1090)) (-4 *4 (-658 *3)))) (-2839 (*1 *1 *2 *3) (-12 (-5 *2 (-884 *4 *5)) (-5 *3 (-884 *4 *6)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-658 *5)) (-5 *1 (-880 *4 *5 *6)))) (-2934 (*1 *2 *1) (-12 (-4 *4 (-1090)) (-5 *2 (-884 *3 *4)) (-5 *1 (-880 *3 *4 *5)) (-4 *3 (-1090)) (-4 *5 (-658 *4)))) (-2233 (*1 *2 *1) (-12 (-4 *4 (-1090)) (-5 *2 (-884 *3 *5)) (-5 *1 (-880 *3 *4 *5)) (-4 *3 (-1090)) (-4 *5 (-658 *4))))) 
-(-13 (-1090) (-10 -8 (-15 -1940 ((-121) $)) (-15 -3483 ($)) (-15 -1849 ($)) (-15 -2839 ($ (-884 |#1| |#2|) (-884 |#1| |#3|))) (-15 -2934 ((-884 |#1| |#2|) $)) (-15 -2233 ((-884 |#1| |#3|) $)))) 
-((-2447 (((-121) $ $) 7)) (-4410 (((-884 |#1| $) $ (-887 |#1|) (-884 |#1| $)) 12)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-1717 (((-121) $ $) 6))) 
+((-2449 (((-121) $ $) NIL)) (-1851 (($) 14)) (-3898 (($ (-884 |#1| |#2|) (-884 |#1| |#3|)) 27)) (-2673 (((-884 |#1| |#3|) $) 16)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-4229 (((-121) $) 22)) (-3485 (($) 19)) (-2747 (((-850) $) 30)) (-2923 (((-884 |#1| |#2|) $) 15)) (-1719 (((-121) $ $) 25))) 
+(((-880 |#1| |#2| |#3|) (-13 (-1090) (-10 -8 (-15 -4229 ((-121) $)) (-15 -3485 ($)) (-15 -1851 ($)) (-15 -3898 ($ (-884 |#1| |#2|) (-884 |#1| |#3|))) (-15 -2923 ((-884 |#1| |#2|) $)) (-15 -2673 ((-884 |#1| |#3|) $)))) (-1090) (-1090) (-658 |#2|)) (T -880)) 
+((-4229 (*1 *2 *1) (-12 (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-880 *3 *4 *5)) (-4 *3 (-1090)) (-4 *5 (-658 *4)))) (-3485 (*1 *1) (-12 (-4 *3 (-1090)) (-5 *1 (-880 *2 *3 *4)) (-4 *2 (-1090)) (-4 *4 (-658 *3)))) (-1851 (*1 *1) (-12 (-4 *3 (-1090)) (-5 *1 (-880 *2 *3 *4)) (-4 *2 (-1090)) (-4 *4 (-658 *3)))) (-3898 (*1 *1 *2 *3) (-12 (-5 *2 (-884 *4 *5)) (-5 *3 (-884 *4 *6)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-658 *5)) (-5 *1 (-880 *4 *5 *6)))) (-2923 (*1 *2 *1) (-12 (-4 *4 (-1090)) (-5 *2 (-884 *3 *4)) (-5 *1 (-880 *3 *4 *5)) (-4 *3 (-1090)) (-4 *5 (-658 *4)))) (-2673 (*1 *2 *1) (-12 (-4 *4 (-1090)) (-5 *2 (-884 *3 *5)) (-5 *1 (-880 *3 *4 *5)) (-4 *3 (-1090)) (-4 *5 (-658 *4))))) 
+(-13 (-1090) (-10 -8 (-15 -4229 ((-121) $)) (-15 -3485 ($)) (-15 -1851 ($)) (-15 -3898 ($ (-884 |#1| |#2|) (-884 |#1| |#3|))) (-15 -2923 ((-884 |#1| |#2|) $)) (-15 -2673 ((-884 |#1| |#3|) $)))) 
+((-2449 (((-121) $ $) 7)) (-1519 (((-884 |#1| $) $ (-887 |#1|) (-884 |#1| $)) 12)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-1719 (((-121) $ $) 6))) 
 (((-881 |#1|) (-1275) (-1090)) (T -881)) 
-((-4410 (*1 *2 *1 *3 *2) (-12 (-5 *2 (-884 *4 *1)) (-5 *3 (-887 *4)) (-4 *1 (-881 *4)) (-4 *4 (-1090))))) 
-(-13 (-1090) (-10 -8 (-15 -4410 ((-884 |t#1| $) $ (-887 |t#1|) (-884 |t#1| $))))) 
+((-1519 (*1 *2 *1 *3 *2) (-12 (-5 *2 (-884 *4 *1)) (-5 *3 (-887 *4)) (-4 *1 (-881 *4)) (-4 *4 (-1090))))) 
+(-13 (-1090) (-10 -8 (-15 -1519 ((-884 |t#1| $) $ (-887 |t#1|) (-884 |t#1| $))))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-2841 (((-121) (-634 |#2|) |#3|) 22) (((-121) |#2| |#3|) 17)) (-3408 (((-884 |#1| |#2|) |#2| |#3|) 42 (-12 (-3044 (|has| |#2| (-1037 (-1161)))) (-3044 (|has| |#2| (-1047))))) (((-634 (-288 (-953 |#2|))) |#2| |#3|) 41 (-12 (|has| |#2| (-1047)) (-3044 (|has| |#2| (-1037 (-1161)))))) (((-634 (-288 |#2|)) |#2| |#3|) 34 (|has| |#2| (-1037 (-1161)))) (((-880 |#1| |#2| (-634 |#2|)) (-634 |#2|) |#3|) 20))) 
-(((-882 |#1| |#2| |#3|) (-10 -7 (-15 -2841 ((-121) |#2| |#3|)) (-15 -2841 ((-121) (-634 |#2|) |#3|)) (-15 -3408 ((-880 |#1| |#2| (-634 |#2|)) (-634 |#2|) |#3|)) (IF (|has| |#2| (-1037 (-1161))) (-15 -3408 ((-634 (-288 |#2|)) |#2| |#3|)) (IF (|has| |#2| (-1047)) (-15 -3408 ((-634 (-288 (-953 |#2|))) |#2| |#3|)) (-15 -3408 ((-884 |#1| |#2|) |#2| |#3|))))) (-1090) (-881 |#1|) (-609 (-887 |#1|))) (T -882)) 
-((-3408 (*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-5 *2 (-884 *5 *3)) (-5 *1 (-882 *5 *3 *4)) (-3044 (-4 *3 (-1037 (-1161)))) (-3044 (-4 *3 (-1047))) (-4 *3 (-881 *5)) (-4 *4 (-609 (-887 *5))))) (-3408 (*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-5 *2 (-634 (-288 (-953 *3)))) (-5 *1 (-882 *5 *3 *4)) (-4 *3 (-1047)) (-3044 (-4 *3 (-1037 (-1161)))) (-4 *3 (-881 *5)) (-4 *4 (-609 (-887 *5))))) (-3408 (*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-5 *2 (-634 (-288 *3))) (-5 *1 (-882 *5 *3 *4)) (-4 *3 (-1037 (-1161))) (-4 *3 (-881 *5)) (-4 *4 (-609 (-887 *5))))) (-3408 (*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-4 *6 (-881 *5)) (-5 *2 (-880 *5 *6 (-634 *6))) (-5 *1 (-882 *5 *6 *4)) (-5 *3 (-634 *6)) (-4 *4 (-609 (-887 *5))))) (-2841 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-4 *6 (-881 *5)) (-4 *5 (-1090)) (-5 *2 (-121)) (-5 *1 (-882 *5 *6 *4)) (-4 *4 (-609 (-887 *5))))) (-2841 (*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-5 *2 (-121)) (-5 *1 (-882 *5 *3 *4)) (-4 *3 (-881 *5)) (-4 *4 (-609 (-887 *5)))))) 
-(-10 -7 (-15 -2841 ((-121) |#2| |#3|)) (-15 -2841 ((-121) (-634 |#2|) |#3|)) (-15 -3408 ((-880 |#1| |#2| (-634 |#2|)) (-634 |#2|) |#3|)) (IF (|has| |#2| (-1037 (-1161))) (-15 -3408 ((-634 (-288 |#2|)) |#2| |#3|)) (IF (|has| |#2| (-1047)) (-15 -3408 ((-634 (-288 (-953 |#2|))) |#2| |#3|)) (-15 -3408 ((-884 |#1| |#2|) |#2| |#3|))))) 
-((-2795 (((-884 |#1| |#3|) (-1 |#3| |#2|) (-884 |#1| |#2|)) 21))) 
-(((-883 |#1| |#2| |#3|) (-10 -7 (-15 -2795 ((-884 |#1| |#3|) (-1 |#3| |#2|) (-884 |#1| |#2|)))) (-1090) (-1090) (-1090)) (T -883)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-884 *5 *6)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-884 *5 *7)) (-5 *1 (-883 *5 *6 *7))))) 
-(-10 -7 (-15 -2795 ((-884 |#1| |#3|) (-1 |#3| |#2|) (-884 |#1| |#2|)))) 
-((-2447 (((-121) $ $) NIL)) (-1791 (($ $ $) 37)) (-1848 (((-3 (-121) "failed") $ (-887 |#1|)) 34)) (-1849 (($) 11)) (-4487 (((-1143) $) NIL)) (-2648 (($ (-887 |#1|) |#2| $) 20)) (-4022 (((-1108) $) NIL)) (-3962 (((-3 |#2| "failed") (-887 |#1|) $) 48)) (-1940 (((-121) $) 14)) (-3483 (($) 12)) (-2043 (((-634 (-2 (|:| -3649 (-1161)) (|:| -4083 |#2|))) $) 25)) (-4287 (($ (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 |#2|)))) 23)) (-2745 (((-850) $) 42)) (-2299 (($ (-887 |#1|) |#2| $ |#2|) 46)) (-4137 (($ (-887 |#1|) |#2| $) 45)) (-1717 (((-121) $ $) 39))) 
-(((-884 |#1| |#2|) (-13 (-1090) (-10 -8 (-15 -1940 ((-121) $)) (-15 -3483 ($)) (-15 -1849 ($)) (-15 -1791 ($ $ $)) (-15 -3962 ((-3 |#2| "failed") (-887 |#1|) $)) (-15 -4137 ($ (-887 |#1|) |#2| $)) (-15 -2648 ($ (-887 |#1|) |#2| $)) (-15 -2299 ($ (-887 |#1|) |#2| $ |#2|)) (-15 -2043 ((-634 (-2 (|:| -3649 (-1161)) (|:| -4083 |#2|))) $)) (-15 -4287 ($ (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 |#2|))))) (-15 -1848 ((-3 (-121) "failed") $ (-887 |#1|))))) (-1090) (-1090)) (T -884)) 
-((-1940 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-884 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)))) (-3483 (*1 *1) (-12 (-5 *1 (-884 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090)))) (-1849 (*1 *1) (-12 (-5 *1 (-884 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090)))) (-1791 (*1 *1 *1 *1) (-12 (-5 *1 (-884 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090)))) (-3962 (*1 *2 *3 *1) (|partial| -12 (-5 *3 (-887 *4)) (-4 *4 (-1090)) (-4 *2 (-1090)) (-5 *1 (-884 *4 *2)))) (-4137 (*1 *1 *2 *3 *1) (-12 (-5 *2 (-887 *4)) (-4 *4 (-1090)) (-5 *1 (-884 *4 *3)) (-4 *3 (-1090)))) (-2648 (*1 *1 *2 *3 *1) (-12 (-5 *2 (-887 *4)) (-4 *4 (-1090)) (-5 *1 (-884 *4 *3)) (-4 *3 (-1090)))) (-2299 (*1 *1 *2 *3 *1 *3) (-12 (-5 *2 (-887 *4)) (-4 *4 (-1090)) (-5 *1 (-884 *4 *3)) (-4 *3 (-1090)))) (-2043 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 *4)))) (-5 *1 (-884 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)))) (-4287 (*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 *4)))) (-4 *4 (-1090)) (-5 *1 (-884 *3 *4)) (-4 *3 (-1090)))) (-1848 (*1 *2 *1 *3) (|partial| -12 (-5 *3 (-887 *4)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-884 *4 *5)) (-4 *5 (-1090))))) 
-(-13 (-1090) (-10 -8 (-15 -1940 ((-121) $)) (-15 -3483 ($)) (-15 -1849 ($)) (-15 -1791 ($ $ $)) (-15 -3962 ((-3 |#2| "failed") (-887 |#1|) $)) (-15 -4137 ($ (-887 |#1|) |#2| $)) (-15 -2648 ($ (-887 |#1|) |#2| $)) (-15 -2299 ($ (-887 |#1|) |#2| $ |#2|)) (-15 -2043 ((-634 (-2 (|:| -3649 (-1161)) (|:| -4083 |#2|))) $)) (-15 -4287 ($ (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 |#2|))))) (-15 -1848 ((-3 (-121) "failed") $ (-887 |#1|))))) 
-((-1562 (((-887 |#1|) (-887 |#1|) (-634 (-1161)) (-1 (-121) (-634 |#2|))) 30) (((-887 |#1|) (-887 |#1|) (-634 (-1 (-121) |#2|))) 42) (((-887 |#1|) (-887 |#1|) (-1 (-121) |#2|)) 33)) (-1848 (((-121) (-634 |#2|) (-887 |#1|)) 39) (((-121) |#2| (-887 |#1|)) 35)) (-1392 (((-1 (-121) |#2|) (-887 |#1|)) 14)) (-4229 (((-634 |#2|) (-887 |#1|)) 23)) (-2526 (((-887 |#1|) (-887 |#1|) |#2|) 19))) 
-(((-885 |#1| |#2|) (-10 -7 (-15 -1562 ((-887 |#1|) (-887 |#1|) (-1 (-121) |#2|))) (-15 -1562 ((-887 |#1|) (-887 |#1|) (-634 (-1 (-121) |#2|)))) (-15 -1562 ((-887 |#1|) (-887 |#1|) (-634 (-1161)) (-1 (-121) (-634 |#2|)))) (-15 -1392 ((-1 (-121) |#2|) (-887 |#1|))) (-15 -1848 ((-121) |#2| (-887 |#1|))) (-15 -1848 ((-121) (-634 |#2|) (-887 |#1|))) (-15 -2526 ((-887 |#1|) (-887 |#1|) |#2|)) (-15 -4229 ((-634 |#2|) (-887 |#1|)))) (-1090) (-1195)) (T -885)) 
-((-4229 (*1 *2 *3) (-12 (-5 *3 (-887 *4)) (-4 *4 (-1090)) (-5 *2 (-634 *5)) (-5 *1 (-885 *4 *5)) (-4 *5 (-1195)))) (-2526 (*1 *2 *2 *3) (-12 (-5 *2 (-887 *4)) (-4 *4 (-1090)) (-5 *1 (-885 *4 *3)) (-4 *3 (-1195)))) (-1848 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-4 *6 (-1195)) (-5 *2 (-121)) (-5 *1 (-885 *5 *6)))) (-1848 (*1 *2 *3 *4) (-12 (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-5 *2 (-121)) (-5 *1 (-885 *5 *3)) (-4 *3 (-1195)))) (-1392 (*1 *2 *3) (-12 (-5 *3 (-887 *4)) (-4 *4 (-1090)) (-5 *2 (-1 (-121) *5)) (-5 *1 (-885 *4 *5)) (-4 *5 (-1195)))) (-1562 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-887 *5)) (-5 *3 (-634 (-1161))) (-5 *4 (-1 (-121) (-634 *6))) (-4 *5 (-1090)) (-4 *6 (-1195)) (-5 *1 (-885 *5 *6)))) (-1562 (*1 *2 *2 *3) (-12 (-5 *2 (-887 *4)) (-5 *3 (-634 (-1 (-121) *5))) (-4 *4 (-1090)) (-4 *5 (-1195)) (-5 *1 (-885 *4 *5)))) (-1562 (*1 *2 *2 *3) (-12 (-5 *2 (-887 *4)) (-5 *3 (-1 (-121) *5)) (-4 *4 (-1090)) (-4 *5 (-1195)) (-5 *1 (-885 *4 *5))))) 
-(-10 -7 (-15 -1562 ((-887 |#1|) (-887 |#1|) (-1 (-121) |#2|))) (-15 -1562 ((-887 |#1|) (-887 |#1|) (-634 (-1 (-121) |#2|)))) (-15 -1562 ((-887 |#1|) (-887 |#1|) (-634 (-1161)) (-1 (-121) (-634 |#2|)))) (-15 -1392 ((-1 (-121) |#2|) (-887 |#1|))) (-15 -1848 ((-121) |#2| (-887 |#1|))) (-15 -1848 ((-121) (-634 |#2|) (-887 |#1|))) (-15 -2526 ((-887 |#1|) (-887 |#1|) |#2|)) (-15 -4229 ((-634 |#2|) (-887 |#1|)))) 
-((-2795 (((-887 |#2|) (-1 |#2| |#1|) (-887 |#1|)) 17))) 
-(((-886 |#1| |#2|) (-10 -7 (-15 -2795 ((-887 |#2|) (-1 |#2| |#1|) (-887 |#1|)))) (-1090) (-1090)) (T -886)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-887 *6)) (-5 *1 (-886 *5 *6))))) 
-(-10 -7 (-15 -2795 ((-887 |#2|) (-1 |#2| |#1|) (-887 |#1|)))) 
-((-2447 (((-121) $ $) NIL)) (-4239 (($ $ (-634 (-57))) 62)) (-2055 (((-634 $) $) 116)) (-3227 (((-2 (|:| |var| (-634 (-1161))) (|:| |pred| (-57))) $) 22)) (-2500 (((-121) $) 29)) (-2624 (($ $ (-634 (-1161)) (-57)) 24)) (-4015 (($ $ (-634 (-57))) 61)) (-3666 (((-3 |#1| "failed") $) 59) (((-3 (-1161) "failed") $) 138)) (-2854 ((|#1| $) 55) (((-1161) $) NIL)) (-3856 (($ $) 106)) (-3573 (((-121) $) 45)) (-2314 (((-634 (-57)) $) 43)) (-3111 (($ (-1161) (-121) (-121) (-121)) 63)) (-1744 (((-3 (-634 $) "failed") (-634 $)) 70)) (-4462 (((-121) $) 48)) (-4345 (((-121) $) 47)) (-4487 (((-1143) $) NIL)) (-3324 (((-3 (-634 $) "failed") $) 34)) (-2258 (((-3 (-2 (|:| |num| $) (|:| |den| $)) "failed") $) 41)) (-2672 (((-3 (-2 (|:| |val| $) (|:| -3438 $)) "failed") $) 81)) (-1794 (((-3 (-634 $) "failed") $) 31)) (-3004 (((-3 (-634 $) "failed") $ (-123)) 105) (((-3 (-2 (|:| -4192 (-123)) (|:| |arg| (-634 $))) "failed") $) 93)) (-3163 (((-3 (-634 $) "failed") $) 35)) (-3751 (((-3 (-2 (|:| |val| $) (|:| -3438 (-763))) "failed") $) 38)) (-2251 (((-121) $) 28)) (-4022 (((-1108) $) NIL)) (-2201 (((-121) $) 20)) (-3606 (((-121) $) 44)) (-3499 (((-634 (-57)) $) 109)) (-3906 (((-121) $) 46)) (-2779 (($ (-123) (-634 $)) 90)) (-4154 (((-763) $) 27)) (-3863 (($ $) 60)) (-4278 (($ (-634 $)) 57)) (-1867 (((-121) $) 25)) (-2745 (((-850) $) 50) (($ |#1|) 18) (($ (-1161)) 64)) (-2526 (($ $ (-57)) 108)) (-3056 (($) 89 T CONST)) (-1556 (($) 71 T CONST)) (-1717 (((-121) $ $) 77)) (-1779 (($ $ $) 98)) (-1767 (($ $ $) 102)) (** (($ $ (-763)) 97) (($ $ $) 51)) (* (($ $ $) 103))) 
-(((-887 |#1|) (-13 (-1090) (-1037 |#1|) (-1037 (-1161)) (-10 -8 (-15 0 ($) -3495) (-15 1 ($) -3495) (-15 -1794 ((-3 (-634 $) "failed") $)) (-15 -3324 ((-3 (-634 $) "failed") $)) (-15 -3004 ((-3 (-634 $) "failed") $ (-123))) (-15 -3004 ((-3 (-2 (|:| -4192 (-123)) (|:| |arg| (-634 $))) "failed") $)) (-15 -3751 ((-3 (-2 (|:| |val| $) (|:| -3438 (-763))) "failed") $)) (-15 -2258 ((-3 (-2 (|:| |num| $) (|:| |den| $)) "failed") $)) (-15 -3163 ((-3 (-634 $) "failed") $)) (-15 -2672 ((-3 (-2 (|:| |val| $) (|:| -3438 $)) "failed") $)) (-15 -2779 ($ (-123) (-634 $))) (-15 -1767 ($ $ $)) (-15 * ($ $ $)) (-15 ** ($ $ (-763))) (-15 ** ($ $ $)) (-15 -1779 ($ $ $)) (-15 -4154 ((-763) $)) (-15 -4278 ($ (-634 $))) (-15 -3863 ($ $)) (-15 -2251 ((-121) $)) (-15 -3573 ((-121) $)) (-15 -2500 ((-121) $)) (-15 -1867 ((-121) $)) (-15 -3906 ((-121) $)) (-15 -4345 ((-121) $)) (-15 -4462 ((-121) $)) (-15 -3606 ((-121) $)) (-15 -2314 ((-634 (-57)) $)) (-15 -4015 ($ $ (-634 (-57)))) (-15 -4239 ($ $ (-634 (-57)))) (-15 -3111 ($ (-1161) (-121) (-121) (-121))) (-15 -2624 ($ $ (-634 (-1161)) (-57))) (-15 -3227 ((-2 (|:| |var| (-634 (-1161))) (|:| |pred| (-57))) $)) (-15 -2201 ((-121) $)) (-15 -3856 ($ $)) (-15 -2526 ($ $ (-57))) (-15 -3499 ((-634 (-57)) $)) (-15 -2055 ((-634 $) $)) (-15 -1744 ((-3 (-634 $) "failed") (-634 $))))) (-1090)) (T -887)) 
-((-3056 (*1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) (-1556 (*1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) (-1794 (*1 *2 *1) (|partial| -12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-3324 (*1 *2 *1) (|partial| -12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-3004 (*1 *2 *1 *3) (|partial| -12 (-5 *3 (-123)) (-5 *2 (-634 (-887 *4))) (-5 *1 (-887 *4)) (-4 *4 (-1090)))) (-3004 (*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| -4192 (-123)) (|:| |arg| (-634 (-887 *3))))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-3751 (*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |val| (-887 *3)) (|:| -3438 (-763)))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-2258 (*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |num| (-887 *3)) (|:| |den| (-887 *3)))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-3163 (*1 *2 *1) (|partial| -12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-2672 (*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |val| (-887 *3)) (|:| -3438 (-887 *3)))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-2779 (*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-634 (-887 *4))) (-5 *1 (-887 *4)) (-4 *4 (-1090)))) (-1767 (*1 *1 *1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) (* (*1 *1 *1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (** (*1 *1 *1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) (-1779 (*1 *1 *1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) (-4154 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-4278 (*1 *1 *2) (-12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-3863 (*1 *1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) (-2251 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-3573 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-2500 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-1867 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-3906 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-4345 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-4462 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-3606 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-2314 (*1 *2 *1) (-12 (-5 *2 (-634 (-57))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-4015 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-57))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-4239 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-57))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-3111 (*1 *1 *2 *3 *3 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-121)) (-5 *1 (-887 *4)) (-4 *4 (-1090)))) (-2624 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-57)) (-5 *1 (-887 *4)) (-4 *4 (-1090)))) (-3227 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |var| (-634 (-1161))) (|:| |pred| (-57)))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-2201 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-3856 (*1 *1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) (-2526 (*1 *1 *1 *2) (-12 (-5 *2 (-57)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-3499 (*1 *2 *1) (-12 (-5 *2 (-634 (-57))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-2055 (*1 *2 *1) (-12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-1744 (*1 *2 *2) (|partial| -12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
-(-13 (-1090) (-1037 |#1|) (-1037 (-1161)) (-10 -8 (-15 (-3056) ($) -3495) (-15 (-1556) ($) -3495) (-15 -1794 ((-3 (-634 $) "failed") $)) (-15 -3324 ((-3 (-634 $) "failed") $)) (-15 -3004 ((-3 (-634 $) "failed") $ (-123))) (-15 -3004 ((-3 (-2 (|:| -4192 (-123)) (|:| |arg| (-634 $))) "failed") $)) (-15 -3751 ((-3 (-2 (|:| |val| $) (|:| -3438 (-763))) "failed") $)) (-15 -2258 ((-3 (-2 (|:| |num| $) (|:| |den| $)) "failed") $)) (-15 -3163 ((-3 (-634 $) "failed") $)) (-15 -2672 ((-3 (-2 (|:| |val| $) (|:| -3438 $)) "failed") $)) (-15 -2779 ($ (-123) (-634 $))) (-15 -1767 ($ $ $)) (-15 * ($ $ $)) (-15 ** ($ $ (-763))) (-15 ** ($ $ $)) (-15 -1779 ($ $ $)) (-15 -4154 ((-763) $)) (-15 -4278 ($ (-634 $))) (-15 -3863 ($ $)) (-15 -2251 ((-121) $)) (-15 -3573 ((-121) $)) (-15 -2500 ((-121) $)) (-15 -1867 ((-121) $)) (-15 -3906 ((-121) $)) (-15 -4345 ((-121) $)) (-15 -4462 ((-121) $)) (-15 -3606 ((-121) $)) (-15 -2314 ((-634 (-57)) $)) (-15 -4015 ($ $ (-634 (-57)))) (-15 -4239 ($ $ (-634 (-57)))) (-15 -3111 ($ (-1161) (-121) (-121) (-121))) (-15 -2624 ($ $ (-634 (-1161)) (-57))) (-15 -3227 ((-2 (|:| |var| (-634 (-1161))) (|:| |pred| (-57))) $)) (-15 -2201 ((-121) $)) (-15 -3856 ($ $)) (-15 -2526 ($ $ (-57))) (-15 -3499 ((-634 (-57)) $)) (-15 -2055 ((-634 $) $)) (-15 -1744 ((-3 (-634 $) "failed") (-634 $))))) 
-((-2447 (((-121) $ $) NIL)) (-3595 (((-634 |#1|) $) 16)) (-3374 (((-121) $) 38)) (-3666 (((-3 (-663 |#1|) "failed") $) 41)) (-2854 (((-663 |#1|) $) 39)) (-3935 (($ $) 18)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-4297 (((-634 (-663 |#1|)) $) 23)) (-3678 (((-763) $) 45)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-3876 (((-663 |#1|) $) 17)) (-2745 (((-850) $) 37) (($ (-663 |#1|)) 21) (((-814 |#1|) $) 27) (($ |#1|) 20)) (-1556 (($) 8 T CONST)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 11)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 48))) 
-(((-888 |#1|) (-13 (-842) (-1037 (-663 |#1|)) (-10 -8 (-15 1 ($) -3495) (-15 -2745 ((-814 |#1|) $)) (-15 -2745 ($ |#1|)) (-15 -3876 ((-663 |#1|) $)) (-15 -3678 ((-763) $)) (-15 -4297 ((-634 (-663 |#1|)) $)) (-15 -3935 ($ $)) (-15 -3374 ((-121) $)) (-15 -3595 ((-634 |#1|) $)))) (-842)) (T -888)) 
-((-1556 (*1 *1) (-12 (-5 *1 (-888 *2)) (-4 *2 (-842)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-814 *3)) (-5 *1 (-888 *3)) (-4 *3 (-842)))) (-2745 (*1 *1 *2) (-12 (-5 *1 (-888 *2)) (-4 *2 (-842)))) (-3876 (*1 *2 *1) (-12 (-5 *2 (-663 *3)) (-5 *1 (-888 *3)) (-4 *3 (-842)))) (-3678 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-888 *3)) (-4 *3 (-842)))) (-4297 (*1 *2 *1) (-12 (-5 *2 (-634 (-663 *3))) (-5 *1 (-888 *3)) (-4 *3 (-842)))) (-3935 (*1 *1 *1) (-12 (-5 *1 (-888 *2)) (-4 *2 (-842)))) (-3374 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-888 *3)) (-4 *3 (-842)))) (-3595 (*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-888 *3)) (-4 *3 (-842))))) 
-(-13 (-842) (-1037 (-663 |#1|)) (-10 -8 (-15 (-1556) ($) -3495) (-15 -2745 ((-814 |#1|) $)) (-15 -2745 ($ |#1|)) (-15 -3876 ((-663 |#1|) $)) (-15 -3678 ((-763) $)) (-15 -4297 ((-634 (-663 |#1|)) $)) (-15 -3935 ($ $)) (-15 -3374 ((-121) $)) (-15 -3595 ((-634 |#1|) $)))) 
-((-1474 ((|#1| |#1| |#1|) 19))) 
-(((-889 |#1| |#2|) (-10 -7 (-15 -1474 (|#1| |#1| |#1|))) (-1219 |#2|) (-1047)) (T -889)) 
-((-1474 (*1 *2 *2 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-889 *2 *3)) (-4 *2 (-1219 *3))))) 
-(-10 -7 (-15 -1474 (|#1| |#1| |#1|))) 
-((-2447 (((-121) $ $) 7)) (-3029 (((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) 13)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-4030 (((-1035) (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) 12)) (-1717 (((-121) $ $) 6))) 
+((-3910 (((-121) (-634 |#2|) |#3|) 22) (((-121) |#2| |#3|) 17)) (-1582 (((-884 |#1| |#2|) |#2| |#3|) 42 (-12 (-3046 (|has| |#2| (-1037 (-1161)))) (-3046 (|has| |#2| (-1047))))) (((-634 (-288 (-953 |#2|))) |#2| |#3|) 41 (-12 (|has| |#2| (-1047)) (-3046 (|has| |#2| (-1037 (-1161)))))) (((-634 (-288 |#2|)) |#2| |#3|) 34 (|has| |#2| (-1037 (-1161)))) (((-880 |#1| |#2| (-634 |#2|)) (-634 |#2|) |#3|) 20))) 
+(((-882 |#1| |#2| |#3|) (-10 -7 (-15 -3910 ((-121) |#2| |#3|)) (-15 -3910 ((-121) (-634 |#2|) |#3|)) (-15 -1582 ((-880 |#1| |#2| (-634 |#2|)) (-634 |#2|) |#3|)) (IF (|has| |#2| (-1037 (-1161))) (-15 -1582 ((-634 (-288 |#2|)) |#2| |#3|)) (IF (|has| |#2| (-1047)) (-15 -1582 ((-634 (-288 (-953 |#2|))) |#2| |#3|)) (-15 -1582 ((-884 |#1| |#2|) |#2| |#3|))))) (-1090) (-881 |#1|) (-609 (-887 |#1|))) (T -882)) 
+((-1582 (*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-5 *2 (-884 *5 *3)) (-5 *1 (-882 *5 *3 *4)) (-3046 (-4 *3 (-1037 (-1161)))) (-3046 (-4 *3 (-1047))) (-4 *3 (-881 *5)) (-4 *4 (-609 (-887 *5))))) (-1582 (*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-5 *2 (-634 (-288 (-953 *3)))) (-5 *1 (-882 *5 *3 *4)) (-4 *3 (-1047)) (-3046 (-4 *3 (-1037 (-1161)))) (-4 *3 (-881 *5)) (-4 *4 (-609 (-887 *5))))) (-1582 (*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-5 *2 (-634 (-288 *3))) (-5 *1 (-882 *5 *3 *4)) (-4 *3 (-1037 (-1161))) (-4 *3 (-881 *5)) (-4 *4 (-609 (-887 *5))))) (-1582 (*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-4 *6 (-881 *5)) (-5 *2 (-880 *5 *6 (-634 *6))) (-5 *1 (-882 *5 *6 *4)) (-5 *3 (-634 *6)) (-4 *4 (-609 (-887 *5))))) (-3910 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-4 *6 (-881 *5)) (-4 *5 (-1090)) (-5 *2 (-121)) (-5 *1 (-882 *5 *6 *4)) (-4 *4 (-609 (-887 *5))))) (-3910 (*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-5 *2 (-121)) (-5 *1 (-882 *5 *3 *4)) (-4 *3 (-881 *5)) (-4 *4 (-609 (-887 *5)))))) 
+(-10 -7 (-15 -3910 ((-121) |#2| |#3|)) (-15 -3910 ((-121) (-634 |#2|) |#3|)) (-15 -1582 ((-880 |#1| |#2| (-634 |#2|)) (-634 |#2|) |#3|)) (IF (|has| |#2| (-1037 (-1161))) (-15 -1582 ((-634 (-288 |#2|)) |#2| |#3|)) (IF (|has| |#2| (-1047)) (-15 -1582 ((-634 (-288 (-953 |#2|))) |#2| |#3|)) (-15 -1582 ((-884 |#1| |#2|) |#2| |#3|))))) 
+((-2797 (((-884 |#1| |#3|) (-1 |#3| |#2|) (-884 |#1| |#2|)) 21))) 
+(((-883 |#1| |#2| |#3|) (-10 -7 (-15 -2797 ((-884 |#1| |#3|) (-1 |#3| |#2|) (-884 |#1| |#2|)))) (-1090) (-1090) (-1090)) (T -883)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-884 *5 *6)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-884 *5 *7)) (-5 *1 (-883 *5 *6 *7))))) 
+(-10 -7 (-15 -2797 ((-884 |#1| |#3|) (-1 |#3| |#2|) (-884 |#1| |#2|)))) 
+((-2449 (((-121) $ $) NIL)) (-1793 (($ $ $) 37)) (-2388 (((-3 (-121) "failed") $ (-887 |#1|)) 34)) (-1851 (($) 11)) (-1893 (((-1143) $) NIL)) (-4367 (($ (-887 |#1|) |#2| $) 20)) (-4025 (((-1108) $) NIL)) (-4414 (((-3 |#2| "failed") (-887 |#1|) $) 48)) (-4229 (((-121) $) 14)) (-3485 (($) 12)) (-2045 (((-634 (-2 (|:| -3651 (-1161)) (|:| -4085 |#2|))) $) 25)) (-4289 (($ (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 |#2|)))) 23)) (-2747 (((-850) $) 42)) (-3622 (($ (-887 |#1|) |#2| $ |#2|) 46)) (-3737 (($ (-887 |#1|) |#2| $) 45)) (-1719 (((-121) $ $) 39))) 
+(((-884 |#1| |#2|) (-13 (-1090) (-10 -8 (-15 -4229 ((-121) $)) (-15 -3485 ($)) (-15 -1851 ($)) (-15 -1793 ($ $ $)) (-15 -4414 ((-3 |#2| "failed") (-887 |#1|) $)) (-15 -3737 ($ (-887 |#1|) |#2| $)) (-15 -4367 ($ (-887 |#1|) |#2| $)) (-15 -3622 ($ (-887 |#1|) |#2| $ |#2|)) (-15 -2045 ((-634 (-2 (|:| -3651 (-1161)) (|:| -4085 |#2|))) $)) (-15 -4289 ($ (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 |#2|))))) (-15 -2388 ((-3 (-121) "failed") $ (-887 |#1|))))) (-1090) (-1090)) (T -884)) 
+((-4229 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-884 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)))) (-3485 (*1 *1) (-12 (-5 *1 (-884 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090)))) (-1851 (*1 *1) (-12 (-5 *1 (-884 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090)))) (-1793 (*1 *1 *1 *1) (-12 (-5 *1 (-884 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090)))) (-4414 (*1 *2 *3 *1) (|partial| -12 (-5 *3 (-887 *4)) (-4 *4 (-1090)) (-4 *2 (-1090)) (-5 *1 (-884 *4 *2)))) (-3737 (*1 *1 *2 *3 *1) (-12 (-5 *2 (-887 *4)) (-4 *4 (-1090)) (-5 *1 (-884 *4 *3)) (-4 *3 (-1090)))) (-4367 (*1 *1 *2 *3 *1) (-12 (-5 *2 (-887 *4)) (-4 *4 (-1090)) (-5 *1 (-884 *4 *3)) (-4 *3 (-1090)))) (-3622 (*1 *1 *2 *3 *1 *3) (-12 (-5 *2 (-887 *4)) (-4 *4 (-1090)) (-5 *1 (-884 *4 *3)) (-4 *3 (-1090)))) (-2045 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 *4)))) (-5 *1 (-884 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)))) (-4289 (*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 *4)))) (-4 *4 (-1090)) (-5 *1 (-884 *3 *4)) (-4 *3 (-1090)))) (-2388 (*1 *2 *1 *3) (|partial| -12 (-5 *3 (-887 *4)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-884 *4 *5)) (-4 *5 (-1090))))) 
+(-13 (-1090) (-10 -8 (-15 -4229 ((-121) $)) (-15 -3485 ($)) (-15 -1851 ($)) (-15 -1793 ($ $ $)) (-15 -4414 ((-3 |#2| "failed") (-887 |#1|) $)) (-15 -3737 ($ (-887 |#1|) |#2| $)) (-15 -4367 ($ (-887 |#1|) |#2| $)) (-15 -3622 ($ (-887 |#1|) |#2| $ |#2|)) (-15 -2045 ((-634 (-2 (|:| -3651 (-1161)) (|:| -4085 |#2|))) $)) (-15 -4289 ($ (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 |#2|))))) (-15 -2388 ((-3 (-121) "failed") $ (-887 |#1|))))) 
+((-1563 (((-887 |#1|) (-887 |#1|) (-634 (-1161)) (-1 (-121) (-634 |#2|))) 30) (((-887 |#1|) (-887 |#1|) (-634 (-1 (-121) |#2|))) 42) (((-887 |#1|) (-887 |#1|) (-1 (-121) |#2|)) 33)) (-2388 (((-121) (-634 |#2|) (-887 |#1|)) 39) (((-121) |#2| (-887 |#1|)) 35)) (-3991 (((-1 (-121) |#2|) (-887 |#1|)) 14)) (-4238 (((-634 |#2|) (-887 |#1|)) 23)) (-1763 (((-887 |#1|) (-887 |#1|) |#2|) 19))) 
+(((-885 |#1| |#2|) (-10 -7 (-15 -1563 ((-887 |#1|) (-887 |#1|) (-1 (-121) |#2|))) (-15 -1563 ((-887 |#1|) (-887 |#1|) (-634 (-1 (-121) |#2|)))) (-15 -1563 ((-887 |#1|) (-887 |#1|) (-634 (-1161)) (-1 (-121) (-634 |#2|)))) (-15 -3991 ((-1 (-121) |#2|) (-887 |#1|))) (-15 -2388 ((-121) |#2| (-887 |#1|))) (-15 -2388 ((-121) (-634 |#2|) (-887 |#1|))) (-15 -1763 ((-887 |#1|) (-887 |#1|) |#2|)) (-15 -4238 ((-634 |#2|) (-887 |#1|)))) (-1090) (-1195)) (T -885)) 
+((-4238 (*1 *2 *3) (-12 (-5 *3 (-887 *4)) (-4 *4 (-1090)) (-5 *2 (-634 *5)) (-5 *1 (-885 *4 *5)) (-4 *5 (-1195)))) (-1763 (*1 *2 *2 *3) (-12 (-5 *2 (-887 *4)) (-4 *4 (-1090)) (-5 *1 (-885 *4 *3)) (-4 *3 (-1195)))) (-2388 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-4 *6 (-1195)) (-5 *2 (-121)) (-5 *1 (-885 *5 *6)))) (-2388 (*1 *2 *3 *4) (-12 (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-5 *2 (-121)) (-5 *1 (-885 *5 *3)) (-4 *3 (-1195)))) (-3991 (*1 *2 *3) (-12 (-5 *3 (-887 *4)) (-4 *4 (-1090)) (-5 *2 (-1 (-121) *5)) (-5 *1 (-885 *4 *5)) (-4 *5 (-1195)))) (-1563 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-887 *5)) (-5 *3 (-634 (-1161))) (-5 *4 (-1 (-121) (-634 *6))) (-4 *5 (-1090)) (-4 *6 (-1195)) (-5 *1 (-885 *5 *6)))) (-1563 (*1 *2 *2 *3) (-12 (-5 *2 (-887 *4)) (-5 *3 (-634 (-1 (-121) *5))) (-4 *4 (-1090)) (-4 *5 (-1195)) (-5 *1 (-885 *4 *5)))) (-1563 (*1 *2 *2 *3) (-12 (-5 *2 (-887 *4)) (-5 *3 (-1 (-121) *5)) (-4 *4 (-1090)) (-4 *5 (-1195)) (-5 *1 (-885 *4 *5))))) 
+(-10 -7 (-15 -1563 ((-887 |#1|) (-887 |#1|) (-1 (-121) |#2|))) (-15 -1563 ((-887 |#1|) (-887 |#1|) (-634 (-1 (-121) |#2|)))) (-15 -1563 ((-887 |#1|) (-887 |#1|) (-634 (-1161)) (-1 (-121) (-634 |#2|)))) (-15 -3991 ((-1 (-121) |#2|) (-887 |#1|))) (-15 -2388 ((-121) |#2| (-887 |#1|))) (-15 -2388 ((-121) (-634 |#2|) (-887 |#1|))) (-15 -1763 ((-887 |#1|) (-887 |#1|) |#2|)) (-15 -4238 ((-634 |#2|) (-887 |#1|)))) 
+((-2797 (((-887 |#2|) (-1 |#2| |#1|) (-887 |#1|)) 17))) 
+(((-886 |#1| |#2|) (-10 -7 (-15 -2797 ((-887 |#2|) (-1 |#2| |#1|) (-887 |#1|)))) (-1090) (-1090)) (T -886)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-887 *6)) (-5 *1 (-886 *5 *6))))) 
+(-10 -7 (-15 -2797 ((-887 |#2|) (-1 |#2| |#1|) (-887 |#1|)))) 
+((-2449 (((-121) $ $) NIL)) (-2832 (($ $ (-634 (-57))) 62)) (-2057 (((-634 $) $) 116)) (-1921 (((-2 (|:| |var| (-634 (-1161))) (|:| |pred| (-57))) $) 22)) (-1623 (((-121) $) 29)) (-4224 (($ $ (-634 (-1161)) (-57)) 24)) (-1408 (($ $ (-634 (-57))) 61)) (-3668 (((-3 |#1| "failed") $) 59) (((-3 (-1161) "failed") $) 138)) (-2857 ((|#1| $) 55) (((-1161) $) NIL)) (-1917 (($ $) 106)) (-2900 (((-121) $) 45)) (-3741 (((-634 (-57)) $) 43)) (-2561 (($ (-1161) (-121) (-121) (-121)) 63)) (-3827 (((-3 (-634 $) "failed") (-634 $)) 70)) (-1776 (((-121) $) 48)) (-3220 (((-121) $) 47)) (-1893 (((-1143) $) NIL)) (-4362 (((-3 (-634 $) "failed") $) 34)) (-2260 (((-3 (-2 (|:| |num| $) (|:| |den| $)) "failed") $) 41)) (-4495 (((-3 (-2 (|:| |val| $) (|:| -3483 $)) "failed") $) 81)) (-2112 (((-3 (-634 $) "failed") $) 31)) (-3165 (((-3 (-634 $) "failed") $ (-123)) 105) (((-3 (-2 (|:| -4194 (-123)) (|:| |arg| (-634 $))) "failed") $) 93)) (-1663 (((-3 (-634 $) "failed") $) 35)) (-2617 (((-3 (-2 (|:| |val| $) (|:| -3483 (-763))) "failed") $) 38)) (-3271 (((-121) $) 28)) (-4025 (((-1108) $) NIL)) (-3113 (((-121) $) 20)) (-3028 (((-121) $) 44)) (-3905 (((-634 (-57)) $) 109)) (-2098 (((-121) $) 46)) (-2781 (($ (-123) (-634 $)) 90)) (-4156 (((-763) $) 27)) (-3865 (($ $) 60)) (-4280 (($ (-634 $)) 57)) (-2475 (((-121) $) 25)) (-2747 (((-850) $) 50) (($ |#1|) 18) (($ (-1161)) 64)) (-1763 (($ $ (-57)) 108)) (-3058 (($) 89 T CONST)) (-1557 (($) 71 T CONST)) (-1719 (((-121) $ $) 77)) (-1781 (($ $ $) 98)) (-1769 (($ $ $) 102)) (** (($ $ (-763)) 97) (($ $ $) 51)) (* (($ $ $) 103))) 
+(((-887 |#1|) (-13 (-1090) (-1037 |#1|) (-1037 (-1161)) (-10 -8 (-15 0 ($) -3497) (-15 1 ($) -3497) (-15 -2112 ((-3 (-634 $) "failed") $)) (-15 -4362 ((-3 (-634 $) "failed") $)) (-15 -3165 ((-3 (-634 $) "failed") $ (-123))) (-15 -3165 ((-3 (-2 (|:| -4194 (-123)) (|:| |arg| (-634 $))) "failed") $)) (-15 -2617 ((-3 (-2 (|:| |val| $) (|:| -3483 (-763))) "failed") $)) (-15 -2260 ((-3 (-2 (|:| |num| $) (|:| |den| $)) "failed") $)) (-15 -1663 ((-3 (-634 $) "failed") $)) (-15 -4495 ((-3 (-2 (|:| |val| $) (|:| -3483 $)) "failed") $)) (-15 -2781 ($ (-123) (-634 $))) (-15 -1769 ($ $ $)) (-15 * ($ $ $)) (-15 ** ($ $ (-763))) (-15 ** ($ $ $)) (-15 -1781 ($ $ $)) (-15 -4156 ((-763) $)) (-15 -4280 ($ (-634 $))) (-15 -3865 ($ $)) (-15 -3271 ((-121) $)) (-15 -2900 ((-121) $)) (-15 -1623 ((-121) $)) (-15 -2475 ((-121) $)) (-15 -2098 ((-121) $)) (-15 -3220 ((-121) $)) (-15 -1776 ((-121) $)) (-15 -3028 ((-121) $)) (-15 -3741 ((-634 (-57)) $)) (-15 -1408 ($ $ (-634 (-57)))) (-15 -2832 ($ $ (-634 (-57)))) (-15 -2561 ($ (-1161) (-121) (-121) (-121))) (-15 -4224 ($ $ (-634 (-1161)) (-57))) (-15 -1921 ((-2 (|:| |var| (-634 (-1161))) (|:| |pred| (-57))) $)) (-15 -3113 ((-121) $)) (-15 -1917 ($ $)) (-15 -1763 ($ $ (-57))) (-15 -3905 ((-634 (-57)) $)) (-15 -2057 ((-634 $) $)) (-15 -3827 ((-3 (-634 $) "failed") (-634 $))))) (-1090)) (T -887)) 
+((-3058 (*1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) (-1557 (*1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) (-2112 (*1 *2 *1) (|partial| -12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-4362 (*1 *2 *1) (|partial| -12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-3165 (*1 *2 *1 *3) (|partial| -12 (-5 *3 (-123)) (-5 *2 (-634 (-887 *4))) (-5 *1 (-887 *4)) (-4 *4 (-1090)))) (-3165 (*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| -4194 (-123)) (|:| |arg| (-634 (-887 *3))))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-2617 (*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |val| (-887 *3)) (|:| -3483 (-763)))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-2260 (*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |num| (-887 *3)) (|:| |den| (-887 *3)))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-1663 (*1 *2 *1) (|partial| -12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-4495 (*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |val| (-887 *3)) (|:| -3483 (-887 *3)))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-2781 (*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-634 (-887 *4))) (-5 *1 (-887 *4)) (-4 *4 (-1090)))) (-1769 (*1 *1 *1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) (* (*1 *1 *1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (** (*1 *1 *1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) (-1781 (*1 *1 *1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) (-4156 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-4280 (*1 *1 *2) (-12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-3865 (*1 *1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) (-3271 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-2900 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-1623 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-2475 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-2098 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-3220 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-1776 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-3028 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-3741 (*1 *2 *1) (-12 (-5 *2 (-634 (-57))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-1408 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-57))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-2832 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-57))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-2561 (*1 *1 *2 *3 *3 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-121)) (-5 *1 (-887 *4)) (-4 *4 (-1090)))) (-4224 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-57)) (-5 *1 (-887 *4)) (-4 *4 (-1090)))) (-1921 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |var| (-634 (-1161))) (|:| |pred| (-57)))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-3113 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-1917 (*1 *1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) (-1763 (*1 *1 *1 *2) (-12 (-5 *2 (-57)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-3905 (*1 *2 *1) (-12 (-5 *2 (-634 (-57))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-2057 (*1 *2 *1) (-12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) (-3827 (*1 *2 *2) (|partial| -12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
+(-13 (-1090) (-1037 |#1|) (-1037 (-1161)) (-10 -8 (-15 (-3058) ($) -3497) (-15 (-1557) ($) -3497) (-15 -2112 ((-3 (-634 $) "failed") $)) (-15 -4362 ((-3 (-634 $) "failed") $)) (-15 -3165 ((-3 (-634 $) "failed") $ (-123))) (-15 -3165 ((-3 (-2 (|:| -4194 (-123)) (|:| |arg| (-634 $))) "failed") $)) (-15 -2617 ((-3 (-2 (|:| |val| $) (|:| -3483 (-763))) "failed") $)) (-15 -2260 ((-3 (-2 (|:| |num| $) (|:| |den| $)) "failed") $)) (-15 -1663 ((-3 (-634 $) "failed") $)) (-15 -4495 ((-3 (-2 (|:| |val| $) (|:| -3483 $)) "failed") $)) (-15 -2781 ($ (-123) (-634 $))) (-15 -1769 ($ $ $)) (-15 * ($ $ $)) (-15 ** ($ $ (-763))) (-15 ** ($ $ $)) (-15 -1781 ($ $ $)) (-15 -4156 ((-763) $)) (-15 -4280 ($ (-634 $))) (-15 -3865 ($ $)) (-15 -3271 ((-121) $)) (-15 -2900 ((-121) $)) (-15 -1623 ((-121) $)) (-15 -2475 ((-121) $)) (-15 -2098 ((-121) $)) (-15 -3220 ((-121) $)) (-15 -1776 ((-121) $)) (-15 -3028 ((-121) $)) (-15 -3741 ((-634 (-57)) $)) (-15 -1408 ($ $ (-634 (-57)))) (-15 -2832 ($ $ (-634 (-57)))) (-15 -2561 ($ (-1161) (-121) (-121) (-121))) (-15 -4224 ($ $ (-634 (-1161)) (-57))) (-15 -1921 ((-2 (|:| |var| (-634 (-1161))) (|:| |pred| (-57))) $)) (-15 -3113 ((-121) $)) (-15 -1917 ($ $)) (-15 -1763 ($ $ (-57))) (-15 -3905 ((-634 (-57)) $)) (-15 -2057 ((-634 $) $)) (-15 -3827 ((-3 (-634 $) "failed") (-634 $))))) 
+((-2449 (((-121) $ $) NIL)) (-2981 (((-634 |#1|) $) 16)) (-1407 (((-121) $) 38)) (-3668 (((-3 (-663 |#1|) "failed") $) 41)) (-2857 (((-663 |#1|) $) 39)) (-3936 (($ $) 18)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-3016 (((-634 (-663 |#1|)) $) 23)) (-3680 (((-763) $) 45)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-3877 (((-663 |#1|) $) 17)) (-2747 (((-850) $) 37) (($ (-663 |#1|)) 21) (((-814 |#1|) $) 27) (($ |#1|) 20)) (-1557 (($) 8 T CONST)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 11)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 48))) 
+(((-888 |#1|) (-13 (-842) (-1037 (-663 |#1|)) (-10 -8 (-15 1 ($) -3497) (-15 -2747 ((-814 |#1|) $)) (-15 -2747 ($ |#1|)) (-15 -3877 ((-663 |#1|) $)) (-15 -3680 ((-763) $)) (-15 -3016 ((-634 (-663 |#1|)) $)) (-15 -3936 ($ $)) (-15 -1407 ((-121) $)) (-15 -2981 ((-634 |#1|) $)))) (-842)) (T -888)) 
+((-1557 (*1 *1) (-12 (-5 *1 (-888 *2)) (-4 *2 (-842)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-814 *3)) (-5 *1 (-888 *3)) (-4 *3 (-842)))) (-2747 (*1 *1 *2) (-12 (-5 *1 (-888 *2)) (-4 *2 (-842)))) (-3877 (*1 *2 *1) (-12 (-5 *2 (-663 *3)) (-5 *1 (-888 *3)) (-4 *3 (-842)))) (-3680 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-888 *3)) (-4 *3 (-842)))) (-3016 (*1 *2 *1) (-12 (-5 *2 (-634 (-663 *3))) (-5 *1 (-888 *3)) (-4 *3 (-842)))) (-3936 (*1 *1 *1) (-12 (-5 *1 (-888 *2)) (-4 *2 (-842)))) (-1407 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-888 *3)) (-4 *3 (-842)))) (-2981 (*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-888 *3)) (-4 *3 (-842))))) 
+(-13 (-842) (-1037 (-663 |#1|)) (-10 -8 (-15 (-1557) ($) -3497) (-15 -2747 ((-814 |#1|) $)) (-15 -2747 ($ |#1|)) (-15 -3877 ((-663 |#1|) $)) (-15 -3680 ((-763) $)) (-15 -3016 ((-634 (-663 |#1|)) $)) (-15 -3936 ($ $)) (-15 -1407 ((-121) $)) (-15 -2981 ((-634 |#1|) $)))) 
+((-2480 ((|#1| |#1| |#1|) 19))) 
+(((-889 |#1| |#2|) (-10 -7 (-15 -2480 (|#1| |#1| |#1|))) (-1219 |#2|) (-1047)) (T -889)) 
+((-2480 (*1 *2 *2 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-889 *2 *3)) (-4 *2 (-1219 *3))))) 
+(-10 -7 (-15 -2480 (|#1| |#1| |#1|))) 
+((-2449 (((-121) $ $) 7)) (-3031 (((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) 13)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-1476 (((-1035) (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) 12)) (-1719 (((-121) $ $) 6))) 
 (((-890) (-1275)) (T -890)) 
-((-3029 (*1 *2 *3 *4) (-12 (-4 *1 (-890)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) (-5 *2 (-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)))))) (-4030 (*1 *2 *3) (-12 (-4 *1 (-890)) (-5 *3 (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) (-5 *2 (-1035))))) 
-(-13 (-1090) (-10 -7 (-15 -3029 ((-2 (|:| -3029 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215))))) (-15 -4030 ((-1035) (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215))))))) 
+((-3031 (*1 *2 *3 *4) (-12 (-4 *1 (-890)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) (-5 *2 (-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)))))) (-1476 (*1 *2 *3) (-12 (-4 *1 (-890)) (-5 *3 (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) (-5 *2 (-1035))))) 
+(-13 (-1090) (-10 -7 (-15 -3031 ((-2 (|:| -3031 (-381)) (|:| |explanations| (-1143))) (-1059) (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215))))) (-15 -1476 ((-1035) (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215))))))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-4303 ((|#1| |#1| (-763)) 23)) (-3386 (((-3 |#1| "failed") |#1| |#1|) 22)) (-2847 (((-3 (-2 (|:| -3028 |#1|) (|:| -3284 |#1|)) "failed") |#1| (-763) (-763)) 26) (((-634 |#1|) |#1|) 28))) 
-(((-891 |#1| |#2|) (-10 -7 (-15 -2847 ((-634 |#1|) |#1|)) (-15 -2847 ((-3 (-2 (|:| -3028 |#1|) (|:| -3284 |#1|)) "failed") |#1| (-763) (-763))) (-15 -3386 ((-3 |#1| "failed") |#1| |#1|)) (-15 -4303 (|#1| |#1| (-763)))) (-1219 |#2|) (-365)) (T -891)) 
-((-4303 (*1 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-365)) (-5 *1 (-891 *2 *4)) (-4 *2 (-1219 *4)))) (-3386 (*1 *2 *2 *2) (|partial| -12 (-4 *3 (-365)) (-5 *1 (-891 *2 *3)) (-4 *2 (-1219 *3)))) (-2847 (*1 *2 *3 *4 *4) (|partial| -12 (-5 *4 (-763)) (-4 *5 (-365)) (-5 *2 (-2 (|:| -3028 *3) (|:| -3284 *3))) (-5 *1 (-891 *3 *5)) (-4 *3 (-1219 *5)))) (-2847 (*1 *2 *3) (-12 (-4 *4 (-365)) (-5 *2 (-634 *3)) (-5 *1 (-891 *3 *4)) (-4 *3 (-1219 *4))))) 
-(-10 -7 (-15 -2847 ((-634 |#1|) |#1|)) (-15 -2847 ((-3 (-2 (|:| -3028 |#1|) (|:| -3284 |#1|)) "failed") |#1| (-763) (-763))) (-15 -3386 ((-3 |#1| "failed") |#1| |#1|)) (-15 -4303 (|#1| |#1| (-763)))) 
-((-4351 (((-1035) (-381) (-381) (-381) (-381) (-763) (-763) (-634 (-310 (-381))) (-634 (-634 (-310 (-381)))) (-1143)) 92) (((-1035) (-381) (-381) (-381) (-381) (-763) (-763) (-634 (-310 (-381))) (-634 (-634 (-310 (-381)))) (-1143) (-215)) 87) (((-1035) (-893) (-1059)) 76) (((-1035) (-893)) 77)) (-3029 (((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143)))) (-893) (-1059)) 50) (((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143)))) (-893)) 52))) 
-(((-892) (-10 -7 (-15 -4351 ((-1035) (-893))) (-15 -4351 ((-1035) (-893) (-1059))) (-15 -4351 ((-1035) (-381) (-381) (-381) (-381) (-763) (-763) (-634 (-310 (-381))) (-634 (-634 (-310 (-381)))) (-1143) (-215))) (-15 -4351 ((-1035) (-381) (-381) (-381) (-381) (-763) (-763) (-634 (-310 (-381))) (-634 (-634 (-310 (-381)))) (-1143))) (-15 -3029 ((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143)))) (-893))) (-15 -3029 ((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143)))) (-893) (-1059))))) (T -892)) 
-((-3029 (*1 *2 *3 *4) (-12 (-5 *3 (-893)) (-5 *4 (-1059)) (-5 *2 (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-892)))) (-3029 (*1 *2 *3) (-12 (-5 *3 (-893)) (-5 *2 (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-892)))) (-4351 (*1 *2 *3 *3 *3 *3 *4 *4 *5 *6 *7) (-12 (-5 *4 (-763)) (-5 *6 (-634 (-634 (-310 *3)))) (-5 *7 (-1143)) (-5 *5 (-634 (-310 (-381)))) (-5 *3 (-381)) (-5 *2 (-1035)) (-5 *1 (-892)))) (-4351 (*1 *2 *3 *3 *3 *3 *4 *4 *5 *6 *7 *8) (-12 (-5 *4 (-763)) (-5 *6 (-634 (-634 (-310 *3)))) (-5 *7 (-1143)) (-5 *8 (-215)) (-5 *5 (-634 (-310 (-381)))) (-5 *3 (-381)) (-5 *2 (-1035)) (-5 *1 (-892)))) (-4351 (*1 *2 *3 *4) (-12 (-5 *3 (-893)) (-5 *4 (-1059)) (-5 *2 (-1035)) (-5 *1 (-892)))) (-4351 (*1 *2 *3) (-12 (-5 *3 (-893)) (-5 *2 (-1035)) (-5 *1 (-892))))) 
-(-10 -7 (-15 -4351 ((-1035) (-893))) (-15 -4351 ((-1035) (-893) (-1059))) (-15 -4351 ((-1035) (-381) (-381) (-381) (-381) (-763) (-763) (-634 (-310 (-381))) (-634 (-634 (-310 (-381)))) (-1143) (-215))) (-15 -4351 ((-1035) (-381) (-381) (-381) (-381) (-763) (-763) (-634 (-310 (-381))) (-634 (-634 (-310 (-381)))) (-1143))) (-15 -3029 ((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143)))) (-893))) (-15 -3029 ((-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143)))) (-893) (-1059)))) 
-((-2447 (((-121) $ $) NIL)) (-2854 (((-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215))) $) 10)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 12) (($ (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) 9)) (-1717 (((-121) $ $) NIL))) 
-(((-893) (-13 (-1090) (-10 -8 (-15 -2745 ($ (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215))))) (-15 -2745 ((-850) $)) (-15 -2854 ((-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215))) $))))) (T -893)) 
-((-2745 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-893)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) (-5 *1 (-893)))) (-2854 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) (-5 *1 (-893))))) 
-(-13 (-1090) (-10 -8 (-15 -2745 ($ (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215))))) (-15 -2745 ((-850) $)) (-15 -2854 ((-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215))) $)))) 
-((-4189 (($ $ |#2|) NIL) (($ $ (-634 |#2|)) 10) (($ $ |#2| (-763)) 12) (($ $ (-634 |#2|) (-634 (-763))) 15)) (-3190 (($ $ |#2|) 16) (($ $ (-634 |#2|)) 18) (($ $ |#2| (-763)) 19) (($ $ (-634 |#2|) (-634 (-763))) 21))) 
-(((-894 |#1| |#2|) (-10 -8 (-15 -3190 (|#1| |#1| (-634 |#2|) (-634 (-763)))) (-15 -3190 (|#1| |#1| |#2| (-763))) (-15 -3190 (|#1| |#1| (-634 |#2|))) (-15 -3190 (|#1| |#1| |#2|)) (-15 -4189 (|#1| |#1| (-634 |#2|) (-634 (-763)))) (-15 -4189 (|#1| |#1| |#2| (-763))) (-15 -4189 (|#1| |#1| (-634 |#2|))) (-15 -4189 (|#1| |#1| |#2|))) (-895 |#2|) (-1090)) (T -894)) 
-NIL 
-(-10 -8 (-15 -3190 (|#1| |#1| (-634 |#2|) (-634 (-763)))) (-15 -3190 (|#1| |#1| |#2| (-763))) (-15 -3190 (|#1| |#1| (-634 |#2|))) (-15 -3190 (|#1| |#1| |#2|)) (-15 -4189 (|#1| |#1| (-634 |#2|) (-634 (-763)))) (-15 -4189 (|#1| |#1| |#2| (-763))) (-15 -4189 (|#1| |#1| (-634 |#2|))) (-15 -4189 (|#1| |#1| |#2|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-2925 (((-3 $ "failed") $) 33)) (-2735 (((-121) $) 30)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-4189 (($ $ |#1|) 41) (($ $ (-634 |#1|)) 40) (($ $ |#1| (-763)) 39) (($ $ (-634 |#1|) (-634 (-763))) 38)) (-2745 (((-850) $) 11) (($ (-568)) 27)) (-4078 (((-763)) 28)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $ |#1|) 37) (($ $ (-634 |#1|)) 36) (($ $ |#1| (-763)) 35) (($ $ (-634 |#1|) (-634 (-763))) 34)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
+((-3038 ((|#1| |#1| (-763)) 23)) (-1469 (((-3 |#1| "failed") |#1| |#1|) 22)) (-3946 (((-3 (-2 (|:| -3030 |#1|) (|:| -3286 |#1|)) "failed") |#1| (-763) (-763)) 26) (((-634 |#1|) |#1|) 28))) 
+(((-891 |#1| |#2|) (-10 -7 (-15 -3946 ((-634 |#1|) |#1|)) (-15 -3946 ((-3 (-2 (|:| -3030 |#1|) (|:| -3286 |#1|)) "failed") |#1| (-763) (-763))) (-15 -1469 ((-3 |#1| "failed") |#1| |#1|)) (-15 -3038 (|#1| |#1| (-763)))) (-1219 |#2|) (-365)) (T -891)) 
+((-3038 (*1 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-365)) (-5 *1 (-891 *2 *4)) (-4 *2 (-1219 *4)))) (-1469 (*1 *2 *2 *2) (|partial| -12 (-4 *3 (-365)) (-5 *1 (-891 *2 *3)) (-4 *2 (-1219 *3)))) (-3946 (*1 *2 *3 *4 *4) (|partial| -12 (-5 *4 (-763)) (-4 *5 (-365)) (-5 *2 (-2 (|:| -3030 *3) (|:| -3286 *3))) (-5 *1 (-891 *3 *5)) (-4 *3 (-1219 *5)))) (-3946 (*1 *2 *3) (-12 (-4 *4 (-365)) (-5 *2 (-634 *3)) (-5 *1 (-891 *3 *4)) (-4 *3 (-1219 *4))))) 
+(-10 -7 (-15 -3946 ((-634 |#1|) |#1|)) (-15 -3946 ((-3 (-2 (|:| -3030 |#1|) (|:| -3286 |#1|)) "failed") |#1| (-763) (-763))) (-15 -1469 ((-3 |#1| "failed") |#1| |#1|)) (-15 -3038 (|#1| |#1| (-763)))) 
+((-3259 (((-1035) (-381) (-381) (-381) (-381) (-763) (-763) (-634 (-310 (-381))) (-634 (-634 (-310 (-381)))) (-1143)) 92) (((-1035) (-381) (-381) (-381) (-381) (-763) (-763) (-634 (-310 (-381))) (-634 (-634 (-310 (-381)))) (-1143) (-215)) 87) (((-1035) (-893) (-1059)) 76) (((-1035) (-893)) 77)) (-3031 (((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143)))) (-893) (-1059)) 50) (((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143)))) (-893)) 52))) 
+(((-892) (-10 -7 (-15 -3259 ((-1035) (-893))) (-15 -3259 ((-1035) (-893) (-1059))) (-15 -3259 ((-1035) (-381) (-381) (-381) (-381) (-763) (-763) (-634 (-310 (-381))) (-634 (-634 (-310 (-381)))) (-1143) (-215))) (-15 -3259 ((-1035) (-381) (-381) (-381) (-381) (-763) (-763) (-634 (-310 (-381))) (-634 (-634 (-310 (-381)))) (-1143))) (-15 -3031 ((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143)))) (-893))) (-15 -3031 ((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143)))) (-893) (-1059))))) (T -892)) 
+((-3031 (*1 *2 *3 *4) (-12 (-5 *3 (-893)) (-5 *4 (-1059)) (-5 *2 (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-892)))) (-3031 (*1 *2 *3) (-12 (-5 *3 (-893)) (-5 *2 (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-892)))) (-3259 (*1 *2 *3 *3 *3 *3 *4 *4 *5 *6 *7) (-12 (-5 *4 (-763)) (-5 *6 (-634 (-634 (-310 *3)))) (-5 *7 (-1143)) (-5 *5 (-634 (-310 (-381)))) (-5 *3 (-381)) (-5 *2 (-1035)) (-5 *1 (-892)))) (-3259 (*1 *2 *3 *3 *3 *3 *4 *4 *5 *6 *7 *8) (-12 (-5 *4 (-763)) (-5 *6 (-634 (-634 (-310 *3)))) (-5 *7 (-1143)) (-5 *8 (-215)) (-5 *5 (-634 (-310 (-381)))) (-5 *3 (-381)) (-5 *2 (-1035)) (-5 *1 (-892)))) (-3259 (*1 *2 *3 *4) (-12 (-5 *3 (-893)) (-5 *4 (-1059)) (-5 *2 (-1035)) (-5 *1 (-892)))) (-3259 (*1 *2 *3) (-12 (-5 *3 (-893)) (-5 *2 (-1035)) (-5 *1 (-892))))) 
+(-10 -7 (-15 -3259 ((-1035) (-893))) (-15 -3259 ((-1035) (-893) (-1059))) (-15 -3259 ((-1035) (-381) (-381) (-381) (-381) (-763) (-763) (-634 (-310 (-381))) (-634 (-634 (-310 (-381)))) (-1143) (-215))) (-15 -3259 ((-1035) (-381) (-381) (-381) (-381) (-763) (-763) (-634 (-310 (-381))) (-634 (-634 (-310 (-381)))) (-1143))) (-15 -3031 ((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143)))) (-893))) (-15 -3031 ((-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143)))) (-893) (-1059)))) 
+((-2449 (((-121) $ $) NIL)) (-2857 (((-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215))) $) 10)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 12) (($ (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) 9)) (-1719 (((-121) $ $) NIL))) 
+(((-893) (-13 (-1090) (-10 -8 (-15 -2747 ($ (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215))))) (-15 -2747 ((-850) $)) (-15 -2857 ((-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215))) $))))) (T -893)) 
+((-2747 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-893)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) (-5 *1 (-893)))) (-2857 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) (-5 *1 (-893))))) 
+(-13 (-1090) (-10 -8 (-15 -2747 ($ (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215))))) (-15 -2747 ((-850) $)) (-15 -2857 ((-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215))) $)))) 
+((-4191 (($ $ |#2|) NIL) (($ $ (-634 |#2|)) 10) (($ $ |#2| (-763)) 12) (($ $ (-634 |#2|) (-634 (-763))) 15)) (-3192 (($ $ |#2|) 16) (($ $ (-634 |#2|)) 18) (($ $ |#2| (-763)) 19) (($ $ (-634 |#2|) (-634 (-763))) 21))) 
+(((-894 |#1| |#2|) (-10 -8 (-15 -3192 (|#1| |#1| (-634 |#2|) (-634 (-763)))) (-15 -3192 (|#1| |#1| |#2| (-763))) (-15 -3192 (|#1| |#1| (-634 |#2|))) (-15 -3192 (|#1| |#1| |#2|)) (-15 -4191 (|#1| |#1| (-634 |#2|) (-634 (-763)))) (-15 -4191 (|#1| |#1| |#2| (-763))) (-15 -4191 (|#1| |#1| (-634 |#2|))) (-15 -4191 (|#1| |#1| |#2|))) (-895 |#2|) (-1090)) (T -894)) 
+NIL 
+(-10 -8 (-15 -3192 (|#1| |#1| (-634 |#2|) (-634 (-763)))) (-15 -3192 (|#1| |#1| |#2| (-763))) (-15 -3192 (|#1| |#1| (-634 |#2|))) (-15 -3192 (|#1| |#1| |#2|)) (-15 -4191 (|#1| |#1| (-634 |#2|) (-634 (-763)))) (-15 -4191 (|#1| |#1| |#2| (-763))) (-15 -4191 (|#1| |#1| (-634 |#2|))) (-15 -4191 (|#1| |#1| |#2|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-2902 (((-3 $ "failed") $) 33)) (-1598 (((-121) $) 30)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-4191 (($ $ |#1|) 41) (($ $ (-634 |#1|)) 40) (($ $ |#1| (-763)) 39) (($ $ (-634 |#1|) (-634 (-763))) 38)) (-2747 (((-850) $) 11) (($ (-568)) 27)) (-3425 (((-763)) 28)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $ |#1|) 37) (($ $ (-634 |#1|)) 36) (($ $ |#1| (-763)) 35) (($ $ (-634 |#1|) (-634 (-763))) 34)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
 (((-895 |#1|) (-1275) (-1090)) (T -895)) 
-((-4189 (*1 *1 *1 *2) (-12 (-4 *1 (-895 *2)) (-4 *2 (-1090)))) (-4189 (*1 *1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *1 (-895 *3)) (-4 *3 (-1090)))) (-4189 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-895 *2)) (-4 *2 (-1090)))) (-4189 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *4)) (-5 *3 (-634 (-763))) (-4 *1 (-895 *4)) (-4 *4 (-1090)))) (-3190 (*1 *1 *1 *2) (-12 (-4 *1 (-895 *2)) (-4 *2 (-1090)))) (-3190 (*1 *1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *1 (-895 *3)) (-4 *3 (-1090)))) (-3190 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-895 *2)) (-4 *2 (-1090)))) (-3190 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *4)) (-5 *3 (-634 (-763))) (-4 *1 (-895 *4)) (-4 *4 (-1090))))) 
-(-13 (-1047) (-10 -8 (-15 -4189 ($ $ |t#1|)) (-15 -4189 ($ $ (-634 |t#1|))) (-15 -4189 ($ $ |t#1| (-763))) (-15 -4189 ($ $ (-634 |t#1|) (-634 (-763)))) (-15 -3190 ($ $ |t#1|)) (-15 -3190 ($ $ (-634 |t#1|))) (-15 -3190 ($ $ |t#1| (-763))) (-15 -3190 ($ $ (-634 |t#1|) (-634 (-763)))))) 
+((-4191 (*1 *1 *1 *2) (-12 (-4 *1 (-895 *2)) (-4 *2 (-1090)))) (-4191 (*1 *1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *1 (-895 *3)) (-4 *3 (-1090)))) (-4191 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-895 *2)) (-4 *2 (-1090)))) (-4191 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *4)) (-5 *3 (-634 (-763))) (-4 *1 (-895 *4)) (-4 *4 (-1090)))) (-3192 (*1 *1 *1 *2) (-12 (-4 *1 (-895 *2)) (-4 *2 (-1090)))) (-3192 (*1 *1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *1 (-895 *3)) (-4 *3 (-1090)))) (-3192 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-895 *2)) (-4 *2 (-1090)))) (-3192 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *4)) (-5 *3 (-634 (-763))) (-4 *1 (-895 *4)) (-4 *4 (-1090))))) 
+(-13 (-1047) (-10 -8 (-15 -4191 ($ $ |t#1|)) (-15 -4191 ($ $ (-634 |t#1|))) (-15 -4191 ($ $ |t#1| (-763))) (-15 -4191 ($ $ (-634 |t#1|) (-634 (-763)))) (-15 -3192 ($ $ |t#1|)) (-15 -3192 ($ $ (-634 |t#1|))) (-15 -3192 ($ $ |t#1| (-763))) (-15 -3192 ($ $ (-634 |t#1|) (-634 (-763)))))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 $) . T) ((-716) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2850 ((|#1| $) 26)) (-2510 (((-121) $ (-763)) NIL)) (-1659 ((|#1| $ |#1|) NIL (|has| $ (-6 -4520)))) (-3497 (($ $ $) NIL (|has| $ (-6 -4520)))) (-3089 (($ $ $) NIL (|has| $ (-6 -4520)))) (-2436 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4520))) (($ $ "left" $) NIL (|has| $ (-6 -4520))) (($ $ "right" $) NIL (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) NIL (|has| $ (-6 -4520)))) (-2671 (($) NIL T CONST)) (-3284 (($ $) 25)) (-1844 (($ |#1|) 12) (($ $ $) 17)) (-4360 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-2287 (((-634 $) $) NIL)) (-1700 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1737 (((-121) $ (-763)) NIL)) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3674 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-3028 (($ $) 23)) (-2869 (((-634 |#1|) $) NIL)) (-1651 (((-121) $) 20)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#1| $ "value") NIL) (($ $ "left") NIL) (($ $ "right") NIL)) (-4075 (((-568) $ $) NIL)) (-3790 (((-121) $) NIL)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) NIL)) (-2745 (((-850) $) 29 (|has| |#1| (-1090))) (((-1182 |#1|) $) 9)) (-4339 (((-634 $) $) NIL)) (-3491 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 21 (|has| |#1| (-1090)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-896 |#1|) (-13 (-128 |#1|) (-10 -8 (-15 -1844 ($ |#1|)) (-15 -1844 ($ $ $)) (-15 -2745 ((-1182 |#1|) $)))) (-1090)) (T -896)) 
-((-1844 (*1 *1 *2) (-12 (-5 *1 (-896 *2)) (-4 *2 (-1090)))) (-1844 (*1 *1 *1 *1) (-12 (-5 *1 (-896 *2)) (-4 *2 (-1090)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-1182 *3)) (-5 *1 (-896 *3)) (-4 *3 (-1090))))) 
-(-13 (-128 |#1|) (-10 -8 (-15 -1844 ($ |#1|)) (-15 -1844 ($ $ $)) (-15 -2745 ((-1182 |#1|) $)))) 
-((-3271 ((|#2| (-1127 |#1| |#2|)) 39))) 
-(((-897 |#1| |#2|) (-10 -7 (-15 -3271 (|#2| (-1127 |#1| |#2|)))) (-917) (-13 (-1047) (-10 -7 (-6 (-4521 "*"))))) (T -897)) 
-((-3271 (*1 *2 *3) (-12 (-5 *3 (-1127 *4 *2)) (-14 *4 (-917)) (-4 *2 (-13 (-1047) (-10 -7 (-6 (-4521 "*"))))) (-5 *1 (-897 *4 *2))))) 
-(-10 -7 (-15 -3271 (|#2| (-1127 |#1| |#2|)))) 
-((-2447 (((-121) $ $) 7)) (-2671 (($) 19 T CONST)) (-2925 (((-3 $ "failed") $) 15)) (-3340 (((-1092 |#1|) $ |#1|) 34)) (-2735 (((-121) $) 18)) (-2521 (($ $ $) 32 (-2198 (|has| |#1| (-842)) (|has| |#1| (-370))))) (-3268 (($ $ $) 31 (-2198 (|has| |#1| (-842)) (|has| |#1| (-370))))) (-4487 (((-1143) $) 9)) (-2081 (($ $) 26)) (-4022 (((-1108) $) 10)) (-1339 ((|#1| $ |#1|) 36)) (-2779 ((|#1| $ |#1|) 35)) (-2921 (($ (-634 (-634 |#1|))) 37)) (-3503 (($ (-634 |#1|)) 38)) (-1458 (($ $ $) 22)) (-2353 (($ $ $) 21)) (-2745 (((-850) $) 11)) (-1887 (($ $ (-917)) 12) (($ $ (-763)) 16) (($ $ (-568)) 23)) (-1556 (($) 20 T CONST)) (-1751 (((-121) $ $) 29 (-2198 (|has| |#1| (-842)) (|has| |#1| (-370))))) (-1738 (((-121) $ $) 28 (-2198 (|has| |#1| (-842)) (|has| |#1| (-370))))) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 30 (-2198 (|has| |#1| (-842)) (|has| |#1| (-370))))) (-1732 (((-121) $ $) 33)) (-1779 (($ $ $) 25)) (** (($ $ (-917)) 13) (($ $ (-763)) 17) (($ $ (-568)) 24)) (* (($ $ $) 14))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2852 ((|#1| $) 26)) (-1667 (((-121) $ (-763)) NIL)) (-3370 ((|#1| $ |#1|) NIL (|has| $ (-6 -4522)))) (-3892 (($ $ $) NIL (|has| $ (-6 -4522)))) (-2458 (($ $ $) NIL (|has| $ (-6 -4522)))) (-2438 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4522))) (($ $ "left" $) NIL (|has| $ (-6 -4522))) (($ $ "right" $) NIL (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) NIL (|has| $ (-6 -4522)))) (-4490 (($) NIL T CONST)) (-3286 (($ $) 25)) (-1846 (($ |#1|) 12) (($ $ $) 17)) (-3317 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-3534 (((-634 $) $) NIL)) (-3606 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3791 (((-121) $ (-763)) NIL)) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-2253 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-3030 (($ $) 23)) (-4081 (((-634 |#1|) $) NIL)) (-3319 (((-121) $) 20)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#1| $ "value") NIL) (($ $ "left") NIL) (($ $ "right") NIL)) (-1665 (((-568) $ $) NIL)) (-2763 (((-121) $) NIL)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) NIL)) (-2747 (((-850) $) 29 (|has| |#1| (-1090))) (((-1182 |#1|) $) 9)) (-3180 (((-634 $) $) NIL)) (-3873 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 21 (|has| |#1| (-1090)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-896 |#1|) (-13 (-128 |#1|) (-10 -8 (-15 -1846 ($ |#1|)) (-15 -1846 ($ $ $)) (-15 -2747 ((-1182 |#1|) $)))) (-1090)) (T -896)) 
+((-1846 (*1 *1 *2) (-12 (-5 *1 (-896 *2)) (-4 *2 (-1090)))) (-1846 (*1 *1 *1 *1) (-12 (-5 *1 (-896 *2)) (-4 *2 (-1090)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-1182 *3)) (-5 *1 (-896 *3)) (-4 *3 (-1090))))) 
+(-13 (-128 |#1|) (-10 -8 (-15 -1846 ($ |#1|)) (-15 -1846 ($ $ $)) (-15 -2747 ((-1182 |#1|) $)))) 
+((-2059 ((|#2| (-1127 |#1| |#2|)) 39))) 
+(((-897 |#1| |#2|) (-10 -7 (-15 -2059 (|#2| (-1127 |#1| |#2|)))) (-917) (-13 (-1047) (-10 -7 (-6 (-4523 "*"))))) (T -897)) 
+((-2059 (*1 *2 *3) (-12 (-5 *3 (-1127 *4 *2)) (-14 *4 (-917)) (-4 *2 (-13 (-1047) (-10 -7 (-6 (-4523 "*"))))) (-5 *1 (-897 *4 *2))))) 
+(-10 -7 (-15 -2059 (|#2| (-1127 |#1| |#2|)))) 
+((-2449 (((-121) $ $) 7)) (-4490 (($) 19 T CONST)) (-2902 (((-3 $ "failed") $) 15)) (-4450 (((-1092 |#1|) $ |#1|) 34)) (-1598 (((-121) $) 18)) (-1732 (($ $ $) 32 (-2199 (|has| |#1| (-842)) (|has| |#1| (-370))))) (-2047 (($ $ $) 31 (-2199 (|has| |#1| (-842)) (|has| |#1| (-370))))) (-1893 (((-1143) $) 9)) (-2083 (($ $) 26)) (-4025 (((-1108) $) 10)) (-1339 ((|#1| $ |#1|) 36)) (-2781 ((|#1| $ |#1|) 35)) (-2892 (($ (-634 (-634 |#1|))) 37)) (-3931 (($ (-634 |#1|)) 38)) (-2387 (($ $ $) 22)) (-3985 (($ $ $) 21)) (-2747 (((-850) $) 11)) (-1889 (($ $ (-917)) 12) (($ $ (-763)) 16) (($ $ (-568)) 23)) (-1557 (($) 20 T CONST)) (-1753 (((-121) $ $) 29 (-2199 (|has| |#1| (-842)) (|has| |#1| (-370))))) (-1740 (((-121) $ $) 28 (-2199 (|has| |#1| (-842)) (|has| |#1| (-370))))) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 30 (-2199 (|has| |#1| (-842)) (|has| |#1| (-370))))) (-1734 (((-121) $ $) 33)) (-1781 (($ $ $) 25)) (** (($ $ (-917)) 13) (($ $ (-763)) 17) (($ $ (-568)) 24)) (* (($ $ $) 14))) 
 (((-898 |#1|) (-1275) (-1090)) (T -898)) 
-((-3503 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-4 *1 (-898 *3)))) (-2921 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-1090)) (-4 *1 (-898 *3)))) (-1339 (*1 *2 *1 *2) (-12 (-4 *1 (-898 *2)) (-4 *2 (-1090)))) (-2779 (*1 *2 *1 *2) (-12 (-4 *1 (-898 *2)) (-4 *2 (-1090)))) (-3340 (*1 *2 *1 *3) (-12 (-4 *1 (-898 *3)) (-4 *3 (-1090)) (-5 *2 (-1092 *3)))) (-1732 (*1 *2 *1 *1) (-12 (-4 *1 (-898 *3)) (-4 *3 (-1090)) (-5 *2 (-121))))) 
-(-13 (-478) (-10 -8 (-15 -3503 ($ (-634 |t#1|))) (-15 -2921 ($ (-634 (-634 |t#1|)))) (-15 -1339 (|t#1| $ |t#1|)) (-15 -2779 (|t#1| $ |t#1|)) (-15 -3340 ((-1092 |t#1|) $ |t#1|)) (-15 -1732 ((-121) $ $)) (IF (|has| |t#1| (-842)) (-6 (-842)) |noBranch|) (IF (|has| |t#1| (-370)) (-6 (-842)) |noBranch|))) 
-(((-105) . T) ((-608 (-850)) . T) ((-478) . T) ((-716) . T) ((-842) -2198 (|has| |#1| (-842)) (|has| |#1| (-370))) ((-1102) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2639 (((-634 (-634 (-763))) $) 106)) (-2772 (((-634 (-763)) (-900 |#1|) $) 128)) (-4322 (((-634 (-763)) (-900 |#1|) $) 129)) (-3298 (((-634 (-900 |#1|)) $) 96)) (-1731 (((-900 |#1|) $ (-568)) 101) (((-900 |#1|) $) 102)) (-3901 (($ (-634 (-900 |#1|))) 108)) (-4477 (((-763) $) 103)) (-3389 (((-1092 (-1092 |#1|)) $) 126)) (-3340 (((-1092 |#1|) $ |#1|) 119) (((-1092 (-1092 |#1|)) $ (-1092 |#1|)) 137) (((-1092 (-634 |#1|)) $ (-634 |#1|)) 140)) (-3192 (((-1092 |#1|) $) 99)) (-3109 (((-121) (-900 |#1|) $) 90)) (-4487 (((-1143) $) NIL)) (-1594 (((-1249) $) 93) (((-1249) $ (-568) (-568)) 141)) (-4022 (((-1108) $) NIL)) (-2865 (((-634 (-900 |#1|)) $) 94)) (-2779 (((-900 |#1|) $ (-763)) 97)) (-3206 (((-763) $) 104)) (-2745 (((-850) $) 117) (((-634 (-900 |#1|)) $) 22) (($ (-634 (-900 |#1|))) 107)) (-1461 (((-634 |#1|) $) 105)) (-1717 (((-121) $ $) 134)) (-1745 (((-121) $ $) 132)) (-1732 (((-121) $ $) 131))) 
-(((-899 |#1|) (-13 (-1090) (-10 -8 (-15 -2745 ((-634 (-900 |#1|)) $)) (-15 -2865 ((-634 (-900 |#1|)) $)) (-15 -2779 ((-900 |#1|) $ (-763))) (-15 -1731 ((-900 |#1|) $ (-568))) (-15 -1731 ((-900 |#1|) $)) (-15 -4477 ((-763) $)) (-15 -3206 ((-763) $)) (-15 -1461 ((-634 |#1|) $)) (-15 -3298 ((-634 (-900 |#1|)) $)) (-15 -2639 ((-634 (-634 (-763))) $)) (-15 -2745 ($ (-634 (-900 |#1|)))) (-15 -3901 ($ (-634 (-900 |#1|)))) (-15 -3340 ((-1092 |#1|) $ |#1|)) (-15 -3389 ((-1092 (-1092 |#1|)) $)) (-15 -3340 ((-1092 (-1092 |#1|)) $ (-1092 |#1|))) (-15 -3340 ((-1092 (-634 |#1|)) $ (-634 |#1|))) (-15 -3109 ((-121) (-900 |#1|) $)) (-15 -2772 ((-634 (-763)) (-900 |#1|) $)) (-15 -4322 ((-634 (-763)) (-900 |#1|) $)) (-15 -3192 ((-1092 |#1|) $)) (-15 -1732 ((-121) $ $)) (-15 -1745 ((-121) $ $)) (-15 -1594 ((-1249) $)) (-15 -1594 ((-1249) $ (-568) (-568))))) (-1090)) (T -899)) 
-((-2745 (*1 *2 *1) (-12 (-5 *2 (-634 (-900 *3))) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-2865 (*1 *2 *1) (-12 (-5 *2 (-634 (-900 *3))) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-2779 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-900 *4)) (-5 *1 (-899 *4)) (-4 *4 (-1090)))) (-1731 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-900 *4)) (-5 *1 (-899 *4)) (-4 *4 (-1090)))) (-1731 (*1 *2 *1) (-12 (-5 *2 (-900 *3)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-4477 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-3206 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-1461 (*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-3298 (*1 *2 *1) (-12 (-5 *2 (-634 (-900 *3))) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-2639 (*1 *2 *1) (-12 (-5 *2 (-634 (-634 (-763)))) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-634 (-900 *3))) (-4 *3 (-1090)) (-5 *1 (-899 *3)))) (-3901 (*1 *1 *2) (-12 (-5 *2 (-634 (-900 *3))) (-4 *3 (-1090)) (-5 *1 (-899 *3)))) (-3340 (*1 *2 *1 *3) (-12 (-5 *2 (-1092 *3)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-3389 (*1 *2 *1) (-12 (-5 *2 (-1092 (-1092 *3))) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-3340 (*1 *2 *1 *3) (-12 (-4 *4 (-1090)) (-5 *2 (-1092 (-1092 *4))) (-5 *1 (-899 *4)) (-5 *3 (-1092 *4)))) (-3340 (*1 *2 *1 *3) (-12 (-4 *4 (-1090)) (-5 *2 (-1092 (-634 *4))) (-5 *1 (-899 *4)) (-5 *3 (-634 *4)))) (-3109 (*1 *2 *3 *1) (-12 (-5 *3 (-900 *4)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-899 *4)))) (-2772 (*1 *2 *3 *1) (-12 (-5 *3 (-900 *4)) (-4 *4 (-1090)) (-5 *2 (-634 (-763))) (-5 *1 (-899 *4)))) (-4322 (*1 *2 *3 *1) (-12 (-5 *3 (-900 *4)) (-4 *4 (-1090)) (-5 *2 (-634 (-763))) (-5 *1 (-899 *4)))) (-3192 (*1 *2 *1) (-12 (-5 *2 (-1092 *3)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-1732 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-1745 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-1594 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-1594 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-899 *4)) (-4 *4 (-1090))))) 
-(-13 (-1090) (-10 -8 (-15 -2745 ((-634 (-900 |#1|)) $)) (-15 -2865 ((-634 (-900 |#1|)) $)) (-15 -2779 ((-900 |#1|) $ (-763))) (-15 -1731 ((-900 |#1|) $ (-568))) (-15 -1731 ((-900 |#1|) $)) (-15 -4477 ((-763) $)) (-15 -3206 ((-763) $)) (-15 -1461 ((-634 |#1|) $)) (-15 -3298 ((-634 (-900 |#1|)) $)) (-15 -2639 ((-634 (-634 (-763))) $)) (-15 -2745 ($ (-634 (-900 |#1|)))) (-15 -3901 ($ (-634 (-900 |#1|)))) (-15 -3340 ((-1092 |#1|) $ |#1|)) (-15 -3389 ((-1092 (-1092 |#1|)) $)) (-15 -3340 ((-1092 (-1092 |#1|)) $ (-1092 |#1|))) (-15 -3340 ((-1092 (-634 |#1|)) $ (-634 |#1|))) (-15 -3109 ((-121) (-900 |#1|) $)) (-15 -2772 ((-634 (-763)) (-900 |#1|) $)) (-15 -4322 ((-634 (-763)) (-900 |#1|) $)) (-15 -3192 ((-1092 |#1|) $)) (-15 -1732 ((-121) $ $)) (-15 -1745 ((-121) $ $)) (-15 -1594 ((-1249) $)) (-15 -1594 ((-1249) $ (-568) (-568))))) 
-((-2447 (((-121) $ $) NIL)) (-3644 (((-634 $) (-634 $)) 76)) (-3662 (((-568) $) 59)) (-2671 (($) NIL T CONST)) (-2925 (((-3 $ "failed") $) NIL)) (-4477 (((-763) $) 57)) (-3340 (((-1092 |#1|) $ |#1|) 48)) (-2735 (((-121) $) NIL)) (-1825 (((-121) $) 62)) (-2239 (((-763) $) 60)) (-3192 (((-1092 |#1|) $) 41)) (-2521 (($ $ $) NIL (-2198 (|has| |#1| (-370)) (|has| |#1| (-842))))) (-3268 (($ $ $) NIL (-2198 (|has| |#1| (-370)) (|has| |#1| (-842))))) (-3050 (((-2 (|:| |preimage| (-634 |#1|)) (|:| |image| (-634 |#1|))) $) 35)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) 92)) (-4022 (((-1108) $) NIL)) (-3131 (((-1092 |#1|) $) 98 (|has| |#1| (-370)))) (-3277 (((-121) $) 58)) (-1339 ((|#1| $ |#1|) 46)) (-2779 ((|#1| $ |#1|) 93)) (-3206 (((-763) $) 43)) (-2921 (($ (-634 (-634 |#1|))) 84)) (-2770 (((-972) $) 52)) (-3503 (($ (-634 |#1|)) 21)) (-1458 (($ $ $) NIL)) (-2353 (($ $ $) NIL)) (-2813 (($ (-634 (-634 |#1|))) 38)) (-3531 (($ (-634 (-634 |#1|))) 87)) (-2965 (($ (-634 |#1|)) 95)) (-2745 (((-850) $) 83) (($ (-634 (-634 |#1|))) 65) (($ (-634 |#1|)) 66)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-1556 (($) 16 T CONST)) (-1751 (((-121) $ $) NIL (-2198 (|has| |#1| (-370)) (|has| |#1| (-842))))) (-1738 (((-121) $ $) NIL (-2198 (|has| |#1| (-370)) (|has| |#1| (-842))))) (-1717 (((-121) $ $) 44)) (-1745 (((-121) $ $) NIL (-2198 (|has| |#1| (-370)) (|has| |#1| (-842))))) (-1732 (((-121) $ $) 64)) (-1779 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ $ $) 22))) 
-(((-900 |#1|) (-13 (-898 |#1|) (-10 -8 (-15 -3050 ((-2 (|:| |preimage| (-634 |#1|)) (|:| |image| (-634 |#1|))) $)) (-15 -2813 ($ (-634 (-634 |#1|)))) (-15 -2745 ($ (-634 (-634 |#1|)))) (-15 -2745 ($ (-634 |#1|))) (-15 -3531 ($ (-634 (-634 |#1|)))) (-15 -3206 ((-763) $)) (-15 -3192 ((-1092 |#1|) $)) (-15 -2770 ((-972) $)) (-15 -4477 ((-763) $)) (-15 -2239 ((-763) $)) (-15 -3662 ((-568) $)) (-15 -3277 ((-121) $)) (-15 -1825 ((-121) $)) (-15 -3644 ((-634 $) (-634 $))) (IF (|has| |#1| (-370)) (-15 -3131 ((-1092 |#1|) $)) |noBranch|) (IF (|has| |#1| (-550)) (-15 -2965 ($ (-634 |#1|))) (IF (|has| |#1| (-370)) (-15 -2965 ($ (-634 |#1|))) |noBranch|)))) (-1090)) (T -900)) 
-((-3050 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |preimage| (-634 *3)) (|:| |image| (-634 *3)))) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) (-2813 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-1090)) (-5 *1 (-900 *3)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-1090)) (-5 *1 (-900 *3)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-900 *3)))) (-3531 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-1090)) (-5 *1 (-900 *3)))) (-3206 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) (-3192 (*1 *2 *1) (-12 (-5 *2 (-1092 *3)) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) (-2770 (*1 *2 *1) (-12 (-5 *2 (-972)) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) (-4477 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) (-2239 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) (-3662 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) (-3277 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) (-1825 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) (-3644 (*1 *2 *2) (-12 (-5 *2 (-634 (-900 *3))) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) (-3131 (*1 *2 *1) (-12 (-5 *2 (-1092 *3)) (-5 *1 (-900 *3)) (-4 *3 (-370)) (-4 *3 (-1090)))) (-2965 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-900 *3))))) 
-(-13 (-898 |#1|) (-10 -8 (-15 -3050 ((-2 (|:| |preimage| (-634 |#1|)) (|:| |image| (-634 |#1|))) $)) (-15 -2813 ($ (-634 (-634 |#1|)))) (-15 -2745 ($ (-634 (-634 |#1|)))) (-15 -2745 ($ (-634 |#1|))) (-15 -3531 ($ (-634 (-634 |#1|)))) (-15 -3206 ((-763) $)) (-15 -3192 ((-1092 |#1|) $)) (-15 -2770 ((-972) $)) (-15 -4477 ((-763) $)) (-15 -2239 ((-763) $)) (-15 -3662 ((-568) $)) (-15 -3277 ((-121) $)) (-15 -1825 ((-121) $)) (-15 -3644 ((-634 $) (-634 $))) (IF (|has| |#1| (-370)) (-15 -3131 ((-1092 |#1|) $)) |noBranch|) (IF (|has| |#1| (-550)) (-15 -2965 ($ (-634 |#1|))) (IF (|has| |#1| (-370)) (-15 -2965 ($ (-634 |#1|))) |noBranch|)))) 
-((-1355 (((-3 (-634 (-1157 |#4|)) "failed") (-634 (-1157 |#4|)) (-1157 |#4|)) 127)) (-3629 ((|#1|) 75)) (-2653 (((-420 (-1157 |#4|)) (-1157 |#4|)) 136)) (-2695 (((-420 (-1157 |#4|)) (-634 |#3|) (-1157 |#4|)) 67)) (-3420 (((-420 (-1157 |#4|)) (-1157 |#4|)) 146)) (-3454 (((-3 (-634 (-1157 |#4|)) "failed") (-634 (-1157 |#4|)) (-1157 |#4|) |#3|) 91))) 
-(((-901 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1355 ((-3 (-634 (-1157 |#4|)) "failed") (-634 (-1157 |#4|)) (-1157 |#4|))) (-15 -3420 ((-420 (-1157 |#4|)) (-1157 |#4|))) (-15 -2653 ((-420 (-1157 |#4|)) (-1157 |#4|))) (-15 -3629 (|#1|)) (-15 -3454 ((-3 (-634 (-1157 |#4|)) "failed") (-634 (-1157 |#4|)) (-1157 |#4|) |#3|)) (-15 -2695 ((-420 (-1157 |#4|)) (-634 |#3|) (-1157 |#4|)))) (-904) (-788) (-842) (-950 |#1| |#2| |#3|)) (T -901)) 
-((-2695 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *7)) (-4 *7 (-842)) (-4 *5 (-904)) (-4 *6 (-788)) (-4 *8 (-950 *5 *6 *7)) (-5 *2 (-420 (-1157 *8))) (-5 *1 (-901 *5 *6 *7 *8)) (-5 *4 (-1157 *8)))) (-3454 (*1 *2 *2 *3 *4) (|partial| -12 (-5 *2 (-634 (-1157 *7))) (-5 *3 (-1157 *7)) (-4 *7 (-950 *5 *6 *4)) (-4 *5 (-904)) (-4 *6 (-788)) (-4 *4 (-842)) (-5 *1 (-901 *5 *6 *4 *7)))) (-3629 (*1 *2) (-12 (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-904)) (-5 *1 (-901 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) (-2653 (*1 *2 *3) (-12 (-4 *4 (-904)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-950 *4 *5 *6)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-901 *4 *5 *6 *7)) (-5 *3 (-1157 *7)))) (-3420 (*1 *2 *3) (-12 (-4 *4 (-904)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-950 *4 *5 *6)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-901 *4 *5 *6 *7)) (-5 *3 (-1157 *7)))) (-1355 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 *7))) (-5 *3 (-1157 *7)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-904)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-901 *4 *5 *6 *7))))) 
-(-10 -7 (-15 -1355 ((-3 (-634 (-1157 |#4|)) "failed") (-634 (-1157 |#4|)) (-1157 |#4|))) (-15 -3420 ((-420 (-1157 |#4|)) (-1157 |#4|))) (-15 -2653 ((-420 (-1157 |#4|)) (-1157 |#4|))) (-15 -3629 (|#1|)) (-15 -3454 ((-3 (-634 (-1157 |#4|)) "failed") (-634 (-1157 |#4|)) (-1157 |#4|) |#3|)) (-15 -2695 ((-420 (-1157 |#4|)) (-634 |#3|) (-1157 |#4|)))) 
-((-1355 (((-3 (-634 (-1157 |#2|)) "failed") (-634 (-1157 |#2|)) (-1157 |#2|)) 36)) (-3629 ((|#1|) 53)) (-2653 (((-420 (-1157 |#2|)) (-1157 |#2|)) 101)) (-2695 (((-420 (-1157 |#2|)) (-1157 |#2|)) 88)) (-3420 (((-420 (-1157 |#2|)) (-1157 |#2|)) 112))) 
-(((-902 |#1| |#2|) (-10 -7 (-15 -1355 ((-3 (-634 (-1157 |#2|)) "failed") (-634 (-1157 |#2|)) (-1157 |#2|))) (-15 -3420 ((-420 (-1157 |#2|)) (-1157 |#2|))) (-15 -2653 ((-420 (-1157 |#2|)) (-1157 |#2|))) (-15 -3629 (|#1|)) (-15 -2695 ((-420 (-1157 |#2|)) (-1157 |#2|)))) (-904) (-1219 |#1|)) (T -902)) 
-((-2695 (*1 *2 *3) (-12 (-4 *4 (-904)) (-4 *5 (-1219 *4)) (-5 *2 (-420 (-1157 *5))) (-5 *1 (-902 *4 *5)) (-5 *3 (-1157 *5)))) (-3629 (*1 *2) (-12 (-4 *2 (-904)) (-5 *1 (-902 *2 *3)) (-4 *3 (-1219 *2)))) (-2653 (*1 *2 *3) (-12 (-4 *4 (-904)) (-4 *5 (-1219 *4)) (-5 *2 (-420 (-1157 *5))) (-5 *1 (-902 *4 *5)) (-5 *3 (-1157 *5)))) (-3420 (*1 *2 *3) (-12 (-4 *4 (-904)) (-4 *5 (-1219 *4)) (-5 *2 (-420 (-1157 *5))) (-5 *1 (-902 *4 *5)) (-5 *3 (-1157 *5)))) (-1355 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 *5))) (-5 *3 (-1157 *5)) (-4 *5 (-1219 *4)) (-4 *4 (-904)) (-5 *1 (-902 *4 *5))))) 
-(-10 -7 (-15 -1355 ((-3 (-634 (-1157 |#2|)) "failed") (-634 (-1157 |#2|)) (-1157 |#2|))) (-15 -3420 ((-420 (-1157 |#2|)) (-1157 |#2|))) (-15 -2653 ((-420 (-1157 |#2|)) (-1157 |#2|))) (-15 -3629 (|#1|)) (-15 -2695 ((-420 (-1157 |#2|)) (-1157 |#2|)))) 
-((-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 39)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 18)) (-4371 (((-3 $ "failed") $) 33))) 
-(((-903 |#1|) (-10 -8 (-15 -4371 ((-3 |#1| "failed") |#1|)) (-15 -1858 ((-3 (-634 (-1157 |#1|)) "failed") (-634 (-1157 |#1|)) (-1157 |#1|))) (-15 -2155 ((-1157 |#1|) (-1157 |#1|) (-1157 |#1|)))) (-904)) (T -903)) 
-NIL 
-(-10 -8 (-15 -4371 ((-3 |#1| "failed") |#1|)) (-15 -1858 ((-3 (-634 (-1157 |#1|)) "failed") (-634 (-1157 |#1|)) (-1157 |#1|))) (-15 -2155 ((-1157 |#1|) (-1157 |#1|) (-1157 |#1|)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-3134 (((-3 $ "failed") $ $) 18)) (-1750 (((-420 (-1157 $)) (-1157 $)) 57)) (-4305 (($ $) 49)) (-1678 (((-420 $) $) 50)) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 54)) (-2671 (($) 16 T CONST)) (-2925 (((-3 $ "failed") $) 33)) (-3927 (((-121) $) 51)) (-2735 (((-121) $) 30)) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-2905 (((-420 (-1157 $)) (-1157 $)) 55)) (-3545 (((-420 (-1157 $)) (-1157 $)) 56)) (-3848 (((-420 $) $) 48)) (-2595 (((-3 $ "failed") $ $) 41)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) 53 (|has| $ (-148)))) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42)) (-4371 (((-3 $ "failed") $) 52 (|has| $ (-148)))) (-4078 (((-763)) 28)) (-1826 (((-121) $ $) 38)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
+((-3931 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-4 *1 (-898 *3)))) (-2892 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-1090)) (-4 *1 (-898 *3)))) (-1339 (*1 *2 *1 *2) (-12 (-4 *1 (-898 *2)) (-4 *2 (-1090)))) (-2781 (*1 *2 *1 *2) (-12 (-4 *1 (-898 *2)) (-4 *2 (-1090)))) (-4450 (*1 *2 *1 *3) (-12 (-4 *1 (-898 *3)) (-4 *3 (-1090)) (-5 *2 (-1092 *3)))) (-1734 (*1 *2 *1 *1) (-12 (-4 *1 (-898 *3)) (-4 *3 (-1090)) (-5 *2 (-121))))) 
+(-13 (-478) (-10 -8 (-15 -3931 ($ (-634 |t#1|))) (-15 -2892 ($ (-634 (-634 |t#1|)))) (-15 -1339 (|t#1| $ |t#1|)) (-15 -2781 (|t#1| $ |t#1|)) (-15 -4450 ((-1092 |t#1|) $ |t#1|)) (-15 -1734 ((-121) $ $)) (IF (|has| |t#1| (-842)) (-6 (-842)) |noBranch|) (IF (|has| |t#1| (-370)) (-6 (-842)) |noBranch|))) 
+(((-105) . T) ((-608 (-850)) . T) ((-478) . T) ((-716) . T) ((-842) -2199 (|has| |#1| (-842)) (|has| |#1| (-370))) ((-1102) . T) ((-1090) . T)) 
+((-2449 (((-121) $ $) NIL)) (-4311 (((-634 (-634 (-763))) $) 106)) (-3521 (((-634 (-763)) (-900 |#1|) $) 128)) (-3112 (((-634 (-763)) (-900 |#1|) $) 129)) (-2170 (((-634 (-900 |#1|)) $) 96)) (-1733 (((-900 |#1|) $ (-568)) 101) (((-900 |#1|) $) 102)) (-2071 (($ (-634 (-900 |#1|))) 108)) (-1844 (((-763) $) 103)) (-1489 (((-1092 (-1092 |#1|)) $) 126)) (-4450 (((-1092 |#1|) $ |#1|) 119) (((-1092 (-1092 |#1|)) $ (-1092 |#1|)) 137) (((-1092 (-634 |#1|)) $ (-634 |#1|)) 140)) (-1787 (((-1092 |#1|) $) 99)) (-2551 (((-121) (-900 |#1|) $) 90)) (-1893 (((-1143) $) NIL)) (-1298 (((-1249) $) 93) (((-1249) $ (-568) (-568)) 141)) (-4025 (((-1108) $) NIL)) (-4057 (((-634 (-900 |#1|)) $) 94)) (-2781 (((-900 |#1|) $ (-763)) 97)) (-1836 (((-763) $) 104)) (-2747 (((-850) $) 117) (((-634 (-900 |#1|)) $) 22) (($ (-634 (-900 |#1|))) 107)) (-2404 (((-634 |#1|) $) 105)) (-1719 (((-121) $ $) 134)) (-1747 (((-121) $ $) 132)) (-1734 (((-121) $ $) 131))) 
+(((-899 |#1|) (-13 (-1090) (-10 -8 (-15 -2747 ((-634 (-900 |#1|)) $)) (-15 -4057 ((-634 (-900 |#1|)) $)) (-15 -2781 ((-900 |#1|) $ (-763))) (-15 -1733 ((-900 |#1|) $ (-568))) (-15 -1733 ((-900 |#1|) $)) (-15 -1844 ((-763) $)) (-15 -1836 ((-763) $)) (-15 -2404 ((-634 |#1|) $)) (-15 -2170 ((-634 (-900 |#1|)) $)) (-15 -4311 ((-634 (-634 (-763))) $)) (-15 -2747 ($ (-634 (-900 |#1|)))) (-15 -2071 ($ (-634 (-900 |#1|)))) (-15 -4450 ((-1092 |#1|) $ |#1|)) (-15 -1489 ((-1092 (-1092 |#1|)) $)) (-15 -4450 ((-1092 (-1092 |#1|)) $ (-1092 |#1|))) (-15 -4450 ((-1092 (-634 |#1|)) $ (-634 |#1|))) (-15 -2551 ((-121) (-900 |#1|) $)) (-15 -3521 ((-634 (-763)) (-900 |#1|) $)) (-15 -3112 ((-634 (-763)) (-900 |#1|) $)) (-15 -1787 ((-1092 |#1|) $)) (-15 -1734 ((-121) $ $)) (-15 -1747 ((-121) $ $)) (-15 -1298 ((-1249) $)) (-15 -1298 ((-1249) $ (-568) (-568))))) (-1090)) (T -899)) 
+((-2747 (*1 *2 *1) (-12 (-5 *2 (-634 (-900 *3))) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-4057 (*1 *2 *1) (-12 (-5 *2 (-634 (-900 *3))) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-2781 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-900 *4)) (-5 *1 (-899 *4)) (-4 *4 (-1090)))) (-1733 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-900 *4)) (-5 *1 (-899 *4)) (-4 *4 (-1090)))) (-1733 (*1 *2 *1) (-12 (-5 *2 (-900 *3)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-1844 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-1836 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-2404 (*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-2170 (*1 *2 *1) (-12 (-5 *2 (-634 (-900 *3))) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-4311 (*1 *2 *1) (-12 (-5 *2 (-634 (-634 (-763)))) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-634 (-900 *3))) (-4 *3 (-1090)) (-5 *1 (-899 *3)))) (-2071 (*1 *1 *2) (-12 (-5 *2 (-634 (-900 *3))) (-4 *3 (-1090)) (-5 *1 (-899 *3)))) (-4450 (*1 *2 *1 *3) (-12 (-5 *2 (-1092 *3)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-1489 (*1 *2 *1) (-12 (-5 *2 (-1092 (-1092 *3))) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-4450 (*1 *2 *1 *3) (-12 (-4 *4 (-1090)) (-5 *2 (-1092 (-1092 *4))) (-5 *1 (-899 *4)) (-5 *3 (-1092 *4)))) (-4450 (*1 *2 *1 *3) (-12 (-4 *4 (-1090)) (-5 *2 (-1092 (-634 *4))) (-5 *1 (-899 *4)) (-5 *3 (-634 *4)))) (-2551 (*1 *2 *3 *1) (-12 (-5 *3 (-900 *4)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-899 *4)))) (-3521 (*1 *2 *3 *1) (-12 (-5 *3 (-900 *4)) (-4 *4 (-1090)) (-5 *2 (-634 (-763))) (-5 *1 (-899 *4)))) (-3112 (*1 *2 *3 *1) (-12 (-5 *3 (-900 *4)) (-4 *4 (-1090)) (-5 *2 (-634 (-763))) (-5 *1 (-899 *4)))) (-1787 (*1 *2 *1) (-12 (-5 *2 (-1092 *3)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-1734 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-1747 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-1298 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) (-1298 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-899 *4)) (-4 *4 (-1090))))) 
+(-13 (-1090) (-10 -8 (-15 -2747 ((-634 (-900 |#1|)) $)) (-15 -4057 ((-634 (-900 |#1|)) $)) (-15 -2781 ((-900 |#1|) $ (-763))) (-15 -1733 ((-900 |#1|) $ (-568))) (-15 -1733 ((-900 |#1|) $)) (-15 -1844 ((-763) $)) (-15 -1836 ((-763) $)) (-15 -2404 ((-634 |#1|) $)) (-15 -2170 ((-634 (-900 |#1|)) $)) (-15 -4311 ((-634 (-634 (-763))) $)) (-15 -2747 ($ (-634 (-900 |#1|)))) (-15 -2071 ($ (-634 (-900 |#1|)))) (-15 -4450 ((-1092 |#1|) $ |#1|)) (-15 -1489 ((-1092 (-1092 |#1|)) $)) (-15 -4450 ((-1092 (-1092 |#1|)) $ (-1092 |#1|))) (-15 -4450 ((-1092 (-634 |#1|)) $ (-634 |#1|))) (-15 -2551 ((-121) (-900 |#1|) $)) (-15 -3521 ((-634 (-763)) (-900 |#1|) $)) (-15 -3112 ((-634 (-763)) (-900 |#1|) $)) (-15 -1787 ((-1092 |#1|) $)) (-15 -1734 ((-121) $ $)) (-15 -1747 ((-121) $ $)) (-15 -1298 ((-1249) $)) (-15 -1298 ((-1249) $ (-568) (-568))))) 
+((-2449 (((-121) $ $) NIL)) (-3647 (((-634 $) (-634 $)) 76)) (-3337 (((-568) $) 59)) (-4490 (($) NIL T CONST)) (-2902 (((-3 $ "failed") $) NIL)) (-1844 (((-763) $) 57)) (-4450 (((-1092 |#1|) $ |#1|) 48)) (-1598 (((-121) $) NIL)) (-2268 (((-121) $) 62)) (-2730 (((-763) $) 60)) (-1787 (((-1092 |#1|) $) 41)) (-1732 (($ $ $) NIL (-2199 (|has| |#1| (-370)) (|has| |#1| (-842))))) (-2047 (($ $ $) NIL (-2199 (|has| |#1| (-370)) (|has| |#1| (-842))))) (-2270 (((-2 (|:| |preimage| (-634 |#1|)) (|:| |image| (-634 |#1|))) $) 35)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) 92)) (-4025 (((-1108) $) NIL)) (-2670 (((-1092 |#1|) $) 98 (|has| |#1| (-370)))) (-2080 (((-121) $) 58)) (-1339 ((|#1| $ |#1|) 46)) (-2781 ((|#1| $ |#1|) 93)) (-1836 (((-763) $) 43)) (-2892 (($ (-634 (-634 |#1|))) 84)) (-3507 (((-972) $) 52)) (-3931 (($ (-634 |#1|)) 21)) (-2387 (($ $ $) NIL)) (-3985 (($ $ $) NIL)) (-3728 (($ (-634 (-634 |#1|))) 38)) (-4133 (($ (-634 (-634 |#1|))) 87)) (-3027 (($ (-634 |#1|)) 95)) (-2747 (((-850) $) 83) (($ (-634 (-634 |#1|))) 65) (($ (-634 |#1|)) 66)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-1557 (($) 16 T CONST)) (-1753 (((-121) $ $) NIL (-2199 (|has| |#1| (-370)) (|has| |#1| (-842))))) (-1740 (((-121) $ $) NIL (-2199 (|has| |#1| (-370)) (|has| |#1| (-842))))) (-1719 (((-121) $ $) 44)) (-1747 (((-121) $ $) NIL (-2199 (|has| |#1| (-370)) (|has| |#1| (-842))))) (-1734 (((-121) $ $) 64)) (-1781 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ $ $) 22))) 
+(((-900 |#1|) (-13 (-898 |#1|) (-10 -8 (-15 -2270 ((-2 (|:| |preimage| (-634 |#1|)) (|:| |image| (-634 |#1|))) $)) (-15 -3728 ($ (-634 (-634 |#1|)))) (-15 -2747 ($ (-634 (-634 |#1|)))) (-15 -2747 ($ (-634 |#1|))) (-15 -4133 ($ (-634 (-634 |#1|)))) (-15 -1836 ((-763) $)) (-15 -1787 ((-1092 |#1|) $)) (-15 -3507 ((-972) $)) (-15 -1844 ((-763) $)) (-15 -2730 ((-763) $)) (-15 -3337 ((-568) $)) (-15 -2080 ((-121) $)) (-15 -2268 ((-121) $)) (-15 -3647 ((-634 $) (-634 $))) (IF (|has| |#1| (-370)) (-15 -2670 ((-1092 |#1|) $)) |noBranch|) (IF (|has| |#1| (-550)) (-15 -3027 ($ (-634 |#1|))) (IF (|has| |#1| (-370)) (-15 -3027 ($ (-634 |#1|))) |noBranch|)))) (-1090)) (T -900)) 
+((-2270 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |preimage| (-634 *3)) (|:| |image| (-634 *3)))) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) (-3728 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-1090)) (-5 *1 (-900 *3)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-1090)) (-5 *1 (-900 *3)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-900 *3)))) (-4133 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-1090)) (-5 *1 (-900 *3)))) (-1836 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) (-1787 (*1 *2 *1) (-12 (-5 *2 (-1092 *3)) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) (-3507 (*1 *2 *1) (-12 (-5 *2 (-972)) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) (-1844 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) (-2730 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) (-3337 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) (-2080 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) (-2268 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) (-3647 (*1 *2 *2) (-12 (-5 *2 (-634 (-900 *3))) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) (-2670 (*1 *2 *1) (-12 (-5 *2 (-1092 *3)) (-5 *1 (-900 *3)) (-4 *3 (-370)) (-4 *3 (-1090)))) (-3027 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-900 *3))))) 
+(-13 (-898 |#1|) (-10 -8 (-15 -2270 ((-2 (|:| |preimage| (-634 |#1|)) (|:| |image| (-634 |#1|))) $)) (-15 -3728 ($ (-634 (-634 |#1|)))) (-15 -2747 ($ (-634 (-634 |#1|)))) (-15 -2747 ($ (-634 |#1|))) (-15 -4133 ($ (-634 (-634 |#1|)))) (-15 -1836 ((-763) $)) (-15 -1787 ((-1092 |#1|) $)) (-15 -3507 ((-972) $)) (-15 -1844 ((-763) $)) (-15 -2730 ((-763) $)) (-15 -3337 ((-568) $)) (-15 -2080 ((-121) $)) (-15 -2268 ((-121) $)) (-15 -3647 ((-634 $) (-634 $))) (IF (|has| |#1| (-370)) (-15 -2670 ((-1092 |#1|) $)) |noBranch|) (IF (|has| |#1| (-550)) (-15 -3027 ($ (-634 |#1|))) (IF (|has| |#1| (-370)) (-15 -3027 ($ (-634 |#1|))) |noBranch|)))) 
+((-3711 (((-3 (-634 (-1157 |#4|)) "failed") (-634 (-1157 |#4|)) (-1157 |#4|)) 127)) (-3130 ((|#1|) 75)) (-4394 (((-420 (-1157 |#4|)) (-1157 |#4|)) 136)) (-1387 (((-420 (-1157 |#4|)) (-634 |#3|) (-1157 |#4|)) 67)) (-1629 (((-420 (-1157 |#4|)) (-1157 |#4|)) 146)) (-3593 (((-3 (-634 (-1157 |#4|)) "failed") (-634 (-1157 |#4|)) (-1157 |#4|) |#3|) 91))) 
+(((-901 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3711 ((-3 (-634 (-1157 |#4|)) "failed") (-634 (-1157 |#4|)) (-1157 |#4|))) (-15 -1629 ((-420 (-1157 |#4|)) (-1157 |#4|))) (-15 -4394 ((-420 (-1157 |#4|)) (-1157 |#4|))) (-15 -3130 (|#1|)) (-15 -3593 ((-3 (-634 (-1157 |#4|)) "failed") (-634 (-1157 |#4|)) (-1157 |#4|) |#3|)) (-15 -1387 ((-420 (-1157 |#4|)) (-634 |#3|) (-1157 |#4|)))) (-904) (-788) (-842) (-950 |#1| |#2| |#3|)) (T -901)) 
+((-1387 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *7)) (-4 *7 (-842)) (-4 *5 (-904)) (-4 *6 (-788)) (-4 *8 (-950 *5 *6 *7)) (-5 *2 (-420 (-1157 *8))) (-5 *1 (-901 *5 *6 *7 *8)) (-5 *4 (-1157 *8)))) (-3593 (*1 *2 *2 *3 *4) (|partial| -12 (-5 *2 (-634 (-1157 *7))) (-5 *3 (-1157 *7)) (-4 *7 (-950 *5 *6 *4)) (-4 *5 (-904)) (-4 *6 (-788)) (-4 *4 (-842)) (-5 *1 (-901 *5 *6 *4 *7)))) (-3130 (*1 *2) (-12 (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-904)) (-5 *1 (-901 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) (-4394 (*1 *2 *3) (-12 (-4 *4 (-904)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-950 *4 *5 *6)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-901 *4 *5 *6 *7)) (-5 *3 (-1157 *7)))) (-1629 (*1 *2 *3) (-12 (-4 *4 (-904)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-950 *4 *5 *6)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-901 *4 *5 *6 *7)) (-5 *3 (-1157 *7)))) (-3711 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 *7))) (-5 *3 (-1157 *7)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-904)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-901 *4 *5 *6 *7))))) 
+(-10 -7 (-15 -3711 ((-3 (-634 (-1157 |#4|)) "failed") (-634 (-1157 |#4|)) (-1157 |#4|))) (-15 -1629 ((-420 (-1157 |#4|)) (-1157 |#4|))) (-15 -4394 ((-420 (-1157 |#4|)) (-1157 |#4|))) (-15 -3130 (|#1|)) (-15 -3593 ((-3 (-634 (-1157 |#4|)) "failed") (-634 (-1157 |#4|)) (-1157 |#4|) |#3|)) (-15 -1387 ((-420 (-1157 |#4|)) (-634 |#3|) (-1157 |#4|)))) 
+((-3711 (((-3 (-634 (-1157 |#2|)) "failed") (-634 (-1157 |#2|)) (-1157 |#2|)) 36)) (-3130 ((|#1|) 53)) (-4394 (((-420 (-1157 |#2|)) (-1157 |#2|)) 101)) (-1387 (((-420 (-1157 |#2|)) (-1157 |#2|)) 88)) (-1629 (((-420 (-1157 |#2|)) (-1157 |#2|)) 112))) 
+(((-902 |#1| |#2|) (-10 -7 (-15 -3711 ((-3 (-634 (-1157 |#2|)) "failed") (-634 (-1157 |#2|)) (-1157 |#2|))) (-15 -1629 ((-420 (-1157 |#2|)) (-1157 |#2|))) (-15 -4394 ((-420 (-1157 |#2|)) (-1157 |#2|))) (-15 -3130 (|#1|)) (-15 -1387 ((-420 (-1157 |#2|)) (-1157 |#2|)))) (-904) (-1219 |#1|)) (T -902)) 
+((-1387 (*1 *2 *3) (-12 (-4 *4 (-904)) (-4 *5 (-1219 *4)) (-5 *2 (-420 (-1157 *5))) (-5 *1 (-902 *4 *5)) (-5 *3 (-1157 *5)))) (-3130 (*1 *2) (-12 (-4 *2 (-904)) (-5 *1 (-902 *2 *3)) (-4 *3 (-1219 *2)))) (-4394 (*1 *2 *3) (-12 (-4 *4 (-904)) (-4 *5 (-1219 *4)) (-5 *2 (-420 (-1157 *5))) (-5 *1 (-902 *4 *5)) (-5 *3 (-1157 *5)))) (-1629 (*1 *2 *3) (-12 (-4 *4 (-904)) (-4 *5 (-1219 *4)) (-5 *2 (-420 (-1157 *5))) (-5 *1 (-902 *4 *5)) (-5 *3 (-1157 *5)))) (-3711 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 *5))) (-5 *3 (-1157 *5)) (-4 *5 (-1219 *4)) (-4 *4 (-904)) (-5 *1 (-902 *4 *5))))) 
+(-10 -7 (-15 -3711 ((-3 (-634 (-1157 |#2|)) "failed") (-634 (-1157 |#2|)) (-1157 |#2|))) (-15 -1629 ((-420 (-1157 |#2|)) (-1157 |#2|))) (-15 -4394 ((-420 (-1157 |#2|)) (-1157 |#2|))) (-15 -3130 (|#1|)) (-15 -1387 ((-420 (-1157 |#2|)) (-1157 |#2|)))) 
+((-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 39)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 18)) (-3385 (((-3 $ "failed") $) 33))) 
+(((-903 |#1|) (-10 -8 (-15 -3385 ((-3 |#1| "failed") |#1|)) (-15 -2434 ((-3 (-634 (-1157 |#1|)) "failed") (-634 (-1157 |#1|)) (-1157 |#1|))) (-15 -3603 ((-1157 |#1|) (-1157 |#1|) (-1157 |#1|)))) (-904)) (T -903)) 
+NIL 
+(-10 -8 (-15 -3385 ((-3 |#1| "failed") |#1|)) (-15 -2434 ((-3 (-634 (-1157 |#1|)) "failed") (-634 (-1157 |#1|)) (-1157 |#1|))) (-15 -3603 ((-1157 |#1|) (-1157 |#1|) (-1157 |#1|)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-2689 (((-3 $ "failed") $ $) 18)) (-3863 (((-420 (-1157 $)) (-1157 $)) 57)) (-3045 (($ $) 49)) (-3498 (((-420 $) $) 50)) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 54)) (-4490 (($) 16 T CONST)) (-2902 (((-3 $ "failed") $) 33)) (-2197 (((-121) $) 51)) (-1598 (((-121) $) 30)) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-2841 (((-420 (-1157 $)) (-1157 $)) 55)) (-2795 (((-420 (-1157 $)) (-1157 $)) 56)) (-3850 (((-420 $) $) 48)) (-2597 (((-3 $ "failed") $ $) 41)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) 53 (|has| $ (-148)))) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42)) (-3385 (((-3 $ "failed") $) 52 (|has| $ (-148)))) (-3425 (((-763)) 28)) (-2273 (((-121) $ $) 38)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
 (((-904) (-1275)) (T -904)) 
-((-2155 (*1 *2 *2 *2) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-904)))) (-1750 (*1 *2 *3) (-12 (-4 *1 (-904)) (-5 *2 (-420 (-1157 *1))) (-5 *3 (-1157 *1)))) (-3545 (*1 *2 *3) (-12 (-4 *1 (-904)) (-5 *2 (-420 (-1157 *1))) (-5 *3 (-1157 *1)))) (-2905 (*1 *2 *3) (-12 (-4 *1 (-904)) (-5 *2 (-420 (-1157 *1))) (-5 *3 (-1157 *1)))) (-1858 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 *1))) (-5 *3 (-1157 *1)) (-4 *1 (-904)))) (-2979 (*1 *2 *3) (|partial| -12 (-5 *3 (-679 *1)) (-4 *1 (-148)) (-4 *1 (-904)) (-5 *2 (-1244 *1)))) (-4371 (*1 *1 *1) (|partial| -12 (-4 *1 (-148)) (-4 *1 (-904))))) 
-(-13 (-1199) (-10 -8 (-15 -1750 ((-420 (-1157 $)) (-1157 $))) (-15 -3545 ((-420 (-1157 $)) (-1157 $))) (-15 -2905 ((-420 (-1157 $)) (-1157 $))) (-15 -2155 ((-1157 $) (-1157 $) (-1157 $))) (-15 -1858 ((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $))) (IF (|has| $ (-148)) (PROGN (-15 -2979 ((-3 (-1244 $) "failed") (-679 $))) (-15 -4371 ((-3 $ "failed") $))) |noBranch|))) 
+((-3603 (*1 *2 *2 *2) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-904)))) (-3863 (*1 *2 *3) (-12 (-4 *1 (-904)) (-5 *2 (-420 (-1157 *1))) (-5 *3 (-1157 *1)))) (-2795 (*1 *2 *3) (-12 (-4 *1 (-904)) (-5 *2 (-420 (-1157 *1))) (-5 *3 (-1157 *1)))) (-2841 (*1 *2 *3) (-12 (-4 *1 (-904)) (-5 *2 (-420 (-1157 *1))) (-5 *3 (-1157 *1)))) (-2434 (*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 *1))) (-5 *3 (-1157 *1)) (-4 *1 (-904)))) (-3070 (*1 *2 *3) (|partial| -12 (-5 *3 (-679 *1)) (-4 *1 (-148)) (-4 *1 (-904)) (-5 *2 (-1244 *1)))) (-3385 (*1 *1 *1) (|partial| -12 (-4 *1 (-148)) (-4 *1 (-904))))) 
+(-13 (-1199) (-10 -8 (-15 -3863 ((-420 (-1157 $)) (-1157 $))) (-15 -2795 ((-420 (-1157 $)) (-1157 $))) (-15 -2841 ((-420 (-1157 $)) (-1157 $))) (-15 -3603 ((-1157 $) (-1157 $) (-1157 $))) (-15 -2434 ((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $))) (IF (|has| $ (-148)) (PROGN (-15 -3070 ((-3 (-1244 $) "failed") (-679 $))) (-15 -3385 ((-3 $ "failed") $))) |noBranch|))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-105) . T) ((-120 $ $) . T) ((-137) . T) ((-608 (-850)) . T) ((-172) . T) ((-285) . T) ((-453) . T) ((-558) . T) ((-637 $) . T) ((-707 $) . T) ((-716) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1199) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-2615 (((-121) $) NIL)) (-1739 (((-763)) NIL)) (-1932 (($ $ (-917)) NIL (|has| $ (-370))) (($ $) NIL)) (-3211 (((-1169 (-917) (-763)) (-568)) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1497 (((-121) $ $) NIL)) (-3983 (((-763)) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 $ "failed") $) NIL)) (-2854 (($ $) NIL)) (-3498 (($ (-1244 $)) NIL)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL)) (-2401 (($ $ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1731 (($) NIL)) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-4220 (($) NIL)) (-4456 (((-121) $) NIL)) (-3218 (($ $) NIL) (($ $ (-763)) NIL)) (-3927 (((-121) $) NIL)) (-4477 (((-828 (-917)) $) NIL) (((-917) $) NIL)) (-2735 (((-121) $) NIL)) (-2883 (($) NIL (|has| $ (-370)))) (-3917 (((-121) $) NIL (|has| $ (-370)))) (-2657 (($ $ (-917)) NIL (|has| $ (-370))) (($ $) NIL)) (-3038 (((-3 $ "failed") $) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2045 (((-1157 $) $ (-917)) NIL (|has| $ (-370))) (((-1157 $) $) NIL)) (-3683 (((-917) $) NIL)) (-2035 (((-1157 $) $) NIL (|has| $ (-370)))) (-1422 (((-3 (-1157 $) "failed") $ $) NIL (|has| $ (-370))) (((-1157 $) $) NIL (|has| $ (-370)))) (-2109 (($ $ (-1157 $)) NIL (|has| $ (-370)))) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4434 (($) NIL T CONST)) (-4355 (($ (-917)) NIL)) (-2864 (((-121) $) NIL)) (-4022 (((-1108) $) NIL)) (-2704 (($) NIL (|has| $ (-370)))) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) NIL)) (-3848 (((-420 $) $) NIL)) (-1553 (((-917)) NIL) (((-828 (-917))) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-3143 (((-3 (-763) "failed") $ $) NIL) (((-763) $) NIL)) (-4321 (((-139)) NIL)) (-4189 (($ $ (-763)) NIL) (($ $) NIL)) (-3206 (((-917) $) NIL) (((-828 (-917)) $) NIL)) (-1626 (((-1157 $)) NIL)) (-3065 (($) NIL)) (-2027 (($) NIL (|has| $ (-370)))) (-4073 (((-679 $) (-1244 $)) NIL) (((-1244 $) $) NIL)) (-4278 (((-568) $) NIL)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL)) (-4371 (((-3 $ "failed") $) NIL) (($ $) NIL)) (-4078 (((-763)) NIL)) (-3746 (((-1244 $) (-917)) NIL) (((-1244 $)) NIL)) (-1826 (((-121) $ $) NIL)) (-4390 (((-121) $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-1316 (($ $ (-763)) NIL (|has| $ (-370))) (($ $) NIL (|has| $ (-370)))) (-3190 (($ $ (-763)) NIL) (($ $) NIL)) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2134 (((-121) $) NIL)) (-3800 (((-763)) NIL)) (-1934 (($ $ (-917)) NIL (|has| $ (-370))) (($ $) NIL)) (-1856 (((-1169 (-917) (-763)) (-568)) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2589 (((-121) $ $) NIL)) (-3986 (((-763)) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 $ "failed") $) NIL)) (-2857 (($ $) NIL)) (-3899 (($ (-1244 $)) NIL)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL)) (-2403 (($ $ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1733 (($) NIL)) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-4188 (($) NIL)) (-1748 (((-121) $) NIL)) (-1887 (($ $) NIL) (($ $ (-763)) NIL)) (-2197 (((-121) $) NIL)) (-1844 (((-828 (-917)) $) NIL) (((-917) $) NIL)) (-1598 (((-121) $) NIL)) (-2769 (($) NIL (|has| $ (-370)))) (-2151 (((-121) $) NIL (|has| $ (-370)))) (-4417 (($ $ (-917)) NIL (|has| $ (-370))) (($ $) NIL)) (-2214 (((-3 $ "failed") $) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1497 (((-1157 $) $ (-917)) NIL (|has| $ (-370))) (((-1157 $) $) NIL)) (-2291 (((-917) $) NIL)) (-1447 (((-1157 $) $) NIL (|has| $ (-370)))) (-2193 (((-3 (-1157 $) "failed") $ $) NIL (|has| $ (-370))) (((-1157 $) $) NIL (|has| $ (-370)))) (-3257 (($ $ (-1157 $)) NIL (|has| $ (-370)))) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4436 (($) NIL T CONST)) (-4357 (($ (-917)) NIL)) (-4051 (((-121) $) NIL)) (-4025 (((-1108) $) NIL)) (-2707 (($) NIL (|has| $ (-370)))) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) NIL)) (-3850 (((-420 $) $) NIL)) (-4321 (((-917)) NIL) (((-828 (-917))) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-2721 (((-3 (-763) "failed") $ $) NIL) (((-763) $) NIL)) (-3108 (((-139)) NIL)) (-4191 (($ $ (-763)) NIL) (($ $) NIL)) (-1836 (((-917) $) NIL) (((-828 (-917)) $) NIL)) (-1492 (((-1157 $)) NIL)) (-2330 (($) NIL)) (-1398 (($) NIL (|has| $ (-370)))) (-1656 (((-679 $) (-1244 $)) NIL) (((-1244 $) $) NIL)) (-4280 (((-568) $) NIL)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL)) (-3385 (((-3 $ "failed") $) NIL) (($ $) NIL)) (-3425 (((-763)) NIL)) (-2588 (((-1244 $) (-917)) NIL) (((-1244 $)) NIL)) (-2273 (((-121) $ $) NIL)) (-1413 (((-121) $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3412 (($ $ (-763)) NIL (|has| $ (-370))) (($ $) NIL (|has| $ (-370)))) (-3192 (($ $ (-763)) NIL) (($ $) NIL)) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL))) 
 (((-905 |#1|) (-13 (-350) (-327 $) (-609 (-568))) (-917)) (T -905)) 
 NIL 
 (-13 (-350) (-327 $) (-609 (-568))) 
-((-1747 (((-3 (-2 (|:| -4477 (-763)) (|:| -1864 |#5|)) "failed") (-334 |#2| |#3| |#4| |#5|)) 76)) (-3919 (((-121) (-334 |#2| |#3| |#4| |#5|)) 16)) (-4477 (((-3 (-763) "failed") (-334 |#2| |#3| |#4| |#5|)) 14))) 
-(((-906 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -4477 ((-3 (-763) "failed") (-334 |#2| |#3| |#4| |#5|))) (-15 -3919 ((-121) (-334 |#2| |#3| |#4| |#5|))) (-15 -1747 ((-3 (-2 (|:| -4477 (-763)) (|:| -1864 |#5|)) "failed") (-334 |#2| |#3| |#4| |#5|)))) (-13 (-842) (-558) (-1037 (-568))) (-432 |#1|) (-1219 |#2|) (-1219 (-409 |#3|)) (-340 |#2| |#3| |#4|)) (T -906)) 
-((-1747 (*1 *2 *3) (|partial| -12 (-5 *3 (-334 *5 *6 *7 *8)) (-4 *5 (-432 *4)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-4 *8 (-340 *5 *6 *7)) (-4 *4 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-2 (|:| -4477 (-763)) (|:| -1864 *8))) (-5 *1 (-906 *4 *5 *6 *7 *8)))) (-3919 (*1 *2 *3) (-12 (-5 *3 (-334 *5 *6 *7 *8)) (-4 *5 (-432 *4)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-4 *8 (-340 *5 *6 *7)) (-4 *4 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-121)) (-5 *1 (-906 *4 *5 *6 *7 *8)))) (-4477 (*1 *2 *3) (|partial| -12 (-5 *3 (-334 *5 *6 *7 *8)) (-4 *5 (-432 *4)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-4 *8 (-340 *5 *6 *7)) (-4 *4 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-763)) (-5 *1 (-906 *4 *5 *6 *7 *8))))) 
-(-10 -7 (-15 -4477 ((-3 (-763) "failed") (-334 |#2| |#3| |#4| |#5|))) (-15 -3919 ((-121) (-334 |#2| |#3| |#4| |#5|))) (-15 -1747 ((-3 (-2 (|:| -4477 (-763)) (|:| -1864 |#5|)) "failed") (-334 |#2| |#3| |#4| |#5|)))) 
-((-1747 (((-3 (-2 (|:| -4477 (-763)) (|:| -1864 |#3|)) "failed") (-334 (-409 (-568)) |#1| |#2| |#3|)) 56)) (-3919 (((-121) (-334 (-409 (-568)) |#1| |#2| |#3|)) 13)) (-4477 (((-3 (-763) "failed") (-334 (-409 (-568)) |#1| |#2| |#3|)) 11))) 
-(((-907 |#1| |#2| |#3|) (-10 -7 (-15 -4477 ((-3 (-763) "failed") (-334 (-409 (-568)) |#1| |#2| |#3|))) (-15 -3919 ((-121) (-334 (-409 (-568)) |#1| |#2| |#3|))) (-15 -1747 ((-3 (-2 (|:| -4477 (-763)) (|:| -1864 |#3|)) "failed") (-334 (-409 (-568)) |#1| |#2| |#3|)))) (-1219 (-409 (-568))) (-1219 (-409 |#1|)) (-340 (-409 (-568)) |#1| |#2|)) (T -907)) 
-((-1747 (*1 *2 *3) (|partial| -12 (-5 *3 (-334 (-409 (-568)) *4 *5 *6)) (-4 *4 (-1219 (-409 (-568)))) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 (-409 (-568)) *4 *5)) (-5 *2 (-2 (|:| -4477 (-763)) (|:| -1864 *6))) (-5 *1 (-907 *4 *5 *6)))) (-3919 (*1 *2 *3) (-12 (-5 *3 (-334 (-409 (-568)) *4 *5 *6)) (-4 *4 (-1219 (-409 (-568)))) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 (-409 (-568)) *4 *5)) (-5 *2 (-121)) (-5 *1 (-907 *4 *5 *6)))) (-4477 (*1 *2 *3) (|partial| -12 (-5 *3 (-334 (-409 (-568)) *4 *5 *6)) (-4 *4 (-1219 (-409 (-568)))) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 (-409 (-568)) *4 *5)) (-5 *2 (-763)) (-5 *1 (-907 *4 *5 *6))))) 
-(-10 -7 (-15 -4477 ((-3 (-763) "failed") (-334 (-409 (-568)) |#1| |#2| |#3|))) (-15 -3919 ((-121) (-334 (-409 (-568)) |#1| |#2| |#3|))) (-15 -1747 ((-3 (-2 (|:| -4477 (-763)) (|:| -1864 |#3|)) "failed") (-334 (-409 (-568)) |#1| |#2| |#3|)))) 
-((-3839 (((-1157 |#1|) |#2|) 36)) (-1859 ((|#2| |#2| (-634 |#1|)) 59) ((|#2| |#2| (-634 |#1|) (-568)) 61)) (-2773 (((-763) |#2|) 70)) (-3639 ((|#2| |#2| |#2| (-568)) 51)) (-3742 ((|#2| |#2| |#2|) 49)) (-3841 ((|#2| |#2| |#2|) 48)) (-3994 ((|#2| |#2| (-568)) 64)) (-4064 ((|#2| |#2| (-568)) 60)) (-2976 (((-634 |#2|) |#2|) 15)) (-2563 ((|#2| |#2|) 82)) (-3842 ((|#2| (-1 |#3| |#3|) |#2|) 40)) (-2844 (((-634 |#2|)) 26)) (-2943 (((-634 |#3|) (-568)) 92)) (-3062 (((-634 |#2|) (-763)) 93)) (-3039 ((|#2| |#2| (-568)) 71)) (-4335 ((|#3| |#2|) NIL)) (-1301 (((-763) |#2|) 83)) (-3206 (((-763) |#2| (-568)) 67)) (-1606 ((|#1| |#2| (-917)) 80)) (-3495 ((|#1| |#2|) 81))) 
-(((-908 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3842 (|#2| (-1 |#3| |#3|) |#2|)) (-15 -3206 ((-763) |#2| (-568))) (-15 -3839 ((-1157 |#1|) |#2|)) (-15 -2773 ((-763) |#2|)) (-15 -3841 (|#2| |#2| |#2|)) (-15 -3742 (|#2| |#2| |#2|)) (-15 -3639 (|#2| |#2| |#2| (-568))) (-15 -2563 (|#2| |#2|)) (-15 -4335 (|#3| |#2|)) (-15 -3994 (|#2| |#2| (-568))) (-15 -4064 (|#2| |#2| (-568))) (-15 -1859 (|#2| |#2| (-634 |#1|) (-568))) (-15 -1859 (|#2| |#2| (-634 |#1|))) (-15 -1606 (|#1| |#2| (-917))) (-15 -3495 (|#1| |#2|)) (-15 -3039 (|#2| |#2| (-568))) (-15 -2943 ((-634 |#3|) (-568))) (-15 -3062 ((-634 |#2|) (-763))) (-15 -1301 ((-763) |#2|)) (-15 -2844 ((-634 |#2|))) (-15 -2976 ((-634 |#2|) |#2|))) (-1047) (-324 |#1| |#3|) (-230 |#4| (-763)) (-763)) (T -908)) 
-((-2976 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *2 (-634 *3)) (-5 *1 (-908 *4 *3 *5 *6)) (-4 *3 (-324 *4 *5)))) (-2844 (*1 *2) (-12 (-4 *3 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *2 (-634 *4)) (-5 *1 (-908 *3 *4 *5 *6)) (-4 *4 (-324 *3 *5)))) (-1301 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-230 *6 *2)) (-14 *6 *2) (-5 *2 (-763)) (-5 *1 (-908 *4 *3 *5 *6)) (-4 *3 (-324 *4 *5)))) (-3062 (*1 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-1047)) (-4 *6 (-230 *7 *3)) (-14 *7 *3) (-5 *2 (-634 *5)) (-5 *1 (-908 *4 *5 *6 *7)) (-4 *5 (-324 *4 *6)))) (-2943 (*1 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1047)) (-4 *6 (-230 *7 (-763))) (-14 *7 (-763)) (-5 *2 (-634 *6)) (-5 *1 (-908 *4 *5 *6 *7)) (-4 *5 (-324 *4 *6)))) (-3039 (*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5)))) (-3495 (*1 *2 *3) (-12 (-4 *4 (-230 *5 (-763))) (-14 *5 (-763)) (-4 *2 (-1047)) (-5 *1 (-908 *2 *3 *4 *5)) (-4 *3 (-324 *2 *4)))) (-1606 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-4 *2 (-1047)) (-5 *1 (-908 *2 *3 *5 *6)) (-4 *3 (-324 *2 *5)))) (-1859 (*1 *2 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5)))) (-1859 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-568)) (-4 *5 (-1047)) (-4 *6 (-230 *7 (-763))) (-14 *7 (-763)) (-5 *1 (-908 *5 *2 *6 *7)) (-4 *2 (-324 *5 *6)))) (-4064 (*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5)))) (-3994 (*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5)))) (-4335 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-230 *5 (-763))) (-5 *1 (-908 *4 *3 *2 *5)) (-4 *3 (-324 *4 *2)) (-14 *5 (-763)))) (-2563 (*1 *2 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-230 *5 (-763))) (-14 *5 (-763)) (-5 *1 (-908 *3 *2 *4 *5)) (-4 *2 (-324 *3 *4)))) (-3639 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5)))) (-3742 (*1 *2 *2 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-230 *5 (-763))) (-14 *5 (-763)) (-5 *1 (-908 *3 *2 *4 *5)) (-4 *2 (-324 *3 *4)))) (-3841 (*1 *2 *2 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-230 *5 (-763))) (-14 *5 (-763)) (-5 *1 (-908 *3 *2 *4 *5)) (-4 *2 (-324 *3 *4)))) (-2773 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-230 *6 *2)) (-14 *6 *2) (-5 *2 (-763)) (-5 *1 (-908 *4 *3 *5 *6)) (-4 *3 (-324 *4 *5)))) (-3839 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *2 (-1157 *4)) (-5 *1 (-908 *4 *3 *5 *6)) (-4 *3 (-324 *4 *5)))) (-3206 (*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-1047)) (-4 *6 (-230 *7 *2)) (-14 *7 *2) (-5 *2 (-763)) (-5 *1 (-908 *5 *3 *6 *7)) (-4 *3 (-324 *5 *6)))) (-3842 (*1 *2 *3 *2) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-4 *4 (-1047)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5))))) 
-(-10 -7 (-15 -3842 (|#2| (-1 |#3| |#3|) |#2|)) (-15 -3206 ((-763) |#2| (-568))) (-15 -3839 ((-1157 |#1|) |#2|)) (-15 -2773 ((-763) |#2|)) (-15 -3841 (|#2| |#2| |#2|)) (-15 -3742 (|#2| |#2| |#2|)) (-15 -3639 (|#2| |#2| |#2| (-568))) (-15 -2563 (|#2| |#2|)) (-15 -4335 (|#3| |#2|)) (-15 -3994 (|#2| |#2| (-568))) (-15 -4064 (|#2| |#2| (-568))) (-15 -1859 (|#2| |#2| (-634 |#1|) (-568))) (-15 -1859 (|#2| |#2| (-634 |#1|))) (-15 -1606 (|#1| |#2| (-917))) (-15 -3495 (|#1| |#2|)) (-15 -3039 (|#2| |#2| (-568))) (-15 -2943 ((-634 |#3|) (-568))) (-15 -3062 ((-634 |#2|) (-763))) (-15 -1301 ((-763) |#2|)) (-15 -2844 ((-634 |#2|))) (-15 -2976 ((-634 |#2|) |#2|))) 
-((-3834 ((|#2| |#2|) 25)) (-4466 (((-568) (-634 (-2 (|:| |den| (-568)) (|:| |gcdnum| (-568))))) 15)) (-2515 (((-917) (-568)) 35)) (-1494 (((-568) |#2|) 42)) (-3738 (((-568) |#2|) 21) (((-2 (|:| |den| (-568)) (|:| |gcdnum| (-568))) |#1|) 20))) 
-(((-909 |#1| |#2|) (-10 -7 (-15 -2515 ((-917) (-568))) (-15 -3738 ((-2 (|:| |den| (-568)) (|:| |gcdnum| (-568))) |#1|)) (-15 -3738 ((-568) |#2|)) (-15 -4466 ((-568) (-634 (-2 (|:| |den| (-568)) (|:| |gcdnum| (-568)))))) (-15 -1494 ((-568) |#2|)) (-15 -3834 (|#2| |#2|))) (-1219 (-409 (-568))) (-1219 (-409 |#1|))) (T -909)) 
-((-3834 (*1 *2 *2) (-12 (-4 *3 (-1219 (-409 (-568)))) (-5 *1 (-909 *3 *2)) (-4 *2 (-1219 (-409 *3))))) (-1494 (*1 *2 *3) (-12 (-4 *4 (-1219 (-409 *2))) (-5 *2 (-568)) (-5 *1 (-909 *4 *3)) (-4 *3 (-1219 (-409 *4))))) (-4466 (*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| |den| (-568)) (|:| |gcdnum| (-568))))) (-4 *4 (-1219 (-409 *2))) (-5 *2 (-568)) (-5 *1 (-909 *4 *5)) (-4 *5 (-1219 (-409 *4))))) (-3738 (*1 *2 *3) (-12 (-4 *4 (-1219 (-409 *2))) (-5 *2 (-568)) (-5 *1 (-909 *4 *3)) (-4 *3 (-1219 (-409 *4))))) (-3738 (*1 *2 *3) (-12 (-4 *3 (-1219 (-409 (-568)))) (-5 *2 (-2 (|:| |den| (-568)) (|:| |gcdnum| (-568)))) (-5 *1 (-909 *3 *4)) (-4 *4 (-1219 (-409 *3))))) (-2515 (*1 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1219 (-409 *3))) (-5 *2 (-917)) (-5 *1 (-909 *4 *5)) (-4 *5 (-1219 (-409 *4)))))) 
-(-10 -7 (-15 -2515 ((-917) (-568))) (-15 -3738 ((-2 (|:| |den| (-568)) (|:| |gcdnum| (-568))) |#1|)) (-15 -3738 ((-568) |#2|)) (-15 -4466 ((-568) (-634 (-2 (|:| |den| (-568)) (|:| |gcdnum| (-568)))))) (-15 -1494 ((-568) |#2|)) (-15 -3834 (|#2| |#2|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-1492 ((|#1| $) 80)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1497 (((-121) $ $) NIL)) (-2671 (($) NIL T CONST)) (-2401 (($ $ $) NIL)) (-2925 (((-3 $ "failed") $) 74)) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-2231 (($ |#1| (-420 |#1|)) 72)) (-1985 (((-1157 |#1|) |#1| |#1|) 40)) (-2186 (($ $) 48)) (-2735 (((-121) $) NIL)) (-1427 (((-568) $) 77)) (-2464 (($ $ (-568)) 79)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3862 ((|#1| $) 76)) (-2360 (((-420 |#1|) $) 75)) (-3848 (((-420 $) $) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) 73)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-2720 (($ $) 38)) (-2745 (((-850) $) 98) (($ (-568)) 53) (($ $) NIL) (($ (-409 (-568))) NIL) (($ |#1|) 30) (((-409 |#1|) $) 58) (($ (-409 (-420 |#1|))) 66)) (-4078 (((-763)) 51)) (-1826 (((-121) $ $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) 23 T CONST)) (-1556 (($) 11 T CONST)) (-1717 (((-121) $ $) 67)) (-1779 (($ $ $) NIL)) (-1773 (($ $) 87) (($ $ $) NIL)) (-1767 (($ $ $) 37)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 89) (($ $ $) 36) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ |#1| $) 88) (($ $ |#1|) NIL))) 
-(((-910 |#1|) (-13 (-365) (-43 |#1|) (-10 -8 (-15 -2745 ((-409 |#1|) $)) (-15 -2745 ($ (-409 (-420 |#1|)))) (-15 -2720 ($ $)) (-15 -2360 ((-420 |#1|) $)) (-15 -3862 (|#1| $)) (-15 -2464 ($ $ (-568))) (-15 -1427 ((-568) $)) (-15 -1985 ((-1157 |#1|) |#1| |#1|)) (-15 -2186 ($ $)) (-15 -2231 ($ |#1| (-420 |#1|))) (-15 -1492 (|#1| $)))) (-301)) (T -910)) 
-((-2745 (*1 *2 *1) (-12 (-5 *2 (-409 *3)) (-5 *1 (-910 *3)) (-4 *3 (-301)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-409 (-420 *3))) (-4 *3 (-301)) (-5 *1 (-910 *3)))) (-2720 (*1 *1 *1) (-12 (-5 *1 (-910 *2)) (-4 *2 (-301)))) (-2360 (*1 *2 *1) (-12 (-5 *2 (-420 *3)) (-5 *1 (-910 *3)) (-4 *3 (-301)))) (-3862 (*1 *2 *1) (-12 (-5 *1 (-910 *2)) (-4 *2 (-301)))) (-2464 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-910 *3)) (-4 *3 (-301)))) (-1427 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-910 *3)) (-4 *3 (-301)))) (-1985 (*1 *2 *3 *3) (-12 (-5 *2 (-1157 *3)) (-5 *1 (-910 *3)) (-4 *3 (-301)))) (-2186 (*1 *1 *1) (-12 (-5 *1 (-910 *2)) (-4 *2 (-301)))) (-2231 (*1 *1 *2 *3) (-12 (-5 *3 (-420 *2)) (-4 *2 (-301)) (-5 *1 (-910 *2)))) (-1492 (*1 *2 *1) (-12 (-5 *1 (-910 *2)) (-4 *2 (-301))))) 
-(-13 (-365) (-43 |#1|) (-10 -8 (-15 -2745 ((-409 |#1|) $)) (-15 -2745 ($ (-409 (-420 |#1|)))) (-15 -2720 ($ $)) (-15 -2360 ((-420 |#1|) $)) (-15 -3862 (|#1| $)) (-15 -2464 ($ $ (-568))) (-15 -1427 ((-568) $)) (-15 -1985 ((-1157 |#1|) |#1| |#1|)) (-15 -2186 ($ $)) (-15 -2231 ($ |#1| (-420 |#1|))) (-15 -1492 (|#1| $)))) 
-((-2231 (((-57) (-953 |#1|) (-420 (-953 |#1|)) (-1161)) 16) (((-57) (-409 (-953 |#1|)) (-1161)) 17))) 
-(((-911 |#1|) (-10 -7 (-15 -2231 ((-57) (-409 (-953 |#1|)) (-1161))) (-15 -2231 ((-57) (-953 |#1|) (-420 (-953 |#1|)) (-1161)))) (-13 (-301) (-150))) (T -911)) 
-((-2231 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-420 (-953 *6))) (-5 *5 (-1161)) (-5 *3 (-953 *6)) (-4 *6 (-13 (-301) (-150))) (-5 *2 (-57)) (-5 *1 (-911 *6)))) (-2231 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-150))) (-5 *2 (-57)) (-5 *1 (-911 *5))))) 
-(-10 -7 (-15 -2231 ((-57) (-409 (-953 |#1|)) (-1161))) (-15 -2231 ((-57) (-953 |#1|) (-420 (-953 |#1|)) (-1161)))) 
-((-3400 ((|#4| (-634 |#4|)) 118) (((-1157 |#4|) (-1157 |#4|) (-1157 |#4|)) 65) ((|#4| |#4| |#4|) 117)) (-2721 (((-1157 |#4|) (-634 (-1157 |#4|))) 111) (((-1157 |#4|) (-1157 |#4|) (-1157 |#4|)) 48) ((|#4| (-634 |#4|)) 53) ((|#4| |#4| |#4|) 82))) 
-(((-912 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2721 (|#4| |#4| |#4|)) (-15 -2721 (|#4| (-634 |#4|))) (-15 -2721 ((-1157 |#4|) (-1157 |#4|) (-1157 |#4|))) (-15 -2721 ((-1157 |#4|) (-634 (-1157 |#4|)))) (-15 -3400 (|#4| |#4| |#4|)) (-15 -3400 ((-1157 |#4|) (-1157 |#4|) (-1157 |#4|))) (-15 -3400 (|#4| (-634 |#4|)))) (-788) (-842) (-301) (-950 |#3| |#1| |#2|)) (T -912)) 
-((-3400 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *6 *4 *5)) (-5 *1 (-912 *4 *5 *6 *2)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)))) (-3400 (*1 *2 *2 *2) (-12 (-5 *2 (-1157 *6)) (-4 *6 (-950 *5 *3 *4)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-301)) (-5 *1 (-912 *3 *4 *5 *6)))) (-3400 (*1 *2 *2 *2) (-12 (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-301)) (-5 *1 (-912 *3 *4 *5 *2)) (-4 *2 (-950 *5 *3 *4)))) (-2721 (*1 *2 *3) (-12 (-5 *3 (-634 (-1157 *7))) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)) (-5 *2 (-1157 *7)) (-5 *1 (-912 *4 *5 *6 *7)) (-4 *7 (-950 *6 *4 *5)))) (-2721 (*1 *2 *2 *2) (-12 (-5 *2 (-1157 *6)) (-4 *6 (-950 *5 *3 *4)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-301)) (-5 *1 (-912 *3 *4 *5 *6)))) (-2721 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *6 *4 *5)) (-5 *1 (-912 *4 *5 *6 *2)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)))) (-2721 (*1 *2 *2 *2) (-12 (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-301)) (-5 *1 (-912 *3 *4 *5 *2)) (-4 *2 (-950 *5 *3 *4))))) 
-(-10 -7 (-15 -2721 (|#4| |#4| |#4|)) (-15 -2721 (|#4| (-634 |#4|))) (-15 -2721 ((-1157 |#4|) (-1157 |#4|) (-1157 |#4|))) (-15 -2721 ((-1157 |#4|) (-634 (-1157 |#4|)))) (-15 -3400 (|#4| |#4| |#4|)) (-15 -3400 ((-1157 |#4|) (-1157 |#4|) (-1157 |#4|))) (-15 -3400 (|#4| (-634 |#4|)))) 
-((-1763 (((-899 (-568)) (-972)) 22) (((-899 (-568)) (-634 (-568))) 19)) (-3073 (((-899 (-568)) (-634 (-568))) 46) (((-899 (-568)) (-917)) 47)) (-2319 (((-899 (-568))) 23)) (-1627 (((-899 (-568))) 36) (((-899 (-568)) (-634 (-568))) 35)) (-3702 (((-899 (-568))) 34) (((-899 (-568)) (-634 (-568))) 33)) (-1286 (((-899 (-568))) 32) (((-899 (-568)) (-634 (-568))) 31)) (-3631 (((-899 (-568))) 30) (((-899 (-568)) (-634 (-568))) 29)) (-1652 (((-899 (-568))) 28) (((-899 (-568)) (-634 (-568))) 27)) (-3086 (((-899 (-568))) 38) (((-899 (-568)) (-634 (-568))) 37)) (-3141 (((-899 (-568)) (-634 (-568))) 50) (((-899 (-568)) (-917)) 51)) (-3965 (((-899 (-568)) (-634 (-568))) 48) (((-899 (-568)) (-917)) 49)) (-2927 (((-899 (-568)) (-634 (-568))) 43) (((-899 (-568)) (-917)) 45)) (-3803 (((-899 (-568)) (-634 (-917))) 40))) 
-(((-913) (-10 -7 (-15 -3073 ((-899 (-568)) (-917))) (-15 -3073 ((-899 (-568)) (-634 (-568)))) (-15 -2927 ((-899 (-568)) (-917))) (-15 -2927 ((-899 (-568)) (-634 (-568)))) (-15 -3803 ((-899 (-568)) (-634 (-917)))) (-15 -3965 ((-899 (-568)) (-917))) (-15 -3965 ((-899 (-568)) (-634 (-568)))) (-15 -3141 ((-899 (-568)) (-917))) (-15 -3141 ((-899 (-568)) (-634 (-568)))) (-15 -1652 ((-899 (-568)) (-634 (-568)))) (-15 -1652 ((-899 (-568)))) (-15 -3631 ((-899 (-568)) (-634 (-568)))) (-15 -3631 ((-899 (-568)))) (-15 -1286 ((-899 (-568)) (-634 (-568)))) (-15 -1286 ((-899 (-568)))) (-15 -3702 ((-899 (-568)) (-634 (-568)))) (-15 -3702 ((-899 (-568)))) (-15 -1627 ((-899 (-568)) (-634 (-568)))) (-15 -1627 ((-899 (-568)))) (-15 -3086 ((-899 (-568)) (-634 (-568)))) (-15 -3086 ((-899 (-568)))) (-15 -2319 ((-899 (-568)))) (-15 -1763 ((-899 (-568)) (-634 (-568)))) (-15 -1763 ((-899 (-568)) (-972))))) (T -913)) 
-((-1763 (*1 *2 *3) (-12 (-5 *3 (-972)) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-1763 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-2319 (*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-3086 (*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-3086 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-1627 (*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-1627 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-3702 (*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-3702 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-1286 (*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-1286 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-3631 (*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-3631 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-1652 (*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-1652 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-3141 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-3141 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-3965 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-3965 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-3803 (*1 *2 *3) (-12 (-5 *3 (-634 (-917))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-2927 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-2927 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-3073 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-3073 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
-(-10 -7 (-15 -3073 ((-899 (-568)) (-917))) (-15 -3073 ((-899 (-568)) (-634 (-568)))) (-15 -2927 ((-899 (-568)) (-917))) (-15 -2927 ((-899 (-568)) (-634 (-568)))) (-15 -3803 ((-899 (-568)) (-634 (-917)))) (-15 -3965 ((-899 (-568)) (-917))) (-15 -3965 ((-899 (-568)) (-634 (-568)))) (-15 -3141 ((-899 (-568)) (-917))) (-15 -3141 ((-899 (-568)) (-634 (-568)))) (-15 -1652 ((-899 (-568)) (-634 (-568)))) (-15 -1652 ((-899 (-568)))) (-15 -3631 ((-899 (-568)) (-634 (-568)))) (-15 -3631 ((-899 (-568)))) (-15 -1286 ((-899 (-568)) (-634 (-568)))) (-15 -1286 ((-899 (-568)))) (-15 -3702 ((-899 (-568)) (-634 (-568)))) (-15 -3702 ((-899 (-568)))) (-15 -1627 ((-899 (-568)) (-634 (-568)))) (-15 -1627 ((-899 (-568)))) (-15 -3086 ((-899 (-568)) (-634 (-568)))) (-15 -3086 ((-899 (-568)))) (-15 -2319 ((-899 (-568)))) (-15 -1763 ((-899 (-568)) (-634 (-568)))) (-15 -1763 ((-899 (-568)) (-972)))) 
-((-4138 (((-634 (-953 |#1|)) (-634 (-953 |#1|)) (-634 (-1161))) 10)) (-1532 (((-634 (-953 |#1|)) (-634 (-953 |#1|)) (-634 (-1161))) 9))) 
-(((-914 |#1|) (-10 -7 (-15 -1532 ((-634 (-953 |#1|)) (-634 (-953 |#1|)) (-634 (-1161)))) (-15 -4138 ((-634 (-953 |#1|)) (-634 (-953 |#1|)) (-634 (-1161))))) (-453)) (T -914)) 
-((-4138 (*1 *2 *2 *3) (-12 (-5 *2 (-634 (-953 *4))) (-5 *3 (-634 (-1161))) (-4 *4 (-453)) (-5 *1 (-914 *4)))) (-1532 (*1 *2 *2 *3) (-12 (-5 *2 (-634 (-953 *4))) (-5 *3 (-634 (-1161))) (-4 *4 (-453)) (-5 *1 (-914 *4))))) 
-(-10 -7 (-15 -1532 ((-634 (-953 |#1|)) (-634 (-953 |#1|)) (-634 (-1161)))) (-15 -4138 ((-634 (-953 |#1|)) (-634 (-953 |#1|)) (-634 (-1161))))) 
-((-2745 (((-310 |#1|) (-489)) 15))) 
-(((-915 |#1|) (-10 -7 (-15 -2745 ((-310 |#1|) (-489)))) (-13 (-842) (-558))) (T -915)) 
-((-2745 (*1 *2 *3) (-12 (-5 *3 (-489)) (-5 *2 (-310 *4)) (-5 *1 (-915 *4)) (-4 *4 (-13 (-842) (-558)))))) 
-(-10 -7 (-15 -2745 ((-310 |#1|) (-489)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-2925 (((-3 $ "failed") $) 33)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 49)) (-2735 (((-121) $) 30)) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-2595 (((-3 $ "failed") $ $) 41)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42)) (-4078 (((-763)) 28)) (-1826 (((-121) $ $) 38)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
+((-3844 (((-3 (-2 (|:| -1844 (-763)) (|:| -1866 |#5|)) "failed") (-334 |#2| |#3| |#4| |#5|)) 76)) (-2161 (((-121) (-334 |#2| |#3| |#4| |#5|)) 16)) (-1844 (((-3 (-763) "failed") (-334 |#2| |#3| |#4| |#5|)) 14))) 
+(((-906 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1844 ((-3 (-763) "failed") (-334 |#2| |#3| |#4| |#5|))) (-15 -2161 ((-121) (-334 |#2| |#3| |#4| |#5|))) (-15 -3844 ((-3 (-2 (|:| -1844 (-763)) (|:| -1866 |#5|)) "failed") (-334 |#2| |#3| |#4| |#5|)))) (-13 (-842) (-558) (-1037 (-568))) (-432 |#1|) (-1219 |#2|) (-1219 (-409 |#3|)) (-340 |#2| |#3| |#4|)) (T -906)) 
+((-3844 (*1 *2 *3) (|partial| -12 (-5 *3 (-334 *5 *6 *7 *8)) (-4 *5 (-432 *4)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-4 *8 (-340 *5 *6 *7)) (-4 *4 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-2 (|:| -1844 (-763)) (|:| -1866 *8))) (-5 *1 (-906 *4 *5 *6 *7 *8)))) (-2161 (*1 *2 *3) (-12 (-5 *3 (-334 *5 *6 *7 *8)) (-4 *5 (-432 *4)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-4 *8 (-340 *5 *6 *7)) (-4 *4 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-121)) (-5 *1 (-906 *4 *5 *6 *7 *8)))) (-1844 (*1 *2 *3) (|partial| -12 (-5 *3 (-334 *5 *6 *7 *8)) (-4 *5 (-432 *4)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-4 *8 (-340 *5 *6 *7)) (-4 *4 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-763)) (-5 *1 (-906 *4 *5 *6 *7 *8))))) 
+(-10 -7 (-15 -1844 ((-3 (-763) "failed") (-334 |#2| |#3| |#4| |#5|))) (-15 -2161 ((-121) (-334 |#2| |#3| |#4| |#5|))) (-15 -3844 ((-3 (-2 (|:| -1844 (-763)) (|:| -1866 |#5|)) "failed") (-334 |#2| |#3| |#4| |#5|)))) 
+((-3844 (((-3 (-2 (|:| -1844 (-763)) (|:| -1866 |#3|)) "failed") (-334 (-409 (-568)) |#1| |#2| |#3|)) 56)) (-2161 (((-121) (-334 (-409 (-568)) |#1| |#2| |#3|)) 13)) (-1844 (((-3 (-763) "failed") (-334 (-409 (-568)) |#1| |#2| |#3|)) 11))) 
+(((-907 |#1| |#2| |#3|) (-10 -7 (-15 -1844 ((-3 (-763) "failed") (-334 (-409 (-568)) |#1| |#2| |#3|))) (-15 -2161 ((-121) (-334 (-409 (-568)) |#1| |#2| |#3|))) (-15 -3844 ((-3 (-2 (|:| -1844 (-763)) (|:| -1866 |#3|)) "failed") (-334 (-409 (-568)) |#1| |#2| |#3|)))) (-1219 (-409 (-568))) (-1219 (-409 |#1|)) (-340 (-409 (-568)) |#1| |#2|)) (T -907)) 
+((-3844 (*1 *2 *3) (|partial| -12 (-5 *3 (-334 (-409 (-568)) *4 *5 *6)) (-4 *4 (-1219 (-409 (-568)))) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 (-409 (-568)) *4 *5)) (-5 *2 (-2 (|:| -1844 (-763)) (|:| -1866 *6))) (-5 *1 (-907 *4 *5 *6)))) (-2161 (*1 *2 *3) (-12 (-5 *3 (-334 (-409 (-568)) *4 *5 *6)) (-4 *4 (-1219 (-409 (-568)))) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 (-409 (-568)) *4 *5)) (-5 *2 (-121)) (-5 *1 (-907 *4 *5 *6)))) (-1844 (*1 *2 *3) (|partial| -12 (-5 *3 (-334 (-409 (-568)) *4 *5 *6)) (-4 *4 (-1219 (-409 (-568)))) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 (-409 (-568)) *4 *5)) (-5 *2 (-763)) (-5 *1 (-907 *4 *5 *6))))) 
+(-10 -7 (-15 -1844 ((-3 (-763) "failed") (-334 (-409 (-568)) |#1| |#2| |#3|))) (-15 -2161 ((-121) (-334 (-409 (-568)) |#1| |#2| |#3|))) (-15 -3844 ((-3 (-2 (|:| -1844 (-763)) (|:| -1866 |#3|)) "failed") (-334 (-409 (-568)) |#1| |#2| |#3|)))) 
+((-3840 (((-1157 |#1|) |#2|) 36)) (-1861 ((|#2| |#2| (-634 |#1|)) 59) ((|#2| |#2| (-634 |#1|) (-568)) 61)) (-3528 (((-763) |#2|) 70)) (-3186 ((|#2| |#2| |#2| (-568)) 51)) (-2572 ((|#2| |#2| |#2|) 49)) (-1860 ((|#2| |#2| |#2|) 48)) (-1312 ((|#2| |#2| (-568)) 64)) (-1626 ((|#2| |#2| (-568)) 60)) (-3062 (((-634 |#2|) |#2|) 15)) (-1936 ((|#2| |#2|) 82)) (-1865 ((|#2| (-1 |#3| |#3|) |#2|) 40)) (-3930 (((-634 |#2|)) 26)) (-2955 (((-634 |#3|) (-568)) 92)) (-2316 (((-634 |#2|) (-763)) 93)) (-2219 ((|#2| |#2| (-568)) 71)) (-3160 ((|#3| |#2|) NIL)) (-3294 (((-763) |#2|) 83)) (-1836 (((-763) |#2| (-568)) 67)) (-1373 ((|#1| |#2| (-917)) 80)) (-3497 ((|#1| |#2|) 81))) 
+(((-908 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1865 (|#2| (-1 |#3| |#3|) |#2|)) (-15 -1836 ((-763) |#2| (-568))) (-15 -3840 ((-1157 |#1|) |#2|)) (-15 -3528 ((-763) |#2|)) (-15 -1860 (|#2| |#2| |#2|)) (-15 -2572 (|#2| |#2| |#2|)) (-15 -3186 (|#2| |#2| |#2| (-568))) (-15 -1936 (|#2| |#2|)) (-15 -3160 (|#3| |#2|)) (-15 -1312 (|#2| |#2| (-568))) (-15 -1626 (|#2| |#2| (-568))) (-15 -1861 (|#2| |#2| (-634 |#1|) (-568))) (-15 -1861 (|#2| |#2| (-634 |#1|))) (-15 -1373 (|#1| |#2| (-917))) (-15 -3497 (|#1| |#2|)) (-15 -2219 (|#2| |#2| (-568))) (-15 -2955 ((-634 |#3|) (-568))) (-15 -2316 ((-634 |#2|) (-763))) (-15 -3294 ((-763) |#2|)) (-15 -3930 ((-634 |#2|))) (-15 -3062 ((-634 |#2|) |#2|))) (-1047) (-324 |#1| |#3|) (-230 |#4| (-763)) (-763)) (T -908)) 
+((-3062 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *2 (-634 *3)) (-5 *1 (-908 *4 *3 *5 *6)) (-4 *3 (-324 *4 *5)))) (-3930 (*1 *2) (-12 (-4 *3 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *2 (-634 *4)) (-5 *1 (-908 *3 *4 *5 *6)) (-4 *4 (-324 *3 *5)))) (-3294 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-230 *6 *2)) (-14 *6 *2) (-5 *2 (-763)) (-5 *1 (-908 *4 *3 *5 *6)) (-4 *3 (-324 *4 *5)))) (-2316 (*1 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-1047)) (-4 *6 (-230 *7 *3)) (-14 *7 *3) (-5 *2 (-634 *5)) (-5 *1 (-908 *4 *5 *6 *7)) (-4 *5 (-324 *4 *6)))) (-2955 (*1 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1047)) (-4 *6 (-230 *7 (-763))) (-14 *7 (-763)) (-5 *2 (-634 *6)) (-5 *1 (-908 *4 *5 *6 *7)) (-4 *5 (-324 *4 *6)))) (-2219 (*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5)))) (-3497 (*1 *2 *3) (-12 (-4 *4 (-230 *5 (-763))) (-14 *5 (-763)) (-4 *2 (-1047)) (-5 *1 (-908 *2 *3 *4 *5)) (-4 *3 (-324 *2 *4)))) (-1373 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-4 *2 (-1047)) (-5 *1 (-908 *2 *3 *5 *6)) (-4 *3 (-324 *2 *5)))) (-1861 (*1 *2 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5)))) (-1861 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-568)) (-4 *5 (-1047)) (-4 *6 (-230 *7 (-763))) (-14 *7 (-763)) (-5 *1 (-908 *5 *2 *6 *7)) (-4 *2 (-324 *5 *6)))) (-1626 (*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5)))) (-1312 (*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5)))) (-3160 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-230 *5 (-763))) (-5 *1 (-908 *4 *3 *2 *5)) (-4 *3 (-324 *4 *2)) (-14 *5 (-763)))) (-1936 (*1 *2 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-230 *5 (-763))) (-14 *5 (-763)) (-5 *1 (-908 *3 *2 *4 *5)) (-4 *2 (-324 *3 *4)))) (-3186 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5)))) (-2572 (*1 *2 *2 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-230 *5 (-763))) (-14 *5 (-763)) (-5 *1 (-908 *3 *2 *4 *5)) (-4 *2 (-324 *3 *4)))) (-1860 (*1 *2 *2 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-230 *5 (-763))) (-14 *5 (-763)) (-5 *1 (-908 *3 *2 *4 *5)) (-4 *2 (-324 *3 *4)))) (-3528 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-230 *6 *2)) (-14 *6 *2) (-5 *2 (-763)) (-5 *1 (-908 *4 *3 *5 *6)) (-4 *3 (-324 *4 *5)))) (-3840 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *2 (-1157 *4)) (-5 *1 (-908 *4 *3 *5 *6)) (-4 *3 (-324 *4 *5)))) (-1836 (*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-1047)) (-4 *6 (-230 *7 *2)) (-14 *7 *2) (-5 *2 (-763)) (-5 *1 (-908 *5 *3 *6 *7)) (-4 *3 (-324 *5 *6)))) (-1865 (*1 *2 *3 *2) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-4 *4 (-1047)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5))))) 
+(-10 -7 (-15 -1865 (|#2| (-1 |#3| |#3|) |#2|)) (-15 -1836 ((-763) |#2| (-568))) (-15 -3840 ((-1157 |#1|) |#2|)) (-15 -3528 ((-763) |#2|)) (-15 -1860 (|#2| |#2| |#2|)) (-15 -2572 (|#2| |#2| |#2|)) (-15 -3186 (|#2| |#2| |#2| (-568))) (-15 -1936 (|#2| |#2|)) (-15 -3160 (|#3| |#2|)) (-15 -1312 (|#2| |#2| (-568))) (-15 -1626 (|#2| |#2| (-568))) (-15 -1861 (|#2| |#2| (-634 |#1|) (-568))) (-15 -1861 (|#2| |#2| (-634 |#1|))) (-15 -1373 (|#1| |#2| (-917))) (-15 -3497 (|#1| |#2|)) (-15 -2219 (|#2| |#2| (-568))) (-15 -2955 ((-634 |#3|) (-568))) (-15 -2316 ((-634 |#2|) (-763))) (-15 -3294 ((-763) |#2|)) (-15 -3930 ((-634 |#2|))) (-15 -3062 ((-634 |#2|) |#2|))) 
+((-1833 ((|#2| |#2|) 25)) (-1796 (((-568) (-634 (-2 (|:| |den| (-568)) (|:| |gcdnum| (-568))))) 15)) (-1695 (((-917) (-568)) 35)) (-2574 (((-568) |#2|) 42)) (-2552 (((-568) |#2|) 21) (((-2 (|:| |den| (-568)) (|:| |gcdnum| (-568))) |#1|) 20))) 
+(((-909 |#1| |#2|) (-10 -7 (-15 -1695 ((-917) (-568))) (-15 -2552 ((-2 (|:| |den| (-568)) (|:| |gcdnum| (-568))) |#1|)) (-15 -2552 ((-568) |#2|)) (-15 -1796 ((-568) (-634 (-2 (|:| |den| (-568)) (|:| |gcdnum| (-568)))))) (-15 -2574 ((-568) |#2|)) (-15 -1833 (|#2| |#2|))) (-1219 (-409 (-568))) (-1219 (-409 |#1|))) (T -909)) 
+((-1833 (*1 *2 *2) (-12 (-4 *3 (-1219 (-409 (-568)))) (-5 *1 (-909 *3 *2)) (-4 *2 (-1219 (-409 *3))))) (-2574 (*1 *2 *3) (-12 (-4 *4 (-1219 (-409 *2))) (-5 *2 (-568)) (-5 *1 (-909 *4 *3)) (-4 *3 (-1219 (-409 *4))))) (-1796 (*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| |den| (-568)) (|:| |gcdnum| (-568))))) (-4 *4 (-1219 (-409 *2))) (-5 *2 (-568)) (-5 *1 (-909 *4 *5)) (-4 *5 (-1219 (-409 *4))))) (-2552 (*1 *2 *3) (-12 (-4 *4 (-1219 (-409 *2))) (-5 *2 (-568)) (-5 *1 (-909 *4 *3)) (-4 *3 (-1219 (-409 *4))))) (-2552 (*1 *2 *3) (-12 (-4 *3 (-1219 (-409 (-568)))) (-5 *2 (-2 (|:| |den| (-568)) (|:| |gcdnum| (-568)))) (-5 *1 (-909 *3 *4)) (-4 *4 (-1219 (-409 *3))))) (-1695 (*1 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1219 (-409 *3))) (-5 *2 (-917)) (-5 *1 (-909 *4 *5)) (-4 *5 (-1219 (-409 *4)))))) 
+(-10 -7 (-15 -1695 ((-917) (-568))) (-15 -2552 ((-2 (|:| |den| (-568)) (|:| |gcdnum| (-568))) |#1|)) (-15 -2552 ((-568) |#2|)) (-15 -1796 ((-568) (-634 (-2 (|:| |den| (-568)) (|:| |gcdnum| (-568)))))) (-15 -2574 ((-568) |#2|)) (-15 -1833 (|#2| |#2|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2563 ((|#1| $) 80)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2589 (((-121) $ $) NIL)) (-4490 (($) NIL T CONST)) (-2403 (($ $ $) NIL)) (-2902 (((-3 $ "failed") $) 74)) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-2640 (($ |#1| (-420 |#1|)) 72)) (-4432 (((-1157 |#1|) |#1| |#1|) 40)) (-1960 (($ $) 48)) (-1598 (((-121) $) NIL)) (-2222 (((-568) $) 77)) (-2586 (($ $ (-568)) 79)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1938 ((|#1| $) 76)) (-4032 (((-420 |#1|) $) 75)) (-3850 (((-420 $) $) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) 73)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-1538 (($ $) 38)) (-2747 (((-850) $) 98) (($ (-568)) 53) (($ $) NIL) (($ (-409 (-568))) NIL) (($ |#1|) 30) (((-409 |#1|) $) 58) (($ (-409 (-420 |#1|))) 66)) (-3425 (((-763)) 51)) (-2273 (((-121) $ $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) 23 T CONST)) (-1557 (($) 11 T CONST)) (-1719 (((-121) $ $) 67)) (-1781 (($ $ $) NIL)) (-1775 (($ $) 87) (($ $ $) NIL)) (-1769 (($ $ $) 37)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 89) (($ $ $) 36) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ |#1| $) 88) (($ $ |#1|) NIL))) 
+(((-910 |#1|) (-13 (-365) (-43 |#1|) (-10 -8 (-15 -2747 ((-409 |#1|) $)) (-15 -2747 ($ (-409 (-420 |#1|)))) (-15 -1538 ($ $)) (-15 -4032 ((-420 |#1|) $)) (-15 -1938 (|#1| $)) (-15 -2586 ($ $ (-568))) (-15 -2222 ((-568) $)) (-15 -4432 ((-1157 |#1|) |#1| |#1|)) (-15 -1960 ($ $)) (-15 -2640 ($ |#1| (-420 |#1|))) (-15 -2563 (|#1| $)))) (-301)) (T -910)) 
+((-2747 (*1 *2 *1) (-12 (-5 *2 (-409 *3)) (-5 *1 (-910 *3)) (-4 *3 (-301)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-409 (-420 *3))) (-4 *3 (-301)) (-5 *1 (-910 *3)))) (-1538 (*1 *1 *1) (-12 (-5 *1 (-910 *2)) (-4 *2 (-301)))) (-4032 (*1 *2 *1) (-12 (-5 *2 (-420 *3)) (-5 *1 (-910 *3)) (-4 *3 (-301)))) (-1938 (*1 *2 *1) (-12 (-5 *1 (-910 *2)) (-4 *2 (-301)))) (-2586 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-910 *3)) (-4 *3 (-301)))) (-2222 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-910 *3)) (-4 *3 (-301)))) (-4432 (*1 *2 *3 *3) (-12 (-5 *2 (-1157 *3)) (-5 *1 (-910 *3)) (-4 *3 (-301)))) (-1960 (*1 *1 *1) (-12 (-5 *1 (-910 *2)) (-4 *2 (-301)))) (-2640 (*1 *1 *2 *3) (-12 (-5 *3 (-420 *2)) (-4 *2 (-301)) (-5 *1 (-910 *2)))) (-2563 (*1 *2 *1) (-12 (-5 *1 (-910 *2)) (-4 *2 (-301))))) 
+(-13 (-365) (-43 |#1|) (-10 -8 (-15 -2747 ((-409 |#1|) $)) (-15 -2747 ($ (-409 (-420 |#1|)))) (-15 -1538 ($ $)) (-15 -4032 ((-420 |#1|) $)) (-15 -1938 (|#1| $)) (-15 -2586 ($ $ (-568))) (-15 -2222 ((-568) $)) (-15 -4432 ((-1157 |#1|) |#1| |#1|)) (-15 -1960 ($ $)) (-15 -2640 ($ |#1| (-420 |#1|))) (-15 -2563 (|#1| $)))) 
+((-2640 (((-57) (-953 |#1|) (-420 (-953 |#1|)) (-1161)) 16) (((-57) (-409 (-953 |#1|)) (-1161)) 17))) 
+(((-911 |#1|) (-10 -7 (-15 -2640 ((-57) (-409 (-953 |#1|)) (-1161))) (-15 -2640 ((-57) (-953 |#1|) (-420 (-953 |#1|)) (-1161)))) (-13 (-301) (-150))) (T -911)) 
+((-2640 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-420 (-953 *6))) (-5 *5 (-1161)) (-5 *3 (-953 *6)) (-4 *6 (-13 (-301) (-150))) (-5 *2 (-57)) (-5 *1 (-911 *6)))) (-2640 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-150))) (-5 *2 (-57)) (-5 *1 (-911 *5))))) 
+(-10 -7 (-15 -2640 ((-57) (-409 (-953 |#1|)) (-1161))) (-15 -2640 ((-57) (-953 |#1|) (-420 (-953 |#1|)) (-1161)))) 
+((-1539 ((|#4| (-634 |#4|)) 118) (((-1157 |#4|) (-1157 |#4|) (-1157 |#4|)) 65) ((|#4| |#4| |#4|) 117)) (-2723 (((-1157 |#4|) (-634 (-1157 |#4|))) 111) (((-1157 |#4|) (-1157 |#4|) (-1157 |#4|)) 48) ((|#4| (-634 |#4|)) 53) ((|#4| |#4| |#4|) 82))) 
+(((-912 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2723 (|#4| |#4| |#4|)) (-15 -2723 (|#4| (-634 |#4|))) (-15 -2723 ((-1157 |#4|) (-1157 |#4|) (-1157 |#4|))) (-15 -2723 ((-1157 |#4|) (-634 (-1157 |#4|)))) (-15 -1539 (|#4| |#4| |#4|)) (-15 -1539 ((-1157 |#4|) (-1157 |#4|) (-1157 |#4|))) (-15 -1539 (|#4| (-634 |#4|)))) (-788) (-842) (-301) (-950 |#3| |#1| |#2|)) (T -912)) 
+((-1539 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *6 *4 *5)) (-5 *1 (-912 *4 *5 *6 *2)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)))) (-1539 (*1 *2 *2 *2) (-12 (-5 *2 (-1157 *6)) (-4 *6 (-950 *5 *3 *4)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-301)) (-5 *1 (-912 *3 *4 *5 *6)))) (-1539 (*1 *2 *2 *2) (-12 (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-301)) (-5 *1 (-912 *3 *4 *5 *2)) (-4 *2 (-950 *5 *3 *4)))) (-2723 (*1 *2 *3) (-12 (-5 *3 (-634 (-1157 *7))) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)) (-5 *2 (-1157 *7)) (-5 *1 (-912 *4 *5 *6 *7)) (-4 *7 (-950 *6 *4 *5)))) (-2723 (*1 *2 *2 *2) (-12 (-5 *2 (-1157 *6)) (-4 *6 (-950 *5 *3 *4)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-301)) (-5 *1 (-912 *3 *4 *5 *6)))) (-2723 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *6 *4 *5)) (-5 *1 (-912 *4 *5 *6 *2)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)))) (-2723 (*1 *2 *2 *2) (-12 (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-301)) (-5 *1 (-912 *3 *4 *5 *2)) (-4 *2 (-950 *5 *3 *4))))) 
+(-10 -7 (-15 -2723 (|#4| |#4| |#4|)) (-15 -2723 (|#4| (-634 |#4|))) (-15 -2723 ((-1157 |#4|) (-1157 |#4|) (-1157 |#4|))) (-15 -2723 ((-1157 |#4|) (-634 (-1157 |#4|)))) (-15 -1539 (|#4| |#4| |#4|)) (-15 -1539 ((-1157 |#4|) (-1157 |#4|) (-1157 |#4|))) (-15 -1539 (|#4| (-634 |#4|)))) 
+((-3928 (((-899 (-568)) (-972)) 22) (((-899 (-568)) (-634 (-568))) 19)) (-2375 (((-899 (-568)) (-634 (-568))) 46) (((-899 (-568)) (-917)) 47)) (-3766 (((-899 (-568))) 23)) (-1498 (((-899 (-568))) 36) (((-899 (-568)) (-634 (-568))) 35)) (-2376 (((-899 (-568))) 34) (((-899 (-568)) (-634 (-568))) 33)) (-3175 (((-899 (-568))) 32) (((-899 (-568)) (-634 (-568))) 31)) (-3138 (((-899 (-568))) 30) (((-899 (-568)) (-634 (-568))) 29)) (-3326 (((-899 (-568))) 28) (((-899 (-568)) (-634 (-568))) 27)) (-2442 (((-899 (-568))) 38) (((-899 (-568)) (-634 (-568))) 37)) (-2718 (((-899 (-568)) (-634 (-568))) 50) (((-899 (-568)) (-917)) 51)) (-4425 (((-899 (-568)) (-634 (-568))) 48) (((-899 (-568)) (-917)) 49)) (-2905 (((-899 (-568)) (-634 (-568))) 43) (((-899 (-568)) (-917)) 45)) (-1703 (((-899 (-568)) (-634 (-917))) 40))) 
+(((-913) (-10 -7 (-15 -2375 ((-899 (-568)) (-917))) (-15 -2375 ((-899 (-568)) (-634 (-568)))) (-15 -2905 ((-899 (-568)) (-917))) (-15 -2905 ((-899 (-568)) (-634 (-568)))) (-15 -1703 ((-899 (-568)) (-634 (-917)))) (-15 -4425 ((-899 (-568)) (-917))) (-15 -4425 ((-899 (-568)) (-634 (-568)))) (-15 -2718 ((-899 (-568)) (-917))) (-15 -2718 ((-899 (-568)) (-634 (-568)))) (-15 -3326 ((-899 (-568)) (-634 (-568)))) (-15 -3326 ((-899 (-568)))) (-15 -3138 ((-899 (-568)) (-634 (-568)))) (-15 -3138 ((-899 (-568)))) (-15 -3175 ((-899 (-568)) (-634 (-568)))) (-15 -3175 ((-899 (-568)))) (-15 -2376 ((-899 (-568)) (-634 (-568)))) (-15 -2376 ((-899 (-568)))) (-15 -1498 ((-899 (-568)) (-634 (-568)))) (-15 -1498 ((-899 (-568)))) (-15 -2442 ((-899 (-568)) (-634 (-568)))) (-15 -2442 ((-899 (-568)))) (-15 -3766 ((-899 (-568)))) (-15 -3928 ((-899 (-568)) (-634 (-568)))) (-15 -3928 ((-899 (-568)) (-972))))) (T -913)) 
+((-3928 (*1 *2 *3) (-12 (-5 *3 (-972)) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-3928 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-3766 (*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-2442 (*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-2442 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-1498 (*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-1498 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-2376 (*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-2376 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-3175 (*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-3175 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-3138 (*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-3138 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-3326 (*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-3326 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-2718 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-2718 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-4425 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-4425 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-1703 (*1 *2 *3) (-12 (-5 *3 (-634 (-917))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-2905 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-2905 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-2375 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) (-2375 (*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
+(-10 -7 (-15 -2375 ((-899 (-568)) (-917))) (-15 -2375 ((-899 (-568)) (-634 (-568)))) (-15 -2905 ((-899 (-568)) (-917))) (-15 -2905 ((-899 (-568)) (-634 (-568)))) (-15 -1703 ((-899 (-568)) (-634 (-917)))) (-15 -4425 ((-899 (-568)) (-917))) (-15 -4425 ((-899 (-568)) (-634 (-568)))) (-15 -2718 ((-899 (-568)) (-917))) (-15 -2718 ((-899 (-568)) (-634 (-568)))) (-15 -3326 ((-899 (-568)) (-634 (-568)))) (-15 -3326 ((-899 (-568)))) (-15 -3138 ((-899 (-568)) (-634 (-568)))) (-15 -3138 ((-899 (-568)))) (-15 -3175 ((-899 (-568)) (-634 (-568)))) (-15 -3175 ((-899 (-568)))) (-15 -2376 ((-899 (-568)) (-634 (-568)))) (-15 -2376 ((-899 (-568)))) (-15 -1498 ((-899 (-568)) (-634 (-568)))) (-15 -1498 ((-899 (-568)))) (-15 -2442 ((-899 (-568)) (-634 (-568)))) (-15 -2442 ((-899 (-568)))) (-15 -3766 ((-899 (-568)))) (-15 -3928 ((-899 (-568)) (-634 (-568)))) (-15 -3928 ((-899 (-568)) (-972)))) 
+((-3744 (((-634 (-953 |#1|)) (-634 (-953 |#1|)) (-634 (-1161))) 10)) (-4190 (((-634 (-953 |#1|)) (-634 (-953 |#1|)) (-634 (-1161))) 9))) 
+(((-914 |#1|) (-10 -7 (-15 -4190 ((-634 (-953 |#1|)) (-634 (-953 |#1|)) (-634 (-1161)))) (-15 -3744 ((-634 (-953 |#1|)) (-634 (-953 |#1|)) (-634 (-1161))))) (-453)) (T -914)) 
+((-3744 (*1 *2 *2 *3) (-12 (-5 *2 (-634 (-953 *4))) (-5 *3 (-634 (-1161))) (-4 *4 (-453)) (-5 *1 (-914 *4)))) (-4190 (*1 *2 *2 *3) (-12 (-5 *2 (-634 (-953 *4))) (-5 *3 (-634 (-1161))) (-4 *4 (-453)) (-5 *1 (-914 *4))))) 
+(-10 -7 (-15 -4190 ((-634 (-953 |#1|)) (-634 (-953 |#1|)) (-634 (-1161)))) (-15 -3744 ((-634 (-953 |#1|)) (-634 (-953 |#1|)) (-634 (-1161))))) 
+((-2747 (((-310 |#1|) (-489)) 15))) 
+(((-915 |#1|) (-10 -7 (-15 -2747 ((-310 |#1|) (-489)))) (-13 (-842) (-558))) (T -915)) 
+((-2747 (*1 *2 *3) (-12 (-5 *3 (-489)) (-5 *2 (-310 *4)) (-5 *1 (-915 *4)) (-4 *4 (-13 (-842) (-558)))))) 
+(-10 -7 (-15 -2747 ((-310 |#1|) (-489)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-2902 (((-3 $ "failed") $) 33)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 49)) (-1598 (((-121) $) 30)) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-2597 (((-3 $ "failed") $ $) 41)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42)) (-3425 (((-763)) 28)) (-2273 (((-121) $ $) 38)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
 (((-916) (-1275)) (T -916)) 
-((-1983 (*1 *2 *3) (-12 (-4 *1 (-916)) (-5 *2 (-2 (|:| -2348 (-634 *1)) (|:| -2704 *1))) (-5 *3 (-634 *1)))) (-2344 (*1 *2 *2 *1) (|partial| -12 (-5 *2 (-634 *1)) (-4 *1 (-916))))) 
-(-13 (-453) (-10 -8 (-15 -1983 ((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $))) (-15 -2344 ((-3 (-634 $) "failed") (-634 $) $)))) 
+((-4422 (*1 *2 *3) (-12 (-4 *1 (-916)) (-5 *2 (-2 (|:| -2350 (-634 *1)) (|:| -2707 *1))) (-5 *3 (-634 *1)))) (-3922 (*1 *2 *2 *1) (|partial| -12 (-5 *2 (-634 *1)) (-4 *1 (-916))))) 
+(-13 (-453) (-10 -8 (-15 -4422 ((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $))) (-15 -3922 ((-3 (-634 $) "failed") (-634 $) $)))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-105) . T) ((-120 $ $) . T) ((-137) . T) ((-608 (-850)) . T) ((-172) . T) ((-285) . T) ((-453) . T) ((-558) . T) ((-637 $) . T) ((-707 $) . T) ((-716) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2671 (($) NIL T CONST)) (-2925 (((-3 $ "failed") $) NIL)) (-2735 (((-121) $) NIL)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2721 (($ $ $) NIL)) (-2745 (((-850) $) NIL)) (-1887 (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (-1556 (($) NIL T CONST)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (* (($ (-917) $) NIL) (($ $ $) NIL))) 
-(((-917) (-13 (-25) (-842) (-716) (-10 -8 (-15 -2721 ($ $ $)) (-6 (-4521 "*"))))) (T -917)) 
-((-2721 (*1 *1 *1 *1) (-5 *1 (-917)))) 
-(-13 (-25) (-842) (-716) (-10 -8 (-15 -2721 ($ $ $)) (-6 (-4521 "*")))) 
-((-1327 ((|#2| (-634 |#1|) (-634 |#1|)) 22))) 
-(((-918 |#1| |#2|) (-10 -7 (-15 -1327 (|#2| (-634 |#1|) (-634 |#1|)))) (-365) (-1219 |#1|)) (T -918)) 
-((-1327 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-4 *2 (-1219 *4)) (-5 *1 (-918 *4 *2))))) 
-(-10 -7 (-15 -1327 (|#2| (-634 |#1|) (-634 |#1|)))) 
-((-1919 (((-1157 |#2|) (-634 |#2|) (-634 |#2|)) 17) (((-1216 |#1| |#2|) (-1216 |#1| |#2|) (-634 |#2|) (-634 |#2|)) 13))) 
-(((-919 |#1| |#2|) (-10 -7 (-15 -1919 ((-1216 |#1| |#2|) (-1216 |#1| |#2|) (-634 |#2|) (-634 |#2|))) (-15 -1919 ((-1157 |#2|) (-634 |#2|) (-634 |#2|)))) (-1161) (-365)) (T -919)) 
-((-1919 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *5)) (-4 *5 (-365)) (-5 *2 (-1157 *5)) (-5 *1 (-919 *4 *5)) (-14 *4 (-1161)))) (-1919 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-1216 *4 *5)) (-5 *3 (-634 *5)) (-14 *4 (-1161)) (-4 *5 (-365)) (-5 *1 (-919 *4 *5))))) 
-(-10 -7 (-15 -1919 ((-1216 |#1| |#2|) (-1216 |#1| |#2|) (-634 |#2|) (-634 |#2|))) (-15 -1919 ((-1157 |#2|) (-634 |#2|) (-634 |#2|)))) 
-((-2447 (((-121) $ $) 7)) (-4313 (((-1249) $ (-634 |#2|)) 19)) (-1288 (((-634 $)) 14)) (-1510 (((-1249) $ (-917)) 18)) (-3092 (((-236 $) (-634 $)) 23)) (-3361 (((-634 |#2|) $) 20)) (-1651 (((-121) $) 17)) (-4487 (((-1143) $) 9)) (-3580 (((-1249) $) 16)) (-4022 (((-1108) $) 10)) (-3763 (((-634 $)) 15)) (-2779 ((|#1| $ (-568)) 13)) (-3206 (((-917) $) 12)) (-2373 (($ (-634 |#1|)) 22) (($ (-1161)) 21)) (-2745 (((-850) $) 11)) (-1717 (((-121) $ $) 6)) (-1773 (((-236 $) $ $) 28) (((-236 $) (-236 $) $) 27) (((-236 $) $ (-236 $)) 26) (((-236 $) $) 25)) (-1767 (((-236 $) $ $) 31) (((-236 $) (-236 $) $) 30) (((-236 $) $ (-236 $)) 29)) (* (((-236 $) (-568) $) 24))) 
+((-2449 (((-121) $ $) NIL)) (-4490 (($) NIL T CONST)) (-2902 (((-3 $ "failed") $) NIL)) (-1598 (((-121) $) NIL)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2723 (($ $ $) NIL)) (-2747 (((-850) $) NIL)) (-1889 (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (-1557 (($) NIL T CONST)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (* (($ (-917) $) NIL) (($ $ $) NIL))) 
+(((-917) (-13 (-25) (-842) (-716) (-10 -8 (-15 -2723 ($ $ $)) (-6 (-4523 "*"))))) (T -917)) 
+((-2723 (*1 *1 *1 *1) (-5 *1 (-917)))) 
+(-13 (-25) (-842) (-716) (-10 -8 (-15 -2723 ($ $ $)) (-6 (-4523 "*")))) 
+((-3504 ((|#2| (-634 |#1|) (-634 |#1|)) 22))) 
+(((-918 |#1| |#2|) (-10 -7 (-15 -3504 (|#2| (-634 |#1|) (-634 |#1|)))) (-365) (-1219 |#1|)) (T -918)) 
+((-3504 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-4 *2 (-1219 *4)) (-5 *1 (-918 *4 *2))))) 
+(-10 -7 (-15 -3504 (|#2| (-634 |#1|) (-634 |#1|)))) 
+((-2709 (((-1157 |#2|) (-634 |#2|) (-634 |#2|)) 17) (((-1216 |#1| |#2|) (-1216 |#1| |#2|) (-634 |#2|) (-634 |#2|)) 13))) 
+(((-919 |#1| |#2|) (-10 -7 (-15 -2709 ((-1216 |#1| |#2|) (-1216 |#1| |#2|) (-634 |#2|) (-634 |#2|))) (-15 -2709 ((-1157 |#2|) (-634 |#2|) (-634 |#2|)))) (-1161) (-365)) (T -919)) 
+((-2709 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *5)) (-4 *5 (-365)) (-5 *2 (-1157 *5)) (-5 *1 (-919 *4 *5)) (-14 *4 (-1161)))) (-2709 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-1216 *4 *5)) (-5 *3 (-634 *5)) (-14 *4 (-1161)) (-4 *5 (-365)) (-5 *1 (-919 *4 *5))))) 
+(-10 -7 (-15 -2709 ((-1216 |#1| |#2|) (-1216 |#1| |#2|) (-634 |#2|) (-634 |#2|))) (-15 -2709 ((-1157 |#2|) (-634 |#2|) (-634 |#2|)))) 
+((-2449 (((-121) $ $) 7)) (-3072 (((-1249) $ (-634 |#2|)) 19)) (-3189 (((-634 $)) 14)) (-2662 (((-1249) $ (-917)) 18)) (-3094 (((-236 $) (-634 $)) 23)) (-1322 (((-634 |#2|) $) 20)) (-3319 (((-121) $) 17)) (-1893 (((-1143) $) 9)) (-2924 (((-1249) $) 16)) (-4025 (((-1108) $) 10)) (-2666 (((-634 $)) 15)) (-2781 ((|#1| $ (-568)) 13)) (-1836 (((-917) $) 12)) (-4116 (($ (-634 |#1|)) 22) (($ (-1161)) 21)) (-2747 (((-850) $) 11)) (-1719 (((-121) $ $) 6)) (-1775 (((-236 $) $ $) 28) (((-236 $) (-236 $) $) 27) (((-236 $) $ (-236 $)) 26) (((-236 $) $) 25)) (-1769 (((-236 $) $ $) 31) (((-236 $) (-236 $) $) 30) (((-236 $) $ (-236 $)) 29)) (* (((-236 $) (-568) $) 24))) 
 (((-920 |#1| |#2|) (-1275) (-365) (-641 |t#1|)) (T -920)) 
-((-1767 (*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)))) (-1767 (*1 *2 *2 *1) (-12 (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)))) (-1767 (*1 *2 *1 *2) (-12 (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)))) (-1773 (*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)))) (-1773 (*1 *2 *2 *1) (-12 (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)))) (-1773 (*1 *2 *1 *2) (-12 (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)))) (-1773 (*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)))) (* (*1 *2 *3 *1) (-12 (-5 *3 (-568)) (-4 *4 (-365)) (-4 *5 (-641 *4)) (-5 *2 (-236 *1)) (-4 *1 (-920 *4 *5)))) (-3092 (*1 *2 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-920 *4 *5)) (-4 *4 (-365)) (-4 *5 (-641 *4)) (-5 *2 (-236 *1)))) (-2373 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-4 *1 (-920 *3 *4)) (-4 *4 (-641 *3)))) (-2373 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-4 *3 (-365)) (-4 *1 (-920 *3 *4)) (-4 *4 (-641 *3)))) (-3361 (*1 *2 *1) (-12 (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-634 *4)))) (-4313 (*1 *2 *1 *3) (-12 (-5 *3 (-634 *5)) (-4 *1 (-920 *4 *5)) (-4 *4 (-365)) (-4 *5 (-641 *4)) (-5 *2 (-1249)))) (-1510 (*1 *2 *1 *3) (-12 (-5 *3 (-917)) (-4 *1 (-920 *4 *5)) (-4 *4 (-365)) (-4 *5 (-641 *4)) (-5 *2 (-1249)))) (-1651 (*1 *2 *1) (-12 (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-121)))) (-3580 (*1 *2 *1) (-12 (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-1249)))) (-3763 (*1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-634 *1)) (-4 *1 (-920 *3 *4)))) (-1288 (*1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-634 *1)) (-4 *1 (-920 *3 *4)))) (-2779 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-920 *2 *4)) (-4 *4 (-641 *2)) (-4 *2 (-365))))) 
-(-13 (-1088) (-10 -8 (-15 -1767 ((-236 $) $ $)) (-15 -1767 ((-236 $) (-236 $) $)) (-15 -1767 ((-236 $) $ (-236 $))) (-15 -1773 ((-236 $) $ $)) (-15 -1773 ((-236 $) (-236 $) $)) (-15 -1773 ((-236 $) $ (-236 $))) (-15 -1773 ((-236 $) $)) (-15 * ((-236 $) (-568) $)) (-15 -3092 ((-236 $) (-634 $))) (-15 -2373 ($ (-634 |t#1|))) (-15 -2373 ($ (-1161))) (-15 -3361 ((-634 |t#2|) $)) (-15 -4313 ((-1249) $ (-634 |t#2|))) (-15 -1510 ((-1249) $ (-917))) (-15 -1651 ((-121) $)) (-15 -3580 ((-1249) $)) (-15 -3763 ((-634 $))) (-15 -1288 ((-634 $))) (-15 -2779 (|t#1| $ (-568))))) 
+((-1769 (*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)))) (-1769 (*1 *2 *2 *1) (-12 (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)))) (-1769 (*1 *2 *1 *2) (-12 (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)))) (-1775 (*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)))) (-1775 (*1 *2 *2 *1) (-12 (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)))) (-1775 (*1 *2 *1 *2) (-12 (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)))) (-1775 (*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)))) (* (*1 *2 *3 *1) (-12 (-5 *3 (-568)) (-4 *4 (-365)) (-4 *5 (-641 *4)) (-5 *2 (-236 *1)) (-4 *1 (-920 *4 *5)))) (-3094 (*1 *2 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-920 *4 *5)) (-4 *4 (-365)) (-4 *5 (-641 *4)) (-5 *2 (-236 *1)))) (-4116 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-4 *1 (-920 *3 *4)) (-4 *4 (-641 *3)))) (-4116 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-4 *3 (-365)) (-4 *1 (-920 *3 *4)) (-4 *4 (-641 *3)))) (-1322 (*1 *2 *1) (-12 (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-634 *4)))) (-3072 (*1 *2 *1 *3) (-12 (-5 *3 (-634 *5)) (-4 *1 (-920 *4 *5)) (-4 *4 (-365)) (-4 *5 (-641 *4)) (-5 *2 (-1249)))) (-2662 (*1 *2 *1 *3) (-12 (-5 *3 (-917)) (-4 *1 (-920 *4 *5)) (-4 *4 (-365)) (-4 *5 (-641 *4)) (-5 *2 (-1249)))) (-3319 (*1 *2 *1) (-12 (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-121)))) (-2924 (*1 *2 *1) (-12 (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-1249)))) (-2666 (*1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-634 *1)) (-4 *1 (-920 *3 *4)))) (-3189 (*1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-634 *1)) (-4 *1 (-920 *3 *4)))) (-2781 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-920 *2 *4)) (-4 *4 (-641 *2)) (-4 *2 (-365))))) 
+(-13 (-1088) (-10 -8 (-15 -1769 ((-236 $) $ $)) (-15 -1769 ((-236 $) (-236 $) $)) (-15 -1769 ((-236 $) $ (-236 $))) (-15 -1775 ((-236 $) $ $)) (-15 -1775 ((-236 $) (-236 $) $)) (-15 -1775 ((-236 $) $ (-236 $))) (-15 -1775 ((-236 $) $)) (-15 * ((-236 $) (-568) $)) (-15 -3094 ((-236 $) (-634 $))) (-15 -4116 ($ (-634 |t#1|))) (-15 -4116 ($ (-1161))) (-15 -1322 ((-634 |t#2|) $)) (-15 -3072 ((-1249) $ (-634 |t#2|))) (-15 -2662 ((-1249) $ (-917))) (-15 -3319 ((-121) $)) (-15 -2924 ((-1249) $)) (-15 -2666 ((-634 $))) (-15 -3189 ((-634 $))) (-15 -2781 (|t#1| $ (-568))))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T) ((-1088) . T)) 
-((-2447 (((-121) $ $) NIL)) (-4313 (((-1249) $ (-634 (-774 |#1|))) NIL)) (-1288 (((-634 $)) NIL)) (-1510 (((-1249) $ (-917)) NIL)) (-3092 (((-236 $) (-634 $)) NIL)) (-3361 (((-634 (-774 |#1|)) $) NIL)) (-1651 (((-121) $) NIL)) (-4487 (((-1143) $) NIL)) (-3580 (((-1249) $) NIL)) (-4022 (((-1108) $) NIL)) (-3763 (((-634 $)) NIL)) (-2779 ((|#1| $ (-568)) NIL)) (-3206 (((-917) $) NIL)) (-2373 (($ (-634 |#1|)) NIL) (($ (-1161)) NIL)) (-2745 (((-850) $) NIL)) (-1717 (((-121) $ $) NIL)) (-1773 (((-236 $) $ $) NIL) (((-236 $) (-236 $) $) NIL) (((-236 $) $ (-236 $)) NIL) (((-236 $) $) NIL)) (-1767 (((-236 $) $ $) NIL) (((-236 $) (-236 $) $) NIL) (((-236 $) $ (-236 $)) NIL)) (* (((-236 $) (-568) $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-3072 (((-1249) $ (-634 (-774 |#1|))) NIL)) (-3189 (((-634 $)) NIL)) (-2662 (((-1249) $ (-917)) NIL)) (-3094 (((-236 $) (-634 $)) NIL)) (-1322 (((-634 (-774 |#1|)) $) NIL)) (-3319 (((-121) $) NIL)) (-1893 (((-1143) $) NIL)) (-2924 (((-1249) $) NIL)) (-4025 (((-1108) $) NIL)) (-2666 (((-634 $)) NIL)) (-2781 ((|#1| $ (-568)) NIL)) (-1836 (((-917) $) NIL)) (-4116 (($ (-634 |#1|)) NIL) (($ (-1161)) NIL)) (-2747 (((-850) $) NIL)) (-1719 (((-121) $ $) NIL)) (-1775 (((-236 $) $ $) NIL) (((-236 $) (-236 $) $) NIL) (((-236 $) $ (-236 $)) NIL) (((-236 $) $) NIL)) (-1769 (((-236 $) $ $) NIL) (((-236 $) (-236 $) $) NIL) (((-236 $) $ (-236 $)) NIL)) (* (((-236 $) (-568) $) NIL))) 
 (((-921 |#1|) (-920 |#1| (-774 |#1|)) (-365)) (T -921)) 
 NIL 
 (-920 |#1| (-774 |#1|)) 
-((-2447 (((-121) $ $) NIL)) (-4313 (((-1249) $ (-634 (-774 (-857 |#1|)))) NIL)) (-1288 (((-634 $)) NIL)) (-1510 (((-1249) $ (-917)) NIL)) (-3092 (((-236 $) (-634 $)) NIL)) (-3361 (((-634 (-774 (-857 |#1|))) $) NIL)) (-1651 (((-121) $) NIL)) (-4487 (((-1143) $) NIL)) (-3580 (((-1249) $) NIL)) (-4022 (((-1108) $) NIL)) (-3763 (((-634 $)) NIL)) (-2779 (((-857 |#1|) $ (-568)) NIL)) (-3206 (((-917) $) NIL)) (-2373 (($ (-634 (-857 |#1|))) NIL) (($ (-1161)) NIL)) (-2745 (((-850) $) NIL)) (-1717 (((-121) $ $) NIL)) (-1773 (((-236 $) $ $) NIL) (((-236 $) (-236 $) $) NIL) (((-236 $) $ (-236 $)) NIL) (((-236 $) $) NIL)) (-1767 (((-236 $) $ $) NIL) (((-236 $) (-236 $) $) NIL) (((-236 $) $ (-236 $)) NIL)) (* (((-236 $) (-568) $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-3072 (((-1249) $ (-634 (-774 (-857 |#1|)))) NIL)) (-3189 (((-634 $)) NIL)) (-2662 (((-1249) $ (-917)) NIL)) (-3094 (((-236 $) (-634 $)) NIL)) (-1322 (((-634 (-774 (-857 |#1|))) $) NIL)) (-3319 (((-121) $) NIL)) (-1893 (((-1143) $) NIL)) (-2924 (((-1249) $) NIL)) (-4025 (((-1108) $) NIL)) (-2666 (((-634 $)) NIL)) (-2781 (((-857 |#1|) $ (-568)) NIL)) (-1836 (((-917) $) NIL)) (-4116 (($ (-634 (-857 |#1|))) NIL) (($ (-1161)) NIL)) (-2747 (((-850) $) NIL)) (-1719 (((-121) $ $) NIL)) (-1775 (((-236 $) $ $) NIL) (((-236 $) (-236 $) $) NIL) (((-236 $) $ (-236 $)) NIL) (((-236 $) $) NIL)) (-1769 (((-236 $) $ $) NIL) (((-236 $) (-236 $) $) NIL) (((-236 $) $ (-236 $)) NIL)) (* (((-236 $) (-568) $) NIL))) 
 (((-922 |#1|) (-920 (-857 |#1|) (-774 (-857 |#1|))) (-350)) (T -922)) 
 NIL 
 (-920 (-857 |#1|) (-774 (-857 |#1|))) 
-((-2447 (((-121) $ $) NIL)) (-4313 (((-1249) $ (-634 |#2|)) 73)) (-1288 (((-634 $)) 62)) (-1510 (((-1249) $ (-917)) 71)) (-3092 (((-236 $) (-634 $)) 27)) (-3361 (((-634 |#2|) $) 74)) (-1651 (((-121) $) 54)) (-4487 (((-1143) $) NIL)) (-3580 (((-1249) $) 57)) (-4022 (((-1108) $) NIL)) (-3763 (((-634 $)) 59)) (-2779 ((|#1| $ (-568)) 53)) (-3206 (((-917) $) 42)) (-2373 (($ (-634 |#1|)) 69) (($ (-1161)) 70)) (-2745 (((-850) $) 45)) (-1717 (((-121) $ $) 50)) (-1773 (((-236 $) $ $) 18) (((-236 $) (-236 $) $) 30) (((-236 $) $ (-236 $)) 31) (((-236 $) $) 33)) (-1767 (((-236 $) $ $) 16) (((-236 $) (-236 $) $) 28) (((-236 $) $ (-236 $)) 29)) (* (((-236 $) (-568) $) 21))) 
+((-2449 (((-121) $ $) NIL)) (-3072 (((-1249) $ (-634 |#2|)) 73)) (-3189 (((-634 $)) 62)) (-2662 (((-1249) $ (-917)) 71)) (-3094 (((-236 $) (-634 $)) 27)) (-1322 (((-634 |#2|) $) 74)) (-3319 (((-121) $) 54)) (-1893 (((-1143) $) NIL)) (-2924 (((-1249) $) 57)) (-4025 (((-1108) $) NIL)) (-2666 (((-634 $)) 59)) (-2781 ((|#1| $ (-568)) 53)) (-1836 (((-917) $) 42)) (-4116 (($ (-634 |#1|)) 69) (($ (-1161)) 70)) (-2747 (((-850) $) 45)) (-1719 (((-121) $ $) 50)) (-1775 (((-236 $) $ $) 18) (((-236 $) (-236 $) $) 30) (((-236 $) $ (-236 $)) 31) (((-236 $) $) 33)) (-1769 (((-236 $) $ $) 16) (((-236 $) (-236 $) $) 28) (((-236 $) $ (-236 $)) 29)) (* (((-236 $) (-568) $) 21))) 
 (((-923 |#1| |#2|) (-920 |#1| |#2|) (-365) (-641 |#1|)) (T -923)) 
 NIL 
 (-920 |#1| |#2|) 
-((-1295 (((-568) (-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-1143)) 137)) (-3872 ((|#4| |#4|) 153)) (-1845 (((-634 (-409 (-953 |#1|))) (-634 (-1161))) 116)) (-3691 (((-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|)))))))) (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))) (-679 |#4|) (-634 (-409 (-953 |#1|))) (-634 (-634 |#4|)) (-763) (-763) (-568)) 73)) (-1329 (((-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|)))))) (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|)))))) (-634 |#4|)) 57)) (-2232 (((-679 |#4|) (-679 |#4|) (-634 |#4|)) 53)) (-1370 (((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-1143)) 149)) (-4376 (((-568) (-679 |#4|) (-917) (-1143)) 130) (((-568) (-679 |#4|) (-634 (-1161)) (-917) (-1143)) 129) (((-568) (-679 |#4|) (-634 |#4|) (-917) (-1143)) 128) (((-568) (-679 |#4|) (-1143)) 125) (((-568) (-679 |#4|) (-634 (-1161)) (-1143)) 124) (((-568) (-679 |#4|) (-634 |#4|) (-1143)) 123) (((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-917)) 122) (((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 (-1161)) (-917)) 121) (((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 |#4|) (-917)) 120) (((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|)) 118) (((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 (-1161))) 117) (((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 |#4|)) 114)) (-3267 ((|#4| (-953 |#1|)) 66)) (-1425 (((-121) (-634 |#4|) (-634 (-634 |#4|))) 150)) (-3080 (((-634 (-634 (-568))) (-568) (-568)) 127)) (-4428 (((-634 (-634 |#4|)) (-634 (-634 |#4|))) 85)) (-2034 (((-763) (-634 (-2 (|:| -3700 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 |#4|))))) 83)) (-2843 (((-763) (-634 (-2 (|:| -3700 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 |#4|))))) 82)) (-3537 (((-121) (-634 (-953 |#1|))) 17) (((-121) (-634 |#4|)) 13)) (-1545 (((-2 (|:| |sysok| (-121)) (|:| |z0| (-634 |#4|)) (|:| |n0| (-634 |#4|))) (-634 |#4|) (-634 |#4|)) 69)) (-1514 (((-634 |#4|) |#4|) 47)) (-1559 (((-634 (-409 (-953 |#1|))) (-634 |#4|)) 112) (((-679 (-409 (-953 |#1|))) (-679 |#4|)) 54) (((-409 (-953 |#1|)) |#4|) 109)) (-3549 (((-2 (|:| |rgl| (-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|)))))))))) (|:| |rgsz| (-568))) (-679 |#4|) (-634 (-409 (-953 |#1|))) (-763) (-1143) (-568)) 89)) (-2730 (((-634 (-2 (|:| -3700 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 |#4|)))) (-679 |#4|) (-763)) 81)) (-3589 (((-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568))))) (-679 |#4|) (-763)) 98)) (-3945 (((-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|)))))) (-2 (|:| -2928 (-679 (-409 (-953 |#1|)))) (|:| |vec| (-634 (-409 (-953 |#1|)))) (|:| -3700 (-763)) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568))))) 46))) 
-(((-924 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -4376 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 |#4|))) (-15 -4376 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 (-1161)))) (-15 -4376 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|))) (-15 -4376 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 |#4|) (-917))) (-15 -4376 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 (-1161)) (-917))) (-15 -4376 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-917))) (-15 -4376 ((-568) (-679 |#4|) (-634 |#4|) (-1143))) (-15 -4376 ((-568) (-679 |#4|) (-634 (-1161)) (-1143))) (-15 -4376 ((-568) (-679 |#4|) (-1143))) (-15 -4376 ((-568) (-679 |#4|) (-634 |#4|) (-917) (-1143))) (-15 -4376 ((-568) (-679 |#4|) (-634 (-1161)) (-917) (-1143))) (-15 -4376 ((-568) (-679 |#4|) (-917) (-1143))) (-15 -1295 ((-568) (-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-1143))) (-15 -1370 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-1143))) (-15 -3549 ((-2 (|:| |rgl| (-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|)))))))))) (|:| |rgsz| (-568))) (-679 |#4|) (-634 (-409 (-953 |#1|))) (-763) (-1143) (-568))) (-15 -1559 ((-409 (-953 |#1|)) |#4|)) (-15 -1559 ((-679 (-409 (-953 |#1|))) (-679 |#4|))) (-15 -1559 ((-634 (-409 (-953 |#1|))) (-634 |#4|))) (-15 -1845 ((-634 (-409 (-953 |#1|))) (-634 (-1161)))) (-15 -3267 (|#4| (-953 |#1|))) (-15 -1545 ((-2 (|:| |sysok| (-121)) (|:| |z0| (-634 |#4|)) (|:| |n0| (-634 |#4|))) (-634 |#4|) (-634 |#4|))) (-15 -2730 ((-634 (-2 (|:| -3700 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 |#4|)))) (-679 |#4|) (-763))) (-15 -1329 ((-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|)))))) (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|)))))) (-634 |#4|))) (-15 -3945 ((-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|)))))) (-2 (|:| -2928 (-679 (-409 (-953 |#1|)))) (|:| |vec| (-634 (-409 (-953 |#1|)))) (|:| -3700 (-763)) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (-15 -1514 ((-634 |#4|) |#4|)) (-15 -2843 ((-763) (-634 (-2 (|:| -3700 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 |#4|)))))) (-15 -2034 ((-763) (-634 (-2 (|:| -3700 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 |#4|)))))) (-15 -4428 ((-634 (-634 |#4|)) (-634 (-634 |#4|)))) (-15 -3080 ((-634 (-634 (-568))) (-568) (-568))) (-15 -1425 ((-121) (-634 |#4|) (-634 (-634 |#4|)))) (-15 -3589 ((-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568))))) (-679 |#4|) (-763))) (-15 -2232 ((-679 |#4|) (-679 |#4|) (-634 |#4|))) (-15 -3691 ((-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|)))))))) (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))) (-679 |#4|) (-634 (-409 (-953 |#1|))) (-634 (-634 |#4|)) (-763) (-763) (-568))) (-15 -3872 (|#4| |#4|)) (-15 -3537 ((-121) (-634 |#4|))) (-15 -3537 ((-121) (-634 (-953 |#1|))))) (-13 (-301) (-150)) (-13 (-842) (-609 (-1161))) (-788) (-950 |#1| |#3| |#2|)) (T -924)) 
-((-3537 (*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-121)) (-5 *1 (-924 *4 *5 *6 *7)) (-4 *7 (-950 *4 *6 *5)))) (-3537 (*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-121)) (-5 *1 (-924 *4 *5 *6 *7)))) (-3872 (*1 *2 *2) (-12 (-4 *3 (-13 (-301) (-150))) (-4 *4 (-13 (-842) (-609 (-1161)))) (-4 *5 (-788)) (-5 *1 (-924 *3 *4 *5 *2)) (-4 *2 (-950 *3 *5 *4)))) (-3691 (*1 *2 *3 *4 *5 *6 *7 *7 *8) (-12 (-5 *3 (-2 (|:| |det| *12) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568))))) (-5 *4 (-679 *12)) (-5 *5 (-634 (-409 (-953 *9)))) (-5 *6 (-634 (-634 *12))) (-5 *7 (-763)) (-5 *8 (-568)) (-4 *9 (-13 (-301) (-150))) (-4 *12 (-950 *9 *11 *10)) (-4 *10 (-13 (-842) (-609 (-1161)))) (-4 *11 (-788)) (-5 *2 (-2 (|:| |eqzro| (-634 *12)) (|:| |neqzro| (-634 *12)) (|:| |wcond| (-634 (-953 *9))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *9)))) (|:| -3746 (-634 (-1244 (-409 (-953 *9))))))))) (-5 *1 (-924 *9 *10 *11 *12)))) (-2232 (*1 *2 *2 *3) (-12 (-5 *2 (-679 *7)) (-5 *3 (-634 *7)) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *1 (-924 *4 *5 *6 *7)))) (-3589 (*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-5 *4 (-763)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-634 (-2 (|:| |det| *8) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (-5 *1 (-924 *5 *6 *7 *8)))) (-1425 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-634 *8))) (-5 *3 (-634 *8)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-121)) (-5 *1 (-924 *5 *6 *7 *8)))) (-3080 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 (-634 (-568)))) (-5 *1 (-924 *4 *5 *6 *7)) (-5 *3 (-568)) (-4 *7 (-950 *4 *6 *5)))) (-4428 (*1 *2 *2) (-12 (-5 *2 (-634 (-634 *6))) (-4 *6 (-950 *3 *5 *4)) (-4 *3 (-13 (-301) (-150))) (-4 *4 (-13 (-842) (-609 (-1161)))) (-4 *5 (-788)) (-5 *1 (-924 *3 *4 *5 *6)))) (-2034 (*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3700 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| *7) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 *7))))) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-763)) (-5 *1 (-924 *4 *5 *6 *7)))) (-2843 (*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3700 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| *7) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 *7))))) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-763)) (-5 *1 (-924 *4 *5 *6 *7)))) (-1514 (*1 *2 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 *3)) (-5 *1 (-924 *4 *5 *6 *3)) (-4 *3 (-950 *4 *6 *5)))) (-3945 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| -2928 (-679 (-409 (-953 *4)))) (|:| |vec| (-634 (-409 (-953 *4)))) (|:| -3700 (-763)) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568))))) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-2 (|:| |partsol| (-1244 (-409 (-953 *4)))) (|:| -3746 (-634 (-1244 (-409 (-953 *4))))))) (-5 *1 (-924 *4 *5 *6 *7)) (-4 *7 (-950 *4 *6 *5)))) (-1329 (*1 *2 *2 *3) (-12 (-5 *2 (-2 (|:| |partsol| (-1244 (-409 (-953 *4)))) (|:| -3746 (-634 (-1244 (-409 (-953 *4))))))) (-5 *3 (-634 *7)) (-4 *4 (-13 (-301) (-150))) (-4 *7 (-950 *4 *6 *5)) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *1 (-924 *4 *5 *6 *7)))) (-2730 (*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-634 (-2 (|:| -3700 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| *8) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 *8))))) (-5 *1 (-924 *5 *6 *7 *8)) (-5 *4 (-763)))) (-1545 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-4 *7 (-950 *4 *6 *5)) (-5 *2 (-2 (|:| |sysok| (-121)) (|:| |z0| (-634 *7)) (|:| |n0| (-634 *7)))) (-5 *1 (-924 *4 *5 *6 *7)) (-5 *3 (-634 *7)))) (-3267 (*1 *2 *3) (-12 (-5 *3 (-953 *4)) (-4 *4 (-13 (-301) (-150))) (-4 *2 (-950 *4 *6 *5)) (-5 *1 (-924 *4 *5 *6 *2)) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)))) (-1845 (*1 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 (-409 (-953 *4)))) (-5 *1 (-924 *4 *5 *6 *7)) (-4 *7 (-950 *4 *6 *5)))) (-1559 (*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 (-409 (-953 *4)))) (-5 *1 (-924 *4 *5 *6 *7)))) (-1559 (*1 *2 *3) (-12 (-5 *3 (-679 *7)) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-679 (-409 (-953 *4)))) (-5 *1 (-924 *4 *5 *6 *7)))) (-1559 (*1 *2 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-409 (-953 *4))) (-5 *1 (-924 *4 *5 *6 *3)) (-4 *3 (-950 *4 *6 *5)))) (-3549 (*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *3 (-679 *11)) (-5 *4 (-634 (-409 (-953 *8)))) (-5 *5 (-763)) (-5 *6 (-1143)) (-4 *8 (-13 (-301) (-150))) (-4 *11 (-950 *8 *10 *9)) (-4 *9 (-13 (-842) (-609 (-1161)))) (-4 *10 (-788)) (-5 *2 (-2 (|:| |rgl| (-634 (-2 (|:| |eqzro| (-634 *11)) (|:| |neqzro| (-634 *11)) (|:| |wcond| (-634 (-953 *8))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *8)))) (|:| -3746 (-634 (-1244 (-409 (-953 *8)))))))))) (|:| |rgsz| (-568)))) (-5 *1 (-924 *8 *9 *10 *11)) (-5 *7 (-568)))) (-1370 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *7)) (|:| |neqzro| (-634 *7)) (|:| |wcond| (-634 (-953 *4))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *4)))) (|:| -3746 (-634 (-1244 (-409 (-953 *4)))))))))) (-5 *1 (-924 *4 *5 *6 *7)) (-4 *7 (-950 *4 *6 *5)))) (-1295 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-2 (|:| |eqzro| (-634 *8)) (|:| |neqzro| (-634 *8)) (|:| |wcond| (-634 (-953 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *5)))) (|:| -3746 (-634 (-1244 (-409 (-953 *5)))))))))) (-5 *4 (-1143)) (-4 *5 (-13 (-301) (-150))) (-4 *8 (-950 *5 *7 *6)) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *5 *6 *7 *8)))) (-4376 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *9)) (-5 *4 (-917)) (-5 *5 (-1143)) (-4 *9 (-950 *6 *8 *7)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-13 (-842) (-609 (-1161)))) (-4 *8 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *6 *7 *8 *9)))) (-4376 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-679 *10)) (-5 *4 (-634 (-1161))) (-5 *5 (-917)) (-5 *6 (-1143)) (-4 *10 (-950 *7 *9 *8)) (-4 *7 (-13 (-301) (-150))) (-4 *8 (-13 (-842) (-609 (-1161)))) (-4 *9 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *7 *8 *9 *10)))) (-4376 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-679 *10)) (-5 *4 (-634 *10)) (-5 *5 (-917)) (-5 *6 (-1143)) (-4 *10 (-950 *7 *9 *8)) (-4 *7 (-13 (-301) (-150))) (-4 *8 (-13 (-842) (-609 (-1161)))) (-4 *9 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *7 *8 *9 *10)))) (-4376 (*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-5 *4 (-1143)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *5 *6 *7 *8)))) (-4376 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *9)) (-5 *4 (-634 (-1161))) (-5 *5 (-1143)) (-4 *9 (-950 *6 *8 *7)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-13 (-842) (-609 (-1161)))) (-4 *8 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *6 *7 *8 *9)))) (-4376 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *9)) (-5 *4 (-634 *9)) (-5 *5 (-1143)) (-4 *9 (-950 *6 *8 *7)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-13 (-842) (-609 (-1161)))) (-4 *8 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *6 *7 *8 *9)))) (-4376 (*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-5 *4 (-917)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *8)) (|:| |neqzro| (-634 *8)) (|:| |wcond| (-634 (-953 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *5)))) (|:| -3746 (-634 (-1244 (-409 (-953 *5)))))))))) (-5 *1 (-924 *5 *6 *7 *8)))) (-4376 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *9)) (-5 *4 (-634 (-1161))) (-5 *5 (-917)) (-4 *9 (-950 *6 *8 *7)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-13 (-842) (-609 (-1161)))) (-4 *8 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *9)) (|:| |neqzro| (-634 *9)) (|:| |wcond| (-634 (-953 *6))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *6)))) (|:| -3746 (-634 (-1244 (-409 (-953 *6)))))))))) (-5 *1 (-924 *6 *7 *8 *9)))) (-4376 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *9)) (-5 *5 (-917)) (-4 *9 (-950 *6 *8 *7)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-13 (-842) (-609 (-1161)))) (-4 *8 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *9)) (|:| |neqzro| (-634 *9)) (|:| |wcond| (-634 (-953 *6))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *6)))) (|:| -3746 (-634 (-1244 (-409 (-953 *6)))))))))) (-5 *1 (-924 *6 *7 *8 *9)) (-5 *4 (-634 *9)))) (-4376 (*1 *2 *3) (-12 (-5 *3 (-679 *7)) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *7)) (|:| |neqzro| (-634 *7)) (|:| |wcond| (-634 (-953 *4))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *4)))) (|:| -3746 (-634 (-1244 (-409 (-953 *4)))))))))) (-5 *1 (-924 *4 *5 *6 *7)))) (-4376 (*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-5 *4 (-634 (-1161))) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *8)) (|:| |neqzro| (-634 *8)) (|:| |wcond| (-634 (-953 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *5)))) (|:| -3746 (-634 (-1244 (-409 (-953 *5)))))))))) (-5 *1 (-924 *5 *6 *7 *8)))) (-4376 (*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *8)) (|:| |neqzro| (-634 *8)) (|:| |wcond| (-634 (-953 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *5)))) (|:| -3746 (-634 (-1244 (-409 (-953 *5)))))))))) (-5 *1 (-924 *5 *6 *7 *8)) (-5 *4 (-634 *8))))) 
-(-10 -7 (-15 -4376 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 |#4|))) (-15 -4376 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 (-1161)))) (-15 -4376 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|))) (-15 -4376 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 |#4|) (-917))) (-15 -4376 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 (-1161)) (-917))) (-15 -4376 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-917))) (-15 -4376 ((-568) (-679 |#4|) (-634 |#4|) (-1143))) (-15 -4376 ((-568) (-679 |#4|) (-634 (-1161)) (-1143))) (-15 -4376 ((-568) (-679 |#4|) (-1143))) (-15 -4376 ((-568) (-679 |#4|) (-634 |#4|) (-917) (-1143))) (-15 -4376 ((-568) (-679 |#4|) (-634 (-1161)) (-917) (-1143))) (-15 -4376 ((-568) (-679 |#4|) (-917) (-1143))) (-15 -1295 ((-568) (-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-1143))) (-15 -1370 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|))))))))) (-1143))) (-15 -3549 ((-2 (|:| |rgl| (-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|)))))))))) (|:| |rgsz| (-568))) (-679 |#4|) (-634 (-409 (-953 |#1|))) (-763) (-1143) (-568))) (-15 -1559 ((-409 (-953 |#1|)) |#4|)) (-15 -1559 ((-679 (-409 (-953 |#1|))) (-679 |#4|))) (-15 -1559 ((-634 (-409 (-953 |#1|))) (-634 |#4|))) (-15 -1845 ((-634 (-409 (-953 |#1|))) (-634 (-1161)))) (-15 -3267 (|#4| (-953 |#1|))) (-15 -1545 ((-2 (|:| |sysok| (-121)) (|:| |z0| (-634 |#4|)) (|:| |n0| (-634 |#4|))) (-634 |#4|) (-634 |#4|))) (-15 -2730 ((-634 (-2 (|:| -3700 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 |#4|)))) (-679 |#4|) (-763))) (-15 -1329 ((-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|)))))) (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|)))))) (-634 |#4|))) (-15 -3945 ((-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|)))))) (-2 (|:| -2928 (-679 (-409 (-953 |#1|)))) (|:| |vec| (-634 (-409 (-953 |#1|)))) (|:| -3700 (-763)) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (-15 -1514 ((-634 |#4|) |#4|)) (-15 -2843 ((-763) (-634 (-2 (|:| -3700 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 |#4|)))))) (-15 -2034 ((-763) (-634 (-2 (|:| -3700 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 |#4|)))))) (-15 -4428 ((-634 (-634 |#4|)) (-634 (-634 |#4|)))) (-15 -3080 ((-634 (-634 (-568))) (-568) (-568))) (-15 -1425 ((-121) (-634 |#4|) (-634 (-634 |#4|)))) (-15 -3589 ((-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568))))) (-679 |#4|) (-763))) (-15 -2232 ((-679 |#4|) (-679 |#4|) (-634 |#4|))) (-15 -3691 ((-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -3746 (-634 (-1244 (-409 (-953 |#1|)))))))) (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))) (-679 |#4|) (-634 (-409 (-953 |#1|))) (-634 (-634 |#4|)) (-763) (-763) (-568))) (-15 -3872 (|#4| |#4|)) (-15 -3537 ((-121) (-634 |#4|))) (-15 -3537 ((-121) (-634 (-953 |#1|))))) 
-((-1343 (((-927) |#1| (-1161)) 16) (((-927) |#1| (-1161) (-1084 (-215))) 20)) (-2059 (((-927) |#1| |#1| (-1161) (-1084 (-215))) 18) (((-927) |#1| (-1161) (-1084 (-215))) 14))) 
-(((-925 |#1|) (-10 -7 (-15 -2059 ((-927) |#1| (-1161) (-1084 (-215)))) (-15 -2059 ((-927) |#1| |#1| (-1161) (-1084 (-215)))) (-15 -1343 ((-927) |#1| (-1161) (-1084 (-215)))) (-15 -1343 ((-927) |#1| (-1161)))) (-609 (-541))) (T -925)) 
-((-1343 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-5 *2 (-927)) (-5 *1 (-925 *3)) (-4 *3 (-609 (-541))))) (-1343 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1161)) (-5 *5 (-1084 (-215))) (-5 *2 (-927)) (-5 *1 (-925 *3)) (-4 *3 (-609 (-541))))) (-2059 (*1 *2 *3 *3 *4 *5) (-12 (-5 *4 (-1161)) (-5 *5 (-1084 (-215))) (-5 *2 (-927)) (-5 *1 (-925 *3)) (-4 *3 (-609 (-541))))) (-2059 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1161)) (-5 *5 (-1084 (-215))) (-5 *2 (-927)) (-5 *1 (-925 *3)) (-4 *3 (-609 (-541)))))) 
-(-10 -7 (-15 -2059 ((-927) |#1| (-1161) (-1084 (-215)))) (-15 -2059 ((-927) |#1| |#1| (-1161) (-1084 (-215)))) (-15 -1343 ((-927) |#1| (-1161) (-1084 (-215)))) (-15 -1343 ((-927) |#1| (-1161)))) 
-((-2868 (($ $ (-1084 (-215)) (-1084 (-215)) (-1084 (-215))) 68)) (-2514 (((-1084 (-215)) $) 40)) (-4017 (((-1084 (-215)) $) 39)) (-1351 (((-1084 (-215)) $) 38)) (-4228 (((-634 (-634 (-215))) $) 43)) (-2560 (((-1084 (-215)) $) 41)) (-1835 (((-568) (-568)) 32)) (-1894 (((-568) (-568)) 28)) (-4340 (((-568) (-568)) 30)) (-1326 (((-121) (-121)) 35)) (-2547 (((-568)) 31)) (-4069 (($ $ (-1084 (-215))) 71) (($ $) 72)) (-1823 (($ (-1 (-944 (-215)) (-215)) (-1084 (-215))) 76) (($ (-1 (-944 (-215)) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215))) 77)) (-2059 (($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215))) 79) (($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215))) 80) (($ $ (-1084 (-215))) 74)) (-1899 (((-568)) 36)) (-4260 (((-568)) 27)) (-2440 (((-568)) 29)) (-2550 (((-634 (-634 (-944 (-215)))) $) 92)) (-3066 (((-121) (-121)) 37)) (-2745 (((-850) $) 91)) (-2629 (((-121)) 34))) 
-(((-926) (-13 (-975) (-10 -8 (-15 -1823 ($ (-1 (-944 (-215)) (-215)) (-1084 (-215)))) (-15 -1823 ($ (-1 (-944 (-215)) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -2059 ($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215)))) (-15 -2059 ($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -2059 ($ $ (-1084 (-215)))) (-15 -2868 ($ $ (-1084 (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -4069 ($ $ (-1084 (-215)))) (-15 -4069 ($ $)) (-15 -2560 ((-1084 (-215)) $)) (-15 -4228 ((-634 (-634 (-215))) $)) (-15 -4260 ((-568))) (-15 -1894 ((-568) (-568))) (-15 -2440 ((-568))) (-15 -4340 ((-568) (-568))) (-15 -2547 ((-568))) (-15 -1835 ((-568) (-568))) (-15 -2629 ((-121))) (-15 -1326 ((-121) (-121))) (-15 -1899 ((-568))) (-15 -3066 ((-121) (-121)))))) (T -926)) 
-((-1823 (*1 *1 *2 *3) (-12 (-5 *2 (-1 (-944 (-215)) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-926)))) (-1823 (*1 *1 *2 *3 *3 *3 *3) (-12 (-5 *2 (-1 (-944 (-215)) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-926)))) (-2059 (*1 *1 *2 *2 *2 *2 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-926)))) (-2059 (*1 *1 *2 *2 *2 *2 *3 *3 *3 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-926)))) (-2059 (*1 *1 *1 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-926)))) (-2868 (*1 *1 *1 *2 *2 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-926)))) (-4069 (*1 *1 *1 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-926)))) (-4069 (*1 *1 *1) (-5 *1 (-926))) (-2560 (*1 *2 *1) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-926)))) (-4228 (*1 *2 *1) (-12 (-5 *2 (-634 (-634 (-215)))) (-5 *1 (-926)))) (-4260 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926)))) (-1894 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926)))) (-2440 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926)))) (-4340 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926)))) (-2547 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926)))) (-1835 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926)))) (-2629 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-926)))) (-1326 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-926)))) (-1899 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926)))) (-3066 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-926))))) 
-(-13 (-975) (-10 -8 (-15 -1823 ($ (-1 (-944 (-215)) (-215)) (-1084 (-215)))) (-15 -1823 ($ (-1 (-944 (-215)) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -2059 ($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215)))) (-15 -2059 ($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -2059 ($ $ (-1084 (-215)))) (-15 -2868 ($ $ (-1084 (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -4069 ($ $ (-1084 (-215)))) (-15 -4069 ($ $)) (-15 -2560 ((-1084 (-215)) $)) (-15 -4228 ((-634 (-634 (-215))) $)) (-15 -4260 ((-568))) (-15 -1894 ((-568) (-568))) (-15 -2440 ((-568))) (-15 -4340 ((-568) (-568))) (-15 -2547 ((-568))) (-15 -1835 ((-568) (-568))) (-15 -2629 ((-121))) (-15 -1326 ((-121) (-121))) (-15 -1899 ((-568))) (-15 -3066 ((-121) (-121))))) 
-((-2868 (($ $ (-1084 (-215))) 69) (($ $ (-1084 (-215)) (-1084 (-215))) 70)) (-4017 (((-1084 (-215)) $) 43)) (-1351 (((-1084 (-215)) $) 42)) (-2560 (((-1084 (-215)) $) 44)) (-4010 (((-568) (-568)) 36)) (-3946 (((-568) (-568)) 32)) (-2058 (((-568) (-568)) 34)) (-4372 (((-121) (-121)) 38)) (-3964 (((-568)) 35)) (-4069 (($ $ (-1084 (-215))) 73) (($ $) 74)) (-1823 (($ (-1 (-944 (-215)) (-215)) (-1084 (-215))) 83) (($ (-1 (-944 (-215)) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215))) 84)) (-1343 (($ (-1 (-215) (-215)) (-1084 (-215))) 91) (($ (-1 (-215) (-215))) 94)) (-2059 (($ (-1 (-215) (-215)) (-1084 (-215))) 78) (($ (-1 (-215) (-215)) (-1084 (-215)) (-1084 (-215))) 79) (($ (-634 (-1 (-215) (-215))) (-1084 (-215))) 86) (($ (-634 (-1 (-215) (-215))) (-1084 (-215)) (-1084 (-215))) 87) (($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215))) 80) (($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215))) 81) (($ $ (-1084 (-215))) 75)) (-3518 (((-121) $) 39)) (-1996 (((-568)) 40)) (-4035 (((-568)) 31)) (-3144 (((-568)) 33)) (-2550 (((-634 (-634 (-944 (-215)))) $) 22)) (-4019 (((-121) (-121)) 41)) (-2745 (((-850) $) 105)) (-4095 (((-121)) 37))) 
-(((-927) (-13 (-955) (-10 -8 (-15 -2059 ($ (-1 (-215) (-215)) (-1084 (-215)))) (-15 -2059 ($ (-1 (-215) (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -2059 ($ (-634 (-1 (-215) (-215))) (-1084 (-215)))) (-15 -2059 ($ (-634 (-1 (-215) (-215))) (-1084 (-215)) (-1084 (-215)))) (-15 -2059 ($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215)))) (-15 -2059 ($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -1823 ($ (-1 (-944 (-215)) (-215)) (-1084 (-215)))) (-15 -1823 ($ (-1 (-944 (-215)) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -1343 ($ (-1 (-215) (-215)) (-1084 (-215)))) (-15 -1343 ($ (-1 (-215) (-215)))) (-15 -2059 ($ $ (-1084 (-215)))) (-15 -3518 ((-121) $)) (-15 -2868 ($ $ (-1084 (-215)))) (-15 -2868 ($ $ (-1084 (-215)) (-1084 (-215)))) (-15 -4069 ($ $ (-1084 (-215)))) (-15 -4069 ($ $)) (-15 -2560 ((-1084 (-215)) $)) (-15 -4035 ((-568))) (-15 -3946 ((-568) (-568))) (-15 -3144 ((-568))) (-15 -2058 ((-568) (-568))) (-15 -3964 ((-568))) (-15 -4010 ((-568) (-568))) (-15 -4095 ((-121))) (-15 -4372 ((-121) (-121))) (-15 -1996 ((-568))) (-15 -4019 ((-121) (-121)))))) (T -927)) 
-((-2059 (*1 *1 *2 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) (-2059 (*1 *1 *2 *3 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) (-2059 (*1 *1 *2 *3) (-12 (-5 *2 (-634 (-1 (-215) (-215)))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) (-2059 (*1 *1 *2 *3 *3) (-12 (-5 *2 (-634 (-1 (-215) (-215)))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) (-2059 (*1 *1 *2 *2 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) (-2059 (*1 *1 *2 *2 *3 *3 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) (-1823 (*1 *1 *2 *3) (-12 (-5 *2 (-1 (-944 (-215)) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) (-1823 (*1 *1 *2 *3 *3 *3) (-12 (-5 *2 (-1 (-944 (-215)) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) (-1343 (*1 *1 *2 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) (-1343 (*1 *1 *2) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *1 (-927)))) (-2059 (*1 *1 *1 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-927)))) (-3518 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-927)))) (-2868 (*1 *1 *1 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-927)))) (-2868 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-927)))) (-4069 (*1 *1 *1 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-927)))) (-4069 (*1 *1 *1) (-5 *1 (-927))) (-2560 (*1 *2 *1) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-927)))) (-4035 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927)))) (-3946 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927)))) (-3144 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927)))) (-2058 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927)))) (-3964 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927)))) (-4010 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927)))) (-4095 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-927)))) (-4372 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-927)))) (-1996 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927)))) (-4019 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-927))))) 
-(-13 (-955) (-10 -8 (-15 -2059 ($ (-1 (-215) (-215)) (-1084 (-215)))) (-15 -2059 ($ (-1 (-215) (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -2059 ($ (-634 (-1 (-215) (-215))) (-1084 (-215)))) (-15 -2059 ($ (-634 (-1 (-215) (-215))) (-1084 (-215)) (-1084 (-215)))) (-15 -2059 ($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215)))) (-15 -2059 ($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -1823 ($ (-1 (-944 (-215)) (-215)) (-1084 (-215)))) (-15 -1823 ($ (-1 (-944 (-215)) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -1343 ($ (-1 (-215) (-215)) (-1084 (-215)))) (-15 -1343 ($ (-1 (-215) (-215)))) (-15 -2059 ($ $ (-1084 (-215)))) (-15 -3518 ((-121) $)) (-15 -2868 ($ $ (-1084 (-215)))) (-15 -2868 ($ $ (-1084 (-215)) (-1084 (-215)))) (-15 -4069 ($ $ (-1084 (-215)))) (-15 -4069 ($ $)) (-15 -2560 ((-1084 (-215)) $)) (-15 -4035 ((-568))) (-15 -3946 ((-568) (-568))) (-15 -3144 ((-568))) (-15 -2058 ((-568) (-568))) (-15 -3964 ((-568))) (-15 -4010 ((-568) (-568))) (-15 -4095 ((-121))) (-15 -4372 ((-121) (-121))) (-15 -1996 ((-568))) (-15 -4019 ((-121) (-121))))) 
-((-1790 (((-634 (-1084 (-215))) (-634 (-634 (-944 (-215))))) 23))) 
-(((-928) (-10 -7 (-15 -1790 ((-634 (-1084 (-215))) (-634 (-634 (-944 (-215)))))))) (T -928)) 
-((-1790 (*1 *2 *3) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *2 (-634 (-1084 (-215)))) (-5 *1 (-928))))) 
-(-10 -7 (-15 -1790 ((-634 (-1084 (-215))) (-634 (-634 (-944 (-215))))))) 
-((-3481 ((|#2| |#2| |#5|) 39) ((|#2| |#2| |#5| (-568)) 20)) (-3734 (((-121) (-634 |#2|) |#5|) 23)) (-4029 (((-763) |#2| |#5| (-568)) 42) (((-763) |#2| |#5|) 41)) (-2563 ((|#2| |#2| |#5| (-568)) 45) ((|#2| |#2| |#5|) 44)) (-1339 ((|#1| |#2| |#5|) 21))) 
-(((-929 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3734 ((-121) (-634 |#2|) |#5|)) (-15 -1339 (|#1| |#2| |#5|)) (-15 -3481 (|#2| |#2| |#5| (-568))) (-15 -3481 (|#2| |#2| |#5|)) (-15 -2563 (|#2| |#2| |#5|)) (-15 -2563 (|#2| |#2| |#5| (-568))) (-15 -4029 ((-763) |#2| |#5|)) (-15 -4029 ((-763) |#2| |#5| (-568)))) (-365) (-324 |#1| |#3|) (-230 |#4| (-763)) (-763) (-971 |#1|)) (T -929)) 
-((-4029 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-568)) (-4 *6 (-365)) (-4 *7 (-230 *8 *2)) (-14 *8 *2) (-5 *2 (-763)) (-5 *1 (-929 *6 *3 *7 *8 *4)) (-4 *3 (-324 *6 *7)) (-4 *4 (-971 *6)))) (-4029 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-230 *7 *2)) (-14 *7 *2) (-5 *2 (-763)) (-5 *1 (-929 *5 *3 *6 *7 *4)) (-4 *3 (-324 *5 *6)) (-4 *4 (-971 *5)))) (-2563 (*1 *2 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-365)) (-4 *6 (-230 *7 (-763))) (-14 *7 (-763)) (-5 *1 (-929 *5 *2 *6 *7 *3)) (-4 *2 (-324 *5 *6)) (-4 *3 (-971 *5)))) (-2563 (*1 *2 *2 *3) (-12 (-4 *4 (-365)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-929 *4 *2 *5 *6 *3)) (-4 *2 (-324 *4 *5)) (-4 *3 (-971 *4)))) (-3481 (*1 *2 *2 *3) (-12 (-4 *4 (-365)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-929 *4 *2 *5 *6 *3)) (-4 *2 (-324 *4 *5)) (-4 *3 (-971 *4)))) (-3481 (*1 *2 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-365)) (-4 *6 (-230 *7 (-763))) (-14 *7 (-763)) (-5 *1 (-929 *5 *2 *6 *7 *3)) (-4 *2 (-324 *5 *6)) (-4 *3 (-971 *5)))) (-1339 (*1 *2 *3 *4) (-12 (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-4 *2 (-365)) (-5 *1 (-929 *2 *3 *5 *6 *4)) (-4 *3 (-324 *2 *5)) (-4 *4 (-971 *2)))) (-3734 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-4 *6 (-324 *5 *7)) (-4 *7 (-230 *8 (-763))) (-14 *8 (-763)) (-4 *5 (-365)) (-5 *2 (-121)) (-5 *1 (-929 *5 *6 *7 *8 *4)) (-4 *4 (-971 *5))))) 
-(-10 -7 (-15 -3734 ((-121) (-634 |#2|) |#5|)) (-15 -1339 (|#1| |#2| |#5|)) (-15 -3481 (|#2| |#2| |#5| (-568))) (-15 -3481 (|#2| |#2| |#5|)) (-15 -2563 (|#2| |#2| |#5|)) (-15 -2563 (|#2| |#2| |#5| (-568))) (-15 -4029 ((-763) |#2| |#5|)) (-15 -4029 ((-763) |#2| |#5| (-568)))) 
-((-3037 ((|#2| |#2|) 25)) (-3033 ((|#2| |#2|) 26)) (-3495 ((|#2| |#2|) 24)) (-2209 ((|#2| |#2| (-1143)) 23))) 
-(((-930 |#1| |#2|) (-10 -7 (-15 -2209 (|#2| |#2| (-1143))) (-15 -3495 (|#2| |#2|)) (-15 -3037 (|#2| |#2|)) (-15 -3033 (|#2| |#2|))) (-842) (-432 |#1|)) (T -930)) 
-((-3033 (*1 *2 *2) (-12 (-4 *3 (-842)) (-5 *1 (-930 *3 *2)) (-4 *2 (-432 *3)))) (-3037 (*1 *2 *2) (-12 (-4 *3 (-842)) (-5 *1 (-930 *3 *2)) (-4 *2 (-432 *3)))) (-3495 (*1 *2 *2) (-12 (-4 *3 (-842)) (-5 *1 (-930 *3 *2)) (-4 *2 (-432 *3)))) (-2209 (*1 *2 *2 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-842)) (-5 *1 (-930 *4 *2)) (-4 *2 (-432 *4))))) 
-(-10 -7 (-15 -2209 (|#2| |#2| (-1143))) (-15 -3495 (|#2| |#2|)) (-15 -3037 (|#2| |#2|)) (-15 -3033 (|#2| |#2|))) 
-((-3037 (((-310 (-568)) (-1161)) 15)) (-3033 (((-310 (-568)) (-1161)) 13)) (-3495 (((-310 (-568)) (-1161)) 11)) (-2209 (((-310 (-568)) (-1161) (-1143)) 18))) 
-(((-931) (-10 -7 (-15 -2209 ((-310 (-568)) (-1161) (-1143))) (-15 -3495 ((-310 (-568)) (-1161))) (-15 -3037 ((-310 (-568)) (-1161))) (-15 -3033 ((-310 (-568)) (-1161))))) (T -931)) 
-((-3033 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-310 (-568))) (-5 *1 (-931)))) (-3037 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-310 (-568))) (-5 *1 (-931)))) (-3495 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-310 (-568))) (-5 *1 (-931)))) (-2209 (*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-1143)) (-5 *2 (-310 (-568))) (-5 *1 (-931))))) 
-(-10 -7 (-15 -2209 ((-310 (-568)) (-1161) (-1143))) (-15 -3495 ((-310 (-568)) (-1161))) (-15 -3037 ((-310 (-568)) (-1161))) (-15 -3033 ((-310 (-568)) (-1161)))) 
-((-4410 (((-884 |#1| |#3|) |#2| (-887 |#1|) (-884 |#1| |#3|)) 24)) (-2377 (((-1 (-121) |#2|) (-1 (-121) |#3|)) 12))) 
-(((-932 |#1| |#2| |#3|) (-10 -7 (-15 -2377 ((-1 (-121) |#2|) (-1 (-121) |#3|))) (-15 -4410 ((-884 |#1| |#3|) |#2| (-887 |#1|) (-884 |#1| |#3|)))) (-1090) (-881 |#1|) (-13 (-1090) (-1037 |#2|))) (T -932)) 
-((-4410 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *6)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-4 *6 (-13 (-1090) (-1037 *3))) (-4 *3 (-881 *5)) (-5 *1 (-932 *5 *3 *6)))) (-2377 (*1 *2 *3) (-12 (-5 *3 (-1 (-121) *6)) (-4 *6 (-13 (-1090) (-1037 *5))) (-4 *5 (-881 *4)) (-4 *4 (-1090)) (-5 *2 (-1 (-121) *5)) (-5 *1 (-932 *4 *5 *6))))) 
-(-10 -7 (-15 -2377 ((-1 (-121) |#2|) (-1 (-121) |#3|))) (-15 -4410 ((-884 |#1| |#3|) |#2| (-887 |#1|) (-884 |#1| |#3|)))) 
-((-4410 (((-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|)) 29))) 
-(((-933 |#1| |#2| |#3|) (-10 -7 (-15 -4410 ((-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|)))) (-1090) (-13 (-558) (-842) (-881 |#1|)) (-13 (-432 |#2|) (-609 (-887 |#1|)) (-881 |#1|) (-1037 (-607 $)))) (T -933)) 
-((-4410 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *3)) (-4 *5 (-1090)) (-4 *3 (-13 (-432 *6) (-609 *4) (-881 *5) (-1037 (-607 $)))) (-5 *4 (-887 *5)) (-4 *6 (-13 (-558) (-842) (-881 *5))) (-5 *1 (-933 *5 *6 *3))))) 
-(-10 -7 (-15 -4410 ((-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|)))) 
-((-4410 (((-884 (-568) |#1|) |#1| (-887 (-568)) (-884 (-568) |#1|)) 12))) 
-(((-934 |#1|) (-10 -7 (-15 -4410 ((-884 (-568) |#1|) |#1| (-887 (-568)) (-884 (-568) |#1|)))) (-550)) (T -934)) 
-((-4410 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 (-568) *3)) (-5 *4 (-887 (-568))) (-4 *3 (-550)) (-5 *1 (-934 *3))))) 
-(-10 -7 (-15 -4410 ((-884 (-568) |#1|) |#1| (-887 (-568)) (-884 (-568) |#1|)))) 
-((-4410 (((-884 |#1| |#2|) (-607 |#2|) (-887 |#1|) (-884 |#1| |#2|)) 52))) 
-(((-935 |#1| |#2|) (-10 -7 (-15 -4410 ((-884 |#1| |#2|) (-607 |#2|) (-887 |#1|) (-884 |#1| |#2|)))) (-1090) (-13 (-842) (-1037 (-607 $)) (-609 (-887 |#1|)) (-881 |#1|))) (T -935)) 
-((-4410 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *6)) (-5 *3 (-607 *6)) (-4 *5 (-1090)) (-4 *6 (-13 (-842) (-1037 (-607 $)) (-609 *4) (-881 *5))) (-5 *4 (-887 *5)) (-5 *1 (-935 *5 *6))))) 
-(-10 -7 (-15 -4410 ((-884 |#1| |#2|) (-607 |#2|) (-887 |#1|) (-884 |#1| |#2|)))) 
-((-4410 (((-880 |#1| |#2| |#3|) |#3| (-887 |#1|) (-880 |#1| |#2| |#3|)) 14))) 
-(((-936 |#1| |#2| |#3|) (-10 -7 (-15 -4410 ((-880 |#1| |#2| |#3|) |#3| (-887 |#1|) (-880 |#1| |#2| |#3|)))) (-1090) (-881 |#1|) (-658 |#2|)) (T -936)) 
-((-4410 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-880 *5 *6 *3)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-4 *6 (-881 *5)) (-4 *3 (-658 *6)) (-5 *1 (-936 *5 *6 *3))))) 
-(-10 -7 (-15 -4410 ((-880 |#1| |#2| |#3|) |#3| (-887 |#1|) (-880 |#1| |#2| |#3|)))) 
-((-4410 (((-884 |#1| |#5|) |#5| (-887 |#1|) (-884 |#1| |#5|)) 17 (|has| |#3| (-881 |#1|))) (((-884 |#1| |#5|) |#5| (-887 |#1|) (-884 |#1| |#5|) (-1 (-884 |#1| |#5|) |#3| (-887 |#1|) (-884 |#1| |#5|))) 16))) 
-(((-937 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -4410 ((-884 |#1| |#5|) |#5| (-887 |#1|) (-884 |#1| |#5|) (-1 (-884 |#1| |#5|) |#3| (-887 |#1|) (-884 |#1| |#5|)))) (IF (|has| |#3| (-881 |#1|)) (-15 -4410 ((-884 |#1| |#5|) |#5| (-887 |#1|) (-884 |#1| |#5|))) |noBranch|)) (-1090) (-788) (-842) (-13 (-1047) (-842) (-881 |#1|)) (-13 (-950 |#4| |#2| |#3|) (-609 (-887 |#1|)))) (T -937)) 
-((-4410 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *3)) (-4 *5 (-1090)) (-4 *3 (-13 (-950 *8 *6 *7) (-609 *4))) (-5 *4 (-887 *5)) (-4 *7 (-881 *5)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-13 (-1047) (-842) (-881 *5))) (-5 *1 (-937 *5 *6 *7 *8 *3)))) (-4410 (*1 *2 *3 *4 *2 *5) (-12 (-5 *5 (-1 (-884 *6 *3) *8 (-887 *6) (-884 *6 *3))) (-4 *8 (-842)) (-5 *2 (-884 *6 *3)) (-5 *4 (-887 *6)) (-4 *6 (-1090)) (-4 *3 (-13 (-950 *9 *7 *8) (-609 *4))) (-4 *7 (-788)) (-4 *9 (-13 (-1047) (-842) (-881 *6))) (-5 *1 (-937 *6 *7 *8 *9 *3))))) 
-(-10 -7 (-15 -4410 ((-884 |#1| |#5|) |#5| (-887 |#1|) (-884 |#1| |#5|) (-1 (-884 |#1| |#5|) |#3| (-887 |#1|) (-884 |#1| |#5|)))) (IF (|has| |#3| (-881 |#1|)) (-15 -4410 ((-884 |#1| |#5|) |#5| (-887 |#1|) (-884 |#1| |#5|))) |noBranch|)) 
-((-1562 ((|#2| |#2| (-634 (-1 (-121) |#3|))) 11) ((|#2| |#2| (-1 (-121) |#3|)) 12))) 
-(((-938 |#1| |#2| |#3|) (-10 -7 (-15 -1562 (|#2| |#2| (-1 (-121) |#3|))) (-15 -1562 (|#2| |#2| (-634 (-1 (-121) |#3|))))) (-842) (-432 |#1|) (-1195)) (T -938)) 
-((-1562 (*1 *2 *2 *3) (-12 (-5 *3 (-634 (-1 (-121) *5))) (-4 *5 (-1195)) (-4 *4 (-842)) (-5 *1 (-938 *4 *2 *5)) (-4 *2 (-432 *4)))) (-1562 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *5)) (-4 *5 (-1195)) (-4 *4 (-842)) (-5 *1 (-938 *4 *2 *5)) (-4 *2 (-432 *4))))) 
-(-10 -7 (-15 -1562 (|#2| |#2| (-1 (-121) |#3|))) (-15 -1562 (|#2| |#2| (-634 (-1 (-121) |#3|))))) 
-((-1562 (((-310 (-568)) (-1161) (-634 (-1 (-121) |#1|))) 16) (((-310 (-568)) (-1161) (-1 (-121) |#1|)) 13))) 
-(((-939 |#1|) (-10 -7 (-15 -1562 ((-310 (-568)) (-1161) (-1 (-121) |#1|))) (-15 -1562 ((-310 (-568)) (-1161) (-634 (-1 (-121) |#1|))))) (-1195)) (T -939)) 
-((-1562 (*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-634 (-1 (-121) *5))) (-4 *5 (-1195)) (-5 *2 (-310 (-568))) (-5 *1 (-939 *5)))) (-1562 (*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-1 (-121) *5)) (-4 *5 (-1195)) (-5 *2 (-310 (-568))) (-5 *1 (-939 *5))))) 
-(-10 -7 (-15 -1562 ((-310 (-568)) (-1161) (-1 (-121) |#1|))) (-15 -1562 ((-310 (-568)) (-1161) (-634 (-1 (-121) |#1|))))) 
-((-4410 (((-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|)) 25))) 
-(((-940 |#1| |#2| |#3|) (-10 -7 (-15 -4410 ((-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|)))) (-1090) (-13 (-558) (-881 |#1|) (-609 (-887 |#1|))) (-993 |#2|)) (T -940)) 
-((-4410 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *3)) (-4 *5 (-1090)) (-4 *3 (-993 *6)) (-4 *6 (-13 (-558) (-881 *5) (-609 *4))) (-5 *4 (-887 *5)) (-5 *1 (-940 *5 *6 *3))))) 
-(-10 -7 (-15 -4410 ((-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|)))) 
-((-4410 (((-884 |#1| (-1161)) (-1161) (-887 |#1|) (-884 |#1| (-1161))) 17))) 
-(((-941 |#1|) (-10 -7 (-15 -4410 ((-884 |#1| (-1161)) (-1161) (-887 |#1|) (-884 |#1| (-1161))))) (-1090)) (T -941)) 
-((-4410 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 (-1161))) (-5 *3 (-1161)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-5 *1 (-941 *5))))) 
-(-10 -7 (-15 -4410 ((-884 |#1| (-1161)) (-1161) (-887 |#1|) (-884 |#1| (-1161))))) 
-((-2693 (((-884 |#1| |#3|) (-634 |#3|) (-634 (-887 |#1|)) (-884 |#1| |#3|) (-1 (-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|))) 33)) (-4410 (((-884 |#1| |#3|) (-634 |#3|) (-634 (-887 |#1|)) (-1 |#3| (-634 |#3|)) (-884 |#1| |#3|) (-1 (-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|))) 32))) 
-(((-942 |#1| |#2| |#3|) (-10 -7 (-15 -4410 ((-884 |#1| |#3|) (-634 |#3|) (-634 (-887 |#1|)) (-1 |#3| (-634 |#3|)) (-884 |#1| |#3|) (-1 (-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|)))) (-15 -2693 ((-884 |#1| |#3|) (-634 |#3|) (-634 (-887 |#1|)) (-884 |#1| |#3|) (-1 (-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|))))) (-1090) (-13 (-1047) (-842)) (-13 (-1047) (-609 (-887 |#1|)) (-1037 |#2|))) (T -942)) 
-((-2693 (*1 *2 *3 *4 *2 *5) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 (-887 *6))) (-5 *5 (-1 (-884 *6 *8) *8 (-887 *6) (-884 *6 *8))) (-4 *6 (-1090)) (-4 *8 (-13 (-1047) (-609 (-887 *6)) (-1037 *7))) (-5 *2 (-884 *6 *8)) (-4 *7 (-13 (-1047) (-842))) (-5 *1 (-942 *6 *7 *8)))) (-4410 (*1 *2 *3 *4 *5 *2 *6) (-12 (-5 *4 (-634 (-887 *7))) (-5 *5 (-1 *9 (-634 *9))) (-5 *6 (-1 (-884 *7 *9) *9 (-887 *7) (-884 *7 *9))) (-4 *7 (-1090)) (-4 *9 (-13 (-1047) (-609 (-887 *7)) (-1037 *8))) (-5 *2 (-884 *7 *9)) (-5 *3 (-634 *9)) (-4 *8 (-13 (-1047) (-842))) (-5 *1 (-942 *7 *8 *9))))) 
-(-10 -7 (-15 -4410 ((-884 |#1| |#3|) (-634 |#3|) (-634 (-887 |#1|)) (-1 |#3| (-634 |#3|)) (-884 |#1| |#3|) (-1 (-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|)))) (-15 -2693 ((-884 |#1| |#3|) (-634 |#3|) (-634 (-887 |#1|)) (-884 |#1| |#3|) (-1 (-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|))))) 
-((-1291 (((-1157 (-409 (-568))) (-568)) 61)) (-1632 (((-1157 (-568)) (-568)) 64)) (-1308 (((-1157 (-568)) (-568)) 58)) (-3041 (((-568) (-1157 (-568))) 53)) (-3982 (((-1157 (-409 (-568))) (-568)) 47)) (-4411 (((-1157 (-568)) (-568)) 36)) (-3753 (((-1157 (-568)) (-568)) 66)) (-3978 (((-1157 (-568)) (-568)) 65)) (-2542 (((-1157 (-409 (-568))) (-568)) 49))) 
-(((-943) (-10 -7 (-15 -2542 ((-1157 (-409 (-568))) (-568))) (-15 -3978 ((-1157 (-568)) (-568))) (-15 -3753 ((-1157 (-568)) (-568))) (-15 -4411 ((-1157 (-568)) (-568))) (-15 -3982 ((-1157 (-409 (-568))) (-568))) (-15 -3041 ((-568) (-1157 (-568)))) (-15 -1308 ((-1157 (-568)) (-568))) (-15 -1632 ((-1157 (-568)) (-568))) (-15 -1291 ((-1157 (-409 (-568))) (-568))))) (T -943)) 
-((-1291 (*1 *2 *3) (-12 (-5 *2 (-1157 (-409 (-568)))) (-5 *1 (-943)) (-5 *3 (-568)))) (-1632 (*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-943)) (-5 *3 (-568)))) (-1308 (*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-943)) (-5 *3 (-568)))) (-3041 (*1 *2 *3) (-12 (-5 *3 (-1157 (-568))) (-5 *2 (-568)) (-5 *1 (-943)))) (-3982 (*1 *2 *3) (-12 (-5 *2 (-1157 (-409 (-568)))) (-5 *1 (-943)) (-5 *3 (-568)))) (-4411 (*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-943)) (-5 *3 (-568)))) (-3753 (*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-943)) (-5 *3 (-568)))) (-3978 (*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-943)) (-5 *3 (-568)))) (-2542 (*1 *2 *3) (-12 (-5 *2 (-1157 (-409 (-568)))) (-5 *1 (-943)) (-5 *3 (-568))))) 
-(-10 -7 (-15 -2542 ((-1157 (-409 (-568))) (-568))) (-15 -3978 ((-1157 (-568)) (-568))) (-15 -3753 ((-1157 (-568)) (-568))) (-15 -4411 ((-1157 (-568)) (-568))) (-15 -3982 ((-1157 (-409 (-568))) (-568))) (-15 -3041 ((-568) (-1157 (-568)))) (-15 -1308 ((-1157 (-568)) (-568))) (-15 -1632 ((-1157 (-568)) (-568))) (-15 -1291 ((-1157 (-409 (-568))) (-568)))) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3205 (($ (-763)) NIL (|has| |#1| (-23)))) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-2016 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-842)))) (-3908 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4520))) (($ $) NIL (-12 (|has| $ (-6 -4520)) (|has| |#1| (-842))))) (-3644 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-842)))) (-2510 (((-121) $ (-763)) NIL)) (-2436 ((|#1| $ (-568) |#1|) 11 (|has| $ (-6 -4520))) ((|#1| $ (-1210 (-568)) |#1|) NIL (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-2671 (($) NIL T CONST)) (-1578 (($ $) NIL (|has| $ (-6 -4520)))) (-3943 (($ $) NIL)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-4328 (($ |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4519)))) (-3989 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-568)) NIL)) (-2764 (((-568) (-1 (-121) |#1|) $) NIL) (((-568) |#1| $) NIL (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) NIL (|has| |#1| (-1090)))) (-4203 (($ (-634 |#1|)) 13)) (-4360 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-1802 (((-679 |#1|) $ $) NIL (|has| |#1| (-1047)))) (-1849 (($ (-763) |#1|) 8)) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) 10 (|has| (-568) (-842)))) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-1347 (($ (-1 (-121) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-842)))) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2223 (((-568) $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-3674 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-1550 ((|#1| $) NIL (-12 (|has| |#1| (-1002)) (|has| |#1| (-1047))))) (-2166 (((-121) $ (-763)) NIL)) (-3678 ((|#1| $) NIL (-12 (|has| |#1| (-1002)) (|has| |#1| (-1047))))) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4122 (($ |#1| $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3876 ((|#1| $) NIL (|has| (-568) (-842)))) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3724 (($ $ |#1|) NIL (|has| $ (-6 -4520)))) (-1807 (($ $ (-634 |#1|)) 24)) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#1| $ (-568) |#1|) NIL) ((|#1| $ (-568)) 18) (($ $ (-1210 (-568))) NIL)) (-3682 ((|#1| $ $) NIL (|has| |#1| (-1047)))) (-4321 (((-917) $) 16)) (-2826 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-2748 (($ $ $) 22)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2256 (($ $ $ (-568)) NIL (|has| $ (-6 -4520)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| |#1| (-609 (-541)))) (($ (-634 |#1|)) 17)) (-4287 (($ (-634 |#1|)) NIL)) (-2768 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) 23) (($ (-634 $)) NIL)) (-2745 (((-850) $) NIL (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1773 (($ $) NIL (|has| |#1| (-21))) (($ $ $) NIL (|has| |#1| (-21)))) (-1767 (($ $ $) NIL (|has| |#1| (-25)))) (* (($ (-568) $) NIL (|has| |#1| (-21))) (($ |#1| $) NIL (|has| |#1| (-716))) (($ $ |#1|) NIL (|has| |#1| (-716)))) (-1697 (((-763) $) 14 (|has| $ (-6 -4519))))) 
+((-3245 (((-568) (-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-1143)) 137)) (-1971 ((|#4| |#4|) 153)) (-2373 (((-634 (-409 (-953 |#1|))) (-634 (-1161))) 116)) (-2324 (((-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|)))))))) (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))) (-679 |#4|) (-634 (-409 (-953 |#1|))) (-634 (-634 |#4|)) (-763) (-763) (-568)) 73)) (-3518 (((-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|)))))) (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|)))))) (-634 |#4|)) 57)) (-2646 (((-679 |#4|) (-679 |#4|) (-634 |#4|)) 53)) (-3835 (((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-1143)) 149)) (-1327 (((-568) (-679 |#4|) (-917) (-1143)) 130) (((-568) (-679 |#4|) (-634 (-1161)) (-917) (-1143)) 129) (((-568) (-679 |#4|) (-634 |#4|) (-917) (-1143)) 128) (((-568) (-679 |#4|) (-1143)) 125) (((-568) (-679 |#4|) (-634 (-1161)) (-1143)) 124) (((-568) (-679 |#4|) (-634 |#4|) (-1143)) 123) (((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-917)) 122) (((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 (-1161)) (-917)) 121) (((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 |#4|) (-917)) 120) (((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|)) 118) (((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 (-1161))) 117) (((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 |#4|)) 114)) (-2043 ((|#4| (-953 |#1|)) 66)) (-2210 (((-121) (-634 |#4|) (-634 (-634 |#4|))) 150)) (-2412 (((-634 (-634 (-568))) (-568) (-568)) 127)) (-1607 (((-634 (-634 |#4|)) (-634 (-634 |#4|))) 85)) (-1442 (((-763) (-634 (-2 (|:| -2371 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 |#4|))))) 83)) (-3923 (((-763) (-634 (-2 (|:| -2371 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 |#4|))))) 82)) (-4174 (((-121) (-634 (-953 |#1|))) 17) (((-121) (-634 |#4|)) 13)) (-4270 (((-2 (|:| |sysok| (-121)) (|:| |z0| (-634 |#4|)) (|:| |n0| (-634 |#4|))) (-634 |#4|) (-634 |#4|)) 69)) (-4079 (((-634 |#4|) |#4|) 47)) (-4352 (((-634 (-409 (-953 |#1|))) (-634 |#4|)) 112) (((-679 (-409 (-953 |#1|))) (-679 |#4|)) 54) (((-409 (-953 |#1|)) |#4|) 109)) (-2810 (((-2 (|:| |rgl| (-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|)))))))))) (|:| |rgsz| (-568))) (-679 |#4|) (-634 (-409 (-953 |#1|))) (-763) (-1143) (-568)) 89)) (-1581 (((-634 (-2 (|:| -2371 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 |#4|)))) (-679 |#4|) (-763)) 81)) (-2956 (((-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568))))) (-679 |#4|) (-763)) 98)) (-4338 (((-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|)))))) (-2 (|:| -2908 (-679 (-409 (-953 |#1|)))) (|:| |vec| (-634 (-409 (-953 |#1|)))) (|:| -2371 (-763)) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568))))) 46))) 
+(((-924 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1327 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 |#4|))) (-15 -1327 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 (-1161)))) (-15 -1327 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|))) (-15 -1327 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 |#4|) (-917))) (-15 -1327 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 (-1161)) (-917))) (-15 -1327 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-917))) (-15 -1327 ((-568) (-679 |#4|) (-634 |#4|) (-1143))) (-15 -1327 ((-568) (-679 |#4|) (-634 (-1161)) (-1143))) (-15 -1327 ((-568) (-679 |#4|) (-1143))) (-15 -1327 ((-568) (-679 |#4|) (-634 |#4|) (-917) (-1143))) (-15 -1327 ((-568) (-679 |#4|) (-634 (-1161)) (-917) (-1143))) (-15 -1327 ((-568) (-679 |#4|) (-917) (-1143))) (-15 -3245 ((-568) (-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-1143))) (-15 -3835 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-1143))) (-15 -2810 ((-2 (|:| |rgl| (-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|)))))))))) (|:| |rgsz| (-568))) (-679 |#4|) (-634 (-409 (-953 |#1|))) (-763) (-1143) (-568))) (-15 -4352 ((-409 (-953 |#1|)) |#4|)) (-15 -4352 ((-679 (-409 (-953 |#1|))) (-679 |#4|))) (-15 -4352 ((-634 (-409 (-953 |#1|))) (-634 |#4|))) (-15 -2373 ((-634 (-409 (-953 |#1|))) (-634 (-1161)))) (-15 -2043 (|#4| (-953 |#1|))) (-15 -4270 ((-2 (|:| |sysok| (-121)) (|:| |z0| (-634 |#4|)) (|:| |n0| (-634 |#4|))) (-634 |#4|) (-634 |#4|))) (-15 -1581 ((-634 (-2 (|:| -2371 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 |#4|)))) (-679 |#4|) (-763))) (-15 -3518 ((-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|)))))) (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|)))))) (-634 |#4|))) (-15 -4338 ((-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|)))))) (-2 (|:| -2908 (-679 (-409 (-953 |#1|)))) (|:| |vec| (-634 (-409 (-953 |#1|)))) (|:| -2371 (-763)) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (-15 -4079 ((-634 |#4|) |#4|)) (-15 -3923 ((-763) (-634 (-2 (|:| -2371 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 |#4|)))))) (-15 -1442 ((-763) (-634 (-2 (|:| -2371 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 |#4|)))))) (-15 -1607 ((-634 (-634 |#4|)) (-634 (-634 |#4|)))) (-15 -2412 ((-634 (-634 (-568))) (-568) (-568))) (-15 -2210 ((-121) (-634 |#4|) (-634 (-634 |#4|)))) (-15 -2956 ((-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568))))) (-679 |#4|) (-763))) (-15 -2646 ((-679 |#4|) (-679 |#4|) (-634 |#4|))) (-15 -2324 ((-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|)))))))) (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))) (-679 |#4|) (-634 (-409 (-953 |#1|))) (-634 (-634 |#4|)) (-763) (-763) (-568))) (-15 -1971 (|#4| |#4|)) (-15 -4174 ((-121) (-634 |#4|))) (-15 -4174 ((-121) (-634 (-953 |#1|))))) (-13 (-301) (-150)) (-13 (-842) (-609 (-1161))) (-788) (-950 |#1| |#3| |#2|)) (T -924)) 
+((-4174 (*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-121)) (-5 *1 (-924 *4 *5 *6 *7)) (-4 *7 (-950 *4 *6 *5)))) (-4174 (*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-121)) (-5 *1 (-924 *4 *5 *6 *7)))) (-1971 (*1 *2 *2) (-12 (-4 *3 (-13 (-301) (-150))) (-4 *4 (-13 (-842) (-609 (-1161)))) (-4 *5 (-788)) (-5 *1 (-924 *3 *4 *5 *2)) (-4 *2 (-950 *3 *5 *4)))) (-2324 (*1 *2 *3 *4 *5 *6 *7 *7 *8) (-12 (-5 *3 (-2 (|:| |det| *12) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568))))) (-5 *4 (-679 *12)) (-5 *5 (-634 (-409 (-953 *9)))) (-5 *6 (-634 (-634 *12))) (-5 *7 (-763)) (-5 *8 (-568)) (-4 *9 (-13 (-301) (-150))) (-4 *12 (-950 *9 *11 *10)) (-4 *10 (-13 (-842) (-609 (-1161)))) (-4 *11 (-788)) (-5 *2 (-2 (|:| |eqzro| (-634 *12)) (|:| |neqzro| (-634 *12)) (|:| |wcond| (-634 (-953 *9))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *9)))) (|:| -2588 (-634 (-1244 (-409 (-953 *9))))))))) (-5 *1 (-924 *9 *10 *11 *12)))) (-2646 (*1 *2 *2 *3) (-12 (-5 *2 (-679 *7)) (-5 *3 (-634 *7)) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *1 (-924 *4 *5 *6 *7)))) (-2956 (*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-5 *4 (-763)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-634 (-2 (|:| |det| *8) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (-5 *1 (-924 *5 *6 *7 *8)))) (-2210 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-634 *8))) (-5 *3 (-634 *8)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-121)) (-5 *1 (-924 *5 *6 *7 *8)))) (-2412 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 (-634 (-568)))) (-5 *1 (-924 *4 *5 *6 *7)) (-5 *3 (-568)) (-4 *7 (-950 *4 *6 *5)))) (-1607 (*1 *2 *2) (-12 (-5 *2 (-634 (-634 *6))) (-4 *6 (-950 *3 *5 *4)) (-4 *3 (-13 (-301) (-150))) (-4 *4 (-13 (-842) (-609 (-1161)))) (-4 *5 (-788)) (-5 *1 (-924 *3 *4 *5 *6)))) (-1442 (*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -2371 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| *7) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 *7))))) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-763)) (-5 *1 (-924 *4 *5 *6 *7)))) (-3923 (*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -2371 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| *7) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 *7))))) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-763)) (-5 *1 (-924 *4 *5 *6 *7)))) (-4079 (*1 *2 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 *3)) (-5 *1 (-924 *4 *5 *6 *3)) (-4 *3 (-950 *4 *6 *5)))) (-4338 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| -2908 (-679 (-409 (-953 *4)))) (|:| |vec| (-634 (-409 (-953 *4)))) (|:| -2371 (-763)) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568))))) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-2 (|:| |partsol| (-1244 (-409 (-953 *4)))) (|:| -2588 (-634 (-1244 (-409 (-953 *4))))))) (-5 *1 (-924 *4 *5 *6 *7)) (-4 *7 (-950 *4 *6 *5)))) (-3518 (*1 *2 *2 *3) (-12 (-5 *2 (-2 (|:| |partsol| (-1244 (-409 (-953 *4)))) (|:| -2588 (-634 (-1244 (-409 (-953 *4))))))) (-5 *3 (-634 *7)) (-4 *4 (-13 (-301) (-150))) (-4 *7 (-950 *4 *6 *5)) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *1 (-924 *4 *5 *6 *7)))) (-1581 (*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-634 (-2 (|:| -2371 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| *8) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 *8))))) (-5 *1 (-924 *5 *6 *7 *8)) (-5 *4 (-763)))) (-4270 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-4 *7 (-950 *4 *6 *5)) (-5 *2 (-2 (|:| |sysok| (-121)) (|:| |z0| (-634 *7)) (|:| |n0| (-634 *7)))) (-5 *1 (-924 *4 *5 *6 *7)) (-5 *3 (-634 *7)))) (-2043 (*1 *2 *3) (-12 (-5 *3 (-953 *4)) (-4 *4 (-13 (-301) (-150))) (-4 *2 (-950 *4 *6 *5)) (-5 *1 (-924 *4 *5 *6 *2)) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)))) (-2373 (*1 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 (-409 (-953 *4)))) (-5 *1 (-924 *4 *5 *6 *7)) (-4 *7 (-950 *4 *6 *5)))) (-4352 (*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 (-409 (-953 *4)))) (-5 *1 (-924 *4 *5 *6 *7)))) (-4352 (*1 *2 *3) (-12 (-5 *3 (-679 *7)) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-679 (-409 (-953 *4)))) (-5 *1 (-924 *4 *5 *6 *7)))) (-4352 (*1 *2 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-409 (-953 *4))) (-5 *1 (-924 *4 *5 *6 *3)) (-4 *3 (-950 *4 *6 *5)))) (-2810 (*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *3 (-679 *11)) (-5 *4 (-634 (-409 (-953 *8)))) (-5 *5 (-763)) (-5 *6 (-1143)) (-4 *8 (-13 (-301) (-150))) (-4 *11 (-950 *8 *10 *9)) (-4 *9 (-13 (-842) (-609 (-1161)))) (-4 *10 (-788)) (-5 *2 (-2 (|:| |rgl| (-634 (-2 (|:| |eqzro| (-634 *11)) (|:| |neqzro| (-634 *11)) (|:| |wcond| (-634 (-953 *8))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *8)))) (|:| -2588 (-634 (-1244 (-409 (-953 *8)))))))))) (|:| |rgsz| (-568)))) (-5 *1 (-924 *8 *9 *10 *11)) (-5 *7 (-568)))) (-3835 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *7)) (|:| |neqzro| (-634 *7)) (|:| |wcond| (-634 (-953 *4))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *4)))) (|:| -2588 (-634 (-1244 (-409 (-953 *4)))))))))) (-5 *1 (-924 *4 *5 *6 *7)) (-4 *7 (-950 *4 *6 *5)))) (-3245 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-2 (|:| |eqzro| (-634 *8)) (|:| |neqzro| (-634 *8)) (|:| |wcond| (-634 (-953 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *5)))) (|:| -2588 (-634 (-1244 (-409 (-953 *5)))))))))) (-5 *4 (-1143)) (-4 *5 (-13 (-301) (-150))) (-4 *8 (-950 *5 *7 *6)) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *5 *6 *7 *8)))) (-1327 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *9)) (-5 *4 (-917)) (-5 *5 (-1143)) (-4 *9 (-950 *6 *8 *7)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-13 (-842) (-609 (-1161)))) (-4 *8 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *6 *7 *8 *9)))) (-1327 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-679 *10)) (-5 *4 (-634 (-1161))) (-5 *5 (-917)) (-5 *6 (-1143)) (-4 *10 (-950 *7 *9 *8)) (-4 *7 (-13 (-301) (-150))) (-4 *8 (-13 (-842) (-609 (-1161)))) (-4 *9 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *7 *8 *9 *10)))) (-1327 (*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-679 *10)) (-5 *4 (-634 *10)) (-5 *5 (-917)) (-5 *6 (-1143)) (-4 *10 (-950 *7 *9 *8)) (-4 *7 (-13 (-301) (-150))) (-4 *8 (-13 (-842) (-609 (-1161)))) (-4 *9 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *7 *8 *9 *10)))) (-1327 (*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-5 *4 (-1143)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *5 *6 *7 *8)))) (-1327 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *9)) (-5 *4 (-634 (-1161))) (-5 *5 (-1143)) (-4 *9 (-950 *6 *8 *7)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-13 (-842) (-609 (-1161)))) (-4 *8 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *6 *7 *8 *9)))) (-1327 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *9)) (-5 *4 (-634 *9)) (-5 *5 (-1143)) (-4 *9 (-950 *6 *8 *7)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-13 (-842) (-609 (-1161)))) (-4 *8 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *6 *7 *8 *9)))) (-1327 (*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-5 *4 (-917)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *8)) (|:| |neqzro| (-634 *8)) (|:| |wcond| (-634 (-953 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *5)))) (|:| -2588 (-634 (-1244 (-409 (-953 *5)))))))))) (-5 *1 (-924 *5 *6 *7 *8)))) (-1327 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *9)) (-5 *4 (-634 (-1161))) (-5 *5 (-917)) (-4 *9 (-950 *6 *8 *7)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-13 (-842) (-609 (-1161)))) (-4 *8 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *9)) (|:| |neqzro| (-634 *9)) (|:| |wcond| (-634 (-953 *6))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *6)))) (|:| -2588 (-634 (-1244 (-409 (-953 *6)))))))))) (-5 *1 (-924 *6 *7 *8 *9)))) (-1327 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *9)) (-5 *5 (-917)) (-4 *9 (-950 *6 *8 *7)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-13 (-842) (-609 (-1161)))) (-4 *8 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *9)) (|:| |neqzro| (-634 *9)) (|:| |wcond| (-634 (-953 *6))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *6)))) (|:| -2588 (-634 (-1244 (-409 (-953 *6)))))))))) (-5 *1 (-924 *6 *7 *8 *9)) (-5 *4 (-634 *9)))) (-1327 (*1 *2 *3) (-12 (-5 *3 (-679 *7)) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *7)) (|:| |neqzro| (-634 *7)) (|:| |wcond| (-634 (-953 *4))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *4)))) (|:| -2588 (-634 (-1244 (-409 (-953 *4)))))))))) (-5 *1 (-924 *4 *5 *6 *7)))) (-1327 (*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-5 *4 (-634 (-1161))) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *8)) (|:| |neqzro| (-634 *8)) (|:| |wcond| (-634 (-953 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *5)))) (|:| -2588 (-634 (-1244 (-409 (-953 *5)))))))))) (-5 *1 (-924 *5 *6 *7 *8)))) (-1327 (*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *8)) (|:| |neqzro| (-634 *8)) (|:| |wcond| (-634 (-953 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *5)))) (|:| -2588 (-634 (-1244 (-409 (-953 *5)))))))))) (-5 *1 (-924 *5 *6 *7 *8)) (-5 *4 (-634 *8))))) 
+(-10 -7 (-15 -1327 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 |#4|))) (-15 -1327 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 (-1161)))) (-15 -1327 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|))) (-15 -1327 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 |#4|) (-917))) (-15 -1327 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-634 (-1161)) (-917))) (-15 -1327 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-679 |#4|) (-917))) (-15 -1327 ((-568) (-679 |#4|) (-634 |#4|) (-1143))) (-15 -1327 ((-568) (-679 |#4|) (-634 (-1161)) (-1143))) (-15 -1327 ((-568) (-679 |#4|) (-1143))) (-15 -1327 ((-568) (-679 |#4|) (-634 |#4|) (-917) (-1143))) (-15 -1327 ((-568) (-679 |#4|) (-634 (-1161)) (-917) (-1143))) (-15 -1327 ((-568) (-679 |#4|) (-917) (-1143))) (-15 -3245 ((-568) (-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-1143))) (-15 -3835 ((-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|))))))))) (-1143))) (-15 -2810 ((-2 (|:| |rgl| (-634 (-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|)))))))))) (|:| |rgsz| (-568))) (-679 |#4|) (-634 (-409 (-953 |#1|))) (-763) (-1143) (-568))) (-15 -4352 ((-409 (-953 |#1|)) |#4|)) (-15 -4352 ((-679 (-409 (-953 |#1|))) (-679 |#4|))) (-15 -4352 ((-634 (-409 (-953 |#1|))) (-634 |#4|))) (-15 -2373 ((-634 (-409 (-953 |#1|))) (-634 (-1161)))) (-15 -2043 (|#4| (-953 |#1|))) (-15 -4270 ((-2 (|:| |sysok| (-121)) (|:| |z0| (-634 |#4|)) (|:| |n0| (-634 |#4|))) (-634 |#4|) (-634 |#4|))) (-15 -1581 ((-634 (-2 (|:| -2371 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 |#4|)))) (-679 |#4|) (-763))) (-15 -3518 ((-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|)))))) (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|)))))) (-634 |#4|))) (-15 -4338 ((-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|)))))) (-2 (|:| -2908 (-679 (-409 (-953 |#1|)))) (|:| |vec| (-634 (-409 (-953 |#1|)))) (|:| -2371 (-763)) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (-15 -4079 ((-634 |#4|) |#4|)) (-15 -3923 ((-763) (-634 (-2 (|:| -2371 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 |#4|)))))) (-15 -1442 ((-763) (-634 (-2 (|:| -2371 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 |#4|)))))) (-15 -1607 ((-634 (-634 |#4|)) (-634 (-634 |#4|)))) (-15 -2412 ((-634 (-634 (-568))) (-568) (-568))) (-15 -2210 ((-121) (-634 |#4|) (-634 (-634 |#4|)))) (-15 -2956 ((-634 (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568))))) (-679 |#4|) (-763))) (-15 -2646 ((-679 |#4|) (-679 |#4|) (-634 |#4|))) (-15 -2324 ((-2 (|:| |eqzro| (-634 |#4|)) (|:| |neqzro| (-634 |#4|)) (|:| |wcond| (-634 (-953 |#1|))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 |#1|)))) (|:| -2588 (-634 (-1244 (-409 (-953 |#1|)))))))) (-2 (|:| |det| |#4|) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))) (-679 |#4|) (-634 (-409 (-953 |#1|))) (-634 (-634 |#4|)) (-763) (-763) (-568))) (-15 -1971 (|#4| |#4|)) (-15 -4174 ((-121) (-634 |#4|))) (-15 -4174 ((-121) (-634 (-953 |#1|))))) 
+((-3612 (((-927) |#1| (-1161)) 16) (((-927) |#1| (-1161) (-1084 (-215))) 20)) (-1566 (((-927) |#1| |#1| (-1161) (-1084 (-215))) 18) (((-927) |#1| (-1161) (-1084 (-215))) 14))) 
+(((-925 |#1|) (-10 -7 (-15 -1566 ((-927) |#1| (-1161) (-1084 (-215)))) (-15 -1566 ((-927) |#1| |#1| (-1161) (-1084 (-215)))) (-15 -3612 ((-927) |#1| (-1161) (-1084 (-215)))) (-15 -3612 ((-927) |#1| (-1161)))) (-609 (-541))) (T -925)) 
+((-3612 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-5 *2 (-927)) (-5 *1 (-925 *3)) (-4 *3 (-609 (-541))))) (-3612 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1161)) (-5 *5 (-1084 (-215))) (-5 *2 (-927)) (-5 *1 (-925 *3)) (-4 *3 (-609 (-541))))) (-1566 (*1 *2 *3 *3 *4 *5) (-12 (-5 *4 (-1161)) (-5 *5 (-1084 (-215))) (-5 *2 (-927)) (-5 *1 (-925 *3)) (-4 *3 (-609 (-541))))) (-1566 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1161)) (-5 *5 (-1084 (-215))) (-5 *2 (-927)) (-5 *1 (-925 *3)) (-4 *3 (-609 (-541)))))) 
+(-10 -7 (-15 -1566 ((-927) |#1| (-1161) (-1084 (-215)))) (-15 -1566 ((-927) |#1| |#1| (-1161) (-1084 (-215)))) (-15 -3612 ((-927) |#1| (-1161) (-1084 (-215)))) (-15 -3612 ((-927) |#1| (-1161)))) 
+((-4075 (($ $ (-1084 (-215)) (-1084 (-215)) (-1084 (-215))) 68)) (-1689 (((-1084 (-215)) $) 40)) (-1421 (((-1084 (-215)) $) 39)) (-3679 (((-1084 (-215)) $) 38)) (-4232 (((-634 (-634 (-215))) $) 43)) (-1924 (((-1084 (-215)) $) 41)) (-2321 (((-568) (-568)) 32)) (-2596 (((-568) (-568)) 28)) (-3188 (((-568) (-568)) 30)) (-3493 (((-121) (-121)) 35)) (-1863 (((-568)) 31)) (-1642 (($ $ (-1084 (-215))) 71) (($ $) 72)) (-2254 (($ (-1 (-944 (-215)) (-215)) (-1084 (-215))) 76) (($ (-1 (-944 (-215)) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215))) 77)) (-1566 (($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215))) 79) (($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215))) 80) (($ $ (-1084 (-215))) 74)) (-2620 (((-568)) 36)) (-2897 (((-568)) 27)) (-2470 (((-568)) 29)) (-1878 (((-634 (-634 (-944 (-215)))) $) 92)) (-2336 (((-121) (-121)) 37)) (-2747 (((-850) $) 91)) (-4248 (((-121)) 34))) 
+(((-926) (-13 (-975) (-10 -8 (-15 -2254 ($ (-1 (-944 (-215)) (-215)) (-1084 (-215)))) (-15 -2254 ($ (-1 (-944 (-215)) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -1566 ($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215)))) (-15 -1566 ($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -1566 ($ $ (-1084 (-215)))) (-15 -4075 ($ $ (-1084 (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -1642 ($ $ (-1084 (-215)))) (-15 -1642 ($ $)) (-15 -1924 ((-1084 (-215)) $)) (-15 -4232 ((-634 (-634 (-215))) $)) (-15 -2897 ((-568))) (-15 -2596 ((-568) (-568))) (-15 -2470 ((-568))) (-15 -3188 ((-568) (-568))) (-15 -1863 ((-568))) (-15 -2321 ((-568) (-568))) (-15 -4248 ((-121))) (-15 -3493 ((-121) (-121))) (-15 -2620 ((-568))) (-15 -2336 ((-121) (-121)))))) (T -926)) 
+((-2254 (*1 *1 *2 *3) (-12 (-5 *2 (-1 (-944 (-215)) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-926)))) (-2254 (*1 *1 *2 *3 *3 *3 *3) (-12 (-5 *2 (-1 (-944 (-215)) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-926)))) (-1566 (*1 *1 *2 *2 *2 *2 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-926)))) (-1566 (*1 *1 *2 *2 *2 *2 *3 *3 *3 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-926)))) (-1566 (*1 *1 *1 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-926)))) (-4075 (*1 *1 *1 *2 *2 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-926)))) (-1642 (*1 *1 *1 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-926)))) (-1642 (*1 *1 *1) (-5 *1 (-926))) (-1924 (*1 *2 *1) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-926)))) (-4232 (*1 *2 *1) (-12 (-5 *2 (-634 (-634 (-215)))) (-5 *1 (-926)))) (-2897 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926)))) (-2596 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926)))) (-2470 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926)))) (-3188 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926)))) (-1863 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926)))) (-2321 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926)))) (-4248 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-926)))) (-3493 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-926)))) (-2620 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926)))) (-2336 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-926))))) 
+(-13 (-975) (-10 -8 (-15 -2254 ($ (-1 (-944 (-215)) (-215)) (-1084 (-215)))) (-15 -2254 ($ (-1 (-944 (-215)) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -1566 ($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215)))) (-15 -1566 ($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -1566 ($ $ (-1084 (-215)))) (-15 -4075 ($ $ (-1084 (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -1642 ($ $ (-1084 (-215)))) (-15 -1642 ($ $)) (-15 -1924 ((-1084 (-215)) $)) (-15 -4232 ((-634 (-634 (-215))) $)) (-15 -2897 ((-568))) (-15 -2596 ((-568) (-568))) (-15 -2470 ((-568))) (-15 -3188 ((-568) (-568))) (-15 -1863 ((-568))) (-15 -2321 ((-568) (-568))) (-15 -4248 ((-121))) (-15 -3493 ((-121) (-121))) (-15 -2620 ((-568))) (-15 -2336 ((-121) (-121))))) 
+((-4075 (($ $ (-1084 (-215))) 69) (($ $ (-1084 (-215)) (-1084 (-215))) 70)) (-1421 (((-1084 (-215)) $) 43)) (-3679 (((-1084 (-215)) $) 42)) (-1924 (((-1084 (-215)) $) 44)) (-1390 (((-568) (-568)) 36)) (-4344 (((-568) (-568)) 32)) (-1559 (((-568) (-568)) 34)) (-3394 (((-121) (-121)) 38)) (-4420 (((-568)) 35)) (-1642 (($ $ (-1084 (-215))) 73) (($ $) 74)) (-2254 (($ (-1 (-944 (-215)) (-215)) (-1084 (-215))) 83) (($ (-1 (-944 (-215)) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215))) 84)) (-3612 (($ (-1 (-215) (-215)) (-1084 (-215))) 91) (($ (-1 (-215) (-215))) 94)) (-1566 (($ (-1 (-215) (-215)) (-1084 (-215))) 78) (($ (-1 (-215) (-215)) (-1084 (-215)) (-1084 (-215))) 79) (($ (-634 (-1 (-215) (-215))) (-1084 (-215))) 86) (($ (-634 (-1 (-215) (-215))) (-1084 (-215)) (-1084 (-215))) 87) (($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215))) 80) (($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215))) 81) (($ $ (-1084 (-215))) 75)) (-4046 (((-121) $) 39)) (-4474 (((-568)) 40)) (-1502 (((-568)) 31)) (-2728 (((-568)) 33)) (-1878 (((-634 (-634 (-944 (-215)))) $) 22)) (-4021 (((-121) (-121)) 41)) (-2747 (((-850) $) 105)) (-3523 (((-121)) 37))) 
+(((-927) (-13 (-955) (-10 -8 (-15 -1566 ($ (-1 (-215) (-215)) (-1084 (-215)))) (-15 -1566 ($ (-1 (-215) (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -1566 ($ (-634 (-1 (-215) (-215))) (-1084 (-215)))) (-15 -1566 ($ (-634 (-1 (-215) (-215))) (-1084 (-215)) (-1084 (-215)))) (-15 -1566 ($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215)))) (-15 -1566 ($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -2254 ($ (-1 (-944 (-215)) (-215)) (-1084 (-215)))) (-15 -2254 ($ (-1 (-944 (-215)) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -3612 ($ (-1 (-215) (-215)) (-1084 (-215)))) (-15 -3612 ($ (-1 (-215) (-215)))) (-15 -1566 ($ $ (-1084 (-215)))) (-15 -4046 ((-121) $)) (-15 -4075 ($ $ (-1084 (-215)))) (-15 -4075 ($ $ (-1084 (-215)) (-1084 (-215)))) (-15 -1642 ($ $ (-1084 (-215)))) (-15 -1642 ($ $)) (-15 -1924 ((-1084 (-215)) $)) (-15 -1502 ((-568))) (-15 -4344 ((-568) (-568))) (-15 -2728 ((-568))) (-15 -1559 ((-568) (-568))) (-15 -4420 ((-568))) (-15 -1390 ((-568) (-568))) (-15 -3523 ((-121))) (-15 -3394 ((-121) (-121))) (-15 -4474 ((-568))) (-15 -4021 ((-121) (-121)))))) (T -927)) 
+((-1566 (*1 *1 *2 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) (-1566 (*1 *1 *2 *3 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) (-1566 (*1 *1 *2 *3) (-12 (-5 *2 (-634 (-1 (-215) (-215)))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) (-1566 (*1 *1 *2 *3 *3) (-12 (-5 *2 (-634 (-1 (-215) (-215)))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) (-1566 (*1 *1 *2 *2 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) (-1566 (*1 *1 *2 *2 *3 *3 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) (-2254 (*1 *1 *2 *3) (-12 (-5 *2 (-1 (-944 (-215)) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) (-2254 (*1 *1 *2 *3 *3 *3) (-12 (-5 *2 (-1 (-944 (-215)) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) (-3612 (*1 *1 *2 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) (-3612 (*1 *1 *2) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *1 (-927)))) (-1566 (*1 *1 *1 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-927)))) (-4046 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-927)))) (-4075 (*1 *1 *1 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-927)))) (-4075 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-927)))) (-1642 (*1 *1 *1 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-927)))) (-1642 (*1 *1 *1) (-5 *1 (-927))) (-1924 (*1 *2 *1) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-927)))) (-1502 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927)))) (-4344 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927)))) (-2728 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927)))) (-1559 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927)))) (-4420 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927)))) (-1390 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927)))) (-3523 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-927)))) (-3394 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-927)))) (-4474 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927)))) (-4021 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-927))))) 
+(-13 (-955) (-10 -8 (-15 -1566 ($ (-1 (-215) (-215)) (-1084 (-215)))) (-15 -1566 ($ (-1 (-215) (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -1566 ($ (-634 (-1 (-215) (-215))) (-1084 (-215)))) (-15 -1566 ($ (-634 (-1 (-215) (-215))) (-1084 (-215)) (-1084 (-215)))) (-15 -1566 ($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215)))) (-15 -1566 ($ (-1 (-215) (-215)) (-1 (-215) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -2254 ($ (-1 (-944 (-215)) (-215)) (-1084 (-215)))) (-15 -2254 ($ (-1 (-944 (-215)) (-215)) (-1084 (-215)) (-1084 (-215)) (-1084 (-215)))) (-15 -3612 ($ (-1 (-215) (-215)) (-1084 (-215)))) (-15 -3612 ($ (-1 (-215) (-215)))) (-15 -1566 ($ $ (-1084 (-215)))) (-15 -4046 ((-121) $)) (-15 -4075 ($ $ (-1084 (-215)))) (-15 -4075 ($ $ (-1084 (-215)) (-1084 (-215)))) (-15 -1642 ($ $ (-1084 (-215)))) (-15 -1642 ($ $)) (-15 -1924 ((-1084 (-215)) $)) (-15 -1502 ((-568))) (-15 -4344 ((-568) (-568))) (-15 -2728 ((-568))) (-15 -1559 ((-568) (-568))) (-15 -4420 ((-568))) (-15 -1390 ((-568) (-568))) (-15 -3523 ((-121))) (-15 -3394 ((-121) (-121))) (-15 -4474 ((-568))) (-15 -4021 ((-121) (-121))))) 
+((-4068 (((-634 (-1084 (-215))) (-634 (-634 (-944 (-215))))) 23))) 
+(((-928) (-10 -7 (-15 -4068 ((-634 (-1084 (-215))) (-634 (-634 (-944 (-215)))))))) (T -928)) 
+((-4068 (*1 *2 *3) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *2 (-634 (-1084 (-215)))) (-5 *1 (-928))))) 
+(-10 -7 (-15 -4068 ((-634 (-1084 (-215))) (-634 (-634 (-944 (-215))))))) 
+((-3794 ((|#2| |#2| |#5|) 39) ((|#2| |#2| |#5| (-568)) 20)) (-2537 (((-121) (-634 |#2|) |#5|) 23)) (-1470 (((-763) |#2| |#5| (-568)) 42) (((-763) |#2| |#5|) 41)) (-1936 ((|#2| |#2| |#5| (-568)) 45) ((|#2| |#2| |#5|) 44)) (-1339 ((|#1| |#2| |#5|) 21))) 
+(((-929 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2537 ((-121) (-634 |#2|) |#5|)) (-15 -1339 (|#1| |#2| |#5|)) (-15 -3794 (|#2| |#2| |#5| (-568))) (-15 -3794 (|#2| |#2| |#5|)) (-15 -1936 (|#2| |#2| |#5|)) (-15 -1936 (|#2| |#2| |#5| (-568))) (-15 -1470 ((-763) |#2| |#5|)) (-15 -1470 ((-763) |#2| |#5| (-568)))) (-365) (-324 |#1| |#3|) (-230 |#4| (-763)) (-763) (-971 |#1|)) (T -929)) 
+((-1470 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-568)) (-4 *6 (-365)) (-4 *7 (-230 *8 *2)) (-14 *8 *2) (-5 *2 (-763)) (-5 *1 (-929 *6 *3 *7 *8 *4)) (-4 *3 (-324 *6 *7)) (-4 *4 (-971 *6)))) (-1470 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-230 *7 *2)) (-14 *7 *2) (-5 *2 (-763)) (-5 *1 (-929 *5 *3 *6 *7 *4)) (-4 *3 (-324 *5 *6)) (-4 *4 (-971 *5)))) (-1936 (*1 *2 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-365)) (-4 *6 (-230 *7 (-763))) (-14 *7 (-763)) (-5 *1 (-929 *5 *2 *6 *7 *3)) (-4 *2 (-324 *5 *6)) (-4 *3 (-971 *5)))) (-1936 (*1 *2 *2 *3) (-12 (-4 *4 (-365)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-929 *4 *2 *5 *6 *3)) (-4 *2 (-324 *4 *5)) (-4 *3 (-971 *4)))) (-3794 (*1 *2 *2 *3) (-12 (-4 *4 (-365)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-929 *4 *2 *5 *6 *3)) (-4 *2 (-324 *4 *5)) (-4 *3 (-971 *4)))) (-3794 (*1 *2 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-365)) (-4 *6 (-230 *7 (-763))) (-14 *7 (-763)) (-5 *1 (-929 *5 *2 *6 *7 *3)) (-4 *2 (-324 *5 *6)) (-4 *3 (-971 *5)))) (-1339 (*1 *2 *3 *4) (-12 (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-4 *2 (-365)) (-5 *1 (-929 *2 *3 *5 *6 *4)) (-4 *3 (-324 *2 *5)) (-4 *4 (-971 *2)))) (-2537 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-4 *6 (-324 *5 *7)) (-4 *7 (-230 *8 (-763))) (-14 *8 (-763)) (-4 *5 (-365)) (-5 *2 (-121)) (-5 *1 (-929 *5 *6 *7 *8 *4)) (-4 *4 (-971 *5))))) 
+(-10 -7 (-15 -2537 ((-121) (-634 |#2|) |#5|)) (-15 -1339 (|#1| |#2| |#5|)) (-15 -3794 (|#2| |#2| |#5| (-568))) (-15 -3794 (|#2| |#2| |#5|)) (-15 -1936 (|#2| |#2| |#5|)) (-15 -1936 (|#2| |#2| |#5| (-568))) (-15 -1470 ((-763) |#2| |#5|)) (-15 -1470 ((-763) |#2| |#5| (-568)))) 
+((-3039 ((|#2| |#2|) 25)) (-3035 ((|#2| |#2|) 26)) (-3497 ((|#2| |#2|) 24)) (-2211 ((|#2| |#2| (-1143)) 23))) 
+(((-930 |#1| |#2|) (-10 -7 (-15 -2211 (|#2| |#2| (-1143))) (-15 -3497 (|#2| |#2|)) (-15 -3039 (|#2| |#2|)) (-15 -3035 (|#2| |#2|))) (-842) (-432 |#1|)) (T -930)) 
+((-3035 (*1 *2 *2) (-12 (-4 *3 (-842)) (-5 *1 (-930 *3 *2)) (-4 *2 (-432 *3)))) (-3039 (*1 *2 *2) (-12 (-4 *3 (-842)) (-5 *1 (-930 *3 *2)) (-4 *2 (-432 *3)))) (-3497 (*1 *2 *2) (-12 (-4 *3 (-842)) (-5 *1 (-930 *3 *2)) (-4 *2 (-432 *3)))) (-2211 (*1 *2 *2 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-842)) (-5 *1 (-930 *4 *2)) (-4 *2 (-432 *4))))) 
+(-10 -7 (-15 -2211 (|#2| |#2| (-1143))) (-15 -3497 (|#2| |#2|)) (-15 -3039 (|#2| |#2|)) (-15 -3035 (|#2| |#2|))) 
+((-3039 (((-310 (-568)) (-1161)) 15)) (-3035 (((-310 (-568)) (-1161)) 13)) (-3497 (((-310 (-568)) (-1161)) 11)) (-2211 (((-310 (-568)) (-1161) (-1143)) 18))) 
+(((-931) (-10 -7 (-15 -2211 ((-310 (-568)) (-1161) (-1143))) (-15 -3497 ((-310 (-568)) (-1161))) (-15 -3039 ((-310 (-568)) (-1161))) (-15 -3035 ((-310 (-568)) (-1161))))) (T -931)) 
+((-3035 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-310 (-568))) (-5 *1 (-931)))) (-3039 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-310 (-568))) (-5 *1 (-931)))) (-3497 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-310 (-568))) (-5 *1 (-931)))) (-2211 (*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-1143)) (-5 *2 (-310 (-568))) (-5 *1 (-931))))) 
+(-10 -7 (-15 -2211 ((-310 (-568)) (-1161) (-1143))) (-15 -3497 ((-310 (-568)) (-1161))) (-15 -3039 ((-310 (-568)) (-1161))) (-15 -3035 ((-310 (-568)) (-1161)))) 
+((-1519 (((-884 |#1| |#3|) |#2| (-887 |#1|) (-884 |#1| |#3|)) 24)) (-2159 (((-1 (-121) |#2|) (-1 (-121) |#3|)) 12))) 
+(((-932 |#1| |#2| |#3|) (-10 -7 (-15 -2159 ((-1 (-121) |#2|) (-1 (-121) |#3|))) (-15 -1519 ((-884 |#1| |#3|) |#2| (-887 |#1|) (-884 |#1| |#3|)))) (-1090) (-881 |#1|) (-13 (-1090) (-1037 |#2|))) (T -932)) 
+((-1519 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *6)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-4 *6 (-13 (-1090) (-1037 *3))) (-4 *3 (-881 *5)) (-5 *1 (-932 *5 *3 *6)))) (-2159 (*1 *2 *3) (-12 (-5 *3 (-1 (-121) *6)) (-4 *6 (-13 (-1090) (-1037 *5))) (-4 *5 (-881 *4)) (-4 *4 (-1090)) (-5 *2 (-1 (-121) *5)) (-5 *1 (-932 *4 *5 *6))))) 
+(-10 -7 (-15 -2159 ((-1 (-121) |#2|) (-1 (-121) |#3|))) (-15 -1519 ((-884 |#1| |#3|) |#2| (-887 |#1|) (-884 |#1| |#3|)))) 
+((-1519 (((-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|)) 29))) 
+(((-933 |#1| |#2| |#3|) (-10 -7 (-15 -1519 ((-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|)))) (-1090) (-13 (-558) (-842) (-881 |#1|)) (-13 (-432 |#2|) (-609 (-887 |#1|)) (-881 |#1|) (-1037 (-607 $)))) (T -933)) 
+((-1519 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *3)) (-4 *5 (-1090)) (-4 *3 (-13 (-432 *6) (-609 *4) (-881 *5) (-1037 (-607 $)))) (-5 *4 (-887 *5)) (-4 *6 (-13 (-558) (-842) (-881 *5))) (-5 *1 (-933 *5 *6 *3))))) 
+(-10 -7 (-15 -1519 ((-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|)))) 
+((-1519 (((-884 (-568) |#1|) |#1| (-887 (-568)) (-884 (-568) |#1|)) 12))) 
+(((-934 |#1|) (-10 -7 (-15 -1519 ((-884 (-568) |#1|) |#1| (-887 (-568)) (-884 (-568) |#1|)))) (-550)) (T -934)) 
+((-1519 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 (-568) *3)) (-5 *4 (-887 (-568))) (-4 *3 (-550)) (-5 *1 (-934 *3))))) 
+(-10 -7 (-15 -1519 ((-884 (-568) |#1|) |#1| (-887 (-568)) (-884 (-568) |#1|)))) 
+((-1519 (((-884 |#1| |#2|) (-607 |#2|) (-887 |#1|) (-884 |#1| |#2|)) 52))) 
+(((-935 |#1| |#2|) (-10 -7 (-15 -1519 ((-884 |#1| |#2|) (-607 |#2|) (-887 |#1|) (-884 |#1| |#2|)))) (-1090) (-13 (-842) (-1037 (-607 $)) (-609 (-887 |#1|)) (-881 |#1|))) (T -935)) 
+((-1519 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *6)) (-5 *3 (-607 *6)) (-4 *5 (-1090)) (-4 *6 (-13 (-842) (-1037 (-607 $)) (-609 *4) (-881 *5))) (-5 *4 (-887 *5)) (-5 *1 (-935 *5 *6))))) 
+(-10 -7 (-15 -1519 ((-884 |#1| |#2|) (-607 |#2|) (-887 |#1|) (-884 |#1| |#2|)))) 
+((-1519 (((-880 |#1| |#2| |#3|) |#3| (-887 |#1|) (-880 |#1| |#2| |#3|)) 14))) 
+(((-936 |#1| |#2| |#3|) (-10 -7 (-15 -1519 ((-880 |#1| |#2| |#3|) |#3| (-887 |#1|) (-880 |#1| |#2| |#3|)))) (-1090) (-881 |#1|) (-658 |#2|)) (T -936)) 
+((-1519 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-880 *5 *6 *3)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-4 *6 (-881 *5)) (-4 *3 (-658 *6)) (-5 *1 (-936 *5 *6 *3))))) 
+(-10 -7 (-15 -1519 ((-880 |#1| |#2| |#3|) |#3| (-887 |#1|) (-880 |#1| |#2| |#3|)))) 
+((-1519 (((-884 |#1| |#5|) |#5| (-887 |#1|) (-884 |#1| |#5|)) 17 (|has| |#3| (-881 |#1|))) (((-884 |#1| |#5|) |#5| (-887 |#1|) (-884 |#1| |#5|) (-1 (-884 |#1| |#5|) |#3| (-887 |#1|) (-884 |#1| |#5|))) 16))) 
+(((-937 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1519 ((-884 |#1| |#5|) |#5| (-887 |#1|) (-884 |#1| |#5|) (-1 (-884 |#1| |#5|) |#3| (-887 |#1|) (-884 |#1| |#5|)))) (IF (|has| |#3| (-881 |#1|)) (-15 -1519 ((-884 |#1| |#5|) |#5| (-887 |#1|) (-884 |#1| |#5|))) |noBranch|)) (-1090) (-788) (-842) (-13 (-1047) (-842) (-881 |#1|)) (-13 (-950 |#4| |#2| |#3|) (-609 (-887 |#1|)))) (T -937)) 
+((-1519 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *3)) (-4 *5 (-1090)) (-4 *3 (-13 (-950 *8 *6 *7) (-609 *4))) (-5 *4 (-887 *5)) (-4 *7 (-881 *5)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-13 (-1047) (-842) (-881 *5))) (-5 *1 (-937 *5 *6 *7 *8 *3)))) (-1519 (*1 *2 *3 *4 *2 *5) (-12 (-5 *5 (-1 (-884 *6 *3) *8 (-887 *6) (-884 *6 *3))) (-4 *8 (-842)) (-5 *2 (-884 *6 *3)) (-5 *4 (-887 *6)) (-4 *6 (-1090)) (-4 *3 (-13 (-950 *9 *7 *8) (-609 *4))) (-4 *7 (-788)) (-4 *9 (-13 (-1047) (-842) (-881 *6))) (-5 *1 (-937 *6 *7 *8 *9 *3))))) 
+(-10 -7 (-15 -1519 ((-884 |#1| |#5|) |#5| (-887 |#1|) (-884 |#1| |#5|) (-1 (-884 |#1| |#5|) |#3| (-887 |#1|) (-884 |#1| |#5|)))) (IF (|has| |#3| (-881 |#1|)) (-15 -1519 ((-884 |#1| |#5|) |#5| (-887 |#1|) (-884 |#1| |#5|))) |noBranch|)) 
+((-1563 ((|#2| |#2| (-634 (-1 (-121) |#3|))) 11) ((|#2| |#2| (-1 (-121) |#3|)) 12))) 
+(((-938 |#1| |#2| |#3|) (-10 -7 (-15 -1563 (|#2| |#2| (-1 (-121) |#3|))) (-15 -1563 (|#2| |#2| (-634 (-1 (-121) |#3|))))) (-842) (-432 |#1|) (-1195)) (T -938)) 
+((-1563 (*1 *2 *2 *3) (-12 (-5 *3 (-634 (-1 (-121) *5))) (-4 *5 (-1195)) (-4 *4 (-842)) (-5 *1 (-938 *4 *2 *5)) (-4 *2 (-432 *4)))) (-1563 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *5)) (-4 *5 (-1195)) (-4 *4 (-842)) (-5 *1 (-938 *4 *2 *5)) (-4 *2 (-432 *4))))) 
+(-10 -7 (-15 -1563 (|#2| |#2| (-1 (-121) |#3|))) (-15 -1563 (|#2| |#2| (-634 (-1 (-121) |#3|))))) 
+((-1563 (((-310 (-568)) (-1161) (-634 (-1 (-121) |#1|))) 16) (((-310 (-568)) (-1161) (-1 (-121) |#1|)) 13))) 
+(((-939 |#1|) (-10 -7 (-15 -1563 ((-310 (-568)) (-1161) (-1 (-121) |#1|))) (-15 -1563 ((-310 (-568)) (-1161) (-634 (-1 (-121) |#1|))))) (-1195)) (T -939)) 
+((-1563 (*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-634 (-1 (-121) *5))) (-4 *5 (-1195)) (-5 *2 (-310 (-568))) (-5 *1 (-939 *5)))) (-1563 (*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-1 (-121) *5)) (-4 *5 (-1195)) (-5 *2 (-310 (-568))) (-5 *1 (-939 *5))))) 
+(-10 -7 (-15 -1563 ((-310 (-568)) (-1161) (-1 (-121) |#1|))) (-15 -1563 ((-310 (-568)) (-1161) (-634 (-1 (-121) |#1|))))) 
+((-1519 (((-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|)) 25))) 
+(((-940 |#1| |#2| |#3|) (-10 -7 (-15 -1519 ((-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|)))) (-1090) (-13 (-558) (-881 |#1|) (-609 (-887 |#1|))) (-993 |#2|)) (T -940)) 
+((-1519 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *3)) (-4 *5 (-1090)) (-4 *3 (-993 *6)) (-4 *6 (-13 (-558) (-881 *5) (-609 *4))) (-5 *4 (-887 *5)) (-5 *1 (-940 *5 *6 *3))))) 
+(-10 -7 (-15 -1519 ((-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|)))) 
+((-1519 (((-884 |#1| (-1161)) (-1161) (-887 |#1|) (-884 |#1| (-1161))) 17))) 
+(((-941 |#1|) (-10 -7 (-15 -1519 ((-884 |#1| (-1161)) (-1161) (-887 |#1|) (-884 |#1| (-1161))))) (-1090)) (T -941)) 
+((-1519 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 (-1161))) (-5 *3 (-1161)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-5 *1 (-941 *5))))) 
+(-10 -7 (-15 -1519 ((-884 |#1| (-1161)) (-1161) (-887 |#1|) (-884 |#1| (-1161))))) 
+((-1372 (((-884 |#1| |#3|) (-634 |#3|) (-634 (-887 |#1|)) (-884 |#1| |#3|) (-1 (-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|))) 33)) (-1519 (((-884 |#1| |#3|) (-634 |#3|) (-634 (-887 |#1|)) (-1 |#3| (-634 |#3|)) (-884 |#1| |#3|) (-1 (-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|))) 32))) 
+(((-942 |#1| |#2| |#3|) (-10 -7 (-15 -1519 ((-884 |#1| |#3|) (-634 |#3|) (-634 (-887 |#1|)) (-1 |#3| (-634 |#3|)) (-884 |#1| |#3|) (-1 (-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|)))) (-15 -1372 ((-884 |#1| |#3|) (-634 |#3|) (-634 (-887 |#1|)) (-884 |#1| |#3|) (-1 (-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|))))) (-1090) (-13 (-1047) (-842)) (-13 (-1047) (-609 (-887 |#1|)) (-1037 |#2|))) (T -942)) 
+((-1372 (*1 *2 *3 *4 *2 *5) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 (-887 *6))) (-5 *5 (-1 (-884 *6 *8) *8 (-887 *6) (-884 *6 *8))) (-4 *6 (-1090)) (-4 *8 (-13 (-1047) (-609 (-887 *6)) (-1037 *7))) (-5 *2 (-884 *6 *8)) (-4 *7 (-13 (-1047) (-842))) (-5 *1 (-942 *6 *7 *8)))) (-1519 (*1 *2 *3 *4 *5 *2 *6) (-12 (-5 *4 (-634 (-887 *7))) (-5 *5 (-1 *9 (-634 *9))) (-5 *6 (-1 (-884 *7 *9) *9 (-887 *7) (-884 *7 *9))) (-4 *7 (-1090)) (-4 *9 (-13 (-1047) (-609 (-887 *7)) (-1037 *8))) (-5 *2 (-884 *7 *9)) (-5 *3 (-634 *9)) (-4 *8 (-13 (-1047) (-842))) (-5 *1 (-942 *7 *8 *9))))) 
+(-10 -7 (-15 -1519 ((-884 |#1| |#3|) (-634 |#3|) (-634 (-887 |#1|)) (-1 |#3| (-634 |#3|)) (-884 |#1| |#3|) (-1 (-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|)))) (-15 -1372 ((-884 |#1| |#3|) (-634 |#3|) (-634 (-887 |#1|)) (-884 |#1| |#3|) (-1 (-884 |#1| |#3|) |#3| (-887 |#1|) (-884 |#1| |#3|))))) 
+((-3214 (((-1157 (-409 (-568))) (-568)) 61)) (-1530 (((-1157 (-568)) (-568)) 64)) (-3346 (((-1157 (-568)) (-568)) 58)) (-2230 (((-568) (-1157 (-568))) 53)) (-4492 (((-1157 (-409 (-568))) (-568)) 47)) (-1526 (((-1157 (-568)) (-568)) 36)) (-2623 (((-1157 (-568)) (-568)) 66)) (-4477 (((-1157 (-568)) (-568)) 65)) (-1839 (((-1157 (-409 (-568))) (-568)) 49))) 
+(((-943) (-10 -7 (-15 -1839 ((-1157 (-409 (-568))) (-568))) (-15 -4477 ((-1157 (-568)) (-568))) (-15 -2623 ((-1157 (-568)) (-568))) (-15 -1526 ((-1157 (-568)) (-568))) (-15 -4492 ((-1157 (-409 (-568))) (-568))) (-15 -2230 ((-568) (-1157 (-568)))) (-15 -3346 ((-1157 (-568)) (-568))) (-15 -1530 ((-1157 (-568)) (-568))) (-15 -3214 ((-1157 (-409 (-568))) (-568))))) (T -943)) 
+((-3214 (*1 *2 *3) (-12 (-5 *2 (-1157 (-409 (-568)))) (-5 *1 (-943)) (-5 *3 (-568)))) (-1530 (*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-943)) (-5 *3 (-568)))) (-3346 (*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-943)) (-5 *3 (-568)))) (-2230 (*1 *2 *3) (-12 (-5 *3 (-1157 (-568))) (-5 *2 (-568)) (-5 *1 (-943)))) (-4492 (*1 *2 *3) (-12 (-5 *2 (-1157 (-409 (-568)))) (-5 *1 (-943)) (-5 *3 (-568)))) (-1526 (*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-943)) (-5 *3 (-568)))) (-2623 (*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-943)) (-5 *3 (-568)))) (-4477 (*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-943)) (-5 *3 (-568)))) (-1839 (*1 *2 *3) (-12 (-5 *2 (-1157 (-409 (-568)))) (-5 *1 (-943)) (-5 *3 (-568))))) 
+(-10 -7 (-15 -1839 ((-1157 (-409 (-568))) (-568))) (-15 -4477 ((-1157 (-568)) (-568))) (-15 -2623 ((-1157 (-568)) (-568))) (-15 -1526 ((-1157 (-568)) (-568))) (-15 -4492 ((-1157 (-409 (-568))) (-568))) (-15 -2230 ((-568) (-1157 (-568)))) (-15 -3346 ((-1157 (-568)) (-568))) (-15 -1530 ((-1157 (-568)) (-568))) (-15 -3214 ((-1157 (-409 (-568))) (-568)))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3207 (($ (-763)) NIL (|has| |#1| (-23)))) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-1324 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-842)))) (-2109 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4522))) (($ $) NIL (-12 (|has| $ (-6 -4522)) (|has| |#1| (-842))))) (-3647 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-842)))) (-1667 (((-121) $ (-763)) NIL)) (-2438 ((|#1| $ (-568) |#1|) 11 (|has| $ (-6 -4522))) ((|#1| $ (-1210 (-568)) |#1|) NIL (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-4490 (($) NIL T CONST)) (-4452 (($ $) NIL (|has| $ (-6 -4522)))) (-3945 (($ $) NIL)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-4330 (($ |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4521)))) (-1292 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-568)) NIL)) (-2766 (((-568) (-1 (-121) |#1|) $) NIL) (((-568) |#1| $) NIL (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) NIL (|has| |#1| (-1090)))) (-4098 (($ (-634 |#1|)) 13)) (-3317 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-1804 (((-679 |#1|) $ $) NIL (|has| |#1| (-1047)))) (-1851 (($ (-763) |#1|) 8)) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) 10 (|has| (-568) (-842)))) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-3645 (($ (-1 (-121) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-842)))) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3631 (((-568) $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-2253 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-4303 ((|#1| $) NIL (-12 (|has| |#1| (-1002)) (|has| |#1| (-1047))))) (-3796 (((-121) $ (-763)) NIL)) (-3680 ((|#1| $) NIL (-12 (|has| |#1| (-1002)) (|has| |#1| (-1047))))) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4124 (($ |#1| $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3877 ((|#1| $) NIL (|has| (-568) (-842)))) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-2490 (($ $ |#1|) NIL (|has| $ (-6 -4522)))) (-2168 (($ $ (-634 |#1|)) 24)) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#1| $ (-568) |#1|) NIL) ((|#1| $ (-568)) 18) (($ $ (-1210 (-568))) NIL)) (-2286 ((|#1| $ $) NIL (|has| |#1| (-1047)))) (-3108 (((-917) $) 16)) (-2828 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-3372 (($ $ $) 22)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3306 (($ $ $ (-568)) NIL (|has| $ (-6 -4522)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| |#1| (-609 (-541)))) (($ (-634 |#1|)) 17)) (-4289 (($ (-634 |#1|)) NIL)) (-2770 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) 23) (($ (-634 $)) NIL)) (-2747 (((-850) $) NIL (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1775 (($ $) NIL (|has| |#1| (-21))) (($ $ $) NIL (|has| |#1| (-21)))) (-1769 (($ $ $) NIL (|has| |#1| (-25)))) (* (($ (-568) $) NIL (|has| |#1| (-21))) (($ |#1| $) NIL (|has| |#1| (-716))) (($ $ |#1|) NIL (|has| |#1| (-716)))) (-1699 (((-763) $) 14 (|has| $ (-6 -4521))))) 
 (((-944 |#1|) (-981 |#1|) (-1047)) (T -944)) 
 NIL 
 (-981 |#1|) 
-((-3699 (((-492 |#1| |#2|) (-953 |#2|)) 17)) (-3493 (((-242 |#1| |#2|) (-953 |#2|)) 29)) (-3343 (((-953 |#2|) (-492 |#1| |#2|)) 22)) (-4218 (((-242 |#1| |#2|) (-492 |#1| |#2|)) 53)) (-3260 (((-953 |#2|) (-242 |#1| |#2|)) 26)) (-1752 (((-492 |#1| |#2|) (-242 |#1| |#2|)) 44))) 
-(((-945 |#1| |#2|) (-10 -7 (-15 -1752 ((-492 |#1| |#2|) (-242 |#1| |#2|))) (-15 -4218 ((-242 |#1| |#2|) (-492 |#1| |#2|))) (-15 -3699 ((-492 |#1| |#2|) (-953 |#2|))) (-15 -3343 ((-953 |#2|) (-492 |#1| |#2|))) (-15 -3260 ((-953 |#2|) (-242 |#1| |#2|))) (-15 -3493 ((-242 |#1| |#2|) (-953 |#2|)))) (-634 (-1161)) (-1047)) (T -945)) 
-((-3493 (*1 *2 *3) (-12 (-5 *3 (-953 *5)) (-4 *5 (-1047)) (-5 *2 (-242 *4 *5)) (-5 *1 (-945 *4 *5)) (-14 *4 (-634 (-1161))))) (-3260 (*1 *2 *3) (-12 (-5 *3 (-242 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-1047)) (-5 *2 (-953 *5)) (-5 *1 (-945 *4 *5)))) (-3343 (*1 *2 *3) (-12 (-5 *3 (-492 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-1047)) (-5 *2 (-953 *5)) (-5 *1 (-945 *4 *5)))) (-3699 (*1 *2 *3) (-12 (-5 *3 (-953 *5)) (-4 *5 (-1047)) (-5 *2 (-492 *4 *5)) (-5 *1 (-945 *4 *5)) (-14 *4 (-634 (-1161))))) (-4218 (*1 *2 *3) (-12 (-5 *3 (-492 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-1047)) (-5 *2 (-242 *4 *5)) (-5 *1 (-945 *4 *5)))) (-1752 (*1 *2 *3) (-12 (-5 *3 (-242 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-1047)) (-5 *2 (-492 *4 *5)) (-5 *1 (-945 *4 *5))))) 
-(-10 -7 (-15 -1752 ((-492 |#1| |#2|) (-242 |#1| |#2|))) (-15 -4218 ((-242 |#1| |#2|) (-492 |#1| |#2|))) (-15 -3699 ((-492 |#1| |#2|) (-953 |#2|))) (-15 -3343 ((-953 |#2|) (-492 |#1| |#2|))) (-15 -3260 ((-953 |#2|) (-242 |#1| |#2|))) (-15 -3493 ((-242 |#1| |#2|) (-953 |#2|)))) 
-((-1668 (((-634 |#2|) |#2| |#2|) 10)) (-1530 (((-763) (-634 |#1|)) 37 (|has| |#1| (-840)))) (-2634 (((-634 |#2|) |#2|) 11)) (-2527 (((-763) (-634 |#1|) (-568) (-568)) 36 (|has| |#1| (-840)))) (-2359 ((|#1| |#2|) 32 (|has| |#1| (-840))))) 
-(((-946 |#1| |#2|) (-10 -7 (-15 -1668 ((-634 |#2|) |#2| |#2|)) (-15 -2634 ((-634 |#2|) |#2|)) (IF (|has| |#1| (-840)) (PROGN (-15 -2359 (|#1| |#2|)) (-15 -1530 ((-763) (-634 |#1|))) (-15 -2527 ((-763) (-634 |#1|) (-568) (-568)))) |noBranch|)) (-365) (-1219 |#1|)) (T -946)) 
-((-2527 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-568)) (-4 *5 (-840)) (-4 *5 (-365)) (-5 *2 (-763)) (-5 *1 (-946 *5 *6)) (-4 *6 (-1219 *5)))) (-1530 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-840)) (-4 *4 (-365)) (-5 *2 (-763)) (-5 *1 (-946 *4 *5)) (-4 *5 (-1219 *4)))) (-2359 (*1 *2 *3) (-12 (-4 *2 (-365)) (-4 *2 (-840)) (-5 *1 (-946 *2 *3)) (-4 *3 (-1219 *2)))) (-2634 (*1 *2 *3) (-12 (-4 *4 (-365)) (-5 *2 (-634 *3)) (-5 *1 (-946 *4 *3)) (-4 *3 (-1219 *4)))) (-1668 (*1 *2 *3 *3) (-12 (-4 *4 (-365)) (-5 *2 (-634 *3)) (-5 *1 (-946 *4 *3)) (-4 *3 (-1219 *4))))) 
-(-10 -7 (-15 -1668 ((-634 |#2|) |#2| |#2|)) (-15 -2634 ((-634 |#2|) |#2|)) (IF (|has| |#1| (-840)) (PROGN (-15 -2359 (|#1| |#2|)) (-15 -1530 ((-763) (-634 |#1|))) (-15 -2527 ((-763) (-634 |#1|) (-568) (-568)))) |noBranch|)) 
-((-2795 (((-953 |#2|) (-1 |#2| |#1|) (-953 |#1|)) 18))) 
-(((-947 |#1| |#2|) (-10 -7 (-15 -2795 ((-953 |#2|) (-1 |#2| |#1|) (-953 |#1|)))) (-1047) (-1047)) (T -947)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-953 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-5 *2 (-953 *6)) (-5 *1 (-947 *5 *6))))) 
-(-10 -7 (-15 -2795 ((-953 |#2|) (-1 |#2| |#1|) (-953 |#1|)))) 
-((-3839 (((-1216 |#1| (-953 |#2|)) (-953 |#2|) (-1240 |#1|)) 18))) 
-(((-948 |#1| |#2|) (-10 -7 (-15 -3839 ((-1216 |#1| (-953 |#2|)) (-953 |#2|) (-1240 |#1|)))) (-1161) (-1047)) (T -948)) 
-((-3839 (*1 *2 *3 *4) (-12 (-5 *4 (-1240 *5)) (-14 *5 (-1161)) (-4 *6 (-1047)) (-5 *2 (-1216 *5 (-953 *6))) (-5 *1 (-948 *5 *6)) (-5 *3 (-953 *6))))) 
-(-10 -7 (-15 -3839 ((-1216 |#1| (-953 |#2|)) (-953 |#2|) (-1240 |#1|)))) 
-((-2773 (((-763) $) 69) (((-763) $ (-634 |#4|)) 72)) (-4305 (($ $) 169)) (-1678 (((-420 $) $) 161)) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 112)) (-3666 (((-3 |#2| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 (-568) "failed") $) NIL) (((-3 |#4| "failed") $) 58)) (-2854 ((|#2| $) NIL) (((-409 (-568)) $) NIL) (((-568) $) NIL) ((|#4| $) 57)) (-4265 (($ $ $ |#4|) 74)) (-3164 (((-679 (-568)) (-679 $)) NIL) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) 102) (((-679 |#2|) (-679 $)) 95)) (-3250 (($ $) 177) (($ $ |#4|) 180)) (-2108 (((-634 $) $) 61)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 195) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 189)) (-2976 (((-634 $) $) 27)) (-2047 (($ |#2| |#3|) NIL) (($ $ |#4| (-763)) NIL) (($ $ (-634 |#4|) (-634 (-763))) 55)) (-3379 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $ |#4|) 158)) (-3324 (((-3 (-634 $) "failed") $) 41)) (-1794 (((-3 (-634 $) "failed") $) 30)) (-3751 (((-3 (-2 (|:| |var| |#4|) (|:| -3438 (-763))) "failed") $) 45)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 105)) (-2905 (((-420 (-1157 $)) (-1157 $)) 118)) (-3545 (((-420 (-1157 $)) (-1157 $)) 116)) (-3848 (((-420 $) $) 136)) (-1339 (($ $ (-634 (-288 $))) 20) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ |#4| |#2|) NIL) (($ $ (-634 |#4|) (-634 |#2|)) NIL) (($ $ |#4| $) NIL) (($ $ (-634 |#4|) (-634 $)) NIL)) (-2217 (($ $ |#4|) 76)) (-4278 (((-887 (-381)) $) 209) (((-887 (-568)) $) 202) (((-541) $) 217)) (-3367 ((|#2| $) NIL) (($ $ |#4|) 171)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) 150)) (-2604 ((|#2| $ |#3|) NIL) (($ $ |#4| (-763)) 50) (($ $ (-634 |#4|) (-634 (-763))) 53)) (-4371 (((-3 $ "failed") $) 152)) (-1732 (((-121) $ $) 183))) 
-(((-949 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -2155 ((-1157 |#1|) (-1157 |#1|) (-1157 |#1|))) (-15 -1678 ((-420 |#1|) |#1|)) (-15 -4305 (|#1| |#1|)) (-15 -4371 ((-3 |#1| "failed") |#1|)) (-15 -1732 ((-121) |#1| |#1|)) (-15 -4278 ((-541) |#1|)) (-15 -4278 ((-887 (-568)) |#1|)) (-15 -4278 ((-887 (-381)) |#1|)) (-15 -4410 ((-884 (-568) |#1|) |#1| (-887 (-568)) (-884 (-568) |#1|))) (-15 -4410 ((-884 (-381) |#1|) |#1| (-887 (-381)) (-884 (-381) |#1|))) (-15 -3848 ((-420 |#1|) |#1|)) (-15 -3545 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -2905 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -1858 ((-3 (-634 (-1157 |#1|)) "failed") (-634 (-1157 |#1|)) (-1157 |#1|))) (-15 -2979 ((-3 (-1244 |#1|) "failed") (-679 |#1|))) (-15 -3250 (|#1| |#1| |#4|)) (-15 -3367 (|#1| |#1| |#4|)) (-15 -2217 (|#1| |#1| |#4|)) (-15 -4265 (|#1| |#1| |#1| |#4|)) (-15 -2108 ((-634 |#1|) |#1|)) (-15 -2773 ((-763) |#1| (-634 |#4|))) (-15 -2773 ((-763) |#1|)) (-15 -3751 ((-3 (-2 (|:| |var| |#4|) (|:| -3438 (-763))) "failed") |#1|)) (-15 -3324 ((-3 (-634 |#1|) "failed") |#1|)) (-15 -1794 ((-3 (-634 |#1|) "failed") |#1|)) (-15 -2047 (|#1| |#1| (-634 |#4|) (-634 (-763)))) (-15 -2047 (|#1| |#1| |#4| (-763))) (-15 -3379 ((-2 (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1| |#4|)) (-15 -2976 ((-634 |#1|) |#1|)) (-15 -2604 (|#1| |#1| (-634 |#4|) (-634 (-763)))) (-15 -2604 (|#1| |#1| |#4| (-763))) (-15 -3164 ((-679 |#2|) (-679 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 |#1|) (-1244 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -3164 ((-679 (-568)) (-679 |#1|))) (-15 -2854 (|#4| |#1|)) (-15 -3666 ((-3 |#4| "failed") |#1|)) (-15 -1339 (|#1| |#1| (-634 |#4|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#4| |#1|)) (-15 -1339 (|#1| |#1| (-634 |#4|) (-634 |#2|))) (-15 -1339 (|#1| |#1| |#4| |#2|)) (-15 -1339 (|#1| |#1| (-634 |#1|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#1| |#1|)) (-15 -1339 (|#1| |#1| (-288 |#1|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -2047 (|#1| |#2| |#3|)) (-15 -2604 (|#2| |#1| |#3|)) (-15 -2854 ((-568) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -2854 (|#2| |#1|)) (-15 -3367 (|#2| |#1|)) (-15 -3250 (|#1| |#1|))) (-950 |#2| |#3| |#4|) (-1047) (-788) (-842)) (T -949)) 
-NIL 
-(-10 -8 (-15 -2155 ((-1157 |#1|) (-1157 |#1|) (-1157 |#1|))) (-15 -1678 ((-420 |#1|) |#1|)) (-15 -4305 (|#1| |#1|)) (-15 -4371 ((-3 |#1| "failed") |#1|)) (-15 -1732 ((-121) |#1| |#1|)) (-15 -4278 ((-541) |#1|)) (-15 -4278 ((-887 (-568)) |#1|)) (-15 -4278 ((-887 (-381)) |#1|)) (-15 -4410 ((-884 (-568) |#1|) |#1| (-887 (-568)) (-884 (-568) |#1|))) (-15 -4410 ((-884 (-381) |#1|) |#1| (-887 (-381)) (-884 (-381) |#1|))) (-15 -3848 ((-420 |#1|) |#1|)) (-15 -3545 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -2905 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -1858 ((-3 (-634 (-1157 |#1|)) "failed") (-634 (-1157 |#1|)) (-1157 |#1|))) (-15 -2979 ((-3 (-1244 |#1|) "failed") (-679 |#1|))) (-15 -3250 (|#1| |#1| |#4|)) (-15 -3367 (|#1| |#1| |#4|)) (-15 -2217 (|#1| |#1| |#4|)) (-15 -4265 (|#1| |#1| |#1| |#4|)) (-15 -2108 ((-634 |#1|) |#1|)) (-15 -2773 ((-763) |#1| (-634 |#4|))) (-15 -2773 ((-763) |#1|)) (-15 -3751 ((-3 (-2 (|:| |var| |#4|) (|:| -3438 (-763))) "failed") |#1|)) (-15 -3324 ((-3 (-634 |#1|) "failed") |#1|)) (-15 -1794 ((-3 (-634 |#1|) "failed") |#1|)) (-15 -2047 (|#1| |#1| (-634 |#4|) (-634 (-763)))) (-15 -2047 (|#1| |#1| |#4| (-763))) (-15 -3379 ((-2 (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1| |#4|)) (-15 -2976 ((-634 |#1|) |#1|)) (-15 -2604 (|#1| |#1| (-634 |#4|) (-634 (-763)))) (-15 -2604 (|#1| |#1| |#4| (-763))) (-15 -3164 ((-679 |#2|) (-679 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 |#1|) (-1244 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -3164 ((-679 (-568)) (-679 |#1|))) (-15 -2854 (|#4| |#1|)) (-15 -3666 ((-3 |#4| "failed") |#1|)) (-15 -1339 (|#1| |#1| (-634 |#4|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#4| |#1|)) (-15 -1339 (|#1| |#1| (-634 |#4|) (-634 |#2|))) (-15 -1339 (|#1| |#1| |#4| |#2|)) (-15 -1339 (|#1| |#1| (-634 |#1|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#1| |#1|)) (-15 -1339 (|#1| |#1| (-288 |#1|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -2047 (|#1| |#2| |#3|)) (-15 -2604 (|#2| |#1| |#3|)) (-15 -2854 ((-568) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -2854 (|#2| |#1|)) (-15 -3367 (|#2| |#1|)) (-15 -3250 (|#1| |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-2055 (((-634 |#3|) $) 108)) (-3839 (((-1157 $) $ |#3|) 123) (((-1157 |#1|) $) 122)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 85 (|has| |#1| (-558)))) (-2227 (($ $) 86 (|has| |#1| (-558)))) (-1573 (((-121) $) 88 (|has| |#1| (-558)))) (-2773 (((-763) $) 110) (((-763) $ (-634 |#3|)) 109)) (-3134 (((-3 $ "failed") $ $) 18)) (-1750 (((-420 (-1157 $)) (-1157 $)) 98 (|has| |#1| (-904)))) (-4305 (($ $) 96 (|has| |#1| (-453)))) (-1678 (((-420 $) $) 95 (|has| |#1| (-453)))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 101 (|has| |#1| (-904)))) (-2671 (($) 16 T CONST)) (-3666 (((-3 |#1| "failed") $) 162) (((-3 (-409 (-568)) "failed") $) 160 (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) 158 (|has| |#1| (-1037 (-568)))) (((-3 |#3| "failed") $) 134)) (-2854 ((|#1| $) 163) (((-409 (-568)) $) 159 (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) 157 (|has| |#1| (-1037 (-568)))) ((|#3| $) 133)) (-4265 (($ $ $ |#3|) 106 (|has| |#1| (-172)))) (-2114 (($ $) 152)) (-3164 (((-679 (-568)) (-679 $)) 132 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 131 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 130) (((-679 |#1|) (-679 $)) 129)) (-2925 (((-3 $ "failed") $) 33)) (-3250 (($ $) 174 (|has| |#1| (-453))) (($ $ |#3|) 103 (|has| |#1| (-453)))) (-2108 (((-634 $) $) 107)) (-3927 (((-121) $) 94 (|has| |#1| (-904)))) (-3088 (($ $ |#1| |#2| $) 170)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 82 (-12 (|has| |#3| (-881 (-381))) (|has| |#1| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 81 (-12 (|has| |#3| (-881 (-568))) (|has| |#1| (-881 (-568)))))) (-2735 (((-121) $) 30)) (-4178 (((-763) $) 167)) (-2051 (($ (-1157 |#1|) |#3|) 115) (($ (-1157 $) |#3|) 114)) (-2976 (((-634 $) $) 124)) (-3921 (((-121) $) 150)) (-2047 (($ |#1| |#2|) 151) (($ $ |#3| (-763)) 117) (($ $ (-634 |#3|) (-634 (-763))) 116)) (-3379 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $ |#3|) 118)) (-2144 ((|#2| $) 168) (((-763) $ |#3|) 120) (((-634 (-763)) $ (-634 |#3|)) 119)) (-2521 (($ $ $) 77 (|has| |#1| (-842)))) (-3268 (($ $ $) 76 (|has| |#1| (-842)))) (-3842 (($ (-1 |#2| |#2|) $) 169)) (-2795 (($ (-1 |#1| |#1|) $) 149)) (-2244 (((-3 |#3| "failed") $) 121)) (-2097 (($ $) 147)) (-2102 ((|#1| $) 146)) (-2495 (($ (-634 $)) 92 (|has| |#1| (-453))) (($ $ $) 91 (|has| |#1| (-453)))) (-4487 (((-1143) $) 9)) (-3324 (((-3 (-634 $) "failed") $) 112)) (-1794 (((-3 (-634 $) "failed") $) 113)) (-3751 (((-3 (-2 (|:| |var| |#3|) (|:| -3438 (-763))) "failed") $) 111)) (-4022 (((-1108) $) 10)) (-2086 (((-121) $) 164)) (-2091 ((|#1| $) 165)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 93 (|has| |#1| (-453)))) (-2721 (($ (-634 $)) 90 (|has| |#1| (-453))) (($ $ $) 89 (|has| |#1| (-453)))) (-2905 (((-420 (-1157 $)) (-1157 $)) 100 (|has| |#1| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) 99 (|has| |#1| (-904)))) (-3848 (((-420 $) $) 97 (|has| |#1| (-904)))) (-2595 (((-3 $ "failed") $ |#1|) 172 (|has| |#1| (-558))) (((-3 $ "failed") $ $) 84 (|has| |#1| (-558)))) (-1339 (($ $ (-634 (-288 $))) 143) (($ $ (-288 $)) 142) (($ $ $ $) 141) (($ $ (-634 $) (-634 $)) 140) (($ $ |#3| |#1|) 139) (($ $ (-634 |#3|) (-634 |#1|)) 138) (($ $ |#3| $) 137) (($ $ (-634 |#3|) (-634 $)) 136)) (-2217 (($ $ |#3|) 105 (|has| |#1| (-172)))) (-4189 (($ $ |#3|) 41) (($ $ (-634 |#3|)) 40) (($ $ |#3| (-763)) 39) (($ $ (-634 |#3|) (-634 (-763))) 38)) (-3206 ((|#2| $) 148) (((-763) $ |#3|) 128) (((-634 (-763)) $ (-634 |#3|)) 127)) (-4278 (((-887 (-381)) $) 80 (-12 (|has| |#3| (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381)))))) (((-887 (-568)) $) 79 (-12 (|has| |#3| (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568)))))) (((-541) $) 78 (-12 (|has| |#3| (-609 (-541))) (|has| |#1| (-609 (-541)))))) (-3367 ((|#1| $) 173 (|has| |#1| (-453))) (($ $ |#3|) 104 (|has| |#1| (-453)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) 102 (-2139 (|has| $ (-148)) (|has| |#1| (-904))))) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 161) (($ |#3|) 135) (($ $) 83 (|has| |#1| (-558))) (($ (-409 (-568))) 70 (-2198 (|has| |#1| (-1037 (-409 (-568)))) (|has| |#1| (-43 (-409 (-568))))))) (-1302 (((-634 |#1|) $) 166)) (-2604 ((|#1| $ |#2|) 153) (($ $ |#3| (-763)) 126) (($ $ (-634 |#3|) (-634 (-763))) 125)) (-4371 (((-3 $ "failed") $) 71 (-2198 (-2139 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-4078 (((-763)) 28)) (-4171 (($ $ $ (-763)) 171 (|has| |#1| (-172)))) (-1826 (((-121) $ $) 87 (|has| |#1| (-558)))) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $ |#3|) 37) (($ $ (-634 |#3|)) 36) (($ $ |#3| (-763)) 35) (($ $ (-634 |#3|) (-634 (-763))) 34)) (-1751 (((-121) $ $) 74 (|has| |#1| (-842)))) (-1738 (((-121) $ $) 73 (|has| |#1| (-842)))) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 75 (|has| |#1| (-842)))) (-1732 (((-121) $ $) 72 (|has| |#1| (-842)))) (-1779 (($ $ |#1|) 154 (|has| |#1| (-365)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 156 (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) 155 (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) 145) (($ $ |#1|) 144))) 
+((-2366 (((-492 |#1| |#2|) (-953 |#2|)) 17)) (-3880 (((-242 |#1| |#2|) (-953 |#2|)) 29)) (-4466 (((-953 |#2|) (-492 |#1| |#2|)) 22)) (-4181 (((-242 |#1| |#2|) (-492 |#1| |#2|)) 53)) (-2024 (((-953 |#2|) (-242 |#1| |#2|)) 26)) (-3870 (((-492 |#1| |#2|) (-242 |#1| |#2|)) 44))) 
+(((-945 |#1| |#2|) (-10 -7 (-15 -3870 ((-492 |#1| |#2|) (-242 |#1| |#2|))) (-15 -4181 ((-242 |#1| |#2|) (-492 |#1| |#2|))) (-15 -2366 ((-492 |#1| |#2|) (-953 |#2|))) (-15 -4466 ((-953 |#2|) (-492 |#1| |#2|))) (-15 -2024 ((-953 |#2|) (-242 |#1| |#2|))) (-15 -3880 ((-242 |#1| |#2|) (-953 |#2|)))) (-634 (-1161)) (-1047)) (T -945)) 
+((-3880 (*1 *2 *3) (-12 (-5 *3 (-953 *5)) (-4 *5 (-1047)) (-5 *2 (-242 *4 *5)) (-5 *1 (-945 *4 *5)) (-14 *4 (-634 (-1161))))) (-2024 (*1 *2 *3) (-12 (-5 *3 (-242 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-1047)) (-5 *2 (-953 *5)) (-5 *1 (-945 *4 *5)))) (-4466 (*1 *2 *3) (-12 (-5 *3 (-492 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-1047)) (-5 *2 (-953 *5)) (-5 *1 (-945 *4 *5)))) (-2366 (*1 *2 *3) (-12 (-5 *3 (-953 *5)) (-4 *5 (-1047)) (-5 *2 (-492 *4 *5)) (-5 *1 (-945 *4 *5)) (-14 *4 (-634 (-1161))))) (-4181 (*1 *2 *3) (-12 (-5 *3 (-492 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-1047)) (-5 *2 (-242 *4 *5)) (-5 *1 (-945 *4 *5)))) (-3870 (*1 *2 *3) (-12 (-5 *3 (-242 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-1047)) (-5 *2 (-492 *4 *5)) (-5 *1 (-945 *4 *5))))) 
+(-10 -7 (-15 -3870 ((-492 |#1| |#2|) (-242 |#1| |#2|))) (-15 -4181 ((-242 |#1| |#2|) (-492 |#1| |#2|))) (-15 -2366 ((-492 |#1| |#2|) (-953 |#2|))) (-15 -4466 ((-953 |#2|) (-492 |#1| |#2|))) (-15 -2024 ((-953 |#2|) (-242 |#1| |#2|))) (-15 -3880 ((-242 |#1| |#2|) (-953 |#2|)))) 
+((-3438 (((-634 |#2|) |#2| |#2|) 10)) (-4177 (((-763) (-634 |#1|)) 37 (|has| |#1| (-840)))) (-4279 (((-634 |#2|) |#2|) 11)) (-1768 (((-763) (-634 |#1|) (-568) (-568)) 36 (|has| |#1| (-840)))) (-4026 ((|#1| |#2|) 32 (|has| |#1| (-840))))) 
+(((-946 |#1| |#2|) (-10 -7 (-15 -3438 ((-634 |#2|) |#2| |#2|)) (-15 -4279 ((-634 |#2|) |#2|)) (IF (|has| |#1| (-840)) (PROGN (-15 -4026 (|#1| |#2|)) (-15 -4177 ((-763) (-634 |#1|))) (-15 -1768 ((-763) (-634 |#1|) (-568) (-568)))) |noBranch|)) (-365) (-1219 |#1|)) (T -946)) 
+((-1768 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-568)) (-4 *5 (-840)) (-4 *5 (-365)) (-5 *2 (-763)) (-5 *1 (-946 *5 *6)) (-4 *6 (-1219 *5)))) (-4177 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-840)) (-4 *4 (-365)) (-5 *2 (-763)) (-5 *1 (-946 *4 *5)) (-4 *5 (-1219 *4)))) (-4026 (*1 *2 *3) (-12 (-4 *2 (-365)) (-4 *2 (-840)) (-5 *1 (-946 *2 *3)) (-4 *3 (-1219 *2)))) (-4279 (*1 *2 *3) (-12 (-4 *4 (-365)) (-5 *2 (-634 *3)) (-5 *1 (-946 *4 *3)) (-4 *3 (-1219 *4)))) (-3438 (*1 *2 *3 *3) (-12 (-4 *4 (-365)) (-5 *2 (-634 *3)) (-5 *1 (-946 *4 *3)) (-4 *3 (-1219 *4))))) 
+(-10 -7 (-15 -3438 ((-634 |#2|) |#2| |#2|)) (-15 -4279 ((-634 |#2|) |#2|)) (IF (|has| |#1| (-840)) (PROGN (-15 -4026 (|#1| |#2|)) (-15 -4177 ((-763) (-634 |#1|))) (-15 -1768 ((-763) (-634 |#1|) (-568) (-568)))) |noBranch|)) 
+((-2797 (((-953 |#2|) (-1 |#2| |#1|) (-953 |#1|)) 18))) 
+(((-947 |#1| |#2|) (-10 -7 (-15 -2797 ((-953 |#2|) (-1 |#2| |#1|) (-953 |#1|)))) (-1047) (-1047)) (T -947)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-953 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-5 *2 (-953 *6)) (-5 *1 (-947 *5 *6))))) 
+(-10 -7 (-15 -2797 ((-953 |#2|) (-1 |#2| |#1|) (-953 |#1|)))) 
+((-3840 (((-1216 |#1| (-953 |#2|)) (-953 |#2|) (-1240 |#1|)) 18))) 
+(((-948 |#1| |#2|) (-10 -7 (-15 -3840 ((-1216 |#1| (-953 |#2|)) (-953 |#2|) (-1240 |#1|)))) (-1161) (-1047)) (T -948)) 
+((-3840 (*1 *2 *3 *4) (-12 (-5 *4 (-1240 *5)) (-14 *5 (-1161)) (-4 *6 (-1047)) (-5 *2 (-1216 *5 (-953 *6))) (-5 *1 (-948 *5 *6)) (-5 *3 (-953 *6))))) 
+(-10 -7 (-15 -3840 ((-1216 |#1| (-953 |#2|)) (-953 |#2|) (-1240 |#1|)))) 
+((-3528 (((-763) $) 69) (((-763) $ (-634 |#4|)) 72)) (-3045 (($ $) 169)) (-3498 (((-420 $) $) 161)) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 112)) (-3668 (((-3 |#2| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 (-568) "failed") $) NIL) (((-3 |#4| "failed") $) 58)) (-2857 ((|#2| $) NIL) (((-409 (-568)) $) NIL) (((-568) $) NIL) ((|#4| $) 57)) (-2910 (($ $ $ |#4|) 74)) (-1668 (((-679 (-568)) (-679 $)) NIL) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) 102) (((-679 |#2|) (-679 $)) 95)) (-1998 (($ $) 177) (($ $ |#4|) 180)) (-2110 (((-634 $) $) 61)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 195) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 189)) (-3062 (((-634 $) $) 27)) (-2049 (($ |#2| |#3|) NIL) (($ $ |#4| (-763)) NIL) (($ $ (-634 |#4|) (-634 (-763))) 55)) (-1438 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $ |#4|) 158)) (-4362 (((-3 (-634 $) "failed") $) 41)) (-2112 (((-3 (-634 $) "failed") $) 30)) (-2617 (((-3 (-2 (|:| |var| |#4|) (|:| -3483 (-763))) "failed") $) 45)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 105)) (-2841 (((-420 (-1157 $)) (-1157 $)) 118)) (-2795 (((-420 (-1157 $)) (-1157 $)) 116)) (-3850 (((-420 $) $) 136)) (-1339 (($ $ (-634 (-288 $))) 20) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ |#4| |#2|) NIL) (($ $ (-634 |#4|) (-634 |#2|)) NIL) (($ $ |#4| $) NIL) (($ $ (-634 |#4|) (-634 $)) NIL)) (-3440 (($ $ |#4|) 76)) (-4280 (((-887 (-381)) $) 209) (((-887 (-568)) $) 202) (((-541) $) 217)) (-1364 ((|#2| $) NIL) (($ $ |#4|) 171)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) 150)) (-2079 ((|#2| $ |#3|) NIL) (($ $ |#4| (-763)) 50) (($ $ (-634 |#4|) (-634 (-763))) 53)) (-3385 (((-3 $ "failed") $) 152)) (-1734 (((-121) $ $) 183))) 
+(((-949 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3603 ((-1157 |#1|) (-1157 |#1|) (-1157 |#1|))) (-15 -3498 ((-420 |#1|) |#1|)) (-15 -3045 (|#1| |#1|)) (-15 -3385 ((-3 |#1| "failed") |#1|)) (-15 -1734 ((-121) |#1| |#1|)) (-15 -4280 ((-541) |#1|)) (-15 -4280 ((-887 (-568)) |#1|)) (-15 -4280 ((-887 (-381)) |#1|)) (-15 -1519 ((-884 (-568) |#1|) |#1| (-887 (-568)) (-884 (-568) |#1|))) (-15 -1519 ((-884 (-381) |#1|) |#1| (-887 (-381)) (-884 (-381) |#1|))) (-15 -3850 ((-420 |#1|) |#1|)) (-15 -2795 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -2841 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -2434 ((-3 (-634 (-1157 |#1|)) "failed") (-634 (-1157 |#1|)) (-1157 |#1|))) (-15 -3070 ((-3 (-1244 |#1|) "failed") (-679 |#1|))) (-15 -1998 (|#1| |#1| |#4|)) (-15 -1364 (|#1| |#1| |#4|)) (-15 -3440 (|#1| |#1| |#4|)) (-15 -2910 (|#1| |#1| |#1| |#4|)) (-15 -2110 ((-634 |#1|) |#1|)) (-15 -3528 ((-763) |#1| (-634 |#4|))) (-15 -3528 ((-763) |#1|)) (-15 -2617 ((-3 (-2 (|:| |var| |#4|) (|:| -3483 (-763))) "failed") |#1|)) (-15 -4362 ((-3 (-634 |#1|) "failed") |#1|)) (-15 -2112 ((-3 (-634 |#1|) "failed") |#1|)) (-15 -2049 (|#1| |#1| (-634 |#4|) (-634 (-763)))) (-15 -2049 (|#1| |#1| |#4| (-763))) (-15 -1438 ((-2 (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1| |#4|)) (-15 -3062 ((-634 |#1|) |#1|)) (-15 -2079 (|#1| |#1| (-634 |#4|) (-634 (-763)))) (-15 -2079 (|#1| |#1| |#4| (-763))) (-15 -1668 ((-679 |#2|) (-679 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 |#1|) (-1244 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -1668 ((-679 (-568)) (-679 |#1|))) (-15 -2857 (|#4| |#1|)) (-15 -3668 ((-3 |#4| "failed") |#1|)) (-15 -1339 (|#1| |#1| (-634 |#4|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#4| |#1|)) (-15 -1339 (|#1| |#1| (-634 |#4|) (-634 |#2|))) (-15 -1339 (|#1| |#1| |#4| |#2|)) (-15 -1339 (|#1| |#1| (-634 |#1|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#1| |#1|)) (-15 -1339 (|#1| |#1| (-288 |#1|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -2049 (|#1| |#2| |#3|)) (-15 -2079 (|#2| |#1| |#3|)) (-15 -2857 ((-568) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -2857 (|#2| |#1|)) (-15 -1364 (|#2| |#1|)) (-15 -1998 (|#1| |#1|))) (-950 |#2| |#3| |#4|) (-1047) (-788) (-842)) (T -949)) 
+NIL 
+(-10 -8 (-15 -3603 ((-1157 |#1|) (-1157 |#1|) (-1157 |#1|))) (-15 -3498 ((-420 |#1|) |#1|)) (-15 -3045 (|#1| |#1|)) (-15 -3385 ((-3 |#1| "failed") |#1|)) (-15 -1734 ((-121) |#1| |#1|)) (-15 -4280 ((-541) |#1|)) (-15 -4280 ((-887 (-568)) |#1|)) (-15 -4280 ((-887 (-381)) |#1|)) (-15 -1519 ((-884 (-568) |#1|) |#1| (-887 (-568)) (-884 (-568) |#1|))) (-15 -1519 ((-884 (-381) |#1|) |#1| (-887 (-381)) (-884 (-381) |#1|))) (-15 -3850 ((-420 |#1|) |#1|)) (-15 -2795 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -2841 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -2434 ((-3 (-634 (-1157 |#1|)) "failed") (-634 (-1157 |#1|)) (-1157 |#1|))) (-15 -3070 ((-3 (-1244 |#1|) "failed") (-679 |#1|))) (-15 -1998 (|#1| |#1| |#4|)) (-15 -1364 (|#1| |#1| |#4|)) (-15 -3440 (|#1| |#1| |#4|)) (-15 -2910 (|#1| |#1| |#1| |#4|)) (-15 -2110 ((-634 |#1|) |#1|)) (-15 -3528 ((-763) |#1| (-634 |#4|))) (-15 -3528 ((-763) |#1|)) (-15 -2617 ((-3 (-2 (|:| |var| |#4|) (|:| -3483 (-763))) "failed") |#1|)) (-15 -4362 ((-3 (-634 |#1|) "failed") |#1|)) (-15 -2112 ((-3 (-634 |#1|) "failed") |#1|)) (-15 -2049 (|#1| |#1| (-634 |#4|) (-634 (-763)))) (-15 -2049 (|#1| |#1| |#4| (-763))) (-15 -1438 ((-2 (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1| |#4|)) (-15 -3062 ((-634 |#1|) |#1|)) (-15 -2079 (|#1| |#1| (-634 |#4|) (-634 (-763)))) (-15 -2079 (|#1| |#1| |#4| (-763))) (-15 -1668 ((-679 |#2|) (-679 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 |#1|) (-1244 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -1668 ((-679 (-568)) (-679 |#1|))) (-15 -2857 (|#4| |#1|)) (-15 -3668 ((-3 |#4| "failed") |#1|)) (-15 -1339 (|#1| |#1| (-634 |#4|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#4| |#1|)) (-15 -1339 (|#1| |#1| (-634 |#4|) (-634 |#2|))) (-15 -1339 (|#1| |#1| |#4| |#2|)) (-15 -1339 (|#1| |#1| (-634 |#1|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#1| |#1|)) (-15 -1339 (|#1| |#1| (-288 |#1|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -2049 (|#1| |#2| |#3|)) (-15 -2079 (|#2| |#1| |#3|)) (-15 -2857 ((-568) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -2857 (|#2| |#1|)) (-15 -1364 (|#2| |#1|)) (-15 -1998 (|#1| |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2057 (((-634 |#3|) $) 108)) (-3840 (((-1157 $) $ |#3|) 123) (((-1157 |#1|) $) 122)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 85 (|has| |#1| (-558)))) (-3661 (($ $) 86 (|has| |#1| (-558)))) (-4426 (((-121) $) 88 (|has| |#1| (-558)))) (-3528 (((-763) $) 110) (((-763) $ (-634 |#3|)) 109)) (-2689 (((-3 $ "failed") $ $) 18)) (-3863 (((-420 (-1157 $)) (-1157 $)) 98 (|has| |#1| (-904)))) (-3045 (($ $) 96 (|has| |#1| (-453)))) (-3498 (((-420 $) $) 95 (|has| |#1| (-453)))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 101 (|has| |#1| (-904)))) (-4490 (($) 16 T CONST)) (-3668 (((-3 |#1| "failed") $) 162) (((-3 (-409 (-568)) "failed") $) 160 (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) 158 (|has| |#1| (-1037 (-568)))) (((-3 |#3| "failed") $) 134)) (-2857 ((|#1| $) 163) (((-409 (-568)) $) 159 (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) 157 (|has| |#1| (-1037 (-568)))) ((|#3| $) 133)) (-2910 (($ $ $ |#3|) 106 (|has| |#1| (-172)))) (-2116 (($ $) 152)) (-1668 (((-679 (-568)) (-679 $)) 132 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 131 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 130) (((-679 |#1|) (-679 $)) 129)) (-2902 (((-3 $ "failed") $) 33)) (-1998 (($ $) 174 (|has| |#1| (-453))) (($ $ |#3|) 103 (|has| |#1| (-453)))) (-2110 (((-634 $) $) 107)) (-2197 (((-121) $) 94 (|has| |#1| (-904)))) (-2453 (($ $ |#1| |#2| $) 170)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 82 (-12 (|has| |#3| (-881 (-381))) (|has| |#1| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 81 (-12 (|has| |#3| (-881 (-568))) (|has| |#1| (-881 (-568)))))) (-1598 (((-121) $) 30)) (-3971 (((-763) $) 167)) (-2053 (($ (-1157 |#1|) |#3|) 115) (($ (-1157 $) |#3|) 114)) (-3062 (((-634 $) $) 124)) (-2171 (((-121) $) 150)) (-2049 (($ |#1| |#2|) 151) (($ $ |#3| (-763)) 117) (($ $ (-634 |#3|) (-634 (-763))) 116)) (-1438 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $ |#3|) 118)) (-3524 ((|#2| $) 168) (((-763) $ |#3|) 120) (((-634 (-763)) $ (-634 |#3|)) 119)) (-1732 (($ $ $) 77 (|has| |#1| (-842)))) (-2047 (($ $ $) 76 (|has| |#1| (-842)))) (-1865 (($ (-1 |#2| |#2|) $) 169)) (-2797 (($ (-1 |#1| |#1|) $) 149)) (-2817 (((-3 |#3| "failed") $) 121)) (-2099 (($ $) 147)) (-2104 ((|#1| $) 146)) (-2498 (($ (-634 $)) 92 (|has| |#1| (-453))) (($ $ $) 91 (|has| |#1| (-453)))) (-1893 (((-1143) $) 9)) (-4362 (((-3 (-634 $) "failed") $) 112)) (-2112 (((-3 (-634 $) "failed") $) 113)) (-2617 (((-3 (-2 (|:| |var| |#3|) (|:| -3483 (-763))) "failed") $) 111)) (-4025 (((-1108) $) 10)) (-2088 (((-121) $) 164)) (-2093 ((|#1| $) 165)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 93 (|has| |#1| (-453)))) (-2723 (($ (-634 $)) 90 (|has| |#1| (-453))) (($ $ $) 89 (|has| |#1| (-453)))) (-2841 (((-420 (-1157 $)) (-1157 $)) 100 (|has| |#1| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) 99 (|has| |#1| (-904)))) (-3850 (((-420 $) $) 97 (|has| |#1| (-904)))) (-2597 (((-3 $ "failed") $ |#1|) 172 (|has| |#1| (-558))) (((-3 $ "failed") $ $) 84 (|has| |#1| (-558)))) (-1339 (($ $ (-634 (-288 $))) 143) (($ $ (-288 $)) 142) (($ $ $ $) 141) (($ $ (-634 $) (-634 $)) 140) (($ $ |#3| |#1|) 139) (($ $ (-634 |#3|) (-634 |#1|)) 138) (($ $ |#3| $) 137) (($ $ (-634 |#3|) (-634 $)) 136)) (-3440 (($ $ |#3|) 105 (|has| |#1| (-172)))) (-4191 (($ $ |#3|) 41) (($ $ (-634 |#3|)) 40) (($ $ |#3| (-763)) 39) (($ $ (-634 |#3|) (-634 (-763))) 38)) (-1836 ((|#2| $) 148) (((-763) $ |#3|) 128) (((-634 (-763)) $ (-634 |#3|)) 127)) (-4280 (((-887 (-381)) $) 80 (-12 (|has| |#3| (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381)))))) (((-887 (-568)) $) 79 (-12 (|has| |#3| (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568)))))) (((-541) $) 78 (-12 (|has| |#3| (-609 (-541))) (|has| |#1| (-609 (-541)))))) (-1364 ((|#1| $) 173 (|has| |#1| (-453))) (($ $ |#3|) 104 (|has| |#1| (-453)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) 102 (-2141 (|has| $ (-148)) (|has| |#1| (-904))))) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 161) (($ |#3|) 135) (($ $) 83 (|has| |#1| (-558))) (($ (-409 (-568))) 70 (-2199 (|has| |#1| (-1037 (-409 (-568)))) (|has| |#1| (-43 (-409 (-568))))))) (-3304 (((-634 |#1|) $) 166)) (-2079 ((|#1| $ |#2|) 153) (($ $ |#3| (-763)) 126) (($ $ (-634 |#3|) (-634 (-763))) 125)) (-3385 (((-3 $ "failed") $) 71 (-2199 (-2141 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-3425 (((-763)) 28)) (-3925 (($ $ $ (-763)) 171 (|has| |#1| (-172)))) (-2273 (((-121) $ $) 87 (|has| |#1| (-558)))) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $ |#3|) 37) (($ $ (-634 |#3|)) 36) (($ $ |#3| (-763)) 35) (($ $ (-634 |#3|) (-634 (-763))) 34)) (-1753 (((-121) $ $) 74 (|has| |#1| (-842)))) (-1740 (((-121) $ $) 73 (|has| |#1| (-842)))) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 75 (|has| |#1| (-842)))) (-1734 (((-121) $ $) 72 (|has| |#1| (-842)))) (-1781 (($ $ |#1|) 154 (|has| |#1| (-365)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 156 (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) 155 (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) 145) (($ $ |#1|) 144))) 
 (((-950 |#1| |#2| |#3|) (-1275) (-1047) (-788) (-842)) (T -950)) 
-((-3250 (*1 *1 *1) (-12 (-4 *1 (-950 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453)))) (-3206 (*1 *2 *1 *3) (-12 (-4 *1 (-950 *4 *5 *3)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-763)))) (-3206 (*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *1 (-950 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 (-763))))) (-2604 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-950 *4 *5 *2)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *2 (-842)))) (-2604 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *6)) (-5 *3 (-634 (-763))) (-4 *1 (-950 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)))) (-2976 (*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-950 *3 *4 *5)))) (-3839 (*1 *2 *1 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-1157 *1)) (-4 *1 (-950 *4 *5 *3)))) (-3839 (*1 *2 *1) (-12 (-4 *1 (-950 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-1157 *3)))) (-2244 (*1 *2 *1) (|partial| -12 (-4 *1 (-950 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) (-2144 (*1 *2 *1 *3) (-12 (-4 *1 (-950 *4 *5 *3)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-763)))) (-2144 (*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *1 (-950 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 (-763))))) (-3379 (*1 *2 *1 *1 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-2 (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-950 *4 *5 *3)))) (-2047 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-950 *4 *5 *2)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *2 (-842)))) (-2047 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *6)) (-5 *3 (-634 (-763))) (-4 *1 (-950 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)))) (-2051 (*1 *1 *2 *3) (-12 (-5 *2 (-1157 *4)) (-4 *4 (-1047)) (-4 *1 (-950 *4 *5 *3)) (-4 *5 (-788)) (-4 *3 (-842)))) (-2051 (*1 *1 *2 *3) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-950 *4 *5 *3)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)))) (-1794 (*1 *2 *1) (|partial| -12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-950 *3 *4 *5)))) (-3324 (*1 *2 *1) (|partial| -12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-950 *3 *4 *5)))) (-3751 (*1 *2 *1) (|partial| -12 (-4 *1 (-950 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| |var| *5) (|:| -3438 (-763)))))) (-2773 (*1 *2 *1) (-12 (-4 *1 (-950 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-763)))) (-2773 (*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *1 (-950 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-763)))) (-2055 (*1 *2 *1) (-12 (-4 *1 (-950 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *5)))) (-2108 (*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-950 *3 *4 *5)))) (-4265 (*1 *1 *1 *1 *2) (-12 (-4 *1 (-950 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *3 (-172)))) (-2217 (*1 *1 *1 *2) (-12 (-4 *1 (-950 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *3 (-172)))) (-3367 (*1 *1 *1 *2) (-12 (-4 *1 (-950 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *3 (-453)))) (-3250 (*1 *1 *1 *2) (-12 (-4 *1 (-950 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *3 (-453)))) (-4305 (*1 *1 *1) (-12 (-4 *1 (-950 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453)))) (-1678 (*1 *2 *1) (-12 (-4 *3 (-453)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-420 *1)) (-4 *1 (-950 *3 *4 *5))))) 
-(-13 (-895 |t#3|) (-324 |t#1| |t#2|) (-303 $) (-523 |t#3| |t#1|) (-523 |t#3| $) (-1037 |t#3|) (-379 |t#1|) (-10 -8 (-15 -3206 ((-763) $ |t#3|)) (-15 -3206 ((-634 (-763)) $ (-634 |t#3|))) (-15 -2604 ($ $ |t#3| (-763))) (-15 -2604 ($ $ (-634 |t#3|) (-634 (-763)))) (-15 -2976 ((-634 $) $)) (-15 -3839 ((-1157 $) $ |t#3|)) (-15 -3839 ((-1157 |t#1|) $)) (-15 -2244 ((-3 |t#3| "failed") $)) (-15 -2144 ((-763) $ |t#3|)) (-15 -2144 ((-634 (-763)) $ (-634 |t#3|))) (-15 -3379 ((-2 (|:| -3961 $) (|:| -1500 $)) $ $ |t#3|)) (-15 -2047 ($ $ |t#3| (-763))) (-15 -2047 ($ $ (-634 |t#3|) (-634 (-763)))) (-15 -2051 ($ (-1157 |t#1|) |t#3|)) (-15 -2051 ($ (-1157 $) |t#3|)) (-15 -1794 ((-3 (-634 $) "failed") $)) (-15 -3324 ((-3 (-634 $) "failed") $)) (-15 -3751 ((-3 (-2 (|:| |var| |t#3|) (|:| -3438 (-763))) "failed") $)) (-15 -2773 ((-763) $)) (-15 -2773 ((-763) $ (-634 |t#3|))) (-15 -2055 ((-634 |t#3|) $)) (-15 -2108 ((-634 $) $)) (IF (|has| |t#1| (-842)) (-6 (-842)) |noBranch|) (IF (|has| |t#1| (-609 (-541))) (IF (|has| |t#3| (-609 (-541))) (-6 (-609 (-541))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-609 (-887 (-568)))) (IF (|has| |t#3| (-609 (-887 (-568)))) (-6 (-609 (-887 (-568)))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-609 (-887 (-381)))) (IF (|has| |t#3| (-609 (-887 (-381)))) (-6 (-609 (-887 (-381)))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-881 (-568))) (IF (|has| |t#3| (-881 (-568))) (-6 (-881 (-568))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-881 (-381))) (IF (|has| |t#3| (-881 (-381))) (-6 (-881 (-381))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-172)) (PROGN (-15 -4265 ($ $ $ |t#3|)) (-15 -2217 ($ $ |t#3|))) |noBranch|) (IF (|has| |t#1| (-453)) (PROGN (-6 (-453)) (-15 -3367 ($ $ |t#3|)) (-15 -3250 ($ $)) (-15 -3250 ($ $ |t#3|)) (-15 -1678 ((-420 $) $)) (-15 -4305 ($ $))) |noBranch|) (IF (|has| |t#1| (-6 -4517)) (-6 -4517) |noBranch|) (IF (|has| |t#1| (-904)) (-6 (-904)) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| |#2|) . T) ((-25) . T) ((-43 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-172))) ((-609 (-541)) -12 (|has| |#1| (-609 (-541))) (|has| |#3| (-609 (-541)))) ((-609 (-887 (-381))) -12 (|has| |#1| (-609 (-887 (-381)))) (|has| |#3| (-609 (-887 (-381))))) ((-609 (-887 (-568))) -12 (|has| |#1| (-609 (-887 (-568)))) (|has| |#3| (-609 (-887 (-568))))) ((-285) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-303 $) . T) ((-324 |#1| |#2|) . T) ((-379 |#1|) . T) ((-413 |#1|) . T) ((-453) -2198 (|has| |#1| (-904)) (|has| |#1| (-453))) ((-523 |#3| |#1|) . T) ((-523 |#3| $) . T) ((-523 $ $) . T) ((-558) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-637 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-637 |#1|) . T) ((-637 $) . T) ((-630 (-568)) |has| |#1| (-630 (-568))) ((-630 |#1|) . T) ((-707 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-716) . T) ((-842) |has| |#1| (-842)) ((-895 |#3|) . T) ((-881 (-381)) -12 (|has| |#1| (-881 (-381))) (|has| |#3| (-881 (-381)))) ((-881 (-568)) -12 (|has| |#1| (-881 (-568))) (|has| |#3| (-881 (-568)))) ((-904) |has| |#1| (-904)) ((-1037 (-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 |#1|) . T) ((-1037 |#3|) . T) ((-1053 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-1053 |#1|) . T) ((-1053 $) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1199) |has| |#1| (-904))) 
-((-2055 (((-634 |#2|) |#5|) 36)) (-3839 (((-1157 |#5|) |#5| |#2| (-1157 |#5|)) 23) (((-409 (-1157 |#5|)) |#5| |#2|) 16)) (-2051 ((|#5| (-409 (-1157 |#5|)) |#2|) 30)) (-2244 (((-3 |#2| "failed") |#5|) 61)) (-3324 (((-3 (-634 |#5|) "failed") |#5|) 55)) (-2672 (((-3 (-2 (|:| |val| |#5|) (|:| -3438 (-568))) "failed") |#5|) 45)) (-1794 (((-3 (-634 |#5|) "failed") |#5|) 57)) (-3751 (((-3 (-2 (|:| |var| |#2|) (|:| -3438 (-568))) "failed") |#5|) 48))) 
-(((-951 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2055 ((-634 |#2|) |#5|)) (-15 -2244 ((-3 |#2| "failed") |#5|)) (-15 -3839 ((-409 (-1157 |#5|)) |#5| |#2|)) (-15 -2051 (|#5| (-409 (-1157 |#5|)) |#2|)) (-15 -3839 ((-1157 |#5|) |#5| |#2| (-1157 |#5|))) (-15 -1794 ((-3 (-634 |#5|) "failed") |#5|)) (-15 -3324 ((-3 (-634 |#5|) "failed") |#5|)) (-15 -3751 ((-3 (-2 (|:| |var| |#2|) (|:| -3438 (-568))) "failed") |#5|)) (-15 -2672 ((-3 (-2 (|:| |val| |#5|) (|:| -3438 (-568))) "failed") |#5|))) (-788) (-842) (-1047) (-950 |#3| |#1| |#2|) (-13 (-365) (-10 -8 (-15 -2745 ($ |#4|)) (-15 -2317 (|#4| $)) (-15 -2324 (|#4| $))))) (T -951)) 
-((-2672 (*1 *2 *3) (|partial| -12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-2 (|:| |val| *3) (|:| -3438 (-568)))) (-5 *1 (-951 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2745 ($ *7)) (-15 -2317 (*7 $)) (-15 -2324 (*7 $))))))) (-3751 (*1 *2 *3) (|partial| -12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-2 (|:| |var| *5) (|:| -3438 (-568)))) (-5 *1 (-951 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2745 ($ *7)) (-15 -2317 (*7 $)) (-15 -2324 (*7 $))))))) (-3324 (*1 *2 *3) (|partial| -12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-634 *3)) (-5 *1 (-951 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2745 ($ *7)) (-15 -2317 (*7 $)) (-15 -2324 (*7 $))))))) (-1794 (*1 *2 *3) (|partial| -12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-634 *3)) (-5 *1 (-951 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2745 ($ *7)) (-15 -2317 (*7 $)) (-15 -2324 (*7 $))))))) (-3839 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-1157 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2745 ($ *7)) (-15 -2317 (*7 $)) (-15 -2324 (*7 $))))) (-4 *7 (-950 *6 *5 *4)) (-4 *5 (-788)) (-4 *4 (-842)) (-4 *6 (-1047)) (-5 *1 (-951 *5 *4 *6 *7 *3)))) (-2051 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-1157 *2))) (-4 *5 (-788)) (-4 *4 (-842)) (-4 *6 (-1047)) (-4 *2 (-13 (-365) (-10 -8 (-15 -2745 ($ *7)) (-15 -2317 (*7 $)) (-15 -2324 (*7 $))))) (-5 *1 (-951 *5 *4 *6 *7 *2)) (-4 *7 (-950 *6 *5 *4)))) (-3839 (*1 *2 *3 *4) (-12 (-4 *5 (-788)) (-4 *4 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *5 *4)) (-5 *2 (-409 (-1157 *3))) (-5 *1 (-951 *5 *4 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2745 ($ *7)) (-15 -2317 (*7 $)) (-15 -2324 (*7 $))))))) (-2244 (*1 *2 *3) (|partial| -12 (-4 *4 (-788)) (-4 *5 (-1047)) (-4 *6 (-950 *5 *4 *2)) (-4 *2 (-842)) (-5 *1 (-951 *4 *2 *5 *6 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2745 ($ *6)) (-15 -2317 (*6 $)) (-15 -2324 (*6 $))))))) (-2055 (*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-634 *5)) (-5 *1 (-951 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2745 ($ *7)) (-15 -2317 (*7 $)) (-15 -2324 (*7 $)))))))) 
-(-10 -7 (-15 -2055 ((-634 |#2|) |#5|)) (-15 -2244 ((-3 |#2| "failed") |#5|)) (-15 -3839 ((-409 (-1157 |#5|)) |#5| |#2|)) (-15 -2051 (|#5| (-409 (-1157 |#5|)) |#2|)) (-15 -3839 ((-1157 |#5|) |#5| |#2| (-1157 |#5|))) (-15 -1794 ((-3 (-634 |#5|) "failed") |#5|)) (-15 -3324 ((-3 (-634 |#5|) "failed") |#5|)) (-15 -3751 ((-3 (-2 (|:| |var| |#2|) (|:| -3438 (-568))) "failed") |#5|)) (-15 -2672 ((-3 (-2 (|:| |val| |#5|) (|:| -3438 (-568))) "failed") |#5|))) 
-((-2795 ((|#5| (-1 |#5| |#2|) (-1 |#5| |#3|) |#4|) 23))) 
-(((-952 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2795 (|#5| (-1 |#5| |#2|) (-1 |#5| |#3|) |#4|))) (-788) (-842) (-1047) (-950 |#3| |#1| |#2|) (-13 (-1090) (-10 -8 (-15 -1767 ($ $ $)) (-15 * ($ $ $)) (-15 ** ($ $ (-763)))))) (T -952)) 
-((-2795 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *7)) (-5 *4 (-1 *2 *8)) (-4 *7 (-842)) (-4 *8 (-1047)) (-4 *6 (-788)) (-4 *2 (-13 (-1090) (-10 -8 (-15 -1767 ($ $ $)) (-15 * ($ $ $)) (-15 ** ($ $ (-763)))))) (-5 *1 (-952 *6 *7 *8 *5 *2)) (-4 *5 (-950 *8 *6 *7))))) 
-(-10 -7 (-15 -2795 (|#5| (-1 |#5| |#2|) (-1 |#5| |#3|) |#4|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2055 (((-634 (-1161)) $) 15)) (-3839 (((-1157 $) $ (-1161)) 21) (((-1157 |#1|) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-2773 (((-763) $) NIL) (((-763) $ (-634 (-1161))) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-4305 (($ $) NIL (|has| |#1| (-453)))) (-1678 (((-420 $) $) NIL (|has| |#1| (-453)))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) 8) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-1161) "failed") $) NIL)) (-2854 ((|#1| $) NIL) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-1161) $) NIL)) (-4265 (($ $ $ (-1161)) NIL (|has| |#1| (-172)))) (-2114 (($ $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3250 (($ $) NIL (|has| |#1| (-453))) (($ $ (-1161)) NIL (|has| |#1| (-453)))) (-2108 (((-634 $) $) NIL)) (-3927 (((-121) $) NIL (|has| |#1| (-904)))) (-3088 (($ $ |#1| (-534 (-1161)) $) NIL)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-1161) (-881 (-381))) (|has| |#1| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-1161) (-881 (-568))) (|has| |#1| (-881 (-568)))))) (-2735 (((-121) $) NIL)) (-4178 (((-763) $) NIL)) (-2051 (($ (-1157 |#1|) (-1161)) NIL) (($ (-1157 $) (-1161)) NIL)) (-2976 (((-634 $) $) NIL)) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| (-534 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL)) (-3379 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $ (-1161)) NIL)) (-2144 (((-534 (-1161)) $) NIL) (((-763) $ (-1161)) NIL) (((-634 (-763)) $ (-634 (-1161))) NIL)) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-3842 (($ (-1 (-534 (-1161)) (-534 (-1161))) $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-2244 (((-3 (-1161) "failed") $) 19)) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-2495 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-4487 (((-1143) $) NIL)) (-3324 (((-3 (-634 $) "failed") $) NIL)) (-1794 (((-3 (-634 $) "failed") $) NIL)) (-3751 (((-3 (-2 (|:| |var| (-1161)) (|:| -3438 (-763))) "failed") $) NIL)) (-3837 (($ $ (-1161)) 29 (|has| |#1| (-43 (-409 (-568)))))) (-4022 (((-1108) $) NIL)) (-2086 (((-121) $) NIL)) (-2091 ((|#1| $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-453)))) (-2721 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3848 (((-420 $) $) NIL (|has| |#1| (-904)))) (-2595 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-1161) |#1|) NIL) (($ $ (-634 (-1161)) (-634 |#1|)) NIL) (($ $ (-1161) $) NIL) (($ $ (-634 (-1161)) (-634 $)) NIL)) (-2217 (($ $ (-1161)) NIL (|has| |#1| (-172)))) (-4189 (($ $ (-1161)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL)) (-3206 (((-534 (-1161)) $) NIL) (((-763) $ (-1161)) NIL) (((-634 (-763)) $ (-634 (-1161))) NIL)) (-4278 (((-887 (-381)) $) NIL (-12 (|has| (-1161) (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-1161) (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-1161) (-609 (-541))) (|has| |#1| (-609 (-541)))))) (-3367 ((|#1| $) NIL (|has| |#1| (-453))) (($ $ (-1161)) NIL (|has| |#1| (-453)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#1| (-904))))) (-2745 (((-850) $) 25) (($ (-568)) NIL) (($ |#1|) NIL) (($ (-1161)) 27) (($ (-409 (-568))) NIL (-2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#1| (-558)))) (-1302 (((-634 |#1|) $) NIL)) (-2604 ((|#1| $ (-534 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-4078 (((-763)) NIL)) (-4171 (($ $ $ (-763)) NIL (|has| |#1| (-172)))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $ (-1161)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL)) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
-(((-953 |#1|) (-13 (-950 |#1| (-534 (-1161)) (-1161)) (-10 -8 (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -3837 ($ $ (-1161))) |noBranch|))) (-1047)) (T -953)) 
-((-3837 (*1 *1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-953 *3)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047))))) 
-(-13 (-950 |#1| (-534 (-1161)) (-1161)) (-10 -8 (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -3837 ($ $ (-1161))) |noBranch|))) 
-((-2613 (((-2 (|:| -3438 (-763)) (|:| -2348 |#5|) (|:| |radicand| |#5|)) |#3| (-763)) 37)) (-3710 (((-2 (|:| -3438 (-763)) (|:| -2348 |#5|) (|:| |radicand| |#5|)) (-409 (-568)) (-763)) 33)) (-2771 (((-2 (|:| -3438 (-763)) (|:| -2348 |#4|) (|:| |radicand| (-634 |#4|))) |#4| (-763)) 52)) (-3563 (((-2 (|:| -3438 (-763)) (|:| -2348 |#5|) (|:| |radicand| |#5|)) |#5| (-763)) 62 (|has| |#3| (-453))))) 
-(((-954 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2613 ((-2 (|:| -3438 (-763)) (|:| -2348 |#5|) (|:| |radicand| |#5|)) |#3| (-763))) (-15 -3710 ((-2 (|:| -3438 (-763)) (|:| -2348 |#5|) (|:| |radicand| |#5|)) (-409 (-568)) (-763))) (IF (|has| |#3| (-453)) (-15 -3563 ((-2 (|:| -3438 (-763)) (|:| -2348 |#5|) (|:| |radicand| |#5|)) |#5| (-763))) |noBranch|) (-15 -2771 ((-2 (|:| -3438 (-763)) (|:| -2348 |#4|) (|:| |radicand| (-634 |#4|))) |#4| (-763)))) (-788) (-842) (-558) (-950 |#3| |#1| |#2|) (-13 (-365) (-10 -8 (-15 -2317 (|#4| $)) (-15 -2324 (|#4| $)) (-15 -2745 ($ |#4|))))) (T -954)) 
-((-2771 (*1 *2 *3 *4) (-12 (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-558)) (-4 *3 (-950 *7 *5 *6)) (-5 *2 (-2 (|:| -3438 (-763)) (|:| -2348 *3) (|:| |radicand| (-634 *3)))) (-5 *1 (-954 *5 *6 *7 *3 *8)) (-5 *4 (-763)) (-4 *8 (-13 (-365) (-10 -8 (-15 -2317 (*3 $)) (-15 -2324 (*3 $)) (-15 -2745 ($ *3))))))) (-3563 (*1 *2 *3 *4) (-12 (-4 *7 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-558)) (-4 *8 (-950 *7 *5 *6)) (-5 *2 (-2 (|:| -3438 (-763)) (|:| -2348 *3) (|:| |radicand| *3))) (-5 *1 (-954 *5 *6 *7 *8 *3)) (-5 *4 (-763)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2317 (*8 $)) (-15 -2324 (*8 $)) (-15 -2745 ($ *8))))))) (-3710 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-568))) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-558)) (-4 *8 (-950 *7 *5 *6)) (-5 *2 (-2 (|:| -3438 (-763)) (|:| -2348 *9) (|:| |radicand| *9))) (-5 *1 (-954 *5 *6 *7 *8 *9)) (-5 *4 (-763)) (-4 *9 (-13 (-365) (-10 -8 (-15 -2317 (*8 $)) (-15 -2324 (*8 $)) (-15 -2745 ($ *8))))))) (-2613 (*1 *2 *3 *4) (-12 (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-558)) (-4 *7 (-950 *3 *5 *6)) (-5 *2 (-2 (|:| -3438 (-763)) (|:| -2348 *8) (|:| |radicand| *8))) (-5 *1 (-954 *5 *6 *3 *7 *8)) (-5 *4 (-763)) (-4 *8 (-13 (-365) (-10 -8 (-15 -2317 (*7 $)) (-15 -2324 (*7 $)) (-15 -2745 ($ *7)))))))) 
-(-10 -7 (-15 -2613 ((-2 (|:| -3438 (-763)) (|:| -2348 |#5|) (|:| |radicand| |#5|)) |#3| (-763))) (-15 -3710 ((-2 (|:| -3438 (-763)) (|:| -2348 |#5|) (|:| |radicand| |#5|)) (-409 (-568)) (-763))) (IF (|has| |#3| (-453)) (-15 -3563 ((-2 (|:| -3438 (-763)) (|:| -2348 |#5|) (|:| |radicand| |#5|)) |#5| (-763))) |noBranch|) (-15 -2771 ((-2 (|:| -3438 (-763)) (|:| -2348 |#4|) (|:| |radicand| (-634 |#4|))) |#4| (-763)))) 
-((-4017 (((-1084 (-215)) $) 7)) (-1351 (((-1084 (-215)) $) 8)) (-2550 (((-634 (-634 (-944 (-215)))) $) 9)) (-2745 (((-850) $) 6))) 
+((-1998 (*1 *1 *1) (-12 (-4 *1 (-950 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453)))) (-1836 (*1 *2 *1 *3) (-12 (-4 *1 (-950 *4 *5 *3)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-763)))) (-1836 (*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *1 (-950 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 (-763))))) (-2079 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-950 *4 *5 *2)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *2 (-842)))) (-2079 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *6)) (-5 *3 (-634 (-763))) (-4 *1 (-950 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)))) (-3062 (*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-950 *3 *4 *5)))) (-3840 (*1 *2 *1 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-1157 *1)) (-4 *1 (-950 *4 *5 *3)))) (-3840 (*1 *2 *1) (-12 (-4 *1 (-950 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-1157 *3)))) (-2817 (*1 *2 *1) (|partial| -12 (-4 *1 (-950 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) (-3524 (*1 *2 *1 *3) (-12 (-4 *1 (-950 *4 *5 *3)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-763)))) (-3524 (*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *1 (-950 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 (-763))))) (-1438 (*1 *2 *1 *1 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-2 (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-950 *4 *5 *3)))) (-2049 (*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-950 *4 *5 *2)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *2 (-842)))) (-2049 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *6)) (-5 *3 (-634 (-763))) (-4 *1 (-950 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)))) (-2053 (*1 *1 *2 *3) (-12 (-5 *2 (-1157 *4)) (-4 *4 (-1047)) (-4 *1 (-950 *4 *5 *3)) (-4 *5 (-788)) (-4 *3 (-842)))) (-2053 (*1 *1 *2 *3) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-950 *4 *5 *3)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)))) (-2112 (*1 *2 *1) (|partial| -12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-950 *3 *4 *5)))) (-4362 (*1 *2 *1) (|partial| -12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-950 *3 *4 *5)))) (-2617 (*1 *2 *1) (|partial| -12 (-4 *1 (-950 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| |var| *5) (|:| -3483 (-763)))))) (-3528 (*1 *2 *1) (-12 (-4 *1 (-950 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-763)))) (-3528 (*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *1 (-950 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-763)))) (-2057 (*1 *2 *1) (-12 (-4 *1 (-950 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *5)))) (-2110 (*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-950 *3 *4 *5)))) (-2910 (*1 *1 *1 *1 *2) (-12 (-4 *1 (-950 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *3 (-172)))) (-3440 (*1 *1 *1 *2) (-12 (-4 *1 (-950 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *3 (-172)))) (-1364 (*1 *1 *1 *2) (-12 (-4 *1 (-950 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *3 (-453)))) (-1998 (*1 *1 *1 *2) (-12 (-4 *1 (-950 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *3 (-453)))) (-3045 (*1 *1 *1) (-12 (-4 *1 (-950 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453)))) (-3498 (*1 *2 *1) (-12 (-4 *3 (-453)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-420 *1)) (-4 *1 (-950 *3 *4 *5))))) 
+(-13 (-895 |t#3|) (-324 |t#1| |t#2|) (-303 $) (-523 |t#3| |t#1|) (-523 |t#3| $) (-1037 |t#3|) (-379 |t#1|) (-10 -8 (-15 -1836 ((-763) $ |t#3|)) (-15 -1836 ((-634 (-763)) $ (-634 |t#3|))) (-15 -2079 ($ $ |t#3| (-763))) (-15 -2079 ($ $ (-634 |t#3|) (-634 (-763)))) (-15 -3062 ((-634 $) $)) (-15 -3840 ((-1157 $) $ |t#3|)) (-15 -3840 ((-1157 |t#1|) $)) (-15 -2817 ((-3 |t#3| "failed") $)) (-15 -3524 ((-763) $ |t#3|)) (-15 -3524 ((-634 (-763)) $ (-634 |t#3|))) (-15 -1438 ((-2 (|:| -4409 $) (|:| -2607 $)) $ $ |t#3|)) (-15 -2049 ($ $ |t#3| (-763))) (-15 -2049 ($ $ (-634 |t#3|) (-634 (-763)))) (-15 -2053 ($ (-1157 |t#1|) |t#3|)) (-15 -2053 ($ (-1157 $) |t#3|)) (-15 -2112 ((-3 (-634 $) "failed") $)) (-15 -4362 ((-3 (-634 $) "failed") $)) (-15 -2617 ((-3 (-2 (|:| |var| |t#3|) (|:| -3483 (-763))) "failed") $)) (-15 -3528 ((-763) $)) (-15 -3528 ((-763) $ (-634 |t#3|))) (-15 -2057 ((-634 |t#3|) $)) (-15 -2110 ((-634 $) $)) (IF (|has| |t#1| (-842)) (-6 (-842)) |noBranch|) (IF (|has| |t#1| (-609 (-541))) (IF (|has| |t#3| (-609 (-541))) (-6 (-609 (-541))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-609 (-887 (-568)))) (IF (|has| |t#3| (-609 (-887 (-568)))) (-6 (-609 (-887 (-568)))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-609 (-887 (-381)))) (IF (|has| |t#3| (-609 (-887 (-381)))) (-6 (-609 (-887 (-381)))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-881 (-568))) (IF (|has| |t#3| (-881 (-568))) (-6 (-881 (-568))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-881 (-381))) (IF (|has| |t#3| (-881 (-381))) (-6 (-881 (-381))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-172)) (PROGN (-15 -2910 ($ $ $ |t#3|)) (-15 -3440 ($ $ |t#3|))) |noBranch|) (IF (|has| |t#1| (-453)) (PROGN (-6 (-453)) (-15 -1364 ($ $ |t#3|)) (-15 -1998 ($ $)) (-15 -1998 ($ $ |t#3|)) (-15 -3498 ((-420 $) $)) (-15 -3045 ($ $))) |noBranch|) (IF (|has| |t#1| (-6 -4519)) (-6 -4519) |noBranch|) (IF (|has| |t#1| (-904)) (-6 (-904)) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| |#2|) . T) ((-25) . T) ((-43 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-172))) ((-609 (-541)) -12 (|has| |#1| (-609 (-541))) (|has| |#3| (-609 (-541)))) ((-609 (-887 (-381))) -12 (|has| |#1| (-609 (-887 (-381)))) (|has| |#3| (-609 (-887 (-381))))) ((-609 (-887 (-568))) -12 (|has| |#1| (-609 (-887 (-568)))) (|has| |#3| (-609 (-887 (-568))))) ((-285) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-303 $) . T) ((-324 |#1| |#2|) . T) ((-379 |#1|) . T) ((-413 |#1|) . T) ((-453) -2199 (|has| |#1| (-904)) (|has| |#1| (-453))) ((-523 |#3| |#1|) . T) ((-523 |#3| $) . T) ((-523 $ $) . T) ((-558) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-637 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-637 |#1|) . T) ((-637 $) . T) ((-630 (-568)) |has| |#1| (-630 (-568))) ((-630 |#1|) . T) ((-707 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-716) . T) ((-842) |has| |#1| (-842)) ((-895 |#3|) . T) ((-881 (-381)) -12 (|has| |#1| (-881 (-381))) (|has| |#3| (-881 (-381)))) ((-881 (-568)) -12 (|has| |#1| (-881 (-568))) (|has| |#3| (-881 (-568)))) ((-904) |has| |#1| (-904)) ((-1037 (-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 |#1|) . T) ((-1037 |#3|) . T) ((-1053 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-1053 |#1|) . T) ((-1053 $) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1199) |has| |#1| (-904))) 
+((-2057 (((-634 |#2|) |#5|) 36)) (-3840 (((-1157 |#5|) |#5| |#2| (-1157 |#5|)) 23) (((-409 (-1157 |#5|)) |#5| |#2|) 16)) (-2053 ((|#5| (-409 (-1157 |#5|)) |#2|) 30)) (-2817 (((-3 |#2| "failed") |#5|) 61)) (-4362 (((-3 (-634 |#5|) "failed") |#5|) 55)) (-4495 (((-3 (-2 (|:| |val| |#5|) (|:| -3483 (-568))) "failed") |#5|) 45)) (-2112 (((-3 (-634 |#5|) "failed") |#5|) 57)) (-2617 (((-3 (-2 (|:| |var| |#2|) (|:| -3483 (-568))) "failed") |#5|) 48))) 
+(((-951 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2057 ((-634 |#2|) |#5|)) (-15 -2817 ((-3 |#2| "failed") |#5|)) (-15 -3840 ((-409 (-1157 |#5|)) |#5| |#2|)) (-15 -2053 (|#5| (-409 (-1157 |#5|)) |#2|)) (-15 -3840 ((-1157 |#5|) |#5| |#2| (-1157 |#5|))) (-15 -2112 ((-3 (-634 |#5|) "failed") |#5|)) (-15 -4362 ((-3 (-634 |#5|) "failed") |#5|)) (-15 -2617 ((-3 (-2 (|:| |var| |#2|) (|:| -3483 (-568))) "failed") |#5|)) (-15 -4495 ((-3 (-2 (|:| |val| |#5|) (|:| -3483 (-568))) "failed") |#5|))) (-788) (-842) (-1047) (-950 |#3| |#1| |#2|) (-13 (-365) (-10 -8 (-15 -2747 ($ |#4|)) (-15 -2319 (|#4| $)) (-15 -2326 (|#4| $))))) (T -951)) 
+((-4495 (*1 *2 *3) (|partial| -12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-2 (|:| |val| *3) (|:| -3483 (-568)))) (-5 *1 (-951 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2747 ($ *7)) (-15 -2319 (*7 $)) (-15 -2326 (*7 $))))))) (-2617 (*1 *2 *3) (|partial| -12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-2 (|:| |var| *5) (|:| -3483 (-568)))) (-5 *1 (-951 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2747 ($ *7)) (-15 -2319 (*7 $)) (-15 -2326 (*7 $))))))) (-4362 (*1 *2 *3) (|partial| -12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-634 *3)) (-5 *1 (-951 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2747 ($ *7)) (-15 -2319 (*7 $)) (-15 -2326 (*7 $))))))) (-2112 (*1 *2 *3) (|partial| -12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-634 *3)) (-5 *1 (-951 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2747 ($ *7)) (-15 -2319 (*7 $)) (-15 -2326 (*7 $))))))) (-3840 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-1157 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2747 ($ *7)) (-15 -2319 (*7 $)) (-15 -2326 (*7 $))))) (-4 *7 (-950 *6 *5 *4)) (-4 *5 (-788)) (-4 *4 (-842)) (-4 *6 (-1047)) (-5 *1 (-951 *5 *4 *6 *7 *3)))) (-2053 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-1157 *2))) (-4 *5 (-788)) (-4 *4 (-842)) (-4 *6 (-1047)) (-4 *2 (-13 (-365) (-10 -8 (-15 -2747 ($ *7)) (-15 -2319 (*7 $)) (-15 -2326 (*7 $))))) (-5 *1 (-951 *5 *4 *6 *7 *2)) (-4 *7 (-950 *6 *5 *4)))) (-3840 (*1 *2 *3 *4) (-12 (-4 *5 (-788)) (-4 *4 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *5 *4)) (-5 *2 (-409 (-1157 *3))) (-5 *1 (-951 *5 *4 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2747 ($ *7)) (-15 -2319 (*7 $)) (-15 -2326 (*7 $))))))) (-2817 (*1 *2 *3) (|partial| -12 (-4 *4 (-788)) (-4 *5 (-1047)) (-4 *6 (-950 *5 *4 *2)) (-4 *2 (-842)) (-5 *1 (-951 *4 *2 *5 *6 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2747 ($ *6)) (-15 -2319 (*6 $)) (-15 -2326 (*6 $))))))) (-2057 (*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-634 *5)) (-5 *1 (-951 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2747 ($ *7)) (-15 -2319 (*7 $)) (-15 -2326 (*7 $)))))))) 
+(-10 -7 (-15 -2057 ((-634 |#2|) |#5|)) (-15 -2817 ((-3 |#2| "failed") |#5|)) (-15 -3840 ((-409 (-1157 |#5|)) |#5| |#2|)) (-15 -2053 (|#5| (-409 (-1157 |#5|)) |#2|)) (-15 -3840 ((-1157 |#5|) |#5| |#2| (-1157 |#5|))) (-15 -2112 ((-3 (-634 |#5|) "failed") |#5|)) (-15 -4362 ((-3 (-634 |#5|) "failed") |#5|)) (-15 -2617 ((-3 (-2 (|:| |var| |#2|) (|:| -3483 (-568))) "failed") |#5|)) (-15 -4495 ((-3 (-2 (|:| |val| |#5|) (|:| -3483 (-568))) "failed") |#5|))) 
+((-2797 ((|#5| (-1 |#5| |#2|) (-1 |#5| |#3|) |#4|) 23))) 
+(((-952 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2797 (|#5| (-1 |#5| |#2|) (-1 |#5| |#3|) |#4|))) (-788) (-842) (-1047) (-950 |#3| |#1| |#2|) (-13 (-1090) (-10 -8 (-15 -1769 ($ $ $)) (-15 * ($ $ $)) (-15 ** ($ $ (-763)))))) (T -952)) 
+((-2797 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *7)) (-5 *4 (-1 *2 *8)) (-4 *7 (-842)) (-4 *8 (-1047)) (-4 *6 (-788)) (-4 *2 (-13 (-1090) (-10 -8 (-15 -1769 ($ $ $)) (-15 * ($ $ $)) (-15 ** ($ $ (-763)))))) (-5 *1 (-952 *6 *7 *8 *5 *2)) (-4 *5 (-950 *8 *6 *7))))) 
+(-10 -7 (-15 -2797 (|#5| (-1 |#5| |#2|) (-1 |#5| |#3|) |#4|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2057 (((-634 (-1161)) $) 15)) (-3840 (((-1157 $) $ (-1161)) 21) (((-1157 |#1|) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-3528 (((-763) $) NIL) (((-763) $ (-634 (-1161))) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3045 (($ $) NIL (|has| |#1| (-453)))) (-3498 (((-420 $) $) NIL (|has| |#1| (-453)))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) 8) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-1161) "failed") $) NIL)) (-2857 ((|#1| $) NIL) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-1161) $) NIL)) (-2910 (($ $ $ (-1161)) NIL (|has| |#1| (-172)))) (-2116 (($ $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1998 (($ $) NIL (|has| |#1| (-453))) (($ $ (-1161)) NIL (|has| |#1| (-453)))) (-2110 (((-634 $) $) NIL)) (-2197 (((-121) $) NIL (|has| |#1| (-904)))) (-2453 (($ $ |#1| (-534 (-1161)) $) NIL)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-1161) (-881 (-381))) (|has| |#1| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-1161) (-881 (-568))) (|has| |#1| (-881 (-568)))))) (-1598 (((-121) $) NIL)) (-3971 (((-763) $) NIL)) (-2053 (($ (-1157 |#1|) (-1161)) NIL) (($ (-1157 $) (-1161)) NIL)) (-3062 (((-634 $) $) NIL)) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| (-534 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL)) (-1438 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $ (-1161)) NIL)) (-3524 (((-534 (-1161)) $) NIL) (((-763) $ (-1161)) NIL) (((-634 (-763)) $ (-634 (-1161))) NIL)) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-1865 (($ (-1 (-534 (-1161)) (-534 (-1161))) $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-2817 (((-3 (-1161) "failed") $) 19)) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-2498 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-1893 (((-1143) $) NIL)) (-4362 (((-3 (-634 $) "failed") $) NIL)) (-2112 (((-3 (-634 $) "failed") $) NIL)) (-2617 (((-3 (-2 (|:| |var| (-1161)) (|:| -3483 (-763))) "failed") $) NIL)) (-1845 (($ $ (-1161)) 29 (|has| |#1| (-43 (-409 (-568)))))) (-4025 (((-1108) $) NIL)) (-2088 (((-121) $) NIL)) (-2093 ((|#1| $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-453)))) (-2723 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3850 (((-420 $) $) NIL (|has| |#1| (-904)))) (-2597 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-1161) |#1|) NIL) (($ $ (-634 (-1161)) (-634 |#1|)) NIL) (($ $ (-1161) $) NIL) (($ $ (-634 (-1161)) (-634 $)) NIL)) (-3440 (($ $ (-1161)) NIL (|has| |#1| (-172)))) (-4191 (($ $ (-1161)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL)) (-1836 (((-534 (-1161)) $) NIL) (((-763) $ (-1161)) NIL) (((-634 (-763)) $ (-634 (-1161))) NIL)) (-4280 (((-887 (-381)) $) NIL (-12 (|has| (-1161) (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-1161) (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-1161) (-609 (-541))) (|has| |#1| (-609 (-541)))))) (-1364 ((|#1| $) NIL (|has| |#1| (-453))) (($ $ (-1161)) NIL (|has| |#1| (-453)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#1| (-904))))) (-2747 (((-850) $) 25) (($ (-568)) NIL) (($ |#1|) NIL) (($ (-1161)) 27) (($ (-409 (-568))) NIL (-2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#1| (-558)))) (-3304 (((-634 |#1|) $) NIL)) (-2079 ((|#1| $ (-534 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-3425 (((-763)) NIL)) (-3925 (($ $ $ (-763)) NIL (|has| |#1| (-172)))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $ (-1161)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL)) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
+(((-953 |#1|) (-13 (-950 |#1| (-534 (-1161)) (-1161)) (-10 -8 (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -1845 ($ $ (-1161))) |noBranch|))) (-1047)) (T -953)) 
+((-1845 (*1 *1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-953 *3)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047))))) 
+(-13 (-950 |#1| (-534 (-1161)) (-1161)) (-10 -8 (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -1845 ($ $ (-1161))) |noBranch|))) 
+((-2124 (((-2 (|:| -3483 (-763)) (|:| -2350 |#5|) (|:| |radicand| |#5|)) |#3| (-763)) 37)) (-2419 (((-2 (|:| -3483 (-763)) (|:| -2350 |#5|) (|:| |radicand| |#5|)) (-409 (-568)) (-763)) 33)) (-3514 (((-2 (|:| -3483 (-763)) (|:| -2350 |#4|) (|:| |radicand| (-634 |#4|))) |#4| (-763)) 52)) (-2862 (((-2 (|:| -3483 (-763)) (|:| -2350 |#5|) (|:| |radicand| |#5|)) |#5| (-763)) 62 (|has| |#3| (-453))))) 
+(((-954 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2124 ((-2 (|:| -3483 (-763)) (|:| -2350 |#5|) (|:| |radicand| |#5|)) |#3| (-763))) (-15 -2419 ((-2 (|:| -3483 (-763)) (|:| -2350 |#5|) (|:| |radicand| |#5|)) (-409 (-568)) (-763))) (IF (|has| |#3| (-453)) (-15 -2862 ((-2 (|:| -3483 (-763)) (|:| -2350 |#5|) (|:| |radicand| |#5|)) |#5| (-763))) |noBranch|) (-15 -3514 ((-2 (|:| -3483 (-763)) (|:| -2350 |#4|) (|:| |radicand| (-634 |#4|))) |#4| (-763)))) (-788) (-842) (-558) (-950 |#3| |#1| |#2|) (-13 (-365) (-10 -8 (-15 -2319 (|#4| $)) (-15 -2326 (|#4| $)) (-15 -2747 ($ |#4|))))) (T -954)) 
+((-3514 (*1 *2 *3 *4) (-12 (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-558)) (-4 *3 (-950 *7 *5 *6)) (-5 *2 (-2 (|:| -3483 (-763)) (|:| -2350 *3) (|:| |radicand| (-634 *3)))) (-5 *1 (-954 *5 *6 *7 *3 *8)) (-5 *4 (-763)) (-4 *8 (-13 (-365) (-10 -8 (-15 -2319 (*3 $)) (-15 -2326 (*3 $)) (-15 -2747 ($ *3))))))) (-2862 (*1 *2 *3 *4) (-12 (-4 *7 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-558)) (-4 *8 (-950 *7 *5 *6)) (-5 *2 (-2 (|:| -3483 (-763)) (|:| -2350 *3) (|:| |radicand| *3))) (-5 *1 (-954 *5 *6 *7 *8 *3)) (-5 *4 (-763)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2319 (*8 $)) (-15 -2326 (*8 $)) (-15 -2747 ($ *8))))))) (-2419 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-568))) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-558)) (-4 *8 (-950 *7 *5 *6)) (-5 *2 (-2 (|:| -3483 (-763)) (|:| -2350 *9) (|:| |radicand| *9))) (-5 *1 (-954 *5 *6 *7 *8 *9)) (-5 *4 (-763)) (-4 *9 (-13 (-365) (-10 -8 (-15 -2319 (*8 $)) (-15 -2326 (*8 $)) (-15 -2747 ($ *8))))))) (-2124 (*1 *2 *3 *4) (-12 (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-558)) (-4 *7 (-950 *3 *5 *6)) (-5 *2 (-2 (|:| -3483 (-763)) (|:| -2350 *8) (|:| |radicand| *8))) (-5 *1 (-954 *5 *6 *3 *7 *8)) (-5 *4 (-763)) (-4 *8 (-13 (-365) (-10 -8 (-15 -2319 (*7 $)) (-15 -2326 (*7 $)) (-15 -2747 ($ *7)))))))) 
+(-10 -7 (-15 -2124 ((-2 (|:| -3483 (-763)) (|:| -2350 |#5|) (|:| |radicand| |#5|)) |#3| (-763))) (-15 -2419 ((-2 (|:| -3483 (-763)) (|:| -2350 |#5|) (|:| |radicand| |#5|)) (-409 (-568)) (-763))) (IF (|has| |#3| (-453)) (-15 -2862 ((-2 (|:| -3483 (-763)) (|:| -2350 |#5|) (|:| |radicand| |#5|)) |#5| (-763))) |noBranch|) (-15 -3514 ((-2 (|:| -3483 (-763)) (|:| -2350 |#4|) (|:| |radicand| (-634 |#4|))) |#4| (-763)))) 
+((-1421 (((-1084 (-215)) $) 7)) (-3679 (((-1084 (-215)) $) 8)) (-1878 (((-634 (-634 (-944 (-215)))) $) 9)) (-2747 (((-850) $) 6))) 
 (((-955) (-1275)) (T -955)) 
-((-2550 (*1 *2 *1) (-12 (-4 *1 (-955)) (-5 *2 (-634 (-634 (-944 (-215))))))) (-1351 (*1 *2 *1) (-12 (-4 *1 (-955)) (-5 *2 (-1084 (-215))))) (-4017 (*1 *2 *1) (-12 (-4 *1 (-955)) (-5 *2 (-1084 (-215)))))) 
-(-13 (-608 (-850)) (-10 -8 (-15 -2550 ((-634 (-634 (-944 (-215)))) $)) (-15 -1351 ((-1084 (-215)) $)) (-15 -4017 ((-1084 (-215)) $)))) 
+((-1878 (*1 *2 *1) (-12 (-4 *1 (-955)) (-5 *2 (-634 (-634 (-944 (-215))))))) (-3679 (*1 *2 *1) (-12 (-4 *1 (-955)) (-5 *2 (-1084 (-215))))) (-1421 (*1 *2 *1) (-12 (-4 *1 (-955)) (-5 *2 (-1084 (-215)))))) 
+(-13 (-608 (-850)) (-10 -8 (-15 -1878 ((-634 (-634 (-944 (-215)))) $)) (-15 -3679 ((-1084 (-215)) $)) (-15 -1421 ((-1084 (-215)) $)))) 
 (((-608 (-850)) . T)) 
-((-3032 (((-3 (-679 |#1|) "failed") |#2| (-917)) 14))) 
-(((-956 |#1| |#2|) (-10 -7 (-15 -3032 ((-3 (-679 |#1|) "failed") |#2| (-917)))) (-558) (-646 |#1|)) (T -956)) 
-((-3032 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-917)) (-4 *5 (-558)) (-5 *2 (-679 *5)) (-5 *1 (-956 *5 *3)) (-4 *3 (-646 *5))))) 
-(-10 -7 (-15 -3032 ((-3 (-679 |#1|) "failed") |#2| (-917)))) 
-((-2512 (((-958 |#2|) (-1 |#2| |#1| |#2|) (-958 |#1|) |#2|) 16)) (-3092 ((|#2| (-1 |#2| |#1| |#2|) (-958 |#1|) |#2|) 18)) (-2795 (((-958 |#2|) (-1 |#2| |#1|) (-958 |#1|)) 13))) 
-(((-957 |#1| |#2|) (-10 -7 (-15 -2512 ((-958 |#2|) (-1 |#2| |#1| |#2|) (-958 |#1|) |#2|)) (-15 -3092 (|#2| (-1 |#2| |#1| |#2|) (-958 |#1|) |#2|)) (-15 -2795 ((-958 |#2|) (-1 |#2| |#1|) (-958 |#1|)))) (-1195) (-1195)) (T -957)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-958 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-958 *6)) (-5 *1 (-957 *5 *6)))) (-3092 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-958 *5)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-957 *5 *2)))) (-2512 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-958 *6)) (-4 *6 (-1195)) (-4 *5 (-1195)) (-5 *2 (-958 *5)) (-5 *1 (-957 *6 *5))))) 
-(-10 -7 (-15 -2512 ((-958 |#2|) (-1 |#2| |#1| |#2|) (-958 |#1|) |#2|)) (-15 -3092 (|#2| (-1 |#2| |#1| |#2|) (-958 |#1|) |#2|)) (-15 -2795 ((-958 |#2|) (-1 |#2| |#1|) (-958 |#1|)))) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-2016 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-842)))) (-3908 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4520))) (($ $) NIL (-12 (|has| $ (-6 -4520)) (|has| |#1| (-842))))) (-3644 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-842)))) (-2510 (((-121) $ (-763)) NIL)) (-2436 ((|#1| $ (-568) |#1|) 17 (|has| $ (-6 -4520))) ((|#1| $ (-1210 (-568)) |#1|) NIL (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-2671 (($) NIL T CONST)) (-1578 (($ $) NIL (|has| $ (-6 -4520)))) (-3943 (($ $) NIL)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-4328 (($ |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4519)))) (-3989 ((|#1| $ (-568) |#1|) 16 (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-568)) 14)) (-2764 (((-568) (-1 (-121) |#1|) $) NIL) (((-568) |#1| $) NIL (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) NIL (|has| |#1| (-1090)))) (-4360 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-1849 (($ (-763) |#1|) 13)) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) 10 (|has| (-568) (-842)))) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-1347 (($ (-1 (-121) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-842)))) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2223 (((-568) $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-3674 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4122 (($ |#1| $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3876 ((|#1| $) NIL (|has| (-568) (-842)))) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3724 (($ $ |#1|) 12 (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) 11)) (-2779 ((|#1| $ (-568) |#1|) NIL) ((|#1| $ (-568)) 15) (($ $ (-1210 (-568))) NIL)) (-2826 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2256 (($ $ $ (-568)) NIL (|has| $ (-6 -4520)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) NIL)) (-2768 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-634 $)) NIL)) (-2745 (((-850) $) NIL (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1697 (((-763) $) 8 (|has| $ (-6 -4519))))) 
+((-2190 (((-3 (-679 |#1|) "failed") |#2| (-917)) 14))) 
+(((-956 |#1| |#2|) (-10 -7 (-15 -2190 ((-3 (-679 |#1|) "failed") |#2| (-917)))) (-558) (-646 |#1|)) (T -956)) 
+((-2190 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-917)) (-4 *5 (-558)) (-5 *2 (-679 *5)) (-5 *1 (-956 *5 *3)) (-4 *3 (-646 *5))))) 
+(-10 -7 (-15 -2190 ((-3 (-679 |#1|) "failed") |#2| (-917)))) 
+((-1678 (((-958 |#2|) (-1 |#2| |#1| |#2|) (-958 |#1|) |#2|) 16)) (-3094 ((|#2| (-1 |#2| |#1| |#2|) (-958 |#1|) |#2|) 18)) (-2797 (((-958 |#2|) (-1 |#2| |#1|) (-958 |#1|)) 13))) 
+(((-957 |#1| |#2|) (-10 -7 (-15 -1678 ((-958 |#2|) (-1 |#2| |#1| |#2|) (-958 |#1|) |#2|)) (-15 -3094 (|#2| (-1 |#2| |#1| |#2|) (-958 |#1|) |#2|)) (-15 -2797 ((-958 |#2|) (-1 |#2| |#1|) (-958 |#1|)))) (-1195) (-1195)) (T -957)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-958 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-958 *6)) (-5 *1 (-957 *5 *6)))) (-3094 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-958 *5)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-957 *5 *2)))) (-1678 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-958 *6)) (-4 *6 (-1195)) (-4 *5 (-1195)) (-5 *2 (-958 *5)) (-5 *1 (-957 *6 *5))))) 
+(-10 -7 (-15 -1678 ((-958 |#2|) (-1 |#2| |#1| |#2|) (-958 |#1|) |#2|)) (-15 -3094 (|#2| (-1 |#2| |#1| |#2|) (-958 |#1|) |#2|)) (-15 -2797 ((-958 |#2|) (-1 |#2| |#1|) (-958 |#1|)))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-1324 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-842)))) (-2109 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4522))) (($ $) NIL (-12 (|has| $ (-6 -4522)) (|has| |#1| (-842))))) (-3647 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-842)))) (-1667 (((-121) $ (-763)) NIL)) (-2438 ((|#1| $ (-568) |#1|) 17 (|has| $ (-6 -4522))) ((|#1| $ (-1210 (-568)) |#1|) NIL (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-4490 (($) NIL T CONST)) (-4452 (($ $) NIL (|has| $ (-6 -4522)))) (-3945 (($ $) NIL)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-4330 (($ |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4521)))) (-1292 ((|#1| $ (-568) |#1|) 16 (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-568)) 14)) (-2766 (((-568) (-1 (-121) |#1|) $) NIL) (((-568) |#1| $) NIL (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) NIL (|has| |#1| (-1090)))) (-3317 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-1851 (($ (-763) |#1|) 13)) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) 10 (|has| (-568) (-842)))) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-3645 (($ (-1 (-121) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-842)))) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3631 (((-568) $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-2253 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4124 (($ |#1| $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3877 ((|#1| $) NIL (|has| (-568) (-842)))) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-2490 (($ $ |#1|) 12 (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) 11)) (-2781 ((|#1| $ (-568) |#1|) NIL) ((|#1| $ (-568)) 15) (($ $ (-1210 (-568))) NIL)) (-2828 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3306 (($ $ $ (-568)) NIL (|has| $ (-6 -4522)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) NIL)) (-2770 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-634 $)) NIL)) (-2747 (((-850) $) NIL (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1699 (((-763) $) 8 (|has| $ (-6 -4521))))) 
 (((-958 |#1|) (-19 |#1|) (-1195)) (T -958)) 
 NIL 
 (-19 |#1|) 
-((-3690 (($ $ (-1082 $)) 7) (($ $ (-1161)) 6))) 
+((-2317 (($ $ (-1082 $)) 7) (($ $ (-1161)) 6))) 
 (((-959) (-1275)) (T -959)) 
-((-3690 (*1 *1 *1 *2) (-12 (-5 *2 (-1082 *1)) (-4 *1 (-959)))) (-3690 (*1 *1 *1 *2) (-12 (-4 *1 (-959)) (-5 *2 (-1161))))) 
-(-13 (-10 -8 (-15 -3690 ($ $ (-1161))) (-15 -3690 ($ $ (-1082 $))))) 
-((-4220 (((-2 (|:| -2348 (-634 (-568))) (|:| |poly| (-634 (-1157 |#1|))) (|:| |prim| (-1157 |#1|))) (-634 (-953 |#1|)) (-634 (-1161)) (-1161)) 23) (((-2 (|:| -2348 (-634 (-568))) (|:| |poly| (-634 (-1157 |#1|))) (|:| |prim| (-1157 |#1|))) (-634 (-953 |#1|)) (-634 (-1161))) 24) (((-2 (|:| |coef1| (-568)) (|:| |coef2| (-568)) (|:| |prim| (-1157 |#1|))) (-953 |#1|) (-1161) (-953 |#1|) (-1161)) 41))) 
-(((-960 |#1|) (-10 -7 (-15 -4220 ((-2 (|:| |coef1| (-568)) (|:| |coef2| (-568)) (|:| |prim| (-1157 |#1|))) (-953 |#1|) (-1161) (-953 |#1|) (-1161))) (-15 -4220 ((-2 (|:| -2348 (-634 (-568))) (|:| |poly| (-634 (-1157 |#1|))) (|:| |prim| (-1157 |#1|))) (-634 (-953 |#1|)) (-634 (-1161)))) (-15 -4220 ((-2 (|:| -2348 (-634 (-568))) (|:| |poly| (-634 (-1157 |#1|))) (|:| |prim| (-1157 |#1|))) (-634 (-953 |#1|)) (-634 (-1161)) (-1161)))) (-13 (-365) (-150))) (T -960)) 
-((-4220 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-953 *6))) (-5 *4 (-634 (-1161))) (-5 *5 (-1161)) (-4 *6 (-13 (-365) (-150))) (-5 *2 (-2 (|:| -2348 (-634 (-568))) (|:| |poly| (-634 (-1157 *6))) (|:| |prim| (-1157 *6)))) (-5 *1 (-960 *6)))) (-4220 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-634 (-1161))) (-4 *5 (-13 (-365) (-150))) (-5 *2 (-2 (|:| -2348 (-634 (-568))) (|:| |poly| (-634 (-1157 *5))) (|:| |prim| (-1157 *5)))) (-5 *1 (-960 *5)))) (-4220 (*1 *2 *3 *4 *3 *4) (-12 (-5 *3 (-953 *5)) (-5 *4 (-1161)) (-4 *5 (-13 (-365) (-150))) (-5 *2 (-2 (|:| |coef1| (-568)) (|:| |coef2| (-568)) (|:| |prim| (-1157 *5)))) (-5 *1 (-960 *5))))) 
-(-10 -7 (-15 -4220 ((-2 (|:| |coef1| (-568)) (|:| |coef2| (-568)) (|:| |prim| (-1157 |#1|))) (-953 |#1|) (-1161) (-953 |#1|) (-1161))) (-15 -4220 ((-2 (|:| -2348 (-634 (-568))) (|:| |poly| (-634 (-1157 |#1|))) (|:| |prim| (-1157 |#1|))) (-634 (-953 |#1|)) (-634 (-1161)))) (-15 -4220 ((-2 (|:| -2348 (-634 (-568))) (|:| |poly| (-634 (-1157 |#1|))) (|:| |prim| (-1157 |#1|))) (-634 (-953 |#1|)) (-634 (-1161)) (-1161)))) 
-((-2828 (((-634 |#1|) |#1| |#1|) 42)) (-3927 (((-121) |#1|) 39)) (-1821 ((|#1| |#1|) 64)) (-4130 ((|#1| |#1|) 63))) 
-(((-961 |#1|) (-10 -7 (-15 -3927 ((-121) |#1|)) (-15 -4130 (|#1| |#1|)) (-15 -1821 (|#1| |#1|)) (-15 -2828 ((-634 |#1|) |#1| |#1|))) (-550)) (T -961)) 
-((-2828 (*1 *2 *3 *3) (-12 (-5 *2 (-634 *3)) (-5 *1 (-961 *3)) (-4 *3 (-550)))) (-1821 (*1 *2 *2) (-12 (-5 *1 (-961 *2)) (-4 *2 (-550)))) (-4130 (*1 *2 *2) (-12 (-5 *1 (-961 *2)) (-4 *2 (-550)))) (-3927 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-961 *3)) (-4 *3 (-550))))) 
-(-10 -7 (-15 -3927 ((-121) |#1|)) (-15 -4130 (|#1| |#1|)) (-15 -1821 (|#1| |#1|)) (-15 -2828 ((-634 |#1|) |#1| |#1|))) 
-((-3417 (((-1249) (-850)) 9))) 
-(((-962) (-10 -7 (-15 -3417 ((-1249) (-850))))) (T -962)) 
-((-3417 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1249)) (-5 *1 (-962))))) 
-(-10 -7 (-15 -3417 ((-1249) (-850)))) 
-((-2725 (((-634 |#5|) |#3| (-634 |#3|)) 70)) (-1846 (((-634 |#5|) |#3|) 45)) (-1895 (((-634 |#5|) |#3| (-917)) 58)) (-2036 (((-634 |#5|) (-634 |#3|)) 48))) 
-(((-963 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -2725 ((-634 |#5|) |#3| (-634 |#3|))) (-15 -1846 ((-634 |#5|) |#3|)) (-15 -2036 ((-634 |#5|) (-634 |#3|))) (-15 -1895 ((-634 |#5|) |#3| (-917)))) (-365) (-634 (-1161)) (-950 |#1| |#4| (-852 |#2|)) (-230 (-1697 |#2|) (-763)) (-971 |#1|)) (T -963)) 
-((-1895 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1697 *6) (-763))) (-5 *2 (-634 *8)) (-5 *1 (-963 *5 *6 *3 *7 *8)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5)))) (-2036 (*1 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *2 (-634 *8)) (-5 *1 (-963 *4 *5 *6 *7 *8)) (-4 *8 (-971 *4)))) (-1846 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-230 (-1697 *5) (-763))) (-5 *2 (-634 *7)) (-5 *1 (-963 *4 *5 *3 *6 *7)) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *7 (-971 *4)))) (-2725 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *7 (-230 (-1697 *6) (-763))) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 *8)) (-5 *1 (-963 *5 *6 *3 *7 *8)) (-4 *8 (-971 *5))))) 
-(-10 -7 (-15 -2725 ((-634 |#5|) |#3| (-634 |#3|))) (-15 -1846 ((-634 |#5|) |#3|)) (-15 -2036 ((-634 |#5|) (-634 |#3|))) (-15 -1895 ((-634 |#5|) |#3| (-917)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 62 (|has| |#1| (-558)))) (-2227 (($ $) 63 (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 28)) (-2854 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) NIL)) (-2114 (($ $) 24)) (-2925 (((-3 $ "failed") $) 35)) (-3250 (($ $) NIL (|has| |#1| (-453)))) (-3088 (($ $ |#1| |#2| $) 47)) (-2735 (((-121) $) NIL)) (-4178 (((-763) $) 16)) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| |#2|) NIL)) (-2144 ((|#2| $) 19)) (-3842 (($ (-1 |#2| |#2|) $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-2097 (($ $) 23)) (-2102 ((|#1| $) 21)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2086 (((-121) $) 40)) (-2091 ((|#1| $) NIL)) (-4285 (($ $ |#2| |#1| $) 71 (-12 (|has| |#2| (-137)) (|has| |#1| (-558))))) (-2595 (((-3 $ "failed") $ $) 73 (|has| |#1| (-558))) (((-3 $ "failed") $ |#1|) 69 (|has| |#1| (-558)))) (-3206 ((|#2| $) 17)) (-3367 ((|#1| $) NIL (|has| |#1| (-453)))) (-2745 (((-850) $) NIL) (($ (-568)) 39) (($ $) NIL (|has| |#1| (-558))) (($ |#1|) 34) (($ (-409 (-568))) NIL (-2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568))))))) (-1302 (((-634 |#1|) $) NIL)) (-2604 ((|#1| $ |#2|) 31)) (-4371 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-4078 (((-763)) 15)) (-4171 (($ $ $ (-763)) 58 (|has| |#1| (-172)))) (-1826 (((-121) $ $) 68 (|has| |#1| (-558)))) (-1887 (($ $ (-917)) 54) (($ $ (-763)) 55)) (-3056 (($) 22 T CONST)) (-1556 (($) 12 T CONST)) (-1717 (((-121) $ $) 67)) (-1779 (($ $ |#1|) 74 (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) 53) (($ $ (-763)) 51)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 50) (($ $ |#1|) 49) (($ |#1| $) 48) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
-(((-964 |#1| |#2|) (-13 (-324 |#1| |#2|) (-10 -8 (IF (|has| |#1| (-558)) (IF (|has| |#2| (-137)) (-15 -4285 ($ $ |#2| |#1| $)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4517)) (-6 -4517) |noBranch|))) (-1047) (-787)) (T -964)) 
-((-4285 (*1 *1 *1 *2 *3 *1) (-12 (-5 *1 (-964 *3 *2)) (-4 *2 (-137)) (-4 *3 (-558)) (-4 *3 (-1047)) (-4 *2 (-787))))) 
-(-13 (-324 |#1| |#2|) (-10 -8 (IF (|has| |#1| (-558)) (IF (|has| |#2| (-137)) (-15 -4285 ($ $ |#2| |#1| $)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4517)) (-6 -4517) |noBranch|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL (-2198 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-137)) (|has| |#2| (-137))) (-12 (|has| |#1| (-788)) (|has| |#2| (-788)))))) (-1462 (($ $ $) 63 (-12 (|has| |#1| (-788)) (|has| |#2| (-788))))) (-3134 (((-3 $ "failed") $ $) 50 (-2198 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-137)) (|has| |#2| (-137))) (-12 (|has| |#1| (-788)) (|has| |#2| (-788)))))) (-3983 (((-763)) 34 (-12 (|has| |#1| (-370)) (|has| |#2| (-370))))) (-2911 ((|#2| $) 21)) (-4091 ((|#1| $) 20)) (-2671 (($) NIL (-2198 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-137)) (|has| |#2| (-137))) (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) (-12 (|has| |#1| (-716)) (|has| |#2| (-716))) (-12 (|has| |#1| (-788)) (|has| |#2| (-788)))) CONST)) (-2925 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) (-12 (|has| |#1| (-716)) (|has| |#2| (-716)))))) (-1731 (($) NIL (-12 (|has| |#1| (-370)) (|has| |#2| (-370))))) (-2735 (((-121) $) NIL (-2198 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) (-12 (|has| |#1| (-716)) (|has| |#2| (-716)))))) (-2521 (($ $ $) NIL (-2198 (-12 (|has| |#1| (-788)) (|has| |#2| (-788))) (-12 (|has| |#1| (-842)) (|has| |#2| (-842)))))) (-3268 (($ $ $) NIL (-2198 (-12 (|has| |#1| (-788)) (|has| |#2| (-788))) (-12 (|has| |#1| (-842)) (|has| |#2| (-842)))))) (-2338 (($ |#1| |#2|) 19)) (-3683 (((-917) $) NIL (-12 (|has| |#1| (-370)) (|has| |#2| (-370))))) (-4487 (((-1143) $) NIL)) (-2081 (($ $) 37 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))))) (-4355 (($ (-917)) NIL (-12 (|has| |#1| (-370)) (|has| |#2| (-370))))) (-4022 (((-1108) $) NIL)) (-1458 (($ $ $) NIL (-12 (|has| |#1| (-478)) (|has| |#2| (-478))))) (-2353 (($ $ $) NIL (-12 (|has| |#1| (-478)) (|has| |#2| (-478))))) (-2745 (((-850) $) 14)) (-1887 (($ $ (-568)) NIL (-12 (|has| |#1| (-478)) (|has| |#2| (-478)))) (($ $ (-763)) NIL (-2198 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) (-12 (|has| |#1| (-716)) (|has| |#2| (-716))))) (($ $ (-917)) NIL (-2198 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) (-12 (|has| |#1| (-716)) (|has| |#2| (-716)))))) (-3056 (($) 40 (-2198 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-137)) (|has| |#2| (-137))) (-12 (|has| |#1| (-788)) (|has| |#2| (-788)))) CONST)) (-1556 (($) 24 (-2198 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) (-12 (|has| |#1| (-716)) (|has| |#2| (-716)))) CONST)) (-1751 (((-121) $ $) NIL (-2198 (-12 (|has| |#1| (-788)) (|has| |#2| (-788))) (-12 (|has| |#1| (-842)) (|has| |#2| (-842)))))) (-1738 (((-121) $ $) NIL (-2198 (-12 (|has| |#1| (-788)) (|has| |#2| (-788))) (-12 (|has| |#1| (-842)) (|has| |#2| (-842)))))) (-1717 (((-121) $ $) 18)) (-1745 (((-121) $ $) NIL (-2198 (-12 (|has| |#1| (-788)) (|has| |#2| (-788))) (-12 (|has| |#1| (-842)) (|has| |#2| (-842)))))) (-1732 (((-121) $ $) 66 (-2198 (-12 (|has| |#1| (-788)) (|has| |#2| (-788))) (-12 (|has| |#1| (-842)) (|has| |#2| (-842)))))) (-1779 (($ $ $) NIL (-12 (|has| |#1| (-478)) (|has| |#2| (-478))))) (-1773 (($ $ $) 56 (-12 (|has| |#1| (-21)) (|has| |#2| (-21)))) (($ $) 53 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))))) (-1767 (($ $ $) 43 (-2198 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-137)) (|has| |#2| (-137))) (-12 (|has| |#1| (-788)) (|has| |#2| (-788)))))) (** (($ $ (-568)) NIL (-12 (|has| |#1| (-478)) (|has| |#2| (-478)))) (($ $ (-763)) 31 (-2198 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) (-12 (|has| |#1| (-716)) (|has| |#2| (-716))))) (($ $ (-917)) NIL (-2198 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) (-12 (|has| |#1| (-716)) (|has| |#2| (-716)))))) (* (($ (-568) $) 60 (-12 (|has| |#1| (-21)) (|has| |#2| (-21)))) (($ (-763) $) 46 (-2198 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-137)) (|has| |#2| (-137))) (-12 (|has| |#1| (-788)) (|has| |#2| (-788))))) (($ (-917) $) NIL (-2198 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-137)) (|has| |#2| (-137))) (-12 (|has| |#1| (-788)) (|has| |#2| (-788))))) (($ $ $) 27 (-2198 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) (-12 (|has| |#1| (-716)) (|has| |#2| (-716))))))) 
-(((-965 |#1| |#2|) (-13 (-1090) (-10 -8 (IF (|has| |#1| (-370)) (IF (|has| |#2| (-370)) (-6 (-370)) |noBranch|) |noBranch|) (IF (|has| |#1| (-716)) (IF (|has| |#2| (-716)) (-6 (-716)) |noBranch|) |noBranch|) (IF (|has| |#1| (-23)) (IF (|has| |#2| (-23)) (-6 (-23)) |noBranch|) |noBranch|) (IF (|has| |#1| (-137)) (IF (|has| |#2| (-137)) (-6 (-137)) |noBranch|) |noBranch|) (IF (|has| |#1| (-478)) (IF (|has| |#2| (-478)) (-6 (-478)) |noBranch|) |noBranch|) (IF (|has| |#1| (-21)) (IF (|has| |#2| (-21)) (-6 (-21)) |noBranch|) |noBranch|) (IF (|has| |#1| (-788)) (IF (|has| |#2| (-788)) (-6 (-788)) |noBranch|) |noBranch|) (IF (|has| |#1| (-842)) (IF (|has| |#2| (-842)) (-6 (-842)) |noBranch|) |noBranch|) (-15 -2338 ($ |#1| |#2|)) (-15 -4091 (|#1| $)) (-15 -2911 (|#2| $)))) (-1090) (-1090)) (T -965)) 
-((-2338 (*1 *1 *2 *3) (-12 (-5 *1 (-965 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090)))) (-4091 (*1 *2 *1) (-12 (-4 *2 (-1090)) (-5 *1 (-965 *2 *3)) (-4 *3 (-1090)))) (-2911 (*1 *2 *1) (-12 (-4 *2 (-1090)) (-5 *1 (-965 *3 *2)) (-4 *3 (-1090))))) 
-(-13 (-1090) (-10 -8 (IF (|has| |#1| (-370)) (IF (|has| |#2| (-370)) (-6 (-370)) |noBranch|) |noBranch|) (IF (|has| |#1| (-716)) (IF (|has| |#2| (-716)) (-6 (-716)) |noBranch|) |noBranch|) (IF (|has| |#1| (-23)) (IF (|has| |#2| (-23)) (-6 (-23)) |noBranch|) |noBranch|) (IF (|has| |#1| (-137)) (IF (|has| |#2| (-137)) (-6 (-137)) |noBranch|) |noBranch|) (IF (|has| |#1| (-478)) (IF (|has| |#2| (-478)) (-6 (-478)) |noBranch|) |noBranch|) (IF (|has| |#1| (-21)) (IF (|has| |#2| (-21)) (-6 (-21)) |noBranch|) |noBranch|) (IF (|has| |#1| (-788)) (IF (|has| |#2| (-788)) (-6 (-788)) |noBranch|) |noBranch|) (IF (|has| |#1| (-842)) (IF (|has| |#2| (-842)) (-6 (-842)) |noBranch|) |noBranch|) (-15 -2338 ($ |#1| |#2|)) (-15 -4091 (|#1| $)) (-15 -2911 (|#2| $)))) 
-((-2447 (((-121) $ $) NIL)) (-2436 ((|#1| $ (-568) |#1|) NIL)) (-1501 (((-634 $) (-634 $) (-763)) NIL) (((-634 $) (-634 $)) NIL)) (-2688 (((-121) $ (-763)) NIL) (((-121) $) NIL)) (-3534 (($ (-634 |#1|)) NIL)) (-3890 (((-634 |#1|) $) NIL)) (-3340 (((-634 $) $) NIL) (((-634 $) $ (-763)) NIL)) (-3896 (((-634 |#1|) $) NIL)) (-4487 (((-1143) $) NIL)) (-4131 (((-568) $) NIL)) (-2891 (((-568) $) NIL)) (-3039 (($ $ (-568)) NIL) (($ $) NIL)) (-4022 (((-1108) $) NIL)) (-2779 ((|#1| $ (-568)) NIL)) (-3206 (((-917) $) NIL)) (-3233 ((|#1| $) NIL)) (-1458 (($ $ (-763)) NIL) (($ $) NIL)) (-2745 (((-850) $) NIL) (((-634 |#1|) $) NIL) (($ (-634 |#1|)) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2317 (*1 *1 *1 *2) (-12 (-5 *2 (-1082 *1)) (-4 *1 (-959)))) (-2317 (*1 *1 *1 *2) (-12 (-4 *1 (-959)) (-5 *2 (-1161))))) 
+(-13 (-10 -8 (-15 -2317 ($ $ (-1161))) (-15 -2317 ($ $ (-1082 $))))) 
+((-4188 (((-2 (|:| -2350 (-634 (-568))) (|:| |poly| (-634 (-1157 |#1|))) (|:| |prim| (-1157 |#1|))) (-634 (-953 |#1|)) (-634 (-1161)) (-1161)) 23) (((-2 (|:| -2350 (-634 (-568))) (|:| |poly| (-634 (-1157 |#1|))) (|:| |prim| (-1157 |#1|))) (-634 (-953 |#1|)) (-634 (-1161))) 24) (((-2 (|:| |coef1| (-568)) (|:| |coef2| (-568)) (|:| |prim| (-1157 |#1|))) (-953 |#1|) (-1161) (-953 |#1|) (-1161)) 41))) 
+(((-960 |#1|) (-10 -7 (-15 -4188 ((-2 (|:| |coef1| (-568)) (|:| |coef2| (-568)) (|:| |prim| (-1157 |#1|))) (-953 |#1|) (-1161) (-953 |#1|) (-1161))) (-15 -4188 ((-2 (|:| -2350 (-634 (-568))) (|:| |poly| (-634 (-1157 |#1|))) (|:| |prim| (-1157 |#1|))) (-634 (-953 |#1|)) (-634 (-1161)))) (-15 -4188 ((-2 (|:| -2350 (-634 (-568))) (|:| |poly| (-634 (-1157 |#1|))) (|:| |prim| (-1157 |#1|))) (-634 (-953 |#1|)) (-634 (-1161)) (-1161)))) (-13 (-365) (-150))) (T -960)) 
+((-4188 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-953 *6))) (-5 *4 (-634 (-1161))) (-5 *5 (-1161)) (-4 *6 (-13 (-365) (-150))) (-5 *2 (-2 (|:| -2350 (-634 (-568))) (|:| |poly| (-634 (-1157 *6))) (|:| |prim| (-1157 *6)))) (-5 *1 (-960 *6)))) (-4188 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-634 (-1161))) (-4 *5 (-13 (-365) (-150))) (-5 *2 (-2 (|:| -2350 (-634 (-568))) (|:| |poly| (-634 (-1157 *5))) (|:| |prim| (-1157 *5)))) (-5 *1 (-960 *5)))) (-4188 (*1 *2 *3 *4 *3 *4) (-12 (-5 *3 (-953 *5)) (-5 *4 (-1161)) (-4 *5 (-13 (-365) (-150))) (-5 *2 (-2 (|:| |coef1| (-568)) (|:| |coef2| (-568)) (|:| |prim| (-1157 *5)))) (-5 *1 (-960 *5))))) 
+(-10 -7 (-15 -4188 ((-2 (|:| |coef1| (-568)) (|:| |coef2| (-568)) (|:| |prim| (-1157 |#1|))) (-953 |#1|) (-1161) (-953 |#1|) (-1161))) (-15 -4188 ((-2 (|:| -2350 (-634 (-568))) (|:| |poly| (-634 (-1157 |#1|))) (|:| |prim| (-1157 |#1|))) (-634 (-953 |#1|)) (-634 (-1161)))) (-15 -4188 ((-2 (|:| -2350 (-634 (-568))) (|:| |poly| (-634 (-1157 |#1|))) (|:| |prim| (-1157 |#1|))) (-634 (-953 |#1|)) (-634 (-1161)) (-1161)))) 
+((-3829 (((-634 |#1|) |#1| |#1|) 42)) (-2197 (((-121) |#1|) 39)) (-2245 ((|#1| |#1|) 64)) (-3702 ((|#1| |#1|) 63))) 
+(((-961 |#1|) (-10 -7 (-15 -2197 ((-121) |#1|)) (-15 -3702 (|#1| |#1|)) (-15 -2245 (|#1| |#1|)) (-15 -3829 ((-634 |#1|) |#1| |#1|))) (-550)) (T -961)) 
+((-3829 (*1 *2 *3 *3) (-12 (-5 *2 (-634 *3)) (-5 *1 (-961 *3)) (-4 *3 (-550)))) (-2245 (*1 *2 *2) (-12 (-5 *1 (-961 *2)) (-4 *2 (-550)))) (-3702 (*1 *2 *2) (-12 (-5 *1 (-961 *2)) (-4 *2 (-550)))) (-2197 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-961 *3)) (-4 *3 (-550))))) 
+(-10 -7 (-15 -2197 ((-121) |#1|)) (-15 -3702 (|#1| |#1|)) (-15 -2245 (|#1| |#1|)) (-15 -3829 ((-634 |#1|) |#1| |#1|))) 
+((-3419 (((-1249) (-850)) 9))) 
+(((-962) (-10 -7 (-15 -3419 ((-1249) (-850))))) (T -962)) 
+((-3419 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1249)) (-5 *1 (-962))))) 
+(-10 -7 (-15 -3419 ((-1249) (-850)))) 
+((-1551 (((-634 |#5|) |#3| (-634 |#3|)) 70)) (-2378 (((-634 |#5|) |#3|) 45)) (-2603 (((-634 |#5|) |#3| (-917)) 58)) (-1455 (((-634 |#5|) (-634 |#3|)) 48))) 
+(((-963 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1551 ((-634 |#5|) |#3| (-634 |#3|))) (-15 -2378 ((-634 |#5|) |#3|)) (-15 -1455 ((-634 |#5|) (-634 |#3|))) (-15 -2603 ((-634 |#5|) |#3| (-917)))) (-365) (-634 (-1161)) (-950 |#1| |#4| (-852 |#2|)) (-230 (-1699 |#2|) (-763)) (-971 |#1|)) (T -963)) 
+((-2603 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1699 *6) (-763))) (-5 *2 (-634 *8)) (-5 *1 (-963 *5 *6 *3 *7 *8)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5)))) (-1455 (*1 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *2 (-634 *8)) (-5 *1 (-963 *4 *5 *6 *7 *8)) (-4 *8 (-971 *4)))) (-2378 (*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-230 (-1699 *5) (-763))) (-5 *2 (-634 *7)) (-5 *1 (-963 *4 *5 *3 *6 *7)) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *7 (-971 *4)))) (-1551 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *7 (-230 (-1699 *6) (-763))) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 *8)) (-5 *1 (-963 *5 *6 *3 *7 *8)) (-4 *8 (-971 *5))))) 
+(-10 -7 (-15 -1551 ((-634 |#5|) |#3| (-634 |#3|))) (-15 -2378 ((-634 |#5|) |#3|)) (-15 -1455 ((-634 |#5|) (-634 |#3|))) (-15 -2603 ((-634 |#5|) |#3| (-917)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 62 (|has| |#1| (-558)))) (-3661 (($ $) 63 (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 28)) (-2857 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) NIL)) (-2116 (($ $) 24)) (-2902 (((-3 $ "failed") $) 35)) (-1998 (($ $) NIL (|has| |#1| (-453)))) (-2453 (($ $ |#1| |#2| $) 47)) (-1598 (((-121) $) NIL)) (-3971 (((-763) $) 16)) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| |#2|) NIL)) (-3524 ((|#2| $) 19)) (-1865 (($ (-1 |#2| |#2|) $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-2099 (($ $) 23)) (-2104 ((|#1| $) 21)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2088 (((-121) $) 40)) (-2093 ((|#1| $) NIL)) (-2973 (($ $ |#2| |#1| $) 71 (-12 (|has| |#2| (-137)) (|has| |#1| (-558))))) (-2597 (((-3 $ "failed") $ $) 73 (|has| |#1| (-558))) (((-3 $ "failed") $ |#1|) 69 (|has| |#1| (-558)))) (-1836 ((|#2| $) 17)) (-1364 ((|#1| $) NIL (|has| |#1| (-453)))) (-2747 (((-850) $) NIL) (($ (-568)) 39) (($ $) NIL (|has| |#1| (-558))) (($ |#1|) 34) (($ (-409 (-568))) NIL (-2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568))))))) (-3304 (((-634 |#1|) $) NIL)) (-2079 ((|#1| $ |#2|) 31)) (-3385 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-3425 (((-763)) 15)) (-3925 (($ $ $ (-763)) 58 (|has| |#1| (-172)))) (-2273 (((-121) $ $) 68 (|has| |#1| (-558)))) (-1889 (($ $ (-917)) 54) (($ $ (-763)) 55)) (-3058 (($) 22 T CONST)) (-1557 (($) 12 T CONST)) (-1719 (((-121) $ $) 67)) (-1781 (($ $ |#1|) 74 (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) 53) (($ $ (-763)) 51)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 50) (($ $ |#1|) 49) (($ |#1| $) 48) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
+(((-964 |#1| |#2|) (-13 (-324 |#1| |#2|) (-10 -8 (IF (|has| |#1| (-558)) (IF (|has| |#2| (-137)) (-15 -2973 ($ $ |#2| |#1| $)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4519)) (-6 -4519) |noBranch|))) (-1047) (-787)) (T -964)) 
+((-2973 (*1 *1 *1 *2 *3 *1) (-12 (-5 *1 (-964 *3 *2)) (-4 *2 (-137)) (-4 *3 (-558)) (-4 *3 (-1047)) (-4 *2 (-787))))) 
+(-13 (-324 |#1| |#2|) (-10 -8 (IF (|has| |#1| (-558)) (IF (|has| |#2| (-137)) (-15 -2973 ($ $ |#2| |#1| $)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4519)) (-6 -4519) |noBranch|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL (-2199 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-137)) (|has| |#2| (-137))) (-12 (|has| |#1| (-788)) (|has| |#2| (-788)))))) (-2409 (($ $ $) 63 (-12 (|has| |#1| (-788)) (|has| |#2| (-788))))) (-2689 (((-3 $ "failed") $ $) 50 (-2199 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-137)) (|has| |#2| (-137))) (-12 (|has| |#1| (-788)) (|has| |#2| (-788)))))) (-3986 (((-763)) 34 (-12 (|has| |#1| (-370)) (|has| |#2| (-370))))) (-2861 ((|#2| $) 21)) (-3502 ((|#1| $) 20)) (-4490 (($) NIL (-2199 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-137)) (|has| |#2| (-137))) (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) (-12 (|has| |#1| (-716)) (|has| |#2| (-716))) (-12 (|has| |#1| (-788)) (|has| |#2| (-788)))) CONST)) (-2902 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) (-12 (|has| |#1| (-716)) (|has| |#2| (-716)))))) (-1733 (($) NIL (-12 (|has| |#1| (-370)) (|has| |#2| (-370))))) (-1598 (((-121) $) NIL (-2199 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) (-12 (|has| |#1| (-716)) (|has| |#2| (-716)))))) (-1732 (($ $ $) NIL (-2199 (-12 (|has| |#1| (-788)) (|has| |#2| (-788))) (-12 (|has| |#1| (-842)) (|has| |#2| (-842)))))) (-2047 (($ $ $) NIL (-2199 (-12 (|has| |#1| (-788)) (|has| |#2| (-788))) (-12 (|has| |#1| (-842)) (|has| |#2| (-842)))))) (-3890 (($ |#1| |#2|) 19)) (-2291 (((-917) $) NIL (-12 (|has| |#1| (-370)) (|has| |#2| (-370))))) (-1893 (((-1143) $) NIL)) (-2083 (($ $) 37 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))))) (-4357 (($ (-917)) NIL (-12 (|has| |#1| (-370)) (|has| |#2| (-370))))) (-4025 (((-1108) $) NIL)) (-2387 (($ $ $) NIL (-12 (|has| |#1| (-478)) (|has| |#2| (-478))))) (-3985 (($ $ $) NIL (-12 (|has| |#1| (-478)) (|has| |#2| (-478))))) (-2747 (((-850) $) 14)) (-1889 (($ $ (-568)) NIL (-12 (|has| |#1| (-478)) (|has| |#2| (-478)))) (($ $ (-763)) NIL (-2199 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) (-12 (|has| |#1| (-716)) (|has| |#2| (-716))))) (($ $ (-917)) NIL (-2199 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) (-12 (|has| |#1| (-716)) (|has| |#2| (-716)))))) (-3058 (($) 40 (-2199 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-137)) (|has| |#2| (-137))) (-12 (|has| |#1| (-788)) (|has| |#2| (-788)))) CONST)) (-1557 (($) 24 (-2199 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) (-12 (|has| |#1| (-716)) (|has| |#2| (-716)))) CONST)) (-1753 (((-121) $ $) NIL (-2199 (-12 (|has| |#1| (-788)) (|has| |#2| (-788))) (-12 (|has| |#1| (-842)) (|has| |#2| (-842)))))) (-1740 (((-121) $ $) NIL (-2199 (-12 (|has| |#1| (-788)) (|has| |#2| (-788))) (-12 (|has| |#1| (-842)) (|has| |#2| (-842)))))) (-1719 (((-121) $ $) 18)) (-1747 (((-121) $ $) NIL (-2199 (-12 (|has| |#1| (-788)) (|has| |#2| (-788))) (-12 (|has| |#1| (-842)) (|has| |#2| (-842)))))) (-1734 (((-121) $ $) 66 (-2199 (-12 (|has| |#1| (-788)) (|has| |#2| (-788))) (-12 (|has| |#1| (-842)) (|has| |#2| (-842)))))) (-1781 (($ $ $) NIL (-12 (|has| |#1| (-478)) (|has| |#2| (-478))))) (-1775 (($ $ $) 56 (-12 (|has| |#1| (-21)) (|has| |#2| (-21)))) (($ $) 53 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))))) (-1769 (($ $ $) 43 (-2199 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-137)) (|has| |#2| (-137))) (-12 (|has| |#1| (-788)) (|has| |#2| (-788)))))) (** (($ $ (-568)) NIL (-12 (|has| |#1| (-478)) (|has| |#2| (-478)))) (($ $ (-763)) 31 (-2199 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) (-12 (|has| |#1| (-716)) (|has| |#2| (-716))))) (($ $ (-917)) NIL (-2199 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) (-12 (|has| |#1| (-716)) (|has| |#2| (-716)))))) (* (($ (-568) $) 60 (-12 (|has| |#1| (-21)) (|has| |#2| (-21)))) (($ (-763) $) 46 (-2199 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-137)) (|has| |#2| (-137))) (-12 (|has| |#1| (-788)) (|has| |#2| (-788))))) (($ (-917) $) NIL (-2199 (-12 (|has| |#1| (-21)) (|has| |#2| (-21))) (-12 (|has| |#1| (-23)) (|has| |#2| (-23))) (-12 (|has| |#1| (-137)) (|has| |#2| (-137))) (-12 (|has| |#1| (-788)) (|has| |#2| (-788))))) (($ $ $) 27 (-2199 (-12 (|has| |#1| (-478)) (|has| |#2| (-478))) (-12 (|has| |#1| (-716)) (|has| |#2| (-716))))))) 
+(((-965 |#1| |#2|) (-13 (-1090) (-10 -8 (IF (|has| |#1| (-370)) (IF (|has| |#2| (-370)) (-6 (-370)) |noBranch|) |noBranch|) (IF (|has| |#1| (-716)) (IF (|has| |#2| (-716)) (-6 (-716)) |noBranch|) |noBranch|) (IF (|has| |#1| (-23)) (IF (|has| |#2| (-23)) (-6 (-23)) |noBranch|) |noBranch|) (IF (|has| |#1| (-137)) (IF (|has| |#2| (-137)) (-6 (-137)) |noBranch|) |noBranch|) (IF (|has| |#1| (-478)) (IF (|has| |#2| (-478)) (-6 (-478)) |noBranch|) |noBranch|) (IF (|has| |#1| (-21)) (IF (|has| |#2| (-21)) (-6 (-21)) |noBranch|) |noBranch|) (IF (|has| |#1| (-788)) (IF (|has| |#2| (-788)) (-6 (-788)) |noBranch|) |noBranch|) (IF (|has| |#1| (-842)) (IF (|has| |#2| (-842)) (-6 (-842)) |noBranch|) |noBranch|) (-15 -3890 ($ |#1| |#2|)) (-15 -3502 (|#1| $)) (-15 -2861 (|#2| $)))) (-1090) (-1090)) (T -965)) 
+((-3890 (*1 *1 *2 *3) (-12 (-5 *1 (-965 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090)))) (-3502 (*1 *2 *1) (-12 (-4 *2 (-1090)) (-5 *1 (-965 *2 *3)) (-4 *3 (-1090)))) (-2861 (*1 *2 *1) (-12 (-4 *2 (-1090)) (-5 *1 (-965 *3 *2)) (-4 *3 (-1090))))) 
+(-13 (-1090) (-10 -8 (IF (|has| |#1| (-370)) (IF (|has| |#2| (-370)) (-6 (-370)) |noBranch|) |noBranch|) (IF (|has| |#1| (-716)) (IF (|has| |#2| (-716)) (-6 (-716)) |noBranch|) |noBranch|) (IF (|has| |#1| (-23)) (IF (|has| |#2| (-23)) (-6 (-23)) |noBranch|) |noBranch|) (IF (|has| |#1| (-137)) (IF (|has| |#2| (-137)) (-6 (-137)) |noBranch|) |noBranch|) (IF (|has| |#1| (-478)) (IF (|has| |#2| (-478)) (-6 (-478)) |noBranch|) |noBranch|) (IF (|has| |#1| (-21)) (IF (|has| |#2| (-21)) (-6 (-21)) |noBranch|) |noBranch|) (IF (|has| |#1| (-788)) (IF (|has| |#2| (-788)) (-6 (-788)) |noBranch|) |noBranch|) (IF (|has| |#1| (-842)) (IF (|has| |#2| (-842)) (-6 (-842)) |noBranch|) |noBranch|) (-15 -3890 ($ |#1| |#2|)) (-15 -3502 (|#1| $)) (-15 -2861 (|#2| $)))) 
+((-2449 (((-121) $ $) NIL)) (-2438 ((|#1| $ (-568) |#1|) NIL)) (-2613 (((-634 $) (-634 $) (-763)) NIL) (((-634 $) (-634 $)) NIL)) (-1338 (((-121) $ (-763)) NIL) (((-121) $) NIL)) (-4154 (($ (-634 |#1|)) NIL)) (-2034 (((-634 |#1|) $) NIL)) (-4450 (((-634 $) $) NIL) (((-634 $) $ (-763)) NIL)) (-3897 (((-634 |#1|) $) NIL)) (-1893 (((-1143) $) NIL)) (-3709 (((-568) $) NIL)) (-2794 (((-568) $) NIL)) (-2219 (($ $ (-568)) NIL) (($ $) NIL)) (-4025 (((-1108) $) NIL)) (-2781 ((|#1| $ (-568)) NIL)) (-1836 (((-917) $) NIL)) (-1937 ((|#1| $) NIL)) (-2387 (($ $ (-763)) NIL) (($ $) NIL)) (-2747 (((-850) $) NIL) (((-634 |#1|) $) NIL) (($ (-634 |#1|)) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-966 |#1|) (-971 |#1|) (-365)) (T -966)) 
 NIL 
 (-971 |#1|) 
-((-2447 (((-121) $ $) NIL)) (-2436 (((-857 |#1|) $ (-568) (-857 |#1|)) NIL)) (-1501 (((-634 $) (-634 $) (-763)) NIL) (((-634 $) (-634 $)) NIL)) (-2688 (((-121) $ (-763)) NIL) (((-121) $) NIL)) (-3534 (($ (-634 (-857 |#1|))) NIL)) (-3890 (((-634 (-857 |#1|)) $) NIL)) (-3340 (((-634 $) $) NIL) (((-634 $) $ (-763)) NIL)) (-3896 (((-634 (-857 |#1|)) $) NIL)) (-4487 (((-1143) $) NIL)) (-4131 (((-568) $) NIL)) (-2891 (((-568) $) NIL)) (-3039 (($ $ (-568)) NIL) (($ $) NIL)) (-4022 (((-1108) $) NIL)) (-2779 (((-857 |#1|) $ (-568)) NIL)) (-3206 (((-917) $) NIL)) (-3233 (((-857 |#1|) $) NIL)) (-1458 (($ $ (-763)) NIL) (($ $) NIL)) (-2745 (((-850) $) NIL) (((-634 (-857 |#1|)) $) NIL) (($ (-634 (-857 |#1|))) NIL)) (-1717 (((-121) $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-2438 (((-857 |#1|) $ (-568) (-857 |#1|)) NIL)) (-2613 (((-634 $) (-634 $) (-763)) NIL) (((-634 $) (-634 $)) NIL)) (-1338 (((-121) $ (-763)) NIL) (((-121) $) NIL)) (-4154 (($ (-634 (-857 |#1|))) NIL)) (-2034 (((-634 (-857 |#1|)) $) NIL)) (-4450 (((-634 $) $) NIL) (((-634 $) $ (-763)) NIL)) (-3897 (((-634 (-857 |#1|)) $) NIL)) (-1893 (((-1143) $) NIL)) (-3709 (((-568) $) NIL)) (-2794 (((-568) $) NIL)) (-2219 (($ $ (-568)) NIL) (($ $) NIL)) (-4025 (((-1108) $) NIL)) (-2781 (((-857 |#1|) $ (-568)) NIL)) (-1836 (((-917) $) NIL)) (-1937 (((-857 |#1|) $) NIL)) (-2387 (($ $ (-763)) NIL) (($ $) NIL)) (-2747 (((-850) $) NIL) (((-634 (-857 |#1|)) $) NIL) (($ (-634 (-857 |#1|))) NIL)) (-1719 (((-121) $ $) NIL))) 
 (((-967 |#1|) (-971 (-857 |#1|)) (-350)) (T -967)) 
 NIL 
 (-971 (-857 |#1|)) 
-((-2447 (((-121) $ $) NIL)) (-2436 ((|#2| $ (-568) |#2|) NIL)) (-1501 (((-634 $) (-634 $) (-763)) 41) (((-634 $) (-634 $)) 42)) (-2688 (((-121) $ (-763)) 38) (((-121) $) 40)) (-3534 (($ (-634 |#2|)) 25)) (-3890 (((-634 |#2|) $) 27)) (-3340 (((-634 $) $) 50) (((-634 $) $ (-763)) 47)) (-3896 (((-634 |#2|) $) 26)) (-4487 (((-1143) $) NIL)) (-4131 (((-568) $) 59)) (-2891 (((-568) $) 62)) (-3039 (($ $ (-568)) 36) (($ $) 52)) (-4022 (((-1108) $) NIL)) (-2779 ((|#2| $ (-568)) 32)) (-3206 (((-917) $) 16)) (-3233 ((|#2| $) 22)) (-1458 (($ $ (-763)) 30) (($ $) 49)) (-2745 (((-850) $) 19) (((-634 |#2|) $) 24) (($ (-634 |#2|)) 58)) (-1717 (((-121) $ $) 37))) 
+((-2449 (((-121) $ $) NIL)) (-2438 ((|#2| $ (-568) |#2|) NIL)) (-2613 (((-634 $) (-634 $) (-763)) 41) (((-634 $) (-634 $)) 42)) (-1338 (((-121) $ (-763)) 38) (((-121) $) 40)) (-4154 (($ (-634 |#2|)) 25)) (-2034 (((-634 |#2|) $) 27)) (-4450 (((-634 $) $) 50) (((-634 $) $ (-763)) 47)) (-3897 (((-634 |#2|) $) 26)) (-1893 (((-1143) $) NIL)) (-3709 (((-568) $) 59)) (-2794 (((-568) $) 62)) (-2219 (($ $ (-568)) 36) (($ $) 52)) (-4025 (((-1108) $) NIL)) (-2781 ((|#2| $ (-568)) 32)) (-1836 (((-917) $) 16)) (-1937 ((|#2| $) 22)) (-2387 (($ $ (-763)) 30) (($ $) 49)) (-2747 (((-850) $) 19) (((-634 |#2|) $) 24) (($ (-634 |#2|)) 58)) (-1719 (((-121) $ $) 37))) 
 (((-968 |#1| |#2|) (-971 |#2|) (-763) (-365)) (T -968)) 
 NIL 
 (-971 |#2|) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2510 (((-121) $ (-763)) 8)) (-2671 (($) 7 T CONST)) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) 9)) (-3349 (($ $ $) 40)) (-1347 (($ $ $) 41)) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3268 ((|#1| $) 42)) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35)) (-2166 (((-121) $ (-763)) 10)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-1890 ((|#1| $) 36)) (-4450 (($ |#1| $) 37)) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-1315 ((|#1| $) 38)) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-2367 (($ (-634 |#1|)) 39)) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-1667 (((-121) $ (-763)) 8)) (-4490 (($) 7 T CONST)) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) 9)) (-4496 (($ $ $) 40)) (-3645 (($ $ $) 41)) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-2047 ((|#1| $) 42)) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35)) (-3796 (((-121) $ (-763)) 10)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-2580 ((|#1| $) 36)) (-1708 (($ |#1| $) 37)) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3403 ((|#1| $) 38)) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-4074 (($ (-634 |#1|)) 39)) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-969 |#1|) (-1275) (-842)) (T -969)) 
-((-3268 (*1 *2 *1) (-12 (-4 *1 (-969 *2)) (-4 *2 (-842)))) (-1347 (*1 *1 *1 *1) (-12 (-4 *1 (-969 *2)) (-4 *2 (-842)))) (-3349 (*1 *1 *1 *1) (-12 (-4 *1 (-969 *2)) (-4 *2 (-842))))) 
-(-13 (-111 |t#1|) (-10 -8 (-6 -4519) (-15 -3268 (|t#1| $)) (-15 -1347 ($ $ $)) (-15 -3349 ($ $ $)))) 
+((-2047 (*1 *2 *1) (-12 (-4 *1 (-969 *2)) (-4 *2 (-842)))) (-3645 (*1 *1 *1 *1) (-12 (-4 *1 (-969 *2)) (-4 *2 (-842)))) (-4496 (*1 *1 *1 *1) (-12 (-4 *1 (-969 *2)) (-4 *2 (-842))))) 
+(-13 (-111 |t#1|) (-10 -8 (-6 -4521) (-15 -2047 (|t#1| $)) (-15 -3645 ($ $ $)) (-15 -4496 ($ $ $)))) 
 (((-39) . T) ((-111 |#1|) . T) ((-105) |has| |#1| (-1090)) ((-608 (-850)) |has| |#1| (-1090)) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-1090) |has| |#1| (-1090)) ((-1195) . T)) 
-((-2538 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -2721 |#2|)) |#2| |#2|) 84)) (-3809 ((|#2| |#2| |#2|) 82)) (-1345 (((-2 (|:| |coef2| |#2|) (|:| -2721 |#2|)) |#2| |#2|) 86)) (-3257 (((-2 (|:| |coef1| |#2|) (|:| -2721 |#2|)) |#2| |#2|) 88)) (-2226 (((-2 (|:| |coef2| |#2|) (|:| -1880 |#1|)) |#2| |#2|) 106 (|has| |#1| (-453)))) (-4164 (((-2 (|:| |coef2| |#2|) (|:| -4265 |#1|)) |#2| |#2|) 45)) (-1280 (((-2 (|:| |coef2| |#2|) (|:| -4265 |#1|)) |#2| |#2|) 63)) (-3265 (((-2 (|:| |coef1| |#2|) (|:| -4265 |#1|)) |#2| |#2|) 65)) (-2437 (((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|) 77)) (-2860 (((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763)) 70)) (-3560 (((-2 (|:| |coef2| |#2|) (|:| -2217 |#1|)) |#2|) 96)) (-3345 (((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763)) 73)) (-3679 (((-634 (-763)) |#2| |#2|) 81)) (-2963 ((|#1| |#2| |#2|) 41)) (-2586 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -1880 |#1|)) |#2| |#2|) 104 (|has| |#1| (-453)))) (-1880 ((|#1| |#2| |#2|) 102 (|has| |#1| (-453)))) (-3733 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -4265 |#1|)) |#2| |#2|) 43)) (-1554 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -4265 |#1|)) |#2| |#2|) 62)) (-4265 ((|#1| |#2| |#2|) 60)) (-4144 (((-2 (|:| -2348 |#1|) (|:| -3961 |#2|) (|:| -1500 |#2|)) |#2| |#2|) 35)) (-3366 ((|#2| |#2| |#2| |#2| |#1|) 52)) (-1704 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|) 75)) (-4330 ((|#2| |#2| |#2|) 74)) (-2938 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763)) 68)) (-2048 ((|#2| |#2| |#2| (-763)) 66)) (-2721 ((|#2| |#2| |#2|) 110 (|has| |#1| (-453)))) (-2595 (((-1244 |#2|) (-1244 |#2|) |#1|) 21)) (-3210 (((-2 (|:| -3961 |#2|) (|:| -1500 |#2|)) |#2| |#2|) 38)) (-1634 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -2217 |#1|)) |#2|) 94)) (-2217 ((|#1| |#2|) 91)) (-2479 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763)) 72)) (-4377 ((|#2| |#2| |#2| (-763)) 71)) (-1805 (((-634 |#2|) |#2| |#2|) 79)) (-2434 ((|#2| |#2| |#1| |#1| (-763)) 49)) (-2211 ((|#1| |#1| |#1| (-763)) 48)) (* (((-1244 |#2|) |#1| (-1244 |#2|)) 16))) 
-(((-970 |#1| |#2|) (-10 -7 (-15 -4265 (|#1| |#2| |#2|)) (-15 -1554 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -4265 |#1|)) |#2| |#2|)) (-15 -1280 ((-2 (|:| |coef2| |#2|) (|:| -4265 |#1|)) |#2| |#2|)) (-15 -3265 ((-2 (|:| |coef1| |#2|) (|:| -4265 |#1|)) |#2| |#2|)) (-15 -2048 (|#2| |#2| |#2| (-763))) (-15 -2938 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763))) (-15 -2860 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763))) (-15 -4377 (|#2| |#2| |#2| (-763))) (-15 -2479 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763))) (-15 -3345 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763))) (-15 -4330 (|#2| |#2| |#2|)) (-15 -1704 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|)) (-15 -2437 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|)) (-15 -3809 (|#2| |#2| |#2|)) (-15 -2538 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -2721 |#2|)) |#2| |#2|)) (-15 -1345 ((-2 (|:| |coef2| |#2|) (|:| -2721 |#2|)) |#2| |#2|)) (-15 -3257 ((-2 (|:| |coef1| |#2|) (|:| -2721 |#2|)) |#2| |#2|)) (-15 -2217 (|#1| |#2|)) (-15 -1634 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -2217 |#1|)) |#2|)) (-15 -3560 ((-2 (|:| |coef2| |#2|) (|:| -2217 |#1|)) |#2|)) (-15 -1805 ((-634 |#2|) |#2| |#2|)) (-15 -3679 ((-634 (-763)) |#2| |#2|)) (IF (|has| |#1| (-453)) (PROGN (-15 -1880 (|#1| |#2| |#2|)) (-15 -2586 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -1880 |#1|)) |#2| |#2|)) (-15 -2226 ((-2 (|:| |coef2| |#2|) (|:| -1880 |#1|)) |#2| |#2|)) (-15 -2721 (|#2| |#2| |#2|))) |noBranch|) (-15 * ((-1244 |#2|) |#1| (-1244 |#2|))) (-15 -2595 ((-1244 |#2|) (-1244 |#2|) |#1|)) (-15 -4144 ((-2 (|:| -2348 |#1|) (|:| -3961 |#2|) (|:| -1500 |#2|)) |#2| |#2|)) (-15 -3210 ((-2 (|:| -3961 |#2|) (|:| -1500 |#2|)) |#2| |#2|)) (-15 -2211 (|#1| |#1| |#1| (-763))) (-15 -2434 (|#2| |#2| |#1| |#1| (-763))) (-15 -3366 (|#2| |#2| |#2| |#2| |#1|)) (-15 -2963 (|#1| |#2| |#2|)) (-15 -3733 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -4265 |#1|)) |#2| |#2|)) (-15 -4164 ((-2 (|:| |coef2| |#2|) (|:| -4265 |#1|)) |#2| |#2|))) (-558) (-1219 |#1|)) (T -970)) 
-((-4164 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -4265 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-3733 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -4265 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-2963 (*1 *2 *3 *3) (-12 (-4 *2 (-558)) (-5 *1 (-970 *2 *3)) (-4 *3 (-1219 *2)))) (-3366 (*1 *2 *2 *2 *2 *3) (-12 (-4 *3 (-558)) (-5 *1 (-970 *3 *2)) (-4 *2 (-1219 *3)))) (-2434 (*1 *2 *2 *3 *3 *4) (-12 (-5 *4 (-763)) (-4 *3 (-558)) (-5 *1 (-970 *3 *2)) (-4 *2 (-1219 *3)))) (-2211 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *2 (-558)) (-5 *1 (-970 *2 *4)) (-4 *4 (-1219 *2)))) (-3210 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| -3961 *3) (|:| -1500 *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-4144 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| -2348 *4) (|:| -3961 *3) (|:| -1500 *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-2595 (*1 *2 *2 *3) (-12 (-5 *2 (-1244 *4)) (-4 *4 (-1219 *3)) (-4 *3 (-558)) (-5 *1 (-970 *3 *4)))) (* (*1 *2 *3 *2) (-12 (-5 *2 (-1244 *4)) (-4 *4 (-1219 *3)) (-4 *3 (-558)) (-5 *1 (-970 *3 *4)))) (-2721 (*1 *2 *2 *2) (-12 (-4 *3 (-453)) (-4 *3 (-558)) (-5 *1 (-970 *3 *2)) (-4 *2 (-1219 *3)))) (-2226 (*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -1880 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-2586 (*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -1880 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-1880 (*1 *2 *3 *3) (-12 (-4 *2 (-558)) (-4 *2 (-453)) (-5 *1 (-970 *2 *3)) (-4 *3 (-1219 *2)))) (-3679 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 (-763))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-1805 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 *3)) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-3560 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -2217 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-1634 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -2217 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-2217 (*1 *2 *3) (-12 (-4 *2 (-558)) (-5 *1 (-970 *2 *3)) (-4 *3 (-1219 *2)))) (-3257 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| -2721 *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-1345 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -2721 *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-2538 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -2721 *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-3809 (*1 *2 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-970 *3 *2)) (-4 *2 (-1219 *3)))) (-2437 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-1704 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-4330 (*1 *2 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-970 *3 *2)) (-4 *2 (-1219 *3)))) (-3345 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-970 *5 *3)) (-4 *3 (-1219 *5)))) (-2479 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-970 *5 *3)) (-4 *3 (-1219 *5)))) (-4377 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-558)) (-5 *1 (-970 *4 *2)) (-4 *2 (-1219 *4)))) (-2860 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-970 *5 *3)) (-4 *3 (-1219 *5)))) (-2938 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-970 *5 *3)) (-4 *3 (-1219 *5)))) (-2048 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-558)) (-5 *1 (-970 *4 *2)) (-4 *2 (-1219 *4)))) (-3265 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| -4265 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-1280 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -4265 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-1554 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -4265 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-4265 (*1 *2 *3 *3) (-12 (-4 *2 (-558)) (-5 *1 (-970 *2 *3)) (-4 *3 (-1219 *2))))) 
-(-10 -7 (-15 -4265 (|#1| |#2| |#2|)) (-15 -1554 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -4265 |#1|)) |#2| |#2|)) (-15 -1280 ((-2 (|:| |coef2| |#2|) (|:| -4265 |#1|)) |#2| |#2|)) (-15 -3265 ((-2 (|:| |coef1| |#2|) (|:| -4265 |#1|)) |#2| |#2|)) (-15 -2048 (|#2| |#2| |#2| (-763))) (-15 -2938 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763))) (-15 -2860 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763))) (-15 -4377 (|#2| |#2| |#2| (-763))) (-15 -2479 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763))) (-15 -3345 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763))) (-15 -4330 (|#2| |#2| |#2|)) (-15 -1704 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|)) (-15 -2437 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|)) (-15 -3809 (|#2| |#2| |#2|)) (-15 -2538 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -2721 |#2|)) |#2| |#2|)) (-15 -1345 ((-2 (|:| |coef2| |#2|) (|:| -2721 |#2|)) |#2| |#2|)) (-15 -3257 ((-2 (|:| |coef1| |#2|) (|:| -2721 |#2|)) |#2| |#2|)) (-15 -2217 (|#1| |#2|)) (-15 -1634 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -2217 |#1|)) |#2|)) (-15 -3560 ((-2 (|:| |coef2| |#2|) (|:| -2217 |#1|)) |#2|)) (-15 -1805 ((-634 |#2|) |#2| |#2|)) (-15 -3679 ((-634 (-763)) |#2| |#2|)) (IF (|has| |#1| (-453)) (PROGN (-15 -1880 (|#1| |#2| |#2|)) (-15 -2586 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -1880 |#1|)) |#2| |#2|)) (-15 -2226 ((-2 (|:| |coef2| |#2|) (|:| -1880 |#1|)) |#2| |#2|)) (-15 -2721 (|#2| |#2| |#2|))) |noBranch|) (-15 * ((-1244 |#2|) |#1| (-1244 |#2|))) (-15 -2595 ((-1244 |#2|) (-1244 |#2|) |#1|)) (-15 -4144 ((-2 (|:| -2348 |#1|) (|:| -3961 |#2|) (|:| -1500 |#2|)) |#2| |#2|)) (-15 -3210 ((-2 (|:| -3961 |#2|) (|:| -1500 |#2|)) |#2| |#2|)) (-15 -2211 (|#1| |#1| |#1| (-763))) (-15 -2434 (|#2| |#2| |#1| |#1| (-763))) (-15 -3366 (|#2| |#2| |#2| |#2| |#1|)) (-15 -2963 (|#1| |#2| |#2|)) (-15 -3733 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -4265 |#1|)) |#2| |#2|)) (-15 -4164 ((-2 (|:| |coef2| |#2|) (|:| -4265 |#1|)) |#2| |#2|))) 
-((-2447 (((-121) $ $) 7)) (-2436 ((|#1| $ (-568) |#1|) 14)) (-1501 (((-634 $) (-634 $) (-763)) 22) (((-634 $) (-634 $)) 21)) (-2688 (((-121) $ (-763)) 20) (((-121) $) 19)) (-3534 (($ (-634 |#1|)) 30)) (-3890 (((-634 |#1|) $) 13)) (-3340 (((-634 $) $) 26) (((-634 $) $ (-763)) 25)) (-3896 (((-634 |#1|) $) 16)) (-4487 (((-1143) $) 9)) (-4131 (((-568) $) 17)) (-2891 (((-568) $) 32)) (-3039 (($ $ (-568)) 31) (($ $) 18)) (-4022 (((-1108) $) 10)) (-2779 ((|#1| $ (-568)) 15)) (-3206 (((-917) $) 12)) (-3233 ((|#1| $) 29)) (-1458 (($ $ (-763)) 24) (($ $) 23)) (-2745 (((-850) $) 11) (((-634 |#1|) $) 28) (($ (-634 |#1|)) 27)) (-1717 (((-121) $ $) 6))) 
+((-1823 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -2723 |#2|)) |#2| |#2|) 84)) (-1736 ((|#2| |#2| |#2|) 82)) (-3628 (((-2 (|:| |coef2| |#2|) (|:| -2723 |#2|)) |#2| |#2|) 86)) (-2018 (((-2 (|:| |coef1| |#2|) (|:| -2723 |#2|)) |#2| |#2|) 88)) (-3657 (((-2 (|:| |coef2| |#2|) (|:| -2534 |#1|)) |#2| |#2|) 106 (|has| |#1| (-453)))) (-3893 (((-2 (|:| |coef2| |#2|) (|:| -2910 |#1|)) |#2| |#2|) 45)) (-1352 (((-2 (|:| |coef2| |#2|) (|:| -2910 |#1|)) |#2| |#2|) 63)) (-2039 (((-2 (|:| |coef1| |#2|) (|:| -2910 |#1|)) |#2| |#2|) 65)) (-2452 (((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|) 77)) (-4033 (((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763)) 70)) (-2849 (((-2 (|:| |coef2| |#2|) (|:| -3440 |#1|)) |#2|) 96)) (-4476 (((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763)) 73)) (-2269 (((-634 (-763)) |#2| |#2|) 81)) (-3019 ((|#1| |#2| |#2|) 41)) (-2023 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -2534 |#1|)) |#2| |#2|) 104 (|has| |#1| (-453)))) (-2534 ((|#1| |#2| |#2|) 102 (|has| |#1| (-453)))) (-2532 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -2910 |#1|)) |#2| |#2|) 43)) (-4328 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -2910 |#1|)) |#2| |#2|) 62)) (-2910 ((|#1| |#2| |#2|) 60)) (-3777 (((-2 (|:| -2350 |#1|) (|:| -4409 |#2|) (|:| -2607 |#2|)) |#2| |#2|) 35)) (-1357 ((|#2| |#2| |#2| |#2| |#1|) 52)) (-3629 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|) 75)) (-3137 ((|#2| |#2| |#2|) 74)) (-2939 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763)) 68)) (-1511 ((|#2| |#2| |#2| (-763)) 66)) (-2723 ((|#2| |#2| |#2|) 110 (|has| |#1| (-453)))) (-2597 (((-1244 |#2|) (-1244 |#2|) |#1|) 21)) (-1854 (((-2 (|:| -4409 |#2|) (|:| -2607 |#2|)) |#2| |#2|) 38)) (-3199 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -3440 |#1|)) |#2|) 94)) (-3440 ((|#1| |#2|) 91)) (-2664 (((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763)) 72)) (-1334 ((|#2| |#2| |#2| (-763)) 71)) (-2158 (((-634 |#2|) |#2| |#2|) 79)) (-2441 ((|#2| |#2| |#1| |#1| (-763)) 49)) (-3381 ((|#1| |#1| |#1| (-763)) 48)) (* (((-1244 |#2|) |#1| (-1244 |#2|)) 16))) 
+(((-970 |#1| |#2|) (-10 -7 (-15 -2910 (|#1| |#2| |#2|)) (-15 -4328 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -2910 |#1|)) |#2| |#2|)) (-15 -1352 ((-2 (|:| |coef2| |#2|) (|:| -2910 |#1|)) |#2| |#2|)) (-15 -2039 ((-2 (|:| |coef1| |#2|) (|:| -2910 |#1|)) |#2| |#2|)) (-15 -1511 (|#2| |#2| |#2| (-763))) (-15 -2939 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763))) (-15 -4033 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763))) (-15 -1334 (|#2| |#2| |#2| (-763))) (-15 -2664 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763))) (-15 -4476 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763))) (-15 -3137 (|#2| |#2| |#2|)) (-15 -3629 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|)) (-15 -2452 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|)) (-15 -1736 (|#2| |#2| |#2|)) (-15 -1823 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -2723 |#2|)) |#2| |#2|)) (-15 -3628 ((-2 (|:| |coef2| |#2|) (|:| -2723 |#2|)) |#2| |#2|)) (-15 -2018 ((-2 (|:| |coef1| |#2|) (|:| -2723 |#2|)) |#2| |#2|)) (-15 -3440 (|#1| |#2|)) (-15 -3199 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -3440 |#1|)) |#2|)) (-15 -2849 ((-2 (|:| |coef2| |#2|) (|:| -3440 |#1|)) |#2|)) (-15 -2158 ((-634 |#2|) |#2| |#2|)) (-15 -2269 ((-634 (-763)) |#2| |#2|)) (IF (|has| |#1| (-453)) (PROGN (-15 -2534 (|#1| |#2| |#2|)) (-15 -2023 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -2534 |#1|)) |#2| |#2|)) (-15 -3657 ((-2 (|:| |coef2| |#2|) (|:| -2534 |#1|)) |#2| |#2|)) (-15 -2723 (|#2| |#2| |#2|))) |noBranch|) (-15 * ((-1244 |#2|) |#1| (-1244 |#2|))) (-15 -2597 ((-1244 |#2|) (-1244 |#2|) |#1|)) (-15 -3777 ((-2 (|:| -2350 |#1|) (|:| -4409 |#2|) (|:| -2607 |#2|)) |#2| |#2|)) (-15 -1854 ((-2 (|:| -4409 |#2|) (|:| -2607 |#2|)) |#2| |#2|)) (-15 -3381 (|#1| |#1| |#1| (-763))) (-15 -2441 (|#2| |#2| |#1| |#1| (-763))) (-15 -1357 (|#2| |#2| |#2| |#2| |#1|)) (-15 -3019 (|#1| |#2| |#2|)) (-15 -2532 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -2910 |#1|)) |#2| |#2|)) (-15 -3893 ((-2 (|:| |coef2| |#2|) (|:| -2910 |#1|)) |#2| |#2|))) (-558) (-1219 |#1|)) (T -970)) 
+((-3893 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -2910 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-2532 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -2910 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-3019 (*1 *2 *3 *3) (-12 (-4 *2 (-558)) (-5 *1 (-970 *2 *3)) (-4 *3 (-1219 *2)))) (-1357 (*1 *2 *2 *2 *2 *3) (-12 (-4 *3 (-558)) (-5 *1 (-970 *3 *2)) (-4 *2 (-1219 *3)))) (-2441 (*1 *2 *2 *3 *3 *4) (-12 (-5 *4 (-763)) (-4 *3 (-558)) (-5 *1 (-970 *3 *2)) (-4 *2 (-1219 *3)))) (-3381 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *2 (-558)) (-5 *1 (-970 *2 *4)) (-4 *4 (-1219 *2)))) (-1854 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| -4409 *3) (|:| -2607 *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-3777 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| -2350 *4) (|:| -4409 *3) (|:| -2607 *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-2597 (*1 *2 *2 *3) (-12 (-5 *2 (-1244 *4)) (-4 *4 (-1219 *3)) (-4 *3 (-558)) (-5 *1 (-970 *3 *4)))) (* (*1 *2 *3 *2) (-12 (-5 *2 (-1244 *4)) (-4 *4 (-1219 *3)) (-4 *3 (-558)) (-5 *1 (-970 *3 *4)))) (-2723 (*1 *2 *2 *2) (-12 (-4 *3 (-453)) (-4 *3 (-558)) (-5 *1 (-970 *3 *2)) (-4 *2 (-1219 *3)))) (-3657 (*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -2534 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-2023 (*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -2534 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-2534 (*1 *2 *3 *3) (-12 (-4 *2 (-558)) (-4 *2 (-453)) (-5 *1 (-970 *2 *3)) (-4 *3 (-1219 *2)))) (-2269 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 (-763))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-2158 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 *3)) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-2849 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -3440 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-3199 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -3440 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-3440 (*1 *2 *3) (-12 (-4 *2 (-558)) (-5 *1 (-970 *2 *3)) (-4 *3 (-1219 *2)))) (-2018 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| -2723 *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-3628 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -2723 *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-1823 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -2723 *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-1736 (*1 *2 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-970 *3 *2)) (-4 *2 (-1219 *3)))) (-2452 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-3629 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-3137 (*1 *2 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-970 *3 *2)) (-4 *2 (-1219 *3)))) (-4476 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-970 *5 *3)) (-4 *3 (-1219 *5)))) (-2664 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-970 *5 *3)) (-4 *3 (-1219 *5)))) (-1334 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-558)) (-5 *1 (-970 *4 *2)) (-4 *2 (-1219 *4)))) (-4033 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-970 *5 *3)) (-4 *3 (-1219 *5)))) (-2939 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-970 *5 *3)) (-4 *3 (-1219 *5)))) (-1511 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-558)) (-5 *1 (-970 *4 *2)) (-4 *2 (-1219 *4)))) (-2039 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| -2910 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-1352 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -2910 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-4328 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -2910 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) (-2910 (*1 *2 *3 *3) (-12 (-4 *2 (-558)) (-5 *1 (-970 *2 *3)) (-4 *3 (-1219 *2))))) 
+(-10 -7 (-15 -2910 (|#1| |#2| |#2|)) (-15 -4328 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -2910 |#1|)) |#2| |#2|)) (-15 -1352 ((-2 (|:| |coef2| |#2|) (|:| -2910 |#1|)) |#2| |#2|)) (-15 -2039 ((-2 (|:| |coef1| |#2|) (|:| -2910 |#1|)) |#2| |#2|)) (-15 -1511 (|#2| |#2| |#2| (-763))) (-15 -2939 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763))) (-15 -4033 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763))) (-15 -1334 (|#2| |#2| |#2| (-763))) (-15 -2664 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763))) (-15 -4476 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2| (-763))) (-15 -3137 (|#2| |#2| |#2|)) (-15 -3629 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|)) (-15 -2452 ((-2 (|:| |coef2| |#2|) (|:| |subResultant| |#2|)) |#2| |#2|)) (-15 -1736 (|#2| |#2| |#2|)) (-15 -1823 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -2723 |#2|)) |#2| |#2|)) (-15 -3628 ((-2 (|:| |coef2| |#2|) (|:| -2723 |#2|)) |#2| |#2|)) (-15 -2018 ((-2 (|:| |coef1| |#2|) (|:| -2723 |#2|)) |#2| |#2|)) (-15 -3440 (|#1| |#2|)) (-15 -3199 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -3440 |#1|)) |#2|)) (-15 -2849 ((-2 (|:| |coef2| |#2|) (|:| -3440 |#1|)) |#2|)) (-15 -2158 ((-634 |#2|) |#2| |#2|)) (-15 -2269 ((-634 (-763)) |#2| |#2|)) (IF (|has| |#1| (-453)) (PROGN (-15 -2534 (|#1| |#2| |#2|)) (-15 -2023 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -2534 |#1|)) |#2| |#2|)) (-15 -3657 ((-2 (|:| |coef2| |#2|) (|:| -2534 |#1|)) |#2| |#2|)) (-15 -2723 (|#2| |#2| |#2|))) |noBranch|) (-15 * ((-1244 |#2|) |#1| (-1244 |#2|))) (-15 -2597 ((-1244 |#2|) (-1244 |#2|) |#1|)) (-15 -3777 ((-2 (|:| -2350 |#1|) (|:| -4409 |#2|) (|:| -2607 |#2|)) |#2| |#2|)) (-15 -1854 ((-2 (|:| -4409 |#2|) (|:| -2607 |#2|)) |#2| |#2|)) (-15 -3381 (|#1| |#1| |#1| (-763))) (-15 -2441 (|#2| |#2| |#1| |#1| (-763))) (-15 -1357 (|#2| |#2| |#2| |#2| |#1|)) (-15 -3019 (|#1| |#2| |#2|)) (-15 -2532 ((-2 (|:| |coef1| |#2|) (|:| |coef2| |#2|) (|:| -2910 |#1|)) |#2| |#2|)) (-15 -3893 ((-2 (|:| |coef2| |#2|) (|:| -2910 |#1|)) |#2| |#2|))) 
+((-2449 (((-121) $ $) 7)) (-2438 ((|#1| $ (-568) |#1|) 14)) (-2613 (((-634 $) (-634 $) (-763)) 22) (((-634 $) (-634 $)) 21)) (-1338 (((-121) $ (-763)) 20) (((-121) $) 19)) (-4154 (($ (-634 |#1|)) 30)) (-2034 (((-634 |#1|) $) 13)) (-4450 (((-634 $) $) 26) (((-634 $) $ (-763)) 25)) (-3897 (((-634 |#1|) $) 16)) (-1893 (((-1143) $) 9)) (-3709 (((-568) $) 17)) (-2794 (((-568) $) 32)) (-2219 (($ $ (-568)) 31) (($ $) 18)) (-4025 (((-1108) $) 10)) (-2781 ((|#1| $ (-568)) 15)) (-1836 (((-917) $) 12)) (-1937 ((|#1| $) 29)) (-2387 (($ $ (-763)) 24) (($ $) 23)) (-2747 (((-850) $) 11) (((-634 |#1|) $) 28) (($ (-634 |#1|)) 27)) (-1719 (((-121) $ $) 6))) 
 (((-971 |#1|) (-1275) (-365)) (T -971)) 
-((-2891 (*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-568)))) (-3039 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-971 *3)) (-4 *3 (-365)))) (-3534 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-4 *1 (-971 *3)))) (-3233 (*1 *2 *1) (-12 (-4 *1 (-971 *2)) (-4 *2 (-365)))) (-2745 (*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-634 *3)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-4 *1 (-971 *3)))) (-3340 (*1 *2 *1) (-12 (-4 *3 (-365)) (-5 *2 (-634 *1)) (-4 *1 (-971 *3)))) (-3340 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *4 (-365)) (-5 *2 (-634 *1)) (-4 *1 (-971 *4)))) (-1458 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-971 *3)) (-4 *3 (-365)))) (-1458 (*1 *1 *1) (-12 (-4 *1 (-971 *2)) (-4 *2 (-365)))) (-1501 (*1 *2 *2 *3) (-12 (-5 *2 (-634 *1)) (-5 *3 (-763)) (-4 *1 (-971 *4)) (-4 *4 (-365)))) (-1501 (*1 *2 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-971 *3)) (-4 *3 (-365)))) (-2688 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-971 *4)) (-4 *4 (-365)) (-5 *2 (-121)))) (-2688 (*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-121)))) (-3039 (*1 *1 *1) (-12 (-4 *1 (-971 *2)) (-4 *2 (-365)))) (-4131 (*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-568)))) (-3896 (*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-634 *3)))) (-2779 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-971 *2)) (-4 *2 (-365)))) (-2436 (*1 *2 *1 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-971 *2)) (-4 *2 (-365)))) (-3890 (*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-634 *3))))) 
-(-13 (-1088) (-10 -8 (-15 -2891 ((-568) $)) (-15 -3039 ($ $ (-568))) (-15 -3534 ($ (-634 |t#1|))) (-15 -3233 (|t#1| $)) (-15 -2745 ((-634 |t#1|) $)) (-15 -2745 ($ (-634 |t#1|))) (-15 -3340 ((-634 $) $)) (-15 -3340 ((-634 $) $ (-763))) (-15 -1458 ($ $ (-763))) (-15 -1458 ($ $)) (-15 -1501 ((-634 $) (-634 $) (-763))) (-15 -1501 ((-634 $) (-634 $))) (-15 -2688 ((-121) $ (-763))) (-15 -2688 ((-121) $)) (-15 -3039 ($ $)) (-15 -4131 ((-568) $)) (-15 -3896 ((-634 |t#1|) $)) (-15 -2779 (|t#1| $ (-568))) (-15 -2436 (|t#1| $ (-568) |t#1|)) (-15 -3890 ((-634 |t#1|) $)))) 
+((-2794 (*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-568)))) (-2219 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-971 *3)) (-4 *3 (-365)))) (-4154 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-4 *1 (-971 *3)))) (-1937 (*1 *2 *1) (-12 (-4 *1 (-971 *2)) (-4 *2 (-365)))) (-2747 (*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-634 *3)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-4 *1 (-971 *3)))) (-4450 (*1 *2 *1) (-12 (-4 *3 (-365)) (-5 *2 (-634 *1)) (-4 *1 (-971 *3)))) (-4450 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *4 (-365)) (-5 *2 (-634 *1)) (-4 *1 (-971 *4)))) (-2387 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-971 *3)) (-4 *3 (-365)))) (-2387 (*1 *1 *1) (-12 (-4 *1 (-971 *2)) (-4 *2 (-365)))) (-2613 (*1 *2 *2 *3) (-12 (-5 *2 (-634 *1)) (-5 *3 (-763)) (-4 *1 (-971 *4)) (-4 *4 (-365)))) (-2613 (*1 *2 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-971 *3)) (-4 *3 (-365)))) (-1338 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-971 *4)) (-4 *4 (-365)) (-5 *2 (-121)))) (-1338 (*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-121)))) (-2219 (*1 *1 *1) (-12 (-4 *1 (-971 *2)) (-4 *2 (-365)))) (-3709 (*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-568)))) (-3897 (*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-634 *3)))) (-2781 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-971 *2)) (-4 *2 (-365)))) (-2438 (*1 *2 *1 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-971 *2)) (-4 *2 (-365)))) (-2034 (*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-634 *3))))) 
+(-13 (-1088) (-10 -8 (-15 -2794 ((-568) $)) (-15 -2219 ($ $ (-568))) (-15 -4154 ($ (-634 |t#1|))) (-15 -1937 (|t#1| $)) (-15 -2747 ((-634 |t#1|) $)) (-15 -2747 ($ (-634 |t#1|))) (-15 -4450 ((-634 $) $)) (-15 -4450 ((-634 $) $ (-763))) (-15 -2387 ($ $ (-763))) (-15 -2387 ($ $)) (-15 -2613 ((-634 $) (-634 $) (-763))) (-15 -2613 ((-634 $) (-634 $))) (-15 -1338 ((-121) $ (-763))) (-15 -1338 ((-121) $)) (-15 -2219 ($ $)) (-15 -3709 ((-568) $)) (-15 -3897 ((-634 |t#1|) $)) (-15 -2781 (|t#1| $ (-568))) (-15 -2438 (|t#1| $ (-568) |t#1|)) (-15 -2034 ((-634 |t#1|) $)))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T) ((-1088) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) 26)) (-2671 (($) NIL T CONST)) (-3590 (((-634 (-634 (-568))) (-634 (-568))) 28)) (-3665 (((-568) $) 44)) (-4473 (($ (-634 (-568))) 17)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-4278 (((-634 (-568)) $) 11)) (-1458 (($ $) 31)) (-2745 (((-850) $) 42) (((-634 (-568)) $) 9)) (-3056 (($) 7 T CONST)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 19)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 18)) (-1767 (($ $ $) 20)) (* (($ (-763) $) 24) (($ (-917) $) NIL))) 
-(((-972) (-13 (-790) (-609 (-634 (-568))) (-10 -8 (-15 -4473 ($ (-634 (-568)))) (-15 -3590 ((-634 (-634 (-568))) (-634 (-568)))) (-15 -3665 ((-568) $)) (-15 -1458 ($ $)) (-15 -2745 ((-634 (-568)) $))))) (T -972)) 
-((-4473 (*1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-972)))) (-3590 (*1 *2 *3) (-12 (-5 *2 (-634 (-634 (-568)))) (-5 *1 (-972)) (-5 *3 (-634 (-568))))) (-3665 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-972)))) (-1458 (*1 *1 *1) (-5 *1 (-972))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-972))))) 
-(-13 (-790) (-609 (-634 (-568))) (-10 -8 (-15 -4473 ($ (-634 (-568)))) (-15 -3590 ((-634 (-634 (-568))) (-634 (-568)))) (-15 -3665 ((-568) $)) (-15 -1458 ($ $)) (-15 -2745 ((-634 (-568)) $)))) 
-((-1779 (($ $ |#2|) 30)) (-1773 (($ $) 22) (($ $ $) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 15) (($ $ $) NIL) (($ $ |#2|) 20) (($ |#2| $) 19) (($ (-409 (-568)) $) 26) (($ $ (-409 (-568))) 28))) 
-(((-973 |#1| |#2| |#3| |#4|) (-10 -8 (-15 * (|#1| |#1| (-409 (-568)))) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 -1779 (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 -1773 (|#1| |#1| |#1|)) (-15 -1773 (|#1| |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|))) (-974 |#2| |#3| |#4|) (-1047) (-787) (-842)) (T -973)) 
-NIL 
-(-10 -8 (-15 * (|#1| |#1| (-409 (-568)))) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 -1779 (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 -1773 (|#1| |#1| |#1|)) (-15 -1773 (|#1| |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-2055 (((-634 |#3|) $) 70)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 50 (|has| |#1| (-558)))) (-2227 (($ $) 51 (|has| |#1| (-558)))) (-1573 (((-121) $) 53 (|has| |#1| (-558)))) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-2114 (($ $) 59)) (-2925 (((-3 $ "failed") $) 33)) (-3992 (((-121) $) 69)) (-2735 (((-121) $) 30)) (-3921 (((-121) $) 61)) (-2047 (($ |#1| |#2|) 60) (($ $ |#3| |#2|) 72) (($ $ (-634 |#3|) (-634 |#2|)) 71)) (-2795 (($ (-1 |#1| |#1|) $) 62)) (-2097 (($ $) 64)) (-2102 ((|#1| $) 65)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2595 (((-3 $ "failed") $ $) 49 (|has| |#1| (-558)))) (-3206 ((|#2| $) 63)) (-1811 (($ $) 68)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ (-409 (-568))) 56 (|has| |#1| (-43 (-409 (-568))))) (($ $) 48 (|has| |#1| (-558))) (($ |#1|) 46 (|has| |#1| (-172)))) (-2604 ((|#1| $ |#2|) 58)) (-4371 (((-3 $ "failed") $) 47 (|has| |#1| (-148)))) (-4078 (((-763)) 28)) (-1826 (((-121) $ $) 52 (|has| |#1| (-558)))) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1779 (($ $ |#1|) 57 (|has| |#1| (-365)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-409 (-568)) $) 55 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 54 (|has| |#1| (-43 (-409 (-568))))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) 26)) (-4490 (($) NIL T CONST)) (-2960 (((-634 (-634 (-568))) (-634 (-568))) 28)) (-2220 (((-568) $) 44)) (-1829 (($ (-634 (-568))) 17)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-4280 (((-634 (-568)) $) 11)) (-2387 (($ $) 31)) (-2747 (((-850) $) 42) (((-634 (-568)) $) 9)) (-3058 (($) 7 T CONST)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 19)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 18)) (-1769 (($ $ $) 20)) (* (($ (-763) $) 24) (($ (-917) $) NIL))) 
+(((-972) (-13 (-790) (-609 (-634 (-568))) (-10 -8 (-15 -1829 ($ (-634 (-568)))) (-15 -2960 ((-634 (-634 (-568))) (-634 (-568)))) (-15 -2220 ((-568) $)) (-15 -2387 ($ $)) (-15 -2747 ((-634 (-568)) $))))) (T -972)) 
+((-1829 (*1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-972)))) (-2960 (*1 *2 *3) (-12 (-5 *2 (-634 (-634 (-568)))) (-5 *1 (-972)) (-5 *3 (-634 (-568))))) (-2220 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-972)))) (-2387 (*1 *1 *1) (-5 *1 (-972))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-972))))) 
+(-13 (-790) (-609 (-634 (-568))) (-10 -8 (-15 -1829 ($ (-634 (-568)))) (-15 -2960 ((-634 (-634 (-568))) (-634 (-568)))) (-15 -2220 ((-568) $)) (-15 -2387 ($ $)) (-15 -2747 ((-634 (-568)) $)))) 
+((-1781 (($ $ |#2|) 30)) (-1775 (($ $) 22) (($ $ $) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 15) (($ $ $) NIL) (($ $ |#2|) 20) (($ |#2| $) 19) (($ (-409 (-568)) $) 26) (($ $ (-409 (-568))) 28))) 
+(((-973 |#1| |#2| |#3| |#4|) (-10 -8 (-15 * (|#1| |#1| (-409 (-568)))) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 -1781 (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 -1775 (|#1| |#1| |#1|)) (-15 -1775 (|#1| |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|))) (-974 |#2| |#3| |#4|) (-1047) (-787) (-842)) (T -973)) 
+NIL 
+(-10 -8 (-15 * (|#1| |#1| (-409 (-568)))) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 -1781 (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 -1775 (|#1| |#1| |#1|)) (-15 -1775 (|#1| |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 * (|#1| (-917) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2057 (((-634 |#3|) $) 70)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 50 (|has| |#1| (-558)))) (-3661 (($ $) 51 (|has| |#1| (-558)))) (-4426 (((-121) $) 53 (|has| |#1| (-558)))) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-2116 (($ $) 59)) (-2902 (((-3 $ "failed") $) 33)) (-1302 (((-121) $) 69)) (-1598 (((-121) $) 30)) (-2171 (((-121) $) 61)) (-2049 (($ |#1| |#2|) 60) (($ $ |#3| |#2|) 72) (($ $ (-634 |#3|) (-634 |#2|)) 71)) (-2797 (($ (-1 |#1| |#1|) $) 62)) (-2099 (($ $) 64)) (-2104 ((|#1| $) 65)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2597 (((-3 $ "failed") $ $) 49 (|has| |#1| (-558)))) (-1836 ((|#2| $) 63)) (-2188 (($ $) 68)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ (-409 (-568))) 56 (|has| |#1| (-43 (-409 (-568))))) (($ $) 48 (|has| |#1| (-558))) (($ |#1|) 46 (|has| |#1| (-172)))) (-2079 ((|#1| $ |#2|) 58)) (-3385 (((-3 $ "failed") $) 47 (|has| |#1| (-148)))) (-3425 (((-763)) 28)) (-2273 (((-121) $ $) 52 (|has| |#1| (-558)))) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1781 (($ $ |#1|) 57 (|has| |#1| (-365)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-409 (-568)) $) 55 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 54 (|has| |#1| (-43 (-409 (-568))))))) 
 (((-974 |#1| |#2| |#3|) (-1275) (-1047) (-787) (-842)) (T -974)) 
-((-2102 (*1 *2 *1) (-12 (-4 *1 (-974 *2 *3 *4)) (-4 *3 (-787)) (-4 *4 (-842)) (-4 *2 (-1047)))) (-2097 (*1 *1 *1) (-12 (-4 *1 (-974 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-787)) (-4 *4 (-842)))) (-3206 (*1 *2 *1) (-12 (-4 *1 (-974 *3 *2 *4)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *2 (-787)))) (-2047 (*1 *1 *1 *2 *3) (-12 (-4 *1 (-974 *4 *3 *2)) (-4 *4 (-1047)) (-4 *3 (-787)) (-4 *2 (-842)))) (-2047 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *6)) (-5 *3 (-634 *5)) (-4 *1 (-974 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-787)) (-4 *6 (-842)))) (-2055 (*1 *2 *1) (-12 (-4 *1 (-974 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-787)) (-4 *5 (-842)) (-5 *2 (-634 *5)))) (-3992 (*1 *2 *1) (-12 (-4 *1 (-974 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-787)) (-4 *5 (-842)) (-5 *2 (-121)))) (-1811 (*1 *1 *1) (-12 (-4 *1 (-974 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-787)) (-4 *4 (-842))))) 
-(-13 (-52 |t#1| |t#2|) (-10 -8 (-15 -2047 ($ $ |t#3| |t#2|)) (-15 -2047 ($ $ (-634 |t#3|) (-634 |t#2|))) (-15 -2097 ($ $)) (-15 -2102 (|t#1| $)) (-15 -3206 (|t#2| $)) (-15 -2055 ((-634 |t#3|) $)) (-15 -3992 ((-121) $)) (-15 -1811 ($ $)))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| |#2|) . T) ((-25) . T) ((-43 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) |has| |#1| (-558)) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2198 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2198 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-285) |has| |#1| (-558)) ((-558) |has| |#1| (-558)) ((-637 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) |has| |#1| (-558)) ((-716) . T) ((-1053 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-1053 |#1|) . T) ((-1053 $) -2198 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-2514 (((-1084 (-215)) $) 7)) (-4017 (((-1084 (-215)) $) 8)) (-1351 (((-1084 (-215)) $) 9)) (-2550 (((-634 (-634 (-944 (-215)))) $) 10)) (-2745 (((-850) $) 6))) 
+((-2104 (*1 *2 *1) (-12 (-4 *1 (-974 *2 *3 *4)) (-4 *3 (-787)) (-4 *4 (-842)) (-4 *2 (-1047)))) (-2099 (*1 *1 *1) (-12 (-4 *1 (-974 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-787)) (-4 *4 (-842)))) (-1836 (*1 *2 *1) (-12 (-4 *1 (-974 *3 *2 *4)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *2 (-787)))) (-2049 (*1 *1 *1 *2 *3) (-12 (-4 *1 (-974 *4 *3 *2)) (-4 *4 (-1047)) (-4 *3 (-787)) (-4 *2 (-842)))) (-2049 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *6)) (-5 *3 (-634 *5)) (-4 *1 (-974 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-787)) (-4 *6 (-842)))) (-2057 (*1 *2 *1) (-12 (-4 *1 (-974 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-787)) (-4 *5 (-842)) (-5 *2 (-634 *5)))) (-1302 (*1 *2 *1) (-12 (-4 *1 (-974 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-787)) (-4 *5 (-842)) (-5 *2 (-121)))) (-2188 (*1 *1 *1) (-12 (-4 *1 (-974 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-787)) (-4 *4 (-842))))) 
+(-13 (-52 |t#1| |t#2|) (-10 -8 (-15 -2049 ($ $ |t#3| |t#2|)) (-15 -2049 ($ $ (-634 |t#3|) (-634 |t#2|))) (-15 -2099 ($ $)) (-15 -2104 (|t#1| $)) (-15 -1836 (|t#2| $)) (-15 -2057 ((-634 |t#3|) $)) (-15 -1302 ((-121) $)) (-15 -2188 ($ $)))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| |#2|) . T) ((-25) . T) ((-43 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) |has| |#1| (-558)) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2199 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2199 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-285) |has| |#1| (-558)) ((-558) |has| |#1| (-558)) ((-637 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) |has| |#1| (-558)) ((-716) . T) ((-1053 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-1053 |#1|) . T) ((-1053 $) -2199 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
+((-1689 (((-1084 (-215)) $) 7)) (-1421 (((-1084 (-215)) $) 8)) (-3679 (((-1084 (-215)) $) 9)) (-1878 (((-634 (-634 (-944 (-215)))) $) 10)) (-2747 (((-850) $) 6))) 
 (((-975) (-1275)) (T -975)) 
-((-2550 (*1 *2 *1) (-12 (-4 *1 (-975)) (-5 *2 (-634 (-634 (-944 (-215))))))) (-1351 (*1 *2 *1) (-12 (-4 *1 (-975)) (-5 *2 (-1084 (-215))))) (-4017 (*1 *2 *1) (-12 (-4 *1 (-975)) (-5 *2 (-1084 (-215))))) (-2514 (*1 *2 *1) (-12 (-4 *1 (-975)) (-5 *2 (-1084 (-215)))))) 
-(-13 (-608 (-850)) (-10 -8 (-15 -2550 ((-634 (-634 (-944 (-215)))) $)) (-15 -1351 ((-1084 (-215)) $)) (-15 -4017 ((-1084 (-215)) $)) (-15 -2514 ((-1084 (-215)) $)))) 
+((-1878 (*1 *2 *1) (-12 (-4 *1 (-975)) (-5 *2 (-634 (-634 (-944 (-215))))))) (-3679 (*1 *2 *1) (-12 (-4 *1 (-975)) (-5 *2 (-1084 (-215))))) (-1421 (*1 *2 *1) (-12 (-4 *1 (-975)) (-5 *2 (-1084 (-215))))) (-1689 (*1 *2 *1) (-12 (-4 *1 (-975)) (-5 *2 (-1084 (-215)))))) 
+(-13 (-608 (-850)) (-10 -8 (-15 -1878 ((-634 (-634 (-944 (-215)))) $)) (-15 -3679 ((-1084 (-215)) $)) (-15 -1421 ((-1084 (-215)) $)) (-15 -1689 ((-1084 (-215)) $)))) 
 (((-608 (-850)) . T)) 
-((-2055 (((-634 |#4|) $) 23)) (-4211 (((-121) $) 47)) (-3824 (((-121) $) 46)) (-3644 (((-2 (|:| |under| $) (|:| -1519 $) (|:| |upper| $)) $ |#4|) 35)) (-1565 (((-121) $) 48)) (-3846 (((-121) $ $) 54)) (-3106 (((-121) $ $) 57)) (-3695 (((-121) $) 52)) (-2355 (((-634 |#5|) (-634 |#5|) $) 89)) (-2492 (((-634 |#5|) (-634 |#5|) $) 86)) (-1500 (((-2 (|:| |rnum| |#2|) (|:| |polnum| |#5|) (|:| |den| |#2|)) |#5| $) 80)) (-1432 (((-634 |#4|) $) 27)) (-3392 (((-121) |#4| $) 29)) (-2705 (((-2 (|:| |num| |#5|) (|:| |den| |#2|)) |#5| $) 72)) (-1290 (($ $ |#4|) 32)) (-3732 (($ $ |#4|) 31)) (-3944 (($ $ |#4|) 33)) (-1717 (((-121) $ $) 39))) 
-(((-976 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 -3824 ((-121) |#1|)) (-15 -2355 ((-634 |#5|) (-634 |#5|) |#1|)) (-15 -2492 ((-634 |#5|) (-634 |#5|) |#1|)) (-15 -1500 ((-2 (|:| |rnum| |#2|) (|:| |polnum| |#5|) (|:| |den| |#2|)) |#5| |#1|)) (-15 -2705 ((-2 (|:| |num| |#5|) (|:| |den| |#2|)) |#5| |#1|)) (-15 -1565 ((-121) |#1|)) (-15 -3106 ((-121) |#1| |#1|)) (-15 -3846 ((-121) |#1| |#1|)) (-15 -3695 ((-121) |#1|)) (-15 -4211 ((-121) |#1|)) (-15 -3644 ((-2 (|:| |under| |#1|) (|:| -1519 |#1|) (|:| |upper| |#1|)) |#1| |#4|)) (-15 -1290 (|#1| |#1| |#4|)) (-15 -3944 (|#1| |#1| |#4|)) (-15 -3732 (|#1| |#1| |#4|)) (-15 -3392 ((-121) |#4| |#1|)) (-15 -1432 ((-634 |#4|) |#1|)) (-15 -2055 ((-634 |#4|) |#1|)) (-15 -1717 ((-121) |#1| |#1|))) (-977 |#2| |#3| |#4| |#5|) (-1047) (-788) (-842) (-1061 |#2| |#3| |#4|)) (T -976)) 
+((-2057 (((-634 |#4|) $) 23)) (-4141 (((-121) $) 47)) (-1794 (((-121) $) 46)) (-3647 (((-2 (|:| |under| $) (|:| -4115 $) (|:| |upper| $)) $ |#4|) 35)) (-4382 (((-121) $) 48)) (-1880 (((-121) $ $) 54)) (-2536 (((-121) $ $) 57)) (-2343 (((-121) $) 52)) (-3993 (((-634 |#5|) (-634 |#5|) $) 89)) (-2727 (((-634 |#5|) (-634 |#5|) $) 86)) (-2607 (((-2 (|:| |rnum| |#2|) (|:| |polnum| |#5|) (|:| |den| |#2|)) |#5| $) 80)) (-2249 (((-634 |#4|) $) 27)) (-1495 (((-121) |#4| $) 29)) (-1440 (((-2 (|:| |num| |#5|) (|:| |den| |#2|)) |#5| $) 72)) (-3206 (($ $ |#4|) 32)) (-2527 (($ $ |#4|) 31)) (-4332 (($ $ |#4|) 33)) (-1719 (((-121) $ $) 39))) 
+(((-976 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 -1794 ((-121) |#1|)) (-15 -3993 ((-634 |#5|) (-634 |#5|) |#1|)) (-15 -2727 ((-634 |#5|) (-634 |#5|) |#1|)) (-15 -2607 ((-2 (|:| |rnum| |#2|) (|:| |polnum| |#5|) (|:| |den| |#2|)) |#5| |#1|)) (-15 -1440 ((-2 (|:| |num| |#5|) (|:| |den| |#2|)) |#5| |#1|)) (-15 -4382 ((-121) |#1|)) (-15 -2536 ((-121) |#1| |#1|)) (-15 -1880 ((-121) |#1| |#1|)) (-15 -2343 ((-121) |#1|)) (-15 -4141 ((-121) |#1|)) (-15 -3647 ((-2 (|:| |under| |#1|) (|:| -4115 |#1|) (|:| |upper| |#1|)) |#1| |#4|)) (-15 -3206 (|#1| |#1| |#4|)) (-15 -4332 (|#1| |#1| |#4|)) (-15 -2527 (|#1| |#1| |#4|)) (-15 -1495 ((-121) |#4| |#1|)) (-15 -2249 ((-634 |#4|) |#1|)) (-15 -2057 ((-634 |#4|) |#1|)) (-15 -1719 ((-121) |#1| |#1|))) (-977 |#2| |#3| |#4| |#5|) (-1047) (-788) (-842) (-1061 |#2| |#3| |#4|)) (T -976)) 
 NIL 
-(-10 -8 (-15 -3824 ((-121) |#1|)) (-15 -2355 ((-634 |#5|) (-634 |#5|) |#1|)) (-15 -2492 ((-634 |#5|) (-634 |#5|) |#1|)) (-15 -1500 ((-2 (|:| |rnum| |#2|) (|:| |polnum| |#5|) (|:| |den| |#2|)) |#5| |#1|)) (-15 -2705 ((-2 (|:| |num| |#5|) (|:| |den| |#2|)) |#5| |#1|)) (-15 -1565 ((-121) |#1|)) (-15 -3106 ((-121) |#1| |#1|)) (-15 -3846 ((-121) |#1| |#1|)) (-15 -3695 ((-121) |#1|)) (-15 -4211 ((-121) |#1|)) (-15 -3644 ((-2 (|:| |under| |#1|) (|:| -1519 |#1|) (|:| |upper| |#1|)) |#1| |#4|)) (-15 -1290 (|#1| |#1| |#4|)) (-15 -3944 (|#1| |#1| |#4|)) (-15 -3732 (|#1| |#1| |#4|)) (-15 -3392 ((-121) |#4| |#1|)) (-15 -1432 ((-634 |#4|) |#1|)) (-15 -2055 ((-634 |#4|) |#1|)) (-15 -1717 ((-121) |#1| |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2055 (((-634 |#3|) $) 32)) (-4211 (((-121) $) 25)) (-3824 (((-121) $) 16 (|has| |#1| (-558)))) (-3644 (((-2 (|:| |under| $) (|:| -1519 $) (|:| |upper| $)) $ |#3|) 26)) (-2510 (((-121) $ (-763)) 43)) (-2801 (($ (-1 (-121) |#4|) $) 64 (|has| $ (-6 -4519)))) (-2671 (($) 44 T CONST)) (-1565 (((-121) $) 21 (|has| |#1| (-558)))) (-3846 (((-121) $ $) 23 (|has| |#1| (-558)))) (-3106 (((-121) $ $) 22 (|has| |#1| (-558)))) (-3695 (((-121) $) 24 (|has| |#1| (-558)))) (-2355 (((-634 |#4|) (-634 |#4|) $) 17 (|has| |#1| (-558)))) (-2492 (((-634 |#4|) (-634 |#4|) $) 18 (|has| |#1| (-558)))) (-3666 (((-3 $ "failed") (-634 |#4|)) 35)) (-2854 (($ (-634 |#4|)) 34)) (-3924 (($ $) 67 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519))))) (-4328 (($ |#4| $) 66 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) |#4|) $) 63 (|has| $ (-6 -4519)))) (-1500 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-558)))) (-3092 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4519))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4519)))) (-4360 (((-634 |#4|) $) 51 (|has| $ (-6 -4519)))) (-2356 ((|#3| $) 33)) (-1737 (((-121) $ (-763)) 42)) (-1979 (((-634 |#4|) $) 52 (|has| $ (-6 -4519)))) (-3109 (((-121) |#4| $) 54 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#4| |#4|) $) 46)) (-1432 (((-634 |#3|) $) 31)) (-3392 (((-121) |#3| $) 30)) (-2166 (((-121) $ (-763)) 41)) (-4487 (((-1143) $) 9)) (-2705 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-558)))) (-4022 (((-1108) $) 10)) (-3775 (((-3 |#4| "failed") (-1 (-121) |#4|) $) 60)) (-1387 (((-121) (-1 (-121) |#4|) $) 49 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 |#4|) (-634 |#4|)) 58 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) 56 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 (-288 |#4|))) 55 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-3171 (((-121) $ $) 37)) (-3084 (((-121) $) 40)) (-3248 (($) 39)) (-4168 (((-763) |#4| $) 53 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519)))) (((-763) (-1 (-121) |#4|) $) 50 (|has| $ (-6 -4519)))) (-3863 (($ $) 38)) (-4278 (((-541) $) 68 (|has| |#4| (-609 (-541))))) (-4287 (($ (-634 |#4|)) 59)) (-1290 (($ $ |#3|) 27)) (-3732 (($ $ |#3|) 29)) (-3944 (($ $ |#3|) 28)) (-2745 (((-850) $) 11) (((-634 |#4|) $) 36)) (-1319 (((-121) (-1 (-121) |#4|) $) 48 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 6)) (-1697 (((-763) $) 45 (|has| $ (-6 -4519))))) 
+(-10 -8 (-15 -1794 ((-121) |#1|)) (-15 -3993 ((-634 |#5|) (-634 |#5|) |#1|)) (-15 -2727 ((-634 |#5|) (-634 |#5|) |#1|)) (-15 -2607 ((-2 (|:| |rnum| |#2|) (|:| |polnum| |#5|) (|:| |den| |#2|)) |#5| |#1|)) (-15 -1440 ((-2 (|:| |num| |#5|) (|:| |den| |#2|)) |#5| |#1|)) (-15 -4382 ((-121) |#1|)) (-15 -2536 ((-121) |#1| |#1|)) (-15 -1880 ((-121) |#1| |#1|)) (-15 -2343 ((-121) |#1|)) (-15 -4141 ((-121) |#1|)) (-15 -3647 ((-2 (|:| |under| |#1|) (|:| -4115 |#1|) (|:| |upper| |#1|)) |#1| |#4|)) (-15 -3206 (|#1| |#1| |#4|)) (-15 -4332 (|#1| |#1| |#4|)) (-15 -2527 (|#1| |#1| |#4|)) (-15 -1495 ((-121) |#4| |#1|)) (-15 -2249 ((-634 |#4|) |#1|)) (-15 -2057 ((-634 |#4|) |#1|)) (-15 -1719 ((-121) |#1| |#1|))) 
+((-2449 (((-121) $ $) 7)) (-2057 (((-634 |#3|) $) 32)) (-4141 (((-121) $) 25)) (-1794 (((-121) $) 16 (|has| |#1| (-558)))) (-3647 (((-2 (|:| |under| $) (|:| -4115 $) (|:| |upper| $)) $ |#3|) 26)) (-1667 (((-121) $ (-763)) 43)) (-2803 (($ (-1 (-121) |#4|) $) 64 (|has| $ (-6 -4521)))) (-4490 (($) 44 T CONST)) (-4382 (((-121) $) 21 (|has| |#1| (-558)))) (-1880 (((-121) $ $) 23 (|has| |#1| (-558)))) (-2536 (((-121) $ $) 22 (|has| |#1| (-558)))) (-2343 (((-121) $) 24 (|has| |#1| (-558)))) (-3993 (((-634 |#4|) (-634 |#4|) $) 17 (|has| |#1| (-558)))) (-2727 (((-634 |#4|) (-634 |#4|) $) 18 (|has| |#1| (-558)))) (-3668 (((-3 $ "failed") (-634 |#4|)) 35)) (-2857 (($ (-634 |#4|)) 34)) (-3926 (($ $) 67 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521))))) (-4330 (($ |#4| $) 66 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) |#4|) $) 63 (|has| $ (-6 -4521)))) (-2607 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-558)))) (-3094 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4521))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4521)))) (-3317 (((-634 |#4|) $) 51 (|has| $ (-6 -4521)))) (-4001 ((|#3| $) 33)) (-3791 (((-121) $ (-763)) 42)) (-4406 (((-634 |#4|) $) 52 (|has| $ (-6 -4521)))) (-2551 (((-121) |#4| $) 54 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#4| |#4|) $) 46)) (-2249 (((-634 |#3|) $) 31)) (-1495 (((-121) |#3| $) 30)) (-3796 (((-121) $ (-763)) 41)) (-1893 (((-1143) $) 9)) (-1440 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-558)))) (-4025 (((-1108) $) 10)) (-2712 (((-3 |#4| "failed") (-1 (-121) |#4|) $) 60)) (-3951 (((-121) (-1 (-121) |#4|) $) 49 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 |#4|) (-634 |#4|)) 58 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) 56 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 (-288 |#4|))) 55 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-1702 (((-121) $ $) 37)) (-2436 (((-121) $) 40)) (-1990 (($) 39)) (-4170 (((-763) |#4| $) 53 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521)))) (((-763) (-1 (-121) |#4|) $) 50 (|has| $ (-6 -4521)))) (-3865 (($ $) 38)) (-4280 (((-541) $) 68 (|has| |#4| (-609 (-541))))) (-4289 (($ (-634 |#4|)) 59)) (-3206 (($ $ |#3|) 27)) (-2527 (($ $ |#3|) 29)) (-4332 (($ $ |#3|) 28)) (-2747 (((-850) $) 11) (((-634 |#4|) $) 36)) (-3437 (((-121) (-1 (-121) |#4|) $) 48 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 6)) (-1699 (((-763) $) 45 (|has| $ (-6 -4521))))) 
 (((-977 |#1| |#2| |#3| |#4|) (-1275) (-1047) (-788) (-842) (-1061 |t#1| |t#2| |t#3|)) (T -977)) 
-((-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *1 (-977 *3 *4 *5 *6)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *1 (-977 *3 *4 *5 *6)))) (-2356 (*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *2 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-1061 *3 *4 *2)) (-4 *2 (-842)))) (-2055 (*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-634 *5)))) (-1432 (*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-634 *5)))) (-3392 (*1 *2 *3 *1) (-12 (-4 *1 (-977 *4 *5 *3 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-4 *6 (-1061 *4 *5 *3)) (-5 *2 (-121)))) (-3732 (*1 *1 *1 *2) (-12 (-4 *1 (-977 *3 *4 *2 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *5 (-1061 *3 *4 *2)))) (-3944 (*1 *1 *1 *2) (-12 (-4 *1 (-977 *3 *4 *2 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *5 (-1061 *3 *4 *2)))) (-1290 (*1 *1 *1 *2) (-12 (-4 *1 (-977 *3 *4 *2 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *5 (-1061 *3 *4 *2)))) (-3644 (*1 *2 *1 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-4 *6 (-1061 *4 *5 *3)) (-5 *2 (-2 (|:| |under| *1) (|:| -1519 *1) (|:| |upper| *1))) (-4 *1 (-977 *4 *5 *3 *6)))) (-4211 (*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) (-3695 (*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-5 *2 (-121)))) (-3846 (*1 *2 *1 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-5 *2 (-121)))) (-3106 (*1 *2 *1 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-5 *2 (-121)))) (-1565 (*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-5 *2 (-121)))) (-2705 (*1 *2 *3 *1) (-12 (-4 *1 (-977 *4 *5 *6 *3)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4))))) (-1500 (*1 *2 *3 *1) (-12 (-4 *1 (-977 *4 *5 *6 *3)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-5 *2 (-2 (|:| |rnum| *4) (|:| |polnum| *3) (|:| |den| *4))))) (-2492 (*1 *2 *2 *1) (-12 (-5 *2 (-634 *6)) (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)))) (-2355 (*1 *2 *2 *1) (-12 (-5 *2 (-634 *6)) (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)))) (-3824 (*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-5 *2 (-121))))) 
-(-13 (-1090) (-154 |t#4|) (-608 (-634 |t#4|)) (-10 -8 (-6 -4519) (-15 -3666 ((-3 $ "failed") (-634 |t#4|))) (-15 -2854 ($ (-634 |t#4|))) (-15 -2356 (|t#3| $)) (-15 -2055 ((-634 |t#3|) $)) (-15 -1432 ((-634 |t#3|) $)) (-15 -3392 ((-121) |t#3| $)) (-15 -3732 ($ $ |t#3|)) (-15 -3944 ($ $ |t#3|)) (-15 -1290 ($ $ |t#3|)) (-15 -3644 ((-2 (|:| |under| $) (|:| -1519 $) (|:| |upper| $)) $ |t#3|)) (-15 -4211 ((-121) $)) (IF (|has| |t#1| (-558)) (PROGN (-15 -3695 ((-121) $)) (-15 -3846 ((-121) $ $)) (-15 -3106 ((-121) $ $)) (-15 -1565 ((-121) $)) (-15 -2705 ((-2 (|:| |num| |t#4|) (|:| |den| |t#1|)) |t#4| $)) (-15 -1500 ((-2 (|:| |rnum| |t#1|) (|:| |polnum| |t#4|) (|:| |den| |t#1|)) |t#4| $)) (-15 -2492 ((-634 |t#4|) (-634 |t#4|) $)) (-15 -2355 ((-634 |t#4|) (-634 |t#4|) $)) (-15 -3824 ((-121) $))) |noBranch|))) 
+((-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *1 (-977 *3 *4 *5 *6)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *1 (-977 *3 *4 *5 *6)))) (-4001 (*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *2 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-1061 *3 *4 *2)) (-4 *2 (-842)))) (-2057 (*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-634 *5)))) (-2249 (*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-634 *5)))) (-1495 (*1 *2 *3 *1) (-12 (-4 *1 (-977 *4 *5 *3 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-4 *6 (-1061 *4 *5 *3)) (-5 *2 (-121)))) (-2527 (*1 *1 *1 *2) (-12 (-4 *1 (-977 *3 *4 *2 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *5 (-1061 *3 *4 *2)))) (-4332 (*1 *1 *1 *2) (-12 (-4 *1 (-977 *3 *4 *2 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *5 (-1061 *3 *4 *2)))) (-3206 (*1 *1 *1 *2) (-12 (-4 *1 (-977 *3 *4 *2 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *5 (-1061 *3 *4 *2)))) (-3647 (*1 *2 *1 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-4 *6 (-1061 *4 *5 *3)) (-5 *2 (-2 (|:| |under| *1) (|:| -4115 *1) (|:| |upper| *1))) (-4 *1 (-977 *4 *5 *3 *6)))) (-4141 (*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) (-2343 (*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-5 *2 (-121)))) (-1880 (*1 *2 *1 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-5 *2 (-121)))) (-2536 (*1 *2 *1 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-5 *2 (-121)))) (-4382 (*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-5 *2 (-121)))) (-1440 (*1 *2 *3 *1) (-12 (-4 *1 (-977 *4 *5 *6 *3)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4))))) (-2607 (*1 *2 *3 *1) (-12 (-4 *1 (-977 *4 *5 *6 *3)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-5 *2 (-2 (|:| |rnum| *4) (|:| |polnum| *3) (|:| |den| *4))))) (-2727 (*1 *2 *2 *1) (-12 (-5 *2 (-634 *6)) (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)))) (-3993 (*1 *2 *2 *1) (-12 (-5 *2 (-634 *6)) (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)))) (-1794 (*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-5 *2 (-121))))) 
+(-13 (-1090) (-154 |t#4|) (-608 (-634 |t#4|)) (-10 -8 (-6 -4521) (-15 -3668 ((-3 $ "failed") (-634 |t#4|))) (-15 -2857 ($ (-634 |t#4|))) (-15 -4001 (|t#3| $)) (-15 -2057 ((-634 |t#3|) $)) (-15 -2249 ((-634 |t#3|) $)) (-15 -1495 ((-121) |t#3| $)) (-15 -2527 ($ $ |t#3|)) (-15 -4332 ($ $ |t#3|)) (-15 -3206 ($ $ |t#3|)) (-15 -3647 ((-2 (|:| |under| $) (|:| -4115 $) (|:| |upper| $)) $ |t#3|)) (-15 -4141 ((-121) $)) (IF (|has| |t#1| (-558)) (PROGN (-15 -2343 ((-121) $)) (-15 -1880 ((-121) $ $)) (-15 -2536 ((-121) $ $)) (-15 -4382 ((-121) $)) (-15 -1440 ((-2 (|:| |num| |t#4|) (|:| |den| |t#1|)) |t#4| $)) (-15 -2607 ((-2 (|:| |rnum| |t#1|) (|:| |polnum| |t#4|) (|:| |den| |t#1|)) |t#4| $)) (-15 -2727 ((-634 |t#4|) (-634 |t#4|) $)) (-15 -3993 ((-634 |t#4|) (-634 |t#4|) $)) (-15 -1794 ((-121) $))) |noBranch|))) 
 (((-39) . T) ((-105) . T) ((-608 (-634 |#4|)) . T) ((-608 (-850)) . T) ((-154 |#4|) . T) ((-609 (-541)) |has| |#4| (-609 (-541))) ((-303 |#4|) -12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))) ((-499 |#4|) . T) ((-523 |#4| |#4|) -12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))) ((-1090) . T) ((-1195) . T)) 
-((-3656 (((-634 |#4|) |#4| |#4|) 114)) (-1599 (((-634 |#4|) (-634 |#4|) (-121)) 103 (|has| |#1| (-453))) (((-634 |#4|) (-634 |#4|)) 104 (|has| |#1| (-453)))) (-3721 (((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|)) 34)) (-2020 (((-121) |#4|) 33)) (-1959 (((-634 |#4|) |#4|) 100 (|has| |#1| (-453)))) (-3216 (((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-1 (-121) |#4|) (-634 |#4|)) 19)) (-3570 (((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 (-1 (-121) |#4|)) (-634 |#4|)) 21)) (-3847 (((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 (-1 (-121) |#4|)) (-634 |#4|)) 22)) (-2946 (((-3 (-2 (|:| |bas| (-481 |#1| |#2| |#3| |#4|)) (|:| -2616 (-634 |#4|))) "failed") (-634 |#4|)) 72)) (-1337 (((-634 |#4|) (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|)) 84)) (-3236 (((-634 |#4|) (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|)) 107)) (-3165 (((-634 |#4|) (-634 |#4|)) 106)) (-2568 (((-634 |#4|) (-634 |#4|) (-634 |#4|) (-121)) 47) (((-634 |#4|) (-634 |#4|) (-634 |#4|)) 49)) (-3403 ((|#4| |#4| (-634 |#4|)) 48)) (-3584 (((-634 |#4|) (-634 |#4|) (-634 |#4|)) 110 (|has| |#1| (-453)))) (-2274 (((-634 |#4|) (-634 |#4|) (-634 |#4|)) 113 (|has| |#1| (-453)))) (-2063 (((-634 |#4|) (-634 |#4|) (-634 |#4|)) 112 (|has| |#1| (-453)))) (-2173 (((-634 |#4|) (-634 |#4|) (-634 |#4|) (-1 (-634 |#4|) (-634 |#4|))) 86) (((-634 |#4|) (-634 |#4|) (-634 |#4|)) 88) (((-634 |#4|) (-634 |#4|) |#4|) 117) (((-634 |#4|) |#4| |#4|) 115) (((-634 |#4|) (-634 |#4|)) 87)) (-3136 (((-634 |#4|) (-634 |#4|) (-634 |#4|)) 97 (-12 (|has| |#1| (-150)) (|has| |#1| (-301))))) (-2052 (((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|)) 40)) (-1435 (((-121) (-634 |#4|)) 61)) (-2535 (((-121) (-634 |#4|) (-634 (-634 |#4|))) 52)) (-1934 (((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|)) 28)) (-4364 (((-121) |#4|) 27)) (-1322 (((-634 |#4|) (-634 |#4|)) 96 (-12 (|has| |#1| (-150)) (|has| |#1| (-301))))) (-2333 (((-634 |#4|) (-634 |#4|)) 95 (-12 (|has| |#1| (-150)) (|has| |#1| (-301))))) (-2545 (((-634 |#4|) (-634 |#4|)) 65)) (-1618 (((-634 |#4|) (-634 |#4|)) 78)) (-3230 (((-121) (-634 |#4|) (-634 |#4|)) 50)) (-3885 (((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|)) 38)) (-3484 (((-121) |#4|) 35))) 
-(((-978 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2173 ((-634 |#4|) (-634 |#4|))) (-15 -2173 ((-634 |#4|) |#4| |#4|)) (-15 -3165 ((-634 |#4|) (-634 |#4|))) (-15 -3656 ((-634 |#4|) |#4| |#4|)) (-15 -2173 ((-634 |#4|) (-634 |#4|) |#4|)) (-15 -2173 ((-634 |#4|) (-634 |#4|) (-634 |#4|))) (-15 -2173 ((-634 |#4|) (-634 |#4|) (-634 |#4|) (-1 (-634 |#4|) (-634 |#4|)))) (-15 -3230 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -2535 ((-121) (-634 |#4|) (-634 (-634 |#4|)))) (-15 -1435 ((-121) (-634 |#4|))) (-15 -3216 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-1 (-121) |#4|) (-634 |#4|))) (-15 -3570 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 (-1 (-121) |#4|)) (-634 |#4|))) (-15 -3847 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 (-1 (-121) |#4|)) (-634 |#4|))) (-15 -2052 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|))) (-15 -2020 ((-121) |#4|)) (-15 -3721 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|))) (-15 -4364 ((-121) |#4|)) (-15 -1934 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|))) (-15 -3484 ((-121) |#4|)) (-15 -3885 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|))) (-15 -2568 ((-634 |#4|) (-634 |#4|) (-634 |#4|))) (-15 -2568 ((-634 |#4|) (-634 |#4|) (-634 |#4|) (-121))) (-15 -3403 (|#4| |#4| (-634 |#4|))) (-15 -2545 ((-634 |#4|) (-634 |#4|))) (-15 -2946 ((-3 (-2 (|:| |bas| (-481 |#1| |#2| |#3| |#4|)) (|:| -2616 (-634 |#4|))) "failed") (-634 |#4|))) (-15 -1618 ((-634 |#4|) (-634 |#4|))) (-15 -1337 ((-634 |#4|) (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -3236 ((-634 |#4|) (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (IF (|has| |#1| (-453)) (PROGN (-15 -1959 ((-634 |#4|) |#4|)) (-15 -1599 ((-634 |#4|) (-634 |#4|))) (-15 -1599 ((-634 |#4|) (-634 |#4|) (-121))) (-15 -3584 ((-634 |#4|) (-634 |#4|) (-634 |#4|))) (-15 -2063 ((-634 |#4|) (-634 |#4|) (-634 |#4|))) (-15 -2274 ((-634 |#4|) (-634 |#4|) (-634 |#4|)))) |noBranch|) (IF (|has| |#1| (-301)) (IF (|has| |#1| (-150)) (PROGN (-15 -2333 ((-634 |#4|) (-634 |#4|))) (-15 -1322 ((-634 |#4|) (-634 |#4|))) (-15 -3136 ((-634 |#4|) (-634 |#4|) (-634 |#4|)))) |noBranch|) |noBranch|)) (-558) (-788) (-842) (-1061 |#1| |#2| |#3|)) (T -978)) 
-((-3136 (*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-150)) (-4 *3 (-301)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-1322 (*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-150)) (-4 *3 (-301)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-2333 (*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-150)) (-4 *3 (-301)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-2274 (*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-453)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-2063 (*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-453)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-3584 (*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-453)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-1599 (*1 *2 *2 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-121)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-978 *4 *5 *6 *7)))) (-1599 (*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-453)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-1959 (*1 *2 *3) (-12 (-4 *4 (-453)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *3)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6)))) (-3236 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-634 *8)) (-5 *3 (-1 (-121) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-978 *5 *6 *7 *8)))) (-1337 (*1 *2 *2 *3 *4 *5) (-12 (-5 *2 (-634 *9)) (-5 *3 (-1 (-121) *9)) (-5 *4 (-1 (-121) *9 *9)) (-5 *5 (-1 *9 *9 *9)) (-4 *9 (-1061 *6 *7 *8)) (-4 *6 (-558)) (-4 *7 (-788)) (-4 *8 (-842)) (-5 *1 (-978 *6 *7 *8 *9)))) (-1618 (*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-2946 (*1 *2 *3) (|partial| -12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-2 (|:| |bas| (-481 *4 *5 *6 *7)) (|:| -2616 (-634 *7)))) (-5 *1 (-978 *4 *5 *6 *7)) (-5 *3 (-634 *7)))) (-2545 (*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-3403 (*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-978 *4 *5 *6 *2)))) (-2568 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-121)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-978 *4 *5 *6 *7)))) (-2568 (*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-3885 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-634 *7)) (|:| |badPols| (-634 *7)))) (-5 *1 (-978 *4 *5 *6 *7)) (-5 *3 (-634 *7)))) (-3484 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6)))) (-1934 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-634 *7)) (|:| |badPols| (-634 *7)))) (-5 *1 (-978 *4 *5 *6 *7)) (-5 *3 (-634 *7)))) (-4364 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6)))) (-3721 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-634 *7)) (|:| |badPols| (-634 *7)))) (-5 *1 (-978 *4 *5 *6 *7)) (-5 *3 (-634 *7)))) (-2020 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6)))) (-2052 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-634 *7)) (|:| |badPols| (-634 *7)))) (-5 *1 (-978 *4 *5 *6 *7)) (-5 *3 (-634 *7)))) (-3847 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1 (-121) *8))) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-2 (|:| |goodPols| (-634 *8)) (|:| |badPols| (-634 *8)))) (-5 *1 (-978 *5 *6 *7 *8)) (-5 *4 (-634 *8)))) (-3570 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1 (-121) *8))) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-2 (|:| |goodPols| (-634 *8)) (|:| |badPols| (-634 *8)))) (-5 *1 (-978 *5 *6 *7 *8)) (-5 *4 (-634 *8)))) (-3216 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-121) *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-2 (|:| |goodPols| (-634 *8)) (|:| |badPols| (-634 *8)))) (-5 *1 (-978 *5 *6 *7 *8)) (-5 *4 (-634 *8)))) (-1435 (*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *4 *5 *6 *7)))) (-2535 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-634 *8))) (-5 *3 (-634 *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *5 *6 *7 *8)))) (-3230 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *4 *5 *6 *7)))) (-2173 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 (-634 *7) (-634 *7))) (-5 *2 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-978 *4 *5 *6 *7)))) (-2173 (*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-2173 (*1 *2 *2 *3) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-978 *4 *5 *6 *3)))) (-3656 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *3)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6)))) (-3165 (*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-2173 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *3)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6)))) (-2173 (*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6))))) 
-(-10 -7 (-15 -2173 ((-634 |#4|) (-634 |#4|))) (-15 -2173 ((-634 |#4|) |#4| |#4|)) (-15 -3165 ((-634 |#4|) (-634 |#4|))) (-15 -3656 ((-634 |#4|) |#4| |#4|)) (-15 -2173 ((-634 |#4|) (-634 |#4|) |#4|)) (-15 -2173 ((-634 |#4|) (-634 |#4|) (-634 |#4|))) (-15 -2173 ((-634 |#4|) (-634 |#4|) (-634 |#4|) (-1 (-634 |#4|) (-634 |#4|)))) (-15 -3230 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -2535 ((-121) (-634 |#4|) (-634 (-634 |#4|)))) (-15 -1435 ((-121) (-634 |#4|))) (-15 -3216 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-1 (-121) |#4|) (-634 |#4|))) (-15 -3570 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 (-1 (-121) |#4|)) (-634 |#4|))) (-15 -3847 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 (-1 (-121) |#4|)) (-634 |#4|))) (-15 -2052 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|))) (-15 -2020 ((-121) |#4|)) (-15 -3721 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|))) (-15 -4364 ((-121) |#4|)) (-15 -1934 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|))) (-15 -3484 ((-121) |#4|)) (-15 -3885 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|))) (-15 -2568 ((-634 |#4|) (-634 |#4|) (-634 |#4|))) (-15 -2568 ((-634 |#4|) (-634 |#4|) (-634 |#4|) (-121))) (-15 -3403 (|#4| |#4| (-634 |#4|))) (-15 -2545 ((-634 |#4|) (-634 |#4|))) (-15 -2946 ((-3 (-2 (|:| |bas| (-481 |#1| |#2| |#3| |#4|)) (|:| -2616 (-634 |#4|))) "failed") (-634 |#4|))) (-15 -1618 ((-634 |#4|) (-634 |#4|))) (-15 -1337 ((-634 |#4|) (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -3236 ((-634 |#4|) (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (IF (|has| |#1| (-453)) (PROGN (-15 -1959 ((-634 |#4|) |#4|)) (-15 -1599 ((-634 |#4|) (-634 |#4|))) (-15 -1599 ((-634 |#4|) (-634 |#4|) (-121))) (-15 -3584 ((-634 |#4|) (-634 |#4|) (-634 |#4|))) (-15 -2063 ((-634 |#4|) (-634 |#4|) (-634 |#4|))) (-15 -2274 ((-634 |#4|) (-634 |#4|) (-634 |#4|)))) |noBranch|) (IF (|has| |#1| (-301)) (IF (|has| |#1| (-150)) (PROGN (-15 -2333 ((-634 |#4|) (-634 |#4|))) (-15 -1322 ((-634 |#4|) (-634 |#4|))) (-15 -3136 ((-634 |#4|) (-634 |#4|) (-634 |#4|)))) |noBranch|) |noBranch|)) 
-((-2633 (((-2 (|:| R (-679 |#1|)) (|:| A (-679 |#1|)) (|:| |Ainv| (-679 |#1|))) (-679 |#1|) (-101 |#1|) (-1 |#1| |#1|)) 19)) (-4468 (((-634 (-2 (|:| C (-679 |#1|)) (|:| |g| (-1244 |#1|)))) (-679 |#1|) (-1244 |#1|)) 35)) (-3799 (((-679 |#1|) (-679 |#1|) (-679 |#1|) (-101 |#1|) (-1 |#1| |#1|)) 16))) 
-(((-979 |#1|) (-10 -7 (-15 -2633 ((-2 (|:| R (-679 |#1|)) (|:| A (-679 |#1|)) (|:| |Ainv| (-679 |#1|))) (-679 |#1|) (-101 |#1|) (-1 |#1| |#1|))) (-15 -3799 ((-679 |#1|) (-679 |#1|) (-679 |#1|) (-101 |#1|) (-1 |#1| |#1|))) (-15 -4468 ((-634 (-2 (|:| C (-679 |#1|)) (|:| |g| (-1244 |#1|)))) (-679 |#1|) (-1244 |#1|)))) (-365)) (T -979)) 
-((-4468 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-5 *2 (-634 (-2 (|:| C (-679 *5)) (|:| |g| (-1244 *5))))) (-5 *1 (-979 *5)) (-5 *3 (-679 *5)) (-5 *4 (-1244 *5)))) (-3799 (*1 *2 *2 *2 *3 *4) (-12 (-5 *2 (-679 *5)) (-5 *3 (-101 *5)) (-5 *4 (-1 *5 *5)) (-4 *5 (-365)) (-5 *1 (-979 *5)))) (-2633 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-101 *6)) (-5 *5 (-1 *6 *6)) (-4 *6 (-365)) (-5 *2 (-2 (|:| R (-679 *6)) (|:| A (-679 *6)) (|:| |Ainv| (-679 *6)))) (-5 *1 (-979 *6)) (-5 *3 (-679 *6))))) 
-(-10 -7 (-15 -2633 ((-2 (|:| R (-679 |#1|)) (|:| A (-679 |#1|)) (|:| |Ainv| (-679 |#1|))) (-679 |#1|) (-101 |#1|) (-1 |#1| |#1|))) (-15 -3799 ((-679 |#1|) (-679 |#1|) (-679 |#1|) (-101 |#1|) (-1 |#1| |#1|))) (-15 -4468 ((-634 (-2 (|:| C (-679 |#1|)) (|:| |g| (-1244 |#1|)))) (-679 |#1|) (-1244 |#1|)))) 
-((-1678 (((-420 |#4|) |#4|) 47))) 
-(((-980 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1678 ((-420 |#4|) |#4|))) (-842) (-788) (-453) (-950 |#3| |#2| |#1|)) (T -980)) 
-((-1678 (*1 *2 *3) (-12 (-4 *4 (-842)) (-4 *5 (-788)) (-4 *6 (-453)) (-5 *2 (-420 *3)) (-5 *1 (-980 *4 *5 *6 *3)) (-4 *3 (-950 *6 *5 *4))))) 
-(-10 -7 (-15 -1678 ((-420 |#4|) |#4|))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-3205 (($ (-763)) 105 (|has| |#1| (-23)))) (-1868 (((-1249) $ (-568) (-568)) 37 (|has| $ (-6 -4520)))) (-2016 (((-121) (-1 (-121) |#1| |#1|) $) 91) (((-121) $) 85 (|has| |#1| (-842)))) (-3908 (($ (-1 (-121) |#1| |#1|) $) 82 (|has| $ (-6 -4520))) (($ $) 81 (-12 (|has| |#1| (-842)) (|has| $ (-6 -4520))))) (-3644 (($ (-1 (-121) |#1| |#1|) $) 92) (($ $) 86 (|has| |#1| (-842)))) (-2510 (((-121) $ (-763)) 8)) (-2436 ((|#1| $ (-568) |#1|) 49 (|has| $ (-6 -4520))) ((|#1| $ (-1210 (-568)) |#1|) 53 (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) |#1|) $) 70 (|has| $ (-6 -4519)))) (-2671 (($) 7 T CONST)) (-1578 (($ $) 83 (|has| $ (-6 -4520)))) (-3943 (($ $) 93)) (-3924 (($ $) 73 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-4328 (($ |#1| $) 72 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) |#1|) $) 69 (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4519)))) (-3989 ((|#1| $ (-568) |#1|) 50 (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-568)) 48)) (-2764 (((-568) (-1 (-121) |#1|) $) 90) (((-568) |#1| $) 89 (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) 88 (|has| |#1| (-1090)))) (-4203 (($ (-634 |#1|)) 110)) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-1802 (((-679 |#1|) $ $) 98 (|has| |#1| (-1047)))) (-1849 (($ (-763) |#1|) 64)) (-1737 (((-121) $ (-763)) 9)) (-1881 (((-568) $) 40 (|has| (-568) (-842)))) (-2521 (($ $ $) 80 (|has| |#1| (-842)))) (-1347 (($ (-1 (-121) |#1| |#1|) $ $) 94) (($ $ $) 87 (|has| |#1| (-842)))) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-2223 (((-568) $) 41 (|has| (-568) (-842)))) (-3268 (($ $ $) 79 (|has| |#1| (-842)))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-1550 ((|#1| $) 95 (-12 (|has| |#1| (-1047)) (|has| |#1| (-1002))))) (-2166 (((-121) $ (-763)) 10)) (-3678 ((|#1| $) 96 (-12 (|has| |#1| (-1047)) (|has| |#1| (-1002))))) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4122 (($ |#1| $ (-568)) 55) (($ $ $ (-568)) 54)) (-4174 (((-634 (-568)) $) 43)) (-3578 (((-121) (-568) $) 44)) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3876 ((|#1| $) 39 (|has| (-568) (-842)))) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 66)) (-3724 (($ $ |#1|) 38 (|has| $ (-6 -4520)))) (-1807 (($ $ (-634 |#1|)) 107)) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-4467 (((-121) |#1| $) 42 (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) 45)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 ((|#1| $ (-568) |#1|) 47) ((|#1| $ (-568)) 46) (($ $ (-1210 (-568))) 58)) (-3682 ((|#1| $ $) 99 (|has| |#1| (-1047)))) (-4321 (((-917) $) 109)) (-2826 (($ $ (-568)) 57) (($ $ (-1210 (-568))) 56)) (-2748 (($ $ $) 97)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-2256 (($ $ $ (-568)) 84 (|has| $ (-6 -4520)))) (-3863 (($ $) 13)) (-4278 (((-541) $) 74 (|has| |#1| (-609 (-541)))) (($ (-634 |#1|)) 108)) (-4287 (($ (-634 |#1|)) 65)) (-2768 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-634 $)) 60)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1751 (((-121) $ $) 77 (|has| |#1| (-842)))) (-1738 (((-121) $ $) 76 (|has| |#1| (-842)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1745 (((-121) $ $) 78 (|has| |#1| (-842)))) (-1732 (((-121) $ $) 75 (|has| |#1| (-842)))) (-1773 (($ $) 104 (|has| |#1| (-21))) (($ $ $) 103 (|has| |#1| (-21)))) (-1767 (($ $ $) 106 (|has| |#1| (-25)))) (* (($ (-568) $) 102 (|has| |#1| (-21))) (($ |#1| $) 101 (|has| |#1| (-716))) (($ $ |#1|) 100 (|has| |#1| (-716)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-3292 (((-634 |#4|) |#4| |#4|) 114)) (-1325 (((-634 |#4|) (-634 |#4|) (-121)) 103 (|has| |#1| (-453))) (((-634 |#4|) (-634 |#4|)) 104 (|has| |#1| (-453)))) (-2478 (((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|)) 34)) (-1355 (((-121) |#4|) 33)) (-4316 (((-634 |#4|) |#4|) 100 (|has| |#1| (-453)))) (-1879 (((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-1 (-121) |#4|) (-634 |#4|)) 19)) (-2890 (((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 (-1 (-121) |#4|)) (-634 |#4|)) 21)) (-1884 (((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 (-1 (-121) |#4|)) (-634 |#4|)) 22)) (-2965 (((-3 (-2 (|:| |bas| (-481 |#1| |#2| |#3| |#4|)) (|:| -2618 (-634 |#4|))) "failed") (-634 |#4|)) 72)) (-3574 (((-634 |#4|) (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|)) 84)) (-1949 (((-634 |#4|) (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|)) 107)) (-1673 (((-634 |#4|) (-634 |#4|)) 106)) (-1956 (((-634 |#4|) (-634 |#4|) (-634 |#4|) (-121)) 47) (((-634 |#4|) (-634 |#4|) (-634 |#4|)) 49)) (-1554 ((|#4| |#4| (-634 |#4|)) 48)) (-2940 (((-634 |#4|) (-634 |#4|) (-634 |#4|)) 110 (|has| |#1| (-453)))) (-3431 (((-634 |#4|) (-634 |#4|) (-634 |#4|)) 113 (|has| |#1| (-453)))) (-3263 (((-634 |#4|) (-634 |#4|) (-634 |#4|)) 112 (|has| |#1| (-453)))) (-3858 (((-634 |#4|) (-634 |#4|) (-634 |#4|) (-1 (-634 |#4|) (-634 |#4|))) 86) (((-634 |#4|) (-634 |#4|) (-634 |#4|)) 88) (((-634 |#4|) (-634 |#4|) |#4|) 117) (((-634 |#4|) |#4| |#4|) 115) (((-634 |#4|) (-634 |#4|)) 87)) (-2698 (((-634 |#4|) (-634 |#4|) (-634 |#4|)) 97 (-12 (|has| |#1| (-150)) (|has| |#1| (-301))))) (-1531 (((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|)) 40)) (-2267 (((-121) (-634 |#4|)) 61)) (-1811 (((-121) (-634 |#4|) (-634 (-634 |#4|))) 52)) (-4199 (((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|)) 28)) (-3338 (((-121) |#4|) 27)) (-3461 (((-634 |#4|) (-634 |#4|)) 96 (-12 (|has| |#1| (-150)) (|has| |#1| (-301))))) (-3864 (((-634 |#4|) (-634 |#4|)) 95 (-12 (|has| |#1| (-150)) (|has| |#1| (-301))))) (-1853 (((-634 |#4|) (-634 |#4|)) 65)) (-1441 (((-634 |#4|) (-634 |#4|)) 78)) (-1925 (((-121) (-634 |#4|) (-634 |#4|)) 50)) (-2019 (((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|)) 38)) (-3812 (((-121) |#4|) 35))) 
+(((-978 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3858 ((-634 |#4|) (-634 |#4|))) (-15 -3858 ((-634 |#4|) |#4| |#4|)) (-15 -1673 ((-634 |#4|) (-634 |#4|))) (-15 -3292 ((-634 |#4|) |#4| |#4|)) (-15 -3858 ((-634 |#4|) (-634 |#4|) |#4|)) (-15 -3858 ((-634 |#4|) (-634 |#4|) (-634 |#4|))) (-15 -3858 ((-634 |#4|) (-634 |#4|) (-634 |#4|) (-1 (-634 |#4|) (-634 |#4|)))) (-15 -1925 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -1811 ((-121) (-634 |#4|) (-634 (-634 |#4|)))) (-15 -2267 ((-121) (-634 |#4|))) (-15 -1879 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-1 (-121) |#4|) (-634 |#4|))) (-15 -2890 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 (-1 (-121) |#4|)) (-634 |#4|))) (-15 -1884 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 (-1 (-121) |#4|)) (-634 |#4|))) (-15 -1531 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|))) (-15 -1355 ((-121) |#4|)) (-15 -2478 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|))) (-15 -3338 ((-121) |#4|)) (-15 -4199 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|))) (-15 -3812 ((-121) |#4|)) (-15 -2019 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|))) (-15 -1956 ((-634 |#4|) (-634 |#4|) (-634 |#4|))) (-15 -1956 ((-634 |#4|) (-634 |#4|) (-634 |#4|) (-121))) (-15 -1554 (|#4| |#4| (-634 |#4|))) (-15 -1853 ((-634 |#4|) (-634 |#4|))) (-15 -2965 ((-3 (-2 (|:| |bas| (-481 |#1| |#2| |#3| |#4|)) (|:| -2618 (-634 |#4|))) "failed") (-634 |#4|))) (-15 -1441 ((-634 |#4|) (-634 |#4|))) (-15 -3574 ((-634 |#4|) (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -1949 ((-634 |#4|) (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (IF (|has| |#1| (-453)) (PROGN (-15 -4316 ((-634 |#4|) |#4|)) (-15 -1325 ((-634 |#4|) (-634 |#4|))) (-15 -1325 ((-634 |#4|) (-634 |#4|) (-121))) (-15 -2940 ((-634 |#4|) (-634 |#4|) (-634 |#4|))) (-15 -3263 ((-634 |#4|) (-634 |#4|) (-634 |#4|))) (-15 -3431 ((-634 |#4|) (-634 |#4|) (-634 |#4|)))) |noBranch|) (IF (|has| |#1| (-301)) (IF (|has| |#1| (-150)) (PROGN (-15 -3864 ((-634 |#4|) (-634 |#4|))) (-15 -3461 ((-634 |#4|) (-634 |#4|))) (-15 -2698 ((-634 |#4|) (-634 |#4|) (-634 |#4|)))) |noBranch|) |noBranch|)) (-558) (-788) (-842) (-1061 |#1| |#2| |#3|)) (T -978)) 
+((-2698 (*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-150)) (-4 *3 (-301)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-3461 (*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-150)) (-4 *3 (-301)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-3864 (*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-150)) (-4 *3 (-301)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-3431 (*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-453)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-3263 (*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-453)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-2940 (*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-453)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-1325 (*1 *2 *2 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-121)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-978 *4 *5 *6 *7)))) (-1325 (*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-453)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-4316 (*1 *2 *3) (-12 (-4 *4 (-453)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *3)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6)))) (-1949 (*1 *2 *2 *3 *4) (-12 (-5 *2 (-634 *8)) (-5 *3 (-1 (-121) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-978 *5 *6 *7 *8)))) (-3574 (*1 *2 *2 *3 *4 *5) (-12 (-5 *2 (-634 *9)) (-5 *3 (-1 (-121) *9)) (-5 *4 (-1 (-121) *9 *9)) (-5 *5 (-1 *9 *9 *9)) (-4 *9 (-1061 *6 *7 *8)) (-4 *6 (-558)) (-4 *7 (-788)) (-4 *8 (-842)) (-5 *1 (-978 *6 *7 *8 *9)))) (-1441 (*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-2965 (*1 *2 *3) (|partial| -12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-2 (|:| |bas| (-481 *4 *5 *6 *7)) (|:| -2618 (-634 *7)))) (-5 *1 (-978 *4 *5 *6 *7)) (-5 *3 (-634 *7)))) (-1853 (*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-1554 (*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-978 *4 *5 *6 *2)))) (-1956 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-121)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-978 *4 *5 *6 *7)))) (-1956 (*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-2019 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-634 *7)) (|:| |badPols| (-634 *7)))) (-5 *1 (-978 *4 *5 *6 *7)) (-5 *3 (-634 *7)))) (-3812 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6)))) (-4199 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-634 *7)) (|:| |badPols| (-634 *7)))) (-5 *1 (-978 *4 *5 *6 *7)) (-5 *3 (-634 *7)))) (-3338 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6)))) (-2478 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-634 *7)) (|:| |badPols| (-634 *7)))) (-5 *1 (-978 *4 *5 *6 *7)) (-5 *3 (-634 *7)))) (-1355 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6)))) (-1531 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-634 *7)) (|:| |badPols| (-634 *7)))) (-5 *1 (-978 *4 *5 *6 *7)) (-5 *3 (-634 *7)))) (-1884 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1 (-121) *8))) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-2 (|:| |goodPols| (-634 *8)) (|:| |badPols| (-634 *8)))) (-5 *1 (-978 *5 *6 *7 *8)) (-5 *4 (-634 *8)))) (-2890 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1 (-121) *8))) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-2 (|:| |goodPols| (-634 *8)) (|:| |badPols| (-634 *8)))) (-5 *1 (-978 *5 *6 *7 *8)) (-5 *4 (-634 *8)))) (-1879 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-121) *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-2 (|:| |goodPols| (-634 *8)) (|:| |badPols| (-634 *8)))) (-5 *1 (-978 *5 *6 *7 *8)) (-5 *4 (-634 *8)))) (-2267 (*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *4 *5 *6 *7)))) (-1811 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-634 *8))) (-5 *3 (-634 *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *5 *6 *7 *8)))) (-1925 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *4 *5 *6 *7)))) (-3858 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 (-634 *7) (-634 *7))) (-5 *2 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-978 *4 *5 *6 *7)))) (-3858 (*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-3858 (*1 *2 *2 *3) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-978 *4 *5 *6 *3)))) (-3292 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *3)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6)))) (-1673 (*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) (-3858 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *3)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6)))) (-3858 (*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6))))) 
+(-10 -7 (-15 -3858 ((-634 |#4|) (-634 |#4|))) (-15 -3858 ((-634 |#4|) |#4| |#4|)) (-15 -1673 ((-634 |#4|) (-634 |#4|))) (-15 -3292 ((-634 |#4|) |#4| |#4|)) (-15 -3858 ((-634 |#4|) (-634 |#4|) |#4|)) (-15 -3858 ((-634 |#4|) (-634 |#4|) (-634 |#4|))) (-15 -3858 ((-634 |#4|) (-634 |#4|) (-634 |#4|) (-1 (-634 |#4|) (-634 |#4|)))) (-15 -1925 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -1811 ((-121) (-634 |#4|) (-634 (-634 |#4|)))) (-15 -2267 ((-121) (-634 |#4|))) (-15 -1879 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-1 (-121) |#4|) (-634 |#4|))) (-15 -2890 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 (-1 (-121) |#4|)) (-634 |#4|))) (-15 -1884 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 (-1 (-121) |#4|)) (-634 |#4|))) (-15 -1531 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|))) (-15 -1355 ((-121) |#4|)) (-15 -2478 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|))) (-15 -3338 ((-121) |#4|)) (-15 -4199 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|))) (-15 -3812 ((-121) |#4|)) (-15 -2019 ((-2 (|:| |goodPols| (-634 |#4|)) (|:| |badPols| (-634 |#4|))) (-634 |#4|))) (-15 -1956 ((-634 |#4|) (-634 |#4|) (-634 |#4|))) (-15 -1956 ((-634 |#4|) (-634 |#4|) (-634 |#4|) (-121))) (-15 -1554 (|#4| |#4| (-634 |#4|))) (-15 -1853 ((-634 |#4|) (-634 |#4|))) (-15 -2965 ((-3 (-2 (|:| |bas| (-481 |#1| |#2| |#3| |#4|)) (|:| -2618 (-634 |#4|))) "failed") (-634 |#4|))) (-15 -1441 ((-634 |#4|) (-634 |#4|))) (-15 -3574 ((-634 |#4|) (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -1949 ((-634 |#4|) (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (IF (|has| |#1| (-453)) (PROGN (-15 -4316 ((-634 |#4|) |#4|)) (-15 -1325 ((-634 |#4|) (-634 |#4|))) (-15 -1325 ((-634 |#4|) (-634 |#4|) (-121))) (-15 -2940 ((-634 |#4|) (-634 |#4|) (-634 |#4|))) (-15 -3263 ((-634 |#4|) (-634 |#4|) (-634 |#4|))) (-15 -3431 ((-634 |#4|) (-634 |#4|) (-634 |#4|)))) |noBranch|) (IF (|has| |#1| (-301)) (IF (|has| |#1| (-150)) (PROGN (-15 -3864 ((-634 |#4|) (-634 |#4|))) (-15 -3461 ((-634 |#4|) (-634 |#4|))) (-15 -2698 ((-634 |#4|) (-634 |#4|) (-634 |#4|)))) |noBranch|) |noBranch|)) 
+((-4272 (((-2 (|:| R (-679 |#1|)) (|:| A (-679 |#1|)) (|:| |Ainv| (-679 |#1|))) (-679 |#1|) (-101 |#1|) (-1 |#1| |#1|)) 19)) (-1808 (((-634 (-2 (|:| C (-679 |#1|)) (|:| |g| (-1244 |#1|)))) (-679 |#1|) (-1244 |#1|)) 35)) (-1680 (((-679 |#1|) (-679 |#1|) (-679 |#1|) (-101 |#1|) (-1 |#1| |#1|)) 16))) 
+(((-979 |#1|) (-10 -7 (-15 -4272 ((-2 (|:| R (-679 |#1|)) (|:| A (-679 |#1|)) (|:| |Ainv| (-679 |#1|))) (-679 |#1|) (-101 |#1|) (-1 |#1| |#1|))) (-15 -1680 ((-679 |#1|) (-679 |#1|) (-679 |#1|) (-101 |#1|) (-1 |#1| |#1|))) (-15 -1808 ((-634 (-2 (|:| C (-679 |#1|)) (|:| |g| (-1244 |#1|)))) (-679 |#1|) (-1244 |#1|)))) (-365)) (T -979)) 
+((-1808 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-5 *2 (-634 (-2 (|:| C (-679 *5)) (|:| |g| (-1244 *5))))) (-5 *1 (-979 *5)) (-5 *3 (-679 *5)) (-5 *4 (-1244 *5)))) (-1680 (*1 *2 *2 *2 *3 *4) (-12 (-5 *2 (-679 *5)) (-5 *3 (-101 *5)) (-5 *4 (-1 *5 *5)) (-4 *5 (-365)) (-5 *1 (-979 *5)))) (-4272 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-101 *6)) (-5 *5 (-1 *6 *6)) (-4 *6 (-365)) (-5 *2 (-2 (|:| R (-679 *6)) (|:| A (-679 *6)) (|:| |Ainv| (-679 *6)))) (-5 *1 (-979 *6)) (-5 *3 (-679 *6))))) 
+(-10 -7 (-15 -4272 ((-2 (|:| R (-679 |#1|)) (|:| A (-679 |#1|)) (|:| |Ainv| (-679 |#1|))) (-679 |#1|) (-101 |#1|) (-1 |#1| |#1|))) (-15 -1680 ((-679 |#1|) (-679 |#1|) (-679 |#1|) (-101 |#1|) (-1 |#1| |#1|))) (-15 -1808 ((-634 (-2 (|:| C (-679 |#1|)) (|:| |g| (-1244 |#1|)))) (-679 |#1|) (-1244 |#1|)))) 
+((-3498 (((-420 |#4|) |#4|) 47))) 
+(((-980 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3498 ((-420 |#4|) |#4|))) (-842) (-788) (-453) (-950 |#3| |#2| |#1|)) (T -980)) 
+((-3498 (*1 *2 *3) (-12 (-4 *4 (-842)) (-4 *5 (-788)) (-4 *6 (-453)) (-5 *2 (-420 *3)) (-5 *1 (-980 *4 *5 *6 *3)) (-4 *3 (-950 *6 *5 *4))))) 
+(-10 -7 (-15 -3498 ((-420 |#4|) |#4|))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-3207 (($ (-763)) 105 (|has| |#1| (-23)))) (-2481 (((-1249) $ (-568) (-568)) 37 (|has| $ (-6 -4522)))) (-1324 (((-121) (-1 (-121) |#1| |#1|) $) 91) (((-121) $) 85 (|has| |#1| (-842)))) (-2109 (($ (-1 (-121) |#1| |#1|) $) 82 (|has| $ (-6 -4522))) (($ $) 81 (-12 (|has| |#1| (-842)) (|has| $ (-6 -4522))))) (-3647 (($ (-1 (-121) |#1| |#1|) $) 92) (($ $) 86 (|has| |#1| (-842)))) (-1667 (((-121) $ (-763)) 8)) (-2438 ((|#1| $ (-568) |#1|) 49 (|has| $ (-6 -4522))) ((|#1| $ (-1210 (-568)) |#1|) 53 (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) |#1|) $) 70 (|has| $ (-6 -4521)))) (-4490 (($) 7 T CONST)) (-4452 (($ $) 83 (|has| $ (-6 -4522)))) (-3945 (($ $) 93)) (-3926 (($ $) 73 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-4330 (($ |#1| $) 72 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) |#1|) $) 69 (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4521)))) (-1292 ((|#1| $ (-568) |#1|) 50 (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-568)) 48)) (-2766 (((-568) (-1 (-121) |#1|) $) 90) (((-568) |#1| $) 89 (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) 88 (|has| |#1| (-1090)))) (-4098 (($ (-634 |#1|)) 110)) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-1804 (((-679 |#1|) $ $) 98 (|has| |#1| (-1047)))) (-1851 (($ (-763) |#1|) 64)) (-3791 (((-121) $ (-763)) 9)) (-2539 (((-568) $) 40 (|has| (-568) (-842)))) (-1732 (($ $ $) 80 (|has| |#1| (-842)))) (-3645 (($ (-1 (-121) |#1| |#1|) $ $) 94) (($ $ $) 87 (|has| |#1| (-842)))) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3631 (((-568) $) 41 (|has| (-568) (-842)))) (-2047 (($ $ $) 79 (|has| |#1| (-842)))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-4303 ((|#1| $) 95 (-12 (|has| |#1| (-1047)) (|has| |#1| (-1002))))) (-3796 (((-121) $ (-763)) 10)) (-3680 ((|#1| $) 96 (-12 (|has| |#1| (-1047)) (|has| |#1| (-1002))))) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4124 (($ |#1| $ (-568)) 55) (($ $ $ (-568)) 54)) (-3948 (((-634 (-568)) $) 43)) (-2916 (((-121) (-568) $) 44)) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3877 ((|#1| $) 39 (|has| (-568) (-842)))) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 66)) (-2490 (($ $ |#1|) 38 (|has| $ (-6 -4522)))) (-2168 (($ $ (-634 |#1|)) 107)) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-1801 (((-121) |#1| $) 42 (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) 45)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 ((|#1| $ (-568) |#1|) 47) ((|#1| $ (-568)) 46) (($ $ (-1210 (-568))) 58)) (-2286 ((|#1| $ $) 99 (|has| |#1| (-1047)))) (-3108 (((-917) $) 109)) (-2828 (($ $ (-568)) 57) (($ $ (-1210 (-568))) 56)) (-3372 (($ $ $) 97)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3306 (($ $ $ (-568)) 84 (|has| $ (-6 -4522)))) (-3865 (($ $) 13)) (-4280 (((-541) $) 74 (|has| |#1| (-609 (-541)))) (($ (-634 |#1|)) 108)) (-4289 (($ (-634 |#1|)) 65)) (-2770 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-634 $)) 60)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1753 (((-121) $ $) 77 (|has| |#1| (-842)))) (-1740 (((-121) $ $) 76 (|has| |#1| (-842)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1747 (((-121) $ $) 78 (|has| |#1| (-842)))) (-1734 (((-121) $ $) 75 (|has| |#1| (-842)))) (-1775 (($ $) 104 (|has| |#1| (-21))) (($ $ $) 103 (|has| |#1| (-21)))) (-1769 (($ $ $) 106 (|has| |#1| (-25)))) (* (($ (-568) $) 102 (|has| |#1| (-21))) (($ |#1| $) 101 (|has| |#1| (-716))) (($ $ |#1|) 100 (|has| |#1| (-716)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-981 |#1|) (-1275) (-1047)) (T -981)) 
-((-4203 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1047)) (-4 *1 (-981 *3)))) (-4321 (*1 *2 *1) (-12 (-4 *1 (-981 *3)) (-4 *3 (-1047)) (-5 *2 (-917)))) (-4278 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1047)) (-4 *1 (-981 *3)))) (-2748 (*1 *1 *1 *1) (-12 (-4 *1 (-981 *2)) (-4 *2 (-1047)))) (-1807 (*1 *1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *1 (-981 *3)) (-4 *3 (-1047))))) 
-(-13 (-1242 |t#1|) (-10 -8 (-15 -4203 ($ (-634 |t#1|))) (-15 -4321 ((-917) $)) (-15 -4278 ($ (-634 |t#1|))) (-15 -2748 ($ $ $)) (-15 -1807 ($ $ (-634 |t#1|))))) 
-(((-39) . T) ((-105) -2198 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-608 (-850)) -2198 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-154 |#1|) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-281 (-568) |#1|) . T) ((-283 (-568) |#1|) . T) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-375 |#1|) . T) ((-499 |#1|) . T) ((-601 (-568) |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-640 |#1|) . T) ((-19 |#1|) . T) ((-842) |has| |#1| (-842)) ((-1090) -2198 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-1195) . T) ((-1242 |#1|) . T)) 
-((-2795 (((-944 |#2|) (-1 |#2| |#1|) (-944 |#1|)) 17))) 
-(((-982 |#1| |#2|) (-10 -7 (-15 -2795 ((-944 |#2|) (-1 |#2| |#1|) (-944 |#1|)))) (-1047) (-1047)) (T -982)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-944 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-5 *2 (-944 *6)) (-5 *1 (-982 *5 *6))))) 
-(-10 -7 (-15 -2795 ((-944 |#2|) (-1 |#2| |#1|) (-944 |#1|)))) 
-((-3811 ((|#1| (-944 |#1|)) 13)) (-4166 ((|#1| (-944 |#1|)) 12)) (-3767 ((|#1| (-944 |#1|)) 11)) (-3310 ((|#1| (-944 |#1|)) 15)) (-4386 ((|#1| (-944 |#1|)) 21)) (-2438 ((|#1| (-944 |#1|)) 14)) (-4498 ((|#1| (-944 |#1|)) 16)) (-1819 ((|#1| (-944 |#1|)) 20)) (-1813 ((|#1| (-944 |#1|)) 19))) 
-(((-983 |#1|) (-10 -7 (-15 -3767 (|#1| (-944 |#1|))) (-15 -4166 (|#1| (-944 |#1|))) (-15 -3811 (|#1| (-944 |#1|))) (-15 -2438 (|#1| (-944 |#1|))) (-15 -3310 (|#1| (-944 |#1|))) (-15 -4498 (|#1| (-944 |#1|))) (-15 -1813 (|#1| (-944 |#1|))) (-15 -1819 (|#1| (-944 |#1|))) (-15 -4386 (|#1| (-944 |#1|)))) (-1047)) (T -983)) 
-((-4386 (*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047)))) (-1819 (*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047)))) (-1813 (*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047)))) (-4498 (*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047)))) (-3310 (*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047)))) (-2438 (*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047)))) (-3811 (*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047)))) (-4166 (*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047)))) (-3767 (*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047))))) 
-(-10 -7 (-15 -3767 (|#1| (-944 |#1|))) (-15 -4166 (|#1| (-944 |#1|))) (-15 -3811 (|#1| (-944 |#1|))) (-15 -2438 (|#1| (-944 |#1|))) (-15 -3310 (|#1| (-944 |#1|))) (-15 -4498 (|#1| (-944 |#1|))) (-15 -1813 (|#1| (-944 |#1|))) (-15 -1819 (|#1| (-944 |#1|))) (-15 -4386 (|#1| (-944 |#1|)))) 
-((-2588 (((-3 |#1| "failed") |#1|) 18)) (-4444 (((-3 |#1| "failed") |#1|) 6)) (-3458 (((-3 |#1| "failed") |#1|) 16)) (-1856 (((-3 |#1| "failed") |#1|) 4)) (-2369 (((-3 |#1| "failed") |#1|) 20)) (-3864 (((-3 |#1| "failed") |#1|) 8)) (-1623 (((-3 |#1| "failed") |#1| (-763)) 1)) (-3269 (((-3 |#1| "failed") |#1|) 3)) (-1648 (((-3 |#1| "failed") |#1|) 2)) (-3511 (((-3 |#1| "failed") |#1|) 21)) (-4206 (((-3 |#1| "failed") |#1|) 9)) (-2581 (((-3 |#1| "failed") |#1|) 19)) (-3509 (((-3 |#1| "failed") |#1|) 7)) (-1390 (((-3 |#1| "failed") |#1|) 17)) (-3322 (((-3 |#1| "failed") |#1|) 5)) (-1778 (((-3 |#1| "failed") |#1|) 24)) (-1981 (((-3 |#1| "failed") |#1|) 12)) (-2037 (((-3 |#1| "failed") |#1|) 22)) (-3984 (((-3 |#1| "failed") |#1|) 10)) (-1780 (((-3 |#1| "failed") |#1|) 26)) (-3517 (((-3 |#1| "failed") |#1|) 14)) (-2136 (((-3 |#1| "failed") |#1|) 27)) (-4316 (((-3 |#1| "failed") |#1|) 15)) (-2236 (((-3 |#1| "failed") |#1|) 25)) (-3053 (((-3 |#1| "failed") |#1|) 13)) (-3525 (((-3 |#1| "failed") |#1|) 23)) (-3928 (((-3 |#1| "failed") |#1|) 11))) 
+((-4098 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1047)) (-4 *1 (-981 *3)))) (-3108 (*1 *2 *1) (-12 (-4 *1 (-981 *3)) (-4 *3 (-1047)) (-5 *2 (-917)))) (-4280 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1047)) (-4 *1 (-981 *3)))) (-3372 (*1 *1 *1 *1) (-12 (-4 *1 (-981 *2)) (-4 *2 (-1047)))) (-2168 (*1 *1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *1 (-981 *3)) (-4 *3 (-1047))))) 
+(-13 (-1242 |t#1|) (-10 -8 (-15 -4098 ($ (-634 |t#1|))) (-15 -3108 ((-917) $)) (-15 -4280 ($ (-634 |t#1|))) (-15 -3372 ($ $ $)) (-15 -2168 ($ $ (-634 |t#1|))))) 
+(((-39) . T) ((-105) -2199 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-608 (-850)) -2199 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-154 |#1|) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-281 (-568) |#1|) . T) ((-283 (-568) |#1|) . T) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-375 |#1|) . T) ((-499 |#1|) . T) ((-601 (-568) |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-640 |#1|) . T) ((-19 |#1|) . T) ((-842) |has| |#1| (-842)) ((-1090) -2199 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-1195) . T) ((-1242 |#1|) . T)) 
+((-2797 (((-944 |#2|) (-1 |#2| |#1|) (-944 |#1|)) 17))) 
+(((-982 |#1| |#2|) (-10 -7 (-15 -2797 ((-944 |#2|) (-1 |#2| |#1|) (-944 |#1|)))) (-1047) (-1047)) (T -982)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-944 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-5 *2 (-944 *6)) (-5 *1 (-982 *5 *6))))) 
+(-10 -7 (-15 -2797 ((-944 |#2|) (-1 |#2| |#1|) (-944 |#1|)))) 
+((-1749 ((|#1| (-944 |#1|)) 13)) (-3906 ((|#1| (-944 |#1|)) 12)) (-2684 ((|#1| (-944 |#1|)) 11)) (-4273 ((|#1| (-944 |#1|)) 15)) (-1388 ((|#1| (-944 |#1|)) 21)) (-2457 ((|#1| (-944 |#1|)) 14)) (-3845 ((|#1| (-944 |#1|)) 16)) (-2233 ((|#1| (-944 |#1|)) 20)) (-2200 ((|#1| (-944 |#1|)) 19))) 
+(((-983 |#1|) (-10 -7 (-15 -2684 (|#1| (-944 |#1|))) (-15 -3906 (|#1| (-944 |#1|))) (-15 -1749 (|#1| (-944 |#1|))) (-15 -2457 (|#1| (-944 |#1|))) (-15 -4273 (|#1| (-944 |#1|))) (-15 -3845 (|#1| (-944 |#1|))) (-15 -2200 (|#1| (-944 |#1|))) (-15 -2233 (|#1| (-944 |#1|))) (-15 -1388 (|#1| (-944 |#1|)))) (-1047)) (T -983)) 
+((-1388 (*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047)))) (-2233 (*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047)))) (-2200 (*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047)))) (-3845 (*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047)))) (-4273 (*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047)))) (-2457 (*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047)))) (-1749 (*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047)))) (-3906 (*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047)))) (-2684 (*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047))))) 
+(-10 -7 (-15 -2684 (|#1| (-944 |#1|))) (-15 -3906 (|#1| (-944 |#1|))) (-15 -1749 (|#1| (-944 |#1|))) (-15 -2457 (|#1| (-944 |#1|))) (-15 -4273 (|#1| (-944 |#1|))) (-15 -3845 (|#1| (-944 |#1|))) (-15 -2200 (|#1| (-944 |#1|))) (-15 -2233 (|#1| (-944 |#1|))) (-15 -1388 (|#1| (-944 |#1|)))) 
+((-2029 (((-3 |#1| "failed") |#1|) 18)) (-1674 (((-3 |#1| "failed") |#1|) 6)) (-3624 (((-3 |#1| "failed") |#1|) 16)) (-2422 (((-3 |#1| "failed") |#1|) 4)) (-4087 (((-3 |#1| "failed") |#1|) 20)) (-1942 (((-3 |#1| "failed") |#1|) 8)) (-1472 (((-3 |#1| "failed") |#1| (-763)) 1)) (-2051 (((-3 |#1| "failed") |#1|) 3)) (-3296 (((-3 |#1| "failed") |#1|) 2)) (-3995 (((-3 |#1| "failed") |#1|) 21)) (-4119 (((-3 |#1| "failed") |#1|) 9)) (-2005 (((-3 |#1| "failed") |#1|) 19)) (-3979 (((-3 |#1| "failed") |#1|) 7)) (-3975 (((-3 |#1| "failed") |#1|) 17)) (-4349 (((-3 |#1| "failed") |#1|) 5)) (-4008 (((-3 |#1| "failed") |#1|) 24)) (-4415 (((-3 |#1| "failed") |#1|) 12)) (-1461 (((-3 |#1| "failed") |#1|) 22)) (-4497 (((-3 |#1| "failed") |#1|) 10)) (-4016 (((-3 |#1| "failed") |#1|) 26)) (-4040 (((-3 |#1| "failed") |#1|) 14)) (-3468 (((-3 |#1| "failed") |#1|) 27)) (-3084 (((-3 |#1| "failed") |#1|) 15)) (-2695 (((-3 |#1| "failed") |#1|) 25)) (-2285 (((-3 |#1| "failed") |#1|) 13)) (-4090 (((-3 |#1| "failed") |#1|) 23)) (-2203 (((-3 |#1| "failed") |#1|) 11))) 
 (((-984 |#1|) (-1275) (-1181)) (T -984)) 
-((-2136 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-1780 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-2236 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-1778 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-3525 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-2037 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-3511 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-2369 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-2581 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-2588 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-1390 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-3458 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-4316 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-3517 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-3053 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-1981 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-3928 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-3984 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-4206 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-3864 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-3509 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-4444 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-3322 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-1856 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-3269 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-1648 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-1623 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-763)) (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
-(-13 (-10 -7 (-15 -1623 ((-3 |t#1| "failed") |t#1| (-763))) (-15 -1648 ((-3 |t#1| "failed") |t#1|)) (-15 -3269 ((-3 |t#1| "failed") |t#1|)) (-15 -1856 ((-3 |t#1| "failed") |t#1|)) (-15 -3322 ((-3 |t#1| "failed") |t#1|)) (-15 -4444 ((-3 |t#1| "failed") |t#1|)) (-15 -3509 ((-3 |t#1| "failed") |t#1|)) (-15 -3864 ((-3 |t#1| "failed") |t#1|)) (-15 -4206 ((-3 |t#1| "failed") |t#1|)) (-15 -3984 ((-3 |t#1| "failed") |t#1|)) (-15 -3928 ((-3 |t#1| "failed") |t#1|)) (-15 -1981 ((-3 |t#1| "failed") |t#1|)) (-15 -3053 ((-3 |t#1| "failed") |t#1|)) (-15 -3517 ((-3 |t#1| "failed") |t#1|)) (-15 -4316 ((-3 |t#1| "failed") |t#1|)) (-15 -3458 ((-3 |t#1| "failed") |t#1|)) (-15 -1390 ((-3 |t#1| "failed") |t#1|)) (-15 -2588 ((-3 |t#1| "failed") |t#1|)) (-15 -2581 ((-3 |t#1| "failed") |t#1|)) (-15 -2369 ((-3 |t#1| "failed") |t#1|)) (-15 -3511 ((-3 |t#1| "failed") |t#1|)) (-15 -2037 ((-3 |t#1| "failed") |t#1|)) (-15 -3525 ((-3 |t#1| "failed") |t#1|)) (-15 -1778 ((-3 |t#1| "failed") |t#1|)) (-15 -2236 ((-3 |t#1| "failed") |t#1|)) (-15 -1780 ((-3 |t#1| "failed") |t#1|)) (-15 -2136 ((-3 |t#1| "failed") |t#1|)))) 
-((-2917 ((|#4| |#4| (-634 |#3|)) 55) ((|#4| |#4| |#3|) 54)) (-3352 ((|#4| |#4| (-634 |#3|)) 23) ((|#4| |#4| |#3|) 19)) (-2795 ((|#4| (-1 |#4| (-953 |#1|)) |#4|) 30))) 
-(((-985 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3352 (|#4| |#4| |#3|)) (-15 -3352 (|#4| |#4| (-634 |#3|))) (-15 -2917 (|#4| |#4| |#3|)) (-15 -2917 (|#4| |#4| (-634 |#3|))) (-15 -2795 (|#4| (-1 |#4| (-953 |#1|)) |#4|))) (-1047) (-788) (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $)) (-15 -1305 ((-3 $ "failed") (-1161))))) (-950 (-953 |#1|) |#2| |#3|)) (T -985)) 
-((-2795 (*1 *2 *3 *2) (-12 (-5 *3 (-1 *2 (-953 *4))) (-4 *4 (-1047)) (-4 *2 (-950 (-953 *4) *5 *6)) (-4 *5 (-788)) (-4 *6 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $)) (-15 -1305 ((-3 $ "failed") (-1161)))))) (-5 *1 (-985 *4 *5 *6 *2)))) (-2917 (*1 *2 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $)) (-15 -1305 ((-3 $ "failed") (-1161)))))) (-4 *4 (-1047)) (-4 *5 (-788)) (-5 *1 (-985 *4 *5 *6 *2)) (-4 *2 (-950 (-953 *4) *5 *6)))) (-2917 (*1 *2 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $)) (-15 -1305 ((-3 $ "failed") (-1161)))))) (-5 *1 (-985 *4 *5 *3 *2)) (-4 *2 (-950 (-953 *4) *5 *3)))) (-3352 (*1 *2 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $)) (-15 -1305 ((-3 $ "failed") (-1161)))))) (-4 *4 (-1047)) (-4 *5 (-788)) (-5 *1 (-985 *4 *5 *6 *2)) (-4 *2 (-950 (-953 *4) *5 *6)))) (-3352 (*1 *2 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $)) (-15 -1305 ((-3 $ "failed") (-1161)))))) (-5 *1 (-985 *4 *5 *3 *2)) (-4 *2 (-950 (-953 *4) *5 *3))))) 
-(-10 -7 (-15 -3352 (|#4| |#4| |#3|)) (-15 -3352 (|#4| |#4| (-634 |#3|))) (-15 -2917 (|#4| |#4| |#3|)) (-15 -2917 (|#4| |#4| (-634 |#3|))) (-15 -2795 (|#4| (-1 |#4| (-953 |#1|)) |#4|))) 
-((-1330 ((|#2| |#3|) 34)) (-3714 (((-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) |#2|) 71)) (-3661 (((-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|)))) 86))) 
-(((-986 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3661 ((-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))))) (-15 -3714 ((-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) |#2|)) (-15 -1330 (|#2| |#3|))) (-350) (-1219 |#1|) (-1219 |#2|) (-714 |#2| |#3|)) (T -986)) 
-((-1330 (*1 *2 *3) (-12 (-4 *3 (-1219 *2)) (-4 *2 (-1219 *4)) (-5 *1 (-986 *4 *2 *3 *5)) (-4 *4 (-350)) (-4 *5 (-714 *2 *3)))) (-3714 (*1 *2 *3) (-12 (-4 *4 (-350)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 *3)) (-5 *2 (-2 (|:| -3746 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-5 *1 (-986 *4 *3 *5 *6)) (-4 *6 (-714 *3 *5)))) (-3661 (*1 *2) (-12 (-4 *3 (-350)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| -3746 (-679 *4)) (|:| |basisDen| *4) (|:| |basisInv| (-679 *4)))) (-5 *1 (-986 *3 *4 *5 *6)) (-4 *6 (-714 *4 *5))))) 
-(-10 -7 (-15 -3661 ((-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))))) (-15 -3714 ((-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) |#2|)) (-15 -1330 (|#2| |#3|))) 
-((-2950 (((-988 (-409 (-568)) (-852 |#1|) (-232 |#2| (-763)) (-242 |#1| (-409 (-568)))) (-988 (-409 (-568)) (-852 |#1|) (-232 |#2| (-763)) (-242 |#1| (-409 (-568))))) 64))) 
-(((-987 |#1| |#2|) (-10 -7 (-15 -2950 ((-988 (-409 (-568)) (-852 |#1|) (-232 |#2| (-763)) (-242 |#1| (-409 (-568)))) (-988 (-409 (-568)) (-852 |#1|) (-232 |#2| (-763)) (-242 |#1| (-409 (-568))))))) (-634 (-1161)) (-763)) (T -987)) 
-((-2950 (*1 *2 *2) (-12 (-5 *2 (-988 (-409 (-568)) (-852 *3) (-232 *4 (-763)) (-242 *3 (-409 (-568))))) (-14 *3 (-634 (-1161))) (-14 *4 (-763)) (-5 *1 (-987 *3 *4))))) 
-(-10 -7 (-15 -2950 ((-988 (-409 (-568)) (-852 |#1|) (-232 |#2| (-763)) (-242 |#1| (-409 (-568)))) (-988 (-409 (-568)) (-852 |#1|) (-232 |#2| (-763)) (-242 |#1| (-409 (-568))))))) 
-((-2447 (((-121) $ $) NIL)) (-2812 (((-3 (-121) "failed") $) 67)) (-4352 (($ $) 35 (-12 (|has| |#1| (-150)) (|has| |#1| (-301))))) (-2137 (($ $ (-3 (-121) "failed")) 68)) (-2830 (($ (-634 |#4|) |#4|) 24)) (-4487 (((-1143) $) NIL)) (-2346 (($ $) 65)) (-4022 (((-1108) $) NIL)) (-3084 (((-121) $) 66)) (-3248 (($) 29)) (-2991 ((|#4| $) 70)) (-2422 (((-634 |#4|) $) 69)) (-2745 (((-850) $) 64)) (-1717 (((-121) $ $) NIL))) 
-(((-988 |#1| |#2| |#3| |#4|) (-13 (-1090) (-608 (-850)) (-10 -8 (-15 -3248 ($)) (-15 -2830 ($ (-634 |#4|) |#4|)) (-15 -2812 ((-3 (-121) "failed") $)) (-15 -2137 ($ $ (-3 (-121) "failed"))) (-15 -3084 ((-121) $)) (-15 -2422 ((-634 |#4|) $)) (-15 -2991 (|#4| $)) (-15 -2346 ($ $)) (IF (|has| |#1| (-301)) (IF (|has| |#1| (-150)) (-15 -4352 ($ $)) |noBranch|) |noBranch|))) (-453) (-842) (-788) (-950 |#1| |#3| |#2|)) (T -988)) 
-((-3248 (*1 *1) (-12 (-4 *2 (-453)) (-4 *3 (-842)) (-4 *4 (-788)) (-5 *1 (-988 *2 *3 *4 *5)) (-4 *5 (-950 *2 *4 *3)))) (-2830 (*1 *1 *2 *3) (-12 (-5 *2 (-634 *3)) (-4 *3 (-950 *4 *6 *5)) (-4 *4 (-453)) (-4 *5 (-842)) (-4 *6 (-788)) (-5 *1 (-988 *4 *5 *6 *3)))) (-2812 (*1 *2 *1) (|partial| -12 (-4 *3 (-453)) (-4 *4 (-842)) (-4 *5 (-788)) (-5 *2 (-121)) (-5 *1 (-988 *3 *4 *5 *6)) (-4 *6 (-950 *3 *5 *4)))) (-2137 (*1 *1 *1 *2) (-12 (-5 *2 (-3 (-121) "failed")) (-4 *3 (-453)) (-4 *4 (-842)) (-4 *5 (-788)) (-5 *1 (-988 *3 *4 *5 *6)) (-4 *6 (-950 *3 *5 *4)))) (-3084 (*1 *2 *1) (-12 (-4 *3 (-453)) (-4 *4 (-842)) (-4 *5 (-788)) (-5 *2 (-121)) (-5 *1 (-988 *3 *4 *5 *6)) (-4 *6 (-950 *3 *5 *4)))) (-2422 (*1 *2 *1) (-12 (-4 *3 (-453)) (-4 *4 (-842)) (-4 *5 (-788)) (-5 *2 (-634 *6)) (-5 *1 (-988 *3 *4 *5 *6)) (-4 *6 (-950 *3 *5 *4)))) (-2991 (*1 *2 *1) (-12 (-4 *2 (-950 *3 *5 *4)) (-5 *1 (-988 *3 *4 *5 *2)) (-4 *3 (-453)) (-4 *4 (-842)) (-4 *5 (-788)))) (-2346 (*1 *1 *1) (-12 (-4 *2 (-453)) (-4 *3 (-842)) (-4 *4 (-788)) (-5 *1 (-988 *2 *3 *4 *5)) (-4 *5 (-950 *2 *4 *3)))) (-4352 (*1 *1 *1) (-12 (-4 *2 (-150)) (-4 *2 (-301)) (-4 *2 (-453)) (-4 *3 (-842)) (-4 *4 (-788)) (-5 *1 (-988 *2 *3 *4 *5)) (-4 *5 (-950 *2 *4 *3))))) 
-(-13 (-1090) (-608 (-850)) (-10 -8 (-15 -3248 ($)) (-15 -2830 ($ (-634 |#4|) |#4|)) (-15 -2812 ((-3 (-121) "failed") $)) (-15 -2137 ($ $ (-3 (-121) "failed"))) (-15 -3084 ((-121) $)) (-15 -2422 ((-634 |#4|) $)) (-15 -2991 (|#4| $)) (-15 -2346 ($ $)) (IF (|has| |#1| (-301)) (IF (|has| |#1| (-150)) (-15 -4352 ($ $)) |noBranch|) |noBranch|))) 
-((-1278 (((-121) |#5| |#5|) 37)) (-3891 (((-121) |#5| |#5|) 51)) (-2212 (((-121) |#5| (-634 |#5|)) 73) (((-121) |#5| |#5|) 60)) (-4302 (((-121) (-634 |#4|) (-634 |#4|)) 57)) (-3686 (((-121) (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|)) (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) 62)) (-2008 (((-1249)) 33)) (-1373 (((-1249) (-1143) (-1143) (-1143)) 29)) (-2164 (((-634 |#5|) (-634 |#5|)) 80)) (-2736 (((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|)))) 78)) (-3553 (((-634 (-2 (|:| -1853 (-634 |#4|)) (|:| -3001 |#5|) (|:| |ineq| (-634 |#4|)))) (-634 |#4|) (-634 |#5|) (-121) (-121)) 100)) (-2068 (((-121) |#5| |#5|) 46)) (-4350 (((-3 (-121) "failed") |#5| |#5|) 70)) (-4048 (((-121) (-634 |#4|) (-634 |#4|)) 56)) (-4354 (((-121) (-634 |#4|) (-634 |#4|)) 58)) (-2644 (((-121) (-634 |#4|) (-634 |#4|)) 59)) (-3821 (((-3 (-2 (|:| -1853 (-634 |#4|)) (|:| -3001 |#5|) (|:| |ineq| (-634 |#4|))) "failed") (-634 |#4|) |#5| (-634 |#4|) (-121) (-121) (-121) (-121) (-121)) 96)) (-2283 (((-634 |#5|) (-634 |#5|)) 42))) 
-(((-989 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1373 ((-1249) (-1143) (-1143) (-1143))) (-15 -2008 ((-1249))) (-15 -1278 ((-121) |#5| |#5|)) (-15 -2283 ((-634 |#5|) (-634 |#5|))) (-15 -2068 ((-121) |#5| |#5|)) (-15 -3891 ((-121) |#5| |#5|)) (-15 -4302 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -4048 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -4354 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -2644 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -4350 ((-3 (-121) "failed") |#5| |#5|)) (-15 -2212 ((-121) |#5| |#5|)) (-15 -2212 ((-121) |#5| (-634 |#5|))) (-15 -2164 ((-634 |#5|) (-634 |#5|))) (-15 -3686 ((-121) (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|)) (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|)))) (-15 -2736 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) (-15 -3553 ((-634 (-2 (|:| -1853 (-634 |#4|)) (|:| -3001 |#5|) (|:| |ineq| (-634 |#4|)))) (-634 |#4|) (-634 |#5|) (-121) (-121))) (-15 -3821 ((-3 (-2 (|:| -1853 (-634 |#4|)) (|:| -3001 |#5|) (|:| |ineq| (-634 |#4|))) "failed") (-634 |#4|) |#5| (-634 |#4|) (-121) (-121) (-121) (-121) (-121)))) (-453) (-788) (-842) (-1061 |#1| |#2| |#3|) (-1066 |#1| |#2| |#3| |#4|)) (T -989)) 
-((-3821 (*1 *2 *3 *4 *3 *5 *5 *5 *5 *5) (|partial| -12 (-5 *5 (-121)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *9 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| -1853 (-634 *9)) (|:| -3001 *4) (|:| |ineq| (-634 *9)))) (-5 *1 (-989 *6 *7 *8 *9 *4)) (-5 *3 (-634 *9)) (-4 *4 (-1066 *6 *7 *8 *9)))) (-3553 (*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-634 *10)) (-5 *5 (-121)) (-4 *10 (-1066 *6 *7 *8 *9)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *9 (-1061 *6 *7 *8)) (-5 *2 (-634 (-2 (|:| -1853 (-634 *9)) (|:| -3001 *10) (|:| |ineq| (-634 *9))))) (-5 *1 (-989 *6 *7 *8 *9 *10)) (-5 *3 (-634 *9)))) (-2736 (*1 *2 *2) (-12 (-5 *2 (-634 (-2 (|:| |val| (-634 *6)) (|:| -3001 *7)))) (-4 *6 (-1061 *3 *4 *5)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-989 *3 *4 *5 *6 *7)))) (-3686 (*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |val| (-634 *7)) (|:| -3001 *8))) (-4 *7 (-1061 *4 *5 *6)) (-4 *8 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *8)))) (-2164 (*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *1 (-989 *3 *4 *5 *6 *7)))) (-2212 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-989 *5 *6 *7 *8 *3)))) (-2212 (*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) (-4350 (*1 *2 *3 *3) (|partial| -12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) (-2644 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) (-4354 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) (-4048 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) (-4302 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) (-3891 (*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) (-2068 (*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) (-2283 (*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *1 (-989 *3 *4 *5 *6 *7)))) (-1278 (*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) (-2008 (*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-989 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6)))) (-1373 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-989 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7))))) 
-(-10 -7 (-15 -1373 ((-1249) (-1143) (-1143) (-1143))) (-15 -2008 ((-1249))) (-15 -1278 ((-121) |#5| |#5|)) (-15 -2283 ((-634 |#5|) (-634 |#5|))) (-15 -2068 ((-121) |#5| |#5|)) (-15 -3891 ((-121) |#5| |#5|)) (-15 -4302 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -4048 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -4354 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -2644 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -4350 ((-3 (-121) "failed") |#5| |#5|)) (-15 -2212 ((-121) |#5| |#5|)) (-15 -2212 ((-121) |#5| (-634 |#5|))) (-15 -2164 ((-634 |#5|) (-634 |#5|))) (-15 -3686 ((-121) (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|)) (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|)))) (-15 -2736 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) (-15 -3553 ((-634 (-2 (|:| -1853 (-634 |#4|)) (|:| -3001 |#5|) (|:| |ineq| (-634 |#4|)))) (-634 |#4|) (-634 |#5|) (-121) (-121))) (-15 -3821 ((-3 (-2 (|:| -1853 (-634 |#4|)) (|:| -3001 |#5|) (|:| |ineq| (-634 |#4|))) "failed") (-634 |#4|) |#5| (-634 |#4|) (-121) (-121) (-121) (-121) (-121)))) 
-((-1305 (((-1161) $) 15)) (-2850 (((-1143) $) 16)) (-2783 (($ (-1161) (-1143)) 14)) (-2745 (((-850) $) 13))) 
-(((-990) (-13 (-608 (-850)) (-10 -8 (-15 -2783 ($ (-1161) (-1143))) (-15 -1305 ((-1161) $)) (-15 -2850 ((-1143) $))))) (T -990)) 
-((-2783 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1143)) (-5 *1 (-990)))) (-1305 (*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-990)))) (-2850 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-990))))) 
-(-13 (-608 (-850)) (-10 -8 (-15 -2783 ($ (-1161) (-1143))) (-15 -1305 ((-1161) $)) (-15 -2850 ((-1143) $)))) 
-((-2795 ((|#4| (-1 |#2| |#1|) |#3|) 14))) 
-(((-991 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2795 (|#4| (-1 |#2| |#1|) |#3|))) (-558) (-558) (-993 |#1|) (-993 |#2|)) (T -991)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-558)) (-4 *6 (-558)) (-4 *2 (-993 *6)) (-5 *1 (-991 *5 *6 *4 *2)) (-4 *4 (-993 *5))))) 
-(-10 -7 (-15 -2795 (|#4| (-1 |#2| |#1|) |#3|))) 
-((-3666 (((-3 |#2| "failed") $) NIL) (((-3 (-1161) "failed") $) 65) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 (-568) "failed") $) 95)) (-2854 ((|#2| $) NIL) (((-1161) $) 60) (((-409 (-568)) $) NIL) (((-568) $) 92)) (-3164 (((-679 (-568)) (-679 $)) NIL) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) 112) (((-679 |#2|) (-679 $)) 28)) (-1731 (($) 98)) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 74) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 83)) (-1332 (($ $) 10)) (-3038 (((-3 $ "failed") $) 20)) (-2795 (($ (-1 |#2| |#2|) $) 22)) (-4434 (($) 16)) (-3880 (($ $) 54)) (-4189 (($ $) NIL) (($ $ (-763)) NIL) (($ $ (-1161)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) 36)) (-3013 (($ $) 12)) (-4278 (((-887 (-568)) $) 69) (((-887 (-381)) $) 78) (((-541) $) 40) (((-381) $) 44) (((-215) $) 47)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) 90) (($ |#2|) NIL) (($ (-1161)) 57)) (-4078 (((-763)) 31)) (-1732 (((-121) $ $) 50))) 
-(((-992 |#1| |#2|) (-10 -8 (-15 -1732 ((-121) |#1| |#1|)) (-15 -4434 (|#1|)) (-15 -3038 ((-3 |#1| "failed") |#1|)) (-15 -2854 ((-568) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -4278 ((-215) |#1|)) (-15 -4278 ((-381) |#1|)) (-15 -4278 ((-541) |#1|)) (-15 -2854 ((-1161) |#1|)) (-15 -3666 ((-3 (-1161) "failed") |#1|)) (-15 -2745 (|#1| (-1161))) (-15 -1731 (|#1|)) (-15 -3880 (|#1| |#1|)) (-15 -3013 (|#1| |#1|)) (-15 -1332 (|#1| |#1|)) (-15 -4410 ((-884 (-381) |#1|) |#1| (-887 (-381)) (-884 (-381) |#1|))) (-15 -4410 ((-884 (-568) |#1|) |#1| (-887 (-568)) (-884 (-568) |#1|))) (-15 -4278 ((-887 (-381)) |#1|)) (-15 -4278 ((-887 (-568)) |#1|)) (-15 -3164 ((-679 |#2|) (-679 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 |#1|) (-1244 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -3164 ((-679 (-568)) (-679 |#1|))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -4189 (|#1| |#1| (-1161) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)))) (-15 -4189 (|#1| |#1| (-1161))) (-15 -4189 (|#1| |#1| (-763))) (-15 -4189 (|#1| |#1|)) (-15 -2795 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2854 (|#2| |#1|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -2745 (|#1| |#2|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -2745 (|#1| |#1|)) (-15 -2745 (|#1| (-568))) (-15 -4078 ((-763))) (-15 -2745 ((-850) |#1|))) (-993 |#2|) (-558)) (T -992)) 
-((-4078 (*1 *2) (-12 (-4 *4 (-558)) (-5 *2 (-763)) (-5 *1 (-992 *3 *4)) (-4 *3 (-993 *4))))) 
-(-10 -8 (-15 -1732 ((-121) |#1| |#1|)) (-15 -4434 (|#1|)) (-15 -3038 ((-3 |#1| "failed") |#1|)) (-15 -2854 ((-568) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -4278 ((-215) |#1|)) (-15 -4278 ((-381) |#1|)) (-15 -4278 ((-541) |#1|)) (-15 -2854 ((-1161) |#1|)) (-15 -3666 ((-3 (-1161) "failed") |#1|)) (-15 -2745 (|#1| (-1161))) (-15 -1731 (|#1|)) (-15 -3880 (|#1| |#1|)) (-15 -3013 (|#1| |#1|)) (-15 -1332 (|#1| |#1|)) (-15 -4410 ((-884 (-381) |#1|) |#1| (-887 (-381)) (-884 (-381) |#1|))) (-15 -4410 ((-884 (-568) |#1|) |#1| (-887 (-568)) (-884 (-568) |#1|))) (-15 -4278 ((-887 (-381)) |#1|)) (-15 -4278 ((-887 (-568)) |#1|)) (-15 -3164 ((-679 |#2|) (-679 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 |#1|) (-1244 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -3164 ((-679 (-568)) (-679 |#1|))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -4189 (|#1| |#1| (-1161) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)))) (-15 -4189 (|#1| |#1| (-1161))) (-15 -4189 (|#1| |#1| (-763))) (-15 -4189 (|#1| |#1|)) (-15 -2795 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2854 (|#2| |#1|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -2745 (|#1| |#2|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -2745 (|#1| |#1|)) (-15 -2745 (|#1| (-568))) (-15 -4078 ((-763))) (-15 -2745 ((-850) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-1492 ((|#1| $) 135 (|has| |#1| (-301)))) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-3134 (((-3 $ "failed") $ $) 18)) (-1750 (((-420 (-1157 $)) (-1157 $)) 126 (|has| |#1| (-904)))) (-4305 (($ $) 71)) (-1678 (((-420 $) $) 70)) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 129 (|has| |#1| (-904)))) (-1497 (((-121) $ $) 57)) (-3662 (((-568) $) 116 (|has| |#1| (-815)))) (-2671 (($) 16 T CONST)) (-3666 (((-3 |#1| "failed") $) 174) (((-3 (-1161) "failed") $) 124 (|has| |#1| (-1037 (-1161)))) (((-3 (-409 (-568)) "failed") $) 108 (|has| |#1| (-1037 (-568)))) (((-3 (-568) "failed") $) 106 (|has| |#1| (-1037 (-568))))) (-2854 ((|#1| $) 173) (((-1161) $) 123 (|has| |#1| (-1037 (-1161)))) (((-409 (-568)) $) 107 (|has| |#1| (-1037 (-568)))) (((-568) $) 105 (|has| |#1| (-1037 (-568))))) (-2401 (($ $ $) 53)) (-3164 (((-679 (-568)) (-679 $)) 148 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 147 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 146) (((-679 |#1|) (-679 $)) 145)) (-2925 (((-3 $ "failed") $) 33)) (-1731 (($) 133 (|has| |#1| (-550)))) (-2412 (($ $ $) 54)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 49)) (-3927 (((-121) $) 69)) (-2033 (((-121) $) 118 (|has| |#1| (-815)))) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 142 (|has| |#1| (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 141 (|has| |#1| (-881 (-381))))) (-2735 (((-121) $) 30)) (-1332 (($ $) 137)) (-2317 ((|#1| $) 139)) (-3038 (((-3 $ "failed") $) 104 (|has| |#1| (-1136)))) (-2245 (((-121) $) 117 (|has| |#1| (-815)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-2521 (($ $ $) 114 (|has| |#1| (-842)))) (-3268 (($ $ $) 113 (|has| |#1| (-842)))) (-2795 (($ (-1 |#1| |#1|) $) 165)) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-2081 (($ $) 68)) (-4434 (($) 103 (|has| |#1| (-1136)) CONST)) (-4022 (((-1108) $) 10)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-3880 (($ $) 134 (|has| |#1| (-301)))) (-1519 ((|#1| $) 131 (|has| |#1| (-550)))) (-2905 (((-420 (-1157 $)) (-1157 $)) 128 (|has| |#1| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) 127 (|has| |#1| (-904)))) (-3848 (((-420 $) $) 72)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2595 (((-3 $ "failed") $ $) 41)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-1339 (($ $ (-634 |#1|) (-634 |#1|)) 171 (|has| |#1| (-303 |#1|))) (($ $ |#1| |#1|) 170 (|has| |#1| (-303 |#1|))) (($ $ (-288 |#1|)) 169 (|has| |#1| (-303 |#1|))) (($ $ (-634 (-288 |#1|))) 168 (|has| |#1| (-303 |#1|))) (($ $ (-634 (-1161)) (-634 |#1|)) 167 (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-1161) |#1|) 166 (|has| |#1| (-523 (-1161) |#1|)))) (-2709 (((-763) $) 56)) (-2779 (($ $ |#1|) 172 (|has| |#1| (-281 |#1| |#1|)))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 55)) (-4189 (($ $) 164 (|has| |#1| (-225))) (($ $ (-763)) 162 (|has| |#1| (-225))) (($ $ (-1161)) 160 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 159 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 158 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) 157 (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) 150) (($ $ (-1 |#1| |#1|)) 149)) (-3013 (($ $) 136)) (-2324 ((|#1| $) 138)) (-4278 (((-887 (-568)) $) 144 (|has| |#1| (-609 (-887 (-568))))) (((-887 (-381)) $) 143 (|has| |#1| (-609 (-887 (-381))))) (((-541) $) 121 (|has| |#1| (-609 (-541)))) (((-381) $) 120 (|has| |#1| (-1021))) (((-215) $) 119 (|has| |#1| (-1021)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) 130 (-2139 (|has| $ (-148)) (|has| |#1| (-904))))) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63) (($ |#1|) 177) (($ (-1161)) 125 (|has| |#1| (-1037 (-1161))))) (-4371 (((-3 $ "failed") $) 122 (-2198 (|has| |#1| (-148)) (-2139 (|has| $ (-148)) (|has| |#1| (-904)))))) (-4078 (((-763)) 28)) (-2285 ((|#1| $) 132 (|has| |#1| (-550)))) (-1826 (((-121) $ $) 38)) (-2897 (($ $) 115 (|has| |#1| (-815)))) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $) 163 (|has| |#1| (-225))) (($ $ (-763)) 161 (|has| |#1| (-225))) (($ $ (-1161)) 156 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 155 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 154 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) 153 (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) 152) (($ $ (-1 |#1| |#1|)) 151)) (-1751 (((-121) $ $) 111 (|has| |#1| (-842)))) (-1738 (((-121) $ $) 110 (|has| |#1| (-842)))) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 112 (|has| |#1| (-842)))) (-1732 (((-121) $ $) 109 (|has| |#1| (-842)))) (-1779 (($ $ $) 62) (($ |#1| |#1|) 140)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64) (($ |#1| $) 176) (($ $ |#1|) 175))) 
+((-3468 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-4016 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-2695 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-4008 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-4090 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-1461 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-3995 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-4087 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-2005 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-2029 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-3975 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-3624 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-3084 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-4040 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-2285 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-4415 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-2203 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-4497 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-4119 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-1942 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-3979 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-1674 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-4349 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-2422 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-2051 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-3296 (*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181)))) (-1472 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-763)) (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(-13 (-10 -7 (-15 -1472 ((-3 |t#1| "failed") |t#1| (-763))) (-15 -3296 ((-3 |t#1| "failed") |t#1|)) (-15 -2051 ((-3 |t#1| "failed") |t#1|)) (-15 -2422 ((-3 |t#1| "failed") |t#1|)) (-15 -4349 ((-3 |t#1| "failed") |t#1|)) (-15 -1674 ((-3 |t#1| "failed") |t#1|)) (-15 -3979 ((-3 |t#1| "failed") |t#1|)) (-15 -1942 ((-3 |t#1| "failed") |t#1|)) (-15 -4119 ((-3 |t#1| "failed") |t#1|)) (-15 -4497 ((-3 |t#1| "failed") |t#1|)) (-15 -2203 ((-3 |t#1| "failed") |t#1|)) (-15 -4415 ((-3 |t#1| "failed") |t#1|)) (-15 -2285 ((-3 |t#1| "failed") |t#1|)) (-15 -4040 ((-3 |t#1| "failed") |t#1|)) (-15 -3084 ((-3 |t#1| "failed") |t#1|)) (-15 -3624 ((-3 |t#1| "failed") |t#1|)) (-15 -3975 ((-3 |t#1| "failed") |t#1|)) (-15 -2029 ((-3 |t#1| "failed") |t#1|)) (-15 -2005 ((-3 |t#1| "failed") |t#1|)) (-15 -4087 ((-3 |t#1| "failed") |t#1|)) (-15 -3995 ((-3 |t#1| "failed") |t#1|)) (-15 -1461 ((-3 |t#1| "failed") |t#1|)) (-15 -4090 ((-3 |t#1| "failed") |t#1|)) (-15 -4008 ((-3 |t#1| "failed") |t#1|)) (-15 -2695 ((-3 |t#1| "failed") |t#1|)) (-15 -4016 ((-3 |t#1| "failed") |t#1|)) (-15 -3468 ((-3 |t#1| "failed") |t#1|)))) 
+((-2881 ((|#4| |#4| (-634 |#3|)) 55) ((|#4| |#4| |#3|) 54)) (-1286 ((|#4| |#4| (-634 |#3|)) 23) ((|#4| |#4| |#3|) 19)) (-2797 ((|#4| (-1 |#4| (-953 |#1|)) |#4|) 30))) 
+(((-985 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1286 (|#4| |#4| |#3|)) (-15 -1286 (|#4| |#4| (-634 |#3|))) (-15 -2881 (|#4| |#4| |#3|)) (-15 -2881 (|#4| |#4| (-634 |#3|))) (-15 -2797 (|#4| (-1 |#4| (-953 |#1|)) |#4|))) (-1047) (-788) (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $)) (-15 -3325 ((-3 $ "failed") (-1161))))) (-950 (-953 |#1|) |#2| |#3|)) (T -985)) 
+((-2797 (*1 *2 *3 *2) (-12 (-5 *3 (-1 *2 (-953 *4))) (-4 *4 (-1047)) (-4 *2 (-950 (-953 *4) *5 *6)) (-4 *5 (-788)) (-4 *6 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $)) (-15 -3325 ((-3 $ "failed") (-1161)))))) (-5 *1 (-985 *4 *5 *6 *2)))) (-2881 (*1 *2 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $)) (-15 -3325 ((-3 $ "failed") (-1161)))))) (-4 *4 (-1047)) (-4 *5 (-788)) (-5 *1 (-985 *4 *5 *6 *2)) (-4 *2 (-950 (-953 *4) *5 *6)))) (-2881 (*1 *2 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $)) (-15 -3325 ((-3 $ "failed") (-1161)))))) (-5 *1 (-985 *4 *5 *3 *2)) (-4 *2 (-950 (-953 *4) *5 *3)))) (-1286 (*1 *2 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $)) (-15 -3325 ((-3 $ "failed") (-1161)))))) (-4 *4 (-1047)) (-4 *5 (-788)) (-5 *1 (-985 *4 *5 *6 *2)) (-4 *2 (-950 (-953 *4) *5 *6)))) (-1286 (*1 *2 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $)) (-15 -3325 ((-3 $ "failed") (-1161)))))) (-5 *1 (-985 *4 *5 *3 *2)) (-4 *2 (-950 (-953 *4) *5 *3))))) 
+(-10 -7 (-15 -1286 (|#4| |#4| |#3|)) (-15 -1286 (|#4| |#4| (-634 |#3|))) (-15 -2881 (|#4| |#4| |#3|)) (-15 -2881 (|#4| |#4| (-634 |#3|))) (-15 -2797 (|#4| (-1 |#4| (-953 |#1|)) |#4|))) 
+((-3525 ((|#2| |#3|) 34)) (-2443 (((-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) |#2|) 71)) (-3330 (((-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|)))) 86))) 
+(((-986 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3330 ((-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))))) (-15 -2443 ((-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) |#2|)) (-15 -3525 (|#2| |#3|))) (-350) (-1219 |#1|) (-1219 |#2|) (-714 |#2| |#3|)) (T -986)) 
+((-3525 (*1 *2 *3) (-12 (-4 *3 (-1219 *2)) (-4 *2 (-1219 *4)) (-5 *1 (-986 *4 *2 *3 *5)) (-4 *4 (-350)) (-4 *5 (-714 *2 *3)))) (-2443 (*1 *2 *3) (-12 (-4 *4 (-350)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 *3)) (-5 *2 (-2 (|:| -2588 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-5 *1 (-986 *4 *3 *5 *6)) (-4 *6 (-714 *3 *5)))) (-3330 (*1 *2) (-12 (-4 *3 (-350)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| -2588 (-679 *4)) (|:| |basisDen| *4) (|:| |basisInv| (-679 *4)))) (-5 *1 (-986 *3 *4 *5 *6)) (-4 *6 (-714 *4 *5))))) 
+(-10 -7 (-15 -3330 ((-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))))) (-15 -2443 ((-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) |#2|)) (-15 -3525 (|#2| |#3|))) 
+((-2980 (((-988 (-409 (-568)) (-852 |#1|) (-232 |#2| (-763)) (-242 |#1| (-409 (-568)))) (-988 (-409 (-568)) (-852 |#1|) (-232 |#2| (-763)) (-242 |#1| (-409 (-568))))) 64))) 
+(((-987 |#1| |#2|) (-10 -7 (-15 -2980 ((-988 (-409 (-568)) (-852 |#1|) (-232 |#2| (-763)) (-242 |#1| (-409 (-568)))) (-988 (-409 (-568)) (-852 |#1|) (-232 |#2| (-763)) (-242 |#1| (-409 (-568))))))) (-634 (-1161)) (-763)) (T -987)) 
+((-2980 (*1 *2 *2) (-12 (-5 *2 (-988 (-409 (-568)) (-852 *3) (-232 *4 (-763)) (-242 *3 (-409 (-568))))) (-14 *3 (-634 (-1161))) (-14 *4 (-763)) (-5 *1 (-987 *3 *4))))) 
+(-10 -7 (-15 -2980 ((-988 (-409 (-568)) (-852 |#1|) (-232 |#2| (-763)) (-242 |#1| (-409 (-568)))) (-988 (-409 (-568)) (-852 |#1|) (-232 |#2| (-763)) (-242 |#1| (-409 (-568))))))) 
+((-2449 (((-121) $ $) NIL)) (-2814 (((-3 (-121) "failed") $) 67)) (-3267 (($ $) 35 (-12 (|has| |#1| (-150)) (|has| |#1| (-301))))) (-3477 (($ $ (-3 (-121) "failed")) 68)) (-3847 (($ (-634 |#4|) |#4|) 24)) (-1893 (((-1143) $) NIL)) (-3937 (($ $) 65)) (-4025 (((-1108) $) NIL)) (-2436 (((-121) $) 66)) (-1990 (($) 29)) (-3115 ((|#4| $) 70)) (-2384 (((-634 |#4|) $) 69)) (-2747 (((-850) $) 64)) (-1719 (((-121) $ $) NIL))) 
+(((-988 |#1| |#2| |#3| |#4|) (-13 (-1090) (-608 (-850)) (-10 -8 (-15 -1990 ($)) (-15 -3847 ($ (-634 |#4|) |#4|)) (-15 -2814 ((-3 (-121) "failed") $)) (-15 -3477 ($ $ (-3 (-121) "failed"))) (-15 -2436 ((-121) $)) (-15 -2384 ((-634 |#4|) $)) (-15 -3115 (|#4| $)) (-15 -3937 ($ $)) (IF (|has| |#1| (-301)) (IF (|has| |#1| (-150)) (-15 -3267 ($ $)) |noBranch|) |noBranch|))) (-453) (-842) (-788) (-950 |#1| |#3| |#2|)) (T -988)) 
+((-1990 (*1 *1) (-12 (-4 *2 (-453)) (-4 *3 (-842)) (-4 *4 (-788)) (-5 *1 (-988 *2 *3 *4 *5)) (-4 *5 (-950 *2 *4 *3)))) (-3847 (*1 *1 *2 *3) (-12 (-5 *2 (-634 *3)) (-4 *3 (-950 *4 *6 *5)) (-4 *4 (-453)) (-4 *5 (-842)) (-4 *6 (-788)) (-5 *1 (-988 *4 *5 *6 *3)))) (-2814 (*1 *2 *1) (|partial| -12 (-4 *3 (-453)) (-4 *4 (-842)) (-4 *5 (-788)) (-5 *2 (-121)) (-5 *1 (-988 *3 *4 *5 *6)) (-4 *6 (-950 *3 *5 *4)))) (-3477 (*1 *1 *1 *2) (-12 (-5 *2 (-3 (-121) "failed")) (-4 *3 (-453)) (-4 *4 (-842)) (-4 *5 (-788)) (-5 *1 (-988 *3 *4 *5 *6)) (-4 *6 (-950 *3 *5 *4)))) (-2436 (*1 *2 *1) (-12 (-4 *3 (-453)) (-4 *4 (-842)) (-4 *5 (-788)) (-5 *2 (-121)) (-5 *1 (-988 *3 *4 *5 *6)) (-4 *6 (-950 *3 *5 *4)))) (-2384 (*1 *2 *1) (-12 (-4 *3 (-453)) (-4 *4 (-842)) (-4 *5 (-788)) (-5 *2 (-634 *6)) (-5 *1 (-988 *3 *4 *5 *6)) (-4 *6 (-950 *3 *5 *4)))) (-3115 (*1 *2 *1) (-12 (-4 *2 (-950 *3 *5 *4)) (-5 *1 (-988 *3 *4 *5 *2)) (-4 *3 (-453)) (-4 *4 (-842)) (-4 *5 (-788)))) (-3937 (*1 *1 *1) (-12 (-4 *2 (-453)) (-4 *3 (-842)) (-4 *4 (-788)) (-5 *1 (-988 *2 *3 *4 *5)) (-4 *5 (-950 *2 *4 *3)))) (-3267 (*1 *1 *1) (-12 (-4 *2 (-150)) (-4 *2 (-301)) (-4 *2 (-453)) (-4 *3 (-842)) (-4 *4 (-788)) (-5 *1 (-988 *2 *3 *4 *5)) (-4 *5 (-950 *2 *4 *3))))) 
+(-13 (-1090) (-608 (-850)) (-10 -8 (-15 -1990 ($)) (-15 -3847 ($ (-634 |#4|) |#4|)) (-15 -2814 ((-3 (-121) "failed") $)) (-15 -3477 ($ $ (-3 (-121) "failed"))) (-15 -2436 ((-121) $)) (-15 -2384 ((-634 |#4|) $)) (-15 -3115 (|#4| $)) (-15 -3937 ($ $)) (IF (|has| |#1| (-301)) (IF (|has| |#1| (-150)) (-15 -3267 ($ $)) |noBranch|) |noBranch|))) 
+((-1337 (((-121) |#5| |#5|) 37)) (-2037 (((-121) |#5| |#5|) 51)) (-3407 (((-121) |#5| (-634 |#5|)) 73) (((-121) |#5| |#5|) 60)) (-3034 (((-121) (-634 |#4|) (-634 |#4|)) 57)) (-2301 (((-121) (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|)) (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) 62)) (-1294 (((-1249)) 33)) (-3862 (((-1249) (-1143) (-1143) (-1143)) 29)) (-3778 (((-634 |#5|) (-634 |#5|)) 80)) (-1603 (((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|)))) 78)) (-2823 (((-634 (-2 (|:| -2410 (-634 |#4|)) (|:| -3145 |#5|) (|:| |ineq| (-634 |#4|)))) (-634 |#4|) (-634 |#5|) (-121) (-121)) 100)) (-2808 (((-121) |#5| |#5|) 46)) (-3251 (((-3 (-121) "failed") |#5| |#5|) 70)) (-1569 (((-121) (-634 |#4|) (-634 |#4|)) 56)) (-3284 (((-121) (-634 |#4|) (-634 |#4|)) 58)) (-4342 (((-121) (-634 |#4|) (-634 |#4|)) 59)) (-1788 (((-3 (-2 (|:| -2410 (-634 |#4|)) (|:| -3145 |#5|) (|:| |ineq| (-634 |#4|))) "failed") (-634 |#4|) |#5| (-634 |#4|) (-121) (-121) (-121) (-121) (-121)) 96)) (-3506 (((-634 |#5|) (-634 |#5|)) 42))) 
+(((-989 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3862 ((-1249) (-1143) (-1143) (-1143))) (-15 -1294 ((-1249))) (-15 -1337 ((-121) |#5| |#5|)) (-15 -3506 ((-634 |#5|) (-634 |#5|))) (-15 -2808 ((-121) |#5| |#5|)) (-15 -2037 ((-121) |#5| |#5|)) (-15 -3034 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -1569 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -3284 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -4342 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -3251 ((-3 (-121) "failed") |#5| |#5|)) (-15 -3407 ((-121) |#5| |#5|)) (-15 -3407 ((-121) |#5| (-634 |#5|))) (-15 -3778 ((-634 |#5|) (-634 |#5|))) (-15 -2301 ((-121) (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|)) (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|)))) (-15 -1603 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) (-15 -2823 ((-634 (-2 (|:| -2410 (-634 |#4|)) (|:| -3145 |#5|) (|:| |ineq| (-634 |#4|)))) (-634 |#4|) (-634 |#5|) (-121) (-121))) (-15 -1788 ((-3 (-2 (|:| -2410 (-634 |#4|)) (|:| -3145 |#5|) (|:| |ineq| (-634 |#4|))) "failed") (-634 |#4|) |#5| (-634 |#4|) (-121) (-121) (-121) (-121) (-121)))) (-453) (-788) (-842) (-1061 |#1| |#2| |#3|) (-1066 |#1| |#2| |#3| |#4|)) (T -989)) 
+((-1788 (*1 *2 *3 *4 *3 *5 *5 *5 *5 *5) (|partial| -12 (-5 *5 (-121)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *9 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| -2410 (-634 *9)) (|:| -3145 *4) (|:| |ineq| (-634 *9)))) (-5 *1 (-989 *6 *7 *8 *9 *4)) (-5 *3 (-634 *9)) (-4 *4 (-1066 *6 *7 *8 *9)))) (-2823 (*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-634 *10)) (-5 *5 (-121)) (-4 *10 (-1066 *6 *7 *8 *9)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *9 (-1061 *6 *7 *8)) (-5 *2 (-634 (-2 (|:| -2410 (-634 *9)) (|:| -3145 *10) (|:| |ineq| (-634 *9))))) (-5 *1 (-989 *6 *7 *8 *9 *10)) (-5 *3 (-634 *9)))) (-1603 (*1 *2 *2) (-12 (-5 *2 (-634 (-2 (|:| |val| (-634 *6)) (|:| -3145 *7)))) (-4 *6 (-1061 *3 *4 *5)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-989 *3 *4 *5 *6 *7)))) (-2301 (*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |val| (-634 *7)) (|:| -3145 *8))) (-4 *7 (-1061 *4 *5 *6)) (-4 *8 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *8)))) (-3778 (*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *1 (-989 *3 *4 *5 *6 *7)))) (-3407 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-989 *5 *6 *7 *8 *3)))) (-3407 (*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) (-3251 (*1 *2 *3 *3) (|partial| -12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) (-4342 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) (-3284 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) (-1569 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) (-3034 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) (-2037 (*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) (-2808 (*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) (-3506 (*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *1 (-989 *3 *4 *5 *6 *7)))) (-1337 (*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) (-1294 (*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-989 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6)))) (-3862 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-989 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7))))) 
+(-10 -7 (-15 -3862 ((-1249) (-1143) (-1143) (-1143))) (-15 -1294 ((-1249))) (-15 -1337 ((-121) |#5| |#5|)) (-15 -3506 ((-634 |#5|) (-634 |#5|))) (-15 -2808 ((-121) |#5| |#5|)) (-15 -2037 ((-121) |#5| |#5|)) (-15 -3034 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -1569 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -3284 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -4342 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -3251 ((-3 (-121) "failed") |#5| |#5|)) (-15 -3407 ((-121) |#5| |#5|)) (-15 -3407 ((-121) |#5| (-634 |#5|))) (-15 -3778 ((-634 |#5|) (-634 |#5|))) (-15 -2301 ((-121) (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|)) (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|)))) (-15 -1603 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) (-15 -2823 ((-634 (-2 (|:| -2410 (-634 |#4|)) (|:| -3145 |#5|) (|:| |ineq| (-634 |#4|)))) (-634 |#4|) (-634 |#5|) (-121) (-121))) (-15 -1788 ((-3 (-2 (|:| -2410 (-634 |#4|)) (|:| -3145 |#5|) (|:| |ineq| (-634 |#4|))) "failed") (-634 |#4|) |#5| (-634 |#4|) (-121) (-121) (-121) (-121) (-121)))) 
+((-3325 (((-1161) $) 15)) (-2852 (((-1143) $) 16)) (-2785 (($ (-1161) (-1143)) 14)) (-2747 (((-850) $) 13))) 
+(((-990) (-13 (-608 (-850)) (-10 -8 (-15 -2785 ($ (-1161) (-1143))) (-15 -3325 ((-1161) $)) (-15 -2852 ((-1143) $))))) (T -990)) 
+((-2785 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1143)) (-5 *1 (-990)))) (-3325 (*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-990)))) (-2852 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-990))))) 
+(-13 (-608 (-850)) (-10 -8 (-15 -2785 ($ (-1161) (-1143))) (-15 -3325 ((-1161) $)) (-15 -2852 ((-1143) $)))) 
+((-2797 ((|#4| (-1 |#2| |#1|) |#3|) 14))) 
+(((-991 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2797 (|#4| (-1 |#2| |#1|) |#3|))) (-558) (-558) (-993 |#1|) (-993 |#2|)) (T -991)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-558)) (-4 *6 (-558)) (-4 *2 (-993 *6)) (-5 *1 (-991 *5 *6 *4 *2)) (-4 *4 (-993 *5))))) 
+(-10 -7 (-15 -2797 (|#4| (-1 |#2| |#1|) |#3|))) 
+((-3668 (((-3 |#2| "failed") $) NIL) (((-3 (-1161) "failed") $) 65) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 (-568) "failed") $) 95)) (-2857 ((|#2| $) NIL) (((-1161) $) 60) (((-409 (-568)) $) NIL) (((-568) $) 92)) (-1668 (((-679 (-568)) (-679 $)) NIL) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) 112) (((-679 |#2|) (-679 $)) 28)) (-1733 (($) 98)) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 74) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 83)) (-3539 (($ $) 10)) (-2214 (((-3 $ "failed") $) 20)) (-2797 (($ (-1 |#2| |#2|) $) 22)) (-4436 (($) 16)) (-1999 (($ $) 54)) (-4191 (($ $) NIL) (($ $ (-763)) NIL) (($ $ (-1161)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) 36)) (-3210 (($ $) 12)) (-4280 (((-887 (-568)) $) 69) (((-887 (-381)) $) 78) (((-541) $) 40) (((-381) $) 44) (((-215) $) 47)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) 90) (($ |#2|) NIL) (($ (-1161)) 57)) (-3425 (((-763)) 31)) (-1734 (((-121) $ $) 50))) 
+(((-992 |#1| |#2|) (-10 -8 (-15 -1734 ((-121) |#1| |#1|)) (-15 -4436 (|#1|)) (-15 -2214 ((-3 |#1| "failed") |#1|)) (-15 -2857 ((-568) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -4280 ((-215) |#1|)) (-15 -4280 ((-381) |#1|)) (-15 -4280 ((-541) |#1|)) (-15 -2857 ((-1161) |#1|)) (-15 -3668 ((-3 (-1161) "failed") |#1|)) (-15 -2747 (|#1| (-1161))) (-15 -1733 (|#1|)) (-15 -1999 (|#1| |#1|)) (-15 -3210 (|#1| |#1|)) (-15 -3539 (|#1| |#1|)) (-15 -1519 ((-884 (-381) |#1|) |#1| (-887 (-381)) (-884 (-381) |#1|))) (-15 -1519 ((-884 (-568) |#1|) |#1| (-887 (-568)) (-884 (-568) |#1|))) (-15 -4280 ((-887 (-381)) |#1|)) (-15 -4280 ((-887 (-568)) |#1|)) (-15 -1668 ((-679 |#2|) (-679 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 |#1|) (-1244 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -1668 ((-679 (-568)) (-679 |#1|))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -4191 (|#1| |#1| (-1161) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)))) (-15 -4191 (|#1| |#1| (-1161))) (-15 -4191 (|#1| |#1| (-763))) (-15 -4191 (|#1| |#1|)) (-15 -2797 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2857 (|#2| |#1|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -2747 (|#1| |#2|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -2747 (|#1| |#1|)) (-15 -2747 (|#1| (-568))) (-15 -3425 ((-763))) (-15 -2747 ((-850) |#1|))) (-993 |#2|) (-558)) (T -992)) 
+((-3425 (*1 *2) (-12 (-4 *4 (-558)) (-5 *2 (-763)) (-5 *1 (-992 *3 *4)) (-4 *3 (-993 *4))))) 
+(-10 -8 (-15 -1734 ((-121) |#1| |#1|)) (-15 -4436 (|#1|)) (-15 -2214 ((-3 |#1| "failed") |#1|)) (-15 -2857 ((-568) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -4280 ((-215) |#1|)) (-15 -4280 ((-381) |#1|)) (-15 -4280 ((-541) |#1|)) (-15 -2857 ((-1161) |#1|)) (-15 -3668 ((-3 (-1161) "failed") |#1|)) (-15 -2747 (|#1| (-1161))) (-15 -1733 (|#1|)) (-15 -1999 (|#1| |#1|)) (-15 -3210 (|#1| |#1|)) (-15 -3539 (|#1| |#1|)) (-15 -1519 ((-884 (-381) |#1|) |#1| (-887 (-381)) (-884 (-381) |#1|))) (-15 -1519 ((-884 (-568) |#1|) |#1| (-887 (-568)) (-884 (-568) |#1|))) (-15 -4280 ((-887 (-381)) |#1|)) (-15 -4280 ((-887 (-568)) |#1|)) (-15 -1668 ((-679 |#2|) (-679 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 |#1|) (-1244 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -1668 ((-679 (-568)) (-679 |#1|))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -4191 (|#1| |#1| (-1161) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)))) (-15 -4191 (|#1| |#1| (-1161))) (-15 -4191 (|#1| |#1| (-763))) (-15 -4191 (|#1| |#1|)) (-15 -2797 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -2857 (|#2| |#1|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -2747 (|#1| |#2|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -2747 (|#1| |#1|)) (-15 -2747 (|#1| (-568))) (-15 -3425 ((-763))) (-15 -2747 ((-850) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2563 ((|#1| $) 135 (|has| |#1| (-301)))) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-2689 (((-3 $ "failed") $ $) 18)) (-3863 (((-420 (-1157 $)) (-1157 $)) 126 (|has| |#1| (-904)))) (-3045 (($ $) 71)) (-3498 (((-420 $) $) 70)) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 129 (|has| |#1| (-904)))) (-2589 (((-121) $ $) 57)) (-3337 (((-568) $) 116 (|has| |#1| (-815)))) (-4490 (($) 16 T CONST)) (-3668 (((-3 |#1| "failed") $) 174) (((-3 (-1161) "failed") $) 124 (|has| |#1| (-1037 (-1161)))) (((-3 (-409 (-568)) "failed") $) 108 (|has| |#1| (-1037 (-568)))) (((-3 (-568) "failed") $) 106 (|has| |#1| (-1037 (-568))))) (-2857 ((|#1| $) 173) (((-1161) $) 123 (|has| |#1| (-1037 (-1161)))) (((-409 (-568)) $) 107 (|has| |#1| (-1037 (-568)))) (((-568) $) 105 (|has| |#1| (-1037 (-568))))) (-2403 (($ $ $) 53)) (-1668 (((-679 (-568)) (-679 $)) 148 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 147 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 146) (((-679 |#1|) (-679 $)) 145)) (-2902 (((-3 $ "failed") $) 33)) (-1733 (($) 133 (|has| |#1| (-550)))) (-2414 (($ $ $) 54)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 49)) (-2197 (((-121) $) 69)) (-1436 (((-121) $) 118 (|has| |#1| (-815)))) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 142 (|has| |#1| (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 141 (|has| |#1| (-881 (-381))))) (-1598 (((-121) $) 30)) (-3539 (($ $) 137)) (-2319 ((|#1| $) 139)) (-2214 (((-3 $ "failed") $) 104 (|has| |#1| (-1136)))) (-2859 (((-121) $) 117 (|has| |#1| (-815)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-1732 (($ $ $) 114 (|has| |#1| (-842)))) (-2047 (($ $ $) 113 (|has| |#1| (-842)))) (-2797 (($ (-1 |#1| |#1|) $) 165)) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-2083 (($ $) 68)) (-4436 (($) 103 (|has| |#1| (-1136)) CONST)) (-4025 (((-1108) $) 10)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-1999 (($ $) 134 (|has| |#1| (-301)))) (-4115 ((|#1| $) 131 (|has| |#1| (-550)))) (-2841 (((-420 (-1157 $)) (-1157 $)) 128 (|has| |#1| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) 127 (|has| |#1| (-904)))) (-3850 (((-420 $) $) 72)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2597 (((-3 $ "failed") $ $) 41)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-1339 (($ $ (-634 |#1|) (-634 |#1|)) 171 (|has| |#1| (-303 |#1|))) (($ $ |#1| |#1|) 170 (|has| |#1| (-303 |#1|))) (($ $ (-288 |#1|)) 169 (|has| |#1| (-303 |#1|))) (($ $ (-634 (-288 |#1|))) 168 (|has| |#1| (-303 |#1|))) (($ $ (-634 (-1161)) (-634 |#1|)) 167 (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-1161) |#1|) 166 (|has| |#1| (-523 (-1161) |#1|)))) (-1466 (((-763) $) 56)) (-2781 (($ $ |#1|) 172 (|has| |#1| (-281 |#1| |#1|)))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 55)) (-4191 (($ $) 164 (|has| |#1| (-225))) (($ $ (-763)) 162 (|has| |#1| (-225))) (($ $ (-1161)) 160 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 159 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 158 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) 157 (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) 150) (($ $ (-1 |#1| |#1|)) 149)) (-3210 (($ $) 136)) (-2326 ((|#1| $) 138)) (-4280 (((-887 (-568)) $) 144 (|has| |#1| (-609 (-887 (-568))))) (((-887 (-381)) $) 143 (|has| |#1| (-609 (-887 (-381))))) (((-541) $) 121 (|has| |#1| (-609 (-541)))) (((-381) $) 120 (|has| |#1| (-1021))) (((-215) $) 119 (|has| |#1| (-1021)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) 130 (-2141 (|has| $ (-148)) (|has| |#1| (-904))))) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63) (($ |#1|) 177) (($ (-1161)) 125 (|has| |#1| (-1037 (-1161))))) (-3385 (((-3 $ "failed") $) 122 (-2199 (|has| |#1| (-148)) (-2141 (|has| $ (-148)) (|has| |#1| (-904)))))) (-3425 (((-763)) 28)) (-3520 ((|#1| $) 132 (|has| |#1| (-550)))) (-2273 (((-121) $ $) 38)) (-2811 (($ $) 115 (|has| |#1| (-815)))) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $) 163 (|has| |#1| (-225))) (($ $ (-763)) 161 (|has| |#1| (-225))) (($ $ (-1161)) 156 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 155 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 154 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) 153 (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) 152) (($ $ (-1 |#1| |#1|)) 151)) (-1753 (((-121) $ $) 111 (|has| |#1| (-842)))) (-1740 (((-121) $ $) 110 (|has| |#1| (-842)))) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 112 (|has| |#1| (-842)))) (-1734 (((-121) $ $) 109 (|has| |#1| (-842)))) (-1781 (($ $ $) 62) (($ |#1| |#1|) 140)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64) (($ |#1| $) 176) (($ $ |#1|) 175))) 
 (((-993 |#1|) (-1275) (-558)) (T -993)) 
-((-1779 (*1 *1 *2 *2) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)))) (-2317 (*1 *2 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)))) (-2324 (*1 *2 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)))) (-1332 (*1 *1 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)))) (-3013 (*1 *1 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)))) (-1492 (*1 *2 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)) (-4 *2 (-301)))) (-3880 (*1 *1 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)) (-4 *2 (-301)))) (-1731 (*1 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-550)) (-4 *2 (-558)))) (-2285 (*1 *2 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)) (-4 *2 (-550)))) (-1519 (*1 *2 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)) (-4 *2 (-550))))) 
-(-13 (-365) (-43 |t#1|) (-1037 |t#1|) (-336 |t#1|) (-223 |t#1|) (-379 |t#1|) (-879 |t#1|) (-402 |t#1|) (-10 -8 (-15 -1779 ($ |t#1| |t#1|)) (-15 -2317 (|t#1| $)) (-15 -2324 (|t#1| $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (IF (|has| |t#1| (-1136)) (-6 (-1136)) |noBranch|) (IF (|has| |t#1| (-1037 (-568))) (PROGN (-6 (-1037 (-568))) (-6 (-1037 (-409 (-568))))) |noBranch|) (IF (|has| |t#1| (-842)) (-6 (-842)) |noBranch|) (IF (|has| |t#1| (-815)) (-6 (-815)) |noBranch|) (IF (|has| |t#1| (-1021)) (-6 (-1021)) |noBranch|) (IF (|has| |t#1| (-609 (-541))) (-6 (-609 (-541))) |noBranch|) (IF (|has| |t#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |t#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |t#1| (-1037 (-1161))) (-6 (-1037 (-1161))) |noBranch|) (IF (|has| |t#1| (-301)) (PROGN (-15 -1492 (|t#1| $)) (-15 -3880 ($ $))) |noBranch|) (IF (|has| |t#1| (-550)) (PROGN (-15 -1731 ($)) (-15 -2285 (|t#1| $)) (-15 -1519 (|t#1| $))) |noBranch|) (IF (|has| |t#1| (-904)) (-6 (-904)) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-43 |#1|) . T) ((-43 $) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 |#1| |#1|) . T) ((-120 $ $) . T) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) . T) ((-609 (-215)) |has| |#1| (-1021)) ((-609 (-381)) |has| |#1| (-1021)) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-609 (-887 (-381))) |has| |#1| (-609 (-887 (-381)))) ((-609 (-887 (-568))) |has| |#1| (-609 (-887 (-568)))) ((-223 |#1|) . T) ((-225) |has| |#1| (-225)) ((-238) . T) ((-281 |#1| $) |has| |#1| (-281 |#1| |#1|)) ((-285) . T) ((-301) . T) ((-303 |#1|) |has| |#1| (-303 |#1|)) ((-365) . T) ((-336 |#1|) . T) ((-379 |#1|) . T) ((-402 |#1|) . T) ((-453) . T) ((-523 (-1161) |#1|) |has| |#1| (-523 (-1161) |#1|)) ((-523 |#1| |#1|) |has| |#1| (-303 |#1|)) ((-558) . T) ((-637 (-409 (-568))) . T) ((-637 |#1|) . T) ((-637 $) . T) ((-630 (-568)) |has| |#1| (-630 (-568))) ((-630 |#1|) . T) ((-707 (-409 (-568))) . T) ((-707 |#1|) . T) ((-707 $) . T) ((-716) . T) ((-786) |has| |#1| (-815)) ((-787) |has| |#1| (-815)) ((-789) |has| |#1| (-815)) ((-790) |has| |#1| (-815)) ((-815) |has| |#1| (-815)) ((-840) |has| |#1| (-815)) ((-842) -2198 (|has| |#1| (-842)) (|has| |#1| (-815))) ((-895 (-1161)) |has| |#1| (-895 (-1161))) ((-881 (-381)) |has| |#1| (-881 (-381))) ((-881 (-568)) |has| |#1| (-881 (-568))) ((-879 |#1|) . T) ((-904) |has| |#1| (-904)) ((-916) . T) ((-1021) |has| |#1| (-1021)) ((-1037 (-409 (-568))) |has| |#1| (-1037 (-568))) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 (-1161)) |has| |#1| (-1037 (-1161))) ((-1037 |#1|) . T) ((-1053 (-409 (-568))) . T) ((-1053 |#1|) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1136) |has| |#1| (-1136)) ((-1195) . T) ((-1199) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-3444 (($ (-1127 |#1| |#2|)) 11)) (-2269 (((-1127 |#1| |#2|) $) 12)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2779 ((|#2| $ (-232 |#1| |#2|)) 16)) (-2745 (((-850) $) NIL)) (-3056 (($) NIL T CONST)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL))) 
-(((-994 |#1| |#2|) (-13 (-21) (-10 -8 (-15 -3444 ($ (-1127 |#1| |#2|))) (-15 -2269 ((-1127 |#1| |#2|) $)) (-15 -2779 (|#2| $ (-232 |#1| |#2|))))) (-917) (-365)) (T -994)) 
-((-3444 (*1 *1 *2) (-12 (-5 *2 (-1127 *3 *4)) (-14 *3 (-917)) (-4 *4 (-365)) (-5 *1 (-994 *3 *4)))) (-2269 (*1 *2 *1) (-12 (-5 *2 (-1127 *3 *4)) (-5 *1 (-994 *3 *4)) (-14 *3 (-917)) (-4 *4 (-365)))) (-2779 (*1 *2 *1 *3) (-12 (-5 *3 (-232 *4 *2)) (-14 *4 (-917)) (-4 *2 (-365)) (-5 *1 (-994 *4 *2))))) 
-(-13 (-21) (-10 -8 (-15 -3444 ($ (-1127 |#1| |#2|))) (-15 -2269 ((-1127 |#1| |#2|) $)) (-15 -2779 (|#2| $ (-232 |#1| |#2|))))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2510 (((-121) $ (-763)) 8)) (-2671 (($) 7 T CONST)) (-3475 (($ $) 43)) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) 9)) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35)) (-2166 (((-121) $ (-763)) 10)) (-3678 (((-763) $) 42)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-1890 ((|#1| $) 36)) (-4450 (($ |#1| $) 37)) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3860 ((|#1| $) 41)) (-1315 ((|#1| $) 38)) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-1383 ((|#1| |#1| $) 45)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2368 ((|#1| $) 44)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-2367 (($ (-634 |#1|)) 39)) (-4190 ((|#1| $) 40)) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-1781 (*1 *1 *2 *2) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)))) (-2319 (*1 *2 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)))) (-2326 (*1 *2 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)))) (-3539 (*1 *1 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)))) (-3210 (*1 *1 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)))) (-2563 (*1 *2 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)) (-4 *2 (-301)))) (-1999 (*1 *1 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)) (-4 *2 (-301)))) (-1733 (*1 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-550)) (-4 *2 (-558)))) (-3520 (*1 *2 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)) (-4 *2 (-550)))) (-4115 (*1 *2 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)) (-4 *2 (-550))))) 
+(-13 (-365) (-43 |t#1|) (-1037 |t#1|) (-336 |t#1|) (-223 |t#1|) (-379 |t#1|) (-879 |t#1|) (-402 |t#1|) (-10 -8 (-15 -1781 ($ |t#1| |t#1|)) (-15 -2319 (|t#1| $)) (-15 -2326 (|t#1| $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (IF (|has| |t#1| (-1136)) (-6 (-1136)) |noBranch|) (IF (|has| |t#1| (-1037 (-568))) (PROGN (-6 (-1037 (-568))) (-6 (-1037 (-409 (-568))))) |noBranch|) (IF (|has| |t#1| (-842)) (-6 (-842)) |noBranch|) (IF (|has| |t#1| (-815)) (-6 (-815)) |noBranch|) (IF (|has| |t#1| (-1021)) (-6 (-1021)) |noBranch|) (IF (|has| |t#1| (-609 (-541))) (-6 (-609 (-541))) |noBranch|) (IF (|has| |t#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |t#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |t#1| (-1037 (-1161))) (-6 (-1037 (-1161))) |noBranch|) (IF (|has| |t#1| (-301)) (PROGN (-15 -2563 (|t#1| $)) (-15 -1999 ($ $))) |noBranch|) (IF (|has| |t#1| (-550)) (PROGN (-15 -1733 ($)) (-15 -3520 (|t#1| $)) (-15 -4115 (|t#1| $))) |noBranch|) (IF (|has| |t#1| (-904)) (-6 (-904)) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-43 |#1|) . T) ((-43 $) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 |#1| |#1|) . T) ((-120 $ $) . T) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) . T) ((-609 (-215)) |has| |#1| (-1021)) ((-609 (-381)) |has| |#1| (-1021)) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-609 (-887 (-381))) |has| |#1| (-609 (-887 (-381)))) ((-609 (-887 (-568))) |has| |#1| (-609 (-887 (-568)))) ((-223 |#1|) . T) ((-225) |has| |#1| (-225)) ((-238) . T) ((-281 |#1| $) |has| |#1| (-281 |#1| |#1|)) ((-285) . T) ((-301) . T) ((-303 |#1|) |has| |#1| (-303 |#1|)) ((-365) . T) ((-336 |#1|) . T) ((-379 |#1|) . T) ((-402 |#1|) . T) ((-453) . T) ((-523 (-1161) |#1|) |has| |#1| (-523 (-1161) |#1|)) ((-523 |#1| |#1|) |has| |#1| (-303 |#1|)) ((-558) . T) ((-637 (-409 (-568))) . T) ((-637 |#1|) . T) ((-637 $) . T) ((-630 (-568)) |has| |#1| (-630 (-568))) ((-630 |#1|) . T) ((-707 (-409 (-568))) . T) ((-707 |#1|) . T) ((-707 $) . T) ((-716) . T) ((-786) |has| |#1| (-815)) ((-787) |has| |#1| (-815)) ((-789) |has| |#1| (-815)) ((-790) |has| |#1| (-815)) ((-815) |has| |#1| (-815)) ((-840) |has| |#1| (-815)) ((-842) -2199 (|has| |#1| (-842)) (|has| |#1| (-815))) ((-895 (-1161)) |has| |#1| (-895 (-1161))) ((-881 (-381)) |has| |#1| (-881 (-381))) ((-881 (-568)) |has| |#1| (-881 (-568))) ((-879 |#1|) . T) ((-904) |has| |#1| (-904)) ((-916) . T) ((-1021) |has| |#1| (-1021)) ((-1037 (-409 (-568))) |has| |#1| (-1037 (-568))) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 (-1161)) |has| |#1| (-1037 (-1161))) ((-1037 |#1|) . T) ((-1053 (-409 (-568))) . T) ((-1053 |#1|) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1136) |has| |#1| (-1136)) ((-1195) . T) ((-1199) . T)) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-3522 (($ (-1127 |#1| |#2|)) 11)) (-2271 (((-1127 |#1| |#2|) $) 12)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2781 ((|#2| $ (-232 |#1| |#2|)) 16)) (-2747 (((-850) $) NIL)) (-3058 (($) NIL T CONST)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL))) 
+(((-994 |#1| |#2|) (-13 (-21) (-10 -8 (-15 -3522 ($ (-1127 |#1| |#2|))) (-15 -2271 ((-1127 |#1| |#2|) $)) (-15 -2781 (|#2| $ (-232 |#1| |#2|))))) (-917) (-365)) (T -994)) 
+((-3522 (*1 *1 *2) (-12 (-5 *2 (-1127 *3 *4)) (-14 *3 (-917)) (-4 *4 (-365)) (-5 *1 (-994 *3 *4)))) (-2271 (*1 *2 *1) (-12 (-5 *2 (-1127 *3 *4)) (-5 *1 (-994 *3 *4)) (-14 *3 (-917)) (-4 *4 (-365)))) (-2781 (*1 *2 *1 *3) (-12 (-5 *3 (-232 *4 *2)) (-14 *4 (-917)) (-4 *2 (-365)) (-5 *1 (-994 *4 *2))))) 
+(-13 (-21) (-10 -8 (-15 -3522 ($ (-1127 |#1| |#2|))) (-15 -2271 ((-1127 |#1| |#2|) $)) (-15 -2781 (|#2| $ (-232 |#1| |#2|))))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-1667 (((-121) $ (-763)) 8)) (-4490 (($) 7 T CONST)) (-3743 (($ $) 43)) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) 9)) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35)) (-3796 (((-121) $ (-763)) 10)) (-3680 (((-763) $) 42)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-2580 ((|#1| $) 36)) (-1708 (($ |#1| $) 37)) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-1929 ((|#1| $) 41)) (-3403 ((|#1| $) 38)) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-3920 ((|#1| |#1| $) 45)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-4080 ((|#1| $) 44)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-4074 (($ (-634 |#1|)) 39)) (-4035 ((|#1| $) 40)) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-995 |#1|) (-1275) (-1195)) (T -995)) 
-((-1383 (*1 *2 *2 *1) (-12 (-4 *1 (-995 *2)) (-4 *2 (-1195)))) (-2368 (*1 *2 *1) (-12 (-4 *1 (-995 *2)) (-4 *2 (-1195)))) (-3475 (*1 *1 *1) (-12 (-4 *1 (-995 *2)) (-4 *2 (-1195)))) (-3678 (*1 *2 *1) (-12 (-4 *1 (-995 *3)) (-4 *3 (-1195)) (-5 *2 (-763)))) (-3860 (*1 *2 *1) (-12 (-4 *1 (-995 *2)) (-4 *2 (-1195)))) (-4190 (*1 *2 *1) (-12 (-4 *1 (-995 *2)) (-4 *2 (-1195))))) 
-(-13 (-111 |t#1|) (-10 -8 (-6 -4519) (-15 -1383 (|t#1| |t#1| $)) (-15 -2368 (|t#1| $)) (-15 -3475 ($ $)) (-15 -3678 ((-763) $)) (-15 -3860 (|t#1| $)) (-15 -4190 (|t#1| $)))) 
+((-3920 (*1 *2 *2 *1) (-12 (-4 *1 (-995 *2)) (-4 *2 (-1195)))) (-4080 (*1 *2 *1) (-12 (-4 *1 (-995 *2)) (-4 *2 (-1195)))) (-3743 (*1 *1 *1) (-12 (-4 *1 (-995 *2)) (-4 *2 (-1195)))) (-3680 (*1 *2 *1) (-12 (-4 *1 (-995 *3)) (-4 *3 (-1195)) (-5 *2 (-763)))) (-1929 (*1 *2 *1) (-12 (-4 *1 (-995 *2)) (-4 *2 (-1195)))) (-4035 (*1 *2 *1) (-12 (-4 *1 (-995 *2)) (-4 *2 (-1195))))) 
+(-13 (-111 |t#1|) (-10 -8 (-6 -4521) (-15 -3920 (|t#1| |t#1| $)) (-15 -4080 (|t#1| $)) (-15 -3743 ($ $)) (-15 -3680 ((-763) $)) (-15 -1929 (|t#1| $)) (-15 -4035 (|t#1| $)))) 
 (((-39) . T) ((-111 |#1|) . T) ((-105) |has| |#1| (-1090)) ((-608 (-850)) |has| |#1| (-1090)) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-1090) |has| |#1| (-1090)) ((-1195) . T)) 
-((-2537 (((-121) $) 42)) (-3666 (((-3 (-568) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 |#2| "failed") $) 45)) (-2854 (((-568) $) NIL) (((-409 (-568)) $) NIL) ((|#2| $) 43)) (-1642 (((-3 (-409 (-568)) "failed") $) 78)) (-2688 (((-121) $) 72)) (-2425 (((-409 (-568)) $) 76)) (-2735 (((-121) $) 41)) (-2657 ((|#2| $) 22)) (-2795 (($ (-1 |#2| |#2|) $) 19)) (-2081 (($ $) 61)) (-4189 (($ $) NIL) (($ $ (-763)) NIL) (($ $ (-1161)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) 34)) (-4278 (((-541) $) 67)) (-1458 (($ $) 17)) (-2745 (((-850) $) 56) (($ (-568)) 38) (($ |#2|) 36) (($ (-409 (-568))) NIL)) (-4078 (((-763)) 10)) (-2897 ((|#2| $) 71)) (-1717 (((-121) $ $) 25)) (-1732 (((-121) $ $) 69)) (-1773 (($ $) 29) (($ $ $) 28)) (-1767 (($ $ $) 26)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 33) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) 30) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL))) 
-(((-996 |#1| |#2|) (-10 -8 (-15 -2745 (|#1| (-409 (-568)))) (-15 -1732 ((-121) |#1| |#1|)) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 * (|#1| |#1| (-409 (-568)))) (-15 -2081 (|#1| |#1|)) (-15 -4278 ((-541) |#1|)) (-15 -1642 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2425 ((-409 (-568)) |#1|)) (-15 -2688 ((-121) |#1|)) (-15 -2897 (|#2| |#1|)) (-15 -2657 (|#2| |#1|)) (-15 -1458 (|#1| |#1|)) (-15 -2795 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -4189 (|#1| |#1| (-1161) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)))) (-15 -4189 (|#1| |#1| (-1161))) (-15 -4189 (|#1| |#1| (-763))) (-15 -4189 (|#1| |#1|)) (-15 -2854 (|#2| |#1|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2854 ((-568) |#1|)) (-15 -2745 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -2745 (|#1| (-568))) (-15 -4078 ((-763))) (-15 -2735 ((-121) |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 -1773 (|#1| |#1| |#1|)) (-15 -1773 (|#1| |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 -2537 ((-121) |#1|)) (-15 * (|#1| (-917) |#1|)) (-15 -1767 (|#1| |#1| |#1|)) (-15 -2745 ((-850) |#1|)) (-15 -1717 ((-121) |#1| |#1|))) (-997 |#2|) (-172)) (T -996)) 
-((-4078 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-763)) (-5 *1 (-996 *3 *4)) (-4 *3 (-997 *4))))) 
-(-10 -8 (-15 -2745 (|#1| (-409 (-568)))) (-15 -1732 ((-121) |#1| |#1|)) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 * (|#1| |#1| (-409 (-568)))) (-15 -2081 (|#1| |#1|)) (-15 -4278 ((-541) |#1|)) (-15 -1642 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2425 ((-409 (-568)) |#1|)) (-15 -2688 ((-121) |#1|)) (-15 -2897 (|#2| |#1|)) (-15 -2657 (|#2| |#1|)) (-15 -1458 (|#1| |#1|)) (-15 -2795 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -4189 (|#1| |#1| (-1161) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)))) (-15 -4189 (|#1| |#1| (-1161))) (-15 -4189 (|#1| |#1| (-763))) (-15 -4189 (|#1| |#1|)) (-15 -2854 (|#2| |#1|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2854 ((-568) |#1|)) (-15 -2745 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -2745 (|#1| (-568))) (-15 -4078 ((-763))) (-15 -2735 ((-121) |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 -1773 (|#1| |#1| |#1|)) (-15 -1773 (|#1| |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 -2537 ((-121) |#1|)) (-15 * (|#1| (-917) |#1|)) (-15 -1767 (|#1| |#1| |#1|)) (-15 -2745 ((-850) |#1|)) (-15 -1717 ((-121) |#1| |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-3666 (((-3 (-568) "failed") $) 117 (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) 115 (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 114)) (-2854 (((-568) $) 118 (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) 116 (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) 113)) (-3164 (((-679 (-568)) (-679 $)) 88 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 87 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 86) (((-679 |#1|) (-679 $)) 85)) (-2925 (((-3 $ "failed") $) 33)) (-3857 ((|#1| $) 78)) (-1642 (((-3 (-409 (-568)) "failed") $) 74 (|has| |#1| (-550)))) (-2688 (((-121) $) 76 (|has| |#1| (-550)))) (-2425 (((-409 (-568)) $) 75 (|has| |#1| (-550)))) (-2873 (($ |#1| |#1| |#1| |#1|) 79)) (-2735 (((-121) $) 30)) (-2657 ((|#1| $) 80)) (-2521 (($ $ $) 66 (|has| |#1| (-842)))) (-3268 (($ $ $) 65 (|has| |#1| (-842)))) (-2795 (($ (-1 |#1| |#1|) $) 89)) (-4487 (((-1143) $) 9)) (-2081 (($ $) 71 (|has| |#1| (-365)))) (-1927 ((|#1| $) 81)) (-3312 ((|#1| $) 82)) (-4184 ((|#1| $) 83)) (-4022 (((-1108) $) 10)) (-1339 (($ $ (-634 |#1|) (-634 |#1|)) 95 (|has| |#1| (-303 |#1|))) (($ $ |#1| |#1|) 94 (|has| |#1| (-303 |#1|))) (($ $ (-288 |#1|)) 93 (|has| |#1| (-303 |#1|))) (($ $ (-634 (-288 |#1|))) 92 (|has| |#1| (-303 |#1|))) (($ $ (-634 (-1161)) (-634 |#1|)) 91 (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-1161) |#1|) 90 (|has| |#1| (-523 (-1161) |#1|)))) (-2779 (($ $ |#1|) 96 (|has| |#1| (-281 |#1| |#1|)))) (-4189 (($ $) 112 (|has| |#1| (-225))) (($ $ (-763)) 110 (|has| |#1| (-225))) (($ $ (-1161)) 108 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 107 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 106 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) 105 (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) 98) (($ $ (-1 |#1| |#1|)) 97)) (-4278 (((-541) $) 72 (|has| |#1| (-609 (-541))))) (-1458 (($ $) 84)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 36) (($ (-409 (-568))) 60 (-2198 (|has| |#1| (-365)) (|has| |#1| (-1037 (-409 (-568))))))) (-4371 (((-3 $ "failed") $) 73 (|has| |#1| (-148)))) (-4078 (((-763)) 28)) (-2897 ((|#1| $) 77 (|has| |#1| (-1056)))) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 70 (|has| |#1| (-365)))) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $) 111 (|has| |#1| (-225))) (($ $ (-763)) 109 (|has| |#1| (-225))) (($ $ (-1161)) 104 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 103 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 102 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) 101 (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) 100) (($ $ (-1 |#1| |#1|)) 99)) (-1751 (((-121) $ $) 63 (|has| |#1| (-842)))) (-1738 (((-121) $ $) 62 (|has| |#1| (-842)))) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 64 (|has| |#1| (-842)))) (-1732 (((-121) $ $) 61 (|has| |#1| (-842)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 69 (|has| |#1| (-365)))) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37) (($ $ (-409 (-568))) 68 (|has| |#1| (-365))) (($ (-409 (-568)) $) 67 (|has| |#1| (-365))))) 
+((-1819 (((-121) $) 42)) (-3668 (((-3 (-568) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 |#2| "failed") $) 45)) (-2857 (((-568) $) NIL) (((-409 (-568)) $) NIL) ((|#2| $) 43)) (-3254 (((-3 (-409 (-568)) "failed") $) 78)) (-1338 (((-121) $) 72)) (-2394 (((-409 (-568)) $) 76)) (-1598 (((-121) $) 41)) (-4417 ((|#2| $) 22)) (-2797 (($ (-1 |#2| |#2|) $) 19)) (-2083 (($ $) 61)) (-4191 (($ $) NIL) (($ $ (-763)) NIL) (($ $ (-1161)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) 34)) (-4280 (((-541) $) 67)) (-2387 (($ $) 17)) (-2747 (((-850) $) 56) (($ (-568)) 38) (($ |#2|) 36) (($ (-409 (-568))) NIL)) (-3425 (((-763)) 10)) (-2811 ((|#2| $) 71)) (-1719 (((-121) $ $) 25)) (-1734 (((-121) $ $) 69)) (-1775 (($ $) 29) (($ $ $) 28)) (-1769 (($ $ $) 26)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 33) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) 30) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL))) 
+(((-996 |#1| |#2|) (-10 -8 (-15 -2747 (|#1| (-409 (-568)))) (-15 -1734 ((-121) |#1| |#1|)) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 * (|#1| |#1| (-409 (-568)))) (-15 -2083 (|#1| |#1|)) (-15 -4280 ((-541) |#1|)) (-15 -3254 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2394 ((-409 (-568)) |#1|)) (-15 -1338 ((-121) |#1|)) (-15 -2811 (|#2| |#1|)) (-15 -4417 (|#2| |#1|)) (-15 -2387 (|#1| |#1|)) (-15 -2797 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -4191 (|#1| |#1| (-1161) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)))) (-15 -4191 (|#1| |#1| (-1161))) (-15 -4191 (|#1| |#1| (-763))) (-15 -4191 (|#1| |#1|)) (-15 -2857 (|#2| |#1|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2857 ((-568) |#1|)) (-15 -2747 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -2747 (|#1| (-568))) (-15 -3425 ((-763))) (-15 -1598 ((-121) |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 -1775 (|#1| |#1| |#1|)) (-15 -1775 (|#1| |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 -1819 ((-121) |#1|)) (-15 * (|#1| (-917) |#1|)) (-15 -1769 (|#1| |#1| |#1|)) (-15 -2747 ((-850) |#1|)) (-15 -1719 ((-121) |#1| |#1|))) (-997 |#2|) (-172)) (T -996)) 
+((-3425 (*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-763)) (-5 *1 (-996 *3 *4)) (-4 *3 (-997 *4))))) 
+(-10 -8 (-15 -2747 (|#1| (-409 (-568)))) (-15 -1734 ((-121) |#1| |#1|)) (-15 * (|#1| (-409 (-568)) |#1|)) (-15 * (|#1| |#1| (-409 (-568)))) (-15 -2083 (|#1| |#1|)) (-15 -4280 ((-541) |#1|)) (-15 -3254 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2394 ((-409 (-568)) |#1|)) (-15 -1338 ((-121) |#1|)) (-15 -2811 (|#2| |#1|)) (-15 -4417 (|#2| |#1|)) (-15 -2387 (|#1| |#1|)) (-15 -2797 (|#1| (-1 |#2| |#2|) |#1|)) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -4191 (|#1| |#1| (-1161) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)))) (-15 -4191 (|#1| |#1| (-1161))) (-15 -4191 (|#1| |#1| (-763))) (-15 -4191 (|#1| |#1|)) (-15 -2857 (|#2| |#1|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2857 ((-568) |#1|)) (-15 -2747 (|#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 -2747 (|#1| (-568))) (-15 -3425 ((-763))) (-15 -1598 ((-121) |#1|)) (-15 * (|#1| |#1| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 -1775 (|#1| |#1| |#1|)) (-15 -1775 (|#1| |#1|)) (-15 * (|#1| (-763) |#1|)) (-15 -1819 ((-121) |#1|)) (-15 * (|#1| (-917) |#1|)) (-15 -1769 (|#1| |#1| |#1|)) (-15 -2747 ((-850) |#1|)) (-15 -1719 ((-121) |#1| |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-3668 (((-3 (-568) "failed") $) 117 (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) 115 (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) 114)) (-2857 (((-568) $) 118 (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) 116 (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) 113)) (-1668 (((-679 (-568)) (-679 $)) 88 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 87 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 86) (((-679 |#1|) (-679 $)) 85)) (-2902 (((-3 $ "failed") $) 33)) (-3859 ((|#1| $) 78)) (-3254 (((-3 (-409 (-568)) "failed") $) 74 (|has| |#1| (-550)))) (-1338 (((-121) $) 76 (|has| |#1| (-550)))) (-2394 (((-409 (-568)) $) 75 (|has| |#1| (-550)))) (-4103 (($ |#1| |#1| |#1| |#1|) 79)) (-1598 (((-121) $) 30)) (-4417 ((|#1| $) 80)) (-1732 (($ $ $) 66 (|has| |#1| (-842)))) (-2047 (($ $ $) 65 (|has| |#1| (-842)))) (-2797 (($ (-1 |#1| |#1|) $) 89)) (-1893 (((-1143) $) 9)) (-2083 (($ $) 71 (|has| |#1| (-365)))) (-4173 ((|#1| $) 81)) (-4287 ((|#1| $) 82)) (-4004 ((|#1| $) 83)) (-4025 (((-1108) $) 10)) (-1339 (($ $ (-634 |#1|) (-634 |#1|)) 95 (|has| |#1| (-303 |#1|))) (($ $ |#1| |#1|) 94 (|has| |#1| (-303 |#1|))) (($ $ (-288 |#1|)) 93 (|has| |#1| (-303 |#1|))) (($ $ (-634 (-288 |#1|))) 92 (|has| |#1| (-303 |#1|))) (($ $ (-634 (-1161)) (-634 |#1|)) 91 (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-1161) |#1|) 90 (|has| |#1| (-523 (-1161) |#1|)))) (-2781 (($ $ |#1|) 96 (|has| |#1| (-281 |#1| |#1|)))) (-4191 (($ $) 112 (|has| |#1| (-225))) (($ $ (-763)) 110 (|has| |#1| (-225))) (($ $ (-1161)) 108 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 107 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 106 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) 105 (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) 98) (($ $ (-1 |#1| |#1|)) 97)) (-4280 (((-541) $) 72 (|has| |#1| (-609 (-541))))) (-2387 (($ $) 84)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 36) (($ (-409 (-568))) 60 (-2199 (|has| |#1| (-365)) (|has| |#1| (-1037 (-409 (-568))))))) (-3385 (((-3 $ "failed") $) 73 (|has| |#1| (-148)))) (-3425 (((-763)) 28)) (-2811 ((|#1| $) 77 (|has| |#1| (-1056)))) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 70 (|has| |#1| (-365)))) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $) 111 (|has| |#1| (-225))) (($ $ (-763)) 109 (|has| |#1| (-225))) (($ $ (-1161)) 104 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 103 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 102 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) 101 (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) 100) (($ $ (-1 |#1| |#1|)) 99)) (-1753 (((-121) $ $) 63 (|has| |#1| (-842)))) (-1740 (((-121) $ $) 62 (|has| |#1| (-842)))) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 64 (|has| |#1| (-842)))) (-1734 (((-121) $ $) 61 (|has| |#1| (-842)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 69 (|has| |#1| (-365)))) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 38) (($ |#1| $) 37) (($ $ (-409 (-568))) 68 (|has| |#1| (-365))) (($ (-409 (-568)) $) 67 (|has| |#1| (-365))))) 
 (((-997 |#1|) (-1275) (-172)) (T -997)) 
-((-1458 (*1 *1 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172)))) (-4184 (*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172)))) (-3312 (*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172)))) (-1927 (*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172)))) (-2657 (*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172)))) (-2873 (*1 *1 *2 *2 *2 *2) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172)))) (-3857 (*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172)))) (-2897 (*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172)) (-4 *2 (-1056)))) (-2688 (*1 *2 *1) (-12 (-4 *1 (-997 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-121)))) (-2425 (*1 *2 *1) (-12 (-4 *1 (-997 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-409 (-568))))) (-1642 (*1 *2 *1) (|partial| -12 (-4 *1 (-997 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-409 (-568)))))) 
-(-13 (-43 |t#1|) (-413 |t#1|) (-223 |t#1|) (-336 |t#1|) (-379 |t#1|) (-10 -8 (-15 -1458 ($ $)) (-15 -4184 (|t#1| $)) (-15 -3312 (|t#1| $)) (-15 -1927 (|t#1| $)) (-15 -2657 (|t#1| $)) (-15 -2873 ($ |t#1| |t#1| |t#1| |t#1|)) (-15 -3857 (|t#1| $)) (IF (|has| |t#1| (-285)) (-6 (-285)) |noBranch|) (IF (|has| |t#1| (-842)) (-6 (-842)) |noBranch|) (IF (|has| |t#1| (-365)) (-6 (-238)) |noBranch|) (IF (|has| |t#1| (-609 (-541))) (-6 (-609 (-541))) |noBranch|) (IF (|has| |t#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |t#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |t#1| (-1056)) (-15 -2897 (|t#1| $)) |noBranch|) (IF (|has| |t#1| (-550)) (PROGN (-15 -2688 ((-121) $)) (-15 -2425 ((-409 (-568)) $)) (-15 -1642 ((-3 (-409 (-568)) "failed") $))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) |has| |#1| (-365)) ((-43 |#1|) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-365)) ((-120 |#1| |#1|) . T) ((-120 $ $) -2198 (|has| |#1| (-365)) (|has| |#1| (-285))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-223 |#1|) . T) ((-225) |has| |#1| (-225)) ((-238) |has| |#1| (-365)) ((-281 |#1| $) |has| |#1| (-281 |#1| |#1|)) ((-285) -2198 (|has| |#1| (-365)) (|has| |#1| (-285))) ((-303 |#1|) |has| |#1| (-303 |#1|)) ((-336 |#1|) . T) ((-379 |#1|) . T) ((-413 |#1|) . T) ((-523 (-1161) |#1|) |has| |#1| (-523 (-1161) |#1|)) ((-523 |#1| |#1|) |has| |#1| (-303 |#1|)) ((-637 (-409 (-568))) |has| |#1| (-365)) ((-637 |#1|) . T) ((-637 $) . T) ((-630 (-568)) |has| |#1| (-630 (-568))) ((-630 |#1|) . T) ((-707 (-409 (-568))) |has| |#1| (-365)) ((-707 |#1|) . T) ((-716) . T) ((-842) |has| |#1| (-842)) ((-895 (-1161)) |has| |#1| (-895 (-1161))) ((-1037 (-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 |#1|) . T) ((-1053 (-409 (-568))) |has| |#1| (-365)) ((-1053 |#1|) . T) ((-1053 $) -2198 (|has| |#1| (-365)) (|has| |#1| (-285))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-2795 ((|#3| (-1 |#4| |#2|) |#1|) 16))) 
-(((-998 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2795 (|#3| (-1 |#4| |#2|) |#1|))) (-997 |#2|) (-172) (-997 |#4|) (-172)) (T -998)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-172)) (-4 *6 (-172)) (-4 *2 (-997 *6)) (-5 *1 (-998 *4 *5 *2 *6)) (-4 *4 (-997 *5))))) 
-(-10 -7 (-15 -2795 (|#3| (-1 |#4| |#2|) |#1|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) NIL)) (-2854 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3857 ((|#1| $) 12)) (-1642 (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-550)))) (-2688 (((-121) $) NIL (|has| |#1| (-550)))) (-2425 (((-409 (-568)) $) NIL (|has| |#1| (-550)))) (-2873 (($ |#1| |#1| |#1| |#1|) 16)) (-2735 (((-121) $) NIL)) (-2657 ((|#1| $) NIL)) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL (|has| |#1| (-365)))) (-1927 ((|#1| $) 15)) (-3312 ((|#1| $) 14)) (-4184 ((|#1| $) 13)) (-4022 (((-1108) $) NIL)) (-1339 (($ $ (-634 |#1|) (-634 |#1|)) NIL (|has| |#1| (-303 |#1|))) (($ $ |#1| |#1|) NIL (|has| |#1| (-303 |#1|))) (($ $ (-288 |#1|)) NIL (|has| |#1| (-303 |#1|))) (($ $ (-634 (-288 |#1|))) NIL (|has| |#1| (-303 |#1|))) (($ $ (-634 (-1161)) (-634 |#1|)) NIL (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-1161) |#1|) NIL (|has| |#1| (-523 (-1161) |#1|)))) (-2779 (($ $ |#1|) NIL (|has| |#1| (-281 |#1| |#1|)))) (-4189 (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-4278 (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-1458 (($ $) NIL)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL) (($ (-409 (-568))) NIL (-2198 (|has| |#1| (-365)) (|has| |#1| (-1037 (-409 (-568))))))) (-4371 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-4078 (((-763)) NIL)) (-2897 ((|#1| $) NIL (|has| |#1| (-1056)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (-3056 (($) 8 T CONST)) (-1556 (($) 10 T CONST)) (-3190 (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 20) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ (-409 (-568))) NIL (|has| |#1| (-365))) (($ (-409 (-568)) $) NIL (|has| |#1| (-365))))) 
+((-2387 (*1 *1 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172)))) (-4004 (*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172)))) (-4287 (*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172)))) (-4173 (*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172)))) (-4417 (*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172)))) (-4103 (*1 *1 *2 *2 *2 *2) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172)))) (-3859 (*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172)))) (-2811 (*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172)) (-4 *2 (-1056)))) (-1338 (*1 *2 *1) (-12 (-4 *1 (-997 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-121)))) (-2394 (*1 *2 *1) (-12 (-4 *1 (-997 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-409 (-568))))) (-3254 (*1 *2 *1) (|partial| -12 (-4 *1 (-997 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-409 (-568)))))) 
+(-13 (-43 |t#1|) (-413 |t#1|) (-223 |t#1|) (-336 |t#1|) (-379 |t#1|) (-10 -8 (-15 -2387 ($ $)) (-15 -4004 (|t#1| $)) (-15 -4287 (|t#1| $)) (-15 -4173 (|t#1| $)) (-15 -4417 (|t#1| $)) (-15 -4103 ($ |t#1| |t#1| |t#1| |t#1|)) (-15 -3859 (|t#1| $)) (IF (|has| |t#1| (-285)) (-6 (-285)) |noBranch|) (IF (|has| |t#1| (-842)) (-6 (-842)) |noBranch|) (IF (|has| |t#1| (-365)) (-6 (-238)) |noBranch|) (IF (|has| |t#1| (-609 (-541))) (-6 (-609 (-541))) |noBranch|) (IF (|has| |t#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |t#1| (-148)) (-6 (-148)) |noBranch|) (IF (|has| |t#1| (-1056)) (-15 -2811 (|t#1| $)) |noBranch|) (IF (|has| |t#1| (-550)) (PROGN (-15 -1338 ((-121) $)) (-15 -2394 ((-409 (-568)) $)) (-15 -3254 ((-3 (-409 (-568)) "failed") $))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) |has| |#1| (-365)) ((-43 |#1|) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-365)) ((-120 |#1| |#1|) . T) ((-120 $ $) -2199 (|has| |#1| (-365)) (|has| |#1| (-285))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-223 |#1|) . T) ((-225) |has| |#1| (-225)) ((-238) |has| |#1| (-365)) ((-281 |#1| $) |has| |#1| (-281 |#1| |#1|)) ((-285) -2199 (|has| |#1| (-365)) (|has| |#1| (-285))) ((-303 |#1|) |has| |#1| (-303 |#1|)) ((-336 |#1|) . T) ((-379 |#1|) . T) ((-413 |#1|) . T) ((-523 (-1161) |#1|) |has| |#1| (-523 (-1161) |#1|)) ((-523 |#1| |#1|) |has| |#1| (-303 |#1|)) ((-637 (-409 (-568))) |has| |#1| (-365)) ((-637 |#1|) . T) ((-637 $) . T) ((-630 (-568)) |has| |#1| (-630 (-568))) ((-630 |#1|) . T) ((-707 (-409 (-568))) |has| |#1| (-365)) ((-707 |#1|) . T) ((-716) . T) ((-842) |has| |#1| (-842)) ((-895 (-1161)) |has| |#1| (-895 (-1161))) ((-1037 (-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 |#1|) . T) ((-1053 (-409 (-568))) |has| |#1| (-365)) ((-1053 |#1|) . T) ((-1053 $) -2199 (|has| |#1| (-365)) (|has| |#1| (-285))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
+((-2797 ((|#3| (-1 |#4| |#2|) |#1|) 16))) 
+(((-998 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2797 (|#3| (-1 |#4| |#2|) |#1|))) (-997 |#2|) (-172) (-997 |#4|) (-172)) (T -998)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-172)) (-4 *6 (-172)) (-4 *2 (-997 *6)) (-5 *1 (-998 *4 *5 *2 *6)) (-4 *4 (-997 *5))))) 
+(-10 -7 (-15 -2797 (|#3| (-1 |#4| |#2|) |#1|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) NIL)) (-2857 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-3859 ((|#1| $) 12)) (-3254 (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-550)))) (-1338 (((-121) $) NIL (|has| |#1| (-550)))) (-2394 (((-409 (-568)) $) NIL (|has| |#1| (-550)))) (-4103 (($ |#1| |#1| |#1| |#1|) 16)) (-1598 (((-121) $) NIL)) (-4417 ((|#1| $) NIL)) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL (|has| |#1| (-365)))) (-4173 ((|#1| $) 15)) (-4287 ((|#1| $) 14)) (-4004 ((|#1| $) 13)) (-4025 (((-1108) $) NIL)) (-1339 (($ $ (-634 |#1|) (-634 |#1|)) NIL (|has| |#1| (-303 |#1|))) (($ $ |#1| |#1|) NIL (|has| |#1| (-303 |#1|))) (($ $ (-288 |#1|)) NIL (|has| |#1| (-303 |#1|))) (($ $ (-634 (-288 |#1|))) NIL (|has| |#1| (-303 |#1|))) (($ $ (-634 (-1161)) (-634 |#1|)) NIL (|has| |#1| (-523 (-1161) |#1|))) (($ $ (-1161) |#1|) NIL (|has| |#1| (-523 (-1161) |#1|)))) (-2781 (($ $ |#1|) NIL (|has| |#1| (-281 |#1| |#1|)))) (-4191 (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-4280 (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-2387 (($ $) NIL)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL) (($ (-409 (-568))) NIL (-2199 (|has| |#1| (-365)) (|has| |#1| (-1037 (-409 (-568))))))) (-3385 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-3425 (((-763)) NIL)) (-2811 ((|#1| $) NIL (|has| |#1| (-1056)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (-3058 (($) 8 T CONST)) (-1557 (($) 10 T CONST)) (-3192 (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 20) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ (-409 (-568))) NIL (|has| |#1| (-365))) (($ (-409 (-568)) $) NIL (|has| |#1| (-365))))) 
 (((-999 |#1|) (-997 |#1|) (-172)) (T -999)) 
 NIL 
 (-997 |#1|) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2510 (((-121) $ (-763)) NIL)) (-2671 (($) NIL T CONST)) (-3475 (($ $) 20)) (-3530 (($ (-634 |#1|)) 29)) (-4360 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) NIL)) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3674 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-3678 (((-763) $) 22)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-1890 ((|#1| $) 24)) (-4450 (($ |#1| $) 15)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3860 ((|#1| $) 23)) (-1315 ((|#1| $) 19)) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-1383 ((|#1| |#1| $) 14)) (-3084 (((-121) $) 17)) (-3248 (($) NIL)) (-2368 ((|#1| $) 18)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) NIL)) (-2745 (((-850) $) NIL (|has| |#1| (-1090)))) (-2367 (($ (-634 |#1|)) NIL)) (-4190 ((|#1| $) 26)) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-1000 |#1|) (-13 (-995 |#1|) (-10 -8 (-15 -3530 ($ (-634 |#1|))) (-15 -2368 (|#1| $)) (-15 -1315 (|#1| $)) (-15 -1383 (|#1| |#1| $)) (-15 -4450 ($ |#1| $)) (-15 -1890 (|#1| $)) (-15 -3860 (|#1| $)) (-15 -4190 (|#1| $)) (-15 -3475 ($ $)) (-15 -3678 ((-763) $)) (-15 -2166 ((-121) $ (-763))) (-15 -1737 ((-121) $ (-763))) (-15 -2510 ((-121) $ (-763))) (-15 -2367 ($ (-634 |#1|))) (-15 -3084 ((-121) $)) (-15 -3248 ($)) (-15 -2671 ($)) (-15 -3863 ($ $)) (-15 -3171 ((-121) $ $)) (-15 -2795 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4520)) (-15 -3674 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-15 -4487 ((-1143) $)) (-15 -4022 ((-1108) $)) (-15 -2745 ((-850) $)) (-15 -1717 ((-121) $ $)) (-15 -2447 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4519)) (PROGN (-15 -1387 ((-121) (-1 (-121) |#1|) $)) (-15 -1319 ((-121) (-1 (-121) |#1|) $)) (-15 -4168 ((-763) (-1 (-121) |#1|) $)) (-15 -1697 ((-763) $)) (-15 -4360 ((-634 |#1|) $)) (-15 -1979 ((-634 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4519)) (IF (|has| |#1| (-1090)) (PROGN (-15 -3109 ((-121) |#1| $)) (-15 -4168 ((-763) |#1| $))) |noBranch|) |noBranch|))) (-1090)) (T -1000)) 
-((-3171 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) (-3863 (*1 *1 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) (-3248 (*1 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) (-3084 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) (-2166 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1000 *4)) (-4 *4 (-1090)))) (-1737 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1000 *4)) (-4 *4 (-1090)))) (-2510 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1000 *4)) (-4 *4 (-1090)))) (-2671 (*1 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) (-1697 (*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-763)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) (-2795 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-1000 *3)))) (-3674 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4520)) (-4 *3 (-1090)) (-5 *1 (-1000 *3)))) (-1319 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-1000 *4)))) (-1387 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-1000 *4)))) (-4168 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-763)) (-5 *1 (-1000 *4)))) (-4360 (*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-634 *3)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) (-1979 (*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-634 *3)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) (-4168 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-763)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-3109 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-121)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-4487 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-4022 (*1 *2 *1) (-12 (-5 *2 (-1108)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-1717 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2447 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2367 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-1000 *3)))) (-1315 (*1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) (-4450 (*1 *1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) (-1890 (*1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) (-1383 (*1 *2 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) (-2368 (*1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) (-3475 (*1 *1 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) (-3678 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) (-3860 (*1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) (-4190 (*1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) (-3530 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-1000 *3))))) 
-(-13 (-995 |#1|) (-10 -8 (-15 -3530 ($ (-634 |#1|))) (-15 -2368 (|#1| $)) (-15 -1315 (|#1| $)) (-15 -1383 (|#1| |#1| $)) (-15 -4450 ($ |#1| $)) (-15 -1890 (|#1| $)) (-15 -3860 (|#1| $)) (-15 -4190 (|#1| $)) (-15 -3475 ($ $)) (-15 -3678 ((-763) $)) (-15 -2166 ((-121) $ (-763))) (-15 -1737 ((-121) $ (-763))) (-15 -2510 ((-121) $ (-763))) (-15 -2367 ($ (-634 |#1|))) (-15 -3084 ((-121) $)) (-15 -3248 ($)) (-15 -2671 ($)) (-15 -3863 ($ $)) (-15 -3171 ((-121) $ $)) (-15 -2795 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4520)) (-15 -3674 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-15 -4487 ((-1143) $)) (-15 -4022 ((-1108) $)) (-15 -2745 ((-850) $)) (-15 -1717 ((-121) $ $)) (-15 -2447 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4519)) (PROGN (-15 -1387 ((-121) (-1 (-121) |#1|) $)) (-15 -1319 ((-121) (-1 (-121) |#1|) $)) (-15 -4168 ((-763) (-1 (-121) |#1|) $)) (-15 -1697 ((-763) $)) (-15 -4360 ((-634 |#1|) $)) (-15 -1979 ((-634 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4519)) (IF (|has| |#1| (-1090)) (PROGN (-15 -3109 ((-121) |#1| $)) (-15 -4168 ((-763) |#1| $))) |noBranch|) |noBranch|))) 
-((-1902 (($ $) 12)) (-4044 (($ $ (-568)) 13))) 
-(((-1001 |#1|) (-10 -8 (-15 -1902 (|#1| |#1|)) (-15 -4044 (|#1| |#1| (-568)))) (-1002)) (T -1001)) 
-NIL 
-(-10 -8 (-15 -1902 (|#1| |#1|)) (-15 -4044 (|#1| |#1| (-568)))) 
-((-1902 (($ $) 6)) (-4044 (($ $ (-568)) 7)) (** (($ $ (-409 (-568))) 8))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1667 (((-121) $ (-763)) NIL)) (-4490 (($) NIL T CONST)) (-3743 (($ $) 20)) (-4126 (($ (-634 |#1|)) 29)) (-3317 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) NIL)) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-2253 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-3680 (((-763) $) 22)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-2580 ((|#1| $) 24)) (-1708 (($ |#1| $) 15)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-1929 ((|#1| $) 23)) (-3403 ((|#1| $) 19)) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-3920 ((|#1| |#1| $) 14)) (-2436 (((-121) $) 17)) (-1990 (($) NIL)) (-4080 ((|#1| $) 18)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) NIL)) (-2747 (((-850) $) NIL (|has| |#1| (-1090)))) (-4074 (($ (-634 |#1|)) NIL)) (-4035 ((|#1| $) 26)) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-1000 |#1|) (-13 (-995 |#1|) (-10 -8 (-15 -4126 ($ (-634 |#1|))) (-15 -4080 (|#1| $)) (-15 -3403 (|#1| $)) (-15 -3920 (|#1| |#1| $)) (-15 -1708 ($ |#1| $)) (-15 -2580 (|#1| $)) (-15 -1929 (|#1| $)) (-15 -4035 (|#1| $)) (-15 -3743 ($ $)) (-15 -3680 ((-763) $)) (-15 -3796 ((-121) $ (-763))) (-15 -3791 ((-121) $ (-763))) (-15 -1667 ((-121) $ (-763))) (-15 -4074 ($ (-634 |#1|))) (-15 -2436 ((-121) $)) (-15 -1990 ($)) (-15 -4490 ($)) (-15 -3865 ($ $)) (-15 -1702 ((-121) $ $)) (-15 -2797 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4522)) (-15 -2253 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-15 -1893 ((-1143) $)) (-15 -4025 ((-1108) $)) (-15 -2747 ((-850) $)) (-15 -1719 ((-121) $ $)) (-15 -2449 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4521)) (PROGN (-15 -3951 ((-121) (-1 (-121) |#1|) $)) (-15 -3437 ((-121) (-1 (-121) |#1|) $)) (-15 -4170 ((-763) (-1 (-121) |#1|) $)) (-15 -1699 ((-763) $)) (-15 -3317 ((-634 |#1|) $)) (-15 -4406 ((-634 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4521)) (IF (|has| |#1| (-1090)) (PROGN (-15 -2551 ((-121) |#1| $)) (-15 -4170 ((-763) |#1| $))) |noBranch|) |noBranch|))) (-1090)) (T -1000)) 
+((-1702 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) (-3865 (*1 *1 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) (-1990 (*1 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) (-2436 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) (-3796 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1000 *4)) (-4 *4 (-1090)))) (-3791 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1000 *4)) (-4 *4 (-1090)))) (-1667 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1000 *4)) (-4 *4 (-1090)))) (-4490 (*1 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) (-1699 (*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-763)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) (-2797 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-1000 *3)))) (-2253 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4522)) (-4 *3 (-1090)) (-5 *1 (-1000 *3)))) (-3437 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-1000 *4)))) (-3951 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-1000 *4)))) (-4170 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-763)) (-5 *1 (-1000 *4)))) (-3317 (*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-634 *3)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) (-4406 (*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-634 *3)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) (-4170 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-763)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2551 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-121)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-1893 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-4025 (*1 *2 *1) (-12 (-5 *2 (-1108)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-1719 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2449 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-4074 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-1000 *3)))) (-3403 (*1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) (-1708 (*1 *1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) (-2580 (*1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) (-3920 (*1 *2 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) (-4080 (*1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) (-3743 (*1 *1 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) (-3680 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) (-1929 (*1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) (-4035 (*1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) (-4126 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-1000 *3))))) 
+(-13 (-995 |#1|) (-10 -8 (-15 -4126 ($ (-634 |#1|))) (-15 -4080 (|#1| $)) (-15 -3403 (|#1| $)) (-15 -3920 (|#1| |#1| $)) (-15 -1708 ($ |#1| $)) (-15 -2580 (|#1| $)) (-15 -1929 (|#1| $)) (-15 -4035 (|#1| $)) (-15 -3743 ($ $)) (-15 -3680 ((-763) $)) (-15 -3796 ((-121) $ (-763))) (-15 -3791 ((-121) $ (-763))) (-15 -1667 ((-121) $ (-763))) (-15 -4074 ($ (-634 |#1|))) (-15 -2436 ((-121) $)) (-15 -1990 ($)) (-15 -4490 ($)) (-15 -3865 ($ $)) (-15 -1702 ((-121) $ $)) (-15 -2797 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4522)) (-15 -2253 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-15 -1893 ((-1143) $)) (-15 -4025 ((-1108) $)) (-15 -2747 ((-850) $)) (-15 -1719 ((-121) $ $)) (-15 -2449 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4521)) (PROGN (-15 -3951 ((-121) (-1 (-121) |#1|) $)) (-15 -3437 ((-121) (-1 (-121) |#1|) $)) (-15 -4170 ((-763) (-1 (-121) |#1|) $)) (-15 -1699 ((-763) $)) (-15 -3317 ((-634 |#1|) $)) (-15 -4406 ((-634 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4521)) (IF (|has| |#1| (-1090)) (PROGN (-15 -2551 ((-121) |#1| $)) (-15 -4170 ((-763) |#1| $))) |noBranch|) |noBranch|))) 
+((-1904 (($ $) 12)) (-1550 (($ $ (-568)) 13))) 
+(((-1001 |#1|) (-10 -8 (-15 -1904 (|#1| |#1|)) (-15 -1550 (|#1| |#1| (-568)))) (-1002)) (T -1001)) 
+NIL 
+(-10 -8 (-15 -1904 (|#1| |#1|)) (-15 -1550 (|#1| |#1| (-568)))) 
+((-1904 (($ $) 6)) (-1550 (($ $ (-568)) 7)) (** (($ $ (-409 (-568))) 8))) 
 (((-1002) (-1275)) (T -1002)) 
-((** (*1 *1 *1 *2) (-12 (-4 *1 (-1002)) (-5 *2 (-409 (-568))))) (-4044 (*1 *1 *1 *2) (-12 (-4 *1 (-1002)) (-5 *2 (-568)))) (-1902 (*1 *1 *1) (-4 *1 (-1002)))) 
-(-13 (-10 -8 (-15 -1902 ($ $)) (-15 -4044 ($ $ (-568))) (-15 ** ($ $ (-409 (-568)))))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2646 (((-2 (|:| |num| (-1244 |#2|)) (|:| |den| |#2|)) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| (-409 |#2|) (-365)))) (-2227 (($ $) NIL (|has| (-409 |#2|) (-365)))) (-1573 (((-121) $) NIL (|has| (-409 |#2|) (-365)))) (-4255 (((-679 (-409 |#2|)) (-1244 $)) NIL) (((-679 (-409 |#2|))) NIL)) (-1932 (((-409 |#2|) $) NIL)) (-3211 (((-1169 (-917) (-763)) (-568)) NIL (|has| (-409 |#2|) (-350)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL (|has| (-409 |#2|) (-365)))) (-1678 (((-420 $) $) NIL (|has| (-409 |#2|) (-365)))) (-1497 (((-121) $ $) NIL (|has| (-409 |#2|) (-365)))) (-3983 (((-763)) NIL (|has| (-409 |#2|) (-370)))) (-3926 (((-121)) NIL)) (-1965 (((-121) |#1|) 147) (((-121) |#2|) 152)) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) NIL (|has| (-409 |#2|) (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| (-409 |#2|) (-1037 (-409 (-568))))) (((-3 (-409 |#2|) "failed") $) NIL)) (-2854 (((-568) $) NIL (|has| (-409 |#2|) (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| (-409 |#2|) (-1037 (-409 (-568))))) (((-409 |#2|) $) NIL)) (-3498 (($ (-1244 (-409 |#2|)) (-1244 $)) NIL) (($ (-1244 (-409 |#2|))) 70) (($ (-1244 |#2|) |#2|) NIL)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-409 |#2|) (-350)))) (-2401 (($ $ $) NIL (|has| (-409 |#2|) (-365)))) (-1709 (((-679 (-409 |#2|)) $ (-1244 $)) NIL) (((-679 (-409 |#2|)) $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| (-409 |#2|) (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| (-409 |#2|) (-630 (-568)))) (((-2 (|:| -2928 (-679 (-409 |#2|))) (|:| |vec| (-1244 (-409 |#2|)))) (-679 $) (-1244 $)) NIL) (((-679 (-409 |#2|)) (-679 $)) NIL)) (-3692 (((-1244 $) (-1244 $)) NIL)) (-3092 (($ |#3|) 65) (((-3 $ "failed") (-409 |#3|)) NIL (|has| (-409 |#2|) (-365)))) (-2925 (((-3 $ "failed") $) NIL)) (-1895 (((-634 (-634 |#1|))) NIL (|has| |#1| (-370)))) (-2234 (((-121) |#1| |#1|) NIL)) (-3700 (((-917)) NIL)) (-1731 (($) NIL (|has| (-409 |#2|) (-370)))) (-4449 (((-121)) NIL)) (-4481 (((-121) |#1|) 56) (((-121) |#2|) 149)) (-2412 (($ $ $) NIL (|has| (-409 |#2|) (-365)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| (-409 |#2|) (-365)))) (-3250 (($ $) NIL)) (-4220 (($) NIL (|has| (-409 |#2|) (-350)))) (-4456 (((-121) $) NIL (|has| (-409 |#2|) (-350)))) (-3218 (($ $ (-763)) NIL (|has| (-409 |#2|) (-350))) (($ $) NIL (|has| (-409 |#2|) (-350)))) (-3927 (((-121) $) NIL (|has| (-409 |#2|) (-365)))) (-4477 (((-917) $) NIL (|has| (-409 |#2|) (-350))) (((-828 (-917)) $) NIL (|has| (-409 |#2|) (-350)))) (-2735 (((-121) $) NIL)) (-3900 (((-763)) NIL)) (-3017 (((-1244 $) (-1244 $)) NIL)) (-2657 (((-409 |#2|) $) NIL)) (-1296 (((-634 (-953 |#1|)) (-1161)) NIL (|has| |#1| (-365)))) (-3038 (((-3 $ "failed") $) NIL (|has| (-409 |#2|) (-350)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| (-409 |#2|) (-365)))) (-2045 ((|#3| $) NIL (|has| (-409 |#2|) (-365)))) (-3683 (((-917) $) NIL (|has| (-409 |#2|) (-370)))) (-3085 ((|#3| $) NIL)) (-2495 (($ (-634 $)) NIL (|has| (-409 |#2|) (-365))) (($ $ $) NIL (|has| (-409 |#2|) (-365)))) (-4487 (((-1143) $) NIL)) (-1300 (((-679 (-409 |#2|))) 52)) (-4472 (((-679 (-409 |#2|))) 51)) (-2081 (($ $) NIL (|has| (-409 |#2|) (-365)))) (-4368 (($ (-1244 |#2|) |#2|) 71)) (-3036 (((-679 (-409 |#2|))) 50)) (-1630 (((-679 (-409 |#2|))) 49)) (-1557 (((-2 (|:| |num| (-679 |#2|)) (|:| |den| |#2|)) (-1 |#2| |#2|)) 86)) (-1658 (((-2 (|:| |num| (-1244 |#2|)) (|:| |den| |#2|)) $) 77)) (-1820 (((-1244 $)) 46)) (-3661 (((-1244 $)) 45)) (-3874 (((-121) $) NIL)) (-1489 (((-121) $) NIL) (((-121) $ |#1|) NIL) (((-121) $ |#2|) NIL)) (-4434 (($) NIL (|has| (-409 |#2|) (-350)) CONST)) (-4355 (($ (-917)) NIL (|has| (-409 |#2|) (-370)))) (-3541 (((-3 |#2| "failed")) 63)) (-4022 (((-1108) $) NIL)) (-2126 (((-763)) NIL)) (-2704 (($) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| (-409 |#2|) (-365)))) (-2721 (($ (-634 $)) NIL (|has| (-409 |#2|) (-365))) (($ $ $) NIL (|has| (-409 |#2|) (-365)))) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) NIL (|has| (-409 |#2|) (-350)))) (-3848 (((-420 $) $) NIL (|has| (-409 |#2|) (-365)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| (-409 |#2|) (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| (-409 |#2|) (-365)))) (-2595 (((-3 $ "failed") $ $) NIL (|has| (-409 |#2|) (-365)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| (-409 |#2|) (-365)))) (-2709 (((-763) $) NIL (|has| (-409 |#2|) (-365)))) (-2779 ((|#1| $ |#1| |#1|) NIL)) (-3633 (((-3 |#2| "failed")) 62)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| (-409 |#2|) (-365)))) (-2217 (((-409 |#2|) (-1244 $)) NIL) (((-409 |#2|)) 42)) (-3143 (((-763) $) NIL (|has| (-409 |#2|) (-350))) (((-3 (-763) "failed") $ $) NIL (|has| (-409 |#2|) (-350)))) (-4189 (($ $ (-1 (-409 |#2|) (-409 |#2|)) (-763)) NIL (|has| (-409 |#2|) (-365))) (($ $ (-1 (-409 |#2|) (-409 |#2|))) NIL (|has| (-409 |#2|) (-365))) (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-763)) NIL (-2198 (-12 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350)))) (($ $) NIL (-2198 (-12 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350))))) (-4387 (((-679 (-409 |#2|)) (-1244 $) (-1 (-409 |#2|) (-409 |#2|))) NIL (|has| (-409 |#2|) (-365)))) (-1626 ((|#3|) 53)) (-3065 (($) NIL (|has| (-409 |#2|) (-350)))) (-4073 (((-1244 (-409 |#2|)) $ (-1244 $)) NIL) (((-679 (-409 |#2|)) (-1244 $) (-1244 $)) NIL) (((-1244 (-409 |#2|)) $) 72) (((-679 (-409 |#2|)) (-1244 $)) NIL)) (-4278 (((-1244 (-409 |#2|)) $) NIL) (($ (-1244 (-409 |#2|))) NIL) ((|#3| $) NIL) (($ |#3|) NIL)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| (-409 |#2|) (-350)))) (-3016 (((-1244 $) (-1244 $)) NIL)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ (-409 |#2|)) NIL) (($ (-409 (-568))) NIL (-2198 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-1037 (-409 (-568)))))) (($ $) NIL (|has| (-409 |#2|) (-365)))) (-4371 (($ $) NIL (|has| (-409 |#2|) (-350))) (((-3 $ "failed") $) NIL (|has| (-409 |#2|) (-148)))) (-2678 ((|#3| $) NIL)) (-4078 (((-763)) NIL)) (-4199 (((-121)) 60)) (-2712 (((-121) |#1|) 153) (((-121) |#2|) 154)) (-3746 (((-1244 $)) 124)) (-1826 (((-121) $ $) NIL (|has| (-409 |#2|) (-365)))) (-3223 (((-2 (|:| |num| $) (|:| |den| |#2|) (|:| |derivden| |#2|) (|:| |gd| |#2|)) $ (-1 |#2| |#2|)) NIL)) (-2262 (((-121)) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| (-409 |#2|) (-365)))) (-3056 (($) 94 T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $ (-1 (-409 |#2|) (-409 |#2|)) (-763)) NIL (|has| (-409 |#2|) (-365))) (($ $ (-1 (-409 |#2|) (-409 |#2|))) NIL (|has| (-409 |#2|) (-365))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-763)) NIL (-2198 (-12 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350)))) (($ $) NIL (-2198 (-12 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350))))) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ $) NIL (|has| (-409 |#2|) (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| (-409 |#2|) (-365)))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 |#2|)) NIL) (($ (-409 |#2|) $) NIL) (($ (-409 (-568)) $) NIL (|has| (-409 |#2|) (-365))) (($ $ (-409 (-568))) NIL (|has| (-409 |#2|) (-365))))) 
+((** (*1 *1 *1 *2) (-12 (-4 *1 (-1002)) (-5 *2 (-409 (-568))))) (-1550 (*1 *1 *1 *2) (-12 (-4 *1 (-1002)) (-5 *2 (-568)))) (-1904 (*1 *1 *1) (-4 *1 (-1002)))) 
+(-13 (-10 -8 (-15 -1904 ($ $)) (-15 -1550 ($ $ (-568))) (-15 ** ($ $ (-409 (-568)))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-4354 (((-2 (|:| |num| (-1244 |#2|)) (|:| |den| |#2|)) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| (-409 |#2|) (-365)))) (-3661 (($ $) NIL (|has| (-409 |#2|) (-365)))) (-4426 (((-121) $) NIL (|has| (-409 |#2|) (-365)))) (-2883 (((-679 (-409 |#2|)) (-1244 $)) NIL) (((-679 (-409 |#2|))) NIL)) (-1934 (((-409 |#2|) $) NIL)) (-1856 (((-1169 (-917) (-763)) (-568)) NIL (|has| (-409 |#2|) (-350)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL (|has| (-409 |#2|) (-365)))) (-3498 (((-420 $) $) NIL (|has| (-409 |#2|) (-365)))) (-2589 (((-121) $ $) NIL (|has| (-409 |#2|) (-365)))) (-3986 (((-763)) NIL (|has| (-409 |#2|) (-370)))) (-2191 (((-121)) NIL)) (-4347 (((-121) |#1|) 147) (((-121) |#2|) 152)) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) NIL (|has| (-409 |#2|) (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| (-409 |#2|) (-1037 (-409 (-568))))) (((-3 (-409 |#2|) "failed") $) NIL)) (-2857 (((-568) $) NIL (|has| (-409 |#2|) (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| (-409 |#2|) (-1037 (-409 (-568))))) (((-409 |#2|) $) NIL)) (-3899 (($ (-1244 (-409 |#2|)) (-1244 $)) NIL) (($ (-1244 (-409 |#2|))) 70) (($ (-1244 |#2|) |#2|) NIL)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| (-409 |#2|) (-350)))) (-2403 (($ $ $) NIL (|has| (-409 |#2|) (-365)))) (-3653 (((-679 (-409 |#2|)) $ (-1244 $)) NIL) (((-679 (-409 |#2|)) $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| (-409 |#2|) (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| (-409 |#2|) (-630 (-568)))) (((-2 (|:| -2908 (-679 (-409 |#2|))) (|:| |vec| (-1244 (-409 |#2|)))) (-679 $) (-1244 $)) NIL) (((-679 (-409 |#2|)) (-679 $)) NIL)) (-2331 (((-1244 $) (-1244 $)) NIL)) (-3094 (($ |#3|) 65) (((-3 $ "failed") (-409 |#3|)) NIL (|has| (-409 |#2|) (-365)))) (-2902 (((-3 $ "failed") $) NIL)) (-2603 (((-634 (-634 |#1|))) NIL (|has| |#1| (-370)))) (-2679 (((-121) |#1| |#1|) NIL)) (-2371 (((-917)) NIL)) (-1733 (($) NIL (|has| (-409 |#2|) (-370)))) (-1700 (((-121)) NIL)) (-1862 (((-121) |#1|) 56) (((-121) |#2|) 149)) (-2414 (($ $ $) NIL (|has| (-409 |#2|) (-365)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| (-409 |#2|) (-365)))) (-1998 (($ $) NIL)) (-4188 (($) NIL (|has| (-409 |#2|) (-350)))) (-1748 (((-121) $) NIL (|has| (-409 |#2|) (-350)))) (-1887 (($ $ (-763)) NIL (|has| (-409 |#2|) (-350))) (($ $) NIL (|has| (-409 |#2|) (-350)))) (-2197 (((-121) $) NIL (|has| (-409 |#2|) (-365)))) (-1844 (((-917) $) NIL (|has| (-409 |#2|) (-350))) (((-828 (-917)) $) NIL (|has| (-409 |#2|) (-350)))) (-1598 (((-121) $) NIL)) (-2066 (((-763)) NIL)) (-3233 (((-1244 $) (-1244 $)) NIL)) (-4417 (((-409 |#2|) $) NIL)) (-3247 (((-634 (-953 |#1|)) (-1161)) NIL (|has| |#1| (-365)))) (-2214 (((-3 $ "failed") $) NIL (|has| (-409 |#2|) (-350)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| (-409 |#2|) (-365)))) (-1497 ((|#3| $) NIL (|has| (-409 |#2|) (-365)))) (-2291 (((-917) $) NIL (|has| (-409 |#2|) (-370)))) (-3087 ((|#3| $) NIL)) (-2498 (($ (-634 $)) NIL (|has| (-409 |#2|) (-365))) (($ $ $) NIL (|has| (-409 |#2|) (-365)))) (-1893 (((-1143) $) NIL)) (-3281 (((-679 (-409 |#2|))) 52)) (-1822 (((-679 (-409 |#2|))) 51)) (-2083 (($ $) NIL (|has| (-409 |#2|) (-365)))) (-3368 (($ (-1244 |#2|) |#2|) 71)) (-2208 (((-679 (-409 |#2|))) 50)) (-1515 (((-679 (-409 |#2|))) 49)) (-4339 (((-2 (|:| |num| (-679 |#2|)) (|:| |den| |#2|)) (-1 |#2| |#2|)) 86)) (-3363 (((-2 (|:| |num| (-1244 |#2|)) (|:| |den| |#2|)) $) 77)) (-2239 (((-1244 $)) 46)) (-3330 (((-1244 $)) 45)) (-1979 (((-121) $) NIL)) (-2548 (((-121) $) NIL) (((-121) $ |#1|) NIL) (((-121) $ |#2|) NIL)) (-4436 (($) NIL (|has| (-409 |#2|) (-350)) CONST)) (-4357 (($ (-917)) NIL (|has| (-409 |#2|) (-370)))) (-4201 (((-3 |#2| "failed")) 63)) (-4025 (((-1108) $) NIL)) (-3383 (((-763)) NIL)) (-2707 (($) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| (-409 |#2|) (-365)))) (-2723 (($ (-634 $)) NIL (|has| (-409 |#2|) (-365))) (($ $ $) NIL (|has| (-409 |#2|) (-365)))) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) NIL (|has| (-409 |#2|) (-350)))) (-3850 (((-420 $) $) NIL (|has| (-409 |#2|) (-365)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| (-409 |#2|) (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| (-409 |#2|) (-365)))) (-2597 (((-3 $ "failed") $ $) NIL (|has| (-409 |#2|) (-365)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| (-409 |#2|) (-365)))) (-1466 (((-763) $) NIL (|has| (-409 |#2|) (-365)))) (-2781 ((|#1| $ |#1| |#1|) NIL)) (-3146 (((-3 |#2| "failed")) 62)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| (-409 |#2|) (-365)))) (-3440 (((-409 |#2|) (-1244 $)) NIL) (((-409 |#2|)) 42)) (-2721 (((-763) $) NIL (|has| (-409 |#2|) (-350))) (((-3 (-763) "failed") $ $) NIL (|has| (-409 |#2|) (-350)))) (-4191 (($ $ (-1 (-409 |#2|) (-409 |#2|)) (-763)) NIL (|has| (-409 |#2|) (-365))) (($ $ (-1 (-409 |#2|) (-409 |#2|))) NIL (|has| (-409 |#2|) (-365))) (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-763)) NIL (-2199 (-12 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350)))) (($ $) NIL (-2199 (-12 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350))))) (-1391 (((-679 (-409 |#2|)) (-1244 $) (-1 (-409 |#2|) (-409 |#2|))) NIL (|has| (-409 |#2|) (-365)))) (-1492 ((|#3|) 53)) (-2330 (($) NIL (|has| (-409 |#2|) (-350)))) (-1656 (((-1244 (-409 |#2|)) $ (-1244 $)) NIL) (((-679 (-409 |#2|)) (-1244 $) (-1244 $)) NIL) (((-1244 (-409 |#2|)) $) 72) (((-679 (-409 |#2|)) (-1244 $)) NIL)) (-4280 (((-1244 (-409 |#2|)) $) NIL) (($ (-1244 (-409 |#2|))) NIL) ((|#3| $) NIL) (($ |#3|) NIL)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| (-409 |#2|) (-350)))) (-3224 (((-1244 $) (-1244 $)) NIL)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ (-409 |#2|)) NIL) (($ (-409 (-568))) NIL (-2199 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-1037 (-409 (-568)))))) (($ $) NIL (|has| (-409 |#2|) (-365)))) (-3385 (($ $) NIL (|has| (-409 |#2|) (-350))) (((-3 $ "failed") $) NIL (|has| (-409 |#2|) (-148)))) (-1295 ((|#3| $) NIL)) (-3425 (((-763)) NIL)) (-4077 (((-121)) 60)) (-1487 (((-121) |#1|) 153) (((-121) |#2|) 154)) (-2588 (((-1244 $)) 124)) (-2273 (((-121) $ $) NIL (|has| (-409 |#2|) (-365)))) (-1900 (((-2 (|:| |num| $) (|:| |den| |#2|) (|:| |derivden| |#2|) (|:| |gd| |#2|)) $ (-1 |#2| |#2|)) NIL)) (-3341 (((-121)) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| (-409 |#2|) (-365)))) (-3058 (($) 94 T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $ (-1 (-409 |#2|) (-409 |#2|)) (-763)) NIL (|has| (-409 |#2|) (-365))) (($ $ (-1 (-409 |#2|) (-409 |#2|))) NIL (|has| (-409 |#2|) (-365))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| (-409 |#2|) (-365)) (|has| (-409 |#2|) (-895 (-1161))))) (($ $ (-763)) NIL (-2199 (-12 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350)))) (($ $) NIL (-2199 (-12 (|has| (-409 |#2|) (-225)) (|has| (-409 |#2|) (-365))) (|has| (-409 |#2|) (-350))))) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ $) NIL (|has| (-409 |#2|) (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| (-409 |#2|) (-365)))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 |#2|)) NIL) (($ (-409 |#2|) $) NIL) (($ (-409 (-568)) $) NIL (|has| (-409 |#2|) (-365))) (($ $ (-409 (-568))) NIL (|has| (-409 |#2|) (-365))))) 
 (((-1003 |#1| |#2| |#3| |#4| |#5|) (-340 |#1| |#2| |#3|) (-1199) (-1219 |#1|) (-1219 (-409 |#2|)) (-409 |#2|) (-763)) (T -1003)) 
 NIL 
 (-340 |#1| |#2| |#3|) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3566 (((-634 (-568)) $) 54)) (-4291 (($ (-634 (-568))) 62)) (-1492 (((-568) $) 40 (|has| (-568) (-301)))) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-1497 (((-121) $ $) NIL)) (-3662 (((-568) $) NIL (|has| (-568) (-815)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) 49) (((-3 (-1161) "failed") $) NIL (|has| (-568) (-1037 (-1161)))) (((-3 (-409 (-568)) "failed") $) 47 (|has| (-568) (-1037 (-568)))) (((-3 (-568) "failed") $) 49 (|has| (-568) (-1037 (-568))))) (-2854 (((-568) $) NIL) (((-1161) $) NIL (|has| (-568) (-1037 (-1161)))) (((-409 (-568)) $) NIL (|has| (-568) (-1037 (-568)))) (((-568) $) NIL (|has| (-568) (-1037 (-568))))) (-2401 (($ $ $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| (-568) (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| (-568) (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-679 (-568)) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1731 (($) NIL (|has| (-568) (-550)))) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-1399 (((-634 (-568)) $) 60)) (-2033 (((-121) $) NIL (|has| (-568) (-815)))) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| (-568) (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| (-568) (-881 (-381))))) (-2735 (((-121) $) NIL)) (-1332 (($ $) NIL)) (-2317 (((-568) $) 37)) (-3038 (((-3 $ "failed") $) NIL (|has| (-568) (-1136)))) (-2245 (((-121) $) NIL (|has| (-568) (-815)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2521 (($ $ $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (|has| (-568) (-842)))) (-2795 (($ (-1 (-568) (-568)) $) NIL)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL)) (-4434 (($) NIL (|has| (-568) (-1136)) CONST)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-3880 (($ $) NIL (|has| (-568) (-301))) (((-409 (-568)) $) 42)) (-2888 (((-1141 (-568)) $) 59)) (-4106 (($ (-634 (-568)) (-634 (-568))) 63)) (-1519 (((-568) $) 53 (|has| (-568) (-550)))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-3848 (((-420 $) $) NIL)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1339 (($ $ (-634 (-568)) (-634 (-568))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-568) (-568)) NIL (|has| (-568) (-303 (-568)))) (($ $ (-288 (-568))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-634 (-288 (-568)))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-634 (-1161)) (-634 (-568))) NIL (|has| (-568) (-523 (-1161) (-568)))) (($ $ (-1161) (-568)) NIL (|has| (-568) (-523 (-1161) (-568))))) (-2709 (((-763) $) NIL)) (-2779 (($ $ (-568)) NIL (|has| (-568) (-281 (-568) (-568))))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-4189 (($ $) 11 (|has| (-568) (-225))) (($ $ (-763)) NIL (|has| (-568) (-225))) (($ $ (-1161)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1 (-568) (-568)) (-763)) NIL) (($ $ (-1 (-568) (-568))) NIL)) (-3013 (($ $) NIL)) (-2324 (((-568) $) 39)) (-2652 (((-634 (-568)) $) 61)) (-4278 (((-887 (-568)) $) NIL (|has| (-568) (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| (-568) (-609 (-887 (-381))))) (((-541) $) NIL (|has| (-568) (-609 (-541)))) (((-381) $) NIL (|has| (-568) (-1021))) (((-215) $) NIL (|has| (-568) (-1021)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| (-568) (-904))))) (-2745 (((-850) $) 77) (($ (-568)) 43) (($ $) NIL) (($ (-409 (-568))) 19) (($ (-568)) 43) (($ (-1161)) NIL (|has| (-568) (-1037 (-1161)))) (((-409 (-568)) $) 17)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| (-568) (-904))) (|has| (-568) (-148))))) (-4078 (((-763)) 9)) (-2285 (((-568) $) 51 (|has| (-568) (-550)))) (-1826 (((-121) $ $) NIL)) (-2897 (($ $) NIL (|has| (-568) (-815)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) 10 T CONST)) (-1556 (($) 12 T CONST)) (-3190 (($ $) NIL (|has| (-568) (-225))) (($ $ (-763)) NIL (|has| (-568) (-225))) (($ $ (-1161)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1 (-568) (-568)) (-763)) NIL) (($ $ (-1 (-568) (-568))) NIL)) (-1751 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1738 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1717 (((-121) $ $) 14)) (-1745 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1732 (((-121) $ $) 33 (|has| (-568) (-842)))) (-1779 (($ $ $) 29) (($ (-568) (-568)) 31)) (-1773 (($ $) 15) (($ $ $) 22)) (-1767 (($ $ $) 20)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 25) (($ $ $) 27) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ (-568) $) 25) (($ $ (-568)) NIL))) 
-(((-1004 |#1|) (-13 (-993 (-568)) (-10 -8 (-15 -2745 ((-409 (-568)) $)) (-15 -3880 ((-409 (-568)) $)) (-15 -3566 ((-634 (-568)) $)) (-15 -2888 ((-1141 (-568)) $)) (-15 -1399 ((-634 (-568)) $)) (-15 -2652 ((-634 (-568)) $)) (-15 -4291 ($ (-634 (-568)))) (-15 -4106 ($ (-634 (-568)) (-634 (-568)))))) (-568)) (T -1004)) 
-((-2745 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568)))) (-3880 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568)))) (-3566 (*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568)))) (-2888 (*1 *2 *1) (-12 (-5 *2 (-1141 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568)))) (-1399 (*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568)))) (-2652 (*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568)))) (-4291 (*1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568)))) (-4106 (*1 *1 *2 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568))))) 
-(-13 (-993 (-568)) (-10 -8 (-15 -2745 ((-409 (-568)) $)) (-15 -3880 ((-409 (-568)) $)) (-15 -3566 ((-634 (-568)) $)) (-15 -2888 ((-1141 (-568)) $)) (-15 -1399 ((-634 (-568)) $)) (-15 -2652 ((-634 (-568)) $)) (-15 -4291 ($ (-634 (-568)))) (-15 -4106 ($ (-634 (-568)) (-634 (-568)))))) 
-((-1851 (((-57) (-409 (-568)) (-568)) 9))) 
-(((-1005) (-10 -7 (-15 -1851 ((-57) (-409 (-568)) (-568))))) (T -1005)) 
-((-1851 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-568))) (-5 *4 (-568)) (-5 *2 (-57)) (-5 *1 (-1005))))) 
-(-10 -7 (-15 -1851 ((-57) (-409 (-568)) (-568)))) 
-((-3983 (((-568)) 13)) (-1413 (((-568)) 16)) (-1469 (((-1249) (-568)) 15)) (-3709 (((-568) (-568)) 17) (((-568)) 12))) 
-(((-1006) (-10 -7 (-15 -3709 ((-568))) (-15 -3983 ((-568))) (-15 -3709 ((-568) (-568))) (-15 -1469 ((-1249) (-568))) (-15 -1413 ((-568))))) (T -1006)) 
-((-1413 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1006)))) (-1469 (*1 *2 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-1006)))) (-3709 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1006)))) (-3983 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1006)))) (-3709 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1006))))) 
-(-10 -7 (-15 -3709 ((-568))) (-15 -3983 ((-568))) (-15 -3709 ((-568) (-568))) (-15 -1469 ((-1249) (-568))) (-15 -1413 ((-568)))) 
-((-2630 (((-420 |#1|) |#1|) 40)) (-3848 (((-420 |#1|) |#1|) 39))) 
-(((-1007 |#1|) (-10 -7 (-15 -3848 ((-420 |#1|) |#1|)) (-15 -2630 ((-420 |#1|) |#1|))) (-1219 (-409 (-568)))) (T -1007)) 
-((-2630 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-1007 *3)) (-4 *3 (-1219 (-409 (-568)))))) (-3848 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-1007 *3)) (-4 *3 (-1219 (-409 (-568))))))) 
-(-10 -7 (-15 -3848 ((-420 |#1|) |#1|)) (-15 -2630 ((-420 |#1|) |#1|))) 
-((-1642 (((-3 (-409 (-568)) "failed") |#1|) 14)) (-2688 (((-121) |#1|) 13)) (-2425 (((-409 (-568)) |#1|) 9))) 
-(((-1008 |#1|) (-10 -7 (-15 -2425 ((-409 (-568)) |#1|)) (-15 -2688 ((-121) |#1|)) (-15 -1642 ((-3 (-409 (-568)) "failed") |#1|))) (-1037 (-409 (-568)))) (T -1008)) 
-((-1642 (*1 *2 *3) (|partial| -12 (-5 *2 (-409 (-568))) (-5 *1 (-1008 *3)) (-4 *3 (-1037 *2)))) (-2688 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-1008 *3)) (-4 *3 (-1037 (-409 (-568)))))) (-2425 (*1 *2 *3) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-1008 *3)) (-4 *3 (-1037 *2))))) 
-(-10 -7 (-15 -2425 ((-409 (-568)) |#1|)) (-15 -2688 ((-121) |#1|)) (-15 -1642 ((-3 (-409 (-568)) "failed") |#1|))) 
-((-2436 ((|#2| $ "value" |#2|) 12)) (-2779 ((|#2| $ "value") 10)) (-3491 (((-121) $ $) 18))) 
-(((-1009 |#1| |#2|) (-10 -8 (-15 -2436 (|#2| |#1| "value" |#2|)) (-15 -3491 ((-121) |#1| |#1|)) (-15 -2779 (|#2| |#1| "value"))) (-1010 |#2|) (-1195)) (T -1009)) 
-NIL 
-(-10 -8 (-15 -2436 (|#2| |#1| "value" |#2|)) (-15 -3491 ((-121) |#1| |#1|)) (-15 -2779 (|#2| |#1| "value"))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2850 ((|#1| $) 45)) (-2510 (((-121) $ (-763)) 8)) (-1659 ((|#1| $ |#1|) 36 (|has| $ (-6 -4520)))) (-2436 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) 38 (|has| $ (-6 -4520)))) (-2671 (($) 7 T CONST)) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-2287 (((-634 $) $) 47)) (-1700 (((-121) $ $) 39 (|has| |#1| (-1090)))) (-1737 (((-121) $ (-763)) 9)) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35)) (-2166 (((-121) $ (-763)) 10)) (-2869 (((-634 |#1|) $) 42)) (-1651 (((-121) $) 46)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 ((|#1| $ "value") 44)) (-4075 (((-568) $ $) 41)) (-3790 (((-121) $) 43)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-4339 (((-634 $) $) 48)) (-3491 (((-121) $ $) 40 (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2876 (((-634 (-568)) $) 54)) (-2993 (($ (-634 (-568))) 62)) (-2563 (((-568) $) 40 (|has| (-568) (-301)))) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-2589 (((-121) $ $) NIL)) (-3337 (((-568) $) NIL (|has| (-568) (-815)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) 49) (((-3 (-1161) "failed") $) NIL (|has| (-568) (-1037 (-1161)))) (((-3 (-409 (-568)) "failed") $) 47 (|has| (-568) (-1037 (-568)))) (((-3 (-568) "failed") $) 49 (|has| (-568) (-1037 (-568))))) (-2857 (((-568) $) NIL) (((-1161) $) NIL (|has| (-568) (-1037 (-1161)))) (((-409 (-568)) $) NIL (|has| (-568) (-1037 (-568)))) (((-568) $) NIL (|has| (-568) (-1037 (-568))))) (-2403 (($ $ $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| (-568) (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| (-568) (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-679 (-568)) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1733 (($) NIL (|has| (-568) (-550)))) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-2078 (((-634 (-568)) $) 60)) (-1436 (((-121) $) NIL (|has| (-568) (-815)))) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (|has| (-568) (-881 (-568)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (|has| (-568) (-881 (-381))))) (-1598 (((-121) $) NIL)) (-3539 (($ $) NIL)) (-2319 (((-568) $) 37)) (-2214 (((-3 $ "failed") $) NIL (|has| (-568) (-1136)))) (-2859 (((-121) $) NIL (|has| (-568) (-815)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1732 (($ $ $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (|has| (-568) (-842)))) (-2797 (($ (-1 (-568) (-568)) $) NIL)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL)) (-4436 (($) NIL (|has| (-568) (-1136)) CONST)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1999 (($ $) NIL (|has| (-568) (-301))) (((-409 (-568)) $) 42)) (-2782 (((-1141 (-568)) $) 59)) (-3572 (($ (-634 (-568)) (-634 (-568))) 63)) (-4115 (((-568) $) 53 (|has| (-568) (-550)))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| (-568) (-904)))) (-3850 (((-420 $) $) NIL)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1339 (($ $ (-634 (-568)) (-634 (-568))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-568) (-568)) NIL (|has| (-568) (-303 (-568)))) (($ $ (-288 (-568))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-634 (-288 (-568)))) NIL (|has| (-568) (-303 (-568)))) (($ $ (-634 (-1161)) (-634 (-568))) NIL (|has| (-568) (-523 (-1161) (-568)))) (($ $ (-1161) (-568)) NIL (|has| (-568) (-523 (-1161) (-568))))) (-1466 (((-763) $) NIL)) (-2781 (($ $ (-568)) NIL (|has| (-568) (-281 (-568) (-568))))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-4191 (($ $) 11 (|has| (-568) (-225))) (($ $ (-763)) NIL (|has| (-568) (-225))) (($ $ (-1161)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1 (-568) (-568)) (-763)) NIL) (($ $ (-1 (-568) (-568))) NIL)) (-3210 (($ $) NIL)) (-2326 (((-568) $) 39)) (-4389 (((-634 (-568)) $) 61)) (-4280 (((-887 (-568)) $) NIL (|has| (-568) (-609 (-887 (-568))))) (((-887 (-381)) $) NIL (|has| (-568) (-609 (-887 (-381))))) (((-541) $) NIL (|has| (-568) (-609 (-541)))) (((-381) $) NIL (|has| (-568) (-1021))) (((-215) $) NIL (|has| (-568) (-1021)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| (-568) (-904))))) (-2747 (((-850) $) 77) (($ (-568)) 43) (($ $) NIL) (($ (-409 (-568))) 19) (($ (-568)) 43) (($ (-1161)) NIL (|has| (-568) (-1037 (-1161)))) (((-409 (-568)) $) 17)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| (-568) (-904))) (|has| (-568) (-148))))) (-3425 (((-763)) 9)) (-3520 (((-568) $) 51 (|has| (-568) (-550)))) (-2273 (((-121) $ $) NIL)) (-2811 (($ $) NIL (|has| (-568) (-815)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) 10 T CONST)) (-1557 (($) 12 T CONST)) (-3192 (($ $) NIL (|has| (-568) (-225))) (($ $ (-763)) NIL (|has| (-568) (-225))) (($ $ (-1161)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| (-568) (-895 (-1161)))) (($ $ (-1 (-568) (-568)) (-763)) NIL) (($ $ (-1 (-568) (-568))) NIL)) (-1753 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1740 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1719 (((-121) $ $) 14)) (-1747 (((-121) $ $) NIL (|has| (-568) (-842)))) (-1734 (((-121) $ $) 33 (|has| (-568) (-842)))) (-1781 (($ $ $) 29) (($ (-568) (-568)) 31)) (-1775 (($ $) 15) (($ $ $) 22)) (-1769 (($ $ $) 20)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 25) (($ $ $) 27) (($ $ (-409 (-568))) NIL) (($ (-409 (-568)) $) NIL) (($ (-568) $) 25) (($ $ (-568)) NIL))) 
+(((-1004 |#1|) (-13 (-993 (-568)) (-10 -8 (-15 -2747 ((-409 (-568)) $)) (-15 -1999 ((-409 (-568)) $)) (-15 -2876 ((-634 (-568)) $)) (-15 -2782 ((-1141 (-568)) $)) (-15 -2078 ((-634 (-568)) $)) (-15 -4389 ((-634 (-568)) $)) (-15 -2993 ($ (-634 (-568)))) (-15 -3572 ($ (-634 (-568)) (-634 (-568)))))) (-568)) (T -1004)) 
+((-2747 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568)))) (-1999 (*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568)))) (-2876 (*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568)))) (-2782 (*1 *2 *1) (-12 (-5 *2 (-1141 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568)))) (-2078 (*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568)))) (-4389 (*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568)))) (-2993 (*1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568)))) (-3572 (*1 *1 *2 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568))))) 
+(-13 (-993 (-568)) (-10 -8 (-15 -2747 ((-409 (-568)) $)) (-15 -1999 ((-409 (-568)) $)) (-15 -2876 ((-634 (-568)) $)) (-15 -2782 ((-1141 (-568)) $)) (-15 -2078 ((-634 (-568)) $)) (-15 -4389 ((-634 (-568)) $)) (-15 -2993 ($ (-634 (-568)))) (-15 -3572 ($ (-634 (-568)) (-634 (-568)))))) 
+((-2398 (((-57) (-409 (-568)) (-568)) 9))) 
+(((-1005) (-10 -7 (-15 -2398 ((-57) (-409 (-568)) (-568))))) (T -1005)) 
+((-2398 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-568))) (-5 *4 (-568)) (-5 *2 (-57)) (-5 *1 (-1005))))) 
+(-10 -7 (-15 -2398 ((-57) (-409 (-568)) (-568)))) 
+((-3986 (((-568)) 13)) (-2147 (((-568)) 16)) (-2450 (((-1249) (-568)) 15)) (-2413 (((-568) (-568)) 17) (((-568)) 12))) 
+(((-1006) (-10 -7 (-15 -2413 ((-568))) (-15 -3986 ((-568))) (-15 -2413 ((-568) (-568))) (-15 -2450 ((-1249) (-568))) (-15 -2147 ((-568))))) (T -1006)) 
+((-2147 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1006)))) (-2450 (*1 *2 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-1006)))) (-2413 (*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1006)))) (-3986 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1006)))) (-2413 (*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1006))))) 
+(-10 -7 (-15 -2413 ((-568))) (-15 -3986 ((-568))) (-15 -2413 ((-568) (-568))) (-15 -2450 ((-1249) (-568))) (-15 -2147 ((-568)))) 
+((-4254 (((-420 |#1|) |#1|) 40)) (-3850 (((-420 |#1|) |#1|) 39))) 
+(((-1007 |#1|) (-10 -7 (-15 -3850 ((-420 |#1|) |#1|)) (-15 -4254 ((-420 |#1|) |#1|))) (-1219 (-409 (-568)))) (T -1007)) 
+((-4254 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-1007 *3)) (-4 *3 (-1219 (-409 (-568)))))) (-3850 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-1007 *3)) (-4 *3 (-1219 (-409 (-568))))))) 
+(-10 -7 (-15 -3850 ((-420 |#1|) |#1|)) (-15 -4254 ((-420 |#1|) |#1|))) 
+((-3254 (((-3 (-409 (-568)) "failed") |#1|) 14)) (-1338 (((-121) |#1|) 13)) (-2394 (((-409 (-568)) |#1|) 9))) 
+(((-1008 |#1|) (-10 -7 (-15 -2394 ((-409 (-568)) |#1|)) (-15 -1338 ((-121) |#1|)) (-15 -3254 ((-3 (-409 (-568)) "failed") |#1|))) (-1037 (-409 (-568)))) (T -1008)) 
+((-3254 (*1 *2 *3) (|partial| -12 (-5 *2 (-409 (-568))) (-5 *1 (-1008 *3)) (-4 *3 (-1037 *2)))) (-1338 (*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-1008 *3)) (-4 *3 (-1037 (-409 (-568)))))) (-2394 (*1 *2 *3) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-1008 *3)) (-4 *3 (-1037 *2))))) 
+(-10 -7 (-15 -2394 ((-409 (-568)) |#1|)) (-15 -1338 ((-121) |#1|)) (-15 -3254 ((-3 (-409 (-568)) "failed") |#1|))) 
+((-2438 ((|#2| $ "value" |#2|) 12)) (-2781 ((|#2| $ "value") 10)) (-3873 (((-121) $ $) 18))) 
+(((-1009 |#1| |#2|) (-10 -8 (-15 -2438 (|#2| |#1| "value" |#2|)) (-15 -3873 ((-121) |#1| |#1|)) (-15 -2781 (|#2| |#1| "value"))) (-1010 |#2|) (-1195)) (T -1009)) 
+NIL 
+(-10 -8 (-15 -2438 (|#2| |#1| "value" |#2|)) (-15 -3873 ((-121) |#1| |#1|)) (-15 -2781 (|#2| |#1| "value"))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2852 ((|#1| $) 45)) (-1667 (((-121) $ (-763)) 8)) (-3370 ((|#1| $ |#1|) 36 (|has| $ (-6 -4522)))) (-2438 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) 38 (|has| $ (-6 -4522)))) (-4490 (($) 7 T CONST)) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-3534 (((-634 $) $) 47)) (-3606 (((-121) $ $) 39 (|has| |#1| (-1090)))) (-3791 (((-121) $ (-763)) 9)) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35)) (-3796 (((-121) $ (-763)) 10)) (-4081 (((-634 |#1|) $) 42)) (-3319 (((-121) $) 46)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 ((|#1| $ "value") 44)) (-1665 (((-568) $ $) 41)) (-2763 (((-121) $) 43)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-3180 (((-634 $) $) 48)) (-3873 (((-121) $ $) 40 (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-1010 |#1|) (-1275) (-1195)) (T -1010)) 
-((-4339 (*1 *2 *1) (-12 (-4 *3 (-1195)) (-5 *2 (-634 *1)) (-4 *1 (-1010 *3)))) (-2287 (*1 *2 *1) (-12 (-4 *3 (-1195)) (-5 *2 (-634 *1)) (-4 *1 (-1010 *3)))) (-1651 (*1 *2 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-5 *2 (-121)))) (-2850 (*1 *2 *1) (-12 (-4 *1 (-1010 *2)) (-4 *2 (-1195)))) (-2779 (*1 *2 *1 *3) (-12 (-5 *3 "value") (-4 *1 (-1010 *2)) (-4 *2 (-1195)))) (-3790 (*1 *2 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-5 *2 (-121)))) (-2869 (*1 *2 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-5 *2 (-634 *3)))) (-4075 (*1 *2 *1 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-5 *2 (-568)))) (-3491 (*1 *2 *1 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-121)))) (-1700 (*1 *2 *1 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-121)))) (-3827 (*1 *1 *1 *2) (-12 (-5 *2 (-634 *1)) (|has| *1 (-6 -4520)) (-4 *1 (-1010 *3)) (-4 *3 (-1195)))) (-2436 (*1 *2 *1 *3 *2) (-12 (-5 *3 "value") (|has| *1 (-6 -4520)) (-4 *1 (-1010 *2)) (-4 *2 (-1195)))) (-1659 (*1 *2 *1 *2) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-1010 *2)) (-4 *2 (-1195))))) 
-(-13 (-499 |t#1|) (-10 -8 (-15 -4339 ((-634 $) $)) (-15 -2287 ((-634 $) $)) (-15 -1651 ((-121) $)) (-15 -2850 (|t#1| $)) (-15 -2779 (|t#1| $ "value")) (-15 -3790 ((-121) $)) (-15 -2869 ((-634 |t#1|) $)) (-15 -4075 ((-568) $ $)) (IF (|has| |t#1| (-1090)) (PROGN (-15 -3491 ((-121) $ $)) (-15 -1700 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4520)) (PROGN (-15 -3827 ($ $ (-634 $))) (-15 -2436 (|t#1| $ "value" |t#1|)) (-15 -1659 (|t#1| $ |t#1|))) |noBranch|))) 
+((-3180 (*1 *2 *1) (-12 (-4 *3 (-1195)) (-5 *2 (-634 *1)) (-4 *1 (-1010 *3)))) (-3534 (*1 *2 *1) (-12 (-4 *3 (-1195)) (-5 *2 (-634 *1)) (-4 *1 (-1010 *3)))) (-3319 (*1 *2 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-5 *2 (-121)))) (-2852 (*1 *2 *1) (-12 (-4 *1 (-1010 *2)) (-4 *2 (-1195)))) (-2781 (*1 *2 *1 *3) (-12 (-5 *3 "value") (-4 *1 (-1010 *2)) (-4 *2 (-1195)))) (-2763 (*1 *2 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-5 *2 (-121)))) (-4081 (*1 *2 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-5 *2 (-634 *3)))) (-1665 (*1 *2 *1 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-5 *2 (-568)))) (-3873 (*1 *2 *1 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-121)))) (-3606 (*1 *2 *1 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-121)))) (-1809 (*1 *1 *1 *2) (-12 (-5 *2 (-634 *1)) (|has| *1 (-6 -4522)) (-4 *1 (-1010 *3)) (-4 *3 (-1195)))) (-2438 (*1 *2 *1 *3 *2) (-12 (-5 *3 "value") (|has| *1 (-6 -4522)) (-4 *1 (-1010 *2)) (-4 *2 (-1195)))) (-3370 (*1 *2 *1 *2) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-1010 *2)) (-4 *2 (-1195))))) 
+(-13 (-499 |t#1|) (-10 -8 (-15 -3180 ((-634 $) $)) (-15 -3534 ((-634 $) $)) (-15 -3319 ((-121) $)) (-15 -2852 (|t#1| $)) (-15 -2781 (|t#1| $ "value")) (-15 -2763 ((-121) $)) (-15 -4081 ((-634 |t#1|) $)) (-15 -1665 ((-568) $ $)) (IF (|has| |t#1| (-1090)) (PROGN (-15 -3873 ((-121) $ $)) (-15 -3606 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4522)) (PROGN (-15 -1809 ($ $ (-634 $))) (-15 -2438 (|t#1| $ "value" |t#1|)) (-15 -3370 (|t#1| $ |t#1|))) |noBranch|))) 
 (((-39) . T) ((-105) |has| |#1| (-1090)) ((-608 (-850)) |has| |#1| (-1090)) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-1090) |has| |#1| (-1090)) ((-1195) . T)) 
-((-1902 (($ $) 9) (($ $ (-763)) 43) (($ (-409 (-568))) 12) (($ (-568)) 15)) (-2932 (((-3 $ "failed") (-1157 $) (-917) (-850)) 23) (((-3 $ "failed") (-1157 $) (-917)) 28)) (-4044 (($ $ (-568)) 49)) (-4078 (((-763)) 16)) (-4309 (((-634 $) (-1157 $)) NIL) (((-634 $) (-1157 (-409 (-568)))) 54) (((-634 $) (-1157 (-568))) 59) (((-634 $) (-953 $)) 63) (((-634 $) (-953 (-409 (-568)))) 67) (((-634 $) (-953 (-568))) 71)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL) (($ $ (-409 (-568))) 47))) 
-(((-1011 |#1|) (-10 -8 (-15 -1902 (|#1| (-568))) (-15 -1902 (|#1| (-409 (-568)))) (-15 -1902 (|#1| |#1| (-763))) (-15 -4309 ((-634 |#1|) (-953 (-568)))) (-15 -4309 ((-634 |#1|) (-953 (-409 (-568))))) (-15 -4309 ((-634 |#1|) (-953 |#1|))) (-15 -4309 ((-634 |#1|) (-1157 (-568)))) (-15 -4309 ((-634 |#1|) (-1157 (-409 (-568))))) (-15 -4309 ((-634 |#1|) (-1157 |#1|))) (-15 -2932 ((-3 |#1| "failed") (-1157 |#1|) (-917))) (-15 -2932 ((-3 |#1| "failed") (-1157 |#1|) (-917) (-850))) (-15 ** (|#1| |#1| (-409 (-568)))) (-15 -4044 (|#1| |#1| (-568))) (-15 -1902 (|#1| |#1|)) (-15 ** (|#1| |#1| (-568))) (-15 -4078 ((-763))) (-15 ** (|#1| |#1| (-763))) (-15 ** (|#1| |#1| (-917)))) (-1012)) (T -1011)) 
-((-4078 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1011 *3)) (-4 *3 (-1012))))) 
-(-10 -8 (-15 -1902 (|#1| (-568))) (-15 -1902 (|#1| (-409 (-568)))) (-15 -1902 (|#1| |#1| (-763))) (-15 -4309 ((-634 |#1|) (-953 (-568)))) (-15 -4309 ((-634 |#1|) (-953 (-409 (-568))))) (-15 -4309 ((-634 |#1|) (-953 |#1|))) (-15 -4309 ((-634 |#1|) (-1157 (-568)))) (-15 -4309 ((-634 |#1|) (-1157 (-409 (-568))))) (-15 -4309 ((-634 |#1|) (-1157 |#1|))) (-15 -2932 ((-3 |#1| "failed") (-1157 |#1|) (-917))) (-15 -2932 ((-3 |#1| "failed") (-1157 |#1|) (-917) (-850))) (-15 ** (|#1| |#1| (-409 (-568)))) (-15 -4044 (|#1| |#1| (-568))) (-15 -1902 (|#1| |#1|)) (-15 ** (|#1| |#1| (-568))) (-15 -4078 ((-763))) (-15 ** (|#1| |#1| (-763))) (-15 ** (|#1| |#1| (-917)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 88)) (-2227 (($ $) 89)) (-1573 (((-121) $) 91)) (-3134 (((-3 $ "failed") $ $) 18)) (-4305 (($ $) 108)) (-1678 (((-420 $) $) 109)) (-1902 (($ $) 72) (($ $ (-763)) 58) (($ (-409 (-568))) 57) (($ (-568)) 56)) (-1497 (((-121) $ $) 99)) (-3662 (((-568) $) 126)) (-2671 (($) 16 T CONST)) (-2932 (((-3 $ "failed") (-1157 $) (-917) (-850)) 66) (((-3 $ "failed") (-1157 $) (-917)) 65)) (-3666 (((-3 (-568) "failed") $) 84 (|has| (-409 (-568)) (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) 82 (|has| (-409 (-568)) (-1037 (-409 (-568))))) (((-3 (-409 (-568)) "failed") $) 80)) (-2854 (((-568) $) 85 (|has| (-409 (-568)) (-1037 (-568)))) (((-409 (-568)) $) 83 (|has| (-409 (-568)) (-1037 (-409 (-568))))) (((-409 (-568)) $) 79)) (-2937 (($ $ (-850)) 55)) (-3539 (($ $ (-850)) 54)) (-2401 (($ $ $) 103)) (-2925 (((-3 $ "failed") $) 33)) (-2412 (($ $ $) 102)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 97)) (-3927 (((-121) $) 110)) (-2033 (((-121) $) 124)) (-2735 (((-121) $) 30)) (-4044 (($ $ (-568)) 71)) (-2245 (((-121) $) 125)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 106)) (-2521 (($ $ $) 123)) (-3268 (($ $ $) 122)) (-3442 (((-3 (-1157 $) "failed") $) 67)) (-4461 (((-3 (-850) "failed") $) 69)) (-2031 (((-3 (-1157 $) "failed") $) 68)) (-2495 (($ (-634 $)) 95) (($ $ $) 94)) (-4487 (((-1143) $) 9)) (-2081 (($ $) 111)) (-4022 (((-1108) $) 10)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 96)) (-2721 (($ (-634 $)) 93) (($ $ $) 92)) (-3848 (((-420 $) $) 107)) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 105) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 104)) (-2595 (((-3 $ "failed") $ $) 87)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 98)) (-2709 (((-763) $) 100)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 101)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ (-409 (-568))) 116) (($ $) 86) (($ (-409 (-568))) 81) (($ (-568)) 78) (($ (-409 (-568))) 75)) (-4078 (((-763)) 28)) (-1826 (((-121) $ $) 90)) (-3996 (((-409 (-568)) $ $) 53)) (-4309 (((-634 $) (-1157 $)) 64) (((-634 $) (-1157 (-409 (-568)))) 63) (((-634 $) (-1157 (-568))) 62) (((-634 $) (-953 $)) 61) (((-634 $) (-953 (-409 (-568)))) 60) (((-634 $) (-953 (-568))) 59)) (-2897 (($ $) 127)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 112)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1751 (((-121) $ $) 120)) (-1738 (((-121) $ $) 119)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 121)) (-1732 (((-121) $ $) 118)) (-1779 (($ $ $) 117)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 113) (($ $ (-409 (-568))) 70)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ (-409 (-568)) $) 115) (($ $ (-409 (-568))) 114) (($ (-568) $) 77) (($ $ (-568)) 76) (($ (-409 (-568)) $) 74) (($ $ (-409 (-568))) 73))) 
+((-1904 (($ $) 9) (($ $ (-763)) 43) (($ (-409 (-568))) 12) (($ (-568)) 15)) (-2919 (((-3 $ "failed") (-1157 $) (-917) (-850)) 23) (((-3 $ "failed") (-1157 $) (-917)) 28)) (-1550 (($ $ (-568)) 49)) (-3425 (((-763)) 16)) (-3059 (((-634 $) (-1157 $)) NIL) (((-634 $) (-1157 (-409 (-568)))) 54) (((-634 $) (-1157 (-568))) 59) (((-634 $) (-953 $)) 63) (((-634 $) (-953 (-409 (-568)))) 67) (((-634 $) (-953 (-568))) 71)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL) (($ $ (-409 (-568))) 47))) 
+(((-1011 |#1|) (-10 -8 (-15 -1904 (|#1| (-568))) (-15 -1904 (|#1| (-409 (-568)))) (-15 -1904 (|#1| |#1| (-763))) (-15 -3059 ((-634 |#1|) (-953 (-568)))) (-15 -3059 ((-634 |#1|) (-953 (-409 (-568))))) (-15 -3059 ((-634 |#1|) (-953 |#1|))) (-15 -3059 ((-634 |#1|) (-1157 (-568)))) (-15 -3059 ((-634 |#1|) (-1157 (-409 (-568))))) (-15 -3059 ((-634 |#1|) (-1157 |#1|))) (-15 -2919 ((-3 |#1| "failed") (-1157 |#1|) (-917))) (-15 -2919 ((-3 |#1| "failed") (-1157 |#1|) (-917) (-850))) (-15 ** (|#1| |#1| (-409 (-568)))) (-15 -1550 (|#1| |#1| (-568))) (-15 -1904 (|#1| |#1|)) (-15 ** (|#1| |#1| (-568))) (-15 -3425 ((-763))) (-15 ** (|#1| |#1| (-763))) (-15 ** (|#1| |#1| (-917)))) (-1012)) (T -1011)) 
+((-3425 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1011 *3)) (-4 *3 (-1012))))) 
+(-10 -8 (-15 -1904 (|#1| (-568))) (-15 -1904 (|#1| (-409 (-568)))) (-15 -1904 (|#1| |#1| (-763))) (-15 -3059 ((-634 |#1|) (-953 (-568)))) (-15 -3059 ((-634 |#1|) (-953 (-409 (-568))))) (-15 -3059 ((-634 |#1|) (-953 |#1|))) (-15 -3059 ((-634 |#1|) (-1157 (-568)))) (-15 -3059 ((-634 |#1|) (-1157 (-409 (-568))))) (-15 -3059 ((-634 |#1|) (-1157 |#1|))) (-15 -2919 ((-3 |#1| "failed") (-1157 |#1|) (-917))) (-15 -2919 ((-3 |#1| "failed") (-1157 |#1|) (-917) (-850))) (-15 ** (|#1| |#1| (-409 (-568)))) (-15 -1550 (|#1| |#1| (-568))) (-15 -1904 (|#1| |#1|)) (-15 ** (|#1| |#1| (-568))) (-15 -3425 ((-763))) (-15 ** (|#1| |#1| (-763))) (-15 ** (|#1| |#1| (-917)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 88)) (-3661 (($ $) 89)) (-4426 (((-121) $) 91)) (-2689 (((-3 $ "failed") $ $) 18)) (-3045 (($ $) 108)) (-3498 (((-420 $) $) 109)) (-1904 (($ $) 72) (($ $ (-763)) 58) (($ (-409 (-568))) 57) (($ (-568)) 56)) (-2589 (((-121) $ $) 99)) (-3337 (((-568) $) 126)) (-4490 (($) 16 T CONST)) (-2919 (((-3 $ "failed") (-1157 $) (-917) (-850)) 66) (((-3 $ "failed") (-1157 $) (-917)) 65)) (-3668 (((-3 (-568) "failed") $) 84 (|has| (-409 (-568)) (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) 82 (|has| (-409 (-568)) (-1037 (-409 (-568))))) (((-3 (-409 (-568)) "failed") $) 80)) (-2857 (((-568) $) 85 (|has| (-409 (-568)) (-1037 (-568)))) (((-409 (-568)) $) 83 (|has| (-409 (-568)) (-1037 (-409 (-568))))) (((-409 (-568)) $) 79)) (-2936 (($ $ (-850)) 55)) (-4187 (($ $ (-850)) 54)) (-2403 (($ $ $) 103)) (-2902 (((-3 $ "failed") $) 33)) (-2414 (($ $ $) 102)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 97)) (-2197 (((-121) $) 110)) (-1436 (((-121) $) 124)) (-1598 (((-121) $) 30)) (-1550 (($ $ (-568)) 71)) (-2859 (((-121) $) 125)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 106)) (-1732 (($ $ $) 123)) (-2047 (($ $ $) 122)) (-3515 (((-3 (-1157 $) "failed") $) 67)) (-1771 (((-3 (-850) "failed") $) 69)) (-1424 (((-3 (-1157 $) "failed") $) 68)) (-2498 (($ (-634 $)) 95) (($ $ $) 94)) (-1893 (((-1143) $) 9)) (-2083 (($ $) 111)) (-4025 (((-1108) $) 10)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 96)) (-2723 (($ (-634 $)) 93) (($ $ $) 92)) (-3850 (((-420 $) $) 107)) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 105) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 104)) (-2597 (((-3 $ "failed") $ $) 87)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 98)) (-1466 (((-763) $) 100)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 101)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ (-409 (-568))) 116) (($ $) 86) (($ (-409 (-568))) 81) (($ (-568)) 78) (($ (-409 (-568))) 75)) (-3425 (((-763)) 28)) (-2273 (((-121) $ $) 90)) (-3999 (((-409 (-568)) $ $) 53)) (-3059 (((-634 $) (-1157 $)) 64) (((-634 $) (-1157 (-409 (-568)))) 63) (((-634 $) (-1157 (-568))) 62) (((-634 $) (-953 $)) 61) (((-634 $) (-953 (-409 (-568)))) 60) (((-634 $) (-953 (-568))) 59)) (-2811 (($ $) 127)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 112)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1753 (((-121) $ $) 120)) (-1740 (((-121) $ $) 119)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 121)) (-1734 (((-121) $ $) 118)) (-1781 (($ $ $) 117)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 113) (($ $ (-409 (-568))) 70)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ (-409 (-568)) $) 115) (($ $ (-409 (-568))) 114) (($ (-568) $) 77) (($ $ (-568)) 76) (($ (-409 (-568)) $) 74) (($ $ (-409 (-568))) 73))) 
 (((-1012) (-1275)) (T -1012)) 
-((-1902 (*1 *1 *1) (-4 *1 (-1012))) (-4461 (*1 *2 *1) (|partial| -12 (-4 *1 (-1012)) (-5 *2 (-850)))) (-2031 (*1 *2 *1) (|partial| -12 (-5 *2 (-1157 *1)) (-4 *1 (-1012)))) (-3442 (*1 *2 *1) (|partial| -12 (-5 *2 (-1157 *1)) (-4 *1 (-1012)))) (-2932 (*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-1157 *1)) (-5 *3 (-917)) (-5 *4 (-850)) (-4 *1 (-1012)))) (-2932 (*1 *1 *2 *3) (|partial| -12 (-5 *2 (-1157 *1)) (-5 *3 (-917)) (-4 *1 (-1012)))) (-4309 (*1 *2 *3) (-12 (-5 *3 (-1157 *1)) (-4 *1 (-1012)) (-5 *2 (-634 *1)))) (-4309 (*1 *2 *3) (-12 (-5 *3 (-1157 (-409 (-568)))) (-5 *2 (-634 *1)) (-4 *1 (-1012)))) (-4309 (*1 *2 *3) (-12 (-5 *3 (-1157 (-568))) (-5 *2 (-634 *1)) (-4 *1 (-1012)))) (-4309 (*1 *2 *3) (-12 (-5 *3 (-953 *1)) (-4 *1 (-1012)) (-5 *2 (-634 *1)))) (-4309 (*1 *2 *3) (-12 (-5 *3 (-953 (-409 (-568)))) (-5 *2 (-634 *1)) (-4 *1 (-1012)))) (-4309 (*1 *2 *3) (-12 (-5 *3 (-953 (-568))) (-5 *2 (-634 *1)) (-4 *1 (-1012)))) (-1902 (*1 *1 *1 *2) (-12 (-4 *1 (-1012)) (-5 *2 (-763)))) (-1902 (*1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-4 *1 (-1012)))) (-1902 (*1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-1012)))) (-2937 (*1 *1 *1 *2) (-12 (-4 *1 (-1012)) (-5 *2 (-850)))) (-3539 (*1 *1 *1 *2) (-12 (-4 *1 (-1012)) (-5 *2 (-850)))) (-3996 (*1 *2 *1 *1) (-12 (-4 *1 (-1012)) (-5 *2 (-409 (-568)))))) 
-(-13 (-150) (-840) (-172) (-365) (-413 (-409 (-568))) (-43 (-568)) (-43 (-409 (-568))) (-1002) (-10 -8 (-15 -4461 ((-3 (-850) "failed") $)) (-15 -2031 ((-3 (-1157 $) "failed") $)) (-15 -3442 ((-3 (-1157 $) "failed") $)) (-15 -2932 ((-3 $ "failed") (-1157 $) (-917) (-850))) (-15 -2932 ((-3 $ "failed") (-1157 $) (-917))) (-15 -4309 ((-634 $) (-1157 $))) (-15 -4309 ((-634 $) (-1157 (-409 (-568))))) (-15 -4309 ((-634 $) (-1157 (-568)))) (-15 -4309 ((-634 $) (-953 $))) (-15 -4309 ((-634 $) (-953 (-409 (-568))))) (-15 -4309 ((-634 $) (-953 (-568)))) (-15 -1902 ($ $ (-763))) (-15 -1902 ($ $)) (-15 -1902 ($ (-409 (-568)))) (-15 -1902 ($ (-568))) (-15 -2937 ($ $ (-850))) (-15 -3539 ($ $ (-850))) (-15 -3996 ((-409 (-568)) $ $)))) 
+((-1904 (*1 *1 *1) (-4 *1 (-1012))) (-1771 (*1 *2 *1) (|partial| -12 (-4 *1 (-1012)) (-5 *2 (-850)))) (-1424 (*1 *2 *1) (|partial| -12 (-5 *2 (-1157 *1)) (-4 *1 (-1012)))) (-3515 (*1 *2 *1) (|partial| -12 (-5 *2 (-1157 *1)) (-4 *1 (-1012)))) (-2919 (*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-1157 *1)) (-5 *3 (-917)) (-5 *4 (-850)) (-4 *1 (-1012)))) (-2919 (*1 *1 *2 *3) (|partial| -12 (-5 *2 (-1157 *1)) (-5 *3 (-917)) (-4 *1 (-1012)))) (-3059 (*1 *2 *3) (-12 (-5 *3 (-1157 *1)) (-4 *1 (-1012)) (-5 *2 (-634 *1)))) (-3059 (*1 *2 *3) (-12 (-5 *3 (-1157 (-409 (-568)))) (-5 *2 (-634 *1)) (-4 *1 (-1012)))) (-3059 (*1 *2 *3) (-12 (-5 *3 (-1157 (-568))) (-5 *2 (-634 *1)) (-4 *1 (-1012)))) (-3059 (*1 *2 *3) (-12 (-5 *3 (-953 *1)) (-4 *1 (-1012)) (-5 *2 (-634 *1)))) (-3059 (*1 *2 *3) (-12 (-5 *3 (-953 (-409 (-568)))) (-5 *2 (-634 *1)) (-4 *1 (-1012)))) (-3059 (*1 *2 *3) (-12 (-5 *3 (-953 (-568))) (-5 *2 (-634 *1)) (-4 *1 (-1012)))) (-1904 (*1 *1 *1 *2) (-12 (-4 *1 (-1012)) (-5 *2 (-763)))) (-1904 (*1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-4 *1 (-1012)))) (-1904 (*1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-1012)))) (-2936 (*1 *1 *1 *2) (-12 (-4 *1 (-1012)) (-5 *2 (-850)))) (-4187 (*1 *1 *1 *2) (-12 (-4 *1 (-1012)) (-5 *2 (-850)))) (-3999 (*1 *2 *1 *1) (-12 (-4 *1 (-1012)) (-5 *2 (-409 (-568)))))) 
+(-13 (-150) (-840) (-172) (-365) (-413 (-409 (-568))) (-43 (-568)) (-43 (-409 (-568))) (-1002) (-10 -8 (-15 -1771 ((-3 (-850) "failed") $)) (-15 -1424 ((-3 (-1157 $) "failed") $)) (-15 -3515 ((-3 (-1157 $) "failed") $)) (-15 -2919 ((-3 $ "failed") (-1157 $) (-917) (-850))) (-15 -2919 ((-3 $ "failed") (-1157 $) (-917))) (-15 -3059 ((-634 $) (-1157 $))) (-15 -3059 ((-634 $) (-1157 (-409 (-568))))) (-15 -3059 ((-634 $) (-1157 (-568)))) (-15 -3059 ((-634 $) (-953 $))) (-15 -3059 ((-634 $) (-953 (-409 (-568))))) (-15 -3059 ((-634 $) (-953 (-568)))) (-15 -1904 ($ $ (-763))) (-15 -1904 ($ $)) (-15 -1904 ($ (-409 (-568)))) (-15 -1904 ($ (-568))) (-15 -2936 ($ $ (-850))) (-15 -4187 ($ $ (-850))) (-15 -3999 ((-409 (-568)) $ $)))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-43 (-568)) . T) ((-43 $) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 (-568) (-568)) . T) ((-120 $ $) . T) ((-137) . T) ((-150) . T) ((-608 (-850)) . T) ((-172) . T) ((-238) . T) ((-285) . T) ((-301) . T) ((-365) . T) ((-413 (-409 (-568))) . T) ((-453) . T) ((-558) . T) ((-637 (-409 (-568))) . T) ((-637 (-568)) . T) ((-637 $) . T) ((-707 (-409 (-568))) . T) ((-707 (-568)) . T) ((-707 $) . T) ((-716) . T) ((-786) . T) ((-787) . T) ((-789) . T) ((-790) . T) ((-840) . T) ((-842) . T) ((-916) . T) ((-1002) . T) ((-1037 (-409 (-568))) . T) ((-1037 (-568)) |has| (-409 (-568)) (-1037 (-568))) ((-1053 (-409 (-568))) . T) ((-1053 (-568)) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1199) . T)) 
-((-3555 (((-2 (|:| |ans| |#2|) (|:| -3284 |#2|) (|:| |sol?| (-121))) (-568) |#2| |#2| (-1161) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-634 |#2|)) (-1 (-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)) 61))) 
-(((-1013 |#1| |#2|) (-10 -7 (-15 -3555 ((-2 (|:| |ans| |#2|) (|:| -3284 |#2|) (|:| |sol?| (-121))) (-568) |#2| |#2| (-1161) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-634 |#2|)) (-1 (-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)))) (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568))) (-13 (-1181) (-27) (-432 |#1|))) (T -1013)) 
-((-3555 (*1 *2 *3 *4 *4 *5 *6 *7) (-12 (-5 *5 (-1161)) (-5 *6 (-1 (-3 (-2 (|:| |mainpart| *4) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *4) (|:| |logand| *4))))) "failed") *4 (-634 *4))) (-5 *7 (-1 (-3 (-2 (|:| -1924 *4) (|:| |coeff| *4)) "failed") *4 *4)) (-4 *4 (-13 (-1181) (-27) (-432 *8))) (-4 *8 (-13 (-453) (-842) (-150) (-1037 *3) (-630 *3))) (-5 *3 (-568)) (-5 *2 (-2 (|:| |ans| *4) (|:| -3284 *4) (|:| |sol?| (-121)))) (-5 *1 (-1013 *8 *4))))) 
-(-10 -7 (-15 -3555 ((-2 (|:| |ans| |#2|) (|:| -3284 |#2|) (|:| |sol?| (-121))) (-568) |#2| |#2| (-1161) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-634 |#2|)) (-1 (-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)))) 
-((-1915 (((-3 (-634 |#2|) "failed") (-568) |#2| |#2| |#2| (-1161) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-634 |#2|)) (-1 (-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)) 47))) 
-(((-1014 |#1| |#2|) (-10 -7 (-15 -1915 ((-3 (-634 |#2|) "failed") (-568) |#2| |#2| |#2| (-1161) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-634 |#2|)) (-1 (-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)))) (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568))) (-13 (-1181) (-27) (-432 |#1|))) (T -1014)) 
-((-1915 (*1 *2 *3 *4 *4 *4 *5 *6 *7) (|partial| -12 (-5 *5 (-1161)) (-5 *6 (-1 (-3 (-2 (|:| |mainpart| *4) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *4) (|:| |logand| *4))))) "failed") *4 (-634 *4))) (-5 *7 (-1 (-3 (-2 (|:| -1924 *4) (|:| |coeff| *4)) "failed") *4 *4)) (-4 *4 (-13 (-1181) (-27) (-432 *8))) (-4 *8 (-13 (-453) (-842) (-150) (-1037 *3) (-630 *3))) (-5 *3 (-568)) (-5 *2 (-634 *4)) (-5 *1 (-1014 *8 *4))))) 
-(-10 -7 (-15 -1915 ((-3 (-634 |#2|) "failed") (-568) |#2| |#2| |#2| (-1161) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-634 |#2|)) (-1 (-3 (-2 (|:| -1924 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)))) 
-((-3450 (((-3 (|:| |ans| (-2 (|:| |ans| |#2|) (|:| |nosol| (-121)))) (|:| -1853 (-2 (|:| |b| |#2|) (|:| |c| |#2|) (|:| |m| (-568)) (|:| |alpha| |#2|) (|:| |beta| |#2|)))) |#2| |#2| |#2| (-568) (-1 |#2| |#2|)) 30)) (-3663 (((-3 (-2 (|:| |a| |#2|) (|:| |b| (-409 |#2|)) (|:| |c| (-409 |#2|)) (|:| -3492 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-1 |#2| |#2|)) 56)) (-3259 (((-2 (|:| |ans| (-409 |#2|)) (|:| |nosol| (-121))) (-409 |#2|) (-409 |#2|)) 61))) 
-(((-1015 |#1| |#2|) (-10 -7 (-15 -3663 ((-3 (-2 (|:| |a| |#2|) (|:| |b| (-409 |#2|)) (|:| |c| (-409 |#2|)) (|:| -3492 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-1 |#2| |#2|))) (-15 -3259 ((-2 (|:| |ans| (-409 |#2|)) (|:| |nosol| (-121))) (-409 |#2|) (-409 |#2|))) (-15 -3450 ((-3 (|:| |ans| (-2 (|:| |ans| |#2|) (|:| |nosol| (-121)))) (|:| -1853 (-2 (|:| |b| |#2|) (|:| |c| |#2|) (|:| |m| (-568)) (|:| |alpha| |#2|) (|:| |beta| |#2|)))) |#2| |#2| |#2| (-568) (-1 |#2| |#2|)))) (-13 (-365) (-150) (-1037 (-568))) (-1219 |#1|)) (T -1015)) 
-((-3450 (*1 *2 *3 *3 *3 *4 *5) (-12 (-5 *5 (-1 *3 *3)) (-4 *3 (-1219 *6)) (-4 *6 (-13 (-365) (-150) (-1037 *4))) (-5 *4 (-568)) (-5 *2 (-3 (|:| |ans| (-2 (|:| |ans| *3) (|:| |nosol| (-121)))) (|:| -1853 (-2 (|:| |b| *3) (|:| |c| *3) (|:| |m| *4) (|:| |alpha| *3) (|:| |beta| *3))))) (-5 *1 (-1015 *6 *3)))) (-3259 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-568)))) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| |ans| (-409 *5)) (|:| |nosol| (-121)))) (-5 *1 (-1015 *4 *5)) (-5 *3 (-409 *5)))) (-3663 (*1 *2 *3 *3 *4) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)))) (-5 *2 (-2 (|:| |a| *6) (|:| |b| (-409 *6)) (|:| |c| (-409 *6)) (|:| -3492 *6))) (-5 *1 (-1015 *5 *6)) (-5 *3 (-409 *6))))) 
-(-10 -7 (-15 -3663 ((-3 (-2 (|:| |a| |#2|) (|:| |b| (-409 |#2|)) (|:| |c| (-409 |#2|)) (|:| -3492 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-1 |#2| |#2|))) (-15 -3259 ((-2 (|:| |ans| (-409 |#2|)) (|:| |nosol| (-121))) (-409 |#2|) (-409 |#2|))) (-15 -3450 ((-3 (|:| |ans| (-2 (|:| |ans| |#2|) (|:| |nosol| (-121)))) (|:| -1853 (-2 (|:| |b| |#2|) (|:| |c| |#2|) (|:| |m| (-568)) (|:| |alpha| |#2|) (|:| |beta| |#2|)))) |#2| |#2| |#2| (-568) (-1 |#2| |#2|)))) 
-((-3461 (((-3 (-2 (|:| |a| |#2|) (|:| |b| (-409 |#2|)) (|:| |h| |#2|) (|:| |c1| (-409 |#2|)) (|:| |c2| (-409 |#2|)) (|:| -3492 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|) (-1 |#2| |#2|)) 22)) (-2822 (((-3 (-634 (-409 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|)) 32))) 
-(((-1016 |#1| |#2|) (-10 -7 (-15 -3461 ((-3 (-2 (|:| |a| |#2|) (|:| |b| (-409 |#2|)) (|:| |h| |#2|) (|:| |c1| (-409 |#2|)) (|:| |c2| (-409 |#2|)) (|:| -3492 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|) (-1 |#2| |#2|))) (-15 -2822 ((-3 (-634 (-409 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|)))) (-13 (-365) (-150) (-1037 (-568))) (-1219 |#1|)) (T -1016)) 
-((-2822 (*1 *2 *3 *3 *3) (|partial| -12 (-4 *4 (-13 (-365) (-150) (-1037 (-568)))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-409 *5))) (-5 *1 (-1016 *4 *5)) (-5 *3 (-409 *5)))) (-3461 (*1 *2 *3 *3 *3 *4) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)))) (-5 *2 (-2 (|:| |a| *6) (|:| |b| (-409 *6)) (|:| |h| *6) (|:| |c1| (-409 *6)) (|:| |c2| (-409 *6)) (|:| -3492 *6))) (-5 *1 (-1016 *5 *6)) (-5 *3 (-409 *6))))) 
-(-10 -7 (-15 -3461 ((-3 (-2 (|:| |a| |#2|) (|:| |b| (-409 |#2|)) (|:| |h| |#2|) (|:| |c1| (-409 |#2|)) (|:| |c2| (-409 |#2|)) (|:| -3492 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|) (-1 |#2| |#2|))) (-15 -2822 ((-3 (-634 (-409 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|)))) 
-((-3723 (((-1 |#1|) (-634 (-2 (|:| -2850 |#1|) (|:| -1551 (-568))))) 37)) (-3703 (((-1 |#1|) (-1092 |#1|)) 45)) (-1289 (((-1 |#1|) (-1244 |#1|) (-1244 (-568)) (-568)) 34))) 
-(((-1017 |#1|) (-10 -7 (-15 -3703 ((-1 |#1|) (-1092 |#1|))) (-15 -3723 ((-1 |#1|) (-634 (-2 (|:| -2850 |#1|) (|:| -1551 (-568)))))) (-15 -1289 ((-1 |#1|) (-1244 |#1|) (-1244 (-568)) (-568)))) (-1090)) (T -1017)) 
-((-1289 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1244 *6)) (-5 *4 (-1244 (-568))) (-5 *5 (-568)) (-4 *6 (-1090)) (-5 *2 (-1 *6)) (-5 *1 (-1017 *6)))) (-3723 (*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -2850 *4) (|:| -1551 (-568))))) (-4 *4 (-1090)) (-5 *2 (-1 *4)) (-5 *1 (-1017 *4)))) (-3703 (*1 *2 *3) (-12 (-5 *3 (-1092 *4)) (-4 *4 (-1090)) (-5 *2 (-1 *4)) (-5 *1 (-1017 *4))))) 
-(-10 -7 (-15 -3703 ((-1 |#1|) (-1092 |#1|))) (-15 -3723 ((-1 |#1|) (-634 (-2 (|:| -2850 |#1|) (|:| -1551 (-568)))))) (-15 -1289 ((-1 |#1|) (-1244 |#1|) (-1244 (-568)) (-568)))) 
-((-4477 (((-763) (-334 |#1| |#2| |#3| |#4|) |#3| (-1 |#5| |#1|)) 23))) 
-(((-1018 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -4477 ((-763) (-334 |#1| |#2| |#3| |#4|) |#3| (-1 |#5| |#1|)))) (-365) (-1219 |#1|) (-1219 (-409 |#2|)) (-340 |#1| |#2| |#3|) (-13 (-370) (-365))) (T -1018)) 
-((-4477 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-334 *6 *7 *4 *8)) (-5 *5 (-1 *9 *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-4 *4 (-1219 (-409 *7))) (-4 *8 (-340 *6 *7 *4)) (-4 *9 (-13 (-370) (-365))) (-5 *2 (-763)) (-5 *1 (-1018 *6 *7 *4 *8 *9))))) 
-(-10 -7 (-15 -4477 ((-763) (-334 |#1| |#2| |#3| |#4|) |#3| (-1 |#5| |#1|)))) 
-((-4069 (((-3 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) "failed") |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) 31) (((-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) (-409 (-568))) 28)) (-2146 (((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) (-409 (-568))) 33) (((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1| (-409 (-568))) 29) (((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) 32) (((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1|) 27)) (-3113 (((-634 (-409 (-568))) (-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) 19)) (-4006 (((-409 (-568)) (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) 16))) 
-(((-1019 |#1|) (-10 -7 (-15 -2146 ((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1|)) (-15 -2146 ((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) (-15 -2146 ((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1| (-409 (-568)))) (-15 -2146 ((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) (-409 (-568)))) (-15 -4069 ((-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) (-409 (-568)))) (-15 -4069 ((-3 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) "failed") |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) (-15 -4006 ((-409 (-568)) (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) (-15 -3113 ((-634 (-409 (-568))) (-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))))) (-1219 (-568))) (T -1019)) 
-((-3113 (*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) (-5 *2 (-634 (-409 (-568)))) (-5 *1 (-1019 *4)) (-4 *4 (-1219 (-568))))) (-4006 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) (-5 *2 (-409 (-568))) (-5 *1 (-1019 *4)) (-4 *4 (-1219 (-568))))) (-4069 (*1 *2 *3 *2 *2) (|partial| -12 (-5 *2 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568))))) (-4069 (*1 *2 *3 *2 *4) (-12 (-5 *2 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) (-5 *4 (-409 (-568))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568))))) (-2146 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-409 (-568))) (-5 *2 (-634 (-2 (|:| -3028 *5) (|:| -3284 *5)))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568))) (-5 *4 (-2 (|:| -3028 *5) (|:| -3284 *5))))) (-2146 (*1 *2 *3 *4) (-12 (-5 *2 (-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568))) (-5 *4 (-409 (-568))))) (-2146 (*1 *2 *3 *4) (-12 (-5 *2 (-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568))) (-5 *4 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))))) (-2146 (*1 *2 *3) (-12 (-5 *2 (-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568)))))) 
-(-10 -7 (-15 -2146 ((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1|)) (-15 -2146 ((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) (-15 -2146 ((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1| (-409 (-568)))) (-15 -2146 ((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) (-409 (-568)))) (-15 -4069 ((-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) (-409 (-568)))) (-15 -4069 ((-3 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) "failed") |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) (-15 -4006 ((-409 (-568)) (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) (-15 -3113 ((-634 (-409 (-568))) (-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))))) 
-((-4069 (((-3 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) "failed") |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) 35) (((-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) (-409 (-568))) 32)) (-2146 (((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) (-409 (-568))) 30) (((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1| (-409 (-568))) 26) (((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) 28) (((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1|) 24))) 
-(((-1020 |#1|) (-10 -7 (-15 -2146 ((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1|)) (-15 -2146 ((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) (-15 -2146 ((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1| (-409 (-568)))) (-15 -2146 ((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) (-409 (-568)))) (-15 -4069 ((-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) (-409 (-568)))) (-15 -4069 ((-3 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) "failed") |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))))) (-1219 (-409 (-568)))) (T -1020)) 
-((-4069 (*1 *2 *3 *2 *2) (|partial| -12 (-5 *2 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 (-409 (-568)))))) (-4069 (*1 *2 *3 *2 *4) (-12 (-5 *2 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) (-5 *4 (-409 (-568))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 *4)))) (-2146 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-409 (-568))) (-5 *2 (-634 (-2 (|:| -3028 *5) (|:| -3284 *5)))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 *5)) (-5 *4 (-2 (|:| -3028 *5) (|:| -3284 *5))))) (-2146 (*1 *2 *3 *4) (-12 (-5 *4 (-409 (-568))) (-5 *2 (-634 (-2 (|:| -3028 *4) (|:| -3284 *4)))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 *4)))) (-2146 (*1 *2 *3 *4) (-12 (-5 *2 (-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 (-409 (-568)))) (-5 *4 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))))) (-2146 (*1 *2 *3) (-12 (-5 *2 (-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 (-409 (-568))))))) 
-(-10 -7 (-15 -2146 ((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1|)) (-15 -2146 ((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) (-15 -2146 ((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1| (-409 (-568)))) (-15 -2146 ((-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) (-409 (-568)))) (-15 -4069 ((-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) (-409 (-568)))) (-15 -4069 ((-3 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) "failed") |#1| (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))) (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))))) 
-((-4278 (((-215) $) 6) (((-381) $) 8))) 
+((-2831 (((-2 (|:| |ans| |#2|) (|:| -3286 |#2|) (|:| |sol?| (-121))) (-568) |#2| |#2| (-1161) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-634 |#2|)) (-1 (-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)) 61))) 
+(((-1013 |#1| |#2|) (-10 -7 (-15 -2831 ((-2 (|:| |ans| |#2|) (|:| -3286 |#2|) (|:| |sol?| (-121))) (-568) |#2| |#2| (-1161) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-634 |#2|)) (-1 (-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)))) (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568))) (-13 (-1181) (-27) (-432 |#1|))) (T -1013)) 
+((-2831 (*1 *2 *3 *4 *4 *5 *6 *7) (-12 (-5 *5 (-1161)) (-5 *6 (-1 (-3 (-2 (|:| |mainpart| *4) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *4) (|:| |logand| *4))))) "failed") *4 (-634 *4))) (-5 *7 (-1 (-3 (-2 (|:| -4151 *4) (|:| |coeff| *4)) "failed") *4 *4)) (-4 *4 (-13 (-1181) (-27) (-432 *8))) (-4 *8 (-13 (-453) (-842) (-150) (-1037 *3) (-630 *3))) (-5 *3 (-568)) (-5 *2 (-2 (|:| |ans| *4) (|:| -3286 *4) (|:| |sol?| (-121)))) (-5 *1 (-1013 *8 *4))))) 
+(-10 -7 (-15 -2831 ((-2 (|:| |ans| |#2|) (|:| -3286 |#2|) (|:| |sol?| (-121))) (-568) |#2| |#2| (-1161) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-634 |#2|)) (-1 (-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)))) 
+((-2696 (((-3 (-634 |#2|) "failed") (-568) |#2| |#2| |#2| (-1161) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-634 |#2|)) (-1 (-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)) 47))) 
+(((-1014 |#1| |#2|) (-10 -7 (-15 -2696 ((-3 (-634 |#2|) "failed") (-568) |#2| |#2| |#2| (-1161) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-634 |#2|)) (-1 (-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)))) (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568))) (-13 (-1181) (-27) (-432 |#1|))) (T -1014)) 
+((-2696 (*1 *2 *3 *4 *4 *4 *5 *6 *7) (|partial| -12 (-5 *5 (-1161)) (-5 *6 (-1 (-3 (-2 (|:| |mainpart| *4) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *4) (|:| |logand| *4))))) "failed") *4 (-634 *4))) (-5 *7 (-1 (-3 (-2 (|:| -4151 *4) (|:| |coeff| *4)) "failed") *4 *4)) (-4 *4 (-13 (-1181) (-27) (-432 *8))) (-4 *8 (-13 (-453) (-842) (-150) (-1037 *3) (-630 *3))) (-5 *3 (-568)) (-5 *2 (-634 *4)) (-5 *1 (-1014 *8 *4))))) 
+(-10 -7 (-15 -2696 ((-3 (-634 |#2|) "failed") (-568) |#2| |#2| |#2| (-1161) (-1 (-3 (-2 (|:| |mainpart| |#2|) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| |#2|) (|:| |logand| |#2|))))) "failed") |#2| (-634 |#2|)) (-1 (-3 (-2 (|:| -4151 |#2|) (|:| |coeff| |#2|)) "failed") |#2| |#2|)))) 
+((-3564 (((-3 (|:| |ans| (-2 (|:| |ans| |#2|) (|:| |nosol| (-121)))) (|:| -2410 (-2 (|:| |b| |#2|) (|:| |c| |#2|) (|:| |m| (-568)) (|:| |alpha| |#2|) (|:| |beta| |#2|)))) |#2| |#2| |#2| (-568) (-1 |#2| |#2|)) 30)) (-3343 (((-3 (-2 (|:| |a| |#2|) (|:| |b| (-409 |#2|)) (|:| |c| (-409 |#2|)) (|:| -3494 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-1 |#2| |#2|)) 56)) (-2021 (((-2 (|:| |ans| (-409 |#2|)) (|:| |nosol| (-121))) (-409 |#2|) (-409 |#2|)) 61))) 
+(((-1015 |#1| |#2|) (-10 -7 (-15 -3343 ((-3 (-2 (|:| |a| |#2|) (|:| |b| (-409 |#2|)) (|:| |c| (-409 |#2|)) (|:| -3494 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-1 |#2| |#2|))) (-15 -2021 ((-2 (|:| |ans| (-409 |#2|)) (|:| |nosol| (-121))) (-409 |#2|) (-409 |#2|))) (-15 -3564 ((-3 (|:| |ans| (-2 (|:| |ans| |#2|) (|:| |nosol| (-121)))) (|:| -2410 (-2 (|:| |b| |#2|) (|:| |c| |#2|) (|:| |m| (-568)) (|:| |alpha| |#2|) (|:| |beta| |#2|)))) |#2| |#2| |#2| (-568) (-1 |#2| |#2|)))) (-13 (-365) (-150) (-1037 (-568))) (-1219 |#1|)) (T -1015)) 
+((-3564 (*1 *2 *3 *3 *3 *4 *5) (-12 (-5 *5 (-1 *3 *3)) (-4 *3 (-1219 *6)) (-4 *6 (-13 (-365) (-150) (-1037 *4))) (-5 *4 (-568)) (-5 *2 (-3 (|:| |ans| (-2 (|:| |ans| *3) (|:| |nosol| (-121)))) (|:| -2410 (-2 (|:| |b| *3) (|:| |c| *3) (|:| |m| *4) (|:| |alpha| *3) (|:| |beta| *3))))) (-5 *1 (-1015 *6 *3)))) (-2021 (*1 *2 *3 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-568)))) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| |ans| (-409 *5)) (|:| |nosol| (-121)))) (-5 *1 (-1015 *4 *5)) (-5 *3 (-409 *5)))) (-3343 (*1 *2 *3 *3 *4) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)))) (-5 *2 (-2 (|:| |a| *6) (|:| |b| (-409 *6)) (|:| |c| (-409 *6)) (|:| -3494 *6))) (-5 *1 (-1015 *5 *6)) (-5 *3 (-409 *6))))) 
+(-10 -7 (-15 -3343 ((-3 (-2 (|:| |a| |#2|) (|:| |b| (-409 |#2|)) (|:| |c| (-409 |#2|)) (|:| -3494 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-1 |#2| |#2|))) (-15 -2021 ((-2 (|:| |ans| (-409 |#2|)) (|:| |nosol| (-121))) (-409 |#2|) (-409 |#2|))) (-15 -3564 ((-3 (|:| |ans| (-2 (|:| |ans| |#2|) (|:| |nosol| (-121)))) (|:| -2410 (-2 (|:| |b| |#2|) (|:| |c| |#2|) (|:| |m| (-568)) (|:| |alpha| |#2|) (|:| |beta| |#2|)))) |#2| |#2| |#2| (-568) (-1 |#2| |#2|)))) 
+((-3649 (((-3 (-2 (|:| |a| |#2|) (|:| |b| (-409 |#2|)) (|:| |h| |#2|) (|:| |c1| (-409 |#2|)) (|:| |c2| (-409 |#2|)) (|:| -3494 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|) (-1 |#2| |#2|)) 22)) (-3793 (((-3 (-634 (-409 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|)) 32))) 
+(((-1016 |#1| |#2|) (-10 -7 (-15 -3649 ((-3 (-2 (|:| |a| |#2|) (|:| |b| (-409 |#2|)) (|:| |h| |#2|) (|:| |c1| (-409 |#2|)) (|:| |c2| (-409 |#2|)) (|:| -3494 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|) (-1 |#2| |#2|))) (-15 -3793 ((-3 (-634 (-409 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|)))) (-13 (-365) (-150) (-1037 (-568))) (-1219 |#1|)) (T -1016)) 
+((-3793 (*1 *2 *3 *3 *3) (|partial| -12 (-4 *4 (-13 (-365) (-150) (-1037 (-568)))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-409 *5))) (-5 *1 (-1016 *4 *5)) (-5 *3 (-409 *5)))) (-3649 (*1 *2 *3 *3 *3 *4) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)))) (-5 *2 (-2 (|:| |a| *6) (|:| |b| (-409 *6)) (|:| |h| *6) (|:| |c1| (-409 *6)) (|:| |c2| (-409 *6)) (|:| -3494 *6))) (-5 *1 (-1016 *5 *6)) (-5 *3 (-409 *6))))) 
+(-10 -7 (-15 -3649 ((-3 (-2 (|:| |a| |#2|) (|:| |b| (-409 |#2|)) (|:| |h| |#2|) (|:| |c1| (-409 |#2|)) (|:| |c2| (-409 |#2|)) (|:| -3494 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|) (-1 |#2| |#2|))) (-15 -3793 ((-3 (-634 (-409 |#2|)) "failed") (-409 |#2|) (-409 |#2|) (-409 |#2|)))) 
+((-2484 (((-1 |#1|) (-634 (-2 (|:| -2852 |#1|) (|:| -4308 (-568))))) 37)) (-2381 (((-1 |#1|) (-1092 |#1|)) 45)) (-3198 (((-1 |#1|) (-1244 |#1|) (-1244 (-568)) (-568)) 34))) 
+(((-1017 |#1|) (-10 -7 (-15 -2381 ((-1 |#1|) (-1092 |#1|))) (-15 -2484 ((-1 |#1|) (-634 (-2 (|:| -2852 |#1|) (|:| -4308 (-568)))))) (-15 -3198 ((-1 |#1|) (-1244 |#1|) (-1244 (-568)) (-568)))) (-1090)) (T -1017)) 
+((-3198 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1244 *6)) (-5 *4 (-1244 (-568))) (-5 *5 (-568)) (-4 *6 (-1090)) (-5 *2 (-1 *6)) (-5 *1 (-1017 *6)))) (-2484 (*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -2852 *4) (|:| -4308 (-568))))) (-4 *4 (-1090)) (-5 *2 (-1 *4)) (-5 *1 (-1017 *4)))) (-2381 (*1 *2 *3) (-12 (-5 *3 (-1092 *4)) (-4 *4 (-1090)) (-5 *2 (-1 *4)) (-5 *1 (-1017 *4))))) 
+(-10 -7 (-15 -2381 ((-1 |#1|) (-1092 |#1|))) (-15 -2484 ((-1 |#1|) (-634 (-2 (|:| -2852 |#1|) (|:| -4308 (-568)))))) (-15 -3198 ((-1 |#1|) (-1244 |#1|) (-1244 (-568)) (-568)))) 
+((-1844 (((-763) (-334 |#1| |#2| |#3| |#4|) |#3| (-1 |#5| |#1|)) 23))) 
+(((-1018 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1844 ((-763) (-334 |#1| |#2| |#3| |#4|) |#3| (-1 |#5| |#1|)))) (-365) (-1219 |#1|) (-1219 (-409 |#2|)) (-340 |#1| |#2| |#3|) (-13 (-370) (-365))) (T -1018)) 
+((-1844 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-334 *6 *7 *4 *8)) (-5 *5 (-1 *9 *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-4 *4 (-1219 (-409 *7))) (-4 *8 (-340 *6 *7 *4)) (-4 *9 (-13 (-370) (-365))) (-5 *2 (-763)) (-5 *1 (-1018 *6 *7 *4 *8 *9))))) 
+(-10 -7 (-15 -1844 ((-763) (-334 |#1| |#2| |#3| |#4|) |#3| (-1 |#5| |#1|)))) 
+((-1642 (((-3 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) "failed") |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) 31) (((-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) (-409 (-568))) 28)) (-3538 (((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) (-409 (-568))) 33) (((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1| (-409 (-568))) 29) (((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) 32) (((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1|) 27)) (-2571 (((-634 (-409 (-568))) (-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) 19)) (-1365 (((-409 (-568)) (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) 16))) 
+(((-1019 |#1|) (-10 -7 (-15 -3538 ((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1|)) (-15 -3538 ((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) (-15 -3538 ((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1| (-409 (-568)))) (-15 -3538 ((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) (-409 (-568)))) (-15 -1642 ((-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) (-409 (-568)))) (-15 -1642 ((-3 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) "failed") |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) (-15 -1365 ((-409 (-568)) (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) (-15 -2571 ((-634 (-409 (-568))) (-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))))) (-1219 (-568))) (T -1019)) 
+((-2571 (*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) (-5 *2 (-634 (-409 (-568)))) (-5 *1 (-1019 *4)) (-4 *4 (-1219 (-568))))) (-1365 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) (-5 *2 (-409 (-568))) (-5 *1 (-1019 *4)) (-4 *4 (-1219 (-568))))) (-1642 (*1 *2 *3 *2 *2) (|partial| -12 (-5 *2 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568))))) (-1642 (*1 *2 *3 *2 *4) (-12 (-5 *2 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) (-5 *4 (-409 (-568))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568))))) (-3538 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-409 (-568))) (-5 *2 (-634 (-2 (|:| -3030 *5) (|:| -3286 *5)))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568))) (-5 *4 (-2 (|:| -3030 *5) (|:| -3286 *5))))) (-3538 (*1 *2 *3 *4) (-12 (-5 *2 (-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568))) (-5 *4 (-409 (-568))))) (-3538 (*1 *2 *3 *4) (-12 (-5 *2 (-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568))) (-5 *4 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))))) (-3538 (*1 *2 *3) (-12 (-5 *2 (-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568)))))) 
+(-10 -7 (-15 -3538 ((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1|)) (-15 -3538 ((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) (-15 -3538 ((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1| (-409 (-568)))) (-15 -3538 ((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) (-409 (-568)))) (-15 -1642 ((-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) (-409 (-568)))) (-15 -1642 ((-3 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) "failed") |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) (-15 -1365 ((-409 (-568)) (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) (-15 -2571 ((-634 (-409 (-568))) (-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))))) 
+((-1642 (((-3 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) "failed") |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) 35) (((-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) (-409 (-568))) 32)) (-3538 (((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) (-409 (-568))) 30) (((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1| (-409 (-568))) 26) (((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) 28) (((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1|) 24))) 
+(((-1020 |#1|) (-10 -7 (-15 -3538 ((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1|)) (-15 -3538 ((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) (-15 -3538 ((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1| (-409 (-568)))) (-15 -3538 ((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) (-409 (-568)))) (-15 -1642 ((-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) (-409 (-568)))) (-15 -1642 ((-3 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) "failed") |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))))) (-1219 (-409 (-568)))) (T -1020)) 
+((-1642 (*1 *2 *3 *2 *2) (|partial| -12 (-5 *2 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 (-409 (-568)))))) (-1642 (*1 *2 *3 *2 *4) (-12 (-5 *2 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) (-5 *4 (-409 (-568))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 *4)))) (-3538 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-409 (-568))) (-5 *2 (-634 (-2 (|:| -3030 *5) (|:| -3286 *5)))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 *5)) (-5 *4 (-2 (|:| -3030 *5) (|:| -3286 *5))))) (-3538 (*1 *2 *3 *4) (-12 (-5 *4 (-409 (-568))) (-5 *2 (-634 (-2 (|:| -3030 *4) (|:| -3286 *4)))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 *4)))) (-3538 (*1 *2 *3 *4) (-12 (-5 *2 (-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 (-409 (-568)))) (-5 *4 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))))) (-3538 (*1 *2 *3) (-12 (-5 *2 (-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 (-409 (-568))))))) 
+(-10 -7 (-15 -3538 ((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1|)) (-15 -3538 ((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) (-15 -3538 ((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1| (-409 (-568)))) (-15 -3538 ((-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) (-409 (-568)))) (-15 -1642 ((-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) (-409 (-568)))) (-15 -1642 ((-3 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) "failed") |#1| (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))) (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))))) 
+((-4280 (((-215) $) 6) (((-381) $) 8))) 
 (((-1021) (-1275)) (T -1021)) 
 NIL 
 (-13 (-609 (-215)) (-609 (-381))) 
 (((-609 (-215)) . T) ((-609 (-381)) . T)) 
-((-4351 (((-634 (-381)) (-953 (-568)) (-381)) 27) (((-634 (-381)) (-953 (-409 (-568))) (-381)) 26)) (-3105 (((-634 (-634 (-381))) (-634 (-953 (-568))) (-634 (-1161)) (-381)) 36))) 
-(((-1022) (-10 -7 (-15 -4351 ((-634 (-381)) (-953 (-409 (-568))) (-381))) (-15 -4351 ((-634 (-381)) (-953 (-568)) (-381))) (-15 -3105 ((-634 (-634 (-381))) (-634 (-953 (-568))) (-634 (-1161)) (-381))))) (T -1022)) 
-((-3105 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-634 (-1161))) (-5 *2 (-634 (-634 (-381)))) (-5 *1 (-1022)) (-5 *5 (-381)))) (-4351 (*1 *2 *3 *4) (-12 (-5 *3 (-953 (-568))) (-5 *2 (-634 (-381))) (-5 *1 (-1022)) (-5 *4 (-381)))) (-4351 (*1 *2 *3 *4) (-12 (-5 *3 (-953 (-409 (-568)))) (-5 *2 (-634 (-381))) (-5 *1 (-1022)) (-5 *4 (-381))))) 
-(-10 -7 (-15 -4351 ((-634 (-381)) (-953 (-409 (-568))) (-381))) (-15 -4351 ((-634 (-381)) (-953 (-568)) (-381))) (-15 -3105 ((-634 (-634 (-381))) (-634 (-953 (-568))) (-634 (-1161)) (-381)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 70)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1902 (($ $) NIL) (($ $ (-763)) NIL) (($ (-409 (-568))) NIL) (($ (-568)) NIL)) (-1497 (((-121) $ $) NIL)) (-3662 (((-568) $) 65)) (-2671 (($) NIL T CONST)) (-2932 (((-3 $ "failed") (-1157 $) (-917) (-850)) NIL) (((-3 $ "failed") (-1157 $) (-917)) 49)) (-3666 (((-3 (-409 (-568)) "failed") $) NIL (|has| (-409 (-568)) (-1037 (-409 (-568))))) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 |#1| "failed") $) 108) (((-3 (-568) "failed") $) NIL (-2198 (|has| (-409 (-568)) (-1037 (-568))) (|has| |#1| (-1037 (-568)))))) (-2854 (((-409 (-568)) $) 14 (|has| (-409 (-568)) (-1037 (-409 (-568))))) (((-409 (-568)) $) 14) ((|#1| $) 109) (((-568) $) NIL (-2198 (|has| (-409 (-568)) (-1037 (-568))) (|has| |#1| (-1037 (-568)))))) (-2937 (($ $ (-850)) 40)) (-3539 (($ $ (-850)) 41)) (-2401 (($ $ $) NIL)) (-3820 (((-409 (-568)) $ $) 18)) (-2925 (((-3 $ "failed") $) 83)) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-2033 (((-121) $) 60)) (-2735 (((-121) $) NIL)) (-4044 (($ $ (-568)) NIL)) (-2245 (((-121) $) 63)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-3442 (((-3 (-1157 $) "failed") $) 78)) (-4461 (((-3 (-850) "failed") $) 77)) (-2031 (((-3 (-1157 $) "failed") $) 75)) (-1341 (((-3 (-1057 $ (-1157 $)) "failed") $) 73)) (-2495 (($ (-634 $)) NIL) (($ $ $) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) 84)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ (-634 $)) NIL) (($ $ $) NIL)) (-3848 (((-420 $) $) NIL)) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-2745 (((-850) $) 82) (($ (-568)) NIL) (($ (-409 (-568))) NIL) (($ $) 57) (($ (-409 (-568))) NIL) (($ (-568)) NIL) (($ (-409 (-568))) NIL) (($ |#1|) 111)) (-4078 (((-763)) NIL)) (-1826 (((-121) $ $) NIL)) (-3996 (((-409 (-568)) $ $) 24)) (-4309 (((-634 $) (-1157 $)) 55) (((-634 $) (-1157 (-409 (-568)))) NIL) (((-634 $) (-1157 (-568))) NIL) (((-634 $) (-953 $)) NIL) (((-634 $) (-953 (-409 (-568)))) NIL) (((-634 $) (-953 (-568))) NIL)) (-3440 (($ (-1057 $ (-1157 $)) (-850)) 39)) (-2897 (($ $) 19)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3056 (($) 28 T CONST)) (-1556 (($) 34 T CONST)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 71)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 21)) (-1779 (($ $ $) 32)) (-1773 (($ $) 33) (($ $ $) 69)) (-1767 (($ $ $) 104)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL) (($ $ (-409 (-568))) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 92) (($ $ $) 97) (($ (-409 (-568)) $) NIL) (($ $ (-409 (-568))) NIL) (($ (-568) $) 92) (($ $ (-568)) NIL) (($ (-409 (-568)) $) NIL) (($ $ (-409 (-568))) NIL) (($ |#1| $) 96) (($ $ |#1|) NIL))) 
-(((-1023 |#1|) (-13 (-1012) (-413 |#1|) (-43 |#1|) (-10 -8 (-15 -3440 ($ (-1057 $ (-1157 $)) (-850))) (-15 -1341 ((-3 (-1057 $ (-1157 $)) "failed") $)) (-15 -3820 ((-409 (-568)) $ $)))) (-13 (-840) (-365) (-1021))) (T -1023)) 
-((-3440 (*1 *1 *2 *3) (-12 (-5 *2 (-1057 (-1023 *4) (-1157 (-1023 *4)))) (-5 *3 (-850)) (-5 *1 (-1023 *4)) (-4 *4 (-13 (-840) (-365) (-1021))))) (-1341 (*1 *2 *1) (|partial| -12 (-5 *2 (-1057 (-1023 *3) (-1157 (-1023 *3)))) (-5 *1 (-1023 *3)) (-4 *3 (-13 (-840) (-365) (-1021))))) (-3820 (*1 *2 *1 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-1023 *3)) (-4 *3 (-13 (-840) (-365) (-1021)))))) 
-(-13 (-1012) (-413 |#1|) (-43 |#1|) (-10 -8 (-15 -3440 ($ (-1057 $ (-1157 $)) (-850))) (-15 -1341 ((-3 (-1057 $ (-1157 $)) "failed") $)) (-15 -3820 ((-409 (-568)) $ $)))) 
-((-3115 (((-2 (|:| -3268 (-3 (-568) "failed")) (|:| -1379 (-3 (-568) "failed")) (|:| |ker| (-607 |#2|))) (-123) (-1161) |#2|) 59 (|has| |#1| (-1047)))) (-3282 (((-568) (-568) (-123) (-1161) |#2|) 76)) (-3373 (((-3 (-568) "failed") (-123) (-607 |#2|) (-1161)) 56 (|has| |#1| (-1047)))) (-3508 (((-123) |#2|) 103)) (-3776 ((|#2| |#2|) 102)) (-2988 ((|#2| (-123) (-1161) |#2| |#2| |#2| (-634 |#2|)) 72)) (-3455 ((|#2| (-123) (-1161) |#2| |#2| |#2| (-634 |#2|)) 100))) 
-(((-1024 |#1| |#2|) (-10 -7 (-15 -2988 (|#2| (-123) (-1161) |#2| |#2| |#2| (-634 |#2|))) (-15 -3455 (|#2| (-123) (-1161) |#2| |#2| |#2| (-634 |#2|))) (-15 -3776 (|#2| |#2|)) (-15 -3508 ((-123) |#2|)) (-15 -3282 ((-568) (-568) (-123) (-1161) |#2|)) (IF (|has| |#1| (-1047)) (PROGN (-15 -3373 ((-3 (-568) "failed") (-123) (-607 |#2|) (-1161))) (-15 -3115 ((-2 (|:| -3268 (-3 (-568) "failed")) (|:| -1379 (-3 (-568) "failed")) (|:| |ker| (-607 |#2|))) (-123) (-1161) |#2|))) |noBranch|)) (-13 (-842) (-558) (-609 (-541))) (-13 (-432 |#1|) (-23) (-1037 (-568)) (-1037 (-1161)) (-895 (-1161)) (-161))) (T -1024)) 
-((-3115 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-123)) (-5 *4 (-1161)) (-4 *6 (-1047)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-2 (|:| -3268 (-3 (-568) "failed")) (|:| -1379 (-3 (-568) "failed")) (|:| |ker| (-607 *5)))) (-5 *1 (-1024 *6 *5)) (-4 *5 (-13 (-432 *6) (-23) (-1037 (-568)) (-1037 *4) (-895 *4) (-161))))) (-3373 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-607 *7)) (-4 *7 (-13 (-432 *6) (-23) (-1037 *2) (-1037 *5) (-895 *5) (-161))) (-5 *5 (-1161)) (-4 *6 (-1047)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-568)) (-5 *1 (-1024 *6 *7)))) (-3282 (*1 *2 *2 *3 *4 *5) (-12 (-5 *3 (-123)) (-5 *2 (-568)) (-5 *4 (-1161)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *1 (-1024 *6 *5)) (-4 *5 (-13 (-432 *6) (-23) (-1037 *2) (-1037 *4) (-895 *4) (-161))))) (-3508 (*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-123)) (-5 *1 (-1024 *4 *3)) (-4 *3 (-13 (-432 *4) (-23) (-1037 (-568)) (-1037 (-1161)) (-895 (-1161)) (-161))))) (-3776 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558) (-609 (-541)))) (-5 *1 (-1024 *3 *2)) (-4 *2 (-13 (-432 *3) (-23) (-1037 (-568)) (-1037 (-1161)) (-895 (-1161)) (-161))))) (-3455 (*1 *2 *3 *4 *2 *2 *2 *5) (-12 (-5 *3 (-123)) (-5 *5 (-634 *2)) (-4 *2 (-13 (-432 *6) (-23) (-1037 (-568)) (-1037 *4) (-895 *4) (-161))) (-5 *4 (-1161)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *1 (-1024 *6 *2)))) (-2988 (*1 *2 *3 *4 *2 *2 *2 *5) (-12 (-5 *3 (-123)) (-5 *5 (-634 *2)) (-4 *2 (-13 (-432 *6) (-23) (-1037 (-568)) (-1037 *4) (-895 *4) (-161))) (-5 *4 (-1161)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *1 (-1024 *6 *2))))) 
-(-10 -7 (-15 -2988 (|#2| (-123) (-1161) |#2| |#2| |#2| (-634 |#2|))) (-15 -3455 (|#2| (-123) (-1161) |#2| |#2| |#2| (-634 |#2|))) (-15 -3776 (|#2| |#2|)) (-15 -3508 ((-123) |#2|)) (-15 -3282 ((-568) (-568) (-123) (-1161) |#2|)) (IF (|has| |#1| (-1047)) (PROGN (-15 -3373 ((-3 (-568) "failed") (-123) (-607 |#2|) (-1161))) (-15 -3115 ((-2 (|:| -3268 (-3 (-568) "failed")) (|:| -1379 (-3 (-568) "failed")) (|:| |ker| (-607 |#2|))) (-123) (-1161) |#2|))) |noBranch|)) 
-((-1830 (((-2 (|:| -1853 |#2|) (|:| -4192 (-634 |#1|))) |#2| (-634 |#1|)) 20) ((|#2| |#2| |#1|) 15))) 
-(((-1025 |#1| |#2|) (-10 -7 (-15 -1830 (|#2| |#2| |#1|)) (-15 -1830 ((-2 (|:| -1853 |#2|) (|:| -4192 (-634 |#1|))) |#2| (-634 |#1|)))) (-365) (-646 |#1|)) (T -1025)) 
-((-1830 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-5 *2 (-2 (|:| -1853 *3) (|:| -4192 (-634 *5)))) (-5 *1 (-1025 *5 *3)) (-5 *4 (-634 *5)) (-4 *3 (-646 *5)))) (-1830 (*1 *2 *2 *3) (-12 (-4 *3 (-365)) (-5 *1 (-1025 *3 *2)) (-4 *2 (-646 *3))))) 
-(-10 -7 (-15 -1830 (|#2| |#2| |#1|)) (-15 -1830 ((-2 (|:| -1853 |#2|) (|:| -4192 (-634 |#1|))) |#2| (-634 |#1|)))) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3432 ((|#1| $ |#1|) 14)) (-2436 ((|#1| $ |#1|) 12)) (-1505 (($ |#1|) 10)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-2779 ((|#1| $) 11)) (-2915 ((|#1| $) 13)) (-2745 (((-850) $) 21 (|has| |#1| (-1090)))) (-1717 (((-121) $ $) 9))) 
-(((-1026 |#1|) (-13 (-1195) (-10 -8 (-15 -1505 ($ |#1|)) (-15 -2779 (|#1| $)) (-15 -2436 (|#1| $ |#1|)) (-15 -2915 (|#1| $)) (-15 -3432 (|#1| $ |#1|)) (-15 -1717 ((-121) $ $)) (IF (|has| |#1| (-1090)) (-6 (-1090)) |noBranch|))) (-1195)) (T -1026)) 
-((-1505 (*1 *1 *2) (-12 (-5 *1 (-1026 *2)) (-4 *2 (-1195)))) (-2779 (*1 *2 *1) (-12 (-5 *1 (-1026 *2)) (-4 *2 (-1195)))) (-2436 (*1 *2 *1 *2) (-12 (-5 *1 (-1026 *2)) (-4 *2 (-1195)))) (-2915 (*1 *2 *1) (-12 (-5 *1 (-1026 *2)) (-4 *2 (-1195)))) (-3432 (*1 *2 *1 *2) (-12 (-5 *1 (-1026 *2)) (-4 *2 (-1195)))) (-1717 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1026 *3)) (-4 *3 (-1195))))) 
-(-13 (-1195) (-10 -8 (-15 -1505 ($ |#1|)) (-15 -2779 (|#1| $)) (-15 -2436 (|#1| $ |#1|)) (-15 -2915 (|#1| $)) (-15 -3432 (|#1| $ |#1|)) (-15 -1717 ((-121) $ $)) (IF (|has| |#1| (-1090)) (-6 (-1090)) |noBranch|))) 
-((-2447 (((-121) $ $) NIL)) (-2387 (((-634 (-2 (|:| -4092 $) (|:| -1798 (-634 |#4|)))) (-634 |#4|)) NIL)) (-2415 (((-634 $) (-634 |#4|)) 104) (((-634 $) (-634 |#4|) (-121)) 105) (((-634 $) (-634 |#4|) (-121) (-121)) 103) (((-634 $) (-634 |#4|) (-121) (-121) (-121) (-121)) 106)) (-2055 (((-634 |#3|) $) NIL)) (-4211 (((-121) $) NIL)) (-3824 (((-121) $) NIL (|has| |#1| (-558)))) (-3300 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-2819 ((|#4| |#4| $) NIL)) (-4305 (((-634 (-2 (|:| |val| |#4|) (|:| -3001 $))) |#4| $) 98)) (-3644 (((-2 (|:| |under| $) (|:| -1519 $) (|:| |upper| $)) $ |#3|) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-2801 (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519))) (((-3 |#4| "failed") $ |#3|) 53)) (-2671 (($) NIL T CONST)) (-1565 (((-121) $) 26 (|has| |#1| (-558)))) (-3846 (((-121) $ $) NIL (|has| |#1| (-558)))) (-3106 (((-121) $ $) NIL (|has| |#1| (-558)))) (-3695 (((-121) $) NIL (|has| |#1| (-558)))) (-4275 (((-634 |#4|) (-634 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-2355 (((-634 |#4|) (-634 |#4|) $) NIL (|has| |#1| (-558)))) (-2492 (((-634 |#4|) (-634 |#4|) $) NIL (|has| |#1| (-558)))) (-3666 (((-3 $ "failed") (-634 |#4|)) NIL)) (-2854 (($ (-634 |#4|)) NIL)) (-3935 (((-3 $ "failed") $) 39)) (-2062 ((|#4| |#4| $) 56)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090))))) (-4328 (($ |#4| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090)))) (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-1500 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 72 (|has| |#1| (-558)))) (-1281 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) NIL)) (-4079 ((|#4| |#4| $) NIL)) (-3092 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) NIL (|has| $ (-6 -4519))) ((|#4| (-1 |#4| |#4| |#4|) $) NIL (|has| $ (-6 -4519))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-3635 (((-2 (|:| -4092 (-634 |#4|)) (|:| -1798 (-634 |#4|))) $) NIL)) (-1862 (((-121) |#4| $) NIL)) (-4286 (((-121) |#4| $) NIL)) (-3193 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-1796 (((-2 (|:| |val| (-634 |#4|)) (|:| |towers| (-634 $))) (-634 |#4|) (-121) (-121)) 118)) (-4360 (((-634 |#4|) $) 16 (|has| $ (-6 -4519)))) (-1362 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-2356 ((|#3| $) 33)) (-1737 (((-121) $ (-763)) NIL)) (-1979 (((-634 |#4|) $) 17 (|has| $ (-6 -4519)))) (-3109 (((-121) |#4| $) 25 (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090))))) (-3674 (($ (-1 |#4| |#4|) $) 23 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#4| |#4|) $) 21)) (-1432 (((-634 |#3|) $) NIL)) (-3392 (((-121) |#3| $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL)) (-2717 (((-3 |#4| (-634 $)) |#4| |#4| $) NIL)) (-4330 (((-634 (-2 (|:| |val| |#4|) (|:| -3001 $))) |#4| |#4| $) 96)) (-4162 (((-3 |#4| "failed") $) 37)) (-2335 (((-634 $) |#4| $) 79)) (-1719 (((-3 (-121) (-634 $)) |#4| $) NIL)) (-2632 (((-634 (-2 (|:| |val| (-121)) (|:| -3001 $))) |#4| $) 89) (((-121) |#4| $) 51)) (-3212 (((-634 $) |#4| $) 101) (((-634 $) (-634 |#4|) $) NIL) (((-634 $) (-634 |#4|) (-634 $)) 102) (((-634 $) |#4| (-634 $)) NIL)) (-2099 (((-634 $) (-634 |#4|) (-121) (-121) (-121)) 113)) (-3473 (($ |#4| $) 69) (($ (-634 |#4|) $) 70) (((-634 $) |#4| $ (-121) (-121) (-121) (-121) (-121)) 66)) (-1377 (((-634 |#4|) $) NIL)) (-1415 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-2682 ((|#4| |#4| $) NIL)) (-2644 (((-121) $ $) NIL)) (-2705 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-558)))) (-4347 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-4025 ((|#4| |#4| $) NIL)) (-4022 (((-1108) $) NIL)) (-3876 (((-3 |#4| "failed") $) 35)) (-3775 (((-3 |#4| "failed") (-1 (-121) |#4|) $) NIL)) (-1665 (((-3 $ "failed") $ |#4|) 47)) (-1807 (($ $ |#4|) NIL) (((-634 $) |#4| $) 81) (((-634 $) |#4| (-634 $)) NIL) (((-634 $) (-634 |#4|) $) NIL) (((-634 $) (-634 |#4|) (-634 $)) 76)) (-1387 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 |#4|) (-634 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 (-288 |#4|))) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) 15)) (-3248 (($) 13)) (-3206 (((-763) $) NIL)) (-4168 (((-763) |#4| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090)))) (((-763) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-3863 (($ $) 12)) (-4278 (((-541) $) NIL (|has| |#4| (-609 (-541))))) (-4287 (($ (-634 |#4|)) 20)) (-1290 (($ $ |#3|) 42)) (-3732 (($ $ |#3|) 43)) (-1567 (($ $) NIL)) (-3944 (($ $ |#3|) NIL)) (-2745 (((-850) $) 31) (((-634 |#4|) $) 40)) (-1878 (((-763) $) NIL (|has| |#3| (-370)))) (-3556 (((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4| |#4|)) NIL) (((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-3292 (((-121) $ (-1 (-121) |#4| (-634 |#4|))) NIL)) (-2574 (((-634 $) |#4| $) 78) (((-634 $) |#4| (-634 $)) NIL) (((-634 $) (-634 |#4|) $) NIL) (((-634 $) (-634 |#4|) (-634 $)) NIL)) (-1319 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-2739 (((-634 |#3|) $) NIL)) (-2288 (((-121) |#4| $) NIL)) (-4390 (((-121) |#3| $) 52)) (-1717 (((-121) $ $) NIL)) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-1027 |#1| |#2| |#3| |#4|) (-13 (-1066 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3473 ((-634 $) |#4| $ (-121) (-121) (-121) (-121) (-121))) (-15 -2415 ((-634 $) (-634 |#4|) (-121) (-121))) (-15 -2415 ((-634 $) (-634 |#4|) (-121) (-121) (-121) (-121))) (-15 -2099 ((-634 $) (-634 |#4|) (-121) (-121) (-121))) (-15 -1796 ((-2 (|:| |val| (-634 |#4|)) (|:| |towers| (-634 $))) (-634 |#4|) (-121) (-121))))) (-453) (-788) (-842) (-1061 |#1| |#2| |#3|)) (T -1027)) 
-((-3473 (*1 *2 *3 *1 *4 *4 *4 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1027 *5 *6 *7 *3))) (-5 *1 (-1027 *5 *6 *7 *3)) (-4 *3 (-1061 *5 *6 *7)))) (-2415 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1027 *5 *6 *7 *8))) (-5 *1 (-1027 *5 *6 *7 *8)))) (-2415 (*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1027 *5 *6 *7 *8))) (-5 *1 (-1027 *5 *6 *7 *8)))) (-2099 (*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1027 *5 *6 *7 *8))) (-5 *1 (-1027 *5 *6 *7 *8)))) (-1796 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |val| (-634 *8)) (|:| |towers| (-634 (-1027 *5 *6 *7 *8))))) (-5 *1 (-1027 *5 *6 *7 *8)) (-5 *3 (-634 *8))))) 
-(-13 (-1066 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3473 ((-634 $) |#4| $ (-121) (-121) (-121) (-121) (-121))) (-15 -2415 ((-634 $) (-634 |#4|) (-121) (-121))) (-15 -2415 ((-634 $) (-634 |#4|) (-121) (-121) (-121) (-121))) (-15 -2099 ((-634 $) (-634 |#4|) (-121) (-121) (-121))) (-15 -1796 ((-2 (|:| |val| (-634 |#4|)) (|:| |towers| (-634 $))) (-634 |#4|) (-121) (-121))))) 
-((-2523 (((-634 (-679 |#1|)) (-634 (-679 |#1|))) 56) (((-679 |#1|) (-679 |#1|)) 55) (((-634 (-679 |#1|)) (-634 (-679 |#1|)) (-634 (-679 |#1|))) 54) (((-679 |#1|) (-679 |#1|) (-679 |#1|)) 51)) (-3514 (((-634 (-679 |#1|)) (-634 (-679 |#1|)) (-917)) 50) (((-679 |#1|) (-679 |#1|) (-917)) 49)) (-3125 (((-634 (-679 (-568))) (-634 (-634 (-568)))) 66) (((-634 (-679 (-568))) (-634 (-900 (-568))) (-568)) 65) (((-679 (-568)) (-634 (-568))) 62) (((-679 (-568)) (-900 (-568)) (-568)) 61)) (-3320 (((-679 (-953 |#1|)) (-763)) 79)) (-1882 (((-634 (-679 |#1|)) (-634 (-679 |#1|)) (-917)) 36 (|has| |#1| (-6 (-4521 "*")))) (((-679 |#1|) (-679 |#1|) (-917)) 34 (|has| |#1| (-6 (-4521 "*")))))) 
-(((-1028 |#1|) (-10 -7 (IF (|has| |#1| (-6 (-4521 "*"))) (-15 -1882 ((-679 |#1|) (-679 |#1|) (-917))) |noBranch|) (IF (|has| |#1| (-6 (-4521 "*"))) (-15 -1882 ((-634 (-679 |#1|)) (-634 (-679 |#1|)) (-917))) |noBranch|) (-15 -3320 ((-679 (-953 |#1|)) (-763))) (-15 -3514 ((-679 |#1|) (-679 |#1|) (-917))) (-15 -3514 ((-634 (-679 |#1|)) (-634 (-679 |#1|)) (-917))) (-15 -2523 ((-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -2523 ((-634 (-679 |#1|)) (-634 (-679 |#1|)) (-634 (-679 |#1|)))) (-15 -2523 ((-679 |#1|) (-679 |#1|))) (-15 -2523 ((-634 (-679 |#1|)) (-634 (-679 |#1|)))) (-15 -3125 ((-679 (-568)) (-900 (-568)) (-568))) (-15 -3125 ((-679 (-568)) (-634 (-568)))) (-15 -3125 ((-634 (-679 (-568))) (-634 (-900 (-568))) (-568))) (-15 -3125 ((-634 (-679 (-568))) (-634 (-634 (-568)))))) (-1047)) (T -1028)) 
-((-3125 (*1 *2 *3) (-12 (-5 *3 (-634 (-634 (-568)))) (-5 *2 (-634 (-679 (-568)))) (-5 *1 (-1028 *4)) (-4 *4 (-1047)))) (-3125 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-900 (-568)))) (-5 *4 (-568)) (-5 *2 (-634 (-679 *4))) (-5 *1 (-1028 *5)) (-4 *5 (-1047)))) (-3125 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-679 (-568))) (-5 *1 (-1028 *4)) (-4 *4 (-1047)))) (-3125 (*1 *2 *3 *4) (-12 (-5 *3 (-900 (-568))) (-5 *4 (-568)) (-5 *2 (-679 *4)) (-5 *1 (-1028 *5)) (-4 *5 (-1047)))) (-2523 (*1 *2 *2) (-12 (-5 *2 (-634 (-679 *3))) (-4 *3 (-1047)) (-5 *1 (-1028 *3)))) (-2523 (*1 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-1028 *3)))) (-2523 (*1 *2 *2 *2) (-12 (-5 *2 (-634 (-679 *3))) (-4 *3 (-1047)) (-5 *1 (-1028 *3)))) (-2523 (*1 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-1028 *3)))) (-3514 (*1 *2 *2 *3) (-12 (-5 *2 (-634 (-679 *4))) (-5 *3 (-917)) (-4 *4 (-1047)) (-5 *1 (-1028 *4)))) (-3514 (*1 *2 *2 *3) (-12 (-5 *2 (-679 *4)) (-5 *3 (-917)) (-4 *4 (-1047)) (-5 *1 (-1028 *4)))) (-3320 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-679 (-953 *4))) (-5 *1 (-1028 *4)) (-4 *4 (-1047)))) (-1882 (*1 *2 *2 *3) (-12 (-5 *2 (-634 (-679 *4))) (-5 *3 (-917)) (|has| *4 (-6 (-4521 "*"))) (-4 *4 (-1047)) (-5 *1 (-1028 *4)))) (-1882 (*1 *2 *2 *3) (-12 (-5 *2 (-679 *4)) (-5 *3 (-917)) (|has| *4 (-6 (-4521 "*"))) (-4 *4 (-1047)) (-5 *1 (-1028 *4))))) 
-(-10 -7 (IF (|has| |#1| (-6 (-4521 "*"))) (-15 -1882 ((-679 |#1|) (-679 |#1|) (-917))) |noBranch|) (IF (|has| |#1| (-6 (-4521 "*"))) (-15 -1882 ((-634 (-679 |#1|)) (-634 (-679 |#1|)) (-917))) |noBranch|) (-15 -3320 ((-679 (-953 |#1|)) (-763))) (-15 -3514 ((-679 |#1|) (-679 |#1|) (-917))) (-15 -3514 ((-634 (-679 |#1|)) (-634 (-679 |#1|)) (-917))) (-15 -2523 ((-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -2523 ((-634 (-679 |#1|)) (-634 (-679 |#1|)) (-634 (-679 |#1|)))) (-15 -2523 ((-679 |#1|) (-679 |#1|))) (-15 -2523 ((-634 (-679 |#1|)) (-634 (-679 |#1|)))) (-15 -3125 ((-679 (-568)) (-900 (-568)) (-568))) (-15 -3125 ((-679 (-568)) (-634 (-568)))) (-15 -3125 ((-634 (-679 (-568))) (-634 (-900 (-568))) (-568))) (-15 -3125 ((-634 (-679 (-568))) (-634 (-634 (-568)))))) 
-((-1593 (((-679 |#1|) (-634 (-679 |#1|)) (-1244 |#1|)) 48 (|has| |#1| (-301)))) (-3969 (((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-1244 (-1244 |#1|))) 71 (|has| |#1| (-365))) (((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-1244 |#1|)) 69 (|has| |#1| (-365)))) (-2834 (((-1244 |#1|) (-634 (-1244 |#1|)) (-568)) 73 (-12 (|has| |#1| (-365)) (|has| |#1| (-370))))) (-2609 (((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-917)) 78 (-12 (|has| |#1| (-365)) (|has| |#1| (-370)))) (((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-121)) 76 (-12 (|has| |#1| (-365)) (|has| |#1| (-370)))) (((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|))) 75 (-12 (|has| |#1| (-365)) (|has| |#1| (-370)))) (((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-121) (-568) (-568)) 74 (-12 (|has| |#1| (-365)) (|has| |#1| (-370))))) (-1433 (((-121) (-634 (-679 |#1|))) 67 (|has| |#1| (-365))) (((-121) (-634 (-679 |#1|)) (-568)) 66 (|has| |#1| (-365)))) (-2229 (((-1244 (-1244 |#1|)) (-634 (-679 |#1|)) (-1244 |#1|)) 46 (|has| |#1| (-301)))) (-1772 (((-679 |#1|) (-634 (-679 |#1|)) (-679 |#1|)) 32)) (-2273 (((-679 |#1|) (-1244 (-1244 |#1|))) 29)) (-2004 (((-679 |#1|) (-634 (-679 |#1|)) (-634 (-679 |#1|)) (-568)) 62 (|has| |#1| (-365))) (((-679 |#1|) (-634 (-679 |#1|)) (-634 (-679 |#1|))) 61 (|has| |#1| (-365))) (((-679 |#1|) (-634 (-679 |#1|)) (-634 (-679 |#1|)) (-121) (-568)) 60 (|has| |#1| (-365))))) 
-(((-1029 |#1|) (-10 -7 (-15 -2273 ((-679 |#1|) (-1244 (-1244 |#1|)))) (-15 -1772 ((-679 |#1|) (-634 (-679 |#1|)) (-679 |#1|))) (IF (|has| |#1| (-301)) (PROGN (-15 -2229 ((-1244 (-1244 |#1|)) (-634 (-679 |#1|)) (-1244 |#1|))) (-15 -1593 ((-679 |#1|) (-634 (-679 |#1|)) (-1244 |#1|)))) |noBranch|) (IF (|has| |#1| (-365)) (PROGN (-15 -2004 ((-679 |#1|) (-634 (-679 |#1|)) (-634 (-679 |#1|)) (-121) (-568))) (-15 -2004 ((-679 |#1|) (-634 (-679 |#1|)) (-634 (-679 |#1|)))) (-15 -2004 ((-679 |#1|) (-634 (-679 |#1|)) (-634 (-679 |#1|)) (-568))) (-15 -1433 ((-121) (-634 (-679 |#1|)) (-568))) (-15 -1433 ((-121) (-634 (-679 |#1|)))) (-15 -3969 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-1244 |#1|))) (-15 -3969 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-1244 (-1244 |#1|))))) |noBranch|) (IF (|has| |#1| (-370)) (IF (|has| |#1| (-365)) (PROGN (-15 -2609 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-121) (-568) (-568))) (-15 -2609 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)))) (-15 -2609 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-121))) (-15 -2609 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-917))) (-15 -2834 ((-1244 |#1|) (-634 (-1244 |#1|)) (-568)))) |noBranch|) |noBranch|)) (-1047)) (T -1029)) 
-((-2834 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1244 *5))) (-5 *4 (-568)) (-5 *2 (-1244 *5)) (-5 *1 (-1029 *5)) (-4 *5 (-365)) (-4 *5 (-370)) (-4 *5 (-1047)))) (-2609 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-365)) (-4 *5 (-370)) (-4 *5 (-1047)) (-5 *2 (-634 (-634 (-679 *5)))) (-5 *1 (-1029 *5)) (-5 *3 (-634 (-679 *5))))) (-2609 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-365)) (-4 *5 (-370)) (-4 *5 (-1047)) (-5 *2 (-634 (-634 (-679 *5)))) (-5 *1 (-1029 *5)) (-5 *3 (-634 (-679 *5))))) (-2609 (*1 *2 *3) (-12 (-4 *4 (-365)) (-4 *4 (-370)) (-4 *4 (-1047)) (-5 *2 (-634 (-634 (-679 *4)))) (-5 *1 (-1029 *4)) (-5 *3 (-634 (-679 *4))))) (-2609 (*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-121)) (-5 *5 (-568)) (-4 *6 (-365)) (-4 *6 (-370)) (-4 *6 (-1047)) (-5 *2 (-634 (-634 (-679 *6)))) (-5 *1 (-1029 *6)) (-5 *3 (-634 (-679 *6))))) (-3969 (*1 *2 *3 *4) (-12 (-5 *4 (-1244 (-1244 *5))) (-4 *5 (-365)) (-4 *5 (-1047)) (-5 *2 (-634 (-634 (-679 *5)))) (-5 *1 (-1029 *5)) (-5 *3 (-634 (-679 *5))))) (-3969 (*1 *2 *3 *4) (-12 (-5 *4 (-1244 *5)) (-4 *5 (-365)) (-4 *5 (-1047)) (-5 *2 (-634 (-634 (-679 *5)))) (-5 *1 (-1029 *5)) (-5 *3 (-634 (-679 *5))))) (-1433 (*1 *2 *3) (-12 (-5 *3 (-634 (-679 *4))) (-4 *4 (-365)) (-4 *4 (-1047)) (-5 *2 (-121)) (-5 *1 (-1029 *4)))) (-1433 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-679 *5))) (-5 *4 (-568)) (-4 *5 (-365)) (-4 *5 (-1047)) (-5 *2 (-121)) (-5 *1 (-1029 *5)))) (-2004 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-634 (-679 *5))) (-5 *4 (-568)) (-5 *2 (-679 *5)) (-5 *1 (-1029 *5)) (-4 *5 (-365)) (-4 *5 (-1047)))) (-2004 (*1 *2 *3 *3) (-12 (-5 *3 (-634 (-679 *4))) (-5 *2 (-679 *4)) (-5 *1 (-1029 *4)) (-4 *4 (-365)) (-4 *4 (-1047)))) (-2004 (*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-634 (-679 *6))) (-5 *4 (-121)) (-5 *5 (-568)) (-5 *2 (-679 *6)) (-5 *1 (-1029 *6)) (-4 *6 (-365)) (-4 *6 (-1047)))) (-1593 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-679 *5))) (-5 *4 (-1244 *5)) (-4 *5 (-301)) (-4 *5 (-1047)) (-5 *2 (-679 *5)) (-5 *1 (-1029 *5)))) (-2229 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-679 *5))) (-4 *5 (-301)) (-4 *5 (-1047)) (-5 *2 (-1244 (-1244 *5))) (-5 *1 (-1029 *5)) (-5 *4 (-1244 *5)))) (-1772 (*1 *2 *3 *2) (-12 (-5 *3 (-634 (-679 *4))) (-5 *2 (-679 *4)) (-4 *4 (-1047)) (-5 *1 (-1029 *4)))) (-2273 (*1 *2 *3) (-12 (-5 *3 (-1244 (-1244 *4))) (-4 *4 (-1047)) (-5 *2 (-679 *4)) (-5 *1 (-1029 *4))))) 
-(-10 -7 (-15 -2273 ((-679 |#1|) (-1244 (-1244 |#1|)))) (-15 -1772 ((-679 |#1|) (-634 (-679 |#1|)) (-679 |#1|))) (IF (|has| |#1| (-301)) (PROGN (-15 -2229 ((-1244 (-1244 |#1|)) (-634 (-679 |#1|)) (-1244 |#1|))) (-15 -1593 ((-679 |#1|) (-634 (-679 |#1|)) (-1244 |#1|)))) |noBranch|) (IF (|has| |#1| (-365)) (PROGN (-15 -2004 ((-679 |#1|) (-634 (-679 |#1|)) (-634 (-679 |#1|)) (-121) (-568))) (-15 -2004 ((-679 |#1|) (-634 (-679 |#1|)) (-634 (-679 |#1|)))) (-15 -2004 ((-679 |#1|) (-634 (-679 |#1|)) (-634 (-679 |#1|)) (-568))) (-15 -1433 ((-121) (-634 (-679 |#1|)) (-568))) (-15 -1433 ((-121) (-634 (-679 |#1|)))) (-15 -3969 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-1244 |#1|))) (-15 -3969 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-1244 (-1244 |#1|))))) |noBranch|) (IF (|has| |#1| (-370)) (IF (|has| |#1| (-365)) (PROGN (-15 -2609 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-121) (-568) (-568))) (-15 -2609 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)))) (-15 -2609 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-121))) (-15 -2609 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-917))) (-15 -2834 ((-1244 |#1|) (-634 (-1244 |#1|)) (-568)))) |noBranch|) |noBranch|)) 
-((-3063 ((|#1| (-917) |#1|) 9))) 
-(((-1030 |#1|) (-10 -7 (-15 -3063 (|#1| (-917) |#1|))) (-13 (-1090) (-10 -8 (-15 -1767 ($ $ $))))) (T -1030)) 
-((-3063 (*1 *2 *3 *2) (-12 (-5 *3 (-917)) (-5 *1 (-1030 *2)) (-4 *2 (-13 (-1090) (-10 -8 (-15 -1767 ($ $ $)))))))) 
-(-10 -7 (-15 -3063 (|#1| (-917) |#1|))) 
-((-2266 (((-634 (-2 (|:| |radval| (-310 (-568))) (|:| |radmult| (-568)) (|:| |radvect| (-634 (-679 (-310 (-568))))))) (-679 (-409 (-953 (-568))))) 58)) (-1968 (((-634 (-679 (-310 (-568)))) (-310 (-568)) (-679 (-409 (-953 (-568))))) 48)) (-3825 (((-634 (-310 (-568))) (-679 (-409 (-953 (-568))))) 41)) (-3830 (((-634 (-679 (-310 (-568)))) (-679 (-409 (-953 (-568))))) 67)) (-3170 (((-679 (-310 (-568))) (-679 (-310 (-568)))) 33)) (-2275 (((-634 (-679 (-310 (-568)))) (-634 (-679 (-310 (-568))))) 61)) (-2912 (((-3 (-679 (-310 (-568))) "failed") (-679 (-409 (-953 (-568))))) 65))) 
-(((-1031) (-10 -7 (-15 -2266 ((-634 (-2 (|:| |radval| (-310 (-568))) (|:| |radmult| (-568)) (|:| |radvect| (-634 (-679 (-310 (-568))))))) (-679 (-409 (-953 (-568)))))) (-15 -1968 ((-634 (-679 (-310 (-568)))) (-310 (-568)) (-679 (-409 (-953 (-568)))))) (-15 -3825 ((-634 (-310 (-568))) (-679 (-409 (-953 (-568)))))) (-15 -2912 ((-3 (-679 (-310 (-568))) "failed") (-679 (-409 (-953 (-568)))))) (-15 -3170 ((-679 (-310 (-568))) (-679 (-310 (-568))))) (-15 -2275 ((-634 (-679 (-310 (-568)))) (-634 (-679 (-310 (-568)))))) (-15 -3830 ((-634 (-679 (-310 (-568)))) (-679 (-409 (-953 (-568)))))))) (T -1031)) 
-((-3830 (*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-953 (-568))))) (-5 *2 (-634 (-679 (-310 (-568))))) (-5 *1 (-1031)))) (-2275 (*1 *2 *2) (-12 (-5 *2 (-634 (-679 (-310 (-568))))) (-5 *1 (-1031)))) (-3170 (*1 *2 *2) (-12 (-5 *2 (-679 (-310 (-568)))) (-5 *1 (-1031)))) (-2912 (*1 *2 *3) (|partial| -12 (-5 *3 (-679 (-409 (-953 (-568))))) (-5 *2 (-679 (-310 (-568)))) (-5 *1 (-1031)))) (-3825 (*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-953 (-568))))) (-5 *2 (-634 (-310 (-568)))) (-5 *1 (-1031)))) (-1968 (*1 *2 *3 *4) (-12 (-5 *4 (-679 (-409 (-953 (-568))))) (-5 *2 (-634 (-679 (-310 (-568))))) (-5 *1 (-1031)) (-5 *3 (-310 (-568))))) (-2266 (*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| |radval| (-310 (-568))) (|:| |radmult| (-568)) (|:| |radvect| (-634 (-679 (-310 (-568)))))))) (-5 *1 (-1031))))) 
-(-10 -7 (-15 -2266 ((-634 (-2 (|:| |radval| (-310 (-568))) (|:| |radmult| (-568)) (|:| |radvect| (-634 (-679 (-310 (-568))))))) (-679 (-409 (-953 (-568)))))) (-15 -1968 ((-634 (-679 (-310 (-568)))) (-310 (-568)) (-679 (-409 (-953 (-568)))))) (-15 -3825 ((-634 (-310 (-568))) (-679 (-409 (-953 (-568)))))) (-15 -2912 ((-3 (-679 (-310 (-568))) "failed") (-679 (-409 (-953 (-568)))))) (-15 -3170 ((-679 (-310 (-568))) (-679 (-310 (-568))))) (-15 -2275 ((-634 (-679 (-310 (-568)))) (-634 (-679 (-310 (-568)))))) (-15 -3830 ((-634 (-679 (-310 (-568)))) (-679 (-409 (-953 (-568))))))) 
-((-1876 ((|#1| |#1| (-917)) 9))) 
-(((-1032 |#1|) (-10 -7 (-15 -1876 (|#1| |#1| (-917)))) (-13 (-1090) (-10 -8 (-15 * ($ $ $))))) (T -1032)) 
-((-1876 (*1 *2 *2 *3) (-12 (-5 *3 (-917)) (-5 *1 (-1032 *2)) (-4 *2 (-13 (-1090) (-10 -8 (-15 * ($ $ $)))))))) 
-(-10 -7 (-15 -1876 (|#1| |#1| (-917)))) 
-((-2745 ((|#1| (-305)) 11) (((-1249) |#1|) 9))) 
-(((-1033 |#1|) (-10 -7 (-15 -2745 ((-1249) |#1|)) (-15 -2745 (|#1| (-305)))) (-1195)) (T -1033)) 
-((-2745 (*1 *2 *3) (-12 (-5 *3 (-305)) (-5 *1 (-1033 *2)) (-4 *2 (-1195)))) (-2745 (*1 *2 *3) (-12 (-5 *2 (-1249)) (-5 *1 (-1033 *3)) (-4 *3 (-1195))))) 
-(-10 -7 (-15 -2745 ((-1249) |#1|)) (-15 -2745 (|#1| (-305)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-3092 (($ |#4|) 25)) (-2925 (((-3 $ "failed") $) NIL)) (-2735 (((-121) $) NIL)) (-3085 ((|#4| $) 27)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 46) (($ (-568)) NIL) (($ |#1|) NIL) (($ |#4|) 26)) (-4078 (((-763)) 43)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 21 T CONST)) (-1556 (($) 23 T CONST)) (-1717 (((-121) $ $) 40)) (-1773 (($ $) 31) (($ $ $) NIL)) (-1767 (($ $ $) 29)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 36) (($ $ $) 33) (($ |#1| $) 38) (($ $ |#1|) NIL))) 
-(((-1034 |#1| |#2| |#3| |#4| |#5|) (-13 (-172) (-43 |#1|) (-10 -8 (-15 -3092 ($ |#4|)) (-15 -2745 ($ |#4|)) (-15 -3085 (|#4| $)))) (-365) (-788) (-842) (-950 |#1| |#2| |#3|) (-634 |#4|)) (T -1034)) 
-((-3092 (*1 *1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-1034 *3 *4 *5 *2 *6)) (-4 *2 (-950 *3 *4 *5)) (-14 *6 (-634 *2)))) (-2745 (*1 *1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-1034 *3 *4 *5 *2 *6)) (-4 *2 (-950 *3 *4 *5)) (-14 *6 (-634 *2)))) (-3085 (*1 *2 *1) (-12 (-4 *2 (-950 *3 *4 *5)) (-5 *1 (-1034 *3 *4 *5 *2 *6)) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-14 *6 (-634 *2))))) 
-(-13 (-172) (-43 |#1|) (-10 -8 (-15 -3092 ($ |#4|)) (-15 -2745 ($ |#4|)) (-15 -3085 (|#4| $)))) 
-((-2447 (((-121) $ $) NIL (-2198 (|has| (-57) (-1090)) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090))))) (-2986 (($) NIL) (($ (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))))) NIL)) (-1868 (((-1249) $ (-1161) (-1161)) NIL (|has| $ (-6 -4520)))) (-2510 (((-121) $ (-763)) NIL)) (-4358 (((-121) (-121)) 39)) (-3843 (((-121) (-121)) 38)) (-2436 (((-57) $ (-1161) (-57)) NIL)) (-3507 (($ (-1 (-121) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519)))) (-2674 (((-3 (-57) "failed") (-1161) $) NIL)) (-2671 (($) NIL T CONST)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090))))) (-3405 (($ (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) $) NIL (|has| $ (-6 -4519))) (($ (-1 (-121) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519))) (((-3 (-57) "failed") (-1161) $) NIL)) (-4328 (($ (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090)))) (($ (-1 (-121) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519)))) (-3092 (((-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $ (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090)))) (((-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $ (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) NIL (|has| $ (-6 -4519))) (((-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519)))) (-3989 (((-57) $ (-1161) (-57)) NIL (|has| $ (-6 -4520)))) (-2602 (((-57) $ (-1161)) NIL)) (-4360 (((-634 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519))) (((-634 (-57)) $) NIL (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-1161) $) NIL (|has| (-1161) (-842)))) (-1979 (((-634 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519))) (((-634 (-57)) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090)))) (((-121) (-57) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-57) (-1090))))) (-2223 (((-1161) $) NIL (|has| (-1161) (-842)))) (-3674 (($ (-1 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4520))) (($ (-1 (-57) (-57)) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL) (($ (-1 (-57) (-57)) $) NIL) (($ (-1 (-57) (-57) (-57)) $ $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (-2198 (|has| (-57) (-1090)) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090))))) (-1946 (((-634 (-1161)) $) 34)) (-3548 (((-121) (-1161) $) NIL)) (-1890 (((-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) $) NIL)) (-4450 (($ (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) $) NIL)) (-4174 (((-634 (-1161)) $) NIL)) (-3578 (((-121) (-1161) $) NIL)) (-4022 (((-1108) $) NIL (-2198 (|has| (-57) (-1090)) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090))))) (-3876 (((-57) $) NIL (|has| (-1161) (-842)))) (-3775 (((-3 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) "failed") (-1 (-121) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL)) (-3724 (($ $ (-57)) NIL (|has| $ (-6 -4520)))) (-1315 (((-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) $) NIL)) (-1387 (((-121) (-1 (-121) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))))) NIL (-12 (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-303 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))))) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090)))) (($ $ (-288 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))))) NIL (-12 (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-303 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))))) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090)))) (($ $ (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) NIL (-12 (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-303 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))))) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090)))) (($ $ (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))))) NIL (-12 (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-303 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))))) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090)))) (($ $ (-634 (-57)) (-634 (-57))) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090)))) (($ $ (-57) (-57)) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090)))) (($ $ (-288 (-57))) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090)))) (($ $ (-634 (-288 (-57)))) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) (-57) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-57) (-1090))))) (-2041 (((-634 (-57)) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 (((-57) $ (-1161)) 35) (((-57) $ (-1161) (-57)) NIL)) (-2085 (($) NIL) (($ (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))))) NIL)) (-4168 (((-763) (-1 (-121) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519))) (((-763) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090)))) (((-763) (-57) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-57) (-1090)))) (((-763) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4519)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-609 (-541))))) (-4287 (($ (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))))) NIL)) (-2745 (((-850) $) 37 (-2198 (|has| (-57) (-1090)) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090))))) (-2367 (($ (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))))) NIL)) (-1319 (((-121) (-1 (-121) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) NIL (-2198 (|has| (-57) (-1090)) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090))))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-1035) (-13 (-1172 (-1161) (-57)) (-10 -7 (-15 -4358 ((-121) (-121))) (-15 -3843 ((-121) (-121))) (-6 -4519)))) (T -1035)) 
-((-4358 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1035)))) (-3843 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1035))))) 
-(-13 (-1172 (-1161) (-57)) (-10 -7 (-15 -4358 ((-121) (-121))) (-15 -3843 ((-121) (-121))) (-6 -4519))) 
-((-2854 ((|#2| $) 10))) 
-(((-1036 |#1| |#2|) (-10 -8 (-15 -2854 (|#2| |#1|))) (-1037 |#2|) (-1195)) (T -1036)) 
-NIL 
-(-10 -8 (-15 -2854 (|#2| |#1|))) 
-((-3666 (((-3 |#1| "failed") $) 7)) (-2854 ((|#1| $) 8)) (-2745 (($ |#1|) 6))) 
+((-3259 (((-634 (-381)) (-953 (-568)) (-381)) 27) (((-634 (-381)) (-953 (-409 (-568))) (-381)) 26)) (-2531 (((-634 (-634 (-381))) (-634 (-953 (-568))) (-634 (-1161)) (-381)) 36))) 
+(((-1022) (-10 -7 (-15 -3259 ((-634 (-381)) (-953 (-409 (-568))) (-381))) (-15 -3259 ((-634 (-381)) (-953 (-568)) (-381))) (-15 -2531 ((-634 (-634 (-381))) (-634 (-953 (-568))) (-634 (-1161)) (-381))))) (T -1022)) 
+((-2531 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-634 (-1161))) (-5 *2 (-634 (-634 (-381)))) (-5 *1 (-1022)) (-5 *5 (-381)))) (-3259 (*1 *2 *3 *4) (-12 (-5 *3 (-953 (-568))) (-5 *2 (-634 (-381))) (-5 *1 (-1022)) (-5 *4 (-381)))) (-3259 (*1 *2 *3 *4) (-12 (-5 *3 (-953 (-409 (-568)))) (-5 *2 (-634 (-381))) (-5 *1 (-1022)) (-5 *4 (-381))))) 
+(-10 -7 (-15 -3259 ((-634 (-381)) (-953 (-409 (-568))) (-381))) (-15 -3259 ((-634 (-381)) (-953 (-568)) (-381))) (-15 -2531 ((-634 (-634 (-381))) (-634 (-953 (-568))) (-634 (-1161)) (-381)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 70)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-1904 (($ $) NIL) (($ $ (-763)) NIL) (($ (-409 (-568))) NIL) (($ (-568)) NIL)) (-2589 (((-121) $ $) NIL)) (-3337 (((-568) $) 65)) (-4490 (($) NIL T CONST)) (-2919 (((-3 $ "failed") (-1157 $) (-917) (-850)) NIL) (((-3 $ "failed") (-1157 $) (-917)) 49)) (-3668 (((-3 (-409 (-568)) "failed") $) NIL (|has| (-409 (-568)) (-1037 (-409 (-568))))) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 |#1| "failed") $) 108) (((-3 (-568) "failed") $) NIL (-2199 (|has| (-409 (-568)) (-1037 (-568))) (|has| |#1| (-1037 (-568)))))) (-2857 (((-409 (-568)) $) 14 (|has| (-409 (-568)) (-1037 (-409 (-568))))) (((-409 (-568)) $) 14) ((|#1| $) 109) (((-568) $) NIL (-2199 (|has| (-409 (-568)) (-1037 (-568))) (|has| |#1| (-1037 (-568)))))) (-2936 (($ $ (-850)) 40)) (-4187 (($ $ (-850)) 41)) (-2403 (($ $ $) NIL)) (-1783 (((-409 (-568)) $ $) 18)) (-2902 (((-3 $ "failed") $) 83)) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-1436 (((-121) $) 60)) (-1598 (((-121) $) NIL)) (-1550 (($ $ (-568)) NIL)) (-2859 (((-121) $) 63)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-3515 (((-3 (-1157 $) "failed") $) 78)) (-1771 (((-3 (-850) "failed") $) 77)) (-1424 (((-3 (-1157 $) "failed") $) 75)) (-3597 (((-3 (-1057 $ (-1157 $)) "failed") $) 73)) (-2498 (($ (-634 $)) NIL) (($ $ $) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) 84)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ (-634 $)) NIL) (($ $ $) NIL)) (-3850 (((-420 $) $) NIL)) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-2747 (((-850) $) 82) (($ (-568)) NIL) (($ (-409 (-568))) NIL) (($ $) 57) (($ (-409 (-568))) NIL) (($ (-568)) NIL) (($ (-409 (-568))) NIL) (($ |#1|) 111)) (-3425 (((-763)) NIL)) (-2273 (((-121) $ $) NIL)) (-3999 (((-409 (-568)) $ $) 24)) (-3059 (((-634 $) (-1157 $)) 55) (((-634 $) (-1157 (-409 (-568)))) NIL) (((-634 $) (-1157 (-568))) NIL) (((-634 $) (-953 $)) NIL) (((-634 $) (-953 (-409 (-568)))) NIL) (((-634 $) (-953 (-568))) NIL)) (-3501 (($ (-1057 $ (-1157 $)) (-850)) 39)) (-2811 (($ $) 19)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL)) (-3058 (($) 28 T CONST)) (-1557 (($) 34 T CONST)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 71)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 21)) (-1781 (($ $ $) 32)) (-1775 (($ $) 33) (($ $ $) 69)) (-1769 (($ $ $) 104)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL) (($ $ (-409 (-568))) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 92) (($ $ $) 97) (($ (-409 (-568)) $) NIL) (($ $ (-409 (-568))) NIL) (($ (-568) $) 92) (($ $ (-568)) NIL) (($ (-409 (-568)) $) NIL) (($ $ (-409 (-568))) NIL) (($ |#1| $) 96) (($ $ |#1|) NIL))) 
+(((-1023 |#1|) (-13 (-1012) (-413 |#1|) (-43 |#1|) (-10 -8 (-15 -3501 ($ (-1057 $ (-1157 $)) (-850))) (-15 -3597 ((-3 (-1057 $ (-1157 $)) "failed") $)) (-15 -1783 ((-409 (-568)) $ $)))) (-13 (-840) (-365) (-1021))) (T -1023)) 
+((-3501 (*1 *1 *2 *3) (-12 (-5 *2 (-1057 (-1023 *4) (-1157 (-1023 *4)))) (-5 *3 (-850)) (-5 *1 (-1023 *4)) (-4 *4 (-13 (-840) (-365) (-1021))))) (-3597 (*1 *2 *1) (|partial| -12 (-5 *2 (-1057 (-1023 *3) (-1157 (-1023 *3)))) (-5 *1 (-1023 *3)) (-4 *3 (-13 (-840) (-365) (-1021))))) (-1783 (*1 *2 *1 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-1023 *3)) (-4 *3 (-13 (-840) (-365) (-1021)))))) 
+(-13 (-1012) (-413 |#1|) (-43 |#1|) (-10 -8 (-15 -3501 ($ (-1057 $ (-1157 $)) (-850))) (-15 -3597 ((-3 (-1057 $ (-1157 $)) "failed") $)) (-15 -1783 ((-409 (-568)) $ $)))) 
+((-2582 (((-2 (|:| -2047 (-3 (-568) "failed")) (|:| -3894 (-3 (-568) "failed")) (|:| |ker| (-607 |#2|))) (-123) (-1161) |#2|) 59 (|has| |#1| (-1047)))) (-2108 (((-568) (-568) (-123) (-1161) |#2|) 76)) (-1401 (((-3 (-568) "failed") (-123) (-607 |#2|) (-1161)) 56 (|has| |#1| (-1047)))) (-3970 (((-123) |#2|) 103)) (-2716 ((|#2| |#2|) 102)) (-3100 ((|#2| (-123) (-1161) |#2| |#2| |#2| (-634 |#2|)) 72)) (-3601 ((|#2| (-123) (-1161) |#2| |#2| |#2| (-634 |#2|)) 100))) 
+(((-1024 |#1| |#2|) (-10 -7 (-15 -3100 (|#2| (-123) (-1161) |#2| |#2| |#2| (-634 |#2|))) (-15 -3601 (|#2| (-123) (-1161) |#2| |#2| |#2| (-634 |#2|))) (-15 -2716 (|#2| |#2|)) (-15 -3970 ((-123) |#2|)) (-15 -2108 ((-568) (-568) (-123) (-1161) |#2|)) (IF (|has| |#1| (-1047)) (PROGN (-15 -1401 ((-3 (-568) "failed") (-123) (-607 |#2|) (-1161))) (-15 -2582 ((-2 (|:| -2047 (-3 (-568) "failed")) (|:| -3894 (-3 (-568) "failed")) (|:| |ker| (-607 |#2|))) (-123) (-1161) |#2|))) |noBranch|)) (-13 (-842) (-558) (-609 (-541))) (-13 (-432 |#1|) (-23) (-1037 (-568)) (-1037 (-1161)) (-895 (-1161)) (-161))) (T -1024)) 
+((-2582 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-123)) (-5 *4 (-1161)) (-4 *6 (-1047)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-2 (|:| -2047 (-3 (-568) "failed")) (|:| -3894 (-3 (-568) "failed")) (|:| |ker| (-607 *5)))) (-5 *1 (-1024 *6 *5)) (-4 *5 (-13 (-432 *6) (-23) (-1037 (-568)) (-1037 *4) (-895 *4) (-161))))) (-1401 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-607 *7)) (-4 *7 (-13 (-432 *6) (-23) (-1037 *2) (-1037 *5) (-895 *5) (-161))) (-5 *5 (-1161)) (-4 *6 (-1047)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-568)) (-5 *1 (-1024 *6 *7)))) (-2108 (*1 *2 *2 *3 *4 *5) (-12 (-5 *3 (-123)) (-5 *2 (-568)) (-5 *4 (-1161)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *1 (-1024 *6 *5)) (-4 *5 (-13 (-432 *6) (-23) (-1037 *2) (-1037 *4) (-895 *4) (-161))))) (-3970 (*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-123)) (-5 *1 (-1024 *4 *3)) (-4 *3 (-13 (-432 *4) (-23) (-1037 (-568)) (-1037 (-1161)) (-895 (-1161)) (-161))))) (-2716 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558) (-609 (-541)))) (-5 *1 (-1024 *3 *2)) (-4 *2 (-13 (-432 *3) (-23) (-1037 (-568)) (-1037 (-1161)) (-895 (-1161)) (-161))))) (-3601 (*1 *2 *3 *4 *2 *2 *2 *5) (-12 (-5 *3 (-123)) (-5 *5 (-634 *2)) (-4 *2 (-13 (-432 *6) (-23) (-1037 (-568)) (-1037 *4) (-895 *4) (-161))) (-5 *4 (-1161)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *1 (-1024 *6 *2)))) (-3100 (*1 *2 *3 *4 *2 *2 *2 *5) (-12 (-5 *3 (-123)) (-5 *5 (-634 *2)) (-4 *2 (-13 (-432 *6) (-23) (-1037 (-568)) (-1037 *4) (-895 *4) (-161))) (-5 *4 (-1161)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *1 (-1024 *6 *2))))) 
+(-10 -7 (-15 -3100 (|#2| (-123) (-1161) |#2| |#2| |#2| (-634 |#2|))) (-15 -3601 (|#2| (-123) (-1161) |#2| |#2| |#2| (-634 |#2|))) (-15 -2716 (|#2| |#2|)) (-15 -3970 ((-123) |#2|)) (-15 -2108 ((-568) (-568) (-123) (-1161) |#2|)) (IF (|has| |#1| (-1047)) (PROGN (-15 -1401 ((-3 (-568) "failed") (-123) (-607 |#2|) (-1161))) (-15 -2582 ((-2 (|:| -2047 (-3 (-568) "failed")) (|:| -3894 (-3 (-568) "failed")) (|:| |ker| (-607 |#2|))) (-123) (-1161) |#2|))) |noBranch|)) 
+((-2293 (((-2 (|:| -2410 |#2|) (|:| -4194 (-634 |#1|))) |#2| (-634 |#1|)) 20) ((|#2| |#2| |#1|) 15))) 
+(((-1025 |#1| |#2|) (-10 -7 (-15 -2293 (|#2| |#2| |#1|)) (-15 -2293 ((-2 (|:| -2410 |#2|) (|:| -4194 (-634 |#1|))) |#2| (-634 |#1|)))) (-365) (-646 |#1|)) (T -1025)) 
+((-2293 (*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-5 *2 (-2 (|:| -2410 *3) (|:| -4194 (-634 *5)))) (-5 *1 (-1025 *5 *3)) (-5 *4 (-634 *5)) (-4 *3 (-646 *5)))) (-2293 (*1 *2 *2 *3) (-12 (-4 *3 (-365)) (-5 *1 (-1025 *3 *2)) (-4 *2 (-646 *3))))) 
+(-10 -7 (-15 -2293 (|#2| |#2| |#1|)) (-15 -2293 ((-2 (|:| -2410 |#2|) (|:| -4194 (-634 |#1|))) |#2| (-634 |#1|)))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3433 ((|#1| $ |#1|) 14)) (-2438 ((|#1| $ |#1|) 12)) (-2635 (($ |#1|) 10)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-2781 ((|#1| $) 11)) (-2878 ((|#1| $) 13)) (-2747 (((-850) $) 21 (|has| |#1| (-1090)))) (-1719 (((-121) $ $) 9))) 
+(((-1026 |#1|) (-13 (-1195) (-10 -8 (-15 -2635 ($ |#1|)) (-15 -2781 (|#1| $)) (-15 -2438 (|#1| $ |#1|)) (-15 -2878 (|#1| $)) (-15 -3433 (|#1| $ |#1|)) (-15 -1719 ((-121) $ $)) (IF (|has| |#1| (-1090)) (-6 (-1090)) |noBranch|))) (-1195)) (T -1026)) 
+((-2635 (*1 *1 *2) (-12 (-5 *1 (-1026 *2)) (-4 *2 (-1195)))) (-2781 (*1 *2 *1) (-12 (-5 *1 (-1026 *2)) (-4 *2 (-1195)))) (-2438 (*1 *2 *1 *2) (-12 (-5 *1 (-1026 *2)) (-4 *2 (-1195)))) (-2878 (*1 *2 *1) (-12 (-5 *1 (-1026 *2)) (-4 *2 (-1195)))) (-3433 (*1 *2 *1 *2) (-12 (-5 *1 (-1026 *2)) (-4 *2 (-1195)))) (-1719 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1026 *3)) (-4 *3 (-1195))))) 
+(-13 (-1195) (-10 -8 (-15 -2635 ($ |#1|)) (-15 -2781 (|#1| $)) (-15 -2438 (|#1| $ |#1|)) (-15 -2878 (|#1| $)) (-15 -3433 (|#1| $ |#1|)) (-15 -1719 ((-121) $ $)) (IF (|has| |#1| (-1090)) (-6 (-1090)) |noBranch|))) 
+((-2449 (((-121) $ $) NIL)) (-2213 (((-634 (-2 (|:| -4094 $) (|:| -2133 (-634 |#4|)))) (-634 |#4|)) NIL)) (-2353 (((-634 $) (-634 |#4|)) 104) (((-634 $) (-634 |#4|) (-121)) 105) (((-634 $) (-634 |#4|) (-121) (-121)) 103) (((-634 $) (-634 |#4|) (-121) (-121) (-121) (-121)) 106)) (-2057 (((-634 |#3|) $) NIL)) (-4141 (((-121) $) NIL)) (-1794 (((-121) $) NIL (|has| |#1| (-558)))) (-4231 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-3767 ((|#4| |#4| $) NIL)) (-3045 (((-634 (-2 (|:| |val| |#4|) (|:| -3145 $))) |#4| $) 98)) (-3647 (((-2 (|:| |under| $) (|:| -4115 $) (|:| |upper| $)) $ |#3|) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-2803 (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521))) (((-3 |#4| "failed") $ |#3|) 53)) (-4490 (($) NIL T CONST)) (-4382 (((-121) $) 26 (|has| |#1| (-558)))) (-1880 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2536 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2343 (((-121) $) NIL (|has| |#1| (-558)))) (-2941 (((-634 |#4|) (-634 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-3993 (((-634 |#4|) (-634 |#4|) $) NIL (|has| |#1| (-558)))) (-2727 (((-634 |#4|) (-634 |#4|) $) NIL (|has| |#1| (-558)))) (-3668 (((-3 $ "failed") (-634 |#4|)) NIL)) (-2857 (($ (-634 |#4|)) NIL)) (-3936 (((-3 $ "failed") $) 39)) (-3255 ((|#4| |#4| $) 56)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090))))) (-4330 (($ |#4| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090)))) (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-2607 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 72 (|has| |#1| (-558)))) (-1359 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) NIL)) (-3434 ((|#4| |#4| $) NIL)) (-3094 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) NIL (|has| $ (-6 -4521))) ((|#4| (-1 |#4| |#4| |#4|) $) NIL (|has| $ (-6 -4521))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-3158 (((-2 (|:| -4094 (-634 |#4|)) (|:| -2133 (-634 |#4|))) $) NIL)) (-2451 (((-121) |#4| $) NIL)) (-2978 (((-121) |#4| $) NIL)) (-1792 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-2123 (((-2 (|:| |val| (-634 |#4|)) (|:| |towers| (-634 $))) (-634 |#4|) (-121) (-121)) 118)) (-3317 (((-634 |#4|) $) 16 (|has| $ (-6 -4521)))) (-3764 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-4001 ((|#3| $) 33)) (-3791 (((-121) $ (-763)) NIL)) (-4406 (((-634 |#4|) $) 17 (|has| $ (-6 -4521)))) (-2551 (((-121) |#4| $) 25 (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090))))) (-2253 (($ (-1 |#4| |#4|) $) 23 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#4| |#4|) $) 21)) (-2249 (((-634 |#3|) $) NIL)) (-1495 (((-121) |#3| $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL)) (-1516 (((-3 |#4| (-634 $)) |#4| |#4| $) NIL)) (-3137 (((-634 (-2 (|:| |val| |#4|) (|:| -3145 $))) |#4| |#4| $) 96)) (-4164 (((-3 |#4| "failed") $) 37)) (-3878 (((-634 $) |#4| $) 79)) (-3712 (((-3 (-121) (-634 $)) |#4| $) NIL)) (-4266 (((-634 (-2 (|:| |val| (-121)) (|:| -3145 $))) |#4| $) 89) (((-121) |#4| $) 51)) (-1864 (((-634 $) |#4| $) 101) (((-634 $) (-634 |#4|) $) NIL) (((-634 $) (-634 |#4|) (-634 $)) 102) (((-634 $) |#4| (-634 $)) NIL)) (-3196 (((-634 $) (-634 |#4|) (-121) (-121) (-121)) 113)) (-3736 (($ |#4| $) 69) (($ (-634 |#4|) $) 70) (((-634 $) |#4| $ (-121) (-121) (-121) (-121) (-121)) 66)) (-3882 (((-634 |#4|) $) NIL)) (-2157 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-1315 ((|#4| |#4| $) NIL)) (-4342 (((-121) $ $) NIL)) (-1440 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-558)))) (-3236 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-1452 ((|#4| |#4| $) NIL)) (-4025 (((-1108) $) NIL)) (-3877 (((-3 |#4| "failed") $) 35)) (-2712 (((-3 |#4| "failed") (-1 (-121) |#4|) $) NIL)) (-3413 (((-3 $ "failed") $ |#4|) 47)) (-2168 (($ $ |#4|) NIL) (((-634 $) |#4| $) 81) (((-634 $) |#4| (-634 $)) NIL) (((-634 $) (-634 |#4|) $) NIL) (((-634 $) (-634 |#4|) (-634 $)) 76)) (-3951 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 |#4|) (-634 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 (-288 |#4|))) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) 15)) (-1990 (($) 13)) (-1836 (((-763) $) NIL)) (-4170 (((-763) |#4| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090)))) (((-763) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-3865 (($ $) 12)) (-4280 (((-541) $) NIL (|has| |#4| (-609 (-541))))) (-4289 (($ (-634 |#4|)) 20)) (-3206 (($ $ |#3|) 42)) (-2527 (($ $ |#3|) 43)) (-4392 (($ $) NIL)) (-4332 (($ $ |#3|) NIL)) (-2747 (((-850) $) 31) (((-634 |#4|) $) 40)) (-2524 (((-763) $) NIL (|has| |#3| (-370)))) (-2835 (((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4| |#4|)) NIL) (((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-2145 (((-121) $ (-1 (-121) |#4| (-634 |#4|))) NIL)) (-1977 (((-634 $) |#4| $) 78) (((-634 $) |#4| (-634 $)) NIL) (((-634 $) (-634 |#4|) $) NIL) (((-634 $) (-634 |#4|) (-634 $)) NIL)) (-3437 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-3321 (((-634 |#3|) $) NIL)) (-3541 (((-121) |#4| $) NIL)) (-1413 (((-121) |#3| $) 52)) (-1719 (((-121) $ $) NIL)) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-1027 |#1| |#2| |#3| |#4|) (-13 (-1066 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3736 ((-634 $) |#4| $ (-121) (-121) (-121) (-121) (-121))) (-15 -2353 ((-634 $) (-634 |#4|) (-121) (-121))) (-15 -2353 ((-634 $) (-634 |#4|) (-121) (-121) (-121) (-121))) (-15 -3196 ((-634 $) (-634 |#4|) (-121) (-121) (-121))) (-15 -2123 ((-2 (|:| |val| (-634 |#4|)) (|:| |towers| (-634 $))) (-634 |#4|) (-121) (-121))))) (-453) (-788) (-842) (-1061 |#1| |#2| |#3|)) (T -1027)) 
+((-3736 (*1 *2 *3 *1 *4 *4 *4 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1027 *5 *6 *7 *3))) (-5 *1 (-1027 *5 *6 *7 *3)) (-4 *3 (-1061 *5 *6 *7)))) (-2353 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1027 *5 *6 *7 *8))) (-5 *1 (-1027 *5 *6 *7 *8)))) (-2353 (*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1027 *5 *6 *7 *8))) (-5 *1 (-1027 *5 *6 *7 *8)))) (-3196 (*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1027 *5 *6 *7 *8))) (-5 *1 (-1027 *5 *6 *7 *8)))) (-2123 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |val| (-634 *8)) (|:| |towers| (-634 (-1027 *5 *6 *7 *8))))) (-5 *1 (-1027 *5 *6 *7 *8)) (-5 *3 (-634 *8))))) 
+(-13 (-1066 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3736 ((-634 $) |#4| $ (-121) (-121) (-121) (-121) (-121))) (-15 -2353 ((-634 $) (-634 |#4|) (-121) (-121))) (-15 -2353 ((-634 $) (-634 |#4|) (-121) (-121) (-121) (-121))) (-15 -3196 ((-634 $) (-634 |#4|) (-121) (-121) (-121))) (-15 -2123 ((-2 (|:| |val| (-634 |#4|)) (|:| |towers| (-634 $))) (-634 |#4|) (-121) (-121))))) 
+((-1746 (((-634 (-679 |#1|)) (-634 (-679 |#1|))) 56) (((-679 |#1|) (-679 |#1|)) 55) (((-634 (-679 |#1|)) (-634 (-679 |#1|)) (-634 (-679 |#1|))) 54) (((-679 |#1|) (-679 |#1|) (-679 |#1|)) 51)) (-4019 (((-634 (-679 |#1|)) (-634 (-679 |#1|)) (-917)) 50) (((-679 |#1|) (-679 |#1|) (-917)) 49)) (-2638 (((-634 (-679 (-568))) (-634 (-634 (-568)))) 66) (((-634 (-679 (-568))) (-634 (-900 (-568))) (-568)) 65) (((-679 (-568)) (-634 (-568))) 62) (((-679 (-568)) (-900 (-568)) (-568)) 61)) (-4337 (((-679 (-953 |#1|)) (-763)) 79)) (-2544 (((-634 (-679 |#1|)) (-634 (-679 |#1|)) (-917)) 36 (|has| |#1| (-6 (-4523 "*")))) (((-679 |#1|) (-679 |#1|) (-917)) 34 (|has| |#1| (-6 (-4523 "*")))))) 
+(((-1028 |#1|) (-10 -7 (IF (|has| |#1| (-6 (-4523 "*"))) (-15 -2544 ((-679 |#1|) (-679 |#1|) (-917))) |noBranch|) (IF (|has| |#1| (-6 (-4523 "*"))) (-15 -2544 ((-634 (-679 |#1|)) (-634 (-679 |#1|)) (-917))) |noBranch|) (-15 -4337 ((-679 (-953 |#1|)) (-763))) (-15 -4019 ((-679 |#1|) (-679 |#1|) (-917))) (-15 -4019 ((-634 (-679 |#1|)) (-634 (-679 |#1|)) (-917))) (-15 -1746 ((-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -1746 ((-634 (-679 |#1|)) (-634 (-679 |#1|)) (-634 (-679 |#1|)))) (-15 -1746 ((-679 |#1|) (-679 |#1|))) (-15 -1746 ((-634 (-679 |#1|)) (-634 (-679 |#1|)))) (-15 -2638 ((-679 (-568)) (-900 (-568)) (-568))) (-15 -2638 ((-679 (-568)) (-634 (-568)))) (-15 -2638 ((-634 (-679 (-568))) (-634 (-900 (-568))) (-568))) (-15 -2638 ((-634 (-679 (-568))) (-634 (-634 (-568)))))) (-1047)) (T -1028)) 
+((-2638 (*1 *2 *3) (-12 (-5 *3 (-634 (-634 (-568)))) (-5 *2 (-634 (-679 (-568)))) (-5 *1 (-1028 *4)) (-4 *4 (-1047)))) (-2638 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-900 (-568)))) (-5 *4 (-568)) (-5 *2 (-634 (-679 *4))) (-5 *1 (-1028 *5)) (-4 *5 (-1047)))) (-2638 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-679 (-568))) (-5 *1 (-1028 *4)) (-4 *4 (-1047)))) (-2638 (*1 *2 *3 *4) (-12 (-5 *3 (-900 (-568))) (-5 *4 (-568)) (-5 *2 (-679 *4)) (-5 *1 (-1028 *5)) (-4 *5 (-1047)))) (-1746 (*1 *2 *2) (-12 (-5 *2 (-634 (-679 *3))) (-4 *3 (-1047)) (-5 *1 (-1028 *3)))) (-1746 (*1 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-1028 *3)))) (-1746 (*1 *2 *2 *2) (-12 (-5 *2 (-634 (-679 *3))) (-4 *3 (-1047)) (-5 *1 (-1028 *3)))) (-1746 (*1 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-1028 *3)))) (-4019 (*1 *2 *2 *3) (-12 (-5 *2 (-634 (-679 *4))) (-5 *3 (-917)) (-4 *4 (-1047)) (-5 *1 (-1028 *4)))) (-4019 (*1 *2 *2 *3) (-12 (-5 *2 (-679 *4)) (-5 *3 (-917)) (-4 *4 (-1047)) (-5 *1 (-1028 *4)))) (-4337 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-679 (-953 *4))) (-5 *1 (-1028 *4)) (-4 *4 (-1047)))) (-2544 (*1 *2 *2 *3) (-12 (-5 *2 (-634 (-679 *4))) (-5 *3 (-917)) (|has| *4 (-6 (-4523 "*"))) (-4 *4 (-1047)) (-5 *1 (-1028 *4)))) (-2544 (*1 *2 *2 *3) (-12 (-5 *2 (-679 *4)) (-5 *3 (-917)) (|has| *4 (-6 (-4523 "*"))) (-4 *4 (-1047)) (-5 *1 (-1028 *4))))) 
+(-10 -7 (IF (|has| |#1| (-6 (-4523 "*"))) (-15 -2544 ((-679 |#1|) (-679 |#1|) (-917))) |noBranch|) (IF (|has| |#1| (-6 (-4523 "*"))) (-15 -2544 ((-634 (-679 |#1|)) (-634 (-679 |#1|)) (-917))) |noBranch|) (-15 -4337 ((-679 (-953 |#1|)) (-763))) (-15 -4019 ((-679 |#1|) (-679 |#1|) (-917))) (-15 -4019 ((-634 (-679 |#1|)) (-634 (-679 |#1|)) (-917))) (-15 -1746 ((-679 |#1|) (-679 |#1|) (-679 |#1|))) (-15 -1746 ((-634 (-679 |#1|)) (-634 (-679 |#1|)) (-634 (-679 |#1|)))) (-15 -1746 ((-679 |#1|) (-679 |#1|))) (-15 -1746 ((-634 (-679 |#1|)) (-634 (-679 |#1|)))) (-15 -2638 ((-679 (-568)) (-900 (-568)) (-568))) (-15 -2638 ((-679 (-568)) (-634 (-568)))) (-15 -2638 ((-634 (-679 (-568))) (-634 (-900 (-568))) (-568))) (-15 -2638 ((-634 (-679 (-568))) (-634 (-634 (-568)))))) 
+((-1293 (((-679 |#1|) (-634 (-679 |#1|)) (-1244 |#1|)) 48 (|has| |#1| (-301)))) (-4446 (((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-1244 (-1244 |#1|))) 71 (|has| |#1| (-365))) (((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-1244 |#1|)) 69 (|has| |#1| (-365)))) (-3872 (((-1244 |#1|) (-634 (-1244 |#1|)) (-568)) 73 (-12 (|has| |#1| (-365)) (|has| |#1| (-370))))) (-2107 (((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-917)) 78 (-12 (|has| |#1| (-365)) (|has| |#1| (-370)))) (((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-121)) 76 (-12 (|has| |#1| (-365)) (|has| |#1| (-370)))) (((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|))) 75 (-12 (|has| |#1| (-365)) (|has| |#1| (-370)))) (((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-121) (-568) (-568)) 74 (-12 (|has| |#1| (-365)) (|has| |#1| (-370))))) (-2255 (((-121) (-634 (-679 |#1|))) 67 (|has| |#1| (-365))) (((-121) (-634 (-679 |#1|)) (-568)) 66 (|has| |#1| (-365)))) (-3683 (((-1244 (-1244 |#1|)) (-634 (-679 |#1|)) (-1244 |#1|)) 46 (|has| |#1| (-301)))) (-3976 (((-679 |#1|) (-634 (-679 |#1|)) (-679 |#1|)) 32)) (-3422 (((-679 |#1|) (-1244 (-1244 |#1|))) 29)) (-1279 (((-679 |#1|) (-634 (-679 |#1|)) (-634 (-679 |#1|)) (-568)) 62 (|has| |#1| (-365))) (((-679 |#1|) (-634 (-679 |#1|)) (-634 (-679 |#1|))) 61 (|has| |#1| (-365))) (((-679 |#1|) (-634 (-679 |#1|)) (-634 (-679 |#1|)) (-121) (-568)) 60 (|has| |#1| (-365))))) 
+(((-1029 |#1|) (-10 -7 (-15 -3422 ((-679 |#1|) (-1244 (-1244 |#1|)))) (-15 -3976 ((-679 |#1|) (-634 (-679 |#1|)) (-679 |#1|))) (IF (|has| |#1| (-301)) (PROGN (-15 -3683 ((-1244 (-1244 |#1|)) (-634 (-679 |#1|)) (-1244 |#1|))) (-15 -1293 ((-679 |#1|) (-634 (-679 |#1|)) (-1244 |#1|)))) |noBranch|) (IF (|has| |#1| (-365)) (PROGN (-15 -1279 ((-679 |#1|) (-634 (-679 |#1|)) (-634 (-679 |#1|)) (-121) (-568))) (-15 -1279 ((-679 |#1|) (-634 (-679 |#1|)) (-634 (-679 |#1|)))) (-15 -1279 ((-679 |#1|) (-634 (-679 |#1|)) (-634 (-679 |#1|)) (-568))) (-15 -2255 ((-121) (-634 (-679 |#1|)) (-568))) (-15 -2255 ((-121) (-634 (-679 |#1|)))) (-15 -4446 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-1244 |#1|))) (-15 -4446 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-1244 (-1244 |#1|))))) |noBranch|) (IF (|has| |#1| (-370)) (IF (|has| |#1| (-365)) (PROGN (-15 -2107 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-121) (-568) (-568))) (-15 -2107 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)))) (-15 -2107 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-121))) (-15 -2107 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-917))) (-15 -3872 ((-1244 |#1|) (-634 (-1244 |#1|)) (-568)))) |noBranch|) |noBranch|)) (-1047)) (T -1029)) 
+((-3872 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1244 *5))) (-5 *4 (-568)) (-5 *2 (-1244 *5)) (-5 *1 (-1029 *5)) (-4 *5 (-365)) (-4 *5 (-370)) (-4 *5 (-1047)))) (-2107 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-365)) (-4 *5 (-370)) (-4 *5 (-1047)) (-5 *2 (-634 (-634 (-679 *5)))) (-5 *1 (-1029 *5)) (-5 *3 (-634 (-679 *5))))) (-2107 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-365)) (-4 *5 (-370)) (-4 *5 (-1047)) (-5 *2 (-634 (-634 (-679 *5)))) (-5 *1 (-1029 *5)) (-5 *3 (-634 (-679 *5))))) (-2107 (*1 *2 *3) (-12 (-4 *4 (-365)) (-4 *4 (-370)) (-4 *4 (-1047)) (-5 *2 (-634 (-634 (-679 *4)))) (-5 *1 (-1029 *4)) (-5 *3 (-634 (-679 *4))))) (-2107 (*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-121)) (-5 *5 (-568)) (-4 *6 (-365)) (-4 *6 (-370)) (-4 *6 (-1047)) (-5 *2 (-634 (-634 (-679 *6)))) (-5 *1 (-1029 *6)) (-5 *3 (-634 (-679 *6))))) (-4446 (*1 *2 *3 *4) (-12 (-5 *4 (-1244 (-1244 *5))) (-4 *5 (-365)) (-4 *5 (-1047)) (-5 *2 (-634 (-634 (-679 *5)))) (-5 *1 (-1029 *5)) (-5 *3 (-634 (-679 *5))))) (-4446 (*1 *2 *3 *4) (-12 (-5 *4 (-1244 *5)) (-4 *5 (-365)) (-4 *5 (-1047)) (-5 *2 (-634 (-634 (-679 *5)))) (-5 *1 (-1029 *5)) (-5 *3 (-634 (-679 *5))))) (-2255 (*1 *2 *3) (-12 (-5 *3 (-634 (-679 *4))) (-4 *4 (-365)) (-4 *4 (-1047)) (-5 *2 (-121)) (-5 *1 (-1029 *4)))) (-2255 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-679 *5))) (-5 *4 (-568)) (-4 *5 (-365)) (-4 *5 (-1047)) (-5 *2 (-121)) (-5 *1 (-1029 *5)))) (-1279 (*1 *2 *3 *3 *4) (-12 (-5 *3 (-634 (-679 *5))) (-5 *4 (-568)) (-5 *2 (-679 *5)) (-5 *1 (-1029 *5)) (-4 *5 (-365)) (-4 *5 (-1047)))) (-1279 (*1 *2 *3 *3) (-12 (-5 *3 (-634 (-679 *4))) (-5 *2 (-679 *4)) (-5 *1 (-1029 *4)) (-4 *4 (-365)) (-4 *4 (-1047)))) (-1279 (*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-634 (-679 *6))) (-5 *4 (-121)) (-5 *5 (-568)) (-5 *2 (-679 *6)) (-5 *1 (-1029 *6)) (-4 *6 (-365)) (-4 *6 (-1047)))) (-1293 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-679 *5))) (-5 *4 (-1244 *5)) (-4 *5 (-301)) (-4 *5 (-1047)) (-5 *2 (-679 *5)) (-5 *1 (-1029 *5)))) (-3683 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-679 *5))) (-4 *5 (-301)) (-4 *5 (-1047)) (-5 *2 (-1244 (-1244 *5))) (-5 *1 (-1029 *5)) (-5 *4 (-1244 *5)))) (-3976 (*1 *2 *3 *2) (-12 (-5 *3 (-634 (-679 *4))) (-5 *2 (-679 *4)) (-4 *4 (-1047)) (-5 *1 (-1029 *4)))) (-3422 (*1 *2 *3) (-12 (-5 *3 (-1244 (-1244 *4))) (-4 *4 (-1047)) (-5 *2 (-679 *4)) (-5 *1 (-1029 *4))))) 
+(-10 -7 (-15 -3422 ((-679 |#1|) (-1244 (-1244 |#1|)))) (-15 -3976 ((-679 |#1|) (-634 (-679 |#1|)) (-679 |#1|))) (IF (|has| |#1| (-301)) (PROGN (-15 -3683 ((-1244 (-1244 |#1|)) (-634 (-679 |#1|)) (-1244 |#1|))) (-15 -1293 ((-679 |#1|) (-634 (-679 |#1|)) (-1244 |#1|)))) |noBranch|) (IF (|has| |#1| (-365)) (PROGN (-15 -1279 ((-679 |#1|) (-634 (-679 |#1|)) (-634 (-679 |#1|)) (-121) (-568))) (-15 -1279 ((-679 |#1|) (-634 (-679 |#1|)) (-634 (-679 |#1|)))) (-15 -1279 ((-679 |#1|) (-634 (-679 |#1|)) (-634 (-679 |#1|)) (-568))) (-15 -2255 ((-121) (-634 (-679 |#1|)) (-568))) (-15 -2255 ((-121) (-634 (-679 |#1|)))) (-15 -4446 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-1244 |#1|))) (-15 -4446 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-1244 (-1244 |#1|))))) |noBranch|) (IF (|has| |#1| (-370)) (IF (|has| |#1| (-365)) (PROGN (-15 -2107 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-121) (-568) (-568))) (-15 -2107 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)))) (-15 -2107 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-121))) (-15 -2107 ((-634 (-634 (-679 |#1|))) (-634 (-679 |#1|)) (-917))) (-15 -3872 ((-1244 |#1|) (-634 (-1244 |#1|)) (-568)))) |noBranch|) |noBranch|)) 
+((-3065 ((|#1| (-917) |#1|) 9))) 
+(((-1030 |#1|) (-10 -7 (-15 -3065 (|#1| (-917) |#1|))) (-13 (-1090) (-10 -8 (-15 -1769 ($ $ $))))) (T -1030)) 
+((-3065 (*1 *2 *3 *2) (-12 (-5 *3 (-917)) (-5 *1 (-1030 *2)) (-4 *2 (-13 (-1090) (-10 -8 (-15 -1769 ($ $ $)))))))) 
+(-10 -7 (-15 -3065 (|#1| (-917) |#1|))) 
+((-3371 (((-634 (-2 (|:| |radval| (-310 (-568))) (|:| |radmult| (-568)) (|:| |radvect| (-634 (-679 (-310 (-568))))))) (-679 (-409 (-953 (-568))))) 58)) (-4360 (((-634 (-679 (-310 (-568)))) (-310 (-568)) (-679 (-409 (-953 (-568))))) 48)) (-1799 (((-634 (-310 (-568))) (-679 (-409 (-953 (-568))))) 41)) (-1821 (((-634 (-679 (-310 (-568)))) (-679 (-409 (-953 (-568))))) 67)) (-1696 (((-679 (-310 (-568))) (-679 (-310 (-568)))) 33)) (-3439 (((-634 (-679 (-310 (-568)))) (-634 (-679 (-310 (-568))))) 61)) (-2866 (((-3 (-679 (-310 (-568))) "failed") (-679 (-409 (-953 (-568))))) 65))) 
+(((-1031) (-10 -7 (-15 -3371 ((-634 (-2 (|:| |radval| (-310 (-568))) (|:| |radmult| (-568)) (|:| |radvect| (-634 (-679 (-310 (-568))))))) (-679 (-409 (-953 (-568)))))) (-15 -4360 ((-634 (-679 (-310 (-568)))) (-310 (-568)) (-679 (-409 (-953 (-568)))))) (-15 -1799 ((-634 (-310 (-568))) (-679 (-409 (-953 (-568)))))) (-15 -2866 ((-3 (-679 (-310 (-568))) "failed") (-679 (-409 (-953 (-568)))))) (-15 -1696 ((-679 (-310 (-568))) (-679 (-310 (-568))))) (-15 -3439 ((-634 (-679 (-310 (-568)))) (-634 (-679 (-310 (-568)))))) (-15 -1821 ((-634 (-679 (-310 (-568)))) (-679 (-409 (-953 (-568)))))))) (T -1031)) 
+((-1821 (*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-953 (-568))))) (-5 *2 (-634 (-679 (-310 (-568))))) (-5 *1 (-1031)))) (-3439 (*1 *2 *2) (-12 (-5 *2 (-634 (-679 (-310 (-568))))) (-5 *1 (-1031)))) (-1696 (*1 *2 *2) (-12 (-5 *2 (-679 (-310 (-568)))) (-5 *1 (-1031)))) (-2866 (*1 *2 *3) (|partial| -12 (-5 *3 (-679 (-409 (-953 (-568))))) (-5 *2 (-679 (-310 (-568)))) (-5 *1 (-1031)))) (-1799 (*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-953 (-568))))) (-5 *2 (-634 (-310 (-568)))) (-5 *1 (-1031)))) (-4360 (*1 *2 *3 *4) (-12 (-5 *4 (-679 (-409 (-953 (-568))))) (-5 *2 (-634 (-679 (-310 (-568))))) (-5 *1 (-1031)) (-5 *3 (-310 (-568))))) (-3371 (*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| |radval| (-310 (-568))) (|:| |radmult| (-568)) (|:| |radvect| (-634 (-679 (-310 (-568)))))))) (-5 *1 (-1031))))) 
+(-10 -7 (-15 -3371 ((-634 (-2 (|:| |radval| (-310 (-568))) (|:| |radmult| (-568)) (|:| |radvect| (-634 (-679 (-310 (-568))))))) (-679 (-409 (-953 (-568)))))) (-15 -4360 ((-634 (-679 (-310 (-568)))) (-310 (-568)) (-679 (-409 (-953 (-568)))))) (-15 -1799 ((-634 (-310 (-568))) (-679 (-409 (-953 (-568)))))) (-15 -2866 ((-3 (-679 (-310 (-568))) "failed") (-679 (-409 (-953 (-568)))))) (-15 -1696 ((-679 (-310 (-568))) (-679 (-310 (-568))))) (-15 -3439 ((-634 (-679 (-310 (-568)))) (-634 (-679 (-310 (-568)))))) (-15 -1821 ((-634 (-679 (-310 (-568)))) (-679 (-409 (-953 (-568))))))) 
+((-2514 ((|#1| |#1| (-917)) 9))) 
+(((-1032 |#1|) (-10 -7 (-15 -2514 (|#1| |#1| (-917)))) (-13 (-1090) (-10 -8 (-15 * ($ $ $))))) (T -1032)) 
+((-2514 (*1 *2 *2 *3) (-12 (-5 *3 (-917)) (-5 *1 (-1032 *2)) (-4 *2 (-13 (-1090) (-10 -8 (-15 * ($ $ $)))))))) 
+(-10 -7 (-15 -2514 (|#1| |#1| (-917)))) 
+((-2747 ((|#1| (-305)) 11) (((-1249) |#1|) 9))) 
+(((-1033 |#1|) (-10 -7 (-15 -2747 ((-1249) |#1|)) (-15 -2747 (|#1| (-305)))) (-1195)) (T -1033)) 
+((-2747 (*1 *2 *3) (-12 (-5 *3 (-305)) (-5 *1 (-1033 *2)) (-4 *2 (-1195)))) (-2747 (*1 *2 *3) (-12 (-5 *2 (-1249)) (-5 *1 (-1033 *3)) (-4 *3 (-1195))))) 
+(-10 -7 (-15 -2747 ((-1249) |#1|)) (-15 -2747 (|#1| (-305)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-3094 (($ |#4|) 25)) (-2902 (((-3 $ "failed") $) NIL)) (-1598 (((-121) $) NIL)) (-3087 ((|#4| $) 27)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 46) (($ (-568)) NIL) (($ |#1|) NIL) (($ |#4|) 26)) (-3425 (((-763)) 43)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 21 T CONST)) (-1557 (($) 23 T CONST)) (-1719 (((-121) $ $) 40)) (-1775 (($ $) 31) (($ $ $) NIL)) (-1769 (($ $ $) 29)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 36) (($ $ $) 33) (($ |#1| $) 38) (($ $ |#1|) NIL))) 
+(((-1034 |#1| |#2| |#3| |#4| |#5|) (-13 (-172) (-43 |#1|) (-10 -8 (-15 -3094 ($ |#4|)) (-15 -2747 ($ |#4|)) (-15 -3087 (|#4| $)))) (-365) (-788) (-842) (-950 |#1| |#2| |#3|) (-634 |#4|)) (T -1034)) 
+((-3094 (*1 *1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-1034 *3 *4 *5 *2 *6)) (-4 *2 (-950 *3 *4 *5)) (-14 *6 (-634 *2)))) (-2747 (*1 *1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-1034 *3 *4 *5 *2 *6)) (-4 *2 (-950 *3 *4 *5)) (-14 *6 (-634 *2)))) (-3087 (*1 *2 *1) (-12 (-4 *2 (-950 *3 *4 *5)) (-5 *1 (-1034 *3 *4 *5 *2 *6)) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-14 *6 (-634 *2))))) 
+(-13 (-172) (-43 |#1|) (-10 -8 (-15 -3094 ($ |#4|)) (-15 -2747 ($ |#4|)) (-15 -3087 (|#4| $)))) 
+((-2449 (((-121) $ $) NIL (-2199 (|has| (-57) (-1090)) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090))))) (-2988 (($) NIL) (($ (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))))) NIL)) (-2481 (((-1249) $ (-1161) (-1161)) NIL (|has| $ (-6 -4522)))) (-1667 (((-121) $ (-763)) NIL)) (-3302 (((-121) (-121)) 39)) (-1870 (((-121) (-121)) 38)) (-2438 (((-57) $ (-1161) (-57)) NIL)) (-3963 (($ (-1 (-121) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521)))) (-2678 (((-3 (-57) "failed") (-1161) $) NIL)) (-4490 (($) NIL T CONST)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090))))) (-1568 (($ (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) $) NIL (|has| $ (-6 -4521))) (($ (-1 (-121) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521))) (((-3 (-57) "failed") (-1161) $) NIL)) (-4330 (($ (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090)))) (($ (-1 (-121) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521)))) (-3094 (((-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $ (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090)))) (((-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $ (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) NIL (|has| $ (-6 -4521))) (((-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521)))) (-1292 (((-57) $ (-1161) (-57)) NIL (|has| $ (-6 -4522)))) (-2069 (((-57) $ (-1161)) NIL)) (-3317 (((-634 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521))) (((-634 (-57)) $) NIL (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-1161) $) NIL (|has| (-1161) (-842)))) (-4406 (((-634 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521))) (((-634 (-57)) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090)))) (((-121) (-57) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-57) (-1090))))) (-3631 (((-1161) $) NIL (|has| (-1161) (-842)))) (-2253 (($ (-1 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4522))) (($ (-1 (-57) (-57)) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL) (($ (-1 (-57) (-57)) $) NIL) (($ (-1 (-57) (-57) (-57)) $ $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (-2199 (|has| (-57) (-1090)) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090))))) (-4253 (((-634 (-1161)) $) 34)) (-2807 (((-121) (-1161) $) NIL)) (-2580 (((-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) $) NIL)) (-1708 (($ (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) $) NIL)) (-3948 (((-634 (-1161)) $) NIL)) (-2916 (((-121) (-1161) $) NIL)) (-4025 (((-1108) $) NIL (-2199 (|has| (-57) (-1090)) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090))))) (-3877 (((-57) $) NIL (|has| (-1161) (-842)))) (-2712 (((-3 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) "failed") (-1 (-121) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL)) (-2490 (($ $ (-57)) NIL (|has| $ (-6 -4522)))) (-3403 (((-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) $) NIL)) (-3951 (((-121) (-1 (-121) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))))) NIL (-12 (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-303 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))))) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090)))) (($ $ (-288 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))))) NIL (-12 (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-303 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))))) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090)))) (($ $ (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) NIL (-12 (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-303 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))))) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090)))) (($ $ (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))))) NIL (-12 (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-303 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))))) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090)))) (($ $ (-634 (-57)) (-634 (-57))) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090)))) (($ $ (-57) (-57)) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090)))) (($ $ (-288 (-57))) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090)))) (($ $ (-634 (-288 (-57)))) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) (-57) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-57) (-1090))))) (-1480 (((-634 (-57)) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 (((-57) $ (-1161)) 35) (((-57) $ (-1161) (-57)) NIL)) (-3132 (($) NIL) (($ (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))))) NIL)) (-4170 (((-763) (-1 (-121) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521))) (((-763) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090)))) (((-763) (-57) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-57) (-1090)))) (((-763) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4521)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-609 (-541))))) (-4289 (($ (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))))) NIL)) (-2747 (((-850) $) 37 (-2199 (|has| (-57) (-1090)) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090))))) (-4074 (($ (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))))) NIL)) (-3437 (((-121) (-1 (-121) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) NIL (-2199 (|has| (-57) (-1090)) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090))))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-1035) (-13 (-1172 (-1161) (-57)) (-10 -7 (-15 -3302 ((-121) (-121))) (-15 -1870 ((-121) (-121))) (-6 -4521)))) (T -1035)) 
+((-3302 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1035)))) (-1870 (*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1035))))) 
+(-13 (-1172 (-1161) (-57)) (-10 -7 (-15 -3302 ((-121) (-121))) (-15 -1870 ((-121) (-121))) (-6 -4521))) 
+((-2857 ((|#2| $) 10))) 
+(((-1036 |#1| |#2|) (-10 -8 (-15 -2857 (|#2| |#1|))) (-1037 |#2|) (-1195)) (T -1036)) 
+NIL 
+(-10 -8 (-15 -2857 (|#2| |#1|))) 
+((-3668 (((-3 |#1| "failed") $) 7)) (-2857 ((|#1| $) 8)) (-2747 (($ |#1|) 6))) 
 (((-1037 |#1|) (-1275) (-1195)) (T -1037)) 
-((-2854 (*1 *2 *1) (-12 (-4 *1 (-1037 *2)) (-4 *2 (-1195)))) (-3666 (*1 *2 *1) (|partial| -12 (-4 *1 (-1037 *2)) (-4 *2 (-1195)))) (-2745 (*1 *1 *2) (-12 (-4 *1 (-1037 *2)) (-4 *2 (-1195))))) 
-(-13 (-10 -8 (-15 -2745 ($ |t#1|)) (-15 -3666 ((-3 |t#1| "failed") $)) (-15 -2854 (|t#1| $)))) 
-((-4451 (((-634 (-634 (-288 (-409 (-953 |#2|))))) (-634 (-953 |#2|)) (-634 (-1161))) 35))) 
-(((-1038 |#1| |#2|) (-10 -7 (-15 -4451 ((-634 (-634 (-288 (-409 (-953 |#2|))))) (-634 (-953 |#2|)) (-634 (-1161))))) (-558) (-13 (-558) (-1037 |#1|))) (T -1038)) 
-((-4451 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *6))) (-5 *4 (-634 (-1161))) (-4 *6 (-13 (-558) (-1037 *5))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *6)))))) (-5 *1 (-1038 *5 *6))))) 
-(-10 -7 (-15 -4451 ((-634 (-634 (-288 (-409 (-953 |#2|))))) (-634 (-953 |#2|)) (-634 (-1161))))) 
-((-4024 (((-381)) 15)) (-3703 (((-1 (-381)) (-381) (-381)) 20)) (-3492 (((-1 (-381)) (-763)) 42)) (-3681 (((-381)) 33)) (-2242 (((-1 (-381)) (-381) (-381)) 34)) (-3234 (((-381)) 26)) (-4327 (((-1 (-381)) (-381)) 27)) (-2444 (((-381) (-763)) 37)) (-2692 (((-1 (-381)) (-763)) 38)) (-1478 (((-1 (-381)) (-763) (-763)) 41)) (-3792 (((-1 (-381)) (-763) (-763)) 39))) 
-(((-1039) (-10 -7 (-15 -4024 ((-381))) (-15 -3681 ((-381))) (-15 -3234 ((-381))) (-15 -2444 ((-381) (-763))) (-15 -3703 ((-1 (-381)) (-381) (-381))) (-15 -2242 ((-1 (-381)) (-381) (-381))) (-15 -4327 ((-1 (-381)) (-381))) (-15 -2692 ((-1 (-381)) (-763))) (-15 -3792 ((-1 (-381)) (-763) (-763))) (-15 -1478 ((-1 (-381)) (-763) (-763))) (-15 -3492 ((-1 (-381)) (-763))))) (T -1039)) 
-((-3492 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-381))) (-5 *1 (-1039)))) (-1478 (*1 *2 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-381))) (-5 *1 (-1039)))) (-3792 (*1 *2 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-381))) (-5 *1 (-1039)))) (-2692 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-381))) (-5 *1 (-1039)))) (-4327 (*1 *2 *3) (-12 (-5 *2 (-1 (-381))) (-5 *1 (-1039)) (-5 *3 (-381)))) (-2242 (*1 *2 *3 *3) (-12 (-5 *2 (-1 (-381))) (-5 *1 (-1039)) (-5 *3 (-381)))) (-3703 (*1 *2 *3 *3) (-12 (-5 *2 (-1 (-381))) (-5 *1 (-1039)) (-5 *3 (-381)))) (-2444 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-381)) (-5 *1 (-1039)))) (-3234 (*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1039)))) (-3681 (*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1039)))) (-4024 (*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1039))))) 
-(-10 -7 (-15 -4024 ((-381))) (-15 -3681 ((-381))) (-15 -3234 ((-381))) (-15 -2444 ((-381) (-763))) (-15 -3703 ((-1 (-381)) (-381) (-381))) (-15 -2242 ((-1 (-381)) (-381) (-381))) (-15 -4327 ((-1 (-381)) (-381))) (-15 -2692 ((-1 (-381)) (-763))) (-15 -3792 ((-1 (-381)) (-763) (-763))) (-15 -1478 ((-1 (-381)) (-763) (-763))) (-15 -3492 ((-1 (-381)) (-763)))) 
-((-3848 (((-420 |#1|) |#1|) 31))) 
-(((-1040 |#1|) (-10 -7 (-15 -3848 ((-420 |#1|) |#1|))) (-1219 (-409 (-953 (-568))))) (T -1040)) 
-((-3848 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-1040 *3)) (-4 *3 (-1219 (-409 (-953 (-568)))))))) 
-(-10 -7 (-15 -3848 ((-420 |#1|) |#1|))) 
-((-4269 (((-409 (-420 (-953 |#1|))) (-409 (-953 |#1|))) 14))) 
-(((-1041 |#1|) (-10 -7 (-15 -4269 ((-409 (-420 (-953 |#1|))) (-409 (-953 |#1|))))) (-301)) (T -1041)) 
-((-4269 (*1 *2 *3) (-12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-301)) (-5 *2 (-409 (-420 (-953 *4)))) (-5 *1 (-1041 *4))))) 
-(-10 -7 (-15 -4269 ((-409 (-420 (-953 |#1|))) (-409 (-953 |#1|))))) 
-((-2055 (((-634 (-1161)) (-409 (-953 |#1|))) 15)) (-3839 (((-409 (-1157 (-409 (-953 |#1|)))) (-409 (-953 |#1|)) (-1161)) 22)) (-2051 (((-409 (-953 |#1|)) (-409 (-1157 (-409 (-953 |#1|)))) (-1161)) 24)) (-2244 (((-3 (-1161) "failed") (-409 (-953 |#1|))) 18)) (-1339 (((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-634 (-288 (-409 (-953 |#1|))))) 29) (((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|)))) 31) (((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-634 (-1161)) (-634 (-409 (-953 |#1|)))) 26) (((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-1161) (-409 (-953 |#1|))) 27)) (-2745 (((-409 (-953 |#1|)) |#1|) 11))) 
-(((-1042 |#1|) (-10 -7 (-15 -2055 ((-634 (-1161)) (-409 (-953 |#1|)))) (-15 -2244 ((-3 (-1161) "failed") (-409 (-953 |#1|)))) (-15 -3839 ((-409 (-1157 (-409 (-953 |#1|)))) (-409 (-953 |#1|)) (-1161))) (-15 -2051 ((-409 (-953 |#1|)) (-409 (-1157 (-409 (-953 |#1|)))) (-1161))) (-15 -1339 ((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-1161) (-409 (-953 |#1|)))) (-15 -1339 ((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-634 (-1161)) (-634 (-409 (-953 |#1|))))) (-15 -1339 ((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|))))) (-15 -1339 ((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-634 (-288 (-409 (-953 |#1|)))))) (-15 -2745 ((-409 (-953 |#1|)) |#1|))) (-558)) (T -1042)) 
-((-2745 (*1 *2 *3) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-1042 *3)) (-4 *3 (-558)))) (-1339 (*1 *2 *2 *3) (-12 (-5 *3 (-634 (-288 (-409 (-953 *4))))) (-5 *2 (-409 (-953 *4))) (-4 *4 (-558)) (-5 *1 (-1042 *4)))) (-1339 (*1 *2 *2 *3) (-12 (-5 *3 (-288 (-409 (-953 *4)))) (-5 *2 (-409 (-953 *4))) (-4 *4 (-558)) (-5 *1 (-1042 *4)))) (-1339 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-634 (-1161))) (-5 *4 (-634 (-409 (-953 *5)))) (-5 *2 (-409 (-953 *5))) (-4 *5 (-558)) (-5 *1 (-1042 *5)))) (-1339 (*1 *2 *2 *3 *2) (-12 (-5 *2 (-409 (-953 *4))) (-5 *3 (-1161)) (-4 *4 (-558)) (-5 *1 (-1042 *4)))) (-2051 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-1157 (-409 (-953 *5))))) (-5 *4 (-1161)) (-5 *2 (-409 (-953 *5))) (-5 *1 (-1042 *5)) (-4 *5 (-558)))) (-3839 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-558)) (-5 *2 (-409 (-1157 (-409 (-953 *5))))) (-5 *1 (-1042 *5)) (-5 *3 (-409 (-953 *5))))) (-2244 (*1 *2 *3) (|partial| -12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-558)) (-5 *2 (-1161)) (-5 *1 (-1042 *4)))) (-2055 (*1 *2 *3) (-12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-558)) (-5 *2 (-634 (-1161))) (-5 *1 (-1042 *4))))) 
-(-10 -7 (-15 -2055 ((-634 (-1161)) (-409 (-953 |#1|)))) (-15 -2244 ((-3 (-1161) "failed") (-409 (-953 |#1|)))) (-15 -3839 ((-409 (-1157 (-409 (-953 |#1|)))) (-409 (-953 |#1|)) (-1161))) (-15 -2051 ((-409 (-953 |#1|)) (-409 (-1157 (-409 (-953 |#1|)))) (-1161))) (-15 -1339 ((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-1161) (-409 (-953 |#1|)))) (-15 -1339 ((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-634 (-1161)) (-634 (-409 (-953 |#1|))))) (-15 -1339 ((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|))))) (-15 -1339 ((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-634 (-288 (-409 (-953 |#1|)))))) (-15 -2745 ((-409 (-953 |#1|)) |#1|))) 
-((-4478 (((-634 |#1|) (-634 |#1|)) 45)) (-1604 (((-634 |#1|)) 9)) (-3598 (((-2 (|:| |zeros| (-634 |#1|)) (|:| -2842 (-568))) (-1157 |#1|) |#1|) 19)) (-3051 (((-2 (|:| |zeros| (-634 |#1|)) (|:| -2842 (-568))) (-634 (-1157 |#1|)) |#1|) 37))) 
-(((-1043 |#1|) (-10 -7 (-15 -3598 ((-2 (|:| |zeros| (-634 |#1|)) (|:| -2842 (-568))) (-1157 |#1|) |#1|)) (-15 -3051 ((-2 (|:| |zeros| (-634 |#1|)) (|:| -2842 (-568))) (-634 (-1157 |#1|)) |#1|)) (-15 -1604 ((-634 |#1|))) (-15 -4478 ((-634 |#1|) (-634 |#1|)))) (-365)) (T -1043)) 
-((-4478 (*1 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-5 *1 (-1043 *3)))) (-1604 (*1 *2) (-12 (-5 *2 (-634 *3)) (-5 *1 (-1043 *3)) (-4 *3 (-365)))) (-3051 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1157 *4))) (-4 *4 (-365)) (-5 *2 (-2 (|:| |zeros| (-634 *4)) (|:| -2842 (-568)))) (-5 *1 (-1043 *4)))) (-3598 (*1 *2 *3 *4) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-365)) (-5 *2 (-2 (|:| |zeros| (-634 *4)) (|:| -2842 (-568)))) (-5 *1 (-1043 *4))))) 
-(-10 -7 (-15 -3598 ((-2 (|:| |zeros| (-634 |#1|)) (|:| -2842 (-568))) (-1157 |#1|) |#1|)) (-15 -3051 ((-2 (|:| |zeros| (-634 |#1|)) (|:| -2842 (-568))) (-634 (-1157 |#1|)) |#1|)) (-15 -1604 ((-634 |#1|))) (-15 -4478 ((-634 |#1|) (-634 |#1|)))) 
-((-2447 (((-121) $ $) NIL)) (-2387 (((-634 (-2 (|:| -4092 $) (|:| -1798 (-634 (-775 |#1| (-852 |#2|)))))) (-634 (-775 |#1| (-852 |#2|)))) NIL)) (-2415 (((-634 $) (-634 (-775 |#1| (-852 |#2|)))) NIL) (((-634 $) (-634 (-775 |#1| (-852 |#2|))) (-121)) NIL) (((-634 $) (-634 (-775 |#1| (-852 |#2|))) (-121) (-121)) NIL)) (-2055 (((-634 (-852 |#2|)) $) NIL)) (-4211 (((-121) $) NIL)) (-3824 (((-121) $) NIL (|has| |#1| (-558)))) (-3300 (((-121) (-775 |#1| (-852 |#2|)) $) NIL) (((-121) $) NIL)) (-2819 (((-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) $) NIL)) (-4305 (((-634 (-2 (|:| |val| (-775 |#1| (-852 |#2|))) (|:| -3001 $))) (-775 |#1| (-852 |#2|)) $) NIL)) (-3644 (((-2 (|:| |under| $) (|:| -1519 $) (|:| |upper| $)) $ (-852 |#2|)) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-2801 (($ (-1 (-121) (-775 |#1| (-852 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-3 (-775 |#1| (-852 |#2|)) "failed") $ (-852 |#2|)) NIL)) (-2671 (($) NIL T CONST)) (-1565 (((-121) $) NIL (|has| |#1| (-558)))) (-3846 (((-121) $ $) NIL (|has| |#1| (-558)))) (-3106 (((-121) $ $) NIL (|has| |#1| (-558)))) (-3695 (((-121) $) NIL (|has| |#1| (-558)))) (-4275 (((-634 (-775 |#1| (-852 |#2|))) (-634 (-775 |#1| (-852 |#2|))) $ (-1 (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|))) (-1 (-121) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)))) NIL)) (-2355 (((-634 (-775 |#1| (-852 |#2|))) (-634 (-775 |#1| (-852 |#2|))) $) NIL (|has| |#1| (-558)))) (-2492 (((-634 (-775 |#1| (-852 |#2|))) (-634 (-775 |#1| (-852 |#2|))) $) NIL (|has| |#1| (-558)))) (-3666 (((-3 $ "failed") (-634 (-775 |#1| (-852 |#2|)))) NIL)) (-2854 (($ (-634 (-775 |#1| (-852 |#2|)))) NIL)) (-3935 (((-3 $ "failed") $) NIL)) (-2062 (((-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) $) NIL)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-775 |#1| (-852 |#2|)) (-1090))))) (-4328 (($ (-775 |#1| (-852 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-775 |#1| (-852 |#2|)) (-1090)))) (($ (-1 (-121) (-775 |#1| (-852 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-1500 (((-2 (|:| |rnum| |#1|) (|:| |polnum| (-775 |#1| (-852 |#2|))) (|:| |den| |#1|)) (-775 |#1| (-852 |#2|)) $) NIL (|has| |#1| (-558)))) (-1281 (((-121) (-775 |#1| (-852 |#2|)) $ (-1 (-121) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)))) NIL)) (-4079 (((-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) $) NIL)) (-3092 (((-775 |#1| (-852 |#2|)) (-1 (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|))) $ (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|))) NIL (-12 (|has| $ (-6 -4519)) (|has| (-775 |#1| (-852 |#2|)) (-1090)))) (((-775 |#1| (-852 |#2|)) (-1 (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|))) $ (-775 |#1| (-852 |#2|))) NIL (|has| $ (-6 -4519))) (((-775 |#1| (-852 |#2|)) (-1 (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) $ (-1 (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|))) (-1 (-121) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)))) NIL)) (-3635 (((-2 (|:| -4092 (-634 (-775 |#1| (-852 |#2|)))) (|:| -1798 (-634 (-775 |#1| (-852 |#2|))))) $) NIL)) (-1862 (((-121) (-775 |#1| (-852 |#2|)) $) NIL)) (-4286 (((-121) (-775 |#1| (-852 |#2|)) $) NIL)) (-3193 (((-121) (-775 |#1| (-852 |#2|)) $) NIL) (((-121) $) NIL)) (-4360 (((-634 (-775 |#1| (-852 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-1362 (((-121) (-775 |#1| (-852 |#2|)) $) NIL) (((-121) $) NIL)) (-2356 (((-852 |#2|) $) NIL)) (-1737 (((-121) $ (-763)) NIL)) (-1979 (((-634 (-775 |#1| (-852 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) (-775 |#1| (-852 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-775 |#1| (-852 |#2|)) (-1090))))) (-3674 (($ (-1 (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|))) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|))) $) NIL)) (-1432 (((-634 (-852 |#2|)) $) NIL)) (-3392 (((-121) (-852 |#2|) $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL)) (-2717 (((-3 (-775 |#1| (-852 |#2|)) (-634 $)) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) $) NIL)) (-4330 (((-634 (-2 (|:| |val| (-775 |#1| (-852 |#2|))) (|:| -3001 $))) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) $) NIL)) (-4162 (((-3 (-775 |#1| (-852 |#2|)) "failed") $) NIL)) (-2335 (((-634 $) (-775 |#1| (-852 |#2|)) $) NIL)) (-1719 (((-3 (-121) (-634 $)) (-775 |#1| (-852 |#2|)) $) NIL)) (-2632 (((-634 (-2 (|:| |val| (-121)) (|:| -3001 $))) (-775 |#1| (-852 |#2|)) $) NIL) (((-121) (-775 |#1| (-852 |#2|)) $) NIL)) (-3212 (((-634 $) (-775 |#1| (-852 |#2|)) $) NIL) (((-634 $) (-634 (-775 |#1| (-852 |#2|))) $) NIL) (((-634 $) (-634 (-775 |#1| (-852 |#2|))) (-634 $)) NIL) (((-634 $) (-775 |#1| (-852 |#2|)) (-634 $)) NIL)) (-3473 (($ (-775 |#1| (-852 |#2|)) $) NIL) (($ (-634 (-775 |#1| (-852 |#2|))) $) NIL)) (-1377 (((-634 (-775 |#1| (-852 |#2|))) $) NIL)) (-1415 (((-121) (-775 |#1| (-852 |#2|)) $) NIL) (((-121) $) NIL)) (-2682 (((-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) $) NIL)) (-2644 (((-121) $ $) NIL)) (-2705 (((-2 (|:| |num| (-775 |#1| (-852 |#2|))) (|:| |den| |#1|)) (-775 |#1| (-852 |#2|)) $) NIL (|has| |#1| (-558)))) (-4347 (((-121) (-775 |#1| (-852 |#2|)) $) NIL) (((-121) $) NIL)) (-4025 (((-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) $) NIL)) (-4022 (((-1108) $) NIL)) (-3876 (((-3 (-775 |#1| (-852 |#2|)) "failed") $) NIL)) (-3775 (((-3 (-775 |#1| (-852 |#2|)) "failed") (-1 (-121) (-775 |#1| (-852 |#2|))) $) NIL)) (-1665 (((-3 $ "failed") $ (-775 |#1| (-852 |#2|))) NIL)) (-1807 (($ $ (-775 |#1| (-852 |#2|))) NIL) (((-634 $) (-775 |#1| (-852 |#2|)) $) NIL) (((-634 $) (-775 |#1| (-852 |#2|)) (-634 $)) NIL) (((-634 $) (-634 (-775 |#1| (-852 |#2|))) $) NIL) (((-634 $) (-634 (-775 |#1| (-852 |#2|))) (-634 $)) NIL)) (-1387 (((-121) (-1 (-121) (-775 |#1| (-852 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-775 |#1| (-852 |#2|))) (-634 (-775 |#1| (-852 |#2|)))) NIL (-12 (|has| (-775 |#1| (-852 |#2|)) (-303 (-775 |#1| (-852 |#2|)))) (|has| (-775 |#1| (-852 |#2|)) (-1090)))) (($ $ (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|))) NIL (-12 (|has| (-775 |#1| (-852 |#2|)) (-303 (-775 |#1| (-852 |#2|)))) (|has| (-775 |#1| (-852 |#2|)) (-1090)))) (($ $ (-288 (-775 |#1| (-852 |#2|)))) NIL (-12 (|has| (-775 |#1| (-852 |#2|)) (-303 (-775 |#1| (-852 |#2|)))) (|has| (-775 |#1| (-852 |#2|)) (-1090)))) (($ $ (-634 (-288 (-775 |#1| (-852 |#2|))))) NIL (-12 (|has| (-775 |#1| (-852 |#2|)) (-303 (-775 |#1| (-852 |#2|)))) (|has| (-775 |#1| (-852 |#2|)) (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-3206 (((-763) $) NIL)) (-4168 (((-763) (-775 |#1| (-852 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-775 |#1| (-852 |#2|)) (-1090)))) (((-763) (-1 (-121) (-775 |#1| (-852 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| (-775 |#1| (-852 |#2|)) (-609 (-541))))) (-4287 (($ (-634 (-775 |#1| (-852 |#2|)))) NIL)) (-1290 (($ $ (-852 |#2|)) NIL)) (-3732 (($ $ (-852 |#2|)) NIL)) (-1567 (($ $) NIL)) (-3944 (($ $ (-852 |#2|)) NIL)) (-2745 (((-850) $) NIL) (((-634 (-775 |#1| (-852 |#2|))) $) NIL)) (-1878 (((-763) $) NIL (|has| (-852 |#2|) (-370)))) (-3556 (((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 (-775 |#1| (-852 |#2|))))) "failed") (-634 (-775 |#1| (-852 |#2|))) (-1 (-121) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)))) NIL) (((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 (-775 |#1| (-852 |#2|))))) "failed") (-634 (-775 |#1| (-852 |#2|))) (-1 (-121) (-775 |#1| (-852 |#2|))) (-1 (-121) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)))) NIL)) (-3292 (((-121) $ (-1 (-121) (-775 |#1| (-852 |#2|)) (-634 (-775 |#1| (-852 |#2|))))) NIL)) (-2574 (((-634 $) (-775 |#1| (-852 |#2|)) $) NIL) (((-634 $) (-775 |#1| (-852 |#2|)) (-634 $)) NIL) (((-634 $) (-634 (-775 |#1| (-852 |#2|))) $) NIL) (((-634 $) (-634 (-775 |#1| (-852 |#2|))) (-634 $)) NIL)) (-1319 (((-121) (-1 (-121) (-775 |#1| (-852 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-2739 (((-634 (-852 |#2|)) $) NIL)) (-2288 (((-121) (-775 |#1| (-852 |#2|)) $) NIL)) (-4390 (((-121) (-852 |#2|) $) NIL)) (-1717 (((-121) $ $) NIL)) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-1044 |#1| |#2|) (-13 (-1066 |#1| (-534 (-852 |#2|)) (-852 |#2|) (-775 |#1| (-852 |#2|))) (-10 -8 (-15 -2415 ((-634 $) (-634 (-775 |#1| (-852 |#2|))) (-121) (-121))))) (-453) (-634 (-1161))) (T -1044)) 
-((-2415 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 (-775 *5 (-852 *6)))) (-5 *4 (-121)) (-4 *5 (-453)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-1044 *5 *6))) (-5 *1 (-1044 *5 *6))))) 
-(-13 (-1066 |#1| (-534 (-852 |#2|)) (-852 |#2|) (-775 |#1| (-852 |#2|))) (-10 -8 (-15 -2415 ((-634 $) (-634 (-775 |#1| (-852 |#2|))) (-121) (-121))))) 
-((-3703 (((-1 (-568)) (-1084 (-568))) 33)) (-2694 (((-568) (-568) (-568) (-568) (-568)) 30)) (-1298 (((-1 (-568)) |RationalNumber|) NIL)) (-3064 (((-1 (-568)) |RationalNumber|) NIL)) (-2787 (((-1 (-568)) (-568) |RationalNumber|) NIL))) 
-(((-1045) (-10 -7 (-15 -3703 ((-1 (-568)) (-1084 (-568)))) (-15 -2787 ((-1 (-568)) (-568) |RationalNumber|)) (-15 -1298 ((-1 (-568)) |RationalNumber|)) (-15 -3064 ((-1 (-568)) |RationalNumber|)) (-15 -2694 ((-568) (-568) (-568) (-568) (-568))))) (T -1045)) 
-((-2694 (*1 *2 *2 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1045)))) (-3064 (*1 *2 *3) (-12 (-5 *3 |RationalNumber|) (-5 *2 (-1 (-568))) (-5 *1 (-1045)))) (-1298 (*1 *2 *3) (-12 (-5 *3 |RationalNumber|) (-5 *2 (-1 (-568))) (-5 *1 (-1045)))) (-2787 (*1 *2 *3 *4) (-12 (-5 *4 |RationalNumber|) (-5 *2 (-1 (-568))) (-5 *1 (-1045)) (-5 *3 (-568)))) (-3703 (*1 *2 *3) (-12 (-5 *3 (-1084 (-568))) (-5 *2 (-1 (-568))) (-5 *1 (-1045))))) 
-(-10 -7 (-15 -3703 ((-1 (-568)) (-1084 (-568)))) (-15 -2787 ((-1 (-568)) (-568) |RationalNumber|)) (-15 -1298 ((-1 (-568)) |RationalNumber|)) (-15 -3064 ((-1 (-568)) |RationalNumber|)) (-15 -2694 ((-568) (-568) (-568) (-568) (-568)))) 
-((-2745 (((-850) $) NIL) (($ (-568)) 10))) 
-(((-1046 |#1|) (-10 -8 (-15 -2745 (|#1| (-568))) (-15 -2745 ((-850) |#1|))) (-1047)) (T -1046)) 
-NIL 
-(-10 -8 (-15 -2745 (|#1| (-568))) (-15 -2745 ((-850) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-2925 (((-3 $ "failed") $) 33)) (-2735 (((-121) $) 30)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11) (($ (-568)) 27)) (-4078 (((-763)) 28)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
+((-2857 (*1 *2 *1) (-12 (-4 *1 (-1037 *2)) (-4 *2 (-1195)))) (-3668 (*1 *2 *1) (|partial| -12 (-4 *1 (-1037 *2)) (-4 *2 (-1195)))) (-2747 (*1 *1 *2) (-12 (-4 *1 (-1037 *2)) (-4 *2 (-1195))))) 
+(-13 (-10 -8 (-15 -2747 ($ |t#1|)) (-15 -3668 ((-3 |t#1| "failed") $)) (-15 -2857 (|t#1| $)))) 
+((-1714 (((-634 (-634 (-288 (-409 (-953 |#2|))))) (-634 (-953 |#2|)) (-634 (-1161))) 35))) 
+(((-1038 |#1| |#2|) (-10 -7 (-15 -1714 ((-634 (-634 (-288 (-409 (-953 |#2|))))) (-634 (-953 |#2|)) (-634 (-1161))))) (-558) (-13 (-558) (-1037 |#1|))) (T -1038)) 
+((-1714 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *6))) (-5 *4 (-634 (-1161))) (-4 *6 (-13 (-558) (-1037 *5))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *6)))))) (-5 *1 (-1038 *5 *6))))) 
+(-10 -7 (-15 -1714 ((-634 (-634 (-288 (-409 (-953 |#2|))))) (-634 (-953 |#2|)) (-634 (-1161))))) 
+((-1445 (((-381)) 15)) (-2381 (((-1 (-381)) (-381) (-381)) 20)) (-3494 (((-1 (-381)) (-763)) 42)) (-2281 (((-381)) 33)) (-2244 (((-1 (-381)) (-381) (-381)) 34)) (-1941 (((-381)) 26)) (-3129 (((-1 (-381)) (-381)) 27)) (-2494 (((-381) (-763)) 37)) (-1369 (((-1 (-381)) (-763)) 38)) (-1478 (((-1 (-381)) (-763) (-763)) 41)) (-2768 (((-1 (-381)) (-763) (-763)) 39))) 
+(((-1039) (-10 -7 (-15 -1445 ((-381))) (-15 -2281 ((-381))) (-15 -1941 ((-381))) (-15 -2494 ((-381) (-763))) (-15 -2381 ((-1 (-381)) (-381) (-381))) (-15 -2244 ((-1 (-381)) (-381) (-381))) (-15 -3129 ((-1 (-381)) (-381))) (-15 -1369 ((-1 (-381)) (-763))) (-15 -2768 ((-1 (-381)) (-763) (-763))) (-15 -1478 ((-1 (-381)) (-763) (-763))) (-15 -3494 ((-1 (-381)) (-763))))) (T -1039)) 
+((-3494 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-381))) (-5 *1 (-1039)))) (-1478 (*1 *2 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-381))) (-5 *1 (-1039)))) (-2768 (*1 *2 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-381))) (-5 *1 (-1039)))) (-1369 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-381))) (-5 *1 (-1039)))) (-3129 (*1 *2 *3) (-12 (-5 *2 (-1 (-381))) (-5 *1 (-1039)) (-5 *3 (-381)))) (-2244 (*1 *2 *3 *3) (-12 (-5 *2 (-1 (-381))) (-5 *1 (-1039)) (-5 *3 (-381)))) (-2381 (*1 *2 *3 *3) (-12 (-5 *2 (-1 (-381))) (-5 *1 (-1039)) (-5 *3 (-381)))) (-2494 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-381)) (-5 *1 (-1039)))) (-1941 (*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1039)))) (-2281 (*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1039)))) (-1445 (*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1039))))) 
+(-10 -7 (-15 -1445 ((-381))) (-15 -2281 ((-381))) (-15 -1941 ((-381))) (-15 -2494 ((-381) (-763))) (-15 -2381 ((-1 (-381)) (-381) (-381))) (-15 -2244 ((-1 (-381)) (-381) (-381))) (-15 -3129 ((-1 (-381)) (-381))) (-15 -1369 ((-1 (-381)) (-763))) (-15 -2768 ((-1 (-381)) (-763) (-763))) (-15 -1478 ((-1 (-381)) (-763) (-763))) (-15 -3494 ((-1 (-381)) (-763)))) 
+((-3850 (((-420 |#1|) |#1|) 31))) 
+(((-1040 |#1|) (-10 -7 (-15 -3850 ((-420 |#1|) |#1|))) (-1219 (-409 (-953 (-568))))) (T -1040)) 
+((-3850 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-1040 *3)) (-4 *3 (-1219 (-409 (-953 (-568)))))))) 
+(-10 -7 (-15 -3850 ((-420 |#1|) |#1|))) 
+((-2921 (((-409 (-420 (-953 |#1|))) (-409 (-953 |#1|))) 14))) 
+(((-1041 |#1|) (-10 -7 (-15 -2921 ((-409 (-420 (-953 |#1|))) (-409 (-953 |#1|))))) (-301)) (T -1041)) 
+((-2921 (*1 *2 *3) (-12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-301)) (-5 *2 (-409 (-420 (-953 *4)))) (-5 *1 (-1041 *4))))) 
+(-10 -7 (-15 -2921 ((-409 (-420 (-953 |#1|))) (-409 (-953 |#1|))))) 
+((-2057 (((-634 (-1161)) (-409 (-953 |#1|))) 15)) (-3840 (((-409 (-1157 (-409 (-953 |#1|)))) (-409 (-953 |#1|)) (-1161)) 22)) (-2053 (((-409 (-953 |#1|)) (-409 (-1157 (-409 (-953 |#1|)))) (-1161)) 24)) (-2817 (((-3 (-1161) "failed") (-409 (-953 |#1|))) 18)) (-1339 (((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-634 (-288 (-409 (-953 |#1|))))) 29) (((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|)))) 31) (((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-634 (-1161)) (-634 (-409 (-953 |#1|)))) 26) (((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-1161) (-409 (-953 |#1|))) 27)) (-2747 (((-409 (-953 |#1|)) |#1|) 11))) 
+(((-1042 |#1|) (-10 -7 (-15 -2057 ((-634 (-1161)) (-409 (-953 |#1|)))) (-15 -2817 ((-3 (-1161) "failed") (-409 (-953 |#1|)))) (-15 -3840 ((-409 (-1157 (-409 (-953 |#1|)))) (-409 (-953 |#1|)) (-1161))) (-15 -2053 ((-409 (-953 |#1|)) (-409 (-1157 (-409 (-953 |#1|)))) (-1161))) (-15 -1339 ((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-1161) (-409 (-953 |#1|)))) (-15 -1339 ((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-634 (-1161)) (-634 (-409 (-953 |#1|))))) (-15 -1339 ((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|))))) (-15 -1339 ((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-634 (-288 (-409 (-953 |#1|)))))) (-15 -2747 ((-409 (-953 |#1|)) |#1|))) (-558)) (T -1042)) 
+((-2747 (*1 *2 *3) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-1042 *3)) (-4 *3 (-558)))) (-1339 (*1 *2 *2 *3) (-12 (-5 *3 (-634 (-288 (-409 (-953 *4))))) (-5 *2 (-409 (-953 *4))) (-4 *4 (-558)) (-5 *1 (-1042 *4)))) (-1339 (*1 *2 *2 *3) (-12 (-5 *3 (-288 (-409 (-953 *4)))) (-5 *2 (-409 (-953 *4))) (-4 *4 (-558)) (-5 *1 (-1042 *4)))) (-1339 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-634 (-1161))) (-5 *4 (-634 (-409 (-953 *5)))) (-5 *2 (-409 (-953 *5))) (-4 *5 (-558)) (-5 *1 (-1042 *5)))) (-1339 (*1 *2 *2 *3 *2) (-12 (-5 *2 (-409 (-953 *4))) (-5 *3 (-1161)) (-4 *4 (-558)) (-5 *1 (-1042 *4)))) (-2053 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-1157 (-409 (-953 *5))))) (-5 *4 (-1161)) (-5 *2 (-409 (-953 *5))) (-5 *1 (-1042 *5)) (-4 *5 (-558)))) (-3840 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-558)) (-5 *2 (-409 (-1157 (-409 (-953 *5))))) (-5 *1 (-1042 *5)) (-5 *3 (-409 (-953 *5))))) (-2817 (*1 *2 *3) (|partial| -12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-558)) (-5 *2 (-1161)) (-5 *1 (-1042 *4)))) (-2057 (*1 *2 *3) (-12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-558)) (-5 *2 (-634 (-1161))) (-5 *1 (-1042 *4))))) 
+(-10 -7 (-15 -2057 ((-634 (-1161)) (-409 (-953 |#1|)))) (-15 -2817 ((-3 (-1161) "failed") (-409 (-953 |#1|)))) (-15 -3840 ((-409 (-1157 (-409 (-953 |#1|)))) (-409 (-953 |#1|)) (-1161))) (-15 -2053 ((-409 (-953 |#1|)) (-409 (-1157 (-409 (-953 |#1|)))) (-1161))) (-15 -1339 ((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-1161) (-409 (-953 |#1|)))) (-15 -1339 ((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-634 (-1161)) (-634 (-409 (-953 |#1|))))) (-15 -1339 ((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-288 (-409 (-953 |#1|))))) (-15 -1339 ((-409 (-953 |#1|)) (-409 (-953 |#1|)) (-634 (-288 (-409 (-953 |#1|)))))) (-15 -2747 ((-409 (-953 |#1|)) |#1|))) 
+((-1847 (((-634 |#1|) (-634 |#1|)) 45)) (-1361 (((-634 |#1|)) 9)) (-2997 (((-2 (|:| |zeros| (-634 |#1|)) (|:| -3917 (-568))) (-1157 |#1|) |#1|) 19)) (-2275 (((-2 (|:| |zeros| (-634 |#1|)) (|:| -3917 (-568))) (-634 (-1157 |#1|)) |#1|) 37))) 
+(((-1043 |#1|) (-10 -7 (-15 -2997 ((-2 (|:| |zeros| (-634 |#1|)) (|:| -3917 (-568))) (-1157 |#1|) |#1|)) (-15 -2275 ((-2 (|:| |zeros| (-634 |#1|)) (|:| -3917 (-568))) (-634 (-1157 |#1|)) |#1|)) (-15 -1361 ((-634 |#1|))) (-15 -1847 ((-634 |#1|) (-634 |#1|)))) (-365)) (T -1043)) 
+((-1847 (*1 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-5 *1 (-1043 *3)))) (-1361 (*1 *2) (-12 (-5 *2 (-634 *3)) (-5 *1 (-1043 *3)) (-4 *3 (-365)))) (-2275 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1157 *4))) (-4 *4 (-365)) (-5 *2 (-2 (|:| |zeros| (-634 *4)) (|:| -3917 (-568)))) (-5 *1 (-1043 *4)))) (-2997 (*1 *2 *3 *4) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-365)) (-5 *2 (-2 (|:| |zeros| (-634 *4)) (|:| -3917 (-568)))) (-5 *1 (-1043 *4))))) 
+(-10 -7 (-15 -2997 ((-2 (|:| |zeros| (-634 |#1|)) (|:| -3917 (-568))) (-1157 |#1|) |#1|)) (-15 -2275 ((-2 (|:| |zeros| (-634 |#1|)) (|:| -3917 (-568))) (-634 (-1157 |#1|)) |#1|)) (-15 -1361 ((-634 |#1|))) (-15 -1847 ((-634 |#1|) (-634 |#1|)))) 
+((-2449 (((-121) $ $) NIL)) (-2213 (((-634 (-2 (|:| -4094 $) (|:| -2133 (-634 (-775 |#1| (-852 |#2|)))))) (-634 (-775 |#1| (-852 |#2|)))) NIL)) (-2353 (((-634 $) (-634 (-775 |#1| (-852 |#2|)))) NIL) (((-634 $) (-634 (-775 |#1| (-852 |#2|))) (-121)) NIL) (((-634 $) (-634 (-775 |#1| (-852 |#2|))) (-121) (-121)) NIL)) (-2057 (((-634 (-852 |#2|)) $) NIL)) (-4141 (((-121) $) NIL)) (-1794 (((-121) $) NIL (|has| |#1| (-558)))) (-4231 (((-121) (-775 |#1| (-852 |#2|)) $) NIL) (((-121) $) NIL)) (-3767 (((-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) $) NIL)) (-3045 (((-634 (-2 (|:| |val| (-775 |#1| (-852 |#2|))) (|:| -3145 $))) (-775 |#1| (-852 |#2|)) $) NIL)) (-3647 (((-2 (|:| |under| $) (|:| -4115 $) (|:| |upper| $)) $ (-852 |#2|)) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-2803 (($ (-1 (-121) (-775 |#1| (-852 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-3 (-775 |#1| (-852 |#2|)) "failed") $ (-852 |#2|)) NIL)) (-4490 (($) NIL T CONST)) (-4382 (((-121) $) NIL (|has| |#1| (-558)))) (-1880 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2536 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2343 (((-121) $) NIL (|has| |#1| (-558)))) (-2941 (((-634 (-775 |#1| (-852 |#2|))) (-634 (-775 |#1| (-852 |#2|))) $ (-1 (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|))) (-1 (-121) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)))) NIL)) (-3993 (((-634 (-775 |#1| (-852 |#2|))) (-634 (-775 |#1| (-852 |#2|))) $) NIL (|has| |#1| (-558)))) (-2727 (((-634 (-775 |#1| (-852 |#2|))) (-634 (-775 |#1| (-852 |#2|))) $) NIL (|has| |#1| (-558)))) (-3668 (((-3 $ "failed") (-634 (-775 |#1| (-852 |#2|)))) NIL)) (-2857 (($ (-634 (-775 |#1| (-852 |#2|)))) NIL)) (-3936 (((-3 $ "failed") $) NIL)) (-3255 (((-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) $) NIL)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-775 |#1| (-852 |#2|)) (-1090))))) (-4330 (($ (-775 |#1| (-852 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-775 |#1| (-852 |#2|)) (-1090)))) (($ (-1 (-121) (-775 |#1| (-852 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-2607 (((-2 (|:| |rnum| |#1|) (|:| |polnum| (-775 |#1| (-852 |#2|))) (|:| |den| |#1|)) (-775 |#1| (-852 |#2|)) $) NIL (|has| |#1| (-558)))) (-1359 (((-121) (-775 |#1| (-852 |#2|)) $ (-1 (-121) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)))) NIL)) (-3434 (((-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) $) NIL)) (-3094 (((-775 |#1| (-852 |#2|)) (-1 (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|))) $ (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|))) NIL (-12 (|has| $ (-6 -4521)) (|has| (-775 |#1| (-852 |#2|)) (-1090)))) (((-775 |#1| (-852 |#2|)) (-1 (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|))) $ (-775 |#1| (-852 |#2|))) NIL (|has| $ (-6 -4521))) (((-775 |#1| (-852 |#2|)) (-1 (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) $ (-1 (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|))) (-1 (-121) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)))) NIL)) (-3158 (((-2 (|:| -4094 (-634 (-775 |#1| (-852 |#2|)))) (|:| -2133 (-634 (-775 |#1| (-852 |#2|))))) $) NIL)) (-2451 (((-121) (-775 |#1| (-852 |#2|)) $) NIL)) (-2978 (((-121) (-775 |#1| (-852 |#2|)) $) NIL)) (-1792 (((-121) (-775 |#1| (-852 |#2|)) $) NIL) (((-121) $) NIL)) (-3317 (((-634 (-775 |#1| (-852 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-3764 (((-121) (-775 |#1| (-852 |#2|)) $) NIL) (((-121) $) NIL)) (-4001 (((-852 |#2|) $) NIL)) (-3791 (((-121) $ (-763)) NIL)) (-4406 (((-634 (-775 |#1| (-852 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) (-775 |#1| (-852 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-775 |#1| (-852 |#2|)) (-1090))))) (-2253 (($ (-1 (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|))) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|))) $) NIL)) (-2249 (((-634 (-852 |#2|)) $) NIL)) (-1495 (((-121) (-852 |#2|) $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL)) (-1516 (((-3 (-775 |#1| (-852 |#2|)) (-634 $)) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) $) NIL)) (-3137 (((-634 (-2 (|:| |val| (-775 |#1| (-852 |#2|))) (|:| -3145 $))) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) $) NIL)) (-4164 (((-3 (-775 |#1| (-852 |#2|)) "failed") $) NIL)) (-3878 (((-634 $) (-775 |#1| (-852 |#2|)) $) NIL)) (-3712 (((-3 (-121) (-634 $)) (-775 |#1| (-852 |#2|)) $) NIL)) (-4266 (((-634 (-2 (|:| |val| (-121)) (|:| -3145 $))) (-775 |#1| (-852 |#2|)) $) NIL) (((-121) (-775 |#1| (-852 |#2|)) $) NIL)) (-1864 (((-634 $) (-775 |#1| (-852 |#2|)) $) NIL) (((-634 $) (-634 (-775 |#1| (-852 |#2|))) $) NIL) (((-634 $) (-634 (-775 |#1| (-852 |#2|))) (-634 $)) NIL) (((-634 $) (-775 |#1| (-852 |#2|)) (-634 $)) NIL)) (-3736 (($ (-775 |#1| (-852 |#2|)) $) NIL) (($ (-634 (-775 |#1| (-852 |#2|))) $) NIL)) (-3882 (((-634 (-775 |#1| (-852 |#2|))) $) NIL)) (-2157 (((-121) (-775 |#1| (-852 |#2|)) $) NIL) (((-121) $) NIL)) (-1315 (((-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) $) NIL)) (-4342 (((-121) $ $) NIL)) (-1440 (((-2 (|:| |num| (-775 |#1| (-852 |#2|))) (|:| |den| |#1|)) (-775 |#1| (-852 |#2|)) $) NIL (|has| |#1| (-558)))) (-3236 (((-121) (-775 |#1| (-852 |#2|)) $) NIL) (((-121) $) NIL)) (-1452 (((-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)) $) NIL)) (-4025 (((-1108) $) NIL)) (-3877 (((-3 (-775 |#1| (-852 |#2|)) "failed") $) NIL)) (-2712 (((-3 (-775 |#1| (-852 |#2|)) "failed") (-1 (-121) (-775 |#1| (-852 |#2|))) $) NIL)) (-3413 (((-3 $ "failed") $ (-775 |#1| (-852 |#2|))) NIL)) (-2168 (($ $ (-775 |#1| (-852 |#2|))) NIL) (((-634 $) (-775 |#1| (-852 |#2|)) $) NIL) (((-634 $) (-775 |#1| (-852 |#2|)) (-634 $)) NIL) (((-634 $) (-634 (-775 |#1| (-852 |#2|))) $) NIL) (((-634 $) (-634 (-775 |#1| (-852 |#2|))) (-634 $)) NIL)) (-3951 (((-121) (-1 (-121) (-775 |#1| (-852 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-775 |#1| (-852 |#2|))) (-634 (-775 |#1| (-852 |#2|)))) NIL (-12 (|has| (-775 |#1| (-852 |#2|)) (-303 (-775 |#1| (-852 |#2|)))) (|has| (-775 |#1| (-852 |#2|)) (-1090)))) (($ $ (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|))) NIL (-12 (|has| (-775 |#1| (-852 |#2|)) (-303 (-775 |#1| (-852 |#2|)))) (|has| (-775 |#1| (-852 |#2|)) (-1090)))) (($ $ (-288 (-775 |#1| (-852 |#2|)))) NIL (-12 (|has| (-775 |#1| (-852 |#2|)) (-303 (-775 |#1| (-852 |#2|)))) (|has| (-775 |#1| (-852 |#2|)) (-1090)))) (($ $ (-634 (-288 (-775 |#1| (-852 |#2|))))) NIL (-12 (|has| (-775 |#1| (-852 |#2|)) (-303 (-775 |#1| (-852 |#2|)))) (|has| (-775 |#1| (-852 |#2|)) (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-1836 (((-763) $) NIL)) (-4170 (((-763) (-775 |#1| (-852 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-775 |#1| (-852 |#2|)) (-1090)))) (((-763) (-1 (-121) (-775 |#1| (-852 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| (-775 |#1| (-852 |#2|)) (-609 (-541))))) (-4289 (($ (-634 (-775 |#1| (-852 |#2|)))) NIL)) (-3206 (($ $ (-852 |#2|)) NIL)) (-2527 (($ $ (-852 |#2|)) NIL)) (-4392 (($ $) NIL)) (-4332 (($ $ (-852 |#2|)) NIL)) (-2747 (((-850) $) NIL) (((-634 (-775 |#1| (-852 |#2|))) $) NIL)) (-2524 (((-763) $) NIL (|has| (-852 |#2|) (-370)))) (-2835 (((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 (-775 |#1| (-852 |#2|))))) "failed") (-634 (-775 |#1| (-852 |#2|))) (-1 (-121) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)))) NIL) (((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 (-775 |#1| (-852 |#2|))))) "failed") (-634 (-775 |#1| (-852 |#2|))) (-1 (-121) (-775 |#1| (-852 |#2|))) (-1 (-121) (-775 |#1| (-852 |#2|)) (-775 |#1| (-852 |#2|)))) NIL)) (-2145 (((-121) $ (-1 (-121) (-775 |#1| (-852 |#2|)) (-634 (-775 |#1| (-852 |#2|))))) NIL)) (-1977 (((-634 $) (-775 |#1| (-852 |#2|)) $) NIL) (((-634 $) (-775 |#1| (-852 |#2|)) (-634 $)) NIL) (((-634 $) (-634 (-775 |#1| (-852 |#2|))) $) NIL) (((-634 $) (-634 (-775 |#1| (-852 |#2|))) (-634 $)) NIL)) (-3437 (((-121) (-1 (-121) (-775 |#1| (-852 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-3321 (((-634 (-852 |#2|)) $) NIL)) (-3541 (((-121) (-775 |#1| (-852 |#2|)) $) NIL)) (-1413 (((-121) (-852 |#2|) $) NIL)) (-1719 (((-121) $ $) NIL)) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-1044 |#1| |#2|) (-13 (-1066 |#1| (-534 (-852 |#2|)) (-852 |#2|) (-775 |#1| (-852 |#2|))) (-10 -8 (-15 -2353 ((-634 $) (-634 (-775 |#1| (-852 |#2|))) (-121) (-121))))) (-453) (-634 (-1161))) (T -1044)) 
+((-2353 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 (-775 *5 (-852 *6)))) (-5 *4 (-121)) (-4 *5 (-453)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-1044 *5 *6))) (-5 *1 (-1044 *5 *6))))) 
+(-13 (-1066 |#1| (-534 (-852 |#2|)) (-852 |#2|) (-775 |#1| (-852 |#2|))) (-10 -8 (-15 -2353 ((-634 $) (-634 (-775 |#1| (-852 |#2|))) (-121) (-121))))) 
+((-2381 (((-1 (-568)) (-1084 (-568))) 33)) (-1381 (((-568) (-568) (-568) (-568) (-568)) 30)) (-3269 (((-1 (-568)) |RationalNumber|) NIL)) (-2323 (((-1 (-568)) |RationalNumber|) NIL)) (-3584 (((-1 (-568)) (-568) |RationalNumber|) NIL))) 
+(((-1045) (-10 -7 (-15 -2381 ((-1 (-568)) (-1084 (-568)))) (-15 -3584 ((-1 (-568)) (-568) |RationalNumber|)) (-15 -3269 ((-1 (-568)) |RationalNumber|)) (-15 -2323 ((-1 (-568)) |RationalNumber|)) (-15 -1381 ((-568) (-568) (-568) (-568) (-568))))) (T -1045)) 
+((-1381 (*1 *2 *2 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1045)))) (-2323 (*1 *2 *3) (-12 (-5 *3 |RationalNumber|) (-5 *2 (-1 (-568))) (-5 *1 (-1045)))) (-3269 (*1 *2 *3) (-12 (-5 *3 |RationalNumber|) (-5 *2 (-1 (-568))) (-5 *1 (-1045)))) (-3584 (*1 *2 *3 *4) (-12 (-5 *4 |RationalNumber|) (-5 *2 (-1 (-568))) (-5 *1 (-1045)) (-5 *3 (-568)))) (-2381 (*1 *2 *3) (-12 (-5 *3 (-1084 (-568))) (-5 *2 (-1 (-568))) (-5 *1 (-1045))))) 
+(-10 -7 (-15 -2381 ((-1 (-568)) (-1084 (-568)))) (-15 -3584 ((-1 (-568)) (-568) |RationalNumber|)) (-15 -3269 ((-1 (-568)) |RationalNumber|)) (-15 -2323 ((-1 (-568)) |RationalNumber|)) (-15 -1381 ((-568) (-568) (-568) (-568) (-568)))) 
+((-2747 (((-850) $) NIL) (($ (-568)) 10))) 
+(((-1046 |#1|) (-10 -8 (-15 -2747 (|#1| (-568))) (-15 -2747 ((-850) |#1|))) (-1047)) (T -1046)) 
+NIL 
+(-10 -8 (-15 -2747 (|#1| (-568))) (-15 -2747 ((-850) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-2902 (((-3 $ "failed") $) 33)) (-1598 (((-121) $) 30)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11) (($ (-568)) 27)) (-3425 (((-763)) 28)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
 (((-1047) (-1275)) (T -1047)) 
-((-4078 (*1 *2) (-12 (-4 *1 (-1047)) (-5 *2 (-763)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-1047))))) 
-(-13 (-1054) (-716) (-637 $) (-10 -8 (-15 -4078 ((-763))) (-15 -2745 ($ (-568))) (-6 -4516))) 
+((-3425 (*1 *2) (-12 (-4 *1 (-1047)) (-5 *2 (-763)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-1047))))) 
+(-13 (-1054) (-716) (-637 $) (-10 -8 (-15 -3425 ((-763))) (-15 -2747 ($ (-568))) (-6 -4518))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 $) . T) ((-716) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-1919 (((-409 (-953 |#2|)) (-634 |#2|) (-634 |#2|) (-763) (-763)) 45))) 
-(((-1048 |#1| |#2|) (-10 -7 (-15 -1919 ((-409 (-953 |#2|)) (-634 |#2|) (-634 |#2|) (-763) (-763)))) (-1161) (-365)) (T -1048)) 
-((-1919 (*1 *2 *3 *3 *4 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-763)) (-4 *6 (-365)) (-5 *2 (-409 (-953 *6))) (-5 *1 (-1048 *5 *6)) (-14 *5 (-1161))))) 
-(-10 -7 (-15 -1919 ((-409 (-953 |#2|)) (-634 |#2|) (-634 |#2|) (-763) (-763)))) 
-((-1335 (((-121) $) 27)) (-2230 (((-121) $) 16)) (-3043 (((-763) $) 13)) (-2555 (((-763) $) 14)) (-1960 (((-121) $) 25)) (-1910 (((-121) $) 29))) 
-(((-1049 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -8 (-15 -2555 ((-763) |#1|)) (-15 -3043 ((-763) |#1|)) (-15 -1910 ((-121) |#1|)) (-15 -1335 ((-121) |#1|)) (-15 -1960 ((-121) |#1|)) (-15 -2230 ((-121) |#1|))) (-1050 |#2| |#3| |#4| |#5| |#6|) (-763) (-763) (-1047) (-230 |#3| |#4|) (-230 |#2| |#4|)) (T -1049)) 
-NIL 
-(-10 -8 (-15 -2555 ((-763) |#1|)) (-15 -3043 ((-763) |#1|)) (-15 -1910 ((-121) |#1|)) (-15 -1335 ((-121) |#1|)) (-15 -1960 ((-121) |#1|)) (-15 -2230 ((-121) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-1335 (((-121) $) 48)) (-3134 (((-3 $ "failed") $ $) 18)) (-2230 (((-121) $) 50)) (-2510 (((-121) $ (-763)) 58)) (-2671 (($) 16 T CONST)) (-4167 (($ $) 31 (|has| |#3| (-301)))) (-1818 ((|#4| $ (-568)) 36)) (-3700 (((-763) $) 30 (|has| |#3| (-558)))) (-2602 ((|#3| $ (-568) (-568)) 38)) (-4360 (((-634 |#3|) $) 65 (|has| $ (-6 -4519)))) (-2121 (((-763) $) 29 (|has| |#3| (-558)))) (-4272 (((-634 |#5|) $) 28 (|has| |#3| (-558)))) (-3043 (((-763) $) 42)) (-2555 (((-763) $) 41)) (-1737 (((-121) $ (-763)) 57)) (-2087 (((-568) $) 46)) (-3364 (((-568) $) 44)) (-1979 (((-634 |#3|) $) 66 (|has| $ (-6 -4519)))) (-3109 (((-121) |#3| $) 68 (-12 (|has| |#3| (-1090)) (|has| $ (-6 -4519))))) (-1663 (((-568) $) 45)) (-2893 (((-568) $) 43)) (-2269 (($ (-634 (-634 |#3|))) 51)) (-3674 (($ (-1 |#3| |#3|) $) 61 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#3| |#3|) $) 60) (($ (-1 |#3| |#3| |#3|) $ $) 34)) (-3208 (((-634 (-634 |#3|)) $) 40)) (-2166 (((-121) $ (-763)) 56)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2595 (((-3 $ "failed") $ |#3|) 33 (|has| |#3| (-558)))) (-1387 (((-121) (-1 (-121) |#3|) $) 63 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 |#3|) (-634 |#3|)) 72 (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ |#3| |#3|) 71 (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ (-288 |#3|)) 70 (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ (-634 (-288 |#3|))) 69 (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090))))) (-3171 (((-121) $ $) 52)) (-3084 (((-121) $) 55)) (-3248 (($) 54)) (-2779 ((|#3| $ (-568) (-568)) 39) ((|#3| $ (-568) (-568) |#3|) 37)) (-1960 (((-121) $) 49)) (-4168 (((-763) |#3| $) 67 (-12 (|has| |#3| (-1090)) (|has| $ (-6 -4519)))) (((-763) (-1 (-121) |#3|) $) 64 (|has| $ (-6 -4519)))) (-3863 (($ $) 53)) (-3731 ((|#5| $ (-568)) 35)) (-2745 (((-850) $) 11)) (-1319 (((-121) (-1 (-121) |#3|) $) 62 (|has| $ (-6 -4519)))) (-1910 (((-121) $) 47)) (-3056 (($) 17 T CONST)) (-1717 (((-121) $ $) 6)) (-1779 (($ $ |#3|) 32 (|has| |#3| (-365)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ |#3| $) 22) (($ $ |#3|) 24)) (-1697 (((-763) $) 59 (|has| $ (-6 -4519))))) 
+((-2709 (((-409 (-953 |#2|)) (-634 |#2|) (-634 |#2|) (-763) (-763)) 45))) 
+(((-1048 |#1| |#2|) (-10 -7 (-15 -2709 ((-409 (-953 |#2|)) (-634 |#2|) (-634 |#2|) (-763) (-763)))) (-1161) (-365)) (T -1048)) 
+((-2709 (*1 *2 *3 *3 *4 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-763)) (-4 *6 (-365)) (-5 *2 (-409 (-953 *6))) (-5 *1 (-1048 *5 *6)) (-14 *5 (-1161))))) 
+(-10 -7 (-15 -2709 ((-409 (-953 |#2|)) (-634 |#2|) (-634 |#2|) (-763) (-763)))) 
+((-3560 (((-121) $) 27)) (-3691 (((-121) $) 16)) (-2241 (((-763) $) 13)) (-1901 (((-763) $) 14)) (-4322 (((-121) $) 25)) (-2675 (((-121) $) 29))) 
+(((-1049 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -8 (-15 -1901 ((-763) |#1|)) (-15 -2241 ((-763) |#1|)) (-15 -2675 ((-121) |#1|)) (-15 -3560 ((-121) |#1|)) (-15 -4322 ((-121) |#1|)) (-15 -3691 ((-121) |#1|))) (-1050 |#2| |#3| |#4| |#5| |#6|) (-763) (-763) (-1047) (-230 |#3| |#4|) (-230 |#2| |#4|)) (T -1049)) 
+NIL 
+(-10 -8 (-15 -1901 ((-763) |#1|)) (-15 -2241 ((-763) |#1|)) (-15 -2675 ((-121) |#1|)) (-15 -3560 ((-121) |#1|)) (-15 -4322 ((-121) |#1|)) (-15 -3691 ((-121) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-3560 (((-121) $) 48)) (-2689 (((-3 $ "failed") $ $) 18)) (-3691 (((-121) $) 50)) (-1667 (((-121) $ (-763)) 58)) (-4490 (($) 16 T CONST)) (-3912 (($ $) 31 (|has| |#3| (-301)))) (-2228 ((|#4| $ (-568)) 36)) (-2371 (((-763) $) 30 (|has| |#3| (-558)))) (-2069 ((|#3| $ (-568) (-568)) 38)) (-3317 (((-634 |#3|) $) 65 (|has| $ (-6 -4521)))) (-3344 (((-763) $) 29 (|has| |#3| (-558)))) (-2934 (((-634 |#5|) $) 28 (|has| |#3| (-558)))) (-2241 (((-763) $) 42)) (-1901 (((-763) $) 41)) (-3791 (((-121) $ (-763)) 57)) (-3139 (((-568) $) 46)) (-1343 (((-568) $) 44)) (-4406 (((-634 |#3|) $) 66 (|has| $ (-6 -4521)))) (-2551 (((-121) |#3| $) 68 (-12 (|has| |#3| (-1090)) (|has| $ (-6 -4521))))) (-3405 (((-568) $) 45)) (-2801 (((-568) $) 43)) (-2271 (($ (-634 (-634 |#3|))) 51)) (-2253 (($ (-1 |#3| |#3|) $) 61 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#3| |#3|) $) 60) (($ (-1 |#3| |#3| |#3|) $ $) 34)) (-1843 (((-634 (-634 |#3|)) $) 40)) (-3796 (((-121) $ (-763)) 56)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2597 (((-3 $ "failed") $ |#3|) 33 (|has| |#3| (-558)))) (-3951 (((-121) (-1 (-121) |#3|) $) 63 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 |#3|) (-634 |#3|)) 72 (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ |#3| |#3|) 71 (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ (-288 |#3|)) 70 (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ (-634 (-288 |#3|))) 69 (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090))))) (-1702 (((-121) $ $) 52)) (-2436 (((-121) $) 55)) (-1990 (($) 54)) (-2781 ((|#3| $ (-568) (-568)) 39) ((|#3| $ (-568) (-568) |#3|) 37)) (-4322 (((-121) $) 49)) (-4170 (((-763) |#3| $) 67 (-12 (|has| |#3| (-1090)) (|has| $ (-6 -4521)))) (((-763) (-1 (-121) |#3|) $) 64 (|has| $ (-6 -4521)))) (-3865 (($ $) 53)) (-2522 ((|#5| $ (-568)) 35)) (-2747 (((-850) $) 11)) (-3437 (((-121) (-1 (-121) |#3|) $) 62 (|has| $ (-6 -4521)))) (-2675 (((-121) $) 47)) (-3058 (($) 17 T CONST)) (-1719 (((-121) $ $) 6)) (-1781 (($ $ |#3|) 32 (|has| |#3| (-365)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ |#3| $) 22) (($ $ |#3|) 24)) (-1699 (((-763) $) 59 (|has| $ (-6 -4521))))) 
 (((-1050 |#1| |#2| |#3| |#4| |#5|) (-1275) (-763) (-763) (-1047) (-230 |t#2| |t#3|) (-230 |t#1| |t#3|)) (T -1050)) 
-((-2795 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *5 *5)) (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)))) (-2269 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 *5))) (-4 *5 (-1047)) (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)))) (-2230 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-121)))) (-1960 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-121)))) (-1335 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-121)))) (-1910 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-121)))) (-2087 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-568)))) (-1663 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-568)))) (-3364 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-568)))) (-2893 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-568)))) (-3043 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-763)))) (-2555 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-763)))) (-3208 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-634 (-634 *5))))) (-2779 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1050 *4 *5 *2 *6 *7)) (-4 *6 (-230 *5 *2)) (-4 *7 (-230 *4 *2)) (-4 *2 (-1047)))) (-2602 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1050 *4 *5 *2 *6 *7)) (-4 *6 (-230 *5 *2)) (-4 *7 (-230 *4 *2)) (-4 *2 (-1047)))) (-2779 (*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-1050 *4 *5 *2 *6 *7)) (-4 *2 (-1047)) (-4 *6 (-230 *5 *2)) (-4 *7 (-230 *4 *2)))) (-1818 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1050 *4 *5 *6 *2 *7)) (-4 *6 (-1047)) (-4 *7 (-230 *4 *6)) (-4 *2 (-230 *5 *6)))) (-3731 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1050 *4 *5 *6 *7 *2)) (-4 *6 (-1047)) (-4 *7 (-230 *5 *6)) (-4 *2 (-230 *4 *6)))) (-2795 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *5 *5 *5)) (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)))) (-2595 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-1050 *3 *4 *2 *5 *6)) (-4 *2 (-1047)) (-4 *5 (-230 *4 *2)) (-4 *6 (-230 *3 *2)) (-4 *2 (-558)))) (-1779 (*1 *1 *1 *2) (-12 (-4 *1 (-1050 *3 *4 *2 *5 *6)) (-4 *2 (-1047)) (-4 *5 (-230 *4 *2)) (-4 *6 (-230 *3 *2)) (-4 *2 (-365)))) (-4167 (*1 *1 *1) (-12 (-4 *1 (-1050 *2 *3 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-230 *3 *4)) (-4 *6 (-230 *2 *4)) (-4 *4 (-301)))) (-3700 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-4 *5 (-558)) (-5 *2 (-763)))) (-2121 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-4 *5 (-558)) (-5 *2 (-763)))) (-4272 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-4 *5 (-558)) (-5 *2 (-634 *7))))) 
-(-13 (-120 |t#3| |t#3|) (-499 |t#3|) (-10 -8 (-6 -4519) (IF (|has| |t#3| (-172)) (-6 (-707 |t#3|)) |noBranch|) (-15 -2269 ($ (-634 (-634 |t#3|)))) (-15 -2230 ((-121) $)) (-15 -1960 ((-121) $)) (-15 -1335 ((-121) $)) (-15 -1910 ((-121) $)) (-15 -2087 ((-568) $)) (-15 -1663 ((-568) $)) (-15 -3364 ((-568) $)) (-15 -2893 ((-568) $)) (-15 -3043 ((-763) $)) (-15 -2555 ((-763) $)) (-15 -3208 ((-634 (-634 |t#3|)) $)) (-15 -2779 (|t#3| $ (-568) (-568))) (-15 -2602 (|t#3| $ (-568) (-568))) (-15 -2779 (|t#3| $ (-568) (-568) |t#3|)) (-15 -1818 (|t#4| $ (-568))) (-15 -3731 (|t#5| $ (-568))) (-15 -2795 ($ (-1 |t#3| |t#3|) $)) (-15 -2795 ($ (-1 |t#3| |t#3| |t#3|) $ $)) (IF (|has| |t#3| (-558)) (-15 -2595 ((-3 $ "failed") $ |t#3|)) |noBranch|) (IF (|has| |t#3| (-365)) (-15 -1779 ($ $ |t#3|)) |noBranch|) (IF (|has| |t#3| (-301)) (-15 -4167 ($ $)) |noBranch|) (IF (|has| |t#3| (-558)) (PROGN (-15 -3700 ((-763) $)) (-15 -2121 ((-763) $)) (-15 -4272 ((-634 |t#5|) $))) |noBranch|))) 
+((-2797 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *5 *5)) (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)))) (-2271 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 *5))) (-4 *5 (-1047)) (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)))) (-3691 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-121)))) (-4322 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-121)))) (-3560 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-121)))) (-2675 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-121)))) (-3139 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-568)))) (-3405 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-568)))) (-1343 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-568)))) (-2801 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-568)))) (-2241 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-763)))) (-1901 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-763)))) (-1843 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-634 (-634 *5))))) (-2781 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1050 *4 *5 *2 *6 *7)) (-4 *6 (-230 *5 *2)) (-4 *7 (-230 *4 *2)) (-4 *2 (-1047)))) (-2069 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1050 *4 *5 *2 *6 *7)) (-4 *6 (-230 *5 *2)) (-4 *7 (-230 *4 *2)) (-4 *2 (-1047)))) (-2781 (*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-1050 *4 *5 *2 *6 *7)) (-4 *2 (-1047)) (-4 *6 (-230 *5 *2)) (-4 *7 (-230 *4 *2)))) (-2228 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1050 *4 *5 *6 *2 *7)) (-4 *6 (-1047)) (-4 *7 (-230 *4 *6)) (-4 *2 (-230 *5 *6)))) (-2522 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1050 *4 *5 *6 *7 *2)) (-4 *6 (-1047)) (-4 *7 (-230 *5 *6)) (-4 *2 (-230 *4 *6)))) (-2797 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *5 *5 *5)) (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)))) (-2597 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-1050 *3 *4 *2 *5 *6)) (-4 *2 (-1047)) (-4 *5 (-230 *4 *2)) (-4 *6 (-230 *3 *2)) (-4 *2 (-558)))) (-1781 (*1 *1 *1 *2) (-12 (-4 *1 (-1050 *3 *4 *2 *5 *6)) (-4 *2 (-1047)) (-4 *5 (-230 *4 *2)) (-4 *6 (-230 *3 *2)) (-4 *2 (-365)))) (-3912 (*1 *1 *1) (-12 (-4 *1 (-1050 *2 *3 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-230 *3 *4)) (-4 *6 (-230 *2 *4)) (-4 *4 (-301)))) (-2371 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-4 *5 (-558)) (-5 *2 (-763)))) (-3344 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-4 *5 (-558)) (-5 *2 (-763)))) (-2934 (*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-4 *5 (-558)) (-5 *2 (-634 *7))))) 
+(-13 (-120 |t#3| |t#3|) (-499 |t#3|) (-10 -8 (-6 -4521) (IF (|has| |t#3| (-172)) (-6 (-707 |t#3|)) |noBranch|) (-15 -2271 ($ (-634 (-634 |t#3|)))) (-15 -3691 ((-121) $)) (-15 -4322 ((-121) $)) (-15 -3560 ((-121) $)) (-15 -2675 ((-121) $)) (-15 -3139 ((-568) $)) (-15 -3405 ((-568) $)) (-15 -1343 ((-568) $)) (-15 -2801 ((-568) $)) (-15 -2241 ((-763) $)) (-15 -1901 ((-763) $)) (-15 -1843 ((-634 (-634 |t#3|)) $)) (-15 -2781 (|t#3| $ (-568) (-568))) (-15 -2069 (|t#3| $ (-568) (-568))) (-15 -2781 (|t#3| $ (-568) (-568) |t#3|)) (-15 -2228 (|t#4| $ (-568))) (-15 -2522 (|t#5| $ (-568))) (-15 -2797 ($ (-1 |t#3| |t#3|) $)) (-15 -2797 ($ (-1 |t#3| |t#3| |t#3|) $ $)) (IF (|has| |t#3| (-558)) (-15 -2597 ((-3 $ "failed") $ |t#3|)) |noBranch|) (IF (|has| |t#3| (-365)) (-15 -1781 ($ $ |t#3|)) |noBranch|) (IF (|has| |t#3| (-301)) (-15 -3912 ($ $)) |noBranch|) (IF (|has| |t#3| (-558)) (PROGN (-15 -2371 ((-763) $)) (-15 -3344 ((-763) $)) (-15 -2934 ((-634 |t#5|) $))) |noBranch|))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-39) . T) ((-105) . T) ((-120 |#3| |#3|) . T) ((-137) . T) ((-608 (-850)) . T) ((-303 |#3|) -12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090))) ((-499 |#3|) . T) ((-523 |#3| |#3|) -12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090))) ((-637 |#3|) . T) ((-707 |#3|) |has| |#3| (-172)) ((-1053 |#3|) . T) ((-1090) . T) ((-1195) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-1335 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2230 (((-121) $) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-2671 (($) NIL T CONST)) (-4167 (($ $) 40 (|has| |#3| (-301)))) (-1818 (((-232 |#2| |#3|) $ (-568)) 29)) (-2846 (($ (-679 |#3|)) 38)) (-3700 (((-763) $) 42 (|has| |#3| (-558)))) (-2602 ((|#3| $ (-568) (-568)) NIL)) (-4360 (((-634 |#3|) $) NIL (|has| $ (-6 -4519)))) (-2121 (((-763) $) 44 (|has| |#3| (-558)))) (-4272 (((-634 (-232 |#1| |#3|)) $) 48 (|has| |#3| (-558)))) (-3043 (((-763) $) NIL)) (-2555 (((-763) $) NIL)) (-1737 (((-121) $ (-763)) NIL)) (-2087 (((-568) $) NIL)) (-3364 (((-568) $) NIL)) (-1979 (((-634 |#3|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#3| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#3| (-1090))))) (-1663 (((-568) $) NIL)) (-2893 (((-568) $) NIL)) (-2269 (($ (-634 (-634 |#3|))) 24)) (-3674 (($ (-1 |#3| |#3|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#3| |#3|) $) NIL) (($ (-1 |#3| |#3| |#3|) $ $) NIL)) (-3208 (((-634 (-634 |#3|)) $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2595 (((-3 $ "failed") $ |#3|) NIL (|has| |#3| (-558)))) (-1387 (((-121) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 |#3|) (-634 |#3|)) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ |#3| |#3|) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ (-288 |#3|)) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ (-634 (-288 |#3|))) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#3| $ (-568) (-568)) NIL) ((|#3| $ (-568) (-568) |#3|) NIL)) (-4321 (((-139)) 51 (|has| |#3| (-365)))) (-1960 (((-121) $) NIL)) (-4168 (((-763) |#3| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#3| (-1090)))) (((-763) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4519)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) 60 (|has| |#3| (-609 (-541))))) (-3731 (((-232 |#1| |#3|) $ (-568)) 33)) (-2745 (((-850) $) 16) (((-679 |#3|) $) 35)) (-1319 (((-121) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4519)))) (-1910 (((-121) $) NIL)) (-3056 (($) 13 T CONST)) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ |#3|) NIL (|has| |#3| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ |#3| $) NIL) (($ $ |#3|) NIL)) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-1051 |#1| |#2| |#3|) (-13 (-1050 |#1| |#2| |#3| (-232 |#2| |#3|) (-232 |#1| |#3|)) (-608 (-679 |#3|)) (-10 -8 (IF (|has| |#3| (-365)) (-6 (-1251 |#3|)) |noBranch|) (IF (|has| |#3| (-609 (-541))) (-6 (-609 (-541))) |noBranch|) (-15 -2846 ($ (-679 |#3|))) (-15 -2745 ((-679 |#3|) $)))) (-763) (-763) (-1047)) (T -1051)) 
-((-2745 (*1 *2 *1) (-12 (-5 *2 (-679 *5)) (-5 *1 (-1051 *3 *4 *5)) (-14 *3 (-763)) (-14 *4 (-763)) (-4 *5 (-1047)))) (-2846 (*1 *1 *2) (-12 (-5 *2 (-679 *5)) (-4 *5 (-1047)) (-5 *1 (-1051 *3 *4 *5)) (-14 *3 (-763)) (-14 *4 (-763))))) 
-(-13 (-1050 |#1| |#2| |#3| (-232 |#2| |#3|) (-232 |#1| |#3|)) (-608 (-679 |#3|)) (-10 -8 (IF (|has| |#3| (-365)) (-6 (-1251 |#3|)) |noBranch|) (IF (|has| |#3| (-609 (-541))) (-6 (-609 (-541))) |noBranch|) (-15 -2846 ($ (-679 |#3|))) (-15 -2745 ((-679 |#3|) $)))) 
-((-3092 ((|#7| (-1 |#7| |#3| |#7|) |#6| |#7|) 34)) (-2795 ((|#10| (-1 |#7| |#3|) |#6|) 32))) 
-(((-1052 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9| |#10|) (-10 -7 (-15 -2795 (|#10| (-1 |#7| |#3|) |#6|)) (-15 -3092 (|#7| (-1 |#7| |#3| |#7|) |#6| |#7|))) (-763) (-763) (-1047) (-230 |#2| |#3|) (-230 |#1| |#3|) (-1050 |#1| |#2| |#3| |#4| |#5|) (-1047) (-230 |#2| |#7|) (-230 |#1| |#7|) (-1050 |#1| |#2| |#7| |#8| |#9|)) (T -1052)) 
-((-3092 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *7 *2)) (-4 *7 (-1047)) (-4 *2 (-1047)) (-14 *5 (-763)) (-14 *6 (-763)) (-4 *8 (-230 *6 *7)) (-4 *9 (-230 *5 *7)) (-4 *10 (-230 *6 *2)) (-4 *11 (-230 *5 *2)) (-5 *1 (-1052 *5 *6 *7 *8 *9 *4 *2 *10 *11 *12)) (-4 *4 (-1050 *5 *6 *7 *8 *9)) (-4 *12 (-1050 *5 *6 *2 *10 *11)))) (-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *10 *7)) (-4 *7 (-1047)) (-4 *10 (-1047)) (-14 *5 (-763)) (-14 *6 (-763)) (-4 *8 (-230 *6 *7)) (-4 *9 (-230 *5 *7)) (-4 *2 (-1050 *5 *6 *10 *11 *12)) (-5 *1 (-1052 *5 *6 *7 *8 *9 *4 *10 *11 *12 *2)) (-4 *4 (-1050 *5 *6 *7 *8 *9)) (-4 *11 (-230 *6 *10)) (-4 *12 (-230 *5 *10))))) 
-(-10 -7 (-15 -2795 (|#10| (-1 |#7| |#3|) |#6|)) (-15 -3092 (|#7| (-1 |#7| |#3| |#7|) |#6| |#7|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-3056 (($) 17 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ |#1|) 22))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-3560 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3691 (((-121) $) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-4490 (($) NIL T CONST)) (-3912 (($ $) 40 (|has| |#3| (-301)))) (-2228 (((-232 |#2| |#3|) $ (-568)) 29)) (-3938 (($ (-679 |#3|)) 38)) (-2371 (((-763) $) 42 (|has| |#3| (-558)))) (-2069 ((|#3| $ (-568) (-568)) NIL)) (-3317 (((-634 |#3|) $) NIL (|has| $ (-6 -4521)))) (-3344 (((-763) $) 44 (|has| |#3| (-558)))) (-2934 (((-634 (-232 |#1| |#3|)) $) 48 (|has| |#3| (-558)))) (-2241 (((-763) $) NIL)) (-1901 (((-763) $) NIL)) (-3791 (((-121) $ (-763)) NIL)) (-3139 (((-568) $) NIL)) (-1343 (((-568) $) NIL)) (-4406 (((-634 |#3|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#3| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#3| (-1090))))) (-3405 (((-568) $) NIL)) (-2801 (((-568) $) NIL)) (-2271 (($ (-634 (-634 |#3|))) 24)) (-2253 (($ (-1 |#3| |#3|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#3| |#3|) $) NIL) (($ (-1 |#3| |#3| |#3|) $ $) NIL)) (-1843 (((-634 (-634 |#3|)) $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2597 (((-3 $ "failed") $ |#3|) NIL (|has| |#3| (-558)))) (-3951 (((-121) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 |#3|) (-634 |#3|)) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ |#3| |#3|) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ (-288 |#3|)) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ (-634 (-288 |#3|))) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#3| $ (-568) (-568)) NIL) ((|#3| $ (-568) (-568) |#3|) NIL)) (-3108 (((-139)) 51 (|has| |#3| (-365)))) (-4322 (((-121) $) NIL)) (-4170 (((-763) |#3| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#3| (-1090)))) (((-763) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4521)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) 60 (|has| |#3| (-609 (-541))))) (-2522 (((-232 |#1| |#3|) $ (-568)) 33)) (-2747 (((-850) $) 16) (((-679 |#3|) $) 35)) (-3437 (((-121) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4521)))) (-2675 (((-121) $) NIL)) (-3058 (($) 13 T CONST)) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ |#3|) NIL (|has| |#3| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ |#3| $) NIL) (($ $ |#3|) NIL)) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-1051 |#1| |#2| |#3|) (-13 (-1050 |#1| |#2| |#3| (-232 |#2| |#3|) (-232 |#1| |#3|)) (-608 (-679 |#3|)) (-10 -8 (IF (|has| |#3| (-365)) (-6 (-1251 |#3|)) |noBranch|) (IF (|has| |#3| (-609 (-541))) (-6 (-609 (-541))) |noBranch|) (-15 -3938 ($ (-679 |#3|))) (-15 -2747 ((-679 |#3|) $)))) (-763) (-763) (-1047)) (T -1051)) 
+((-2747 (*1 *2 *1) (-12 (-5 *2 (-679 *5)) (-5 *1 (-1051 *3 *4 *5)) (-14 *3 (-763)) (-14 *4 (-763)) (-4 *5 (-1047)))) (-3938 (*1 *1 *2) (-12 (-5 *2 (-679 *5)) (-4 *5 (-1047)) (-5 *1 (-1051 *3 *4 *5)) (-14 *3 (-763)) (-14 *4 (-763))))) 
+(-13 (-1050 |#1| |#2| |#3| (-232 |#2| |#3|) (-232 |#1| |#3|)) (-608 (-679 |#3|)) (-10 -8 (IF (|has| |#3| (-365)) (-6 (-1251 |#3|)) |noBranch|) (IF (|has| |#3| (-609 (-541))) (-6 (-609 (-541))) |noBranch|) (-15 -3938 ($ (-679 |#3|))) (-15 -2747 ((-679 |#3|) $)))) 
+((-3094 ((|#7| (-1 |#7| |#3| |#7|) |#6| |#7|) 34)) (-2797 ((|#10| (-1 |#7| |#3|) |#6|) 32))) 
+(((-1052 |#1| |#2| |#3| |#4| |#5| |#6| |#7| |#8| |#9| |#10|) (-10 -7 (-15 -2797 (|#10| (-1 |#7| |#3|) |#6|)) (-15 -3094 (|#7| (-1 |#7| |#3| |#7|) |#6| |#7|))) (-763) (-763) (-1047) (-230 |#2| |#3|) (-230 |#1| |#3|) (-1050 |#1| |#2| |#3| |#4| |#5|) (-1047) (-230 |#2| |#7|) (-230 |#1| |#7|) (-1050 |#1| |#2| |#7| |#8| |#9|)) (T -1052)) 
+((-3094 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *7 *2)) (-4 *7 (-1047)) (-4 *2 (-1047)) (-14 *5 (-763)) (-14 *6 (-763)) (-4 *8 (-230 *6 *7)) (-4 *9 (-230 *5 *7)) (-4 *10 (-230 *6 *2)) (-4 *11 (-230 *5 *2)) (-5 *1 (-1052 *5 *6 *7 *8 *9 *4 *2 *10 *11 *12)) (-4 *4 (-1050 *5 *6 *7 *8 *9)) (-4 *12 (-1050 *5 *6 *2 *10 *11)))) (-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *10 *7)) (-4 *7 (-1047)) (-4 *10 (-1047)) (-14 *5 (-763)) (-14 *6 (-763)) (-4 *8 (-230 *6 *7)) (-4 *9 (-230 *5 *7)) (-4 *2 (-1050 *5 *6 *10 *11 *12)) (-5 *1 (-1052 *5 *6 *7 *8 *9 *4 *10 *11 *12 *2)) (-4 *4 (-1050 *5 *6 *7 *8 *9)) (-4 *11 (-230 *6 *10)) (-4 *12 (-230 *5 *10))))) 
+(-10 -7 (-15 -2797 (|#10| (-1 |#7| |#3|) |#6|)) (-15 -3094 (|#7| (-1 |#7| |#3| |#7|) |#6| |#7|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-3058 (($) 17 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ |#1|) 22))) 
 (((-1053 |#1|) (-1275) (-1054)) (T -1053)) 
 ((* (*1 *1 *1 *2) (-12 (-4 *1 (-1053 *2)) (-4 *2 (-1054))))) 
 (-13 (-21) (-10 -8 (-15 * ($ $ |t#1|)))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-137) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-1887 (($ $ (-917)) 25)) (-3056 (($) 17 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-1889 (($ $ (-917)) 25)) (-3058 (($) 17 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
 (((-1054) (-1275)) (T -1054)) 
 NIL 
 (-13 (-21) (-1102)) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-137) . T) ((-608 (-850)) . T) ((-1102) . T) ((-1090) . T)) 
-((-2617 (($ $) 16)) (-3047 (($ $) 22)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 49)) (-2657 (($ $) 24)) (-3880 (($ $) 11)) (-1519 (($ $) 38)) (-4278 (((-381) $) NIL) (((-215) $) NIL) (((-887 (-381)) $) 33)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) 28) (($ (-568)) NIL) (($ (-409 (-568))) 28)) (-4078 (((-763)) 8)) (-2285 (($ $) 39))) 
-(((-1055 |#1|) (-10 -8 (-15 -3047 (|#1| |#1|)) (-15 -2617 (|#1| |#1|)) (-15 -3880 (|#1| |#1|)) (-15 -1519 (|#1| |#1|)) (-15 -2285 (|#1| |#1|)) (-15 -2657 (|#1| |#1|)) (-15 -4410 ((-884 (-381) |#1|) |#1| (-887 (-381)) (-884 (-381) |#1|))) (-15 -4278 ((-887 (-381)) |#1|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -2745 (|#1| (-568))) (-15 -4278 ((-215) |#1|)) (-15 -4278 ((-381) |#1|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -2745 (|#1| |#1|)) (-15 -2745 (|#1| (-568))) (-15 -4078 ((-763))) (-15 -2745 ((-850) |#1|))) (-1056)) (T -1055)) 
-((-4078 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1055 *3)) (-4 *3 (-1056))))) 
-(-10 -8 (-15 -3047 (|#1| |#1|)) (-15 -2617 (|#1| |#1|)) (-15 -3880 (|#1| |#1|)) (-15 -1519 (|#1| |#1|)) (-15 -2285 (|#1| |#1|)) (-15 -2657 (|#1| |#1|)) (-15 -4410 ((-884 (-381) |#1|) |#1| (-887 (-381)) (-884 (-381) |#1|))) (-15 -4278 ((-887 (-381)) |#1|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -2745 (|#1| (-568))) (-15 -4278 ((-215) |#1|)) (-15 -4278 ((-381) |#1|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -2745 (|#1| |#1|)) (-15 -2745 (|#1| (-568))) (-15 -4078 ((-763))) (-15 -2745 ((-850) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-1492 (((-568) $) 85)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-2617 (($ $) 83)) (-3134 (((-3 $ "failed") $ $) 18)) (-4305 (($ $) 71)) (-1678 (((-420 $) $) 70)) (-1902 (($ $) 93)) (-1497 (((-121) $ $) 57)) (-3662 (((-568) $) 110)) (-2671 (($) 16 T CONST)) (-3047 (($ $) 82)) (-3666 (((-3 (-568) "failed") $) 98) (((-3 (-409 (-568)) "failed") $) 95)) (-2854 (((-568) $) 97) (((-409 (-568)) $) 94)) (-2401 (($ $ $) 53)) (-2925 (((-3 $ "failed") $) 33)) (-2412 (($ $ $) 54)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 49)) (-3927 (((-121) $) 69)) (-2033 (((-121) $) 108)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 89)) (-2735 (((-121) $) 30)) (-4044 (($ $ (-568)) 92)) (-2657 (($ $) 88)) (-2245 (((-121) $) 109)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-2521 (($ $ $) 107)) (-3268 (($ $ $) 106)) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-2081 (($ $) 68)) (-4022 (((-1108) $) 10)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-3880 (($ $) 84)) (-1519 (($ $) 86)) (-3848 (((-420 $) $) 72)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2595 (((-3 $ "failed") $ $) 41)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-2709 (((-763) $) 56)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 55)) (-4278 (((-381) $) 101) (((-215) $) 100) (((-887 (-381)) $) 90)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63) (($ (-568)) 99) (($ (-409 (-568))) 96)) (-4078 (((-763)) 28)) (-2285 (($ $) 87)) (-1826 (((-121) $ $) 38)) (-2897 (($ $) 111)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1751 (((-121) $ $) 104)) (-1738 (((-121) $ $) 103)) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 105)) (-1732 (((-121) $ $) 102)) (-1779 (($ $ $) 62)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66) (($ $ (-409 (-568))) 91)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64))) 
+((-4179 (($ $) 16)) (-2252 (($ $) 22)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 49)) (-4417 (($ $) 24)) (-1999 (($ $) 11)) (-4115 (($ $) 38)) (-4280 (((-381) $) NIL) (((-215) $) NIL) (((-887 (-381)) $) 33)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL) (($ (-409 (-568))) 28) (($ (-568)) NIL) (($ (-409 (-568))) 28)) (-3425 (((-763)) 8)) (-3520 (($ $) 39))) 
+(((-1055 |#1|) (-10 -8 (-15 -2252 (|#1| |#1|)) (-15 -4179 (|#1| |#1|)) (-15 -1999 (|#1| |#1|)) (-15 -4115 (|#1| |#1|)) (-15 -3520 (|#1| |#1|)) (-15 -4417 (|#1| |#1|)) (-15 -1519 ((-884 (-381) |#1|) |#1| (-887 (-381)) (-884 (-381) |#1|))) (-15 -4280 ((-887 (-381)) |#1|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -2747 (|#1| (-568))) (-15 -4280 ((-215) |#1|)) (-15 -4280 ((-381) |#1|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -2747 (|#1| |#1|)) (-15 -2747 (|#1| (-568))) (-15 -3425 ((-763))) (-15 -2747 ((-850) |#1|))) (-1056)) (T -1055)) 
+((-3425 (*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1055 *3)) (-4 *3 (-1056))))) 
+(-10 -8 (-15 -2252 (|#1| |#1|)) (-15 -4179 (|#1| |#1|)) (-15 -1999 (|#1| |#1|)) (-15 -4115 (|#1| |#1|)) (-15 -3520 (|#1| |#1|)) (-15 -4417 (|#1| |#1|)) (-15 -1519 ((-884 (-381) |#1|) |#1| (-887 (-381)) (-884 (-381) |#1|))) (-15 -4280 ((-887 (-381)) |#1|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -2747 (|#1| (-568))) (-15 -4280 ((-215) |#1|)) (-15 -4280 ((-381) |#1|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -2747 (|#1| |#1|)) (-15 -2747 (|#1| (-568))) (-15 -3425 ((-763))) (-15 -2747 ((-850) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2563 (((-568) $) 85)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-4179 (($ $) 83)) (-2689 (((-3 $ "failed") $ $) 18)) (-3045 (($ $) 71)) (-3498 (((-420 $) $) 70)) (-1904 (($ $) 93)) (-2589 (((-121) $ $) 57)) (-3337 (((-568) $) 110)) (-4490 (($) 16 T CONST)) (-2252 (($ $) 82)) (-3668 (((-3 (-568) "failed") $) 98) (((-3 (-409 (-568)) "failed") $) 95)) (-2857 (((-568) $) 97) (((-409 (-568)) $) 94)) (-2403 (($ $ $) 53)) (-2902 (((-3 $ "failed") $) 33)) (-2414 (($ $ $) 54)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 49)) (-2197 (((-121) $) 69)) (-1436 (((-121) $) 108)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 89)) (-1598 (((-121) $) 30)) (-1550 (($ $ (-568)) 92)) (-4417 (($ $) 88)) (-2859 (((-121) $) 109)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-1732 (($ $ $) 107)) (-2047 (($ $ $) 106)) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-2083 (($ $) 68)) (-4025 (((-1108) $) 10)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-1999 (($ $) 84)) (-4115 (($ $) 86)) (-3850 (((-420 $) $) 72)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2597 (((-3 $ "failed") $ $) 41)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-1466 (((-763) $) 56)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 55)) (-4280 (((-381) $) 101) (((-215) $) 100) (((-887 (-381)) $) 90)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63) (($ (-568)) 99) (($ (-409 (-568))) 96)) (-3425 (((-763)) 28)) (-3520 (($ $) 87)) (-2273 (((-121) $ $) 38)) (-2811 (($ $) 111)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1753 (((-121) $ $) 104)) (-1740 (((-121) $ $) 103)) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 105)) (-1734 (((-121) $ $) 102)) (-1781 (($ $ $) 62)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66) (($ $ (-409 (-568))) 91)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64))) 
 (((-1056) (-1275)) (T -1056)) 
-((-2897 (*1 *1 *1) (-4 *1 (-1056))) (-2657 (*1 *1 *1) (-4 *1 (-1056))) (-2285 (*1 *1 *1) (-4 *1 (-1056))) (-1519 (*1 *1 *1) (-4 *1 (-1056))) (-1492 (*1 *2 *1) (-12 (-4 *1 (-1056)) (-5 *2 (-568)))) (-3880 (*1 *1 *1) (-4 *1 (-1056))) (-2617 (*1 *1 *1) (-4 *1 (-1056))) (-3047 (*1 *1 *1) (-4 *1 (-1056)))) 
-(-13 (-365) (-840) (-1021) (-1037 (-568)) (-1037 (-409 (-568))) (-1002) (-609 (-887 (-381))) (-881 (-381)) (-150) (-10 -8 (-15 -2657 ($ $)) (-15 -2285 ($ $)) (-15 -1519 ($ $)) (-15 -1492 ((-568) $)) (-15 -3880 ($ $)) (-15 -2617 ($ $)) (-15 -3047 ($ $)) (-15 -2897 ($ $)))) 
+((-2811 (*1 *1 *1) (-4 *1 (-1056))) (-4417 (*1 *1 *1) (-4 *1 (-1056))) (-3520 (*1 *1 *1) (-4 *1 (-1056))) (-4115 (*1 *1 *1) (-4 *1 (-1056))) (-2563 (*1 *2 *1) (-12 (-4 *1 (-1056)) (-5 *2 (-568)))) (-1999 (*1 *1 *1) (-4 *1 (-1056))) (-4179 (*1 *1 *1) (-4 *1 (-1056))) (-2252 (*1 *1 *1) (-4 *1 (-1056)))) 
+(-13 (-365) (-840) (-1021) (-1037 (-568)) (-1037 (-409 (-568))) (-1002) (-609 (-887 (-381))) (-881 (-381)) (-150) (-10 -8 (-15 -4417 ($ $)) (-15 -3520 ($ $)) (-15 -4115 ($ $)) (-15 -2563 ((-568) $)) (-15 -1999 ($ $)) (-15 -4179 ($ $)) (-15 -2252 ($ $)) (-15 -2811 ($ $)))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 $ $) . T) ((-137) . T) ((-150) . T) ((-608 (-850)) . T) ((-172) . T) ((-609 (-215)) . T) ((-609 (-381)) . T) ((-609 (-887 (-381))) . T) ((-238) . T) ((-285) . T) ((-301) . T) ((-365) . T) ((-453) . T) ((-558) . T) ((-637 (-409 (-568))) . T) ((-637 $) . T) ((-707 (-409 (-568))) . T) ((-707 $) . T) ((-716) . T) ((-786) . T) ((-787) . T) ((-789) . T) ((-790) . T) ((-840) . T) ((-842) . T) ((-881 (-381)) . T) ((-916) . T) ((-1002) . T) ((-1021) . T) ((-1037 (-409 (-568))) . T) ((-1037 (-568)) . T) ((-1053 (-409 (-568))) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1199) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) |#2| $) 23)) (-3983 ((|#1| $) 10)) (-3662 (((-568) |#2| $) 88)) (-2932 (((-3 $ "failed") |#2| (-917)) 58)) (-3284 ((|#1| $) 28)) (-3820 ((|#1| |#2| $ |#1|) 37)) (-4069 (($ $) 25)) (-2925 (((-3 |#2| "failed") |#2| $) 87)) (-2033 (((-121) |#2| $) NIL)) (-2245 (((-121) |#2| $) NIL)) (-2707 (((-121) |#2| $) 24)) (-4279 ((|#1| $) 89)) (-3028 ((|#1| $) 27)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-1626 ((|#2| $) 79)) (-2745 (((-850) $) 71)) (-3996 ((|#1| |#2| $ |#1|) 38)) (-4309 (((-634 $) |#2|) 60)) (-1717 (((-121) $ $) 74))) 
-(((-1057 |#1| |#2|) (-13 (-1063 |#1| |#2|) (-10 -8 (-15 -3028 (|#1| $)) (-15 -3284 (|#1| $)) (-15 -3983 (|#1| $)) (-15 -4279 (|#1| $)) (-15 -4069 ($ $)) (-15 -2707 ((-121) |#2| $)) (-15 -3820 (|#1| |#2| $ |#1|)))) (-13 (-840) (-365)) (-1219 |#1|)) (T -1057)) 
-((-3820 (*1 *2 *3 *1 *2) (-12 (-4 *2 (-13 (-840) (-365))) (-5 *1 (-1057 *2 *3)) (-4 *3 (-1219 *2)))) (-3028 (*1 *2 *1) (-12 (-4 *2 (-13 (-840) (-365))) (-5 *1 (-1057 *2 *3)) (-4 *3 (-1219 *2)))) (-3284 (*1 *2 *1) (-12 (-4 *2 (-13 (-840) (-365))) (-5 *1 (-1057 *2 *3)) (-4 *3 (-1219 *2)))) (-3983 (*1 *2 *1) (-12 (-4 *2 (-13 (-840) (-365))) (-5 *1 (-1057 *2 *3)) (-4 *3 (-1219 *2)))) (-4279 (*1 *2 *1) (-12 (-4 *2 (-13 (-840) (-365))) (-5 *1 (-1057 *2 *3)) (-4 *3 (-1219 *2)))) (-4069 (*1 *1 *1) (-12 (-4 *2 (-13 (-840) (-365))) (-5 *1 (-1057 *2 *3)) (-4 *3 (-1219 *2)))) (-2707 (*1 *2 *3 *1) (-12 (-4 *4 (-13 (-840) (-365))) (-5 *2 (-121)) (-5 *1 (-1057 *4 *3)) (-4 *3 (-1219 *4))))) 
-(-13 (-1063 |#1| |#2|) (-10 -8 (-15 -3028 (|#1| $)) (-15 -3284 (|#1| $)) (-15 -3983 (|#1| $)) (-15 -4279 (|#1| $)) (-15 -4069 ($ $)) (-15 -2707 ((-121) |#2| $)) (-15 -3820 (|#1| |#2| $ |#1|)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-1877 (($ $ $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2690 (($ $ $ $) NIL)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1497 (((-121) $ $) NIL)) (-3662 (((-568) $) NIL)) (-1870 (($ $ $) NIL)) (-2671 (($) NIL T CONST)) (-3630 (($ (-1161)) 10) (($ (-568)) 7)) (-3666 (((-3 (-568) "failed") $) NIL)) (-2854 (((-568) $) NIL)) (-2401 (($ $ $) NIL)) (-3164 (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-679 (-568)) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1642 (((-3 (-409 (-568)) "failed") $) NIL)) (-2688 (((-121) $) NIL)) (-2425 (((-409 (-568)) $) NIL)) (-1731 (($) NIL) (($ $) NIL)) (-2412 (($ $ $) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-1457 (($ $ $ $) NIL)) (-1283 (($ $ $) NIL)) (-2033 (((-121) $) NIL)) (-2413 (($ $ $) NIL)) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL)) (-2735 (((-121) $) NIL)) (-1825 (((-121) $) NIL)) (-3038 (((-3 $ "failed") $) NIL)) (-2245 (((-121) $) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3326 (($ $ $ $) NIL)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-3651 (($ $) NIL)) (-3678 (($ $) NIL)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2110 (($ $ $) NIL)) (-4434 (($) NIL T CONST)) (-3850 (($ $) NIL)) (-4022 (((-1108) $) NIL) (($ $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) NIL) (($ (-634 $)) NIL)) (-2427 (($ $) NIL)) (-3848 (((-420 $) $) NIL)) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3277 (((-121) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-4189 (($ $ (-763)) NIL) (($ $) NIL)) (-2349 (($ $) NIL)) (-3863 (($ $) NIL)) (-4278 (((-568) $) 16) (((-541) $) NIL) (((-887 (-568)) $) NIL) (((-381) $) NIL) (((-215) $) NIL) (($ (-1161)) 9)) (-2745 (((-850) $) 20) (($ (-568)) 6) (($ $) NIL) (($ (-568)) 6)) (-4078 (((-763)) NIL)) (-2791 (((-121) $ $) NIL)) (-2787 (($ $ $) NIL)) (-1461 (($) NIL)) (-1826 (((-121) $ $) NIL)) (-4419 (($ $ $ $) NIL)) (-2897 (($ $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $ (-763)) NIL) (($ $) NIL)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) NIL)) (-1773 (($ $) 19) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL))) 
-(((-1058) (-13 (-550) (-10 -8 (-6 -4506) (-6 -4511) (-6 -4507) (-15 -4278 ($ (-1161))) (-15 -3630 ($ (-1161))) (-15 -3630 ($ (-568)))))) (T -1058)) 
-((-4278 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1058)))) (-3630 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1058)))) (-3630 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1058))))) 
-(-13 (-550) (-10 -8 (-6 -4506) (-6 -4511) (-6 -4507) (-15 -4278 ($ (-1161))) (-15 -3630 ($ (-1161))) (-15 -3630 ($ (-568))))) 
-((-2447 (((-121) $ $) NIL (-2198 (|has| (-57) (-1090)) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090))))) (-2986 (($) NIL) (($ (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))))) NIL)) (-1868 (((-1249) $ (-1161) (-1161)) NIL (|has| $ (-6 -4520)))) (-2510 (((-121) $ (-763)) NIL)) (-2591 (($) 9)) (-2436 (((-57) $ (-1161) (-57)) NIL)) (-1814 (($ $) 23)) (-3930 (($ $) 21)) (-4077 (($ $) 20)) (-3567 (($ $) 22)) (-2106 (($ $) 25)) (-2995 (($ $) 26)) (-3249 (($ $) 19)) (-4223 (($ $) 24)) (-3507 (($ (-1 (-121) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) 18 (|has| $ (-6 -4519)))) (-2674 (((-3 (-57) "failed") (-1161) $) 34)) (-2671 (($) NIL T CONST)) (-3879 (($) 7)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090))))) (-3405 (($ (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) $) 46 (|has| $ (-6 -4519))) (($ (-1 (-121) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519))) (((-3 (-57) "failed") (-1161) $) NIL)) (-4328 (($ (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090)))) (($ (-1 (-121) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519)))) (-3092 (((-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $ (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090)))) (((-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $ (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) NIL (|has| $ (-6 -4519))) (((-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519)))) (-3957 (((-3 (-1143) "failed") $ (-1143) (-568)) 59)) (-3989 (((-57) $ (-1161) (-57)) NIL (|has| $ (-6 -4520)))) (-2602 (((-57) $ (-1161)) NIL)) (-4360 (((-634 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519))) (((-634 (-57)) $) NIL (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-1161) $) NIL (|has| (-1161) (-842)))) (-1979 (((-634 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) 28 (|has| $ (-6 -4519))) (((-634 (-57)) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090)))) (((-121) (-57) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-57) (-1090))))) (-2223 (((-1161) $) NIL (|has| (-1161) (-842)))) (-3674 (($ (-1 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4520))) (($ (-1 (-57) (-57)) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL) (($ (-1 (-57) (-57)) $) NIL) (($ (-1 (-57) (-57) (-57)) $ $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (-2198 (|has| (-57) (-1090)) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090))))) (-1946 (((-634 (-1161)) $) NIL)) (-3548 (((-121) (-1161) $) NIL)) (-1890 (((-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) $) NIL)) (-4450 (($ (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) $) 37)) (-4174 (((-634 (-1161)) $) NIL)) (-3578 (((-121) (-1161) $) NIL)) (-4022 (((-1108) $) NIL (-2198 (|has| (-57) (-1090)) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090))))) (-2404 (((-381) $ (-1161)) 45)) (-2679 (((-634 (-1143)) $ (-1143)) 60)) (-3876 (((-57) $) NIL (|has| (-1161) (-842)))) (-3775 (((-3 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) "failed") (-1 (-121) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL)) (-3724 (($ $ (-57)) NIL (|has| $ (-6 -4520)))) (-1315 (((-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) $) NIL)) (-1387 (((-121) (-1 (-121) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))))) NIL (-12 (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-303 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))))) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090)))) (($ $ (-288 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))))) NIL (-12 (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-303 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))))) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090)))) (($ $ (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) NIL (-12 (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-303 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))))) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090)))) (($ $ (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))))) NIL (-12 (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-303 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))))) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090)))) (($ $ (-634 (-57)) (-634 (-57))) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090)))) (($ $ (-57) (-57)) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090)))) (($ $ (-288 (-57))) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090)))) (($ $ (-634 (-288 (-57)))) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) (-57) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-57) (-1090))))) (-2041 (((-634 (-57)) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 (((-57) $ (-1161)) NIL) (((-57) $ (-1161) (-57)) NIL)) (-2085 (($) NIL) (($ (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))))) NIL)) (-3412 (($ $ (-1161)) 47)) (-4168 (((-763) (-1 (-121) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519))) (((-763) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090)))) (((-763) (-57) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-57) (-1090)))) (((-763) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4519)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-609 (-541))))) (-4287 (($ (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))))) 30)) (-2768 (($ $ $) 31)) (-2745 (((-850) $) NIL (-2198 (|has| (-57) (-1090)) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090))))) (-4453 (($ $ (-1161) (-381)) 43)) (-1342 (($ $ (-1161) (-381)) 44)) (-2367 (($ (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))))) NIL)) (-1319 (((-121) (-1 (-121) (-2 (|:| -3649 (-1161)) (|:| -4083 (-57)))) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) NIL (-2198 (|has| (-57) (-1090)) (|has| (-2 (|:| -3649 (-1161)) (|:| -4083 (-57))) (-1090))))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-1059) (-13 (-1172 (-1161) (-57)) (-10 -8 (-15 -2768 ($ $ $)) (-15 -3879 ($)) (-15 -3249 ($ $)) (-15 -4077 ($ $)) (-15 -3930 ($ $)) (-15 -3567 ($ $)) (-15 -4223 ($ $)) (-15 -1814 ($ $)) (-15 -2106 ($ $)) (-15 -2995 ($ $)) (-15 -4453 ($ $ (-1161) (-381))) (-15 -1342 ($ $ (-1161) (-381))) (-15 -2404 ((-381) $ (-1161))) (-15 -2679 ((-634 (-1143)) $ (-1143))) (-15 -3412 ($ $ (-1161))) (-15 -2591 ($)) (-15 -3957 ((-3 (-1143) "failed") $ (-1143) (-568))) (-6 -4519)))) (T -1059)) 
-((-2768 (*1 *1 *1 *1) (-5 *1 (-1059))) (-3879 (*1 *1) (-5 *1 (-1059))) (-3249 (*1 *1 *1) (-5 *1 (-1059))) (-4077 (*1 *1 *1) (-5 *1 (-1059))) (-3930 (*1 *1 *1) (-5 *1 (-1059))) (-3567 (*1 *1 *1) (-5 *1 (-1059))) (-4223 (*1 *1 *1) (-5 *1 (-1059))) (-1814 (*1 *1 *1) (-5 *1 (-1059))) (-2106 (*1 *1 *1) (-5 *1 (-1059))) (-2995 (*1 *1 *1) (-5 *1 (-1059))) (-4453 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-381)) (-5 *1 (-1059)))) (-1342 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-381)) (-5 *1 (-1059)))) (-2404 (*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-381)) (-5 *1 (-1059)))) (-2679 (*1 *2 *1 *3) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1059)) (-5 *3 (-1143)))) (-3412 (*1 *1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1059)))) (-2591 (*1 *1) (-5 *1 (-1059))) (-3957 (*1 *2 *1 *2 *3) (|partial| -12 (-5 *2 (-1143)) (-5 *3 (-568)) (-5 *1 (-1059))))) 
-(-13 (-1172 (-1161) (-57)) (-10 -8 (-15 -2768 ($ $ $)) (-15 -3879 ($)) (-15 -3249 ($ $)) (-15 -4077 ($ $)) (-15 -3930 ($ $)) (-15 -3567 ($ $)) (-15 -4223 ($ $)) (-15 -1814 ($ $)) (-15 -2106 ($ $)) (-15 -2995 ($ $)) (-15 -4453 ($ $ (-1161) (-381))) (-15 -1342 ($ $ (-1161) (-381))) (-15 -2404 ((-381) $ (-1161))) (-15 -2679 ((-634 (-1143)) $ (-1143))) (-15 -3412 ($ $ (-1161))) (-15 -2591 ($)) (-15 -3957 ((-3 (-1143) "failed") $ (-1143) (-568))) (-6 -4519))) 
-((-2796 (($ $) 45)) (-3653 (((-121) $ $) 74)) (-3666 (((-3 |#2| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 (-568) "failed") $) NIL) (((-3 |#4| "failed") $) NIL) (((-3 $ "failed") (-953 (-409 (-568)))) 226) (((-3 $ "failed") (-953 (-568))) 225) (((-3 $ "failed") (-953 |#2|)) 228)) (-2854 ((|#2| $) NIL) (((-409 (-568)) $) NIL) (((-568) $) NIL) ((|#4| $) NIL) (($ (-953 (-409 (-568)))) 214) (($ (-953 (-568))) 210) (($ (-953 |#2|)) 230)) (-2114 (($ $) NIL) (($ $ |#4|) 43)) (-1281 (((-121) $ $) 111) (((-121) $ (-634 $)) 112)) (-4054 (((-121) $) 56)) (-4144 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 106)) (-2053 (($ $) 137)) (-3069 (($ $) 133)) (-3431 (($ $) 132)) (-4293 (($ $ $) 79) (($ $ $ |#4|) 84)) (-2875 (($ $ $) 82) (($ $ $ |#4|) 86)) (-1362 (((-121) $ $) 120) (((-121) $ (-634 $)) 121)) (-2356 ((|#4| $) 33)) (-2507 (($ $ $) 109)) (-2278 (((-121) $) 55)) (-3838 (((-763) $) 35)) (-3290 (($ $) 151)) (-2297 (($ $) 148)) (-4093 (((-634 $) $) 68)) (-2429 (($ $) 57)) (-2111 (($ $) 144)) (-2380 (((-634 $) $) 65)) (-2104 (($ $) 59)) (-2102 ((|#2| $) NIL) (($ $ |#4|) 38)) (-2280 (((-2 (|:| |polnum| $) (|:| |polden| $) (|:| -3741 (-763))) $ $) 110)) (-3547 (((-2 (|:| -2348 $) (|:| |gap| (-763)) (|:| -3961 $) (|:| -1500 $)) $ $) 107) (((-2 (|:| -2348 $) (|:| |gap| (-763)) (|:| -3961 $) (|:| -1500 $)) $ $ |#4|) 108)) (-2409 (((-2 (|:| -2348 $) (|:| |gap| (-763)) (|:| -1500 $)) $ $) 103) (((-2 (|:| -2348 $) (|:| |gap| (-763)) (|:| -1500 $)) $ $ |#4|) 104)) (-3413 (($ $ $) 89) (($ $ $ |#4|) 94)) (-3774 (($ $ $) 90) (($ $ $ |#4|) 95)) (-1901 (((-634 $) $) 51)) (-1415 (((-121) $ $) 117) (((-121) $ (-634 $)) 118)) (-2682 (($ $ $) 102)) (-4434 (($ $) 37)) (-2644 (((-121) $ $) 72)) (-4347 (((-121) $ $) 113) (((-121) $ (-634 $)) 115)) (-4025 (($ $ $) 100)) (-1733 (($ $) 40)) (-2721 ((|#2| |#2| $) 141) (($ (-634 $)) NIL) (($ $ $) NIL)) (-3055 (($ $ |#2|) NIL) (($ $ $) 130)) (-4049 (($ $ |#2|) 125) (($ $ $) 128)) (-1595 (($ $) 48)) (-2734 (($ $) 52)) (-4278 (((-887 (-381)) $) NIL) (((-887 (-568)) $) NIL) (((-541) $) NIL) (($ (-953 (-409 (-568)))) 216) (($ (-953 (-568))) 212) (($ (-953 |#2|)) 227) (((-1143) $) 249) (((-953 |#2|) $) 161)) (-2745 (((-850) $) 30) (($ (-568)) NIL) (($ |#2|) NIL) (($ |#4|) NIL) (((-953 |#2|) $) 162) (($ (-409 (-568))) NIL) (($ $) NIL)) (-3601 (((-3 (-121) "failed") $ $) 71))) 
-(((-1060 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -2745 (|#1| |#1|)) (-15 -2721 (|#1| |#1| |#1|)) (-15 -2721 (|#1| (-634 |#1|))) (-15 -2745 (|#1| (-409 (-568)))) (-15 -2745 ((-953 |#2|) |#1|)) (-15 -4278 ((-953 |#2|) |#1|)) (-15 -4278 ((-1143) |#1|)) (-15 -3290 (|#1| |#1|)) (-15 -2297 (|#1| |#1|)) (-15 -2111 (|#1| |#1|)) (-15 -2053 (|#1| |#1|)) (-15 -2721 (|#2| |#2| |#1|)) (-15 -3055 (|#1| |#1| |#1|)) (-15 -4049 (|#1| |#1| |#1|)) (-15 -3055 (|#1| |#1| |#2|)) (-15 -4049 (|#1| |#1| |#2|)) (-15 -3069 (|#1| |#1|)) (-15 -3431 (|#1| |#1|)) (-15 -4278 (|#1| (-953 |#2|))) (-15 -2854 (|#1| (-953 |#2|))) (-15 -3666 ((-3 |#1| "failed") (-953 |#2|))) (-15 -4278 (|#1| (-953 (-568)))) (-15 -2854 (|#1| (-953 (-568)))) (-15 -3666 ((-3 |#1| "failed") (-953 (-568)))) (-15 -4278 (|#1| (-953 (-409 (-568))))) (-15 -2854 (|#1| (-953 (-409 (-568))))) (-15 -3666 ((-3 |#1| "failed") (-953 (-409 (-568))))) (-15 -2682 (|#1| |#1| |#1|)) (-15 -4025 (|#1| |#1| |#1|)) (-15 -2280 ((-2 (|:| |polnum| |#1|) (|:| |polden| |#1|) (|:| -3741 (-763))) |#1| |#1|)) (-15 -2507 (|#1| |#1| |#1|)) (-15 -4144 ((-2 (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1|)) (-15 -3547 ((-2 (|:| -2348 |#1|) (|:| |gap| (-763)) (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1| |#4|)) (-15 -3547 ((-2 (|:| -2348 |#1|) (|:| |gap| (-763)) (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1|)) (-15 -2409 ((-2 (|:| -2348 |#1|) (|:| |gap| (-763)) (|:| -1500 |#1|)) |#1| |#1| |#4|)) (-15 -2409 ((-2 (|:| -2348 |#1|) (|:| |gap| (-763)) (|:| -1500 |#1|)) |#1| |#1|)) (-15 -3774 (|#1| |#1| |#1| |#4|)) (-15 -3413 (|#1| |#1| |#1| |#4|)) (-15 -3774 (|#1| |#1| |#1|)) (-15 -3413 (|#1| |#1| |#1|)) (-15 -2875 (|#1| |#1| |#1| |#4|)) (-15 -4293 (|#1| |#1| |#1| |#4|)) (-15 -2875 (|#1| |#1| |#1|)) (-15 -4293 (|#1| |#1| |#1|)) (-15 -1362 ((-121) |#1| (-634 |#1|))) (-15 -1362 ((-121) |#1| |#1|)) (-15 -1415 ((-121) |#1| (-634 |#1|))) (-15 -1415 ((-121) |#1| |#1|)) (-15 -4347 ((-121) |#1| (-634 |#1|))) (-15 -4347 ((-121) |#1| |#1|)) (-15 -1281 ((-121) |#1| (-634 |#1|))) (-15 -1281 ((-121) |#1| |#1|)) (-15 -3653 ((-121) |#1| |#1|)) (-15 -2644 ((-121) |#1| |#1|)) (-15 -3601 ((-3 (-121) "failed") |#1| |#1|)) (-15 -4093 ((-634 |#1|) |#1|)) (-15 -2380 ((-634 |#1|) |#1|)) (-15 -2104 (|#1| |#1|)) (-15 -2429 (|#1| |#1|)) (-15 -4054 ((-121) |#1|)) (-15 -2278 ((-121) |#1|)) (-15 -2114 (|#1| |#1| |#4|)) (-15 -2102 (|#1| |#1| |#4|)) (-15 -2734 (|#1| |#1|)) (-15 -1901 ((-634 |#1|) |#1|)) (-15 -1595 (|#1| |#1|)) (-15 -2796 (|#1| |#1|)) (-15 -1733 (|#1| |#1|)) (-15 -4434 (|#1| |#1|)) (-15 -3838 ((-763) |#1|)) (-15 -2356 (|#4| |#1|)) (-15 -4278 ((-541) |#1|)) (-15 -4278 ((-887 (-568)) |#1|)) (-15 -4278 ((-887 (-381)) |#1|)) (-15 -2854 (|#4| |#1|)) (-15 -3666 ((-3 |#4| "failed") |#1|)) (-15 -2745 (|#1| |#4|)) (-15 -2102 (|#2| |#1|)) (-15 -2114 (|#1| |#1|)) (-15 -2854 ((-568) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2745 (|#1| |#2|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -2854 (|#2| |#1|)) (-15 -2745 (|#1| (-568))) (-15 -2745 ((-850) |#1|))) (-1061 |#2| |#3| |#4|) (-1047) (-788) (-842)) (T -1060)) 
-NIL 
-(-10 -8 (-15 -2745 (|#1| |#1|)) (-15 -2721 (|#1| |#1| |#1|)) (-15 -2721 (|#1| (-634 |#1|))) (-15 -2745 (|#1| (-409 (-568)))) (-15 -2745 ((-953 |#2|) |#1|)) (-15 -4278 ((-953 |#2|) |#1|)) (-15 -4278 ((-1143) |#1|)) (-15 -3290 (|#1| |#1|)) (-15 -2297 (|#1| |#1|)) (-15 -2111 (|#1| |#1|)) (-15 -2053 (|#1| |#1|)) (-15 -2721 (|#2| |#2| |#1|)) (-15 -3055 (|#1| |#1| |#1|)) (-15 -4049 (|#1| |#1| |#1|)) (-15 -3055 (|#1| |#1| |#2|)) (-15 -4049 (|#1| |#1| |#2|)) (-15 -3069 (|#1| |#1|)) (-15 -3431 (|#1| |#1|)) (-15 -4278 (|#1| (-953 |#2|))) (-15 -2854 (|#1| (-953 |#2|))) (-15 -3666 ((-3 |#1| "failed") (-953 |#2|))) (-15 -4278 (|#1| (-953 (-568)))) (-15 -2854 (|#1| (-953 (-568)))) (-15 -3666 ((-3 |#1| "failed") (-953 (-568)))) (-15 -4278 (|#1| (-953 (-409 (-568))))) (-15 -2854 (|#1| (-953 (-409 (-568))))) (-15 -3666 ((-3 |#1| "failed") (-953 (-409 (-568))))) (-15 -2682 (|#1| |#1| |#1|)) (-15 -4025 (|#1| |#1| |#1|)) (-15 -2280 ((-2 (|:| |polnum| |#1|) (|:| |polden| |#1|) (|:| -3741 (-763))) |#1| |#1|)) (-15 -2507 (|#1| |#1| |#1|)) (-15 -4144 ((-2 (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1|)) (-15 -3547 ((-2 (|:| -2348 |#1|) (|:| |gap| (-763)) (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1| |#4|)) (-15 -3547 ((-2 (|:| -2348 |#1|) (|:| |gap| (-763)) (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1|)) (-15 -2409 ((-2 (|:| -2348 |#1|) (|:| |gap| (-763)) (|:| -1500 |#1|)) |#1| |#1| |#4|)) (-15 -2409 ((-2 (|:| -2348 |#1|) (|:| |gap| (-763)) (|:| -1500 |#1|)) |#1| |#1|)) (-15 -3774 (|#1| |#1| |#1| |#4|)) (-15 -3413 (|#1| |#1| |#1| |#4|)) (-15 -3774 (|#1| |#1| |#1|)) (-15 -3413 (|#1| |#1| |#1|)) (-15 -2875 (|#1| |#1| |#1| |#4|)) (-15 -4293 (|#1| |#1| |#1| |#4|)) (-15 -2875 (|#1| |#1| |#1|)) (-15 -4293 (|#1| |#1| |#1|)) (-15 -1362 ((-121) |#1| (-634 |#1|))) (-15 -1362 ((-121) |#1| |#1|)) (-15 -1415 ((-121) |#1| (-634 |#1|))) (-15 -1415 ((-121) |#1| |#1|)) (-15 -4347 ((-121) |#1| (-634 |#1|))) (-15 -4347 ((-121) |#1| |#1|)) (-15 -1281 ((-121) |#1| (-634 |#1|))) (-15 -1281 ((-121) |#1| |#1|)) (-15 -3653 ((-121) |#1| |#1|)) (-15 -2644 ((-121) |#1| |#1|)) (-15 -3601 ((-3 (-121) "failed") |#1| |#1|)) (-15 -4093 ((-634 |#1|) |#1|)) (-15 -2380 ((-634 |#1|) |#1|)) (-15 -2104 (|#1| |#1|)) (-15 -2429 (|#1| |#1|)) (-15 -4054 ((-121) |#1|)) (-15 -2278 ((-121) |#1|)) (-15 -2114 (|#1| |#1| |#4|)) (-15 -2102 (|#1| |#1| |#4|)) (-15 -2734 (|#1| |#1|)) (-15 -1901 ((-634 |#1|) |#1|)) (-15 -1595 (|#1| |#1|)) (-15 -2796 (|#1| |#1|)) (-15 -1733 (|#1| |#1|)) (-15 -4434 (|#1| |#1|)) (-15 -3838 ((-763) |#1|)) (-15 -2356 (|#4| |#1|)) (-15 -4278 ((-541) |#1|)) (-15 -4278 ((-887 (-568)) |#1|)) (-15 -4278 ((-887 (-381)) |#1|)) (-15 -2854 (|#4| |#1|)) (-15 -3666 ((-3 |#4| "failed") |#1|)) (-15 -2745 (|#1| |#4|)) (-15 -2102 (|#2| |#1|)) (-15 -2114 (|#1| |#1|)) (-15 -2854 ((-568) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2745 (|#1| |#2|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -2854 (|#2| |#1|)) (-15 -2745 (|#1| (-568))) (-15 -2745 ((-850) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-2055 (((-634 |#3|) $) 108)) (-3839 (((-1157 $) $ |#3|) 123) (((-1157 |#1|) $) 122)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 85 (|has| |#1| (-558)))) (-2227 (($ $) 86 (|has| |#1| (-558)))) (-1573 (((-121) $) 88 (|has| |#1| (-558)))) (-2773 (((-763) $) 110) (((-763) $ (-634 |#3|)) 109)) (-2796 (($ $) 250)) (-3653 (((-121) $ $) 236)) (-3134 (((-3 $ "failed") $ $) 18)) (-3809 (($ $ $) 195 (|has| |#1| (-558)))) (-3909 (((-634 $) $ $) 190 (|has| |#1| (-558)))) (-1750 (((-420 (-1157 $)) (-1157 $)) 98 (|has| |#1| (-904)))) (-4305 (($ $) 96 (|has| |#1| (-453)))) (-1678 (((-420 $) $) 95 (|has| |#1| (-453)))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 101 (|has| |#1| (-904)))) (-2671 (($) 16 T CONST)) (-3666 (((-3 |#1| "failed") $) 162) (((-3 (-409 (-568)) "failed") $) 160 (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) 158 (|has| |#1| (-1037 (-568)))) (((-3 |#3| "failed") $) 134) (((-3 $ "failed") (-953 (-409 (-568)))) 210 (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#3| (-609 (-1161))))) (((-3 $ "failed") (-953 (-568))) 207 (-2198 (-12 (-3044 (|has| |#1| (-43 (-409 (-568))))) (|has| |#1| (-43 (-568))) (|has| |#3| (-609 (-1161)))) (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#3| (-609 (-1161)))))) (((-3 $ "failed") (-953 |#1|)) 204 (-2198 (-12 (-3044 (|has| |#1| (-43 (-409 (-568))))) (-3044 (|has| |#1| (-43 (-568)))) (|has| |#3| (-609 (-1161)))) (-12 (-3044 (|has| |#1| (-550))) (-3044 (|has| |#1| (-43 (-409 (-568))))) (|has| |#1| (-43 (-568))) (|has| |#3| (-609 (-1161)))) (-12 (-3044 (|has| |#1| (-993 (-568)))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#3| (-609 (-1161))))))) (-2854 ((|#1| $) 163) (((-409 (-568)) $) 159 (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) 157 (|has| |#1| (-1037 (-568)))) ((|#3| $) 133) (($ (-953 (-409 (-568)))) 209 (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#3| (-609 (-1161))))) (($ (-953 (-568))) 206 (-2198 (-12 (-3044 (|has| |#1| (-43 (-409 (-568))))) (|has| |#1| (-43 (-568))) (|has| |#3| (-609 (-1161)))) (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#3| (-609 (-1161)))))) (($ (-953 |#1|)) 203 (-2198 (-12 (-3044 (|has| |#1| (-43 (-409 (-568))))) (-3044 (|has| |#1| (-43 (-568)))) (|has| |#3| (-609 (-1161)))) (-12 (-3044 (|has| |#1| (-550))) (-3044 (|has| |#1| (-43 (-409 (-568))))) (|has| |#1| (-43 (-568))) (|has| |#3| (-609 (-1161)))) (-12 (-3044 (|has| |#1| (-993 (-568)))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#3| (-609 (-1161))))))) (-4265 (($ $ $ |#3|) 106 (|has| |#1| (-172))) (($ $ $) 191 (|has| |#1| (-558)))) (-2114 (($ $) 152) (($ $ |#3|) 245)) (-3164 (((-679 (-568)) (-679 $)) 132 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 131 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 130) (((-679 |#1|) (-679 $)) 129)) (-1281 (((-121) $ $) 235) (((-121) $ (-634 $)) 234)) (-2925 (((-3 $ "failed") $) 33)) (-4054 (((-121) $) 243)) (-4144 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 215)) (-2053 (($ $) 184 (|has| |#1| (-453)))) (-3250 (($ $) 174 (|has| |#1| (-453))) (($ $ |#3|) 103 (|has| |#1| (-453)))) (-2108 (((-634 $) $) 107)) (-3927 (((-121) $) 94 (|has| |#1| (-904)))) (-3069 (($ $) 200 (|has| |#1| (-558)))) (-3431 (($ $) 201 (|has| |#1| (-558)))) (-4293 (($ $ $) 227) (($ $ $ |#3|) 225)) (-2875 (($ $ $) 226) (($ $ $ |#3|) 224)) (-3088 (($ $ |#1| |#2| $) 170)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 82 (-12 (|has| |#3| (-881 (-381))) (|has| |#1| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 81 (-12 (|has| |#3| (-881 (-568))) (|has| |#1| (-881 (-568)))))) (-2735 (((-121) $) 30)) (-4178 (((-763) $) 167)) (-1362 (((-121) $ $) 229) (((-121) $ (-634 $)) 228)) (-4396 (($ $ $ $ $) 186 (|has| |#1| (-558)))) (-2356 ((|#3| $) 254)) (-2051 (($ (-1157 |#1|) |#3|) 115) (($ (-1157 $) |#3|) 114)) (-2976 (((-634 $) $) 124)) (-3921 (((-121) $) 150)) (-2047 (($ |#1| |#2|) 151) (($ $ |#3| (-763)) 117) (($ $ (-634 |#3|) (-634 (-763))) 116)) (-2507 (($ $ $) 214)) (-3379 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $ |#3|) 118)) (-2278 (((-121) $) 244)) (-2144 ((|#2| $) 168) (((-763) $ |#3|) 120) (((-634 (-763)) $ (-634 |#3|)) 119)) (-2521 (($ $ $) 77 (|has| |#1| (-842)))) (-3838 (((-763) $) 253)) (-3268 (($ $ $) 76 (|has| |#1| (-842)))) (-3842 (($ (-1 |#2| |#2|) $) 169)) (-2795 (($ (-1 |#1| |#1|) $) 149)) (-2244 (((-3 |#3| "failed") $) 121)) (-3290 (($ $) 181 (|has| |#1| (-453)))) (-2297 (($ $) 182 (|has| |#1| (-453)))) (-4093 (((-634 $) $) 239)) (-2429 (($ $) 242)) (-2111 (($ $) 183 (|has| |#1| (-453)))) (-2380 (((-634 $) $) 240)) (-2104 (($ $) 241)) (-2097 (($ $) 147)) (-2102 ((|#1| $) 146) (($ $ |#3|) 246)) (-2495 (($ (-634 $)) 92 (|has| |#1| (-453))) (($ $ $) 91 (|has| |#1| (-453)))) (-2280 (((-2 (|:| |polnum| $) (|:| |polden| $) (|:| -3741 (-763))) $ $) 213)) (-3547 (((-2 (|:| -2348 $) (|:| |gap| (-763)) (|:| -3961 $) (|:| -1500 $)) $ $) 217) (((-2 (|:| -2348 $) (|:| |gap| (-763)) (|:| -3961 $) (|:| -1500 $)) $ $ |#3|) 216)) (-2409 (((-2 (|:| -2348 $) (|:| |gap| (-763)) (|:| -1500 $)) $ $) 219) (((-2 (|:| -2348 $) (|:| |gap| (-763)) (|:| -1500 $)) $ $ |#3|) 218)) (-3413 (($ $ $) 223) (($ $ $ |#3|) 221)) (-3774 (($ $ $) 222) (($ $ $ |#3|) 220)) (-4487 (((-1143) $) 9)) (-4330 (($ $ $) 189 (|has| |#1| (-558)))) (-1901 (((-634 $) $) 248)) (-3324 (((-3 (-634 $) "failed") $) 112)) (-1794 (((-3 (-634 $) "failed") $) 113)) (-3751 (((-3 (-2 (|:| |var| |#3|) (|:| -3438 (-763))) "failed") $) 111)) (-1415 (((-121) $ $) 231) (((-121) $ (-634 $)) 230)) (-2682 (($ $ $) 211)) (-4434 (($ $) 252)) (-2644 (((-121) $ $) 237)) (-4347 (((-121) $ $) 233) (((-121) $ (-634 $)) 232)) (-4025 (($ $ $) 212)) (-1733 (($ $) 251)) (-4022 (((-1108) $) 10)) (-2879 (((-2 (|:| -2721 $) (|:| |coef2| $)) $ $) 192 (|has| |#1| (-558)))) (-3203 (((-2 (|:| -2721 $) (|:| |coef1| $)) $ $) 193 (|has| |#1| (-558)))) (-2086 (((-121) $) 164)) (-2091 ((|#1| $) 165)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 93 (|has| |#1| (-453)))) (-2721 ((|#1| |#1| $) 185 (|has| |#1| (-453))) (($ (-634 $)) 90 (|has| |#1| (-453))) (($ $ $) 89 (|has| |#1| (-453)))) (-2905 (((-420 (-1157 $)) (-1157 $)) 100 (|has| |#1| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) 99 (|has| |#1| (-904)))) (-3848 (((-420 $) $) 97 (|has| |#1| (-904)))) (-1297 (((-2 (|:| -2721 $) (|:| |coef1| $) (|:| |coef2| $)) $ $) 194 (|has| |#1| (-558)))) (-2595 (((-3 $ "failed") $ |#1|) 172 (|has| |#1| (-558))) (((-3 $ "failed") $ $) 84 (|has| |#1| (-558)))) (-3055 (($ $ |#1|) 198 (|has| |#1| (-558))) (($ $ $) 196 (|has| |#1| (-558)))) (-4049 (($ $ |#1|) 199 (|has| |#1| (-558))) (($ $ $) 197 (|has| |#1| (-558)))) (-1339 (($ $ (-634 (-288 $))) 143) (($ $ (-288 $)) 142) (($ $ $ $) 141) (($ $ (-634 $) (-634 $)) 140) (($ $ |#3| |#1|) 139) (($ $ (-634 |#3|) (-634 |#1|)) 138) (($ $ |#3| $) 137) (($ $ (-634 |#3|) (-634 $)) 136)) (-2217 (($ $ |#3|) 105 (|has| |#1| (-172)))) (-4189 (($ $ |#3|) 41) (($ $ (-634 |#3|)) 40) (($ $ |#3| (-763)) 39) (($ $ (-634 |#3|) (-634 (-763))) 38)) (-3206 ((|#2| $) 148) (((-763) $ |#3|) 128) (((-634 (-763)) $ (-634 |#3|)) 127)) (-1595 (($ $) 249)) (-2734 (($ $) 247)) (-4278 (((-887 (-381)) $) 80 (-12 (|has| |#3| (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381)))))) (((-887 (-568)) $) 79 (-12 (|has| |#3| (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568)))))) (((-541) $) 78 (-12 (|has| |#3| (-609 (-541))) (|has| |#1| (-609 (-541))))) (($ (-953 (-409 (-568)))) 208 (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#3| (-609 (-1161))))) (($ (-953 (-568))) 205 (-2198 (-12 (-3044 (|has| |#1| (-43 (-409 (-568))))) (|has| |#1| (-43 (-568))) (|has| |#3| (-609 (-1161)))) (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#3| (-609 (-1161)))))) (($ (-953 |#1|)) 202 (|has| |#3| (-609 (-1161)))) (((-1143) $) 180 (-12 (|has| |#1| (-1037 (-568))) (|has| |#3| (-609 (-1161))))) (((-953 |#1|) $) 179 (|has| |#3| (-609 (-1161))))) (-3367 ((|#1| $) 173 (|has| |#1| (-453))) (($ $ |#3|) 104 (|has| |#1| (-453)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) 102 (-2139 (|has| $ (-148)) (|has| |#1| (-904))))) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 161) (($ |#3|) 135) (((-953 |#1|) $) 178 (|has| |#3| (-609 (-1161)))) (($ (-409 (-568))) 70 (-2198 (|has| |#1| (-1037 (-409 (-568)))) (|has| |#1| (-43 (-409 (-568)))))) (($ $) 83 (|has| |#1| (-558)))) (-1302 (((-634 |#1|) $) 166)) (-2604 ((|#1| $ |#2|) 153) (($ $ |#3| (-763)) 126) (($ $ (-634 |#3|) (-634 (-763))) 125)) (-4371 (((-3 $ "failed") $) 71 (-2198 (-2139 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-4078 (((-763)) 28)) (-4171 (($ $ $ (-763)) 171 (|has| |#1| (-172)))) (-1826 (((-121) $ $) 87 (|has| |#1| (-558)))) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-3601 (((-3 (-121) "failed") $ $) 238)) (-1556 (($) 29 T CONST)) (-2361 (($ $ $ $ (-763)) 187 (|has| |#1| (-558)))) (-2156 (($ $ $ (-763)) 188 (|has| |#1| (-558)))) (-3190 (($ $ |#3|) 37) (($ $ (-634 |#3|)) 36) (($ $ |#3| (-763)) 35) (($ $ (-634 |#3|) (-634 (-763))) 34)) (-1751 (((-121) $ $) 74 (|has| |#1| (-842)))) (-1738 (((-121) $ $) 73 (|has| |#1| (-842)))) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 75 (|has| |#1| (-842)))) (-1732 (((-121) $ $) 72 (|has| |#1| (-842)))) (-1779 (($ $ |#1|) 154 (|has| |#1| (-365)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 156 (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) 155 (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) 145) (($ $ |#1|) 144))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) |#2| $) 23)) (-3986 ((|#1| $) 10)) (-3337 (((-568) |#2| $) 88)) (-2919 (((-3 $ "failed") |#2| (-917)) 58)) (-3286 ((|#1| $) 28)) (-1783 ((|#1| |#2| $ |#1|) 37)) (-1642 (($ $) 25)) (-2902 (((-3 |#2| "failed") |#2| $) 87)) (-1436 (((-121) |#2| $) NIL)) (-2859 (((-121) |#2| $) NIL)) (-1453 (((-121) |#2| $) 24)) (-2953 ((|#1| $) 89)) (-3030 ((|#1| $) 27)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-1492 ((|#2| $) 79)) (-2747 (((-850) $) 71)) (-3999 ((|#1| |#2| $ |#1|) 38)) (-3059 (((-634 $) |#2|) 60)) (-1719 (((-121) $ $) 74))) 
+(((-1057 |#1| |#2|) (-13 (-1063 |#1| |#2|) (-10 -8 (-15 -3030 (|#1| $)) (-15 -3286 (|#1| $)) (-15 -3986 (|#1| $)) (-15 -2953 (|#1| $)) (-15 -1642 ($ $)) (-15 -1453 ((-121) |#2| $)) (-15 -1783 (|#1| |#2| $ |#1|)))) (-13 (-840) (-365)) (-1219 |#1|)) (T -1057)) 
+((-1783 (*1 *2 *3 *1 *2) (-12 (-4 *2 (-13 (-840) (-365))) (-5 *1 (-1057 *2 *3)) (-4 *3 (-1219 *2)))) (-3030 (*1 *2 *1) (-12 (-4 *2 (-13 (-840) (-365))) (-5 *1 (-1057 *2 *3)) (-4 *3 (-1219 *2)))) (-3286 (*1 *2 *1) (-12 (-4 *2 (-13 (-840) (-365))) (-5 *1 (-1057 *2 *3)) (-4 *3 (-1219 *2)))) (-3986 (*1 *2 *1) (-12 (-4 *2 (-13 (-840) (-365))) (-5 *1 (-1057 *2 *3)) (-4 *3 (-1219 *2)))) (-2953 (*1 *2 *1) (-12 (-4 *2 (-13 (-840) (-365))) (-5 *1 (-1057 *2 *3)) (-4 *3 (-1219 *2)))) (-1642 (*1 *1 *1) (-12 (-4 *2 (-13 (-840) (-365))) (-5 *1 (-1057 *2 *3)) (-4 *3 (-1219 *2)))) (-1453 (*1 *2 *3 *1) (-12 (-4 *4 (-13 (-840) (-365))) (-5 *2 (-121)) (-5 *1 (-1057 *4 *3)) (-4 *3 (-1219 *4))))) 
+(-13 (-1063 |#1| |#2|) (-10 -8 (-15 -3030 (|#1| $)) (-15 -3286 (|#1| $)) (-15 -3986 (|#1| $)) (-15 -2953 (|#1| $)) (-15 -1642 ($ $)) (-15 -1453 ((-121) |#2| $)) (-15 -1783 (|#1| |#2| $ |#1|)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2519 (($ $ $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-1353 (($ $ $ $) NIL)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2589 (((-121) $ $) NIL)) (-3337 (((-568) $) NIL)) (-1872 (($ $ $) NIL)) (-4490 (($) NIL T CONST)) (-3134 (($ (-1161)) 10) (($ (-568)) 7)) (-3668 (((-3 (-568) "failed") $) NIL)) (-2857 (((-568) $) NIL)) (-2403 (($ $ $) NIL)) (-1668 (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-679 (-568)) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-3254 (((-3 (-409 (-568)) "failed") $) NIL)) (-1338 (((-121) $) NIL)) (-2394 (((-409 (-568)) $) NIL)) (-1733 (($) NIL) (($ $) NIL)) (-2414 (($ $ $) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-2382 (($ $ $ $) NIL)) (-3155 (($ $ $) NIL)) (-1436 (((-121) $) NIL)) (-2341 (($ $ $) NIL)) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL)) (-1598 (((-121) $) NIL)) (-2268 (((-121) $) NIL)) (-2214 (((-3 $ "failed") $) NIL)) (-2859 (((-121) $) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-4374 (($ $ $ $) NIL)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-3248 (($ $) NIL)) (-3680 (($ $) NIL)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-3264 (($ $ $) NIL)) (-4436 (($) NIL T CONST)) (-1890 (($ $) NIL)) (-4025 (((-1108) $) NIL) (($ $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) NIL) (($ (-634 $)) NIL)) (-2406 (($ $) NIL)) (-3850 (((-420 $) $) NIL)) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2080 (((-121) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-4191 (($ $ (-763)) NIL) (($ $) NIL)) (-3953 (($ $) NIL)) (-3865 (($ $) NIL)) (-4280 (((-568) $) 16) (((-541) $) NIL) (((-887 (-568)) $) NIL) (((-381) $) NIL) (((-215) $) NIL) (($ (-1161)) 9)) (-2747 (((-850) $) 20) (($ (-568)) 6) (($ $) NIL) (($ (-568)) 6)) (-3425 (((-763)) NIL)) (-3600 (((-121) $ $) NIL)) (-3584 (($ $ $) NIL)) (-2404 (($) NIL)) (-2273 (((-121) $ $) NIL)) (-1564 (($ $ $ $) NIL)) (-2811 (($ $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $ (-763)) NIL) (($ $) NIL)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) NIL)) (-1775 (($ $) 19) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL))) 
+(((-1058) (-13 (-550) (-10 -8 (-6 -4508) (-6 -4513) (-6 -4509) (-15 -4280 ($ (-1161))) (-15 -3134 ($ (-1161))) (-15 -3134 ($ (-568)))))) (T -1058)) 
+((-4280 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1058)))) (-3134 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1058)))) (-3134 (*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1058))))) 
+(-13 (-550) (-10 -8 (-6 -4508) (-6 -4513) (-6 -4509) (-15 -4280 ($ (-1161))) (-15 -3134 ($ (-1161))) (-15 -3134 ($ (-568))))) 
+((-2449 (((-121) $ $) NIL (-2199 (|has| (-57) (-1090)) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090))))) (-2988 (($) NIL) (($ (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))))) NIL)) (-2481 (((-1249) $ (-1161) (-1161)) NIL (|has| $ (-6 -4522)))) (-1667 (((-121) $ (-763)) NIL)) (-2038 (($) 9)) (-2438 (((-57) $ (-1161) (-57)) NIL)) (-2206 (($ $) 23)) (-4268 (($ $) 21)) (-1670 (($ $) 20)) (-2879 (($ $) 22)) (-3243 (($ $) 25)) (-3125 (($ $) 26)) (-1994 (($ $) 19)) (-4208 (($ $) 24)) (-3963 (($ (-1 (-121) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) 18 (|has| $ (-6 -4521)))) (-2678 (((-3 (-57) "failed") (-1161) $) 34)) (-4490 (($) NIL T CONST)) (-1995 (($) 7)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090))))) (-1568 (($ (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) $) 46 (|has| $ (-6 -4521))) (($ (-1 (-121) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521))) (((-3 (-57) "failed") (-1161) $) NIL)) (-4330 (($ (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090)))) (($ (-1 (-121) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521)))) (-3094 (((-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $ (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090)))) (((-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $ (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) NIL (|has| $ (-6 -4521))) (((-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521)))) (-4391 (((-3 (-1143) "failed") $ (-1143) (-568)) 59)) (-1292 (((-57) $ (-1161) (-57)) NIL (|has| $ (-6 -4522)))) (-2069 (((-57) $ (-1161)) NIL)) (-3317 (((-634 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521))) (((-634 (-57)) $) NIL (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-1161) $) NIL (|has| (-1161) (-842)))) (-4406 (((-634 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) 28 (|has| $ (-6 -4521))) (((-634 (-57)) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090)))) (((-121) (-57) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-57) (-1090))))) (-3631 (((-1161) $) NIL (|has| (-1161) (-842)))) (-2253 (($ (-1 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4522))) (($ (-1 (-57) (-57)) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL) (($ (-1 (-57) (-57)) $) NIL) (($ (-1 (-57) (-57) (-57)) $ $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (-2199 (|has| (-57) (-1090)) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090))))) (-4253 (((-634 (-1161)) $) NIL)) (-2807 (((-121) (-1161) $) NIL)) (-2580 (((-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) $) NIL)) (-1708 (($ (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) $) 37)) (-3948 (((-634 (-1161)) $) NIL)) (-2916 (((-121) (-1161) $) NIL)) (-4025 (((-1108) $) NIL (-2199 (|has| (-57) (-1090)) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090))))) (-2294 (((-381) $ (-1161)) 45)) (-1300 (((-634 (-1143)) $ (-1143)) 60)) (-3877 (((-57) $) NIL (|has| (-1161) (-842)))) (-2712 (((-3 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) "failed") (-1 (-121) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL)) (-2490 (($ $ (-57)) NIL (|has| $ (-6 -4522)))) (-3403 (((-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) $) NIL)) (-3951 (((-121) (-1 (-121) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))))) NIL (-12 (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-303 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))))) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090)))) (($ $ (-288 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))))) NIL (-12 (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-303 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))))) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090)))) (($ $ (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) NIL (-12 (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-303 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))))) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090)))) (($ $ (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))))) NIL (-12 (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-303 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))))) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090)))) (($ $ (-634 (-57)) (-634 (-57))) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090)))) (($ $ (-57) (-57)) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090)))) (($ $ (-288 (-57))) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090)))) (($ $ (-634 (-288 (-57)))) NIL (-12 (|has| (-57) (-303 (-57))) (|has| (-57) (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) (-57) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-57) (-1090))))) (-1480 (((-634 (-57)) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 (((-57) $ (-1161)) NIL) (((-57) $ (-1161) (-57)) NIL)) (-3132 (($) NIL) (($ (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))))) NIL)) (-1600 (($ $ (-1161)) 47)) (-4170 (((-763) (-1 (-121) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521))) (((-763) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090)))) (((-763) (-57) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-57) (-1090)))) (((-763) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4521)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-609 (-541))))) (-4289 (($ (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))))) 30)) (-2770 (($ $ $) 31)) (-2747 (((-850) $) NIL (-2199 (|has| (-57) (-1090)) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090))))) (-1728 (($ $ (-1161) (-381)) 43)) (-3605 (($ $ (-1161) (-381)) 44)) (-4074 (($ (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))))) NIL)) (-3437 (((-121) (-1 (-121) (-2 (|:| -3651 (-1161)) (|:| -4085 (-57)))) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) (-57)) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) NIL (-2199 (|has| (-57) (-1090)) (|has| (-2 (|:| -3651 (-1161)) (|:| -4085 (-57))) (-1090))))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-1059) (-13 (-1172 (-1161) (-57)) (-10 -8 (-15 -2770 ($ $ $)) (-15 -1995 ($)) (-15 -1994 ($ $)) (-15 -1670 ($ $)) (-15 -4268 ($ $)) (-15 -2879 ($ $)) (-15 -4208 ($ $)) (-15 -2206 ($ $)) (-15 -3243 ($ $)) (-15 -3125 ($ $)) (-15 -1728 ($ $ (-1161) (-381))) (-15 -3605 ($ $ (-1161) (-381))) (-15 -2294 ((-381) $ (-1161))) (-15 -1300 ((-634 (-1143)) $ (-1143))) (-15 -1600 ($ $ (-1161))) (-15 -2038 ($)) (-15 -4391 ((-3 (-1143) "failed") $ (-1143) (-568))) (-6 -4521)))) (T -1059)) 
+((-2770 (*1 *1 *1 *1) (-5 *1 (-1059))) (-1995 (*1 *1) (-5 *1 (-1059))) (-1994 (*1 *1 *1) (-5 *1 (-1059))) (-1670 (*1 *1 *1) (-5 *1 (-1059))) (-4268 (*1 *1 *1) (-5 *1 (-1059))) (-2879 (*1 *1 *1) (-5 *1 (-1059))) (-4208 (*1 *1 *1) (-5 *1 (-1059))) (-2206 (*1 *1 *1) (-5 *1 (-1059))) (-3243 (*1 *1 *1) (-5 *1 (-1059))) (-3125 (*1 *1 *1) (-5 *1 (-1059))) (-1728 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-381)) (-5 *1 (-1059)))) (-3605 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-381)) (-5 *1 (-1059)))) (-2294 (*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-381)) (-5 *1 (-1059)))) (-1300 (*1 *2 *1 *3) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1059)) (-5 *3 (-1143)))) (-1600 (*1 *1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1059)))) (-2038 (*1 *1) (-5 *1 (-1059))) (-4391 (*1 *2 *1 *2 *3) (|partial| -12 (-5 *2 (-1143)) (-5 *3 (-568)) (-5 *1 (-1059))))) 
+(-13 (-1172 (-1161) (-57)) (-10 -8 (-15 -2770 ($ $ $)) (-15 -1995 ($)) (-15 -1994 ($ $)) (-15 -1670 ($ $)) (-15 -4268 ($ $)) (-15 -2879 ($ $)) (-15 -4208 ($ $)) (-15 -2206 ($ $)) (-15 -3243 ($ $)) (-15 -3125 ($ $)) (-15 -1728 ($ $ (-1161) (-381))) (-15 -3605 ($ $ (-1161) (-381))) (-15 -2294 ((-381) $ (-1161))) (-15 -1300 ((-634 (-1143)) $ (-1143))) (-15 -1600 ($ $ (-1161))) (-15 -2038 ($)) (-15 -4391 ((-3 (-1143) "failed") $ (-1143) (-568))) (-6 -4521))) 
+((-3623 (($ $) 45)) (-3266 (((-121) $ $) 74)) (-3668 (((-3 |#2| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 (-568) "failed") $) NIL) (((-3 |#4| "failed") $) NIL) (((-3 $ "failed") (-953 (-409 (-568)))) 226) (((-3 $ "failed") (-953 (-568))) 225) (((-3 $ "failed") (-953 |#2|)) 228)) (-2857 ((|#2| $) NIL) (((-409 (-568)) $) NIL) (((-568) $) NIL) ((|#4| $) NIL) (($ (-953 (-409 (-568)))) 214) (($ (-953 (-568))) 210) (($ (-953 |#2|)) 230)) (-2116 (($ $) NIL) (($ $ |#4|) 43)) (-1359 (((-121) $ $) 111) (((-121) $ (-634 $)) 112)) (-1593 (((-121) $) 56)) (-3777 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 106)) (-1537 (($ $) 137)) (-2354 (($ $) 133)) (-3424 (($ $) 132)) (-3002 (($ $ $) 79) (($ $ $ |#4|) 84)) (-4117 (($ $ $) 82) (($ $ $ |#4|) 86)) (-3764 (((-121) $ $) 120) (((-121) $ (-634 $)) 121)) (-4001 ((|#4| $) 33)) (-1653 (($ $ $) 109)) (-3463 (((-121) $) 55)) (-1850 (((-763) $) 35)) (-2135 (($ $) 151)) (-3607 (($ $) 148)) (-3509 (((-634 $) $) 68)) (-2417 (($ $) 57)) (-3274 (($ $) 144)) (-2174 (((-634 $) $) 65)) (-3226 (($ $) 59)) (-2104 ((|#2| $) NIL) (($ $ |#4|) 38)) (-3481 (((-2 (|:| |polnum| $) (|:| |polden| $) (|:| -2567 (-763))) $ $) 110)) (-2802 (((-2 (|:| -2350 $) (|:| |gap| (-763)) (|:| -4409 $) (|:| -2607 $)) $ $) 107) (((-2 (|:| -2350 $) (|:| |gap| (-763)) (|:| -4409 $) (|:| -2607 $)) $ $ |#4|) 108)) (-2322 (((-2 (|:| -2350 $) (|:| |gap| (-763)) (|:| -2607 $)) $ $) 103) (((-2 (|:| -2350 $) (|:| |gap| (-763)) (|:| -2607 $)) $ $ |#4|) 104)) (-1604 (($ $ $) 89) (($ $ $ |#4|) 94)) (-2708 (($ $ $) 90) (($ $ $ |#4|) 95)) (-2631 (((-634 $) $) 51)) (-2157 (((-121) $ $) 117) (((-121) $ (-634 $)) 118)) (-1315 (($ $ $) 102)) (-4436 (($ $) 37)) (-4342 (((-121) $ $) 72)) (-3236 (((-121) $ $) 113) (((-121) $ (-634 $)) 115)) (-1452 (($ $ $) 100)) (-3763 (($ $) 40)) (-2723 ((|#2| |#2| $) 141) (($ (-634 $)) NIL) (($ $ $) NIL)) (-2295 (($ $ |#2|) NIL) (($ $ $) 130)) (-1574 (($ $ |#2|) 125) (($ $ $) 128)) (-1303 (($ $) 48)) (-1595 (($ $) 52)) (-4280 (((-887 (-381)) $) NIL) (((-887 (-568)) $) NIL) (((-541) $) NIL) (($ (-953 (-409 (-568)))) 216) (($ (-953 (-568))) 212) (($ (-953 |#2|)) 227) (((-1143) $) 249) (((-953 |#2|) $) 161)) (-2747 (((-850) $) 30) (($ (-568)) NIL) (($ |#2|) NIL) (($ |#4|) NIL) (((-953 |#2|) $) 162) (($ (-409 (-568))) NIL) (($ $) NIL)) (-3011 (((-3 (-121) "failed") $ $) 71))) 
+(((-1060 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -2747 (|#1| |#1|)) (-15 -2723 (|#1| |#1| |#1|)) (-15 -2723 (|#1| (-634 |#1|))) (-15 -2747 (|#1| (-409 (-568)))) (-15 -2747 ((-953 |#2|) |#1|)) (-15 -4280 ((-953 |#2|) |#1|)) (-15 -4280 ((-1143) |#1|)) (-15 -2135 (|#1| |#1|)) (-15 -3607 (|#1| |#1|)) (-15 -3274 (|#1| |#1|)) (-15 -1537 (|#1| |#1|)) (-15 -2723 (|#2| |#2| |#1|)) (-15 -2295 (|#1| |#1| |#1|)) (-15 -1574 (|#1| |#1| |#1|)) (-15 -2295 (|#1| |#1| |#2|)) (-15 -1574 (|#1| |#1| |#2|)) (-15 -2354 (|#1| |#1|)) (-15 -3424 (|#1| |#1|)) (-15 -4280 (|#1| (-953 |#2|))) (-15 -2857 (|#1| (-953 |#2|))) (-15 -3668 ((-3 |#1| "failed") (-953 |#2|))) (-15 -4280 (|#1| (-953 (-568)))) (-15 -2857 (|#1| (-953 (-568)))) (-15 -3668 ((-3 |#1| "failed") (-953 (-568)))) (-15 -4280 (|#1| (-953 (-409 (-568))))) (-15 -2857 (|#1| (-953 (-409 (-568))))) (-15 -3668 ((-3 |#1| "failed") (-953 (-409 (-568))))) (-15 -1315 (|#1| |#1| |#1|)) (-15 -1452 (|#1| |#1| |#1|)) (-15 -3481 ((-2 (|:| |polnum| |#1|) (|:| |polden| |#1|) (|:| -2567 (-763))) |#1| |#1|)) (-15 -1653 (|#1| |#1| |#1|)) (-15 -3777 ((-2 (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1|)) (-15 -2802 ((-2 (|:| -2350 |#1|) (|:| |gap| (-763)) (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1| |#4|)) (-15 -2802 ((-2 (|:| -2350 |#1|) (|:| |gap| (-763)) (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1|)) (-15 -2322 ((-2 (|:| -2350 |#1|) (|:| |gap| (-763)) (|:| -2607 |#1|)) |#1| |#1| |#4|)) (-15 -2322 ((-2 (|:| -2350 |#1|) (|:| |gap| (-763)) (|:| -2607 |#1|)) |#1| |#1|)) (-15 -2708 (|#1| |#1| |#1| |#4|)) (-15 -1604 (|#1| |#1| |#1| |#4|)) (-15 -2708 (|#1| |#1| |#1|)) (-15 -1604 (|#1| |#1| |#1|)) (-15 -4117 (|#1| |#1| |#1| |#4|)) (-15 -3002 (|#1| |#1| |#1| |#4|)) (-15 -4117 (|#1| |#1| |#1|)) (-15 -3002 (|#1| |#1| |#1|)) (-15 -3764 ((-121) |#1| (-634 |#1|))) (-15 -3764 ((-121) |#1| |#1|)) (-15 -2157 ((-121) |#1| (-634 |#1|))) (-15 -2157 ((-121) |#1| |#1|)) (-15 -3236 ((-121) |#1| (-634 |#1|))) (-15 -3236 ((-121) |#1| |#1|)) (-15 -1359 ((-121) |#1| (-634 |#1|))) (-15 -1359 ((-121) |#1| |#1|)) (-15 -3266 ((-121) |#1| |#1|)) (-15 -4342 ((-121) |#1| |#1|)) (-15 -3011 ((-3 (-121) "failed") |#1| |#1|)) (-15 -3509 ((-634 |#1|) |#1|)) (-15 -2174 ((-634 |#1|) |#1|)) (-15 -3226 (|#1| |#1|)) (-15 -2417 (|#1| |#1|)) (-15 -1593 ((-121) |#1|)) (-15 -3463 ((-121) |#1|)) (-15 -2116 (|#1| |#1| |#4|)) (-15 -2104 (|#1| |#1| |#4|)) (-15 -1595 (|#1| |#1|)) (-15 -2631 ((-634 |#1|) |#1|)) (-15 -1303 (|#1| |#1|)) (-15 -3623 (|#1| |#1|)) (-15 -3763 (|#1| |#1|)) (-15 -4436 (|#1| |#1|)) (-15 -1850 ((-763) |#1|)) (-15 -4001 (|#4| |#1|)) (-15 -4280 ((-541) |#1|)) (-15 -4280 ((-887 (-568)) |#1|)) (-15 -4280 ((-887 (-381)) |#1|)) (-15 -2857 (|#4| |#1|)) (-15 -3668 ((-3 |#4| "failed") |#1|)) (-15 -2747 (|#1| |#4|)) (-15 -2104 (|#2| |#1|)) (-15 -2116 (|#1| |#1|)) (-15 -2857 ((-568) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2747 (|#1| |#2|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -2857 (|#2| |#1|)) (-15 -2747 (|#1| (-568))) (-15 -2747 ((-850) |#1|))) (-1061 |#2| |#3| |#4|) (-1047) (-788) (-842)) (T -1060)) 
+NIL 
+(-10 -8 (-15 -2747 (|#1| |#1|)) (-15 -2723 (|#1| |#1| |#1|)) (-15 -2723 (|#1| (-634 |#1|))) (-15 -2747 (|#1| (-409 (-568)))) (-15 -2747 ((-953 |#2|) |#1|)) (-15 -4280 ((-953 |#2|) |#1|)) (-15 -4280 ((-1143) |#1|)) (-15 -2135 (|#1| |#1|)) (-15 -3607 (|#1| |#1|)) (-15 -3274 (|#1| |#1|)) (-15 -1537 (|#1| |#1|)) (-15 -2723 (|#2| |#2| |#1|)) (-15 -2295 (|#1| |#1| |#1|)) (-15 -1574 (|#1| |#1| |#1|)) (-15 -2295 (|#1| |#1| |#2|)) (-15 -1574 (|#1| |#1| |#2|)) (-15 -2354 (|#1| |#1|)) (-15 -3424 (|#1| |#1|)) (-15 -4280 (|#1| (-953 |#2|))) (-15 -2857 (|#1| (-953 |#2|))) (-15 -3668 ((-3 |#1| "failed") (-953 |#2|))) (-15 -4280 (|#1| (-953 (-568)))) (-15 -2857 (|#1| (-953 (-568)))) (-15 -3668 ((-3 |#1| "failed") (-953 (-568)))) (-15 -4280 (|#1| (-953 (-409 (-568))))) (-15 -2857 (|#1| (-953 (-409 (-568))))) (-15 -3668 ((-3 |#1| "failed") (-953 (-409 (-568))))) (-15 -1315 (|#1| |#1| |#1|)) (-15 -1452 (|#1| |#1| |#1|)) (-15 -3481 ((-2 (|:| |polnum| |#1|) (|:| |polden| |#1|) (|:| -2567 (-763))) |#1| |#1|)) (-15 -1653 (|#1| |#1| |#1|)) (-15 -3777 ((-2 (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1|)) (-15 -2802 ((-2 (|:| -2350 |#1|) (|:| |gap| (-763)) (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1| |#4|)) (-15 -2802 ((-2 (|:| -2350 |#1|) (|:| |gap| (-763)) (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1|)) (-15 -2322 ((-2 (|:| -2350 |#1|) (|:| |gap| (-763)) (|:| -2607 |#1|)) |#1| |#1| |#4|)) (-15 -2322 ((-2 (|:| -2350 |#1|) (|:| |gap| (-763)) (|:| -2607 |#1|)) |#1| |#1|)) (-15 -2708 (|#1| |#1| |#1| |#4|)) (-15 -1604 (|#1| |#1| |#1| |#4|)) (-15 -2708 (|#1| |#1| |#1|)) (-15 -1604 (|#1| |#1| |#1|)) (-15 -4117 (|#1| |#1| |#1| |#4|)) (-15 -3002 (|#1| |#1| |#1| |#4|)) (-15 -4117 (|#1| |#1| |#1|)) (-15 -3002 (|#1| |#1| |#1|)) (-15 -3764 ((-121) |#1| (-634 |#1|))) (-15 -3764 ((-121) |#1| |#1|)) (-15 -2157 ((-121) |#1| (-634 |#1|))) (-15 -2157 ((-121) |#1| |#1|)) (-15 -3236 ((-121) |#1| (-634 |#1|))) (-15 -3236 ((-121) |#1| |#1|)) (-15 -1359 ((-121) |#1| (-634 |#1|))) (-15 -1359 ((-121) |#1| |#1|)) (-15 -3266 ((-121) |#1| |#1|)) (-15 -4342 ((-121) |#1| |#1|)) (-15 -3011 ((-3 (-121) "failed") |#1| |#1|)) (-15 -3509 ((-634 |#1|) |#1|)) (-15 -2174 ((-634 |#1|) |#1|)) (-15 -3226 (|#1| |#1|)) (-15 -2417 (|#1| |#1|)) (-15 -1593 ((-121) |#1|)) (-15 -3463 ((-121) |#1|)) (-15 -2116 (|#1| |#1| |#4|)) (-15 -2104 (|#1| |#1| |#4|)) (-15 -1595 (|#1| |#1|)) (-15 -2631 ((-634 |#1|) |#1|)) (-15 -1303 (|#1| |#1|)) (-15 -3623 (|#1| |#1|)) (-15 -3763 (|#1| |#1|)) (-15 -4436 (|#1| |#1|)) (-15 -1850 ((-763) |#1|)) (-15 -4001 (|#4| |#1|)) (-15 -4280 ((-541) |#1|)) (-15 -4280 ((-887 (-568)) |#1|)) (-15 -4280 ((-887 (-381)) |#1|)) (-15 -2857 (|#4| |#1|)) (-15 -3668 ((-3 |#4| "failed") |#1|)) (-15 -2747 (|#1| |#4|)) (-15 -2104 (|#2| |#1|)) (-15 -2116 (|#1| |#1|)) (-15 -2857 ((-568) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2747 (|#1| |#2|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -2857 (|#2| |#1|)) (-15 -2747 (|#1| (-568))) (-15 -2747 ((-850) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2057 (((-634 |#3|) $) 108)) (-3840 (((-1157 $) $ |#3|) 123) (((-1157 |#1|) $) 122)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 85 (|has| |#1| (-558)))) (-3661 (($ $) 86 (|has| |#1| (-558)))) (-4426 (((-121) $) 88 (|has| |#1| (-558)))) (-3528 (((-763) $) 110) (((-763) $ (-634 |#3|)) 109)) (-3623 (($ $) 250)) (-3266 (((-121) $ $) 236)) (-2689 (((-3 $ "failed") $ $) 18)) (-1736 (($ $ $) 195 (|has| |#1| (-558)))) (-2115 (((-634 $) $ $) 190 (|has| |#1| (-558)))) (-3863 (((-420 (-1157 $)) (-1157 $)) 98 (|has| |#1| (-904)))) (-3045 (($ $) 96 (|has| |#1| (-453)))) (-3498 (((-420 $) $) 95 (|has| |#1| (-453)))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 101 (|has| |#1| (-904)))) (-4490 (($) 16 T CONST)) (-3668 (((-3 |#1| "failed") $) 162) (((-3 (-409 (-568)) "failed") $) 160 (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) 158 (|has| |#1| (-1037 (-568)))) (((-3 |#3| "failed") $) 134) (((-3 $ "failed") (-953 (-409 (-568)))) 210 (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#3| (-609 (-1161))))) (((-3 $ "failed") (-953 (-568))) 207 (-2199 (-12 (-3046 (|has| |#1| (-43 (-409 (-568))))) (|has| |#1| (-43 (-568))) (|has| |#3| (-609 (-1161)))) (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#3| (-609 (-1161)))))) (((-3 $ "failed") (-953 |#1|)) 204 (-2199 (-12 (-3046 (|has| |#1| (-43 (-409 (-568))))) (-3046 (|has| |#1| (-43 (-568)))) (|has| |#3| (-609 (-1161)))) (-12 (-3046 (|has| |#1| (-550))) (-3046 (|has| |#1| (-43 (-409 (-568))))) (|has| |#1| (-43 (-568))) (|has| |#3| (-609 (-1161)))) (-12 (-3046 (|has| |#1| (-993 (-568)))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#3| (-609 (-1161))))))) (-2857 ((|#1| $) 163) (((-409 (-568)) $) 159 (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) 157 (|has| |#1| (-1037 (-568)))) ((|#3| $) 133) (($ (-953 (-409 (-568)))) 209 (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#3| (-609 (-1161))))) (($ (-953 (-568))) 206 (-2199 (-12 (-3046 (|has| |#1| (-43 (-409 (-568))))) (|has| |#1| (-43 (-568))) (|has| |#3| (-609 (-1161)))) (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#3| (-609 (-1161)))))) (($ (-953 |#1|)) 203 (-2199 (-12 (-3046 (|has| |#1| (-43 (-409 (-568))))) (-3046 (|has| |#1| (-43 (-568)))) (|has| |#3| (-609 (-1161)))) (-12 (-3046 (|has| |#1| (-550))) (-3046 (|has| |#1| (-43 (-409 (-568))))) (|has| |#1| (-43 (-568))) (|has| |#3| (-609 (-1161)))) (-12 (-3046 (|has| |#1| (-993 (-568)))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#3| (-609 (-1161))))))) (-2910 (($ $ $ |#3|) 106 (|has| |#1| (-172))) (($ $ $) 191 (|has| |#1| (-558)))) (-2116 (($ $) 152) (($ $ |#3|) 245)) (-1668 (((-679 (-568)) (-679 $)) 132 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 131 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 130) (((-679 |#1|) (-679 $)) 129)) (-1359 (((-121) $ $) 235) (((-121) $ (-634 $)) 234)) (-2902 (((-3 $ "failed") $) 33)) (-1593 (((-121) $) 243)) (-3777 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 215)) (-1537 (($ $) 184 (|has| |#1| (-453)))) (-1998 (($ $) 174 (|has| |#1| (-453))) (($ $ |#3|) 103 (|has| |#1| (-453)))) (-2110 (((-634 $) $) 107)) (-2197 (((-121) $) 94 (|has| |#1| (-904)))) (-2354 (($ $) 200 (|has| |#1| (-558)))) (-3424 (($ $) 201 (|has| |#1| (-558)))) (-3002 (($ $ $) 227) (($ $ $ |#3|) 225)) (-4117 (($ $ $) 226) (($ $ $ |#3|) 224)) (-2453 (($ $ |#1| |#2| $) 170)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 82 (-12 (|has| |#3| (-881 (-381))) (|has| |#1| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 81 (-12 (|has| |#3| (-881 (-568))) (|has| |#1| (-881 (-568)))))) (-1598 (((-121) $) 30)) (-3971 (((-763) $) 167)) (-3764 (((-121) $ $) 229) (((-121) $ (-634 $)) 228)) (-1443 (($ $ $ $ $) 186 (|has| |#1| (-558)))) (-4001 ((|#3| $) 254)) (-2053 (($ (-1157 |#1|) |#3|) 115) (($ (-1157 $) |#3|) 114)) (-3062 (((-634 $) $) 124)) (-2171 (((-121) $) 150)) (-2049 (($ |#1| |#2|) 151) (($ $ |#3| (-763)) 117) (($ $ (-634 |#3|) (-634 (-763))) 116)) (-1653 (($ $ $) 214)) (-1438 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $ |#3|) 118)) (-3463 (((-121) $) 244)) (-3524 ((|#2| $) 168) (((-763) $ |#3|) 120) (((-634 (-763)) $ (-634 |#3|)) 119)) (-1732 (($ $ $) 77 (|has| |#1| (-842)))) (-1850 (((-763) $) 253)) (-2047 (($ $ $) 76 (|has| |#1| (-842)))) (-1865 (($ (-1 |#2| |#2|) $) 169)) (-2797 (($ (-1 |#1| |#1|) $) 149)) (-2817 (((-3 |#3| "failed") $) 121)) (-2135 (($ $) 181 (|has| |#1| (-453)))) (-3607 (($ $) 182 (|has| |#1| (-453)))) (-3509 (((-634 $) $) 239)) (-2417 (($ $) 242)) (-3274 (($ $) 183 (|has| |#1| (-453)))) (-2174 (((-634 $) $) 240)) (-3226 (($ $) 241)) (-2099 (($ $) 147)) (-2104 ((|#1| $) 146) (($ $ |#3|) 246)) (-2498 (($ (-634 $)) 92 (|has| |#1| (-453))) (($ $ $) 91 (|has| |#1| (-453)))) (-3481 (((-2 (|:| |polnum| $) (|:| |polden| $) (|:| -2567 (-763))) $ $) 213)) (-2802 (((-2 (|:| -2350 $) (|:| |gap| (-763)) (|:| -4409 $) (|:| -2607 $)) $ $) 217) (((-2 (|:| -2350 $) (|:| |gap| (-763)) (|:| -4409 $) (|:| -2607 $)) $ $ |#3|) 216)) (-2322 (((-2 (|:| -2350 $) (|:| |gap| (-763)) (|:| -2607 $)) $ $) 219) (((-2 (|:| -2350 $) (|:| |gap| (-763)) (|:| -2607 $)) $ $ |#3|) 218)) (-1604 (($ $ $) 223) (($ $ $ |#3|) 221)) (-2708 (($ $ $) 222) (($ $ $ |#3|) 220)) (-1893 (((-1143) $) 9)) (-3137 (($ $ $) 189 (|has| |#1| (-558)))) (-2631 (((-634 $) $) 248)) (-4362 (((-3 (-634 $) "failed") $) 112)) (-2112 (((-3 (-634 $) "failed") $) 113)) (-2617 (((-3 (-2 (|:| |var| |#3|) (|:| -3483 (-763))) "failed") $) 111)) (-2157 (((-121) $ $) 231) (((-121) $ (-634 $)) 230)) (-1315 (($ $ $) 211)) (-4436 (($ $) 252)) (-4342 (((-121) $ $) 237)) (-3236 (((-121) $ $) 233) (((-121) $ (-634 $)) 232)) (-1452 (($ $ $) 212)) (-3763 (($ $) 251)) (-4025 (((-1108) $) 10)) (-4146 (((-2 (|:| -2723 $) (|:| |coef2| $)) $ $) 192 (|has| |#1| (-558)))) (-1832 (((-2 (|:| -2723 $) (|:| |coef1| $)) $ $) 193 (|has| |#1| (-558)))) (-2088 (((-121) $) 164)) (-2093 ((|#1| $) 165)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 93 (|has| |#1| (-453)))) (-2723 ((|#1| |#1| $) 185 (|has| |#1| (-453))) (($ (-634 $)) 90 (|has| |#1| (-453))) (($ $ $) 89 (|has| |#1| (-453)))) (-2841 (((-420 (-1157 $)) (-1157 $)) 100 (|has| |#1| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) 99 (|has| |#1| (-904)))) (-3850 (((-420 $) $) 97 (|has| |#1| (-904)))) (-3261 (((-2 (|:| -2723 $) (|:| |coef1| $) (|:| |coef2| $)) $ $) 194 (|has| |#1| (-558)))) (-2597 (((-3 $ "failed") $ |#1|) 172 (|has| |#1| (-558))) (((-3 $ "failed") $ $) 84 (|has| |#1| (-558)))) (-2295 (($ $ |#1|) 198 (|has| |#1| (-558))) (($ $ $) 196 (|has| |#1| (-558)))) (-1574 (($ $ |#1|) 199 (|has| |#1| (-558))) (($ $ $) 197 (|has| |#1| (-558)))) (-1339 (($ $ (-634 (-288 $))) 143) (($ $ (-288 $)) 142) (($ $ $ $) 141) (($ $ (-634 $) (-634 $)) 140) (($ $ |#3| |#1|) 139) (($ $ (-634 |#3|) (-634 |#1|)) 138) (($ $ |#3| $) 137) (($ $ (-634 |#3|) (-634 $)) 136)) (-3440 (($ $ |#3|) 105 (|has| |#1| (-172)))) (-4191 (($ $ |#3|) 41) (($ $ (-634 |#3|)) 40) (($ $ |#3| (-763)) 39) (($ $ (-634 |#3|) (-634 (-763))) 38)) (-1836 ((|#2| $) 148) (((-763) $ |#3|) 128) (((-634 (-763)) $ (-634 |#3|)) 127)) (-1303 (($ $) 249)) (-1595 (($ $) 247)) (-4280 (((-887 (-381)) $) 80 (-12 (|has| |#3| (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381)))))) (((-887 (-568)) $) 79 (-12 (|has| |#3| (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568)))))) (((-541) $) 78 (-12 (|has| |#3| (-609 (-541))) (|has| |#1| (-609 (-541))))) (($ (-953 (-409 (-568)))) 208 (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#3| (-609 (-1161))))) (($ (-953 (-568))) 205 (-2199 (-12 (-3046 (|has| |#1| (-43 (-409 (-568))))) (|has| |#1| (-43 (-568))) (|has| |#3| (-609 (-1161)))) (-12 (|has| |#1| (-43 (-409 (-568)))) (|has| |#3| (-609 (-1161)))))) (($ (-953 |#1|)) 202 (|has| |#3| (-609 (-1161)))) (((-1143) $) 180 (-12 (|has| |#1| (-1037 (-568))) (|has| |#3| (-609 (-1161))))) (((-953 |#1|) $) 179 (|has| |#3| (-609 (-1161))))) (-1364 ((|#1| $) 173 (|has| |#1| (-453))) (($ $ |#3|) 104 (|has| |#1| (-453)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) 102 (-2141 (|has| $ (-148)) (|has| |#1| (-904))))) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 161) (($ |#3|) 135) (((-953 |#1|) $) 178 (|has| |#3| (-609 (-1161)))) (($ (-409 (-568))) 70 (-2199 (|has| |#1| (-1037 (-409 (-568)))) (|has| |#1| (-43 (-409 (-568)))))) (($ $) 83 (|has| |#1| (-558)))) (-3304 (((-634 |#1|) $) 166)) (-2079 ((|#1| $ |#2|) 153) (($ $ |#3| (-763)) 126) (($ $ (-634 |#3|) (-634 (-763))) 125)) (-3385 (((-3 $ "failed") $) 71 (-2199 (-2141 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-3425 (((-763)) 28)) (-3925 (($ $ $ (-763)) 171 (|has| |#1| (-172)))) (-2273 (((-121) $ $) 87 (|has| |#1| (-558)))) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-3011 (((-3 (-121) "failed") $ $) 238)) (-1557 (($) 29 T CONST)) (-4038 (($ $ $ $ (-763)) 187 (|has| |#1| (-558)))) (-3611 (($ $ $ (-763)) 188 (|has| |#1| (-558)))) (-3192 (($ $ |#3|) 37) (($ $ (-634 |#3|)) 36) (($ $ |#3| (-763)) 35) (($ $ (-634 |#3|) (-634 (-763))) 34)) (-1753 (((-121) $ $) 74 (|has| |#1| (-842)))) (-1740 (((-121) $ $) 73 (|has| |#1| (-842)))) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 75 (|has| |#1| (-842)))) (-1734 (((-121) $ $) 72 (|has| |#1| (-842)))) (-1781 (($ $ |#1|) 154 (|has| |#1| (-365)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 156 (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) 155 (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) 145) (($ $ |#1|) 144))) 
 (((-1061 |#1| |#2| |#3|) (-1275) (-1047) (-788) (-842)) (T -1061)) 
-((-2356 (*1 *2 *1) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) (-3838 (*1 *2 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-763)))) (-4434 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-1733 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-2796 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-1595 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-1901 (*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1061 *3 *4 *5)))) (-2734 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-2102 (*1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) (-2114 (*1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) (-2278 (*1 *2 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) (-4054 (*1 *2 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) (-2429 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-2104 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-2380 (*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1061 *3 *4 *5)))) (-4093 (*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1061 *3 *4 *5)))) (-3601 (*1 *2 *1 *1) (|partial| -12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) (-2644 (*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) (-3653 (*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) (-1281 (*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) (-1281 (*1 *2 *1 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-1061 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)))) (-4347 (*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) (-4347 (*1 *2 *1 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-1061 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)))) (-1415 (*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) (-1415 (*1 *2 *1 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-1061 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)))) (-1362 (*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) (-1362 (*1 *2 *1 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-1061 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)))) (-4293 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-2875 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-4293 (*1 *1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) (-2875 (*1 *1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) (-3413 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-3774 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-3413 (*1 *1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) (-3774 (*1 *1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) (-2409 (*1 *2 *1 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -2348 *1) (|:| |gap| (-763)) (|:| -1500 *1))) (-4 *1 (-1061 *3 *4 *5)))) (-2409 (*1 *2 *1 *1 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-2 (|:| -2348 *1) (|:| |gap| (-763)) (|:| -1500 *1))) (-4 *1 (-1061 *4 *5 *3)))) (-3547 (*1 *2 *1 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -2348 *1) (|:| |gap| (-763)) (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-1061 *3 *4 *5)))) (-3547 (*1 *2 *1 *1 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-2 (|:| -2348 *1) (|:| |gap| (-763)) (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-1061 *4 *5 *3)))) (-4144 (*1 *2 *1 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-1061 *3 *4 *5)))) (-2507 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-2280 (*1 *2 *1 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| |polnum| *1) (|:| |polden| *1) (|:| -3741 (-763)))) (-4 *1 (-1061 *3 *4 *5)))) (-4025 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-2682 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-3666 (*1 *1 *2) (|partial| -12 (-5 *2 (-953 (-409 (-568)))) (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)))) (-2854 (*1 *1 *2) (-12 (-5 *2 (-953 (-409 (-568)))) (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)))) (-4278 (*1 *1 *2) (-12 (-5 *2 (-953 (-409 (-568)))) (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)))) (-3666 (*1 *1 *2) (|partial| -2198 (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-3044 (-4 *3 (-43 (-409 (-568))))) (-4 *3 (-43 (-568))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))))) (-2854 (*1 *1 *2) (-2198 (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-3044 (-4 *3 (-43 (-409 (-568))))) (-4 *3 (-43 (-568))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))))) (-4278 (*1 *1 *2) (-2198 (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-3044 (-4 *3 (-43 (-409 (-568))))) (-4 *3 (-43 (-568))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))))) (-3666 (*1 *1 *2) (|partial| -2198 (-12 (-5 *2 (-953 *3)) (-12 (-3044 (-4 *3 (-43 (-409 (-568))))) (-3044 (-4 *3 (-43 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 *3)) (-12 (-3044 (-4 *3 (-550))) (-3044 (-4 *3 (-43 (-409 (-568))))) (-4 *3 (-43 (-568))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 *3)) (-12 (-3044 (-4 *3 (-993 (-568)))) (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))))) (-2854 (*1 *1 *2) (-2198 (-12 (-5 *2 (-953 *3)) (-12 (-3044 (-4 *3 (-43 (-409 (-568))))) (-3044 (-4 *3 (-43 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 *3)) (-12 (-3044 (-4 *3 (-550))) (-3044 (-4 *3 (-43 (-409 (-568))))) (-4 *3 (-43 (-568))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 *3)) (-12 (-3044 (-4 *3 (-993 (-568)))) (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))))) (-4278 (*1 *1 *2) (-12 (-5 *2 (-953 *3)) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *5 (-609 (-1161))) (-4 *4 (-788)) (-4 *5 (-842)))) (-3431 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) (-3069 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) (-4049 (*1 *1 *1 *2) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) (-3055 (*1 *1 *1 *2) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) (-4049 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) (-3055 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) (-3809 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) (-1297 (*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -2721 *1) (|:| |coef1| *1) (|:| |coef2| *1))) (-4 *1 (-1061 *3 *4 *5)))) (-3203 (*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -2721 *1) (|:| |coef1| *1))) (-4 *1 (-1061 *3 *4 *5)))) (-2879 (*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -2721 *1) (|:| |coef2| *1))) (-4 *1 (-1061 *3 *4 *5)))) (-4265 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) (-3909 (*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1061 *3 *4 *5)))) (-4330 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) (-2156 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *3 (-558)))) (-2361 (*1 *1 *1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *3 (-558)))) (-4396 (*1 *1 *1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) (-2721 (*1 *2 *2 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453)))) (-2053 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453)))) (-2111 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453)))) (-2297 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453)))) (-3290 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453))))) 
-(-13 (-950 |t#1| |t#2| |t#3|) (-10 -8 (-15 -2356 (|t#3| $)) (-15 -3838 ((-763) $)) (-15 -4434 ($ $)) (-15 -1733 ($ $)) (-15 -2796 ($ $)) (-15 -1595 ($ $)) (-15 -1901 ((-634 $) $)) (-15 -2734 ($ $)) (-15 -2102 ($ $ |t#3|)) (-15 -2114 ($ $ |t#3|)) (-15 -2278 ((-121) $)) (-15 -4054 ((-121) $)) (-15 -2429 ($ $)) (-15 -2104 ($ $)) (-15 -2380 ((-634 $) $)) (-15 -4093 ((-634 $) $)) (-15 -3601 ((-3 (-121) "failed") $ $)) (-15 -2644 ((-121) $ $)) (-15 -3653 ((-121) $ $)) (-15 -1281 ((-121) $ $)) (-15 -1281 ((-121) $ (-634 $))) (-15 -4347 ((-121) $ $)) (-15 -4347 ((-121) $ (-634 $))) (-15 -1415 ((-121) $ $)) (-15 -1415 ((-121) $ (-634 $))) (-15 -1362 ((-121) $ $)) (-15 -1362 ((-121) $ (-634 $))) (-15 -4293 ($ $ $)) (-15 -2875 ($ $ $)) (-15 -4293 ($ $ $ |t#3|)) (-15 -2875 ($ $ $ |t#3|)) (-15 -3413 ($ $ $)) (-15 -3774 ($ $ $)) (-15 -3413 ($ $ $ |t#3|)) (-15 -3774 ($ $ $ |t#3|)) (-15 -2409 ((-2 (|:| -2348 $) (|:| |gap| (-763)) (|:| -1500 $)) $ $)) (-15 -2409 ((-2 (|:| -2348 $) (|:| |gap| (-763)) (|:| -1500 $)) $ $ |t#3|)) (-15 -3547 ((-2 (|:| -2348 $) (|:| |gap| (-763)) (|:| -3961 $) (|:| -1500 $)) $ $)) (-15 -3547 ((-2 (|:| -2348 $) (|:| |gap| (-763)) (|:| -3961 $) (|:| -1500 $)) $ $ |t#3|)) (-15 -4144 ((-2 (|:| -3961 $) (|:| -1500 $)) $ $)) (-15 -2507 ($ $ $)) (-15 -2280 ((-2 (|:| |polnum| $) (|:| |polden| $) (|:| -3741 (-763))) $ $)) (-15 -4025 ($ $ $)) (-15 -2682 ($ $ $)) (IF (|has| |t#3| (-609 (-1161))) (PROGN (-6 (-608 (-953 |t#1|))) (-6 (-609 (-953 |t#1|))) (IF (|has| |t#1| (-43 (-409 (-568)))) (PROGN (-15 -3666 ((-3 $ "failed") (-953 (-409 (-568))))) (-15 -2854 ($ (-953 (-409 (-568))))) (-15 -4278 ($ (-953 (-409 (-568))))) (-15 -3666 ((-3 $ "failed") (-953 (-568)))) (-15 -2854 ($ (-953 (-568)))) (-15 -4278 ($ (-953 (-568)))) (IF (|has| |t#1| (-993 (-568))) |noBranch| (PROGN (-15 -3666 ((-3 $ "failed") (-953 |t#1|))) (-15 -2854 ($ (-953 |t#1|)))))) |noBranch|) (IF (|has| |t#1| (-43 (-568))) (IF (|has| |t#1| (-43 (-409 (-568)))) |noBranch| (PROGN (-15 -3666 ((-3 $ "failed") (-953 (-568)))) (-15 -2854 ($ (-953 (-568)))) (-15 -4278 ($ (-953 (-568)))) (IF (|has| |t#1| (-550)) |noBranch| (PROGN (-15 -3666 ((-3 $ "failed") (-953 |t#1|))) (-15 -2854 ($ (-953 |t#1|))))))) |noBranch|) (IF (|has| |t#1| (-43 (-568))) |noBranch| (IF (|has| |t#1| (-43 (-409 (-568)))) |noBranch| (PROGN (-15 -3666 ((-3 $ "failed") (-953 |t#1|))) (-15 -2854 ($ (-953 |t#1|)))))) (-15 -4278 ($ (-953 |t#1|))) (IF (|has| |t#1| (-1037 (-568))) (-6 (-609 (-1143))) |noBranch|)) |noBranch|) (IF (|has| |t#1| (-558)) (PROGN (-15 -3431 ($ $)) (-15 -3069 ($ $)) (-15 -4049 ($ $ |t#1|)) (-15 -3055 ($ $ |t#1|)) (-15 -4049 ($ $ $)) (-15 -3055 ($ $ $)) (-15 -3809 ($ $ $)) (-15 -1297 ((-2 (|:| -2721 $) (|:| |coef1| $) (|:| |coef2| $)) $ $)) (-15 -3203 ((-2 (|:| -2721 $) (|:| |coef1| $)) $ $)) (-15 -2879 ((-2 (|:| -2721 $) (|:| |coef2| $)) $ $)) (-15 -4265 ($ $ $)) (-15 -3909 ((-634 $) $ $)) (-15 -4330 ($ $ $)) (-15 -2156 ($ $ $ (-763))) (-15 -2361 ($ $ $ $ (-763))) (-15 -4396 ($ $ $ $ $))) |noBranch|) (IF (|has| |t#1| (-453)) (PROGN (-15 -2721 (|t#1| |t#1| $)) (-15 -2053 ($ $)) (-15 -2111 ($ $)) (-15 -2297 ($ $)) (-15 -3290 ($ $))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| |#2|) . T) ((-25) . T) ((-43 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-608 (-953 |#1|)) |has| |#3| (-609 (-1161))) ((-172) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-172))) ((-609 (-541)) -12 (|has| |#1| (-609 (-541))) (|has| |#3| (-609 (-541)))) ((-609 (-887 (-381))) -12 (|has| |#1| (-609 (-887 (-381)))) (|has| |#3| (-609 (-887 (-381))))) ((-609 (-887 (-568))) -12 (|has| |#1| (-609 (-887 (-568)))) (|has| |#3| (-609 (-887 (-568))))) ((-609 (-953 |#1|)) |has| |#3| (-609 (-1161))) ((-609 (-1143)) -12 (|has| |#1| (-1037 (-568))) (|has| |#3| (-609 (-1161)))) ((-285) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-303 $) . T) ((-324 |#1| |#2|) . T) ((-379 |#1|) . T) ((-413 |#1|) . T) ((-453) -2198 (|has| |#1| (-904)) (|has| |#1| (-453))) ((-523 |#3| |#1|) . T) ((-523 |#3| $) . T) ((-523 $ $) . T) ((-558) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-637 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-637 |#1|) . T) ((-637 $) . T) ((-630 (-568)) |has| |#1| (-630 (-568))) ((-630 |#1|) . T) ((-707 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-716) . T) ((-842) |has| |#1| (-842)) ((-895 |#3|) . T) ((-881 (-381)) -12 (|has| |#1| (-881 (-381))) (|has| |#3| (-881 (-381)))) ((-881 (-568)) -12 (|has| |#1| (-881 (-568))) (|has| |#3| (-881 (-568)))) ((-950 |#1| |#2| |#3|) . T) ((-904) |has| |#1| (-904)) ((-1037 (-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 |#1|) . T) ((-1037 |#3|) . T) ((-1053 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-1053 |#1|) . T) ((-1053 $) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1199) |has| |#1| (-904))) 
-((-2537 (((-121) |#3| $) 13)) (-2932 (((-3 $ "failed") |#3| (-917)) 23)) (-2925 (((-3 |#3| "failed") |#3| $) 37)) (-2033 (((-121) |#3| $) 16)) (-2245 (((-121) |#3| $) 14))) 
-(((-1062 |#1| |#2| |#3|) (-10 -8 (-15 -2932 ((-3 |#1| "failed") |#3| (-917))) (-15 -2925 ((-3 |#3| "failed") |#3| |#1|)) (-15 -2033 ((-121) |#3| |#1|)) (-15 -2245 ((-121) |#3| |#1|)) (-15 -2537 ((-121) |#3| |#1|))) (-1063 |#2| |#3|) (-13 (-840) (-365)) (-1219 |#2|)) (T -1062)) 
-NIL 
-(-10 -8 (-15 -2932 ((-3 |#1| "failed") |#3| (-917))) (-15 -2925 ((-3 |#3| "failed") |#3| |#1|)) (-15 -2033 ((-121) |#3| |#1|)) (-15 -2245 ((-121) |#3| |#1|)) (-15 -2537 ((-121) |#3| |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) |#2| $) 20)) (-3662 (((-568) |#2| $) 21)) (-2932 (((-3 $ "failed") |#2| (-917)) 14)) (-3820 ((|#1| |#2| $ |#1|) 12)) (-2925 (((-3 |#2| "failed") |#2| $) 17)) (-2033 (((-121) |#2| $) 18)) (-2245 (((-121) |#2| $) 19)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-1626 ((|#2| $) 16)) (-2745 (((-850) $) 11)) (-3996 ((|#1| |#2| $ |#1|) 13)) (-4309 (((-634 $) |#2|) 15)) (-1717 (((-121) $ $) 6))) 
+((-4001 (*1 *2 *1) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) (-1850 (*1 *2 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-763)))) (-4436 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-3763 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-3623 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-1303 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-2631 (*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1061 *3 *4 *5)))) (-1595 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-2104 (*1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) (-2116 (*1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) (-3463 (*1 *2 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) (-1593 (*1 *2 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) (-2417 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-3226 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-2174 (*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1061 *3 *4 *5)))) (-3509 (*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1061 *3 *4 *5)))) (-3011 (*1 *2 *1 *1) (|partial| -12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) (-4342 (*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) (-3266 (*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) (-1359 (*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) (-1359 (*1 *2 *1 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-1061 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)))) (-3236 (*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) (-3236 (*1 *2 *1 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-1061 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)))) (-2157 (*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) (-2157 (*1 *2 *1 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-1061 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)))) (-3764 (*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) (-3764 (*1 *2 *1 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-1061 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)))) (-3002 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-4117 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-3002 (*1 *1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) (-4117 (*1 *1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) (-1604 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-2708 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-1604 (*1 *1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) (-2708 (*1 *1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) (-2322 (*1 *2 *1 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -2350 *1) (|:| |gap| (-763)) (|:| -2607 *1))) (-4 *1 (-1061 *3 *4 *5)))) (-2322 (*1 *2 *1 *1 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-2 (|:| -2350 *1) (|:| |gap| (-763)) (|:| -2607 *1))) (-4 *1 (-1061 *4 *5 *3)))) (-2802 (*1 *2 *1 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -2350 *1) (|:| |gap| (-763)) (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-1061 *3 *4 *5)))) (-2802 (*1 *2 *1 *1 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-2 (|:| -2350 *1) (|:| |gap| (-763)) (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-1061 *4 *5 *3)))) (-3777 (*1 *2 *1 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-1061 *3 *4 *5)))) (-1653 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-3481 (*1 *2 *1 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| |polnum| *1) (|:| |polden| *1) (|:| -2567 (-763)))) (-4 *1 (-1061 *3 *4 *5)))) (-1452 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-1315 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) (-3668 (*1 *1 *2) (|partial| -12 (-5 *2 (-953 (-409 (-568)))) (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)))) (-2857 (*1 *1 *2) (-12 (-5 *2 (-953 (-409 (-568)))) (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)))) (-4280 (*1 *1 *2) (-12 (-5 *2 (-953 (-409 (-568)))) (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)))) (-3668 (*1 *1 *2) (|partial| -2199 (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-3046 (-4 *3 (-43 (-409 (-568))))) (-4 *3 (-43 (-568))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))))) (-2857 (*1 *1 *2) (-2199 (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-3046 (-4 *3 (-43 (-409 (-568))))) (-4 *3 (-43 (-568))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))))) (-4280 (*1 *1 *2) (-2199 (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-3046 (-4 *3 (-43 (-409 (-568))))) (-4 *3 (-43 (-568))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))))) (-3668 (*1 *1 *2) (|partial| -2199 (-12 (-5 *2 (-953 *3)) (-12 (-3046 (-4 *3 (-43 (-409 (-568))))) (-3046 (-4 *3 (-43 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 *3)) (-12 (-3046 (-4 *3 (-550))) (-3046 (-4 *3 (-43 (-409 (-568))))) (-4 *3 (-43 (-568))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 *3)) (-12 (-3046 (-4 *3 (-993 (-568)))) (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))))) (-2857 (*1 *1 *2) (-2199 (-12 (-5 *2 (-953 *3)) (-12 (-3046 (-4 *3 (-43 (-409 (-568))))) (-3046 (-4 *3 (-43 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 *3)) (-12 (-3046 (-4 *3 (-550))) (-3046 (-4 *3 (-43 (-409 (-568))))) (-4 *3 (-43 (-568))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 *3)) (-12 (-3046 (-4 *3 (-993 (-568)))) (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))))) (-4280 (*1 *1 *2) (-12 (-5 *2 (-953 *3)) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *5 (-609 (-1161))) (-4 *4 (-788)) (-4 *5 (-842)))) (-3424 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) (-2354 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) (-1574 (*1 *1 *1 *2) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) (-2295 (*1 *1 *1 *2) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) (-1574 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) (-2295 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) (-1736 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) (-3261 (*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -2723 *1) (|:| |coef1| *1) (|:| |coef2| *1))) (-4 *1 (-1061 *3 *4 *5)))) (-1832 (*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -2723 *1) (|:| |coef1| *1))) (-4 *1 (-1061 *3 *4 *5)))) (-4146 (*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -2723 *1) (|:| |coef2| *1))) (-4 *1 (-1061 *3 *4 *5)))) (-2910 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) (-2115 (*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1061 *3 *4 *5)))) (-3137 (*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) (-3611 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *3 (-558)))) (-4038 (*1 *1 *1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *3 (-558)))) (-1443 (*1 *1 *1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) (-2723 (*1 *2 *2 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453)))) (-1537 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453)))) (-3274 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453)))) (-3607 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453)))) (-2135 (*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453))))) 
+(-13 (-950 |t#1| |t#2| |t#3|) (-10 -8 (-15 -4001 (|t#3| $)) (-15 -1850 ((-763) $)) (-15 -4436 ($ $)) (-15 -3763 ($ $)) (-15 -3623 ($ $)) (-15 -1303 ($ $)) (-15 -2631 ((-634 $) $)) (-15 -1595 ($ $)) (-15 -2104 ($ $ |t#3|)) (-15 -2116 ($ $ |t#3|)) (-15 -3463 ((-121) $)) (-15 -1593 ((-121) $)) (-15 -2417 ($ $)) (-15 -3226 ($ $)) (-15 -2174 ((-634 $) $)) (-15 -3509 ((-634 $) $)) (-15 -3011 ((-3 (-121) "failed") $ $)) (-15 -4342 ((-121) $ $)) (-15 -3266 ((-121) $ $)) (-15 -1359 ((-121) $ $)) (-15 -1359 ((-121) $ (-634 $))) (-15 -3236 ((-121) $ $)) (-15 -3236 ((-121) $ (-634 $))) (-15 -2157 ((-121) $ $)) (-15 -2157 ((-121) $ (-634 $))) (-15 -3764 ((-121) $ $)) (-15 -3764 ((-121) $ (-634 $))) (-15 -3002 ($ $ $)) (-15 -4117 ($ $ $)) (-15 -3002 ($ $ $ |t#3|)) (-15 -4117 ($ $ $ |t#3|)) (-15 -1604 ($ $ $)) (-15 -2708 ($ $ $)) (-15 -1604 ($ $ $ |t#3|)) (-15 -2708 ($ $ $ |t#3|)) (-15 -2322 ((-2 (|:| -2350 $) (|:| |gap| (-763)) (|:| -2607 $)) $ $)) (-15 -2322 ((-2 (|:| -2350 $) (|:| |gap| (-763)) (|:| -2607 $)) $ $ |t#3|)) (-15 -2802 ((-2 (|:| -2350 $) (|:| |gap| (-763)) (|:| -4409 $) (|:| -2607 $)) $ $)) (-15 -2802 ((-2 (|:| -2350 $) (|:| |gap| (-763)) (|:| -4409 $) (|:| -2607 $)) $ $ |t#3|)) (-15 -3777 ((-2 (|:| -4409 $) (|:| -2607 $)) $ $)) (-15 -1653 ($ $ $)) (-15 -3481 ((-2 (|:| |polnum| $) (|:| |polden| $) (|:| -2567 (-763))) $ $)) (-15 -1452 ($ $ $)) (-15 -1315 ($ $ $)) (IF (|has| |t#3| (-609 (-1161))) (PROGN (-6 (-608 (-953 |t#1|))) (-6 (-609 (-953 |t#1|))) (IF (|has| |t#1| (-43 (-409 (-568)))) (PROGN (-15 -3668 ((-3 $ "failed") (-953 (-409 (-568))))) (-15 -2857 ($ (-953 (-409 (-568))))) (-15 -4280 ($ (-953 (-409 (-568))))) (-15 -3668 ((-3 $ "failed") (-953 (-568)))) (-15 -2857 ($ (-953 (-568)))) (-15 -4280 ($ (-953 (-568)))) (IF (|has| |t#1| (-993 (-568))) |noBranch| (PROGN (-15 -3668 ((-3 $ "failed") (-953 |t#1|))) (-15 -2857 ($ (-953 |t#1|)))))) |noBranch|) (IF (|has| |t#1| (-43 (-568))) (IF (|has| |t#1| (-43 (-409 (-568)))) |noBranch| (PROGN (-15 -3668 ((-3 $ "failed") (-953 (-568)))) (-15 -2857 ($ (-953 (-568)))) (-15 -4280 ($ (-953 (-568)))) (IF (|has| |t#1| (-550)) |noBranch| (PROGN (-15 -3668 ((-3 $ "failed") (-953 |t#1|))) (-15 -2857 ($ (-953 |t#1|))))))) |noBranch|) (IF (|has| |t#1| (-43 (-568))) |noBranch| (IF (|has| |t#1| (-43 (-409 (-568)))) |noBranch| (PROGN (-15 -3668 ((-3 $ "failed") (-953 |t#1|))) (-15 -2857 ($ (-953 |t#1|)))))) (-15 -4280 ($ (-953 |t#1|))) (IF (|has| |t#1| (-1037 (-568))) (-6 (-609 (-1143))) |noBranch|)) |noBranch|) (IF (|has| |t#1| (-558)) (PROGN (-15 -3424 ($ $)) (-15 -2354 ($ $)) (-15 -1574 ($ $ |t#1|)) (-15 -2295 ($ $ |t#1|)) (-15 -1574 ($ $ $)) (-15 -2295 ($ $ $)) (-15 -1736 ($ $ $)) (-15 -3261 ((-2 (|:| -2723 $) (|:| |coef1| $) (|:| |coef2| $)) $ $)) (-15 -1832 ((-2 (|:| -2723 $) (|:| |coef1| $)) $ $)) (-15 -4146 ((-2 (|:| -2723 $) (|:| |coef2| $)) $ $)) (-15 -2910 ($ $ $)) (-15 -2115 ((-634 $) $ $)) (-15 -3137 ($ $ $)) (-15 -3611 ($ $ $ (-763))) (-15 -4038 ($ $ $ $ (-763))) (-15 -1443 ($ $ $ $ $))) |noBranch|) (IF (|has| |t#1| (-453)) (PROGN (-15 -2723 (|t#1| |t#1| $)) (-15 -1537 ($ $)) (-15 -3274 ($ $)) (-15 -3607 ($ $)) (-15 -2135 ($ $))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| |#2|) . T) ((-25) . T) ((-43 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-608 (-953 |#1|)) |has| |#3| (-609 (-1161))) ((-172) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-172))) ((-609 (-541)) -12 (|has| |#1| (-609 (-541))) (|has| |#3| (-609 (-541)))) ((-609 (-887 (-381))) -12 (|has| |#1| (-609 (-887 (-381)))) (|has| |#3| (-609 (-887 (-381))))) ((-609 (-887 (-568))) -12 (|has| |#1| (-609 (-887 (-568)))) (|has| |#3| (-609 (-887 (-568))))) ((-609 (-953 |#1|)) |has| |#3| (-609 (-1161))) ((-609 (-1143)) -12 (|has| |#1| (-1037 (-568))) (|has| |#3| (-609 (-1161)))) ((-285) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-303 $) . T) ((-324 |#1| |#2|) . T) ((-379 |#1|) . T) ((-413 |#1|) . T) ((-453) -2199 (|has| |#1| (-904)) (|has| |#1| (-453))) ((-523 |#3| |#1|) . T) ((-523 |#3| $) . T) ((-523 $ $) . T) ((-558) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-637 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-637 |#1|) . T) ((-637 $) . T) ((-630 (-568)) |has| |#1| (-630 (-568))) ((-630 |#1|) . T) ((-707 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453))) ((-716) . T) ((-842) |has| |#1| (-842)) ((-895 |#3|) . T) ((-881 (-381)) -12 (|has| |#1| (-881 (-381))) (|has| |#3| (-881 (-381)))) ((-881 (-568)) -12 (|has| |#1| (-881 (-568))) (|has| |#3| (-881 (-568)))) ((-950 |#1| |#2| |#3|) . T) ((-904) |has| |#1| (-904)) ((-1037 (-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 |#1|) . T) ((-1037 |#3|) . T) ((-1053 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-1053 |#1|) . T) ((-1053 $) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1199) |has| |#1| (-904))) 
+((-1819 (((-121) |#3| $) 13)) (-2919 (((-3 $ "failed") |#3| (-917)) 23)) (-2902 (((-3 |#3| "failed") |#3| $) 37)) (-1436 (((-121) |#3| $) 16)) (-2859 (((-121) |#3| $) 14))) 
+(((-1062 |#1| |#2| |#3|) (-10 -8 (-15 -2919 ((-3 |#1| "failed") |#3| (-917))) (-15 -2902 ((-3 |#3| "failed") |#3| |#1|)) (-15 -1436 ((-121) |#3| |#1|)) (-15 -2859 ((-121) |#3| |#1|)) (-15 -1819 ((-121) |#3| |#1|))) (-1063 |#2| |#3|) (-13 (-840) (-365)) (-1219 |#2|)) (T -1062)) 
+NIL 
+(-10 -8 (-15 -2919 ((-3 |#1| "failed") |#3| (-917))) (-15 -2902 ((-3 |#3| "failed") |#3| |#1|)) (-15 -1436 ((-121) |#3| |#1|)) (-15 -2859 ((-121) |#3| |#1|)) (-15 -1819 ((-121) |#3| |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) |#2| $) 20)) (-3337 (((-568) |#2| $) 21)) (-2919 (((-3 $ "failed") |#2| (-917)) 14)) (-1783 ((|#1| |#2| $ |#1|) 12)) (-2902 (((-3 |#2| "failed") |#2| $) 17)) (-1436 (((-121) |#2| $) 18)) (-2859 (((-121) |#2| $) 19)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-1492 ((|#2| $) 16)) (-2747 (((-850) $) 11)) (-3999 ((|#1| |#2| $ |#1|) 13)) (-3059 (((-634 $) |#2|) 15)) (-1719 (((-121) $ $) 6))) 
 (((-1063 |#1| |#2|) (-1275) (-13 (-840) (-365)) (-1219 |t#1|)) (T -1063)) 
-((-3662 (*1 *2 *3 *1) (-12 (-4 *1 (-1063 *4 *3)) (-4 *4 (-13 (-840) (-365))) (-4 *3 (-1219 *4)) (-5 *2 (-568)))) (-2537 (*1 *2 *3 *1) (-12 (-4 *1 (-1063 *4 *3)) (-4 *4 (-13 (-840) (-365))) (-4 *3 (-1219 *4)) (-5 *2 (-121)))) (-2245 (*1 *2 *3 *1) (-12 (-4 *1 (-1063 *4 *3)) (-4 *4 (-13 (-840) (-365))) (-4 *3 (-1219 *4)) (-5 *2 (-121)))) (-2033 (*1 *2 *3 *1) (-12 (-4 *1 (-1063 *4 *3)) (-4 *4 (-13 (-840) (-365))) (-4 *3 (-1219 *4)) (-5 *2 (-121)))) (-2925 (*1 *2 *2 *1) (|partial| -12 (-4 *1 (-1063 *3 *2)) (-4 *3 (-13 (-840) (-365))) (-4 *2 (-1219 *3)))) (-1626 (*1 *2 *1) (-12 (-4 *1 (-1063 *3 *2)) (-4 *3 (-13 (-840) (-365))) (-4 *2 (-1219 *3)))) (-4309 (*1 *2 *3) (-12 (-4 *4 (-13 (-840) (-365))) (-4 *3 (-1219 *4)) (-5 *2 (-634 *1)) (-4 *1 (-1063 *4 *3)))) (-2932 (*1 *1 *2 *3) (|partial| -12 (-5 *3 (-917)) (-4 *4 (-13 (-840) (-365))) (-4 *1 (-1063 *4 *2)) (-4 *2 (-1219 *4)))) (-3996 (*1 *2 *3 *1 *2) (-12 (-4 *1 (-1063 *2 *3)) (-4 *2 (-13 (-840) (-365))) (-4 *3 (-1219 *2)))) (-3820 (*1 *2 *3 *1 *2) (-12 (-4 *1 (-1063 *2 *3)) (-4 *2 (-13 (-840) (-365))) (-4 *3 (-1219 *2))))) 
-(-13 (-1090) (-10 -8 (-15 -3662 ((-568) |t#2| $)) (-15 -2537 ((-121) |t#2| $)) (-15 -2245 ((-121) |t#2| $)) (-15 -2033 ((-121) |t#2| $)) (-15 -2925 ((-3 |t#2| "failed") |t#2| $)) (-15 -1626 (|t#2| $)) (-15 -4309 ((-634 $) |t#2|)) (-15 -2932 ((-3 $ "failed") |t#2| (-917))) (-15 -3996 (|t#1| |t#2| $ |t#1|)) (-15 -3820 (|t#1| |t#2| $ |t#1|)))) 
+((-3337 (*1 *2 *3 *1) (-12 (-4 *1 (-1063 *4 *3)) (-4 *4 (-13 (-840) (-365))) (-4 *3 (-1219 *4)) (-5 *2 (-568)))) (-1819 (*1 *2 *3 *1) (-12 (-4 *1 (-1063 *4 *3)) (-4 *4 (-13 (-840) (-365))) (-4 *3 (-1219 *4)) (-5 *2 (-121)))) (-2859 (*1 *2 *3 *1) (-12 (-4 *1 (-1063 *4 *3)) (-4 *4 (-13 (-840) (-365))) (-4 *3 (-1219 *4)) (-5 *2 (-121)))) (-1436 (*1 *2 *3 *1) (-12 (-4 *1 (-1063 *4 *3)) (-4 *4 (-13 (-840) (-365))) (-4 *3 (-1219 *4)) (-5 *2 (-121)))) (-2902 (*1 *2 *2 *1) (|partial| -12 (-4 *1 (-1063 *3 *2)) (-4 *3 (-13 (-840) (-365))) (-4 *2 (-1219 *3)))) (-1492 (*1 *2 *1) (-12 (-4 *1 (-1063 *3 *2)) (-4 *3 (-13 (-840) (-365))) (-4 *2 (-1219 *3)))) (-3059 (*1 *2 *3) (-12 (-4 *4 (-13 (-840) (-365))) (-4 *3 (-1219 *4)) (-5 *2 (-634 *1)) (-4 *1 (-1063 *4 *3)))) (-2919 (*1 *1 *2 *3) (|partial| -12 (-5 *3 (-917)) (-4 *4 (-13 (-840) (-365))) (-4 *1 (-1063 *4 *2)) (-4 *2 (-1219 *4)))) (-3999 (*1 *2 *3 *1 *2) (-12 (-4 *1 (-1063 *2 *3)) (-4 *2 (-13 (-840) (-365))) (-4 *3 (-1219 *2)))) (-1783 (*1 *2 *3 *1 *2) (-12 (-4 *1 (-1063 *2 *3)) (-4 *2 (-13 (-840) (-365))) (-4 *3 (-1219 *2))))) 
+(-13 (-1090) (-10 -8 (-15 -3337 ((-568) |t#2| $)) (-15 -1819 ((-121) |t#2| $)) (-15 -2859 ((-121) |t#2| $)) (-15 -1436 ((-121) |t#2| $)) (-15 -2902 ((-3 |t#2| "failed") |t#2| $)) (-15 -1492 (|t#2| $)) (-15 -3059 ((-634 $) |t#2|)) (-15 -2919 ((-3 $ "failed") |t#2| (-917))) (-15 -3999 (|t#1| |t#2| $ |t#1|)) (-15 -1783 (|t#1| |t#2| $ |t#1|)))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-3404 (((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-634 |#4|) (-634 |#5|) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) (-763)) 95)) (-2497 (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5|) 56) (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5| (-763)) 55)) (-1277 (((-1249) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-763)) 87)) (-4032 (((-763) (-634 |#4|) (-634 |#5|)) 27)) (-4475 (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5|) 58) (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5| (-763)) 57) (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5| (-763) (-121)) 59)) (-2847 (((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121) (-121) (-121) (-121)) 78) (((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121)) 79)) (-4278 (((-1143) (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) 82)) (-1677 (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5| (-121)) 54)) (-4295 (((-763) (-634 |#4|) (-634 |#5|)) 19))) 
-(((-1064 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -4295 ((-763) (-634 |#4|) (-634 |#5|))) (-15 -4032 ((-763) (-634 |#4|) (-634 |#5|))) (-15 -1677 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5| (-121))) (-15 -2497 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5| (-763))) (-15 -2497 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5|)) (-15 -4475 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5| (-763) (-121))) (-15 -4475 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5| (-763))) (-15 -4475 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5|)) (-15 -2847 ((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121))) (-15 -2847 ((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121) (-121) (-121) (-121))) (-15 -3404 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-634 |#4|) (-634 |#5|) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) (-763))) (-15 -4278 ((-1143) (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|)))) (-15 -1277 ((-1249) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-763)))) (-453) (-788) (-842) (-1061 |#1| |#2| |#3|) (-1066 |#1| |#2| |#3| |#4|)) (T -1064)) 
-((-1277 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-2 (|:| |val| (-634 *8)) (|:| -3001 *9)))) (-5 *4 (-763)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-1249)) (-5 *1 (-1064 *5 *6 *7 *8 *9)))) (-4278 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |val| (-634 *7)) (|:| -3001 *8))) (-4 *7 (-1061 *4 *5 *6)) (-4 *8 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1143)) (-5 *1 (-1064 *4 *5 *6 *7 *8)))) (-3404 (*1 *2 *3 *4 *2 *5 *6) (-12 (-5 *5 (-2 (|:| |done| (-634 *11)) (|:| |todo| (-634 (-2 (|:| |val| *3) (|:| -3001 *11)))))) (-5 *6 (-763)) (-5 *2 (-634 (-2 (|:| |val| (-634 *10)) (|:| -3001 *11)))) (-5 *3 (-634 *10)) (-5 *4 (-634 *11)) (-4 *10 (-1061 *7 *8 *9)) (-4 *11 (-1066 *7 *8 *9 *10)) (-4 *7 (-453)) (-4 *8 (-788)) (-4 *9 (-842)) (-5 *1 (-1064 *7 *8 *9 *10 *11)))) (-2847 (*1 *2 *3 *2 *4 *4 *4 *4 *4) (-12 (-5 *2 (-634 *9)) (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1064 *5 *6 *7 *8 *9)))) (-2847 (*1 *2 *3 *2 *4 *4) (-12 (-5 *2 (-634 *9)) (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1064 *5 *6 *7 *8 *9)))) (-4475 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1064 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-4475 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-763)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1064 *6 *7 *8 *3 *4)) (-4 *4 (-1066 *6 *7 *8 *3)))) (-4475 (*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-763)) (-5 *6 (-121)) (-4 *7 (-453)) (-4 *8 (-788)) (-4 *9 (-842)) (-4 *3 (-1061 *7 *8 *9)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1064 *7 *8 *9 *3 *4)) (-4 *4 (-1066 *7 *8 *9 *3)))) (-2497 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1064 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-2497 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-763)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1064 *6 *7 *8 *3 *4)) (-4 *4 (-1066 *6 *7 *8 *3)))) (-1677 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-121)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1064 *6 *7 *8 *3 *4)) (-4 *4 (-1066 *6 *7 *8 *3)))) (-4032 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 *9)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-763)) (-5 *1 (-1064 *5 *6 *7 *8 *9)))) (-4295 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 *9)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-763)) (-5 *1 (-1064 *5 *6 *7 *8 *9))))) 
-(-10 -7 (-15 -4295 ((-763) (-634 |#4|) (-634 |#5|))) (-15 -4032 ((-763) (-634 |#4|) (-634 |#5|))) (-15 -1677 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5| (-121))) (-15 -2497 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5| (-763))) (-15 -2497 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5|)) (-15 -4475 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5| (-763) (-121))) (-15 -4475 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5| (-763))) (-15 -4475 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5|)) (-15 -2847 ((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121))) (-15 -2847 ((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121) (-121) (-121) (-121))) (-15 -3404 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-634 |#4|) (-634 |#5|) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) (-763))) (-15 -4278 ((-1143) (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|)))) (-15 -1277 ((-1249) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-763)))) 
-((-1862 (((-121) |#5| $) 20)) (-4286 (((-121) |#5| $) 23)) (-3193 (((-121) |#5| $) 16) (((-121) $) 44)) (-3212 (((-634 $) |#5| $) NIL) (((-634 $) (-634 |#5|) $) 76) (((-634 $) (-634 |#5|) (-634 $)) 74) (((-634 $) |#5| (-634 $)) 77)) (-1807 (($ $ |#5|) NIL) (((-634 $) |#5| $) NIL) (((-634 $) |#5| (-634 $)) 59) (((-634 $) (-634 |#5|) $) 61) (((-634 $) (-634 |#5|) (-634 $)) 63)) (-2574 (((-634 $) |#5| $) NIL) (((-634 $) |#5| (-634 $)) 53) (((-634 $) (-634 |#5|) $) 55) (((-634 $) (-634 |#5|) (-634 $)) 57)) (-2288 (((-121) |#5| $) 26))) 
-(((-1065 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 -1807 ((-634 |#1|) (-634 |#5|) (-634 |#1|))) (-15 -1807 ((-634 |#1|) (-634 |#5|) |#1|)) (-15 -1807 ((-634 |#1|) |#5| (-634 |#1|))) (-15 -1807 ((-634 |#1|) |#5| |#1|)) (-15 -2574 ((-634 |#1|) (-634 |#5|) (-634 |#1|))) (-15 -2574 ((-634 |#1|) (-634 |#5|) |#1|)) (-15 -2574 ((-634 |#1|) |#5| (-634 |#1|))) (-15 -2574 ((-634 |#1|) |#5| |#1|)) (-15 -3212 ((-634 |#1|) |#5| (-634 |#1|))) (-15 -3212 ((-634 |#1|) (-634 |#5|) (-634 |#1|))) (-15 -3212 ((-634 |#1|) (-634 |#5|) |#1|)) (-15 -3212 ((-634 |#1|) |#5| |#1|)) (-15 -4286 ((-121) |#5| |#1|)) (-15 -3193 ((-121) |#1|)) (-15 -2288 ((-121) |#5| |#1|)) (-15 -1862 ((-121) |#5| |#1|)) (-15 -3193 ((-121) |#5| |#1|)) (-15 -1807 (|#1| |#1| |#5|))) (-1066 |#2| |#3| |#4| |#5|) (-453) (-788) (-842) (-1061 |#2| |#3| |#4|)) (T -1065)) 
-NIL 
-(-10 -8 (-15 -1807 ((-634 |#1|) (-634 |#5|) (-634 |#1|))) (-15 -1807 ((-634 |#1|) (-634 |#5|) |#1|)) (-15 -1807 ((-634 |#1|) |#5| (-634 |#1|))) (-15 -1807 ((-634 |#1|) |#5| |#1|)) (-15 -2574 ((-634 |#1|) (-634 |#5|) (-634 |#1|))) (-15 -2574 ((-634 |#1|) (-634 |#5|) |#1|)) (-15 -2574 ((-634 |#1|) |#5| (-634 |#1|))) (-15 -2574 ((-634 |#1|) |#5| |#1|)) (-15 -3212 ((-634 |#1|) |#5| (-634 |#1|))) (-15 -3212 ((-634 |#1|) (-634 |#5|) (-634 |#1|))) (-15 -3212 ((-634 |#1|) (-634 |#5|) |#1|)) (-15 -3212 ((-634 |#1|) |#5| |#1|)) (-15 -4286 ((-121) |#5| |#1|)) (-15 -3193 ((-121) |#1|)) (-15 -2288 ((-121) |#5| |#1|)) (-15 -1862 ((-121) |#5| |#1|)) (-15 -3193 ((-121) |#5| |#1|)) (-15 -1807 (|#1| |#1| |#5|))) 
-((-2447 (((-121) $ $) 7)) (-2387 (((-634 (-2 (|:| -4092 $) (|:| -1798 (-634 |#4|)))) (-634 |#4|)) 78)) (-2415 (((-634 $) (-634 |#4|)) 79) (((-634 $) (-634 |#4|) (-121)) 104)) (-2055 (((-634 |#3|) $) 32)) (-4211 (((-121) $) 25)) (-3824 (((-121) $) 16 (|has| |#1| (-558)))) (-3300 (((-121) |#4| $) 94) (((-121) $) 90)) (-2819 ((|#4| |#4| $) 85)) (-4305 (((-634 (-2 (|:| |val| |#4|) (|:| -3001 $))) |#4| $) 119)) (-3644 (((-2 (|:| |under| $) (|:| -1519 $) (|:| |upper| $)) $ |#3|) 26)) (-2510 (((-121) $ (-763)) 43)) (-2801 (($ (-1 (-121) |#4|) $) 64 (|has| $ (-6 -4519))) (((-3 |#4| "failed") $ |#3|) 72)) (-2671 (($) 44 T CONST)) (-1565 (((-121) $) 21 (|has| |#1| (-558)))) (-3846 (((-121) $ $) 23 (|has| |#1| (-558)))) (-3106 (((-121) $ $) 22 (|has| |#1| (-558)))) (-3695 (((-121) $) 24 (|has| |#1| (-558)))) (-4275 (((-634 |#4|) (-634 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 86)) (-2355 (((-634 |#4|) (-634 |#4|) $) 17 (|has| |#1| (-558)))) (-2492 (((-634 |#4|) (-634 |#4|) $) 18 (|has| |#1| (-558)))) (-3666 (((-3 $ "failed") (-634 |#4|)) 35)) (-2854 (($ (-634 |#4|)) 34)) (-3935 (((-3 $ "failed") $) 75)) (-2062 ((|#4| |#4| $) 82)) (-3924 (($ $) 67 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519))))) (-4328 (($ |#4| $) 66 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) |#4|) $) 63 (|has| $ (-6 -4519)))) (-1500 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-558)))) (-1281 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) 95)) (-4079 ((|#4| |#4| $) 80)) (-3092 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4519))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4519))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 87)) (-3635 (((-2 (|:| -4092 (-634 |#4|)) (|:| -1798 (-634 |#4|))) $) 98)) (-1862 (((-121) |#4| $) 129)) (-4286 (((-121) |#4| $) 126)) (-3193 (((-121) |#4| $) 130) (((-121) $) 127)) (-4360 (((-634 |#4|) $) 51 (|has| $ (-6 -4519)))) (-1362 (((-121) |#4| $) 97) (((-121) $) 96)) (-2356 ((|#3| $) 33)) (-1737 (((-121) $ (-763)) 42)) (-1979 (((-634 |#4|) $) 52 (|has| $ (-6 -4519)))) (-3109 (((-121) |#4| $) 54 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#4| |#4|) $) 46)) (-1432 (((-634 |#3|) $) 31)) (-3392 (((-121) |#3| $) 30)) (-2166 (((-121) $ (-763)) 41)) (-4487 (((-1143) $) 9)) (-2717 (((-3 |#4| (-634 $)) |#4| |#4| $) 121)) (-4330 (((-634 (-2 (|:| |val| |#4|) (|:| -3001 $))) |#4| |#4| $) 120)) (-4162 (((-3 |#4| "failed") $) 76)) (-2335 (((-634 $) |#4| $) 122)) (-1719 (((-3 (-121) (-634 $)) |#4| $) 125)) (-2632 (((-634 (-2 (|:| |val| (-121)) (|:| -3001 $))) |#4| $) 124) (((-121) |#4| $) 123)) (-3212 (((-634 $) |#4| $) 118) (((-634 $) (-634 |#4|) $) 117) (((-634 $) (-634 |#4|) (-634 $)) 116) (((-634 $) |#4| (-634 $)) 115)) (-3473 (($ |#4| $) 110) (($ (-634 |#4|) $) 109)) (-1377 (((-634 |#4|) $) 100)) (-1415 (((-121) |#4| $) 92) (((-121) $) 88)) (-2682 ((|#4| |#4| $) 83)) (-2644 (((-121) $ $) 103)) (-2705 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-558)))) (-4347 (((-121) |#4| $) 93) (((-121) $) 89)) (-4025 ((|#4| |#4| $) 84)) (-4022 (((-1108) $) 10)) (-3876 (((-3 |#4| "failed") $) 77)) (-3775 (((-3 |#4| "failed") (-1 (-121) |#4|) $) 60)) (-1665 (((-3 $ "failed") $ |#4|) 71)) (-1807 (($ $ |#4|) 70) (((-634 $) |#4| $) 108) (((-634 $) |#4| (-634 $)) 107) (((-634 $) (-634 |#4|) $) 106) (((-634 $) (-634 |#4|) (-634 $)) 105)) (-1387 (((-121) (-1 (-121) |#4|) $) 49 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 |#4|) (-634 |#4|)) 58 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) 56 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 (-288 |#4|))) 55 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-3171 (((-121) $ $) 37)) (-3084 (((-121) $) 40)) (-3248 (($) 39)) (-3206 (((-763) $) 99)) (-4168 (((-763) |#4| $) 53 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519)))) (((-763) (-1 (-121) |#4|) $) 50 (|has| $ (-6 -4519)))) (-3863 (($ $) 38)) (-4278 (((-541) $) 68 (|has| |#4| (-609 (-541))))) (-4287 (($ (-634 |#4|)) 59)) (-1290 (($ $ |#3|) 27)) (-3732 (($ $ |#3|) 29)) (-1567 (($ $) 81)) (-3944 (($ $ |#3|) 28)) (-2745 (((-850) $) 11) (((-634 |#4|) $) 36)) (-1878 (((-763) $) 69 (|has| |#3| (-370)))) (-3556 (((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4| |#4|)) 102) (((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) 101)) (-3292 (((-121) $ (-1 (-121) |#4| (-634 |#4|))) 91)) (-2574 (((-634 $) |#4| $) 114) (((-634 $) |#4| (-634 $)) 113) (((-634 $) (-634 |#4|) $) 112) (((-634 $) (-634 |#4|) (-634 $)) 111)) (-1319 (((-121) (-1 (-121) |#4|) $) 48 (|has| $ (-6 -4519)))) (-2739 (((-634 |#3|) $) 74)) (-2288 (((-121) |#4| $) 128)) (-4390 (((-121) |#3| $) 73)) (-1717 (((-121) $ $) 6)) (-1697 (((-763) $) 45 (|has| $ (-6 -4519))))) 
+((-1561 (((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-634 |#4|) (-634 |#5|) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) (-763)) 95)) (-2742 (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5|) 56) (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5| (-763)) 55)) (-1277 (((-1249) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-763)) 87)) (-1490 (((-763) (-634 |#4|) (-634 |#5|)) 27)) (-1837 (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5|) 58) (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5| (-763)) 57) (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5| (-763) (-121)) 59)) (-3946 (((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121) (-121) (-121) (-121)) 78) (((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121)) 79)) (-4280 (((-1143) (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) 82)) (-3489 (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5| (-121)) 54)) (-3006 (((-763) (-634 |#4|) (-634 |#5|)) 19))) 
+(((-1064 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3006 ((-763) (-634 |#4|) (-634 |#5|))) (-15 -1490 ((-763) (-634 |#4|) (-634 |#5|))) (-15 -3489 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5| (-121))) (-15 -2742 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5| (-763))) (-15 -2742 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5|)) (-15 -1837 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5| (-763) (-121))) (-15 -1837 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5| (-763))) (-15 -1837 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5|)) (-15 -3946 ((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121))) (-15 -3946 ((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121) (-121) (-121) (-121))) (-15 -1561 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-634 |#4|) (-634 |#5|) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) (-763))) (-15 -4280 ((-1143) (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|)))) (-15 -1277 ((-1249) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-763)))) (-453) (-788) (-842) (-1061 |#1| |#2| |#3|) (-1066 |#1| |#2| |#3| |#4|)) (T -1064)) 
+((-1277 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-2 (|:| |val| (-634 *8)) (|:| -3145 *9)))) (-5 *4 (-763)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-1249)) (-5 *1 (-1064 *5 *6 *7 *8 *9)))) (-4280 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |val| (-634 *7)) (|:| -3145 *8))) (-4 *7 (-1061 *4 *5 *6)) (-4 *8 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1143)) (-5 *1 (-1064 *4 *5 *6 *7 *8)))) (-1561 (*1 *2 *3 *4 *2 *5 *6) (-12 (-5 *5 (-2 (|:| |done| (-634 *11)) (|:| |todo| (-634 (-2 (|:| |val| *3) (|:| -3145 *11)))))) (-5 *6 (-763)) (-5 *2 (-634 (-2 (|:| |val| (-634 *10)) (|:| -3145 *11)))) (-5 *3 (-634 *10)) (-5 *4 (-634 *11)) (-4 *10 (-1061 *7 *8 *9)) (-4 *11 (-1066 *7 *8 *9 *10)) (-4 *7 (-453)) (-4 *8 (-788)) (-4 *9 (-842)) (-5 *1 (-1064 *7 *8 *9 *10 *11)))) (-3946 (*1 *2 *3 *2 *4 *4 *4 *4 *4) (-12 (-5 *2 (-634 *9)) (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1064 *5 *6 *7 *8 *9)))) (-3946 (*1 *2 *3 *2 *4 *4) (-12 (-5 *2 (-634 *9)) (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1064 *5 *6 *7 *8 *9)))) (-1837 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1064 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-1837 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-763)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1064 *6 *7 *8 *3 *4)) (-4 *4 (-1066 *6 *7 *8 *3)))) (-1837 (*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-763)) (-5 *6 (-121)) (-4 *7 (-453)) (-4 *8 (-788)) (-4 *9 (-842)) (-4 *3 (-1061 *7 *8 *9)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1064 *7 *8 *9 *3 *4)) (-4 *4 (-1066 *7 *8 *9 *3)))) (-2742 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1064 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-2742 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-763)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1064 *6 *7 *8 *3 *4)) (-4 *4 (-1066 *6 *7 *8 *3)))) (-3489 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-121)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1064 *6 *7 *8 *3 *4)) (-4 *4 (-1066 *6 *7 *8 *3)))) (-1490 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 *9)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-763)) (-5 *1 (-1064 *5 *6 *7 *8 *9)))) (-3006 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 *9)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-763)) (-5 *1 (-1064 *5 *6 *7 *8 *9))))) 
+(-10 -7 (-15 -3006 ((-763) (-634 |#4|) (-634 |#5|))) (-15 -1490 ((-763) (-634 |#4|) (-634 |#5|))) (-15 -3489 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5| (-121))) (-15 -2742 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5| (-763))) (-15 -2742 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5|)) (-15 -1837 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5| (-763) (-121))) (-15 -1837 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5| (-763))) (-15 -1837 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5|)) (-15 -3946 ((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121))) (-15 -3946 ((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121) (-121) (-121) (-121))) (-15 -1561 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-634 |#4|) (-634 |#5|) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) (-763))) (-15 -4280 ((-1143) (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|)))) (-15 -1277 ((-1249) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-763)))) 
+((-2451 (((-121) |#5| $) 20)) (-2978 (((-121) |#5| $) 23)) (-1792 (((-121) |#5| $) 16) (((-121) $) 44)) (-1864 (((-634 $) |#5| $) NIL) (((-634 $) (-634 |#5|) $) 76) (((-634 $) (-634 |#5|) (-634 $)) 74) (((-634 $) |#5| (-634 $)) 77)) (-2168 (($ $ |#5|) NIL) (((-634 $) |#5| $) NIL) (((-634 $) |#5| (-634 $)) 59) (((-634 $) (-634 |#5|) $) 61) (((-634 $) (-634 |#5|) (-634 $)) 63)) (-1977 (((-634 $) |#5| $) NIL) (((-634 $) |#5| (-634 $)) 53) (((-634 $) (-634 |#5|) $) 55) (((-634 $) (-634 |#5|) (-634 $)) 57)) (-3541 (((-121) |#5| $) 26))) 
+(((-1065 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 -2168 ((-634 |#1|) (-634 |#5|) (-634 |#1|))) (-15 -2168 ((-634 |#1|) (-634 |#5|) |#1|)) (-15 -2168 ((-634 |#1|) |#5| (-634 |#1|))) (-15 -2168 ((-634 |#1|) |#5| |#1|)) (-15 -1977 ((-634 |#1|) (-634 |#5|) (-634 |#1|))) (-15 -1977 ((-634 |#1|) (-634 |#5|) |#1|)) (-15 -1977 ((-634 |#1|) |#5| (-634 |#1|))) (-15 -1977 ((-634 |#1|) |#5| |#1|)) (-15 -1864 ((-634 |#1|) |#5| (-634 |#1|))) (-15 -1864 ((-634 |#1|) (-634 |#5|) (-634 |#1|))) (-15 -1864 ((-634 |#1|) (-634 |#5|) |#1|)) (-15 -1864 ((-634 |#1|) |#5| |#1|)) (-15 -2978 ((-121) |#5| |#1|)) (-15 -1792 ((-121) |#1|)) (-15 -3541 ((-121) |#5| |#1|)) (-15 -2451 ((-121) |#5| |#1|)) (-15 -1792 ((-121) |#5| |#1|)) (-15 -2168 (|#1| |#1| |#5|))) (-1066 |#2| |#3| |#4| |#5|) (-453) (-788) (-842) (-1061 |#2| |#3| |#4|)) (T -1065)) 
+NIL 
+(-10 -8 (-15 -2168 ((-634 |#1|) (-634 |#5|) (-634 |#1|))) (-15 -2168 ((-634 |#1|) (-634 |#5|) |#1|)) (-15 -2168 ((-634 |#1|) |#5| (-634 |#1|))) (-15 -2168 ((-634 |#1|) |#5| |#1|)) (-15 -1977 ((-634 |#1|) (-634 |#5|) (-634 |#1|))) (-15 -1977 ((-634 |#1|) (-634 |#5|) |#1|)) (-15 -1977 ((-634 |#1|) |#5| (-634 |#1|))) (-15 -1977 ((-634 |#1|) |#5| |#1|)) (-15 -1864 ((-634 |#1|) |#5| (-634 |#1|))) (-15 -1864 ((-634 |#1|) (-634 |#5|) (-634 |#1|))) (-15 -1864 ((-634 |#1|) (-634 |#5|) |#1|)) (-15 -1864 ((-634 |#1|) |#5| |#1|)) (-15 -2978 ((-121) |#5| |#1|)) (-15 -1792 ((-121) |#1|)) (-15 -3541 ((-121) |#5| |#1|)) (-15 -2451 ((-121) |#5| |#1|)) (-15 -1792 ((-121) |#5| |#1|)) (-15 -2168 (|#1| |#1| |#5|))) 
+((-2449 (((-121) $ $) 7)) (-2213 (((-634 (-2 (|:| -4094 $) (|:| -2133 (-634 |#4|)))) (-634 |#4|)) 78)) (-2353 (((-634 $) (-634 |#4|)) 79) (((-634 $) (-634 |#4|) (-121)) 104)) (-2057 (((-634 |#3|) $) 32)) (-4141 (((-121) $) 25)) (-1794 (((-121) $) 16 (|has| |#1| (-558)))) (-4231 (((-121) |#4| $) 94) (((-121) $) 90)) (-3767 ((|#4| |#4| $) 85)) (-3045 (((-634 (-2 (|:| |val| |#4|) (|:| -3145 $))) |#4| $) 119)) (-3647 (((-2 (|:| |under| $) (|:| -4115 $) (|:| |upper| $)) $ |#3|) 26)) (-1667 (((-121) $ (-763)) 43)) (-2803 (($ (-1 (-121) |#4|) $) 64 (|has| $ (-6 -4521))) (((-3 |#4| "failed") $ |#3|) 72)) (-4490 (($) 44 T CONST)) (-4382 (((-121) $) 21 (|has| |#1| (-558)))) (-1880 (((-121) $ $) 23 (|has| |#1| (-558)))) (-2536 (((-121) $ $) 22 (|has| |#1| (-558)))) (-2343 (((-121) $) 24 (|has| |#1| (-558)))) (-2941 (((-634 |#4|) (-634 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 86)) (-3993 (((-634 |#4|) (-634 |#4|) $) 17 (|has| |#1| (-558)))) (-2727 (((-634 |#4|) (-634 |#4|) $) 18 (|has| |#1| (-558)))) (-3668 (((-3 $ "failed") (-634 |#4|)) 35)) (-2857 (($ (-634 |#4|)) 34)) (-3936 (((-3 $ "failed") $) 75)) (-3255 ((|#4| |#4| $) 82)) (-3926 (($ $) 67 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521))))) (-4330 (($ |#4| $) 66 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) |#4|) $) 63 (|has| $ (-6 -4521)))) (-2607 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-558)))) (-1359 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) 95)) (-3434 ((|#4| |#4| $) 80)) (-3094 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4521))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4521))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 87)) (-3158 (((-2 (|:| -4094 (-634 |#4|)) (|:| -2133 (-634 |#4|))) $) 98)) (-2451 (((-121) |#4| $) 129)) (-2978 (((-121) |#4| $) 126)) (-1792 (((-121) |#4| $) 130) (((-121) $) 127)) (-3317 (((-634 |#4|) $) 51 (|has| $ (-6 -4521)))) (-3764 (((-121) |#4| $) 97) (((-121) $) 96)) (-4001 ((|#3| $) 33)) (-3791 (((-121) $ (-763)) 42)) (-4406 (((-634 |#4|) $) 52 (|has| $ (-6 -4521)))) (-2551 (((-121) |#4| $) 54 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#4| |#4|) $) 46)) (-2249 (((-634 |#3|) $) 31)) (-1495 (((-121) |#3| $) 30)) (-3796 (((-121) $ (-763)) 41)) (-1893 (((-1143) $) 9)) (-1516 (((-3 |#4| (-634 $)) |#4| |#4| $) 121)) (-3137 (((-634 (-2 (|:| |val| |#4|) (|:| -3145 $))) |#4| |#4| $) 120)) (-4164 (((-3 |#4| "failed") $) 76)) (-3878 (((-634 $) |#4| $) 122)) (-3712 (((-3 (-121) (-634 $)) |#4| $) 125)) (-4266 (((-634 (-2 (|:| |val| (-121)) (|:| -3145 $))) |#4| $) 124) (((-121) |#4| $) 123)) (-1864 (((-634 $) |#4| $) 118) (((-634 $) (-634 |#4|) $) 117) (((-634 $) (-634 |#4|) (-634 $)) 116) (((-634 $) |#4| (-634 $)) 115)) (-3736 (($ |#4| $) 110) (($ (-634 |#4|) $) 109)) (-3882 (((-634 |#4|) $) 100)) (-2157 (((-121) |#4| $) 92) (((-121) $) 88)) (-1315 ((|#4| |#4| $) 83)) (-4342 (((-121) $ $) 103)) (-1440 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-558)))) (-3236 (((-121) |#4| $) 93) (((-121) $) 89)) (-1452 ((|#4| |#4| $) 84)) (-4025 (((-1108) $) 10)) (-3877 (((-3 |#4| "failed") $) 77)) (-2712 (((-3 |#4| "failed") (-1 (-121) |#4|) $) 60)) (-3413 (((-3 $ "failed") $ |#4|) 71)) (-2168 (($ $ |#4|) 70) (((-634 $) |#4| $) 108) (((-634 $) |#4| (-634 $)) 107) (((-634 $) (-634 |#4|) $) 106) (((-634 $) (-634 |#4|) (-634 $)) 105)) (-3951 (((-121) (-1 (-121) |#4|) $) 49 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 |#4|) (-634 |#4|)) 58 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) 56 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 (-288 |#4|))) 55 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-1702 (((-121) $ $) 37)) (-2436 (((-121) $) 40)) (-1990 (($) 39)) (-1836 (((-763) $) 99)) (-4170 (((-763) |#4| $) 53 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521)))) (((-763) (-1 (-121) |#4|) $) 50 (|has| $ (-6 -4521)))) (-3865 (($ $) 38)) (-4280 (((-541) $) 68 (|has| |#4| (-609 (-541))))) (-4289 (($ (-634 |#4|)) 59)) (-3206 (($ $ |#3|) 27)) (-2527 (($ $ |#3|) 29)) (-4392 (($ $) 81)) (-4332 (($ $ |#3|) 28)) (-2747 (((-850) $) 11) (((-634 |#4|) $) 36)) (-2524 (((-763) $) 69 (|has| |#3| (-370)))) (-2835 (((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4| |#4|)) 102) (((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) 101)) (-2145 (((-121) $ (-1 (-121) |#4| (-634 |#4|))) 91)) (-1977 (((-634 $) |#4| $) 114) (((-634 $) |#4| (-634 $)) 113) (((-634 $) (-634 |#4|) $) 112) (((-634 $) (-634 |#4|) (-634 $)) 111)) (-3437 (((-121) (-1 (-121) |#4|) $) 48 (|has| $ (-6 -4521)))) (-3321 (((-634 |#3|) $) 74)) (-3541 (((-121) |#4| $) 128)) (-1413 (((-121) |#3| $) 73)) (-1719 (((-121) $ $) 6)) (-1699 (((-763) $) 45 (|has| $ (-6 -4521))))) 
 (((-1066 |#1| |#2| |#3| |#4|) (-1275) (-453) (-788) (-842) (-1061 |t#1| |t#2| |t#3|)) (T -1066)) 
-((-3193 (*1 *2 *3 *1) (-12 (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121)))) (-1862 (*1 *2 *3 *1) (-12 (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121)))) (-2288 (*1 *2 *3 *1) (-12 (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121)))) (-3193 (*1 *2 *1) (-12 (-4 *1 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) (-4286 (*1 *2 *3 *1) (-12 (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121)))) (-1719 (*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-3 (-121) (-634 *1))) (-4 *1 (-1066 *4 *5 *6 *3)))) (-2632 (*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3001 *1)))) (-4 *1 (-1066 *4 *5 *6 *3)))) (-2632 (*1 *2 *3 *1) (-12 (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121)))) (-2335 (*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)))) (-2717 (*1 *2 *3 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-3 *3 (-634 *1))) (-4 *1 (-1066 *4 *5 *6 *3)))) (-4330 (*1 *2 *3 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *1)))) (-4 *1 (-1066 *4 *5 *6 *3)))) (-4305 (*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *1)))) (-4 *1 (-1066 *4 *5 *6 *3)))) (-3212 (*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)))) (-3212 (*1 *2 *3 *1) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *7)))) (-3212 (*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-5 *3 (-634 *7)) (-4 *1 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)))) (-3212 (*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)))) (-2574 (*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)))) (-2574 (*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)))) (-2574 (*1 *2 *3 *1) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *7)))) (-2574 (*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-5 *3 (-634 *7)) (-4 *1 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)))) (-3473 (*1 *1 *2 *1) (-12 (-4 *1 (-1066 *3 *4 *5 *2)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) (-3473 (*1 *1 *2 *1) (-12 (-5 *2 (-634 *6)) (-4 *1 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)))) (-1807 (*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)))) (-1807 (*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)))) (-1807 (*1 *2 *3 *1) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *7)))) (-1807 (*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-5 *3 (-634 *7)) (-4 *1 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)))) (-2415 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *5 *6 *7 *8))))) 
-(-13 (-1189 |t#1| |t#2| |t#3| |t#4|) (-10 -8 (-15 -3193 ((-121) |t#4| $)) (-15 -1862 ((-121) |t#4| $)) (-15 -2288 ((-121) |t#4| $)) (-15 -3193 ((-121) $)) (-15 -4286 ((-121) |t#4| $)) (-15 -1719 ((-3 (-121) (-634 $)) |t#4| $)) (-15 -2632 ((-634 (-2 (|:| |val| (-121)) (|:| -3001 $))) |t#4| $)) (-15 -2632 ((-121) |t#4| $)) (-15 -2335 ((-634 $) |t#4| $)) (-15 -2717 ((-3 |t#4| (-634 $)) |t#4| |t#4| $)) (-15 -4330 ((-634 (-2 (|:| |val| |t#4|) (|:| -3001 $))) |t#4| |t#4| $)) (-15 -4305 ((-634 (-2 (|:| |val| |t#4|) (|:| -3001 $))) |t#4| $)) (-15 -3212 ((-634 $) |t#4| $)) (-15 -3212 ((-634 $) (-634 |t#4|) $)) (-15 -3212 ((-634 $) (-634 |t#4|) (-634 $))) (-15 -3212 ((-634 $) |t#4| (-634 $))) (-15 -2574 ((-634 $) |t#4| $)) (-15 -2574 ((-634 $) |t#4| (-634 $))) (-15 -2574 ((-634 $) (-634 |t#4|) $)) (-15 -2574 ((-634 $) (-634 |t#4|) (-634 $))) (-15 -3473 ($ |t#4| $)) (-15 -3473 ($ (-634 |t#4|) $)) (-15 -1807 ((-634 $) |t#4| $)) (-15 -1807 ((-634 $) |t#4| (-634 $))) (-15 -1807 ((-634 $) (-634 |t#4|) $)) (-15 -1807 ((-634 $) (-634 |t#4|) (-634 $))) (-15 -2415 ((-634 $) (-634 |t#4|) (-121))))) 
+((-1792 (*1 *2 *3 *1) (-12 (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121)))) (-2451 (*1 *2 *3 *1) (-12 (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121)))) (-3541 (*1 *2 *3 *1) (-12 (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121)))) (-1792 (*1 *2 *1) (-12 (-4 *1 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) (-2978 (*1 *2 *3 *1) (-12 (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121)))) (-3712 (*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-3 (-121) (-634 *1))) (-4 *1 (-1066 *4 *5 *6 *3)))) (-4266 (*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3145 *1)))) (-4 *1 (-1066 *4 *5 *6 *3)))) (-4266 (*1 *2 *3 *1) (-12 (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121)))) (-3878 (*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)))) (-1516 (*1 *2 *3 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-3 *3 (-634 *1))) (-4 *1 (-1066 *4 *5 *6 *3)))) (-3137 (*1 *2 *3 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *1)))) (-4 *1 (-1066 *4 *5 *6 *3)))) (-3045 (*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *1)))) (-4 *1 (-1066 *4 *5 *6 *3)))) (-1864 (*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)))) (-1864 (*1 *2 *3 *1) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *7)))) (-1864 (*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-5 *3 (-634 *7)) (-4 *1 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)))) (-1864 (*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)))) (-1977 (*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)))) (-1977 (*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)))) (-1977 (*1 *2 *3 *1) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *7)))) (-1977 (*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-5 *3 (-634 *7)) (-4 *1 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)))) (-3736 (*1 *1 *2 *1) (-12 (-4 *1 (-1066 *3 *4 *5 *2)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) (-3736 (*1 *1 *2 *1) (-12 (-5 *2 (-634 *6)) (-4 *1 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)))) (-2168 (*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)))) (-2168 (*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)))) (-2168 (*1 *2 *3 *1) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *7)))) (-2168 (*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-5 *3 (-634 *7)) (-4 *1 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)))) (-2353 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *5 *6 *7 *8))))) 
+(-13 (-1189 |t#1| |t#2| |t#3| |t#4|) (-10 -8 (-15 -1792 ((-121) |t#4| $)) (-15 -2451 ((-121) |t#4| $)) (-15 -3541 ((-121) |t#4| $)) (-15 -1792 ((-121) $)) (-15 -2978 ((-121) |t#4| $)) (-15 -3712 ((-3 (-121) (-634 $)) |t#4| $)) (-15 -4266 ((-634 (-2 (|:| |val| (-121)) (|:| -3145 $))) |t#4| $)) (-15 -4266 ((-121) |t#4| $)) (-15 -3878 ((-634 $) |t#4| $)) (-15 -1516 ((-3 |t#4| (-634 $)) |t#4| |t#4| $)) (-15 -3137 ((-634 (-2 (|:| |val| |t#4|) (|:| -3145 $))) |t#4| |t#4| $)) (-15 -3045 ((-634 (-2 (|:| |val| |t#4|) (|:| -3145 $))) |t#4| $)) (-15 -1864 ((-634 $) |t#4| $)) (-15 -1864 ((-634 $) (-634 |t#4|) $)) (-15 -1864 ((-634 $) (-634 |t#4|) (-634 $))) (-15 -1864 ((-634 $) |t#4| (-634 $))) (-15 -1977 ((-634 $) |t#4| $)) (-15 -1977 ((-634 $) |t#4| (-634 $))) (-15 -1977 ((-634 $) (-634 |t#4|) $)) (-15 -1977 ((-634 $) (-634 |t#4|) (-634 $))) (-15 -3736 ($ |t#4| $)) (-15 -3736 ($ (-634 |t#4|) $)) (-15 -2168 ((-634 $) |t#4| $)) (-15 -2168 ((-634 $) |t#4| (-634 $))) (-15 -2168 ((-634 $) (-634 |t#4|) $)) (-15 -2168 ((-634 $) (-634 |t#4|) (-634 $))) (-15 -2353 ((-634 $) (-634 |t#4|) (-121))))) 
 (((-39) . T) ((-105) . T) ((-608 (-634 |#4|)) . T) ((-608 (-850)) . T) ((-154 |#4|) . T) ((-609 (-541)) |has| |#4| (-609 (-541))) ((-303 |#4|) -12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))) ((-499 |#4|) . T) ((-523 |#4| |#4|) -12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))) ((-977 |#1| |#2| |#3| |#4|) . T) ((-1090) . T) ((-1189 |#1| |#2| |#3| |#4|) . T) ((-1195) . T)) 
-((-3418 (((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#5|) 81)) (-3855 (((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#4| |#5|) 112)) (-2686 (((-634 |#5|) |#4| |#5|) 70)) (-1421 (((-634 (-2 (|:| |val| (-121)) (|:| -3001 |#5|))) |#4| |#5|) 44) (((-121) |#4| |#5|) 52)) (-3818 (((-1249)) 35)) (-2270 (((-1249)) 25)) (-3194 (((-1249) (-1143) (-1143) (-1143)) 31)) (-3179 (((-1249) (-1143) (-1143) (-1143)) 20)) (-4230 (((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) |#4| |#4| |#5|) 95)) (-2222 (((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) |#3| (-121)) 106) (((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#4| |#5| (-121) (-121)) 49)) (-2364 (((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#4| |#5|) 101))) 
-(((-1067 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3179 ((-1249) (-1143) (-1143) (-1143))) (-15 -2270 ((-1249))) (-15 -3194 ((-1249) (-1143) (-1143) (-1143))) (-15 -3818 ((-1249))) (-15 -4230 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) |#4| |#4| |#5|)) (-15 -2222 ((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#4| |#5| (-121) (-121))) (-15 -2222 ((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) |#3| (-121))) (-15 -2364 ((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#4| |#5|)) (-15 -3855 ((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#4| |#5|)) (-15 -1421 ((-121) |#4| |#5|)) (-15 -1421 ((-634 (-2 (|:| |val| (-121)) (|:| -3001 |#5|))) |#4| |#5|)) (-15 -2686 ((-634 |#5|) |#4| |#5|)) (-15 -3418 ((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#5|))) (-453) (-788) (-842) (-1061 |#1| |#2| |#3|) (-1066 |#1| |#2| |#3| |#4|)) (T -1067)) 
-((-3418 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *4)))) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-2686 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 *4)) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-1421 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3001 *4)))) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-1421 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-3855 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *4)))) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-2364 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *4)))) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-2222 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-2 (|:| |val| (-634 *8)) (|:| -3001 *9)))) (-5 *5 (-121)) (-4 *8 (-1061 *6 *7 *4)) (-4 *9 (-1066 *6 *7 *4 *8)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *4 (-842)) (-5 *2 (-634 (-2 (|:| |val| *8) (|:| -3001 *9)))) (-5 *1 (-1067 *6 *7 *4 *8 *9)))) (-2222 (*1 *2 *3 *3 *4 *5 *5) (-12 (-5 *5 (-121)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *4)))) (-5 *1 (-1067 *6 *7 *8 *3 *4)) (-4 *4 (-1066 *6 *7 *8 *3)))) (-4230 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-3818 (*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-1067 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6)))) (-3194 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-1067 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) (-2270 (*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-1067 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6)))) (-3179 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-1067 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7))))) 
-(-10 -7 (-15 -3179 ((-1249) (-1143) (-1143) (-1143))) (-15 -2270 ((-1249))) (-15 -3194 ((-1249) (-1143) (-1143) (-1143))) (-15 -3818 ((-1249))) (-15 -4230 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) |#4| |#4| |#5|)) (-15 -2222 ((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#4| |#5| (-121) (-121))) (-15 -2222 ((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) |#3| (-121))) (-15 -2364 ((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#4| |#5|)) (-15 -3855 ((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#4| |#5|)) (-15 -1421 ((-121) |#4| |#5|)) (-15 -1421 ((-634 (-2 (|:| |val| (-121)) (|:| -3001 |#5|))) |#4| |#5|)) (-15 -2686 ((-634 |#5|) |#4| |#5|)) (-15 -3418 ((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#5|))) 
-((-2447 (((-121) $ $) NIL)) (-3391 (((-1161) $) 8)) (-4487 (((-1143) $) 16)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 11)) (-1717 (((-121) $ $) 13))) 
-(((-1068 |#1|) (-13 (-1090) (-10 -8 (-15 -3391 ((-1161) $)))) (-1161)) (T -1068)) 
-((-3391 (*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-1068 *3)) (-14 *3 *2)))) 
-(-13 (-1090) (-10 -8 (-15 -3391 ((-1161) $)))) 
-((-2447 (((-121) $ $) NIL)) (-1562 (($ $ (-634 (-1161)) (-1 (-121) (-634 |#3|))) 29)) (-3360 (($ |#3| |#3|) 21) (($ |#3| |#3| (-634 (-1161))) 19)) (-2107 ((|#3| $) 13)) (-3666 (((-3 (-288 |#3|) "failed") $) 56)) (-2854 (((-288 |#3|) $) NIL)) (-2284 (((-634 (-1161)) $) 15)) (-1561 (((-887 |#1|) $) 11)) (-1466 ((|#3| $) 12)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2779 ((|#3| $ |#3|) 25) ((|#3| $ |#3| (-917)) 36)) (-2745 (((-850) $) 84) (($ (-288 |#3|)) 20)) (-1717 (((-121) $ $) 33))) 
-(((-1069 |#1| |#2| |#3|) (-13 (-1090) (-281 |#3| |#3|) (-1037 (-288 |#3|)) (-10 -8 (-15 -3360 ($ |#3| |#3|)) (-15 -3360 ($ |#3| |#3| (-634 (-1161)))) (-15 -1562 ($ $ (-634 (-1161)) (-1 (-121) (-634 |#3|)))) (-15 -1561 ((-887 |#1|) $)) (-15 -1466 (|#3| $)) (-15 -2107 (|#3| $)) (-15 -2779 (|#3| $ |#3| (-917))) (-15 -2284 ((-634 (-1161)) $)))) (-1090) (-13 (-1047) (-881 |#1|) (-842) (-609 (-887 |#1|))) (-13 (-432 |#2|) (-881 |#1|) (-609 (-887 |#1|)))) (T -1069)) 
-((-3360 (*1 *1 *2 *2) (-12 (-4 *3 (-1090)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 (-887 *3)))) (-5 *1 (-1069 *3 *4 *2)) (-4 *2 (-13 (-432 *4) (-881 *3) (-609 (-887 *3)))))) (-3360 (*1 *1 *2 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-5 *1 (-1069 *4 *5 *2)) (-4 *2 (-13 (-432 *5) (-881 *4) (-609 (-887 *4)))))) (-1562 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-1 (-121) (-634 *6))) (-4 *6 (-13 (-432 *5) (-881 *4) (-609 (-887 *4)))) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-5 *1 (-1069 *4 *5 *6)))) (-1561 (*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 *2))) (-5 *2 (-887 *3)) (-5 *1 (-1069 *3 *4 *5)) (-4 *5 (-13 (-432 *4) (-881 *3) (-609 *2))))) (-1466 (*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *2 (-13 (-432 *4) (-881 *3) (-609 (-887 *3)))) (-5 *1 (-1069 *3 *4 *2)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 (-887 *3)))))) (-2107 (*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *2 (-13 (-432 *4) (-881 *3) (-609 (-887 *3)))) (-5 *1 (-1069 *3 *4 *2)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 (-887 *3)))))) (-2779 (*1 *2 *1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-5 *1 (-1069 *4 *5 *2)) (-4 *2 (-13 (-432 *5) (-881 *4) (-609 (-887 *4)))))) (-2284 (*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 (-887 *3)))) (-5 *2 (-634 (-1161))) (-5 *1 (-1069 *3 *4 *5)) (-4 *5 (-13 (-432 *4) (-881 *3) (-609 (-887 *3))))))) 
-(-13 (-1090) (-281 |#3| |#3|) (-1037 (-288 |#3|)) (-10 -8 (-15 -3360 ($ |#3| |#3|)) (-15 -3360 ($ |#3| |#3| (-634 (-1161)))) (-15 -1562 ($ $ (-634 (-1161)) (-1 (-121) (-634 |#3|)))) (-15 -1561 ((-887 |#1|) $)) (-15 -1466 (|#3| $)) (-15 -2107 (|#3| $)) (-15 -2779 (|#3| $ |#3| (-917))) (-15 -2284 ((-634 (-1161)) $)))) 
-((-2447 (((-121) $ $) NIL)) (-3385 (($ (-634 (-1069 |#1| |#2| |#3|))) 12)) (-2094 (((-634 (-1069 |#1| |#2| |#3|)) $) 19)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2779 ((|#3| $ |#3|) 22) ((|#3| $ |#3| (-917)) 25)) (-2745 (((-850) $) 15)) (-1717 (((-121) $ $) 18))) 
-(((-1070 |#1| |#2| |#3|) (-13 (-1090) (-281 |#3| |#3|) (-10 -8 (-15 -3385 ($ (-634 (-1069 |#1| |#2| |#3|)))) (-15 -2094 ((-634 (-1069 |#1| |#2| |#3|)) $)) (-15 -2779 (|#3| $ |#3| (-917))))) (-1090) (-13 (-1047) (-881 |#1|) (-842) (-609 (-887 |#1|))) (-13 (-432 |#2|) (-881 |#1|) (-609 (-887 |#1|)))) (T -1070)) 
-((-3385 (*1 *1 *2) (-12 (-5 *2 (-634 (-1069 *3 *4 *5))) (-4 *3 (-1090)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 (-887 *3)))) (-4 *5 (-13 (-432 *4) (-881 *3) (-609 (-887 *3)))) (-5 *1 (-1070 *3 *4 *5)))) (-2094 (*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 (-887 *3)))) (-5 *2 (-634 (-1069 *3 *4 *5))) (-5 *1 (-1070 *3 *4 *5)) (-4 *5 (-13 (-432 *4) (-881 *3) (-609 (-887 *3)))))) (-2779 (*1 *2 *1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-5 *1 (-1070 *4 *5 *2)) (-4 *2 (-13 (-432 *5) (-881 *4) (-609 (-887 *4))))))) 
-(-13 (-1090) (-281 |#3| |#3|) (-10 -8 (-15 -3385 ($ (-634 (-1069 |#1| |#2| |#3|)))) (-15 -2094 ((-634 (-1069 |#1| |#2| |#3|)) $)) (-15 -2779 (|#3| $ |#3| (-917))))) 
-((-2067 (((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121) (-121)) 73) (((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-634 (-953 |#1|))) 75) (((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121)) 74))) 
-(((-1071 |#1| |#2|) (-10 -7 (-15 -2067 ((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121))) (-15 -2067 ((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-634 (-953 |#1|)))) (-15 -2067 ((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121) (-121)))) (-13 (-301) (-150)) (-634 (-1161))) (T -1071)) 
-((-2067 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-5 *2 (-634 (-2 (|:| -3471 (-1157 *5)) (|:| -4073 (-634 (-953 *5)))))) (-5 *1 (-1071 *5 *6)) (-5 *3 (-634 (-953 *5))) (-14 *6 (-634 (-1161))))) (-2067 (*1 *2 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-5 *2 (-634 (-2 (|:| -3471 (-1157 *4)) (|:| -4073 (-634 (-953 *4)))))) (-5 *1 (-1071 *4 *5)) (-5 *3 (-634 (-953 *4))) (-14 *5 (-634 (-1161))))) (-2067 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-5 *2 (-634 (-2 (|:| -3471 (-1157 *5)) (|:| -4073 (-634 (-953 *5)))))) (-5 *1 (-1071 *5 *6)) (-5 *3 (-634 (-953 *5))) (-14 *6 (-634 (-1161)))))) 
-(-10 -7 (-15 -2067 ((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121))) (-15 -2067 ((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-634 (-953 |#1|)))) (-15 -2067 ((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121) (-121)))) 
-((-3848 (((-420 |#3|) |#3|) 16))) 
-(((-1072 |#1| |#2| |#3|) (-10 -7 (-15 -3848 ((-420 |#3|) |#3|))) (-1219 (-409 (-568))) (-13 (-365) (-150) (-714 (-409 (-568)) |#1|)) (-1219 |#2|)) (T -1072)) 
-((-3848 (*1 *2 *3) (-12 (-4 *4 (-1219 (-409 (-568)))) (-4 *5 (-13 (-365) (-150) (-714 (-409 (-568)) *4))) (-5 *2 (-420 *3)) (-5 *1 (-1072 *4 *5 *3)) (-4 *3 (-1219 *5))))) 
-(-10 -7 (-15 -3848 ((-420 |#3|) |#3|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 125)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-365)))) (-2227 (($ $) NIL (|has| |#1| (-365)))) (-1573 (((-121) $) NIL (|has| |#1| (-365)))) (-4255 (((-679 |#1|) (-1244 $)) NIL) (((-679 |#1|)) 115)) (-1932 ((|#1| $) 119)) (-3211 (((-1169 (-917) (-763)) (-568)) NIL (|has| |#1| (-350)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL (|has| |#1| (-365)))) (-1678 (((-420 $) $) NIL (|has| |#1| (-365)))) (-1497 (((-121) $ $) NIL (|has| |#1| (-365)))) (-3983 (((-763)) 40 (|has| |#1| (-370)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) NIL)) (-2854 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) NIL)) (-3498 (($ (-1244 |#1|) (-1244 $)) NIL) (($ (-1244 |#1|)) 43)) (-2022 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| |#1| (-350)))) (-2401 (($ $ $) NIL (|has| |#1| (-365)))) (-1709 (((-679 |#1|) $ (-1244 $)) NIL) (((-679 |#1|) $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 106) (((-679 |#1|) (-679 $)) 100)) (-3092 (($ |#2|) 61) (((-3 $ "failed") (-409 |#2|)) NIL (|has| |#1| (-365)))) (-2925 (((-3 $ "failed") $) NIL)) (-3700 (((-917)) 77)) (-1731 (($) 44 (|has| |#1| (-370)))) (-2412 (($ $ $) NIL (|has| |#1| (-365)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-4220 (($) NIL (|has| |#1| (-350)))) (-4456 (((-121) $) NIL (|has| |#1| (-350)))) (-3218 (($ $ (-763)) NIL (|has| |#1| (-350))) (($ $) NIL (|has| |#1| (-350)))) (-3927 (((-121) $) NIL (|has| |#1| (-365)))) (-4477 (((-917) $) NIL (|has| |#1| (-350))) (((-828 (-917)) $) NIL (|has| |#1| (-350)))) (-2735 (((-121) $) NIL)) (-2657 ((|#1| $) NIL)) (-3038 (((-3 $ "failed") $) NIL (|has| |#1| (-350)))) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-2045 ((|#2| $) 84 (|has| |#1| (-365)))) (-3683 (((-917) $) 129 (|has| |#1| (-370)))) (-3085 ((|#2| $) 58)) (-2495 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL (|has| |#1| (-365)))) (-4434 (($) NIL (|has| |#1| (-350)) CONST)) (-4355 (($ (-917)) 124 (|has| |#1| (-370)))) (-4022 (((-1108) $) NIL)) (-2704 (($) 121)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-365)))) (-2721 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-1418 (((-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568))))) NIL (|has| |#1| (-350)))) (-3848 (((-420 $) $) NIL (|has| |#1| (-365)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-365)))) (-2595 (((-3 $ "failed") $ $) NIL (|has| |#1| (-365)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-2709 (((-763) $) NIL (|has| |#1| (-365)))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-365)))) (-2217 ((|#1| (-1244 $)) NIL) ((|#1|) 109)) (-3143 (((-763) $) NIL (|has| |#1| (-350))) (((-3 (-763) "failed") $ $) NIL (|has| |#1| (-350)))) (-4189 (($ $) NIL (-2198 (-12 (|has| |#1| (-225)) (|has| |#1| (-365))) (|has| |#1| (-350)))) (($ $ (-763)) NIL (-2198 (-12 (|has| |#1| (-225)) (|has| |#1| (-365))) (|has| |#1| (-350)))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))))) (($ $ (-1 |#1| |#1|) (-763)) NIL (|has| |#1| (-365))) (($ $ (-1 |#1| |#1|)) NIL (|has| |#1| (-365)))) (-4387 (((-679 |#1|) (-1244 $) (-1 |#1| |#1|)) NIL (|has| |#1| (-365)))) (-1626 ((|#2|) 73)) (-3065 (($) NIL (|has| |#1| (-350)))) (-4073 (((-1244 |#1|) $ (-1244 $)) 89) (((-679 |#1|) (-1244 $) (-1244 $)) NIL) (((-1244 |#1|) $) 71) (((-679 |#1|) (-1244 $)) 85)) (-4278 (((-1244 |#1|) $) NIL) (($ (-1244 |#1|)) NIL) ((|#2| $) NIL) (($ |#2|) NIL)) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| |#1| (-350)))) (-2745 (((-850) $) 57) (($ (-568)) 53) (($ |#1|) 54) (($ $) NIL (|has| |#1| (-365))) (($ (-409 (-568))) NIL (-2198 (|has| |#1| (-365)) (|has| |#1| (-1037 (-409 (-568))))))) (-4371 (($ $) NIL (|has| |#1| (-350))) (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-2678 ((|#2| $) 82)) (-4078 (((-763)) 75)) (-3746 (((-1244 $)) 81)) (-1826 (((-121) $ $) NIL (|has| |#1| (-365)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (-3056 (($) 30 T CONST)) (-1556 (($) 19 T CONST)) (-3190 (($ $) NIL (-2198 (-12 (|has| |#1| (-225)) (|has| |#1| (-365))) (|has| |#1| (-350)))) (($ $ (-763)) NIL (-2198 (-12 (|has| |#1| (-225)) (|has| |#1| (-365))) (|has| |#1| (-350)))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))))) (($ $ (-1 |#1| |#1|) (-763)) NIL (|has| |#1| (-365))) (($ $ (-1 |#1| |#1|)) NIL (|has| |#1| (-365)))) (-1717 (((-121) $ $) 63)) (-1779 (($ $ $) NIL (|has| |#1| (-365)))) (-1773 (($ $) 67) (($ $ $) NIL)) (-1767 (($ $ $) 65)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 51) (($ $ $) 69) (($ $ |#1|) NIL) (($ |#1| $) 48) (($ (-409 (-568)) $) NIL (|has| |#1| (-365))) (($ $ (-409 (-568))) NIL (|has| |#1| (-365))))) 
+((-1621 (((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#5|) 81)) (-1912 (((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#4| |#5|) 112)) (-1326 (((-634 |#5|) |#4| |#5|) 70)) (-2187 (((-634 (-2 (|:| |val| (-121)) (|:| -3145 |#5|))) |#4| |#5|) 44) (((-121) |#4| |#5|) 52)) (-1777 (((-1249)) 35)) (-3398 (((-1249)) 25)) (-1798 (((-1249) (-1143) (-1143) (-1143)) 31)) (-1741 (((-1249) (-1143) (-1143) (-1143)) 20)) (-4244 (((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) |#4| |#4| |#5|) 95)) (-3491 (((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) |#3| (-121)) 106) (((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#4| |#5| (-121) (-121)) 49)) (-4056 (((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#4| |#5|) 101))) 
+(((-1067 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1741 ((-1249) (-1143) (-1143) (-1143))) (-15 -3398 ((-1249))) (-15 -1798 ((-1249) (-1143) (-1143) (-1143))) (-15 -1777 ((-1249))) (-15 -4244 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) |#4| |#4| |#5|)) (-15 -3491 ((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#4| |#5| (-121) (-121))) (-15 -3491 ((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) |#3| (-121))) (-15 -4056 ((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#4| |#5|)) (-15 -1912 ((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#4| |#5|)) (-15 -2187 ((-121) |#4| |#5|)) (-15 -2187 ((-634 (-2 (|:| |val| (-121)) (|:| -3145 |#5|))) |#4| |#5|)) (-15 -1326 ((-634 |#5|) |#4| |#5|)) (-15 -1621 ((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#5|))) (-453) (-788) (-842) (-1061 |#1| |#2| |#3|) (-1066 |#1| |#2| |#3| |#4|)) (T -1067)) 
+((-1621 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *4)))) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-1326 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 *4)) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-2187 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3145 *4)))) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-2187 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-1912 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *4)))) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-4056 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *4)))) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-3491 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-2 (|:| |val| (-634 *8)) (|:| -3145 *9)))) (-5 *5 (-121)) (-4 *8 (-1061 *6 *7 *4)) (-4 *9 (-1066 *6 *7 *4 *8)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *4 (-842)) (-5 *2 (-634 (-2 (|:| |val| *8) (|:| -3145 *9)))) (-5 *1 (-1067 *6 *7 *4 *8 *9)))) (-3491 (*1 *2 *3 *3 *4 *5 *5) (-12 (-5 *5 (-121)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *4)))) (-5 *1 (-1067 *6 *7 *8 *3 *4)) (-4 *4 (-1066 *6 *7 *8 *3)))) (-4244 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-1777 (*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-1067 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6)))) (-1798 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-1067 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) (-3398 (*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-1067 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6)))) (-1741 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-1067 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7))))) 
+(-10 -7 (-15 -1741 ((-1249) (-1143) (-1143) (-1143))) (-15 -3398 ((-1249))) (-15 -1798 ((-1249) (-1143) (-1143) (-1143))) (-15 -1777 ((-1249))) (-15 -4244 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) |#4| |#4| |#5|)) (-15 -3491 ((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#4| |#5| (-121) (-121))) (-15 -3491 ((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) |#3| (-121))) (-15 -4056 ((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#4| |#5|)) (-15 -1912 ((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#4| |#5|)) (-15 -2187 ((-121) |#4| |#5|)) (-15 -2187 ((-634 (-2 (|:| |val| (-121)) (|:| -3145 |#5|))) |#4| |#5|)) (-15 -1326 ((-634 |#5|) |#4| |#5|)) (-15 -1621 ((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#5|))) 
+((-2449 (((-121) $ $) NIL)) (-3393 (((-1161) $) 8)) (-1893 (((-1143) $) 16)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 11)) (-1719 (((-121) $ $) 13))) 
+(((-1068 |#1|) (-13 (-1090) (-10 -8 (-15 -3393 ((-1161) $)))) (-1161)) (T -1068)) 
+((-3393 (*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-1068 *3)) (-14 *3 *2)))) 
+(-13 (-1090) (-10 -8 (-15 -3393 ((-1161) $)))) 
+((-2449 (((-121) $ $) NIL)) (-1563 (($ $ (-634 (-1161)) (-1 (-121) (-634 |#3|))) 29)) (-3362 (($ |#3| |#3|) 21) (($ |#3| |#3| (-634 (-1161))) 19)) (-3250 ((|#3| $) 13)) (-3668 (((-3 (-288 |#3|) "failed") $) 56)) (-2857 (((-288 |#3|) $) NIL)) (-3513 (((-634 (-1161)) $) 15)) (-4365 (((-887 |#1|) $) 11)) (-2433 ((|#3| $) 12)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2781 ((|#3| $ |#3|) 25) ((|#3| $ |#3| (-917)) 36)) (-2747 (((-850) $) 84) (($ (-288 |#3|)) 20)) (-1719 (((-121) $ $) 33))) 
+(((-1069 |#1| |#2| |#3|) (-13 (-1090) (-281 |#3| |#3|) (-1037 (-288 |#3|)) (-10 -8 (-15 -3362 ($ |#3| |#3|)) (-15 -3362 ($ |#3| |#3| (-634 (-1161)))) (-15 -1563 ($ $ (-634 (-1161)) (-1 (-121) (-634 |#3|)))) (-15 -4365 ((-887 |#1|) $)) (-15 -2433 (|#3| $)) (-15 -3250 (|#3| $)) (-15 -2781 (|#3| $ |#3| (-917))) (-15 -3513 ((-634 (-1161)) $)))) (-1090) (-13 (-1047) (-881 |#1|) (-842) (-609 (-887 |#1|))) (-13 (-432 |#2|) (-881 |#1|) (-609 (-887 |#1|)))) (T -1069)) 
+((-3362 (*1 *1 *2 *2) (-12 (-4 *3 (-1090)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 (-887 *3)))) (-5 *1 (-1069 *3 *4 *2)) (-4 *2 (-13 (-432 *4) (-881 *3) (-609 (-887 *3)))))) (-3362 (*1 *1 *2 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-5 *1 (-1069 *4 *5 *2)) (-4 *2 (-13 (-432 *5) (-881 *4) (-609 (-887 *4)))))) (-1563 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-1 (-121) (-634 *6))) (-4 *6 (-13 (-432 *5) (-881 *4) (-609 (-887 *4)))) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-5 *1 (-1069 *4 *5 *6)))) (-4365 (*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 *2))) (-5 *2 (-887 *3)) (-5 *1 (-1069 *3 *4 *5)) (-4 *5 (-13 (-432 *4) (-881 *3) (-609 *2))))) (-2433 (*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *2 (-13 (-432 *4) (-881 *3) (-609 (-887 *3)))) (-5 *1 (-1069 *3 *4 *2)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 (-887 *3)))))) (-3250 (*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *2 (-13 (-432 *4) (-881 *3) (-609 (-887 *3)))) (-5 *1 (-1069 *3 *4 *2)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 (-887 *3)))))) (-2781 (*1 *2 *1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-5 *1 (-1069 *4 *5 *2)) (-4 *2 (-13 (-432 *5) (-881 *4) (-609 (-887 *4)))))) (-3513 (*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 (-887 *3)))) (-5 *2 (-634 (-1161))) (-5 *1 (-1069 *3 *4 *5)) (-4 *5 (-13 (-432 *4) (-881 *3) (-609 (-887 *3))))))) 
+(-13 (-1090) (-281 |#3| |#3|) (-1037 (-288 |#3|)) (-10 -8 (-15 -3362 ($ |#3| |#3|)) (-15 -3362 ($ |#3| |#3| (-634 (-1161)))) (-15 -1563 ($ $ (-634 (-1161)) (-1 (-121) (-634 |#3|)))) (-15 -4365 ((-887 |#1|) $)) (-15 -2433 (|#3| $)) (-15 -3250 (|#3| $)) (-15 -2781 (|#3| $ |#3| (-917))) (-15 -3513 ((-634 (-1161)) $)))) 
+((-2449 (((-121) $ $) NIL)) (-3387 (($ (-634 (-1069 |#1| |#2| |#3|))) 12)) (-2095 (((-634 (-1069 |#1| |#2| |#3|)) $) 19)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2781 ((|#3| $ |#3|) 22) ((|#3| $ |#3| (-917)) 25)) (-2747 (((-850) $) 15)) (-1719 (((-121) $ $) 18))) 
+(((-1070 |#1| |#2| |#3|) (-13 (-1090) (-281 |#3| |#3|) (-10 -8 (-15 -3387 ($ (-634 (-1069 |#1| |#2| |#3|)))) (-15 -2095 ((-634 (-1069 |#1| |#2| |#3|)) $)) (-15 -2781 (|#3| $ |#3| (-917))))) (-1090) (-13 (-1047) (-881 |#1|) (-842) (-609 (-887 |#1|))) (-13 (-432 |#2|) (-881 |#1|) (-609 (-887 |#1|)))) (T -1070)) 
+((-3387 (*1 *1 *2) (-12 (-5 *2 (-634 (-1069 *3 *4 *5))) (-4 *3 (-1090)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 (-887 *3)))) (-4 *5 (-13 (-432 *4) (-881 *3) (-609 (-887 *3)))) (-5 *1 (-1070 *3 *4 *5)))) (-2095 (*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 (-887 *3)))) (-5 *2 (-634 (-1069 *3 *4 *5))) (-5 *1 (-1070 *3 *4 *5)) (-4 *5 (-13 (-432 *4) (-881 *3) (-609 (-887 *3)))))) (-2781 (*1 *2 *1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-5 *1 (-1070 *4 *5 *2)) (-4 *2 (-13 (-432 *5) (-881 *4) (-609 (-887 *4))))))) 
+(-13 (-1090) (-281 |#3| |#3|) (-10 -8 (-15 -3387 ($ (-634 (-1069 |#1| |#2| |#3|)))) (-15 -2095 ((-634 (-1069 |#1| |#2| |#3|)) $)) (-15 -2781 (|#3| $ |#3| (-917))))) 
+((-2805 (((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121) (-121)) 73) (((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-634 (-953 |#1|))) 75) (((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121)) 74))) 
+(((-1071 |#1| |#2|) (-10 -7 (-15 -2805 ((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121))) (-15 -2805 ((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-634 (-953 |#1|)))) (-15 -2805 ((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121) (-121)))) (-13 (-301) (-150)) (-634 (-1161))) (T -1071)) 
+((-2805 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-5 *2 (-634 (-2 (|:| -3722 (-1157 *5)) (|:| -1656 (-634 (-953 *5)))))) (-5 *1 (-1071 *5 *6)) (-5 *3 (-634 (-953 *5))) (-14 *6 (-634 (-1161))))) (-2805 (*1 *2 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-5 *2 (-634 (-2 (|:| -3722 (-1157 *4)) (|:| -1656 (-634 (-953 *4)))))) (-5 *1 (-1071 *4 *5)) (-5 *3 (-634 (-953 *4))) (-14 *5 (-634 (-1161))))) (-2805 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-5 *2 (-634 (-2 (|:| -3722 (-1157 *5)) (|:| -1656 (-634 (-953 *5)))))) (-5 *1 (-1071 *5 *6)) (-5 *3 (-634 (-953 *5))) (-14 *6 (-634 (-1161)))))) 
+(-10 -7 (-15 -2805 ((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121))) (-15 -2805 ((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-634 (-953 |#1|)))) (-15 -2805 ((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121) (-121)))) 
+((-3850 (((-420 |#3|) |#3|) 16))) 
+(((-1072 |#1| |#2| |#3|) (-10 -7 (-15 -3850 ((-420 |#3|) |#3|))) (-1219 (-409 (-568))) (-13 (-365) (-150) (-714 (-409 (-568)) |#1|)) (-1219 |#2|)) (T -1072)) 
+((-3850 (*1 *2 *3) (-12 (-4 *4 (-1219 (-409 (-568)))) (-4 *5 (-13 (-365) (-150) (-714 (-409 (-568)) *4))) (-5 *2 (-420 *3)) (-5 *1 (-1072 *4 *5 *3)) (-4 *3 (-1219 *5))))) 
+(-10 -7 (-15 -3850 ((-420 |#3|) |#3|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 125)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-365)))) (-3661 (($ $) NIL (|has| |#1| (-365)))) (-4426 (((-121) $) NIL (|has| |#1| (-365)))) (-2883 (((-679 |#1|) (-1244 $)) NIL) (((-679 |#1|)) 115)) (-1934 ((|#1| $) 119)) (-1856 (((-1169 (-917) (-763)) (-568)) NIL (|has| |#1| (-350)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL (|has| |#1| (-365)))) (-3498 (((-420 $) $) NIL (|has| |#1| (-365)))) (-2589 (((-121) $ $) NIL (|has| |#1| (-365)))) (-3986 (((-763)) 40 (|has| |#1| (-370)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) NIL)) (-2857 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) NIL)) (-3899 (($ (-1244 |#1|) (-1244 $)) NIL) (($ (-1244 |#1|)) 43)) (-1368 (((-3 "prime" "polynomial" "normal" "cyclic")) NIL (|has| |#1| (-350)))) (-2403 (($ $ $) NIL (|has| |#1| (-365)))) (-3653 (((-679 |#1|) $ (-1244 $)) NIL) (((-679 |#1|) $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 106) (((-679 |#1|) (-679 $)) 100)) (-3094 (($ |#2|) 61) (((-3 $ "failed") (-409 |#2|)) NIL (|has| |#1| (-365)))) (-2902 (((-3 $ "failed") $) NIL)) (-2371 (((-917)) 77)) (-1733 (($) 44 (|has| |#1| (-370)))) (-2414 (($ $ $) NIL (|has| |#1| (-365)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-4188 (($) NIL (|has| |#1| (-350)))) (-1748 (((-121) $) NIL (|has| |#1| (-350)))) (-1887 (($ $ (-763)) NIL (|has| |#1| (-350))) (($ $) NIL (|has| |#1| (-350)))) (-2197 (((-121) $) NIL (|has| |#1| (-365)))) (-1844 (((-917) $) NIL (|has| |#1| (-350))) (((-828 (-917)) $) NIL (|has| |#1| (-350)))) (-1598 (((-121) $) NIL)) (-4417 ((|#1| $) NIL)) (-2214 (((-3 $ "failed") $) NIL (|has| |#1| (-350)))) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1497 ((|#2| $) 84 (|has| |#1| (-365)))) (-2291 (((-917) $) 129 (|has| |#1| (-370)))) (-3087 ((|#2| $) 58)) (-2498 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL (|has| |#1| (-365)))) (-4436 (($) NIL (|has| |#1| (-350)) CONST)) (-4357 (($ (-917)) 124 (|has| |#1| (-370)))) (-4025 (((-1108) $) NIL)) (-2707 (($) 121)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-365)))) (-2723 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-2172 (((-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568))))) NIL (|has| |#1| (-350)))) (-3850 (((-420 $) $) NIL (|has| |#1| (-365)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-365)))) (-2597 (((-3 $ "failed") $ $) NIL (|has| |#1| (-365)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1466 (((-763) $) NIL (|has| |#1| (-365)))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-365)))) (-3440 ((|#1| (-1244 $)) NIL) ((|#1|) 109)) (-2721 (((-763) $) NIL (|has| |#1| (-350))) (((-3 (-763) "failed") $ $) NIL (|has| |#1| (-350)))) (-4191 (($ $) NIL (-2199 (-12 (|has| |#1| (-225)) (|has| |#1| (-365))) (|has| |#1| (-350)))) (($ $ (-763)) NIL (-2199 (-12 (|has| |#1| (-225)) (|has| |#1| (-365))) (|has| |#1| (-350)))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))))) (($ $ (-1 |#1| |#1|) (-763)) NIL (|has| |#1| (-365))) (($ $ (-1 |#1| |#1|)) NIL (|has| |#1| (-365)))) (-1391 (((-679 |#1|) (-1244 $) (-1 |#1| |#1|)) NIL (|has| |#1| (-365)))) (-1492 ((|#2|) 73)) (-2330 (($) NIL (|has| |#1| (-350)))) (-1656 (((-1244 |#1|) $ (-1244 $)) 89) (((-679 |#1|) (-1244 $) (-1244 $)) NIL) (((-1244 |#1|) $) 71) (((-679 |#1|) (-1244 $)) 85)) (-4280 (((-1244 |#1|) $) NIL) (($ (-1244 |#1|)) NIL) ((|#2| $) NIL) (($ |#2|) NIL)) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (|has| |#1| (-350)))) (-2747 (((-850) $) 57) (($ (-568)) 53) (($ |#1|) 54) (($ $) NIL (|has| |#1| (-365))) (($ (-409 (-568))) NIL (-2199 (|has| |#1| (-365)) (|has| |#1| (-1037 (-409 (-568))))))) (-3385 (($ $) NIL (|has| |#1| (-350))) (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-1295 ((|#2| $) 82)) (-3425 (((-763)) 75)) (-2588 (((-1244 $)) 81)) (-2273 (((-121) $ $) NIL (|has| |#1| (-365)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (-3058 (($) 30 T CONST)) (-1557 (($) 19 T CONST)) (-3192 (($ $) NIL (-2199 (-12 (|has| |#1| (-225)) (|has| |#1| (-365))) (|has| |#1| (-350)))) (($ $ (-763)) NIL (-2199 (-12 (|has| |#1| (-225)) (|has| |#1| (-365))) (|has| |#1| (-350)))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-365)) (|has| |#1| (-895 (-1161))))) (($ $ (-1 |#1| |#1|) (-763)) NIL (|has| |#1| (-365))) (($ $ (-1 |#1| |#1|)) NIL (|has| |#1| (-365)))) (-1719 (((-121) $ $) 63)) (-1781 (($ $ $) NIL (|has| |#1| (-365)))) (-1775 (($ $) 67) (($ $ $) NIL)) (-1769 (($ $ $) 65)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 51) (($ $ $) 69) (($ $ |#1|) NIL) (($ |#1| $) 48) (($ (-409 (-568)) $) NIL (|has| |#1| (-365))) (($ $ (-409 (-568))) NIL (|has| |#1| (-365))))) 
 (((-1073 |#1| |#2| |#3|) (-714 |#1| |#2|) (-172) (-1219 |#1|) |#2|) (T -1073)) 
 NIL 
 (-714 |#1| |#2|) 
-((-3848 (((-420 |#3|) |#3|) 16))) 
-(((-1074 |#1| |#2| |#3|) (-10 -7 (-15 -3848 ((-420 |#3|) |#3|))) (-1219 (-409 (-953 (-568)))) (-13 (-365) (-150) (-714 (-409 (-953 (-568))) |#1|)) (-1219 |#2|)) (T -1074)) 
-((-3848 (*1 *2 *3) (-12 (-4 *4 (-1219 (-409 (-953 (-568))))) (-4 *5 (-13 (-365) (-150) (-714 (-409 (-953 (-568))) *4))) (-5 *2 (-420 *3)) (-5 *1 (-1074 *4 *5 *3)) (-4 *3 (-1219 *5))))) 
-(-10 -7 (-15 -3848 ((-420 |#3|) |#3|))) 
-((-2447 (((-121) $ $) NIL)) (-2521 (($ $ $) 14)) (-3268 (($ $ $) 15)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2373 (($) 6)) (-4278 (((-1161) $) 18)) (-2745 (((-850) $) 12)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 13)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 8))) 
-(((-1075) (-13 (-842) (-10 -8 (-15 -2373 ($)) (-15 -4278 ((-1161) $))))) (T -1075)) 
-((-2373 (*1 *1) (-5 *1 (-1075))) (-4278 (*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-1075))))) 
-(-13 (-842) (-10 -8 (-15 -2373 ($)) (-15 -4278 ((-1161) $)))) 
-((-3119 ((|#1| |#1| (-1 (-568) |#1| |#1|)) 21) ((|#1| |#1| (-1 (-121) |#1|)) 18)) (-1583 (((-1249)) 15)) (-3302 (((-634 |#1|)) 9))) 
-(((-1076 |#1|) (-10 -7 (-15 -1583 ((-1249))) (-15 -3302 ((-634 |#1|))) (-15 -3119 (|#1| |#1| (-1 (-121) |#1|))) (-15 -3119 (|#1| |#1| (-1 (-568) |#1| |#1|)))) (-138)) (T -1076)) 
-((-3119 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-568) *2 *2)) (-4 *2 (-138)) (-5 *1 (-1076 *2)))) (-3119 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *2)) (-4 *2 (-138)) (-5 *1 (-1076 *2)))) (-3302 (*1 *2) (-12 (-5 *2 (-634 *3)) (-5 *1 (-1076 *3)) (-4 *3 (-138)))) (-1583 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1076 *3)) (-4 *3 (-138))))) 
-(-10 -7 (-15 -1583 ((-1249))) (-15 -3302 ((-634 |#1|))) (-15 -3119 (|#1| |#1| (-1 (-121) |#1|))) (-15 -3119 (|#1| |#1| (-1 (-568) |#1| |#1|)))) 
-((-2776 (((-1244 (-679 |#1|)) (-634 (-679 |#1|))) 41) (((-1244 (-679 (-953 |#1|))) (-634 (-1161)) (-679 (-953 |#1|))) 60) (((-1244 (-679 (-409 (-953 |#1|)))) (-634 (-1161)) (-679 (-409 (-953 |#1|)))) 76)) (-4073 (((-1244 |#1|) (-679 |#1|) (-634 (-679 |#1|))) 35))) 
-(((-1077 |#1|) (-10 -7 (-15 -2776 ((-1244 (-679 (-409 (-953 |#1|)))) (-634 (-1161)) (-679 (-409 (-953 |#1|))))) (-15 -2776 ((-1244 (-679 (-953 |#1|))) (-634 (-1161)) (-679 (-953 |#1|)))) (-15 -2776 ((-1244 (-679 |#1|)) (-634 (-679 |#1|)))) (-15 -4073 ((-1244 |#1|) (-679 |#1|) (-634 (-679 |#1|))))) (-365)) (T -1077)) 
-((-4073 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-679 *5))) (-5 *3 (-679 *5)) (-4 *5 (-365)) (-5 *2 (-1244 *5)) (-5 *1 (-1077 *5)))) (-2776 (*1 *2 *3) (-12 (-5 *3 (-634 (-679 *4))) (-4 *4 (-365)) (-5 *2 (-1244 (-679 *4))) (-5 *1 (-1077 *4)))) (-2776 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1161))) (-4 *5 (-365)) (-5 *2 (-1244 (-679 (-953 *5)))) (-5 *1 (-1077 *5)) (-5 *4 (-679 (-953 *5))))) (-2776 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1161))) (-4 *5 (-365)) (-5 *2 (-1244 (-679 (-409 (-953 *5))))) (-5 *1 (-1077 *5)) (-5 *4 (-679 (-409 (-953 *5))))))) 
-(-10 -7 (-15 -2776 ((-1244 (-679 (-409 (-953 |#1|)))) (-634 (-1161)) (-679 (-409 (-953 |#1|))))) (-15 -2776 ((-1244 (-679 (-953 |#1|))) (-634 (-1161)) (-679 (-953 |#1|)))) (-15 -2776 ((-1244 (-679 |#1|)) (-634 (-679 |#1|)))) (-15 -4073 ((-1244 |#1|) (-679 |#1|) (-634 (-679 |#1|))))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3902 (((-634 (-763)) $) NIL) (((-634 (-763)) $ (-1161)) NIL)) (-1551 (((-763) $) NIL) (((-763) $ (-1161)) NIL)) (-2055 (((-634 (-1079 (-1161))) $) NIL)) (-3839 (((-1157 $) $ (-1079 (-1161))) NIL) (((-1157 |#1|) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-2773 (((-763) $) NIL) (((-763) $ (-634 (-1079 (-1161)))) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-4305 (($ $) NIL (|has| |#1| (-453)))) (-1678 (((-420 $) $) NIL (|has| |#1| (-453)))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-4180 (($ $) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-1079 (-1161)) "failed") $) NIL) (((-3 (-1161) "failed") $) NIL) (((-3 (-1113 |#1| (-1161)) "failed") $) NIL)) (-2854 ((|#1| $) NIL) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-1079 (-1161)) $) NIL) (((-1161) $) NIL) (((-1113 |#1| (-1161)) $) NIL)) (-4265 (($ $ $ (-1079 (-1161))) NIL (|has| |#1| (-172)))) (-2114 (($ $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3250 (($ $) NIL (|has| |#1| (-453))) (($ $ (-1079 (-1161))) NIL (|has| |#1| (-453)))) (-2108 (((-634 $) $) NIL)) (-3927 (((-121) $) NIL (|has| |#1| (-904)))) (-3088 (($ $ |#1| (-534 (-1079 (-1161))) $) NIL)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-1079 (-1161)) (-881 (-381))) (|has| |#1| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-1079 (-1161)) (-881 (-568))) (|has| |#1| (-881 (-568)))))) (-4477 (((-763) $ (-1161)) NIL) (((-763) $) NIL)) (-2735 (((-121) $) NIL)) (-4178 (((-763) $) NIL)) (-2051 (($ (-1157 |#1|) (-1079 (-1161))) NIL) (($ (-1157 $) (-1079 (-1161))) NIL)) (-2976 (((-634 $) $) NIL)) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| (-534 (-1079 (-1161)))) NIL) (($ $ (-1079 (-1161)) (-763)) NIL) (($ $ (-634 (-1079 (-1161))) (-634 (-763))) NIL)) (-3379 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $ (-1079 (-1161))) NIL)) (-2144 (((-534 (-1079 (-1161))) $) NIL) (((-763) $ (-1079 (-1161))) NIL) (((-634 (-763)) $ (-634 (-1079 (-1161)))) NIL)) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-3842 (($ (-1 (-534 (-1079 (-1161))) (-534 (-1079 (-1161)))) $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-4300 (((-1 $ (-763)) (-1161)) NIL) (((-1 $ (-763)) $) NIL (|has| |#1| (-225)))) (-2244 (((-3 (-1079 (-1161)) "failed") $) NIL)) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-1690 (((-1079 (-1161)) $) NIL)) (-2495 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-4487 (((-1143) $) NIL)) (-1989 (((-121) $) NIL)) (-3324 (((-3 (-634 $) "failed") $) NIL)) (-1794 (((-3 (-634 $) "failed") $) NIL)) (-3751 (((-3 (-2 (|:| |var| (-1079 (-1161))) (|:| -3438 (-763))) "failed") $) NIL)) (-1484 (($ $) NIL)) (-4022 (((-1108) $) NIL)) (-2086 (((-121) $) NIL)) (-2091 ((|#1| $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-453)))) (-2721 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3848 (((-420 $) $) NIL (|has| |#1| (-904)))) (-2595 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-1079 (-1161)) |#1|) NIL) (($ $ (-634 (-1079 (-1161))) (-634 |#1|)) NIL) (($ $ (-1079 (-1161)) $) NIL) (($ $ (-634 (-1079 (-1161))) (-634 $)) NIL) (($ $ (-1161) $) NIL (|has| |#1| (-225))) (($ $ (-634 (-1161)) (-634 $)) NIL (|has| |#1| (-225))) (($ $ (-1161) |#1|) NIL (|has| |#1| (-225))) (($ $ (-634 (-1161)) (-634 |#1|)) NIL (|has| |#1| (-225)))) (-2217 (($ $ (-1079 (-1161))) NIL (|has| |#1| (-172)))) (-4189 (($ $ (-1079 (-1161))) NIL) (($ $ (-634 (-1079 (-1161)))) NIL) (($ $ (-1079 (-1161)) (-763)) NIL) (($ $ (-634 (-1079 (-1161))) (-634 (-763))) NIL) (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-3795 (((-634 (-1161)) $) NIL)) (-3206 (((-534 (-1079 (-1161))) $) NIL) (((-763) $ (-1079 (-1161))) NIL) (((-634 (-763)) $ (-634 (-1079 (-1161)))) NIL) (((-763) $ (-1161)) NIL)) (-4278 (((-887 (-381)) $) NIL (-12 (|has| (-1079 (-1161)) (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-1079 (-1161)) (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-1079 (-1161)) (-609 (-541))) (|has| |#1| (-609 (-541)))))) (-3367 ((|#1| $) NIL (|has| |#1| (-453))) (($ $ (-1079 (-1161))) NIL (|has| |#1| (-453)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#1| (-904))))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL) (($ (-1079 (-1161))) NIL) (($ (-1161)) NIL) (($ (-1113 |#1| (-1161))) NIL) (($ (-409 (-568))) NIL (-2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#1| (-558)))) (-1302 (((-634 |#1|) $) NIL)) (-2604 ((|#1| $ (-534 (-1079 (-1161)))) NIL) (($ $ (-1079 (-1161)) (-763)) NIL) (($ $ (-634 (-1079 (-1161))) (-634 (-763))) NIL)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-4078 (((-763)) NIL)) (-4171 (($ $ $ (-763)) NIL (|has| |#1| (-172)))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $ (-1079 (-1161))) NIL) (($ $ (-634 (-1079 (-1161)))) NIL) (($ $ (-1079 (-1161)) (-763)) NIL) (($ $ (-634 (-1079 (-1161))) (-634 (-763))) NIL) (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
+((-3850 (((-420 |#3|) |#3|) 16))) 
+(((-1074 |#1| |#2| |#3|) (-10 -7 (-15 -3850 ((-420 |#3|) |#3|))) (-1219 (-409 (-953 (-568)))) (-13 (-365) (-150) (-714 (-409 (-953 (-568))) |#1|)) (-1219 |#2|)) (T -1074)) 
+((-3850 (*1 *2 *3) (-12 (-4 *4 (-1219 (-409 (-953 (-568))))) (-4 *5 (-13 (-365) (-150) (-714 (-409 (-953 (-568))) *4))) (-5 *2 (-420 *3)) (-5 *1 (-1074 *4 *5 *3)) (-4 *3 (-1219 *5))))) 
+(-10 -7 (-15 -3850 ((-420 |#3|) |#3|))) 
+((-2449 (((-121) $ $) NIL)) (-1732 (($ $ $) 14)) (-2047 (($ $ $) 15)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-4116 (($) 6)) (-4280 (((-1161) $) 18)) (-2747 (((-850) $) 12)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 13)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 8))) 
+(((-1075) (-13 (-842) (-10 -8 (-15 -4116 ($)) (-15 -4280 ((-1161) $))))) (T -1075)) 
+((-4116 (*1 *1) (-5 *1 (-1075))) (-4280 (*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-1075))))) 
+(-13 (-842) (-10 -8 (-15 -4116 ($)) (-15 -4280 ((-1161) $)))) 
+((-2605 ((|#1| |#1| (-1 (-568) |#1| |#1|)) 21) ((|#1| |#1| (-1 (-121) |#1|)) 18)) (-1586 (((-1249)) 15)) (-3303 (((-634 |#1|)) 9))) 
+(((-1076 |#1|) (-10 -7 (-15 -1586 ((-1249))) (-15 -3303 ((-634 |#1|))) (-15 -2605 (|#1| |#1| (-1 (-121) |#1|))) (-15 -2605 (|#1| |#1| (-1 (-568) |#1| |#1|)))) (-138)) (T -1076)) 
+((-2605 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-568) *2 *2)) (-4 *2 (-138)) (-5 *1 (-1076 *2)))) (-2605 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *2)) (-4 *2 (-138)) (-5 *1 (-1076 *2)))) (-3303 (*1 *2) (-12 (-5 *2 (-634 *3)) (-5 *1 (-1076 *3)) (-4 *3 (-138)))) (-1586 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1076 *3)) (-4 *3 (-138))))) 
+(-10 -7 (-15 -1586 ((-1249))) (-15 -3303 ((-634 |#1|))) (-15 -2605 (|#1| |#1| (-1 (-121) |#1|))) (-15 -2605 (|#1| |#1| (-1 (-568) |#1| |#1|)))) 
+((-3542 (((-1244 (-679 |#1|)) (-634 (-679 |#1|))) 41) (((-1244 (-679 (-953 |#1|))) (-634 (-1161)) (-679 (-953 |#1|))) 60) (((-1244 (-679 (-409 (-953 |#1|)))) (-634 (-1161)) (-679 (-409 (-953 |#1|)))) 76)) (-1656 (((-1244 |#1|) (-679 |#1|) (-634 (-679 |#1|))) 35))) 
+(((-1077 |#1|) (-10 -7 (-15 -3542 ((-1244 (-679 (-409 (-953 |#1|)))) (-634 (-1161)) (-679 (-409 (-953 |#1|))))) (-15 -3542 ((-1244 (-679 (-953 |#1|))) (-634 (-1161)) (-679 (-953 |#1|)))) (-15 -3542 ((-1244 (-679 |#1|)) (-634 (-679 |#1|)))) (-15 -1656 ((-1244 |#1|) (-679 |#1|) (-634 (-679 |#1|))))) (-365)) (T -1077)) 
+((-1656 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-679 *5))) (-5 *3 (-679 *5)) (-4 *5 (-365)) (-5 *2 (-1244 *5)) (-5 *1 (-1077 *5)))) (-3542 (*1 *2 *3) (-12 (-5 *3 (-634 (-679 *4))) (-4 *4 (-365)) (-5 *2 (-1244 (-679 *4))) (-5 *1 (-1077 *4)))) (-3542 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1161))) (-4 *5 (-365)) (-5 *2 (-1244 (-679 (-953 *5)))) (-5 *1 (-1077 *5)) (-5 *4 (-679 (-953 *5))))) (-3542 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1161))) (-4 *5 (-365)) (-5 *2 (-1244 (-679 (-409 (-953 *5))))) (-5 *1 (-1077 *5)) (-5 *4 (-679 (-409 (-953 *5))))))) 
+(-10 -7 (-15 -3542 ((-1244 (-679 (-409 (-953 |#1|)))) (-634 (-1161)) (-679 (-409 (-953 |#1|))))) (-15 -3542 ((-1244 (-679 (-953 |#1|))) (-634 (-1161)) (-679 (-953 |#1|)))) (-15 -3542 ((-1244 (-679 |#1|)) (-634 (-679 |#1|)))) (-15 -1656 ((-1244 |#1|) (-679 |#1|) (-634 (-679 |#1|))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2076 (((-634 (-763)) $) NIL) (((-634 (-763)) $ (-1161)) NIL)) (-4308 (((-763) $) NIL) (((-763) $ (-1161)) NIL)) (-2057 (((-634 (-1079 (-1161))) $) NIL)) (-3840 (((-1157 $) $ (-1079 (-1161))) NIL) (((-1157 |#1|) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-3528 (((-763) $) NIL) (((-763) $ (-634 (-1079 (-1161)))) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3045 (($ $) NIL (|has| |#1| (-453)))) (-3498 (((-420 $) $) NIL (|has| |#1| (-453)))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3988 (($ $) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-1079 (-1161)) "failed") $) NIL) (((-3 (-1161) "failed") $) NIL) (((-3 (-1113 |#1| (-1161)) "failed") $) NIL)) (-2857 ((|#1| $) NIL) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-1079 (-1161)) $) NIL) (((-1161) $) NIL) (((-1113 |#1| (-1161)) $) NIL)) (-2910 (($ $ $ (-1079 (-1161))) NIL (|has| |#1| (-172)))) (-2116 (($ $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1998 (($ $) NIL (|has| |#1| (-453))) (($ $ (-1079 (-1161))) NIL (|has| |#1| (-453)))) (-2110 (((-634 $) $) NIL)) (-2197 (((-121) $) NIL (|has| |#1| (-904)))) (-2453 (($ $ |#1| (-534 (-1079 (-1161))) $) NIL)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-1079 (-1161)) (-881 (-381))) (|has| |#1| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-1079 (-1161)) (-881 (-568))) (|has| |#1| (-881 (-568)))))) (-1844 (((-763) $ (-1161)) NIL) (((-763) $) NIL)) (-1598 (((-121) $) NIL)) (-3971 (((-763) $) NIL)) (-2053 (($ (-1157 |#1|) (-1079 (-1161))) NIL) (($ (-1157 $) (-1079 (-1161))) NIL)) (-3062 (((-634 $) $) NIL)) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| (-534 (-1079 (-1161)))) NIL) (($ $ (-1079 (-1161)) (-763)) NIL) (($ $ (-634 (-1079 (-1161))) (-634 (-763))) NIL)) (-1438 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $ (-1079 (-1161))) NIL)) (-3524 (((-534 (-1079 (-1161))) $) NIL) (((-763) $ (-1079 (-1161))) NIL) (((-634 (-763)) $ (-634 (-1079 (-1161)))) NIL)) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-1865 (($ (-1 (-534 (-1079 (-1161))) (-534 (-1079 (-1161)))) $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-3029 (((-1 $ (-763)) (-1161)) NIL) (((-1 $ (-763)) $) NIL (|has| |#1| (-225)))) (-2817 (((-3 (-1079 (-1161)) "failed") $) NIL)) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-1692 (((-1079 (-1161)) $) NIL)) (-2498 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-1893 (((-1143) $) NIL)) (-4448 (((-121) $) NIL)) (-4362 (((-3 (-634 $) "failed") $) NIL)) (-2112 (((-3 (-634 $) "failed") $) NIL)) (-2617 (((-3 (-2 (|:| |var| (-1079 (-1161))) (|:| -3483 (-763))) "failed") $) NIL)) (-1484 (($ $) NIL)) (-4025 (((-1108) $) NIL)) (-2088 (((-121) $) NIL)) (-2093 ((|#1| $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-453)))) (-2723 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3850 (((-420 $) $) NIL (|has| |#1| (-904)))) (-2597 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-1079 (-1161)) |#1|) NIL) (($ $ (-634 (-1079 (-1161))) (-634 |#1|)) NIL) (($ $ (-1079 (-1161)) $) NIL) (($ $ (-634 (-1079 (-1161))) (-634 $)) NIL) (($ $ (-1161) $) NIL (|has| |#1| (-225))) (($ $ (-634 (-1161)) (-634 $)) NIL (|has| |#1| (-225))) (($ $ (-1161) |#1|) NIL (|has| |#1| (-225))) (($ $ (-634 (-1161)) (-634 |#1|)) NIL (|has| |#1| (-225)))) (-3440 (($ $ (-1079 (-1161))) NIL (|has| |#1| (-172)))) (-4191 (($ $ (-1079 (-1161))) NIL) (($ $ (-634 (-1079 (-1161)))) NIL) (($ $ (-1079 (-1161)) (-763)) NIL) (($ $ (-634 (-1079 (-1161))) (-634 (-763))) NIL) (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-2775 (((-634 (-1161)) $) NIL)) (-1836 (((-534 (-1079 (-1161))) $) NIL) (((-763) $ (-1079 (-1161))) NIL) (((-634 (-763)) $ (-634 (-1079 (-1161)))) NIL) (((-763) $ (-1161)) NIL)) (-4280 (((-887 (-381)) $) NIL (-12 (|has| (-1079 (-1161)) (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-1079 (-1161)) (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-1079 (-1161)) (-609 (-541))) (|has| |#1| (-609 (-541)))))) (-1364 ((|#1| $) NIL (|has| |#1| (-453))) (($ $ (-1079 (-1161))) NIL (|has| |#1| (-453)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#1| (-904))))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL) (($ (-1079 (-1161))) NIL) (($ (-1161)) NIL) (($ (-1113 |#1| (-1161))) NIL) (($ (-409 (-568))) NIL (-2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#1| (-558)))) (-3304 (((-634 |#1|) $) NIL)) (-2079 ((|#1| $ (-534 (-1079 (-1161)))) NIL) (($ $ (-1079 (-1161)) (-763)) NIL) (($ $ (-634 (-1079 (-1161))) (-634 (-763))) NIL)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-3425 (((-763)) NIL)) (-3925 (($ $ $ (-763)) NIL (|has| |#1| (-172)))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $ (-1079 (-1161))) NIL) (($ $ (-634 (-1079 (-1161)))) NIL) (($ $ (-1079 (-1161)) (-763)) NIL) (($ $ (-634 (-1079 (-1161))) (-634 (-763))) NIL) (($ $) NIL (|has| |#1| (-225))) (($ $ (-763)) NIL (|has| |#1| (-225))) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
 (((-1078 |#1|) (-13 (-246 |#1| (-1161) (-1079 (-1161)) (-534 (-1079 (-1161)))) (-1037 (-1113 |#1| (-1161)))) (-1047)) (T -1078)) 
 NIL 
 (-13 (-246 |#1| (-1161) (-1079 (-1161)) (-534 (-1079 (-1161)))) (-1037 (-1113 |#1| (-1161)))) 
-((-2447 (((-121) $ $) NIL)) (-1551 (((-763) $) NIL)) (-1305 ((|#1| $) 10)) (-3666 (((-3 |#1| "failed") $) NIL)) (-2854 ((|#1| $) NIL)) (-4477 (((-763) $) 11)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-4300 (($ |#1| (-763)) 9)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-4189 (($ $) NIL) (($ $ (-763)) NIL)) (-2745 (((-850) $) NIL) (($ |#1|) NIL)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 15))) 
+((-2449 (((-121) $ $) NIL)) (-4308 (((-763) $) NIL)) (-3325 ((|#1| $) 10)) (-3668 (((-3 |#1| "failed") $) NIL)) (-2857 ((|#1| $) NIL)) (-1844 (((-763) $) 11)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-3029 (($ |#1| (-763)) 9)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-4191 (($ $) NIL) (($ $ (-763)) NIL)) (-2747 (((-850) $) NIL) (($ |#1|) NIL)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 15))) 
 (((-1079 |#1|) (-262 |#1|) (-842)) (T -1079)) 
 NIL 
 (-262 |#1|) 
-((-2795 (((-634 |#2|) (-1 |#2| |#1|) (-1084 |#1|)) 23 (|has| |#1| (-840))) (((-1084 |#2|) (-1 |#2| |#1|) (-1084 |#1|)) 14))) 
-(((-1080 |#1| |#2|) (-10 -7 (-15 -2795 ((-1084 |#2|) (-1 |#2| |#1|) (-1084 |#1|))) (IF (|has| |#1| (-840)) (-15 -2795 ((-634 |#2|) (-1 |#2| |#1|) (-1084 |#1|))) |noBranch|)) (-1195) (-1195)) (T -1080)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1084 *5)) (-4 *5 (-840)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-634 *6)) (-5 *1 (-1080 *5 *6)))) (-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1084 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1084 *6)) (-5 *1 (-1080 *5 *6))))) 
-(-10 -7 (-15 -2795 ((-1084 |#2|) (-1 |#2| |#1|) (-1084 |#1|))) (IF (|has| |#1| (-840)) (-15 -2795 ((-634 |#2|) (-1 |#2| |#1|) (-1084 |#1|))) |noBranch|)) 
-((-2795 (((-1082 |#2|) (-1 |#2| |#1|) (-1082 |#1|)) 19))) 
-(((-1081 |#1| |#2|) (-10 -7 (-15 -2795 ((-1082 |#2|) (-1 |#2| |#1|) (-1082 |#1|)))) (-1195) (-1195)) (T -1081)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1082 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1082 *6)) (-5 *1 (-1081 *5 *6))))) 
-(-10 -7 (-15 -2795 ((-1082 |#2|) (-1 |#2| |#1|) (-1082 |#1|)))) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1305 (((-1161) $) 11)) (-2463 (((-1084 |#1|) $) 12)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-2783 (($ (-1161) (-1084 |#1|)) 10)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-1717 (((-121) $ $) 15 (|has| |#1| (-1090))))) 
-(((-1082 |#1|) (-13 (-1195) (-10 -8 (-15 -2783 ($ (-1161) (-1084 |#1|))) (-15 -1305 ((-1161) $)) (-15 -2463 ((-1084 |#1|) $)) (IF (|has| |#1| (-1090)) (-6 (-1090)) |noBranch|))) (-1195)) (T -1082)) 
-((-2783 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1084 *4)) (-4 *4 (-1195)) (-5 *1 (-1082 *4)))) (-1305 (*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-1082 *3)) (-4 *3 (-1195)))) (-2463 (*1 *2 *1) (-12 (-5 *2 (-1084 *3)) (-5 *1 (-1082 *3)) (-4 *3 (-1195))))) 
-(-13 (-1195) (-10 -8 (-15 -2783 ($ (-1161) (-1084 |#1|))) (-15 -1305 ((-1161) $)) (-15 -2463 ((-1084 |#1|) $)) (IF (|has| |#1| (-1090)) (-6 (-1090)) |noBranch|))) 
-((-2463 (($ |#1| |#1|) 7)) (-4100 ((|#1| $) 10)) (-2746 ((|#1| $) 12)) (-2751 (((-568) $) 8)) (-2971 ((|#1| $) 9)) (-2754 ((|#1| $) 11)) (-4278 (($ |#1|) 6)) (-4253 (($ |#1| |#1|) 14)) (-4143 (($ $ (-568)) 13))) 
+((-2797 (((-634 |#2|) (-1 |#2| |#1|) (-1084 |#1|)) 23 (|has| |#1| (-840))) (((-1084 |#2|) (-1 |#2| |#1|) (-1084 |#1|)) 14))) 
+(((-1080 |#1| |#2|) (-10 -7 (-15 -2797 ((-1084 |#2|) (-1 |#2| |#1|) (-1084 |#1|))) (IF (|has| |#1| (-840)) (-15 -2797 ((-634 |#2|) (-1 |#2| |#1|) (-1084 |#1|))) |noBranch|)) (-1195) (-1195)) (T -1080)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1084 *5)) (-4 *5 (-840)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-634 *6)) (-5 *1 (-1080 *5 *6)))) (-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1084 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1084 *6)) (-5 *1 (-1080 *5 *6))))) 
+(-10 -7 (-15 -2797 ((-1084 |#2|) (-1 |#2| |#1|) (-1084 |#1|))) (IF (|has| |#1| (-840)) (-15 -2797 ((-634 |#2|) (-1 |#2| |#1|) (-1084 |#1|))) |noBranch|)) 
+((-2797 (((-1082 |#2|) (-1 |#2| |#1|) (-1082 |#1|)) 19))) 
+(((-1081 |#1| |#2|) (-10 -7 (-15 -2797 ((-1082 |#2|) (-1 |#2| |#1|) (-1082 |#1|)))) (-1195) (-1195)) (T -1081)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1082 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1082 *6)) (-5 *1 (-1081 *5 *6))))) 
+(-10 -7 (-15 -2797 ((-1082 |#2|) (-1 |#2| |#1|) (-1082 |#1|)))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3325 (((-1161) $) 11)) (-2465 (((-1084 |#1|) $) 12)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-2785 (($ (-1161) (-1084 |#1|)) 10)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-1719 (((-121) $ $) 15 (|has| |#1| (-1090))))) 
+(((-1082 |#1|) (-13 (-1195) (-10 -8 (-15 -2785 ($ (-1161) (-1084 |#1|))) (-15 -3325 ((-1161) $)) (-15 -2465 ((-1084 |#1|) $)) (IF (|has| |#1| (-1090)) (-6 (-1090)) |noBranch|))) (-1195)) (T -1082)) 
+((-2785 (*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1084 *4)) (-4 *4 (-1195)) (-5 *1 (-1082 *4)))) (-3325 (*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-1082 *3)) (-4 *3 (-1195)))) (-2465 (*1 *2 *1) (-12 (-5 *2 (-1084 *3)) (-5 *1 (-1082 *3)) (-4 *3 (-1195))))) 
+(-13 (-1195) (-10 -8 (-15 -2785 ($ (-1161) (-1084 |#1|))) (-15 -3325 ((-1161) $)) (-15 -2465 ((-1084 |#1|) $)) (IF (|has| |#1| (-1090)) (-6 (-1090)) |noBranch|))) 
+((-2465 (($ |#1| |#1|) 7)) (-3544 ((|#1| $) 10)) (-2748 ((|#1| $) 12)) (-2753 (((-568) $) 8)) (-3043 ((|#1| $) 9)) (-2756 ((|#1| $) 11)) (-4280 (($ |#1|) 6)) (-4255 (($ |#1| |#1|) 14)) (-4145 (($ $ (-568)) 13))) 
 (((-1083 |#1|) (-1275) (-1195)) (T -1083)) 
-((-4253 (*1 *1 *2 *2) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195)))) (-4143 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-1083 *3)) (-4 *3 (-1195)))) (-2746 (*1 *2 *1) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195)))) (-2754 (*1 *2 *1) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195)))) (-4100 (*1 *2 *1) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195)))) (-2971 (*1 *2 *1) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195)))) (-2751 (*1 *2 *1) (-12 (-4 *1 (-1083 *3)) (-4 *3 (-1195)) (-5 *2 (-568)))) (-2463 (*1 *1 *2 *2) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195)))) (-4278 (*1 *1 *2) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195))))) 
-(-13 (-1195) (-10 -8 (-15 -4253 ($ |t#1| |t#1|)) (-15 -4143 ($ $ (-568))) (-15 -2746 (|t#1| $)) (-15 -2754 (|t#1| $)) (-15 -4100 (|t#1| $)) (-15 -2971 (|t#1| $)) (-15 -2751 ((-568) $)) (-15 -2463 ($ |t#1| |t#1|)) (-15 -4278 ($ |t#1|)))) 
+((-4255 (*1 *1 *2 *2) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195)))) (-4145 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-1083 *3)) (-4 *3 (-1195)))) (-2748 (*1 *2 *1) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195)))) (-2756 (*1 *2 *1) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195)))) (-3544 (*1 *2 *1) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195)))) (-3043 (*1 *2 *1) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195)))) (-2753 (*1 *2 *1) (-12 (-4 *1 (-1083 *3)) (-4 *3 (-1195)) (-5 *2 (-568)))) (-2465 (*1 *1 *2 *2) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195)))) (-4280 (*1 *1 *2) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195))))) 
+(-13 (-1195) (-10 -8 (-15 -4255 ($ |t#1| |t#1|)) (-15 -4145 ($ $ (-568))) (-15 -2748 (|t#1| $)) (-15 -2756 (|t#1| $)) (-15 -3544 (|t#1| $)) (-15 -3043 (|t#1| $)) (-15 -2753 ((-568) $)) (-15 -2465 ($ |t#1| |t#1|)) (-15 -4280 ($ |t#1|)))) 
 (((-1195) . T)) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2463 (($ |#1| |#1|) 15)) (-2795 (((-634 |#1|) (-1 |#1| |#1|) $) 37 (|has| |#1| (-840)))) (-4100 ((|#1| $) 10)) (-2746 ((|#1| $) 9)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-2751 (((-568) $) 14)) (-2971 ((|#1| $) 12)) (-2754 ((|#1| $) 11)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-2789 (((-634 |#1|) $) 35 (|has| |#1| (-840))) (((-634 |#1|) (-634 $)) 34 (|has| |#1| (-840)))) (-4278 (($ |#1|) 26)) (-2745 (((-850) $) 25 (|has| |#1| (-1090)))) (-4253 (($ |#1| |#1|) 8)) (-4143 (($ $ (-568)) 16)) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090))))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2465 (($ |#1| |#1|) 15)) (-2797 (((-634 |#1|) (-1 |#1| |#1|) $) 37 (|has| |#1| (-840)))) (-3544 ((|#1| $) 10)) (-2748 ((|#1| $) 9)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-2753 (((-568) $) 14)) (-3043 ((|#1| $) 12)) (-2756 ((|#1| $) 11)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-2791 (((-634 |#1|) $) 35 (|has| |#1| (-840))) (((-634 |#1|) (-634 $)) 34 (|has| |#1| (-840)))) (-4280 (($ |#1|) 26)) (-2747 (((-850) $) 25 (|has| |#1| (-1090)))) (-4255 (($ |#1| |#1|) 8)) (-4145 (($ $ (-568)) 16)) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090))))) 
 (((-1084 |#1|) (-13 (-1083 |#1|) (-10 -7 (IF (|has| |#1| (-1090)) (-6 (-1090)) |noBranch|) (IF (|has| |#1| (-840)) (-6 (-1085 |#1| (-634 |#1|))) |noBranch|))) (-1195)) (T -1084)) 
 NIL 
 (-13 (-1083 |#1|) (-10 -7 (IF (|has| |#1| (-1090)) (-6 (-1090)) |noBranch|) (IF (|has| |#1| (-840)) (-6 (-1085 |#1| (-634 |#1|))) |noBranch|))) 
-((-2463 (($ |#1| |#1|) 7)) (-2795 ((|#2| (-1 |#1| |#1|) $) 15)) (-4100 ((|#1| $) 10)) (-2746 ((|#1| $) 12)) (-2751 (((-568) $) 8)) (-2971 ((|#1| $) 9)) (-2754 ((|#1| $) 11)) (-2789 ((|#2| (-634 $)) 17) ((|#2| $) 16)) (-4278 (($ |#1|) 6)) (-4253 (($ |#1| |#1|) 14)) (-4143 (($ $ (-568)) 13))) 
+((-2465 (($ |#1| |#1|) 7)) (-2797 ((|#2| (-1 |#1| |#1|) $) 15)) (-3544 ((|#1| $) 10)) (-2748 ((|#1| $) 12)) (-2753 (((-568) $) 8)) (-3043 ((|#1| $) 9)) (-2756 ((|#1| $) 11)) (-2791 ((|#2| (-634 $)) 17) ((|#2| $) 16)) (-4280 (($ |#1|) 6)) (-4255 (($ |#1| |#1|) 14)) (-4145 (($ $ (-568)) 13))) 
 (((-1085 |#1| |#2|) (-1275) (-840) (-1134 |t#1|)) (T -1085)) 
-((-2789 (*1 *2 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-1085 *4 *2)) (-4 *4 (-840)) (-4 *2 (-1134 *4)))) (-2789 (*1 *2 *1) (-12 (-4 *1 (-1085 *3 *2)) (-4 *3 (-840)) (-4 *2 (-1134 *3)))) (-2795 (*1 *2 *3 *1) (-12 (-5 *3 (-1 *4 *4)) (-4 *1 (-1085 *4 *2)) (-4 *4 (-840)) (-4 *2 (-1134 *4))))) 
-(-13 (-1083 |t#1|) (-10 -8 (-15 -2789 (|t#2| (-634 $))) (-15 -2789 (|t#2| $)) (-15 -2795 (|t#2| (-1 |t#1| |t#1|) $)))) 
+((-2791 (*1 *2 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-1085 *4 *2)) (-4 *4 (-840)) (-4 *2 (-1134 *4)))) (-2791 (*1 *2 *1) (-12 (-4 *1 (-1085 *3 *2)) (-4 *3 (-840)) (-4 *2 (-1134 *3)))) (-2797 (*1 *2 *3 *1) (-12 (-5 *3 (-1 *4 *4)) (-4 *1 (-1085 *4 *2)) (-4 *4 (-840)) (-4 *2 (-1134 *4))))) 
+(-13 (-1083 |t#1|) (-10 -8 (-15 -2791 (|t#2| (-634 $))) (-15 -2791 (|t#2| $)) (-15 -2797 (|t#2| (-1 |t#1| |t#1|) $)))) 
 (((-1083 |#1|) . T) ((-1195) . T)) 
-((-1791 (($ $ $) NIL) (($ $ |#2|) 13) (($ |#2| $) 14)) (-1536 (($ $ $) 10)) (-4382 (($ $ $) NIL) (($ $ |#2|) 15))) 
-(((-1086 |#1| |#2|) (-10 -8 (-15 -1791 (|#1| |#2| |#1|)) (-15 -1791 (|#1| |#1| |#2|)) (-15 -1791 (|#1| |#1| |#1|)) (-15 -1536 (|#1| |#1| |#1|)) (-15 -4382 (|#1| |#1| |#2|)) (-15 -4382 (|#1| |#1| |#1|))) (-1087 |#2|) (-1090)) (T -1086)) 
+((-1793 (($ $ $) NIL) (($ $ |#2|) 13) (($ |#2| $) 14)) (-4217 (($ $ $) 10)) (-1363 (($ $ $) NIL) (($ $ |#2|) 15))) 
+(((-1086 |#1| |#2|) (-10 -8 (-15 -1793 (|#1| |#2| |#1|)) (-15 -1793 (|#1| |#1| |#2|)) (-15 -1793 (|#1| |#1| |#1|)) (-15 -4217 (|#1| |#1| |#1|)) (-15 -1363 (|#1| |#1| |#2|)) (-15 -1363 (|#1| |#1| |#1|))) (-1087 |#2|) (-1090)) (T -1086)) 
 NIL 
-(-10 -8 (-15 -1791 (|#1| |#2| |#1|)) (-15 -1791 (|#1| |#1| |#2|)) (-15 -1791 (|#1| |#1| |#1|)) (-15 -1536 (|#1| |#1| |#1|)) (-15 -4382 (|#1| |#1| |#2|)) (-15 -4382 (|#1| |#1| |#1|))) 
-((-2447 (((-121) $ $) 7)) (-1791 (($ $ $) 17) (($ $ |#1|) 16) (($ |#1| $) 15)) (-1536 (($ $ $) 19)) (-2032 (((-121) $ $) 18)) (-2510 (((-121) $ (-763)) 34)) (-2749 (($) 24) (($ (-634 |#1|)) 23)) (-2801 (($ (-1 (-121) |#1|) $) 55 (|has| $ (-6 -4519)))) (-2671 (($) 35 T CONST)) (-3924 (($ $) 58 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-4328 (($ |#1| $) 57 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) |#1|) $) 54 (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 56 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 53 (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) 52 (|has| $ (-6 -4519)))) (-4360 (((-634 |#1|) $) 42 (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) 33)) (-1979 (((-634 |#1|) $) 43 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 45 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#1| |#1|) $) 38 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 37)) (-2166 (((-121) $ (-763)) 32)) (-4487 (((-1143) $) 9)) (-3212 (($ $ $) 22)) (-4022 (((-1108) $) 10)) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 51)) (-1387 (((-121) (-1 (-121) |#1|) $) 40 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 |#1|) (-634 |#1|)) 49 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 48 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 47 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 (-288 |#1|))) 46 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 28)) (-3084 (((-121) $) 31)) (-3248 (($) 30)) (-4382 (($ $ $) 21) (($ $ |#1|) 20)) (-4168 (((-763) |#1| $) 44 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) (((-763) (-1 (-121) |#1|) $) 41 (|has| $ (-6 -4519)))) (-3863 (($ $) 29)) (-4278 (((-541) $) 59 (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) 50)) (-2745 (((-850) $) 11)) (-3844 (($) 26) (($ (-634 |#1|)) 25)) (-1319 (((-121) (-1 (-121) |#1|) $) 39 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 6)) (-1732 (((-121) $ $) 27)) (-1697 (((-763) $) 36 (|has| $ (-6 -4519))))) 
+(-10 -8 (-15 -1793 (|#1| |#2| |#1|)) (-15 -1793 (|#1| |#1| |#2|)) (-15 -1793 (|#1| |#1| |#1|)) (-15 -4217 (|#1| |#1| |#1|)) (-15 -1363 (|#1| |#1| |#2|)) (-15 -1363 (|#1| |#1| |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1793 (($ $ $) 17) (($ $ |#1|) 16) (($ |#1| $) 15)) (-4217 (($ $ $) 19)) (-1430 (((-121) $ $) 18)) (-1667 (((-121) $ (-763)) 34)) (-2751 (($) 24) (($ (-634 |#1|)) 23)) (-2803 (($ (-1 (-121) |#1|) $) 55 (|has| $ (-6 -4521)))) (-4490 (($) 35 T CONST)) (-3926 (($ $) 58 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-4330 (($ |#1| $) 57 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) |#1|) $) 54 (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 56 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 53 (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) 52 (|has| $ (-6 -4521)))) (-3317 (((-634 |#1|) $) 42 (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) 33)) (-4406 (((-634 |#1|) $) 43 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 45 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#1| |#1|) $) 38 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 37)) (-3796 (((-121) $ (-763)) 32)) (-1893 (((-1143) $) 9)) (-1864 (($ $ $) 22)) (-4025 (((-1108) $) 10)) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 51)) (-3951 (((-121) (-1 (-121) |#1|) $) 40 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 |#1|) (-634 |#1|)) 49 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 48 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 47 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 (-288 |#1|))) 46 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 28)) (-2436 (((-121) $) 31)) (-1990 (($) 30)) (-1363 (($ $ $) 21) (($ $ |#1|) 20)) (-4170 (((-763) |#1| $) 44 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) (((-763) (-1 (-121) |#1|) $) 41 (|has| $ (-6 -4521)))) (-3865 (($ $) 29)) (-4280 (((-541) $) 59 (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) 50)) (-2747 (((-850) $) 11)) (-3846 (($) 26) (($ (-634 |#1|)) 25)) (-3437 (((-121) (-1 (-121) |#1|) $) 39 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 6)) (-1734 (((-121) $ $) 27)) (-1699 (((-763) $) 36 (|has| $ (-6 -4521))))) 
 (((-1087 |#1|) (-1275) (-1090)) (T -1087)) 
-((-1732 (*1 *2 *1 *1) (-12 (-4 *1 (-1087 *3)) (-4 *3 (-1090)) (-5 *2 (-121)))) (-3844 (*1 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090)))) (-3844 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-4 *1 (-1087 *3)))) (-2749 (*1 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090)))) (-2749 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-4 *1 (-1087 *3)))) (-3212 (*1 *1 *1 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090)))) (-4382 (*1 *1 *1 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090)))) (-4382 (*1 *1 *1 *2) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090)))) (-1536 (*1 *1 *1 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090)))) (-2032 (*1 *2 *1 *1) (-12 (-4 *1 (-1087 *3)) (-4 *3 (-1090)) (-5 *2 (-121)))) (-1791 (*1 *1 *1 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090)))) (-1791 (*1 *1 *1 *2) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090)))) (-1791 (*1 *1 *2 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090))))) 
-(-13 (-1090) (-154 |t#1|) (-10 -8 (-6 -4509) (-15 -1732 ((-121) $ $)) (-15 -3844 ($)) (-15 -3844 ($ (-634 |t#1|))) (-15 -2749 ($)) (-15 -2749 ($ (-634 |t#1|))) (-15 -3212 ($ $ $)) (-15 -4382 ($ $ $)) (-15 -4382 ($ $ |t#1|)) (-15 -1536 ($ $ $)) (-15 -2032 ((-121) $ $)) (-15 -1791 ($ $ $)) (-15 -1791 ($ $ |t#1|)) (-15 -1791 ($ |t#1| $)))) 
+((-1734 (*1 *2 *1 *1) (-12 (-4 *1 (-1087 *3)) (-4 *3 (-1090)) (-5 *2 (-121)))) (-3846 (*1 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090)))) (-3846 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-4 *1 (-1087 *3)))) (-2751 (*1 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090)))) (-2751 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-4 *1 (-1087 *3)))) (-1864 (*1 *1 *1 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090)))) (-1363 (*1 *1 *1 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090)))) (-1363 (*1 *1 *1 *2) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090)))) (-4217 (*1 *1 *1 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090)))) (-1430 (*1 *2 *1 *1) (-12 (-4 *1 (-1087 *3)) (-4 *3 (-1090)) (-5 *2 (-121)))) (-1793 (*1 *1 *1 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090)))) (-1793 (*1 *1 *1 *2) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090)))) (-1793 (*1 *1 *2 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090))))) 
+(-13 (-1090) (-154 |t#1|) (-10 -8 (-6 -4511) (-15 -1734 ((-121) $ $)) (-15 -3846 ($)) (-15 -3846 ($ (-634 |t#1|))) (-15 -2751 ($)) (-15 -2751 ($ (-634 |t#1|))) (-15 -1864 ($ $ $)) (-15 -1363 ($ $ $)) (-15 -1363 ($ $ |t#1|)) (-15 -4217 ($ $ $)) (-15 -1430 ((-121) $ $)) (-15 -1793 ($ $ $)) (-15 -1793 ($ $ |t#1|)) (-15 -1793 ($ |t#1| $)))) 
 (((-39) . T) ((-105) . T) ((-608 (-850)) . T) ((-154 |#1|) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-1090) . T) ((-1195) . T)) 
-((-2447 (((-121) $ $) 7)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-3206 (((-917) $) 12)) (-2745 (((-850) $) 11)) (-1717 (((-121) $ $) 6))) 
+((-2449 (((-121) $ $) 7)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-1836 (((-917) $) 12)) (-2747 (((-850) $) 11)) (-1719 (((-121) $ $) 6))) 
 (((-1088) (-1275)) (T -1088)) 
-((-3206 (*1 *2 *1) (-12 (-4 *1 (-1088)) (-5 *2 (-917))))) 
-(-13 (-1090) (-10 -8 (-15 -3206 ((-917) $)))) 
+((-1836 (*1 *2 *1) (-12 (-4 *1 (-1088)) (-5 *2 (-917))))) 
+(-13 (-1090) (-10 -8 (-15 -1836 ((-917) $)))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-4487 (((-1143) $) 10)) (-4022 (((-1108) $) 8))) 
-(((-1089 |#1|) (-10 -8 (-15 -4487 ((-1143) |#1|)) (-15 -4022 ((-1108) |#1|))) (-1090)) (T -1089)) 
+((-1893 (((-1143) $) 10)) (-4025 (((-1108) $) 8))) 
+(((-1089 |#1|) (-10 -8 (-15 -1893 ((-1143) |#1|)) (-15 -4025 ((-1108) |#1|))) (-1090)) (T -1089)) 
 NIL 
-(-10 -8 (-15 -4487 ((-1143) |#1|)) (-15 -4022 ((-1108) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-1717 (((-121) $ $) 6))) 
+(-10 -8 (-15 -1893 ((-1143) |#1|)) (-15 -4025 ((-1108) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-1719 (((-121) $ $) 6))) 
 (((-1090) (-1275)) (T -1090)) 
-((-4022 (*1 *2 *1) (-12 (-4 *1 (-1090)) (-5 *2 (-1108)))) (-4487 (*1 *2 *1) (-12 (-4 *1 (-1090)) (-5 *2 (-1143))))) 
-(-13 (-105) (-608 (-850)) (-10 -8 (-15 -4022 ((-1108) $)) (-15 -4487 ((-1143) $)))) 
+((-4025 (*1 *2 *1) (-12 (-4 *1 (-1090)) (-5 *2 (-1108)))) (-1893 (*1 *2 *1) (-12 (-4 *1 (-1090)) (-5 *2 (-1143))))) 
+(-13 (-105) (-608 (-850)) (-10 -8 (-15 -4025 ((-1108) $)) (-15 -1893 ((-1143) $)))) 
 (((-105) . T) ((-608 (-850)) . T)) 
-((-2447 (((-121) $ $) NIL)) (-3983 (((-763)) 30)) (-1614 (($ (-634 (-917))) 52)) (-4336 (((-3 $ "failed") $ (-917) (-917)) 57)) (-1731 (($) 32)) (-3109 (((-121) (-917) $) 35)) (-3683 (((-917) $) 50)) (-4487 (((-1143) $) NIL)) (-4355 (($ (-917)) 31)) (-2676 (((-3 $ "failed") $ (-917)) 55)) (-4022 (((-1108) $) NIL)) (-3557 (((-1244 $)) 40)) (-1806 (((-634 (-917)) $) 23)) (-1325 (((-763) $ (-917) (-917)) 56)) (-2745 (((-850) $) 29)) (-1717 (((-121) $ $) 21))) 
-(((-1091 |#1| |#2|) (-13 (-370) (-10 -8 (-15 -2676 ((-3 $ "failed") $ (-917))) (-15 -4336 ((-3 $ "failed") $ (-917) (-917))) (-15 -1806 ((-634 (-917)) $)) (-15 -1614 ($ (-634 (-917)))) (-15 -3557 ((-1244 $))) (-15 -3109 ((-121) (-917) $)) (-15 -1325 ((-763) $ (-917) (-917))))) (-917) (-917)) (T -1091)) 
-((-2676 (*1 *1 *1 *2) (|partial| -12 (-5 *2 (-917)) (-5 *1 (-1091 *3 *4)) (-14 *3 *2) (-14 *4 *2))) (-4336 (*1 *1 *1 *2 *2) (|partial| -12 (-5 *2 (-917)) (-5 *1 (-1091 *3 *4)) (-14 *3 *2) (-14 *4 *2))) (-1806 (*1 *2 *1) (-12 (-5 *2 (-634 (-917))) (-5 *1 (-1091 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917)))) (-1614 (*1 *1 *2) (-12 (-5 *2 (-634 (-917))) (-5 *1 (-1091 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917)))) (-3557 (*1 *2) (-12 (-5 *2 (-1244 (-1091 *3 *4))) (-5 *1 (-1091 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917)))) (-3109 (*1 *2 *3 *1) (-12 (-5 *3 (-917)) (-5 *2 (-121)) (-5 *1 (-1091 *4 *5)) (-14 *4 *3) (-14 *5 *3))) (-1325 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-763)) (-5 *1 (-1091 *4 *5)) (-14 *4 *3) (-14 *5 *3)))) 
-(-13 (-370) (-10 -8 (-15 -2676 ((-3 $ "failed") $ (-917))) (-15 -4336 ((-3 $ "failed") $ (-917) (-917))) (-15 -1806 ((-634 (-917)) $)) (-15 -1614 ($ (-634 (-917)))) (-15 -3557 ((-1244 $))) (-15 -3109 ((-121) (-917) $)) (-15 -1325 ((-763) $ (-917) (-917))))) 
-((-2447 (((-121) $ $) NIL)) (-3415 (($) NIL (|has| |#1| (-370)))) (-1791 (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ $ $) 73)) (-1536 (($ $ $) 71)) (-2032 (((-121) $ $) 72)) (-2510 (((-121) $ (-763)) NIL)) (-3983 (((-763)) NIL (|has| |#1| (-370)))) (-2749 (($ (-634 |#1|)) NIL) (($) 13)) (-3507 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-2671 (($) NIL T CONST)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3405 (($ |#1| $) 67 (|has| $ (-6 -4519))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-4328 (($ |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 43 (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 41 (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) 39 (|has| $ (-6 -4519)))) (-1731 (($) NIL (|has| |#1| (-370)))) (-4360 (((-634 |#1|) $) 19 (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) NIL)) (-2521 ((|#1| $) 57 (|has| |#1| (-842)))) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 66 (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3268 ((|#1| $) 55 (|has| |#1| (-842)))) (-3674 (($ (-1 |#1| |#1|) $) 33 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 34)) (-3683 (((-917) $) NIL (|has| |#1| (-370)))) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL)) (-3212 (($ $ $) 69)) (-1890 ((|#1| $) 25)) (-4450 (($ |#1| $) 65)) (-4355 (($ (-917)) NIL (|has| |#1| (-370)))) (-4022 (((-1108) $) NIL)) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 31)) (-1315 ((|#1| $) 27)) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) 21)) (-3248 (($) 11)) (-4382 (($ $ |#1|) NIL) (($ $ $) 70)) (-2085 (($) NIL) (($ (-634 |#1|)) NIL)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) 16)) (-4278 (((-541) $) 52 (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) 61)) (-2160 (($ $) NIL (|has| |#1| (-370)))) (-2745 (((-850) $) NIL)) (-2432 (((-763) $) NIL)) (-3844 (($ (-634 |#1|)) NIL) (($) 12)) (-2367 (($ (-634 |#1|)) NIL)) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 54)) (-1732 (((-121) $ $) NIL)) (-1697 (((-763) $) 10 (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL)) (-3986 (((-763)) 30)) (-1417 (($ (-634 (-917))) 52)) (-3167 (((-3 $ "failed") $ (-917) (-917)) 57)) (-1733 (($) 32)) (-2551 (((-121) (-917) $) 35)) (-2291 (((-917) $) 50)) (-1893 (((-1143) $) NIL)) (-4357 (($ (-917)) 31)) (-1285 (((-3 $ "failed") $ (-917)) 55)) (-4025 (((-1108) $) NIL)) (-2838 (((-1244 $)) 40)) (-2163 (((-634 (-917)) $) 23)) (-3488 (((-763) $ (-917) (-917)) 56)) (-2747 (((-850) $) 29)) (-1719 (((-121) $ $) 21))) 
+(((-1091 |#1| |#2|) (-13 (-370) (-10 -8 (-15 -1285 ((-3 $ "failed") $ (-917))) (-15 -3167 ((-3 $ "failed") $ (-917) (-917))) (-15 -2163 ((-634 (-917)) $)) (-15 -1417 ($ (-634 (-917)))) (-15 -2838 ((-1244 $))) (-15 -2551 ((-121) (-917) $)) (-15 -3488 ((-763) $ (-917) (-917))))) (-917) (-917)) (T -1091)) 
+((-1285 (*1 *1 *1 *2) (|partial| -12 (-5 *2 (-917)) (-5 *1 (-1091 *3 *4)) (-14 *3 *2) (-14 *4 *2))) (-3167 (*1 *1 *1 *2 *2) (|partial| -12 (-5 *2 (-917)) (-5 *1 (-1091 *3 *4)) (-14 *3 *2) (-14 *4 *2))) (-2163 (*1 *2 *1) (-12 (-5 *2 (-634 (-917))) (-5 *1 (-1091 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917)))) (-1417 (*1 *1 *2) (-12 (-5 *2 (-634 (-917))) (-5 *1 (-1091 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917)))) (-2838 (*1 *2) (-12 (-5 *2 (-1244 (-1091 *3 *4))) (-5 *1 (-1091 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917)))) (-2551 (*1 *2 *3 *1) (-12 (-5 *3 (-917)) (-5 *2 (-121)) (-5 *1 (-1091 *4 *5)) (-14 *4 *3) (-14 *5 *3))) (-3488 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-763)) (-5 *1 (-1091 *4 *5)) (-14 *4 *3) (-14 *5 *3)))) 
+(-13 (-370) (-10 -8 (-15 -1285 ((-3 $ "failed") $ (-917))) (-15 -3167 ((-3 $ "failed") $ (-917) (-917))) (-15 -2163 ((-634 (-917)) $)) (-15 -1417 ($ (-634 (-917)))) (-15 -2838 ((-1244 $))) (-15 -2551 ((-121) (-917) $)) (-15 -3488 ((-763) $ (-917) (-917))))) 
+((-2449 (((-121) $ $) NIL)) (-1611 (($) NIL (|has| |#1| (-370)))) (-1793 (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ $ $) 73)) (-4217 (($ $ $) 71)) (-1430 (((-121) $ $) 72)) (-1667 (((-121) $ (-763)) NIL)) (-3986 (((-763)) NIL (|has| |#1| (-370)))) (-2751 (($ (-634 |#1|)) NIL) (($) 13)) (-3963 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-4490 (($) NIL T CONST)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1568 (($ |#1| $) 67 (|has| $ (-6 -4521))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-4330 (($ |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 43 (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 41 (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) 39 (|has| $ (-6 -4521)))) (-1733 (($) NIL (|has| |#1| (-370)))) (-3317 (((-634 |#1|) $) 19 (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) NIL)) (-1732 ((|#1| $) 57 (|has| |#1| (-842)))) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 66 (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-2047 ((|#1| $) 55 (|has| |#1| (-842)))) (-2253 (($ (-1 |#1| |#1|) $) 33 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 34)) (-2291 (((-917) $) NIL (|has| |#1| (-370)))) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL)) (-1864 (($ $ $) 69)) (-2580 ((|#1| $) 25)) (-1708 (($ |#1| $) 65)) (-4357 (($ (-917)) NIL (|has| |#1| (-370)))) (-4025 (((-1108) $) NIL)) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 31)) (-3403 ((|#1| $) 27)) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) 21)) (-1990 (($) 11)) (-1363 (($ $ |#1|) NIL) (($ $ $) 70)) (-3132 (($) NIL) (($ (-634 |#1|)) NIL)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) 16)) (-4280 (((-541) $) 52 (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) 61)) (-3695 (($ $) NIL (|has| |#1| (-370)))) (-2747 (((-850) $) NIL)) (-2429 (((-763) $) NIL)) (-3846 (($ (-634 |#1|)) NIL) (($) 12)) (-4074 (($ (-634 |#1|)) NIL)) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 54)) (-1734 (((-121) $ $) NIL)) (-1699 (((-763) $) 10 (|has| $ (-6 -4521))))) 
 (((-1092 |#1|) (-427 |#1|) (-1090)) (T -1092)) 
 NIL 
 (-427 |#1|) 
-((-2447 (((-121) $ $) 7)) (-2500 (((-121) $) 31)) (-3180 ((|#2| $) 26)) (-1620 (((-121) $) 32)) (-1742 ((|#1| $) 27)) (-2341 (((-121) $) 34)) (-2491 (((-121) $) 36)) (-1795 (((-121) $) 33)) (-4487 (((-1143) $) 9)) (-4469 (((-121) $) 30)) (-1721 ((|#3| $) 25)) (-4022 (((-1108) $) 10)) (-1487 (((-121) $) 29)) (-3768 ((|#4| $) 24)) (-4151 ((|#5| $) 23)) (-1853 (((-121) $ $) 37)) (-2779 (($ $ (-568)) 13) (($ $ (-634 (-568))) 12)) (-2043 (((-634 $) $) 28)) (-4278 (($ (-634 $)) 22) (($ |#1|) 21) (($ |#2|) 20) (($ |#3|) 19) (($ |#4|) 18) (($ |#5|) 17)) (-2745 (((-850) $) 11)) (-1527 (($ $) 15)) (-1520 (($ $) 16)) (-3826 (((-121) $) 35)) (-1717 (((-121) $ $) 6)) (-1697 (((-568) $) 14))) 
+((-2449 (((-121) $ $) 7)) (-1623 (((-121) $) 31)) (-3182 ((|#2| $) 26)) (-1454 (((-121) $) 32)) (-1744 ((|#1| $) 27)) (-3909 (((-121) $) 34)) (-2722 (((-121) $) 36)) (-2118 (((-121) $) 33)) (-1893 (((-1143) $) 9)) (-1812 (((-121) $) 30)) (-1723 ((|#3| $) 25)) (-4025 (((-1108) $) 10)) (-2538 (((-121) $) 29)) (-3770 ((|#4| $) 24)) (-4153 ((|#5| $) 23)) (-2410 (((-121) $ $) 37)) (-2781 (($ $ (-568)) 13) (($ $ (-634 (-568))) 12)) (-2045 (((-634 $) $) 28)) (-4280 (($ (-634 $)) 22) (($ |#1|) 21) (($ |#2|) 20) (($ |#3|) 19) (($ |#4|) 18) (($ |#5|) 17)) (-2747 (((-850) $) 11)) (-1527 (($ $) 15)) (-1518 (($ $) 16)) (-1803 (((-121) $) 35)) (-1719 (((-121) $ $) 6)) (-1699 (((-568) $) 14))) 
 (((-1093 |#1| |#2| |#3| |#4| |#5|) (-1275) (-1090) (-1090) (-1090) (-1090) (-1090)) (T -1093)) 
-((-1853 (*1 *2 *1 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121)))) (-2491 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121)))) (-3826 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121)))) (-2341 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121)))) (-1795 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121)))) (-1620 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121)))) (-2500 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121)))) (-4469 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121)))) (-1487 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121)))) (-2043 (*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-634 *1)) (-4 *1 (-1093 *3 *4 *5 *6 *7)))) (-1742 (*1 *2 *1) (-12 (-4 *1 (-1093 *2 *3 *4 *5 *6)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-1090)))) (-3180 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *2 *4 *5 *6)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-1090)))) (-1721 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *2 *5 *6)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-1090)))) (-3768 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *2 *6)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-1090)))) (-4151 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *2)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-1090)))) (-4278 (*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)))) (-4278 (*1 *1 *2) (-12 (-4 *1 (-1093 *2 *3 *4 *5 *6)) (-4 *2 (-1090)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)))) (-4278 (*1 *1 *2) (-12 (-4 *1 (-1093 *3 *2 *4 *5 *6)) (-4 *3 (-1090)) (-4 *2 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)))) (-4278 (*1 *1 *2) (-12 (-4 *1 (-1093 *3 *4 *2 *5 *6)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *2 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)))) (-4278 (*1 *1 *2) (-12 (-4 *1 (-1093 *3 *4 *5 *2 *6)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *2 (-1090)) (-4 *6 (-1090)))) (-4278 (*1 *1 *2) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *2)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-1090)))) (-1520 (*1 *1 *1) (-12 (-4 *1 (-1093 *2 *3 *4 *5 *6)) (-4 *2 (-1090)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)))) (-1527 (*1 *1 *1) (-12 (-4 *1 (-1093 *2 *3 *4 *5 *6)) (-4 *2 (-1090)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)))) (-1697 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-568)))) (-2779 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)))) (-2779 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090))))) 
-(-13 (-1090) (-10 -8 (-15 -1853 ((-121) $ $)) (-15 -2491 ((-121) $)) (-15 -3826 ((-121) $)) (-15 -2341 ((-121) $)) (-15 -1795 ((-121) $)) (-15 -1620 ((-121) $)) (-15 -2500 ((-121) $)) (-15 -4469 ((-121) $)) (-15 -1487 ((-121) $)) (-15 -2043 ((-634 $) $)) (-15 -1742 (|t#1| $)) (-15 -3180 (|t#2| $)) (-15 -1721 (|t#3| $)) (-15 -3768 (|t#4| $)) (-15 -4151 (|t#5| $)) (-15 -4278 ($ (-634 $))) (-15 -4278 ($ |t#1|)) (-15 -4278 ($ |t#2|)) (-15 -4278 ($ |t#3|)) (-15 -4278 ($ |t#4|)) (-15 -4278 ($ |t#5|)) (-15 -1520 ($ $)) (-15 -1527 ($ $)) (-15 -1697 ((-568) $)) (-15 -2779 ($ $ (-568))) (-15 -2779 ($ $ (-634 (-568)))))) 
+((-2410 (*1 *2 *1 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121)))) (-2722 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121)))) (-1803 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121)))) (-3909 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121)))) (-2118 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121)))) (-1454 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121)))) (-1623 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121)))) (-1812 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121)))) (-2538 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121)))) (-2045 (*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-634 *1)) (-4 *1 (-1093 *3 *4 *5 *6 *7)))) (-1744 (*1 *2 *1) (-12 (-4 *1 (-1093 *2 *3 *4 *5 *6)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-1090)))) (-3182 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *2 *4 *5 *6)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-1090)))) (-1723 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *2 *5 *6)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-1090)))) (-3770 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *2 *6)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-1090)))) (-4153 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *2)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-1090)))) (-4280 (*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)))) (-4280 (*1 *1 *2) (-12 (-4 *1 (-1093 *2 *3 *4 *5 *6)) (-4 *2 (-1090)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)))) (-4280 (*1 *1 *2) (-12 (-4 *1 (-1093 *3 *2 *4 *5 *6)) (-4 *3 (-1090)) (-4 *2 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)))) (-4280 (*1 *1 *2) (-12 (-4 *1 (-1093 *3 *4 *2 *5 *6)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *2 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)))) (-4280 (*1 *1 *2) (-12 (-4 *1 (-1093 *3 *4 *5 *2 *6)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *2 (-1090)) (-4 *6 (-1090)))) (-4280 (*1 *1 *2) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *2)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-1090)))) (-1518 (*1 *1 *1) (-12 (-4 *1 (-1093 *2 *3 *4 *5 *6)) (-4 *2 (-1090)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)))) (-1527 (*1 *1 *1) (-12 (-4 *1 (-1093 *2 *3 *4 *5 *6)) (-4 *2 (-1090)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)))) (-1699 (*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-568)))) (-2781 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)))) (-2781 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090))))) 
+(-13 (-1090) (-10 -8 (-15 -2410 ((-121) $ $)) (-15 -2722 ((-121) $)) (-15 -1803 ((-121) $)) (-15 -3909 ((-121) $)) (-15 -2118 ((-121) $)) (-15 -1454 ((-121) $)) (-15 -1623 ((-121) $)) (-15 -1812 ((-121) $)) (-15 -2538 ((-121) $)) (-15 -2045 ((-634 $) $)) (-15 -1744 (|t#1| $)) (-15 -3182 (|t#2| $)) (-15 -1723 (|t#3| $)) (-15 -3770 (|t#4| $)) (-15 -4153 (|t#5| $)) (-15 -4280 ($ (-634 $))) (-15 -4280 ($ |t#1|)) (-15 -4280 ($ |t#2|)) (-15 -4280 ($ |t#3|)) (-15 -4280 ($ |t#4|)) (-15 -4280 ($ |t#5|)) (-15 -1518 ($ $)) (-15 -1527 ($ $)) (-15 -1699 ((-568) $)) (-15 -2781 ($ $ (-568))) (-15 -2781 ($ $ (-634 (-568)))))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2500 (((-121) $) NIL)) (-3180 (((-1161) $) NIL)) (-1620 (((-121) $) NIL)) (-1742 (((-1143) $) NIL)) (-2341 (((-121) $) NIL)) (-2491 (((-121) $) NIL)) (-1795 (((-121) $) NIL)) (-4487 (((-1143) $) NIL)) (-4469 (((-121) $) NIL)) (-1721 (((-568) $) NIL)) (-4022 (((-1108) $) NIL)) (-1487 (((-121) $) NIL)) (-3768 (((-215) $) NIL)) (-4151 (((-850) $) NIL)) (-1853 (((-121) $ $) NIL)) (-2779 (($ $ (-568)) NIL) (($ $ (-634 (-568))) NIL)) (-2043 (((-634 $) $) NIL)) (-4278 (($ (-634 $)) NIL) (($ (-1143)) NIL) (($ (-1161)) NIL) (($ (-568)) NIL) (($ (-215)) NIL) (($ (-850)) NIL)) (-2745 (((-850) $) NIL)) (-1527 (($ $) NIL)) (-1520 (($ $) NIL)) (-3826 (((-121) $) NIL)) (-1717 (((-121) $ $) NIL)) (-1697 (((-568) $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-1623 (((-121) $) NIL)) (-3182 (((-1161) $) NIL)) (-1454 (((-121) $) NIL)) (-1744 (((-1143) $) NIL)) (-3909 (((-121) $) NIL)) (-2722 (((-121) $) NIL)) (-2118 (((-121) $) NIL)) (-1893 (((-1143) $) NIL)) (-1812 (((-121) $) NIL)) (-1723 (((-568) $) NIL)) (-4025 (((-1108) $) NIL)) (-2538 (((-121) $) NIL)) (-3770 (((-215) $) NIL)) (-4153 (((-850) $) NIL)) (-2410 (((-121) $ $) NIL)) (-2781 (($ $ (-568)) NIL) (($ $ (-634 (-568))) NIL)) (-2045 (((-634 $) $) NIL)) (-4280 (($ (-634 $)) NIL) (($ (-1143)) NIL) (($ (-1161)) NIL) (($ (-568)) NIL) (($ (-215)) NIL) (($ (-850)) NIL)) (-2747 (((-850) $) NIL)) (-1527 (($ $) NIL)) (-1518 (($ $) NIL)) (-1803 (((-121) $) NIL)) (-1719 (((-121) $ $) NIL)) (-1699 (((-568) $) NIL))) 
 (((-1094) (-1093 (-1143) (-1161) (-568) (-215) (-850))) (T -1094)) 
 NIL 
 (-1093 (-1143) (-1161) (-568) (-215) (-850)) 
-((-2447 (((-121) $ $) NIL)) (-2500 (((-121) $) 37)) (-3180 ((|#2| $) 41)) (-1620 (((-121) $) 36)) (-1742 ((|#1| $) 40)) (-2341 (((-121) $) 34)) (-2491 (((-121) $) 14)) (-1795 (((-121) $) 35)) (-4487 (((-1143) $) NIL)) (-4469 (((-121) $) 38)) (-1721 ((|#3| $) 43)) (-4022 (((-1108) $) NIL)) (-1487 (((-121) $) 39)) (-3768 ((|#4| $) 42)) (-4151 ((|#5| $) 44)) (-1853 (((-121) $ $) 33)) (-2779 (($ $ (-568)) 55) (($ $ (-634 (-568))) 57)) (-2043 (((-634 $) $) 21)) (-4278 (($ (-634 $)) 45) (($ |#1|) 46) (($ |#2|) 47) (($ |#3|) 48) (($ |#4|) 49) (($ |#5|) 50)) (-2745 (((-850) $) 22)) (-1527 (($ $) 20)) (-1520 (($ $) 51)) (-3826 (((-121) $) 18)) (-1717 (((-121) $ $) 32)) (-1697 (((-568) $) 53))) 
+((-2449 (((-121) $ $) NIL)) (-1623 (((-121) $) 37)) (-3182 ((|#2| $) 41)) (-1454 (((-121) $) 36)) (-1744 ((|#1| $) 40)) (-3909 (((-121) $) 34)) (-2722 (((-121) $) 14)) (-2118 (((-121) $) 35)) (-1893 (((-1143) $) NIL)) (-1812 (((-121) $) 38)) (-1723 ((|#3| $) 43)) (-4025 (((-1108) $) NIL)) (-2538 (((-121) $) 39)) (-3770 ((|#4| $) 42)) (-4153 ((|#5| $) 44)) (-2410 (((-121) $ $) 33)) (-2781 (($ $ (-568)) 55) (($ $ (-634 (-568))) 57)) (-2045 (((-634 $) $) 21)) (-4280 (($ (-634 $)) 45) (($ |#1|) 46) (($ |#2|) 47) (($ |#3|) 48) (($ |#4|) 49) (($ |#5|) 50)) (-2747 (((-850) $) 22)) (-1527 (($ $) 20)) (-1518 (($ $) 51)) (-1803 (((-121) $) 18)) (-1719 (((-121) $ $) 32)) (-1699 (((-568) $) 53))) 
 (((-1095 |#1| |#2| |#3| |#4| |#5|) (-1093 |#1| |#2| |#3| |#4| |#5|) (-1090) (-1090) (-1090) (-1090) (-1090)) (T -1095)) 
 NIL 
 (-1093 |#1| |#2| |#3| |#4| |#5|) 
-((-4128 (((-1249) $) 23)) (-3220 (($ (-1161) (-436) |#2|) 11)) (-2745 (((-850) $) 16))) 
-(((-1096 |#1| |#2|) (-13 (-397) (-10 -8 (-15 -3220 ($ (-1161) (-436) |#2|)))) (-842) (-432 |#1|)) (T -1096)) 
-((-3220 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-436)) (-4 *5 (-842)) (-5 *1 (-1096 *5 *4)) (-4 *4 (-432 *5))))) 
-(-13 (-397) (-10 -8 (-15 -3220 ($ (-1161) (-436) |#2|)))) 
-((-1278 (((-121) |#5| |#5|) 37)) (-3891 (((-121) |#5| |#5|) 51)) (-2212 (((-121) |#5| (-634 |#5|)) 74) (((-121) |#5| |#5|) 60)) (-4302 (((-121) (-634 |#4|) (-634 |#4|)) 57)) (-3686 (((-121) (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|)) (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) 62)) (-2008 (((-1249)) 33)) (-1373 (((-1249) (-1143) (-1143) (-1143)) 29)) (-2164 (((-634 |#5|) (-634 |#5|)) 81)) (-2736 (((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|)))) 79)) (-3553 (((-634 (-2 (|:| -1853 (-634 |#4|)) (|:| -3001 |#5|) (|:| |ineq| (-634 |#4|)))) (-634 |#4|) (-634 |#5|) (-121) (-121)) 101)) (-2068 (((-121) |#5| |#5|) 46)) (-4350 (((-3 (-121) "failed") |#5| |#5|) 70)) (-4048 (((-121) (-634 |#4|) (-634 |#4|)) 56)) (-4354 (((-121) (-634 |#4|) (-634 |#4|)) 58)) (-2644 (((-121) (-634 |#4|) (-634 |#4|)) 59)) (-3821 (((-3 (-2 (|:| -1853 (-634 |#4|)) (|:| -3001 |#5|) (|:| |ineq| (-634 |#4|))) "failed") (-634 |#4|) |#5| (-634 |#4|) (-121) (-121) (-121) (-121) (-121)) 97)) (-2283 (((-634 |#5|) (-634 |#5|)) 42))) 
-(((-1097 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1373 ((-1249) (-1143) (-1143) (-1143))) (-15 -2008 ((-1249))) (-15 -1278 ((-121) |#5| |#5|)) (-15 -2283 ((-634 |#5|) (-634 |#5|))) (-15 -2068 ((-121) |#5| |#5|)) (-15 -3891 ((-121) |#5| |#5|)) (-15 -4302 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -4048 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -4354 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -2644 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -4350 ((-3 (-121) "failed") |#5| |#5|)) (-15 -2212 ((-121) |#5| |#5|)) (-15 -2212 ((-121) |#5| (-634 |#5|))) (-15 -2164 ((-634 |#5|) (-634 |#5|))) (-15 -3686 ((-121) (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|)) (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|)))) (-15 -2736 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) (-15 -3553 ((-634 (-2 (|:| -1853 (-634 |#4|)) (|:| -3001 |#5|) (|:| |ineq| (-634 |#4|)))) (-634 |#4|) (-634 |#5|) (-121) (-121))) (-15 -3821 ((-3 (-2 (|:| -1853 (-634 |#4|)) (|:| -3001 |#5|) (|:| |ineq| (-634 |#4|))) "failed") (-634 |#4|) |#5| (-634 |#4|) (-121) (-121) (-121) (-121) (-121)))) (-453) (-788) (-842) (-1061 |#1| |#2| |#3|) (-1066 |#1| |#2| |#3| |#4|)) (T -1097)) 
-((-3821 (*1 *2 *3 *4 *3 *5 *5 *5 *5 *5) (|partial| -12 (-5 *5 (-121)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *9 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| -1853 (-634 *9)) (|:| -3001 *4) (|:| |ineq| (-634 *9)))) (-5 *1 (-1097 *6 *7 *8 *9 *4)) (-5 *3 (-634 *9)) (-4 *4 (-1066 *6 *7 *8 *9)))) (-3553 (*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-634 *10)) (-5 *5 (-121)) (-4 *10 (-1066 *6 *7 *8 *9)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *9 (-1061 *6 *7 *8)) (-5 *2 (-634 (-2 (|:| -1853 (-634 *9)) (|:| -3001 *10) (|:| |ineq| (-634 *9))))) (-5 *1 (-1097 *6 *7 *8 *9 *10)) (-5 *3 (-634 *9)))) (-2736 (*1 *2 *2) (-12 (-5 *2 (-634 (-2 (|:| |val| (-634 *6)) (|:| -3001 *7)))) (-4 *6 (-1061 *3 *4 *5)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-1097 *3 *4 *5 *6 *7)))) (-3686 (*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |val| (-634 *7)) (|:| -3001 *8))) (-4 *7 (-1061 *4 *5 *6)) (-4 *8 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *8)))) (-2164 (*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *1 (-1097 *3 *4 *5 *6 *7)))) (-2212 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-1097 *5 *6 *7 *8 *3)))) (-2212 (*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) (-4350 (*1 *2 *3 *3) (|partial| -12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) (-2644 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) (-4354 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) (-4048 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) (-4302 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) (-3891 (*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) (-2068 (*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) (-2283 (*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *1 (-1097 *3 *4 *5 *6 *7)))) (-1278 (*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) (-2008 (*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-1097 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6)))) (-1373 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-1097 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7))))) 
-(-10 -7 (-15 -1373 ((-1249) (-1143) (-1143) (-1143))) (-15 -2008 ((-1249))) (-15 -1278 ((-121) |#5| |#5|)) (-15 -2283 ((-634 |#5|) (-634 |#5|))) (-15 -2068 ((-121) |#5| |#5|)) (-15 -3891 ((-121) |#5| |#5|)) (-15 -4302 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -4048 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -4354 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -2644 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -4350 ((-3 (-121) "failed") |#5| |#5|)) (-15 -2212 ((-121) |#5| |#5|)) (-15 -2212 ((-121) |#5| (-634 |#5|))) (-15 -2164 ((-634 |#5|) (-634 |#5|))) (-15 -3686 ((-121) (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|)) (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|)))) (-15 -2736 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) (-15 -3553 ((-634 (-2 (|:| -1853 (-634 |#4|)) (|:| -3001 |#5|) (|:| |ineq| (-634 |#4|)))) (-634 |#4|) (-634 |#5|) (-121) (-121))) (-15 -3821 ((-3 (-2 (|:| -1853 (-634 |#4|)) (|:| -3001 |#5|) (|:| |ineq| (-634 |#4|))) "failed") (-634 |#4|) |#5| (-634 |#4|) (-121) (-121) (-121) (-121) (-121)))) 
-((-4346 (((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#5|) 94)) (-3291 (((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) |#4| |#4| |#5|) 70)) (-3522 (((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#4| |#5|) 88)) (-3452 (((-634 |#5|) |#4| |#5|) 109)) (-1310 (((-634 |#5|) |#4| |#5|) 116)) (-4400 (((-634 |#5|) |#4| |#5|) 117)) (-2876 (((-634 (-2 (|:| |val| (-121)) (|:| -3001 |#5|))) |#4| |#5|) 95)) (-1493 (((-634 (-2 (|:| |val| (-121)) (|:| -3001 |#5|))) |#4| |#5|) 115)) (-1756 (((-634 (-2 (|:| |val| (-121)) (|:| -3001 |#5|))) |#4| |#5|) 44) (((-121) |#4| |#5|) 52)) (-1676 (((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) |#3| (-121)) 82) (((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#4| |#5| (-121) (-121)) 49)) (-3504 (((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#4| |#5|) 77)) (-3818 (((-1249)) 35)) (-2270 (((-1249)) 25)) (-3194 (((-1249) (-1143) (-1143) (-1143)) 31)) (-3179 (((-1249) (-1143) (-1143) (-1143)) 20))) 
-(((-1098 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3179 ((-1249) (-1143) (-1143) (-1143))) (-15 -2270 ((-1249))) (-15 -3194 ((-1249) (-1143) (-1143) (-1143))) (-15 -3818 ((-1249))) (-15 -3291 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) |#4| |#4| |#5|)) (-15 -1676 ((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#4| |#5| (-121) (-121))) (-15 -1676 ((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) |#3| (-121))) (-15 -3504 ((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#4| |#5|)) (-15 -3522 ((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#4| |#5|)) (-15 -1756 ((-121) |#4| |#5|)) (-15 -2876 ((-634 (-2 (|:| |val| (-121)) (|:| -3001 |#5|))) |#4| |#5|)) (-15 -3452 ((-634 |#5|) |#4| |#5|)) (-15 -1493 ((-634 (-2 (|:| |val| (-121)) (|:| -3001 |#5|))) |#4| |#5|)) (-15 -1310 ((-634 |#5|) |#4| |#5|)) (-15 -1756 ((-634 (-2 (|:| |val| (-121)) (|:| -3001 |#5|))) |#4| |#5|)) (-15 -4400 ((-634 |#5|) |#4| |#5|)) (-15 -4346 ((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#5|))) (-453) (-788) (-842) (-1061 |#1| |#2| |#3|) (-1066 |#1| |#2| |#3| |#4|)) (T -1098)) 
-((-4346 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-4400 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 *4)) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-1756 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3001 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-1310 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 *4)) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-1493 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3001 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-3452 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 *4)) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-2876 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3001 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-1756 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-3522 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-3504 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-1676 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-2 (|:| |val| (-634 *8)) (|:| -3001 *9)))) (-5 *5 (-121)) (-4 *8 (-1061 *6 *7 *4)) (-4 *9 (-1066 *6 *7 *4 *8)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *4 (-842)) (-5 *2 (-634 (-2 (|:| |val| *8) (|:| -3001 *9)))) (-5 *1 (-1098 *6 *7 *4 *8 *9)))) (-1676 (*1 *2 *3 *3 *4 *5 *5) (-12 (-5 *5 (-121)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *4)))) (-5 *1 (-1098 *6 *7 *8 *3 *4)) (-4 *4 (-1066 *6 *7 *8 *3)))) (-3291 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-3818 (*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-1098 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6)))) (-3194 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-1098 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) (-2270 (*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-1098 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6)))) (-3179 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-1098 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7))))) 
-(-10 -7 (-15 -3179 ((-1249) (-1143) (-1143) (-1143))) (-15 -2270 ((-1249))) (-15 -3194 ((-1249) (-1143) (-1143) (-1143))) (-15 -3818 ((-1249))) (-15 -3291 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) |#4| |#4| |#5|)) (-15 -1676 ((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#4| |#5| (-121) (-121))) (-15 -1676 ((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) |#3| (-121))) (-15 -3504 ((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#4| |#5|)) (-15 -3522 ((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#4| |#5|)) (-15 -1756 ((-121) |#4| |#5|)) (-15 -2876 ((-634 (-2 (|:| |val| (-121)) (|:| -3001 |#5|))) |#4| |#5|)) (-15 -3452 ((-634 |#5|) |#4| |#5|)) (-15 -1493 ((-634 (-2 (|:| |val| (-121)) (|:| -3001 |#5|))) |#4| |#5|)) (-15 -1310 ((-634 |#5|) |#4| |#5|)) (-15 -1756 ((-634 (-2 (|:| |val| (-121)) (|:| -3001 |#5|))) |#4| |#5|)) (-15 -4400 ((-634 |#5|) |#4| |#5|)) (-15 -4346 ((-634 (-2 (|:| |val| |#4|) (|:| -3001 |#5|))) |#4| |#5|))) 
-((-2447 (((-121) $ $) 7)) (-2387 (((-634 (-2 (|:| -4092 $) (|:| -1798 (-634 |#4|)))) (-634 |#4|)) 78)) (-2415 (((-634 $) (-634 |#4|)) 79) (((-634 $) (-634 |#4|) (-121)) 104)) (-2055 (((-634 |#3|) $) 32)) (-4211 (((-121) $) 25)) (-3824 (((-121) $) 16 (|has| |#1| (-558)))) (-3300 (((-121) |#4| $) 94) (((-121) $) 90)) (-2819 ((|#4| |#4| $) 85)) (-4305 (((-634 (-2 (|:| |val| |#4|) (|:| -3001 $))) |#4| $) 119)) (-3644 (((-2 (|:| |under| $) (|:| -1519 $) (|:| |upper| $)) $ |#3|) 26)) (-2510 (((-121) $ (-763)) 43)) (-2801 (($ (-1 (-121) |#4|) $) 64 (|has| $ (-6 -4519))) (((-3 |#4| "failed") $ |#3|) 72)) (-2671 (($) 44 T CONST)) (-1565 (((-121) $) 21 (|has| |#1| (-558)))) (-3846 (((-121) $ $) 23 (|has| |#1| (-558)))) (-3106 (((-121) $ $) 22 (|has| |#1| (-558)))) (-3695 (((-121) $) 24 (|has| |#1| (-558)))) (-4275 (((-634 |#4|) (-634 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 86)) (-2355 (((-634 |#4|) (-634 |#4|) $) 17 (|has| |#1| (-558)))) (-2492 (((-634 |#4|) (-634 |#4|) $) 18 (|has| |#1| (-558)))) (-3666 (((-3 $ "failed") (-634 |#4|)) 35)) (-2854 (($ (-634 |#4|)) 34)) (-3935 (((-3 $ "failed") $) 75)) (-2062 ((|#4| |#4| $) 82)) (-3924 (($ $) 67 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519))))) (-4328 (($ |#4| $) 66 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) |#4|) $) 63 (|has| $ (-6 -4519)))) (-1500 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-558)))) (-1281 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) 95)) (-4079 ((|#4| |#4| $) 80)) (-3092 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4519))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4519))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 87)) (-3635 (((-2 (|:| -4092 (-634 |#4|)) (|:| -1798 (-634 |#4|))) $) 98)) (-1862 (((-121) |#4| $) 129)) (-4286 (((-121) |#4| $) 126)) (-3193 (((-121) |#4| $) 130) (((-121) $) 127)) (-4360 (((-634 |#4|) $) 51 (|has| $ (-6 -4519)))) (-1362 (((-121) |#4| $) 97) (((-121) $) 96)) (-2356 ((|#3| $) 33)) (-1737 (((-121) $ (-763)) 42)) (-1979 (((-634 |#4|) $) 52 (|has| $ (-6 -4519)))) (-3109 (((-121) |#4| $) 54 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#4| |#4|) $) 46)) (-1432 (((-634 |#3|) $) 31)) (-3392 (((-121) |#3| $) 30)) (-2166 (((-121) $ (-763)) 41)) (-4487 (((-1143) $) 9)) (-2717 (((-3 |#4| (-634 $)) |#4| |#4| $) 121)) (-4330 (((-634 (-2 (|:| |val| |#4|) (|:| -3001 $))) |#4| |#4| $) 120)) (-4162 (((-3 |#4| "failed") $) 76)) (-2335 (((-634 $) |#4| $) 122)) (-1719 (((-3 (-121) (-634 $)) |#4| $) 125)) (-2632 (((-634 (-2 (|:| |val| (-121)) (|:| -3001 $))) |#4| $) 124) (((-121) |#4| $) 123)) (-3212 (((-634 $) |#4| $) 118) (((-634 $) (-634 |#4|) $) 117) (((-634 $) (-634 |#4|) (-634 $)) 116) (((-634 $) |#4| (-634 $)) 115)) (-3473 (($ |#4| $) 110) (($ (-634 |#4|) $) 109)) (-1377 (((-634 |#4|) $) 100)) (-1415 (((-121) |#4| $) 92) (((-121) $) 88)) (-2682 ((|#4| |#4| $) 83)) (-2644 (((-121) $ $) 103)) (-2705 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-558)))) (-4347 (((-121) |#4| $) 93) (((-121) $) 89)) (-4025 ((|#4| |#4| $) 84)) (-4022 (((-1108) $) 10)) (-3876 (((-3 |#4| "failed") $) 77)) (-3775 (((-3 |#4| "failed") (-1 (-121) |#4|) $) 60)) (-1665 (((-3 $ "failed") $ |#4|) 71)) (-1807 (($ $ |#4|) 70) (((-634 $) |#4| $) 108) (((-634 $) |#4| (-634 $)) 107) (((-634 $) (-634 |#4|) $) 106) (((-634 $) (-634 |#4|) (-634 $)) 105)) (-1387 (((-121) (-1 (-121) |#4|) $) 49 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 |#4|) (-634 |#4|)) 58 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) 56 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 (-288 |#4|))) 55 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-3171 (((-121) $ $) 37)) (-3084 (((-121) $) 40)) (-3248 (($) 39)) (-3206 (((-763) $) 99)) (-4168 (((-763) |#4| $) 53 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519)))) (((-763) (-1 (-121) |#4|) $) 50 (|has| $ (-6 -4519)))) (-3863 (($ $) 38)) (-4278 (((-541) $) 68 (|has| |#4| (-609 (-541))))) (-4287 (($ (-634 |#4|)) 59)) (-1290 (($ $ |#3|) 27)) (-3732 (($ $ |#3|) 29)) (-1567 (($ $) 81)) (-3944 (($ $ |#3|) 28)) (-2745 (((-850) $) 11) (((-634 |#4|) $) 36)) (-1878 (((-763) $) 69 (|has| |#3| (-370)))) (-3556 (((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4| |#4|)) 102) (((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) 101)) (-3292 (((-121) $ (-1 (-121) |#4| (-634 |#4|))) 91)) (-2574 (((-634 $) |#4| $) 114) (((-634 $) |#4| (-634 $)) 113) (((-634 $) (-634 |#4|) $) 112) (((-634 $) (-634 |#4|) (-634 $)) 111)) (-1319 (((-121) (-1 (-121) |#4|) $) 48 (|has| $ (-6 -4519)))) (-2739 (((-634 |#3|) $) 74)) (-2288 (((-121) |#4| $) 128)) (-4390 (((-121) |#3| $) 73)) (-1717 (((-121) $ $) 6)) (-1697 (((-763) $) 45 (|has| $ (-6 -4519))))) 
+((-4130 (((-1249) $) 23)) (-3222 (($ (-1161) (-436) |#2|) 11)) (-2747 (((-850) $) 16))) 
+(((-1096 |#1| |#2|) (-13 (-397) (-10 -8 (-15 -3222 ($ (-1161) (-436) |#2|)))) (-842) (-432 |#1|)) (T -1096)) 
+((-3222 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-436)) (-4 *5 (-842)) (-5 *1 (-1096 *5 *4)) (-4 *4 (-432 *5))))) 
+(-13 (-397) (-10 -8 (-15 -3222 ($ (-1161) (-436) |#2|)))) 
+((-1337 (((-121) |#5| |#5|) 37)) (-2037 (((-121) |#5| |#5|) 51)) (-3407 (((-121) |#5| (-634 |#5|)) 74) (((-121) |#5| |#5|) 60)) (-3034 (((-121) (-634 |#4|) (-634 |#4|)) 57)) (-2301 (((-121) (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|)) (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) 62)) (-1294 (((-1249)) 33)) (-3862 (((-1249) (-1143) (-1143) (-1143)) 29)) (-3778 (((-634 |#5|) (-634 |#5|)) 81)) (-1603 (((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|)))) 79)) (-2823 (((-634 (-2 (|:| -2410 (-634 |#4|)) (|:| -3145 |#5|) (|:| |ineq| (-634 |#4|)))) (-634 |#4|) (-634 |#5|) (-121) (-121)) 101)) (-2808 (((-121) |#5| |#5|) 46)) (-3251 (((-3 (-121) "failed") |#5| |#5|) 70)) (-1569 (((-121) (-634 |#4|) (-634 |#4|)) 56)) (-3284 (((-121) (-634 |#4|) (-634 |#4|)) 58)) (-4342 (((-121) (-634 |#4|) (-634 |#4|)) 59)) (-1788 (((-3 (-2 (|:| -2410 (-634 |#4|)) (|:| -3145 |#5|) (|:| |ineq| (-634 |#4|))) "failed") (-634 |#4|) |#5| (-634 |#4|) (-121) (-121) (-121) (-121) (-121)) 97)) (-3506 (((-634 |#5|) (-634 |#5|)) 42))) 
+(((-1097 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3862 ((-1249) (-1143) (-1143) (-1143))) (-15 -1294 ((-1249))) (-15 -1337 ((-121) |#5| |#5|)) (-15 -3506 ((-634 |#5|) (-634 |#5|))) (-15 -2808 ((-121) |#5| |#5|)) (-15 -2037 ((-121) |#5| |#5|)) (-15 -3034 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -1569 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -3284 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -4342 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -3251 ((-3 (-121) "failed") |#5| |#5|)) (-15 -3407 ((-121) |#5| |#5|)) (-15 -3407 ((-121) |#5| (-634 |#5|))) (-15 -3778 ((-634 |#5|) (-634 |#5|))) (-15 -2301 ((-121) (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|)) (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|)))) (-15 -1603 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) (-15 -2823 ((-634 (-2 (|:| -2410 (-634 |#4|)) (|:| -3145 |#5|) (|:| |ineq| (-634 |#4|)))) (-634 |#4|) (-634 |#5|) (-121) (-121))) (-15 -1788 ((-3 (-2 (|:| -2410 (-634 |#4|)) (|:| -3145 |#5|) (|:| |ineq| (-634 |#4|))) "failed") (-634 |#4|) |#5| (-634 |#4|) (-121) (-121) (-121) (-121) (-121)))) (-453) (-788) (-842) (-1061 |#1| |#2| |#3|) (-1066 |#1| |#2| |#3| |#4|)) (T -1097)) 
+((-1788 (*1 *2 *3 *4 *3 *5 *5 *5 *5 *5) (|partial| -12 (-5 *5 (-121)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *9 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| -2410 (-634 *9)) (|:| -3145 *4) (|:| |ineq| (-634 *9)))) (-5 *1 (-1097 *6 *7 *8 *9 *4)) (-5 *3 (-634 *9)) (-4 *4 (-1066 *6 *7 *8 *9)))) (-2823 (*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-634 *10)) (-5 *5 (-121)) (-4 *10 (-1066 *6 *7 *8 *9)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *9 (-1061 *6 *7 *8)) (-5 *2 (-634 (-2 (|:| -2410 (-634 *9)) (|:| -3145 *10) (|:| |ineq| (-634 *9))))) (-5 *1 (-1097 *6 *7 *8 *9 *10)) (-5 *3 (-634 *9)))) (-1603 (*1 *2 *2) (-12 (-5 *2 (-634 (-2 (|:| |val| (-634 *6)) (|:| -3145 *7)))) (-4 *6 (-1061 *3 *4 *5)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-1097 *3 *4 *5 *6 *7)))) (-2301 (*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |val| (-634 *7)) (|:| -3145 *8))) (-4 *7 (-1061 *4 *5 *6)) (-4 *8 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *8)))) (-3778 (*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *1 (-1097 *3 *4 *5 *6 *7)))) (-3407 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-1097 *5 *6 *7 *8 *3)))) (-3407 (*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) (-3251 (*1 *2 *3 *3) (|partial| -12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) (-4342 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) (-3284 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) (-1569 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) (-3034 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) (-2037 (*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) (-2808 (*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) (-3506 (*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *1 (-1097 *3 *4 *5 *6 *7)))) (-1337 (*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) (-1294 (*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-1097 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6)))) (-3862 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-1097 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7))))) 
+(-10 -7 (-15 -3862 ((-1249) (-1143) (-1143) (-1143))) (-15 -1294 ((-1249))) (-15 -1337 ((-121) |#5| |#5|)) (-15 -3506 ((-634 |#5|) (-634 |#5|))) (-15 -2808 ((-121) |#5| |#5|)) (-15 -2037 ((-121) |#5| |#5|)) (-15 -3034 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -1569 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -3284 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -4342 ((-121) (-634 |#4|) (-634 |#4|))) (-15 -3251 ((-3 (-121) "failed") |#5| |#5|)) (-15 -3407 ((-121) |#5| |#5|)) (-15 -3407 ((-121) |#5| (-634 |#5|))) (-15 -3778 ((-634 |#5|) (-634 |#5|))) (-15 -2301 ((-121) (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|)) (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|)))) (-15 -1603 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) (-15 -2823 ((-634 (-2 (|:| -2410 (-634 |#4|)) (|:| -3145 |#5|) (|:| |ineq| (-634 |#4|)))) (-634 |#4|) (-634 |#5|) (-121) (-121))) (-15 -1788 ((-3 (-2 (|:| -2410 (-634 |#4|)) (|:| -3145 |#5|) (|:| |ineq| (-634 |#4|))) "failed") (-634 |#4|) |#5| (-634 |#4|) (-121) (-121) (-121) (-121) (-121)))) 
+((-3227 (((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#5|) 94)) (-2139 (((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) |#4| |#4| |#5|) 70)) (-4071 (((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#4| |#5|) 88)) (-3578 (((-634 |#5|) |#4| |#5|) 109)) (-3361 (((-634 |#5|) |#4| |#5|) 116)) (-1468 (((-634 |#5|) |#4| |#5|) 117)) (-4125 (((-634 (-2 (|:| |val| (-121)) (|:| -3145 |#5|))) |#4| |#5|) 95)) (-2568 (((-634 (-2 (|:| |val| (-121)) (|:| -3145 |#5|))) |#4| |#5|) 115)) (-3889 (((-634 (-2 (|:| |val| (-121)) (|:| -3145 |#5|))) |#4| |#5|) 44) (((-121) |#4| |#5|) 52)) (-3480 (((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) |#3| (-121)) 82) (((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#4| |#5| (-121) (-121)) 49)) (-3939 (((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#4| |#5|) 77)) (-1777 (((-1249)) 35)) (-3398 (((-1249)) 25)) (-1798 (((-1249) (-1143) (-1143) (-1143)) 31)) (-1741 (((-1249) (-1143) (-1143) (-1143)) 20))) 
+(((-1098 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -1741 ((-1249) (-1143) (-1143) (-1143))) (-15 -3398 ((-1249))) (-15 -1798 ((-1249) (-1143) (-1143) (-1143))) (-15 -1777 ((-1249))) (-15 -2139 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) |#4| |#4| |#5|)) (-15 -3480 ((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#4| |#5| (-121) (-121))) (-15 -3480 ((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) |#3| (-121))) (-15 -3939 ((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#4| |#5|)) (-15 -4071 ((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#4| |#5|)) (-15 -3889 ((-121) |#4| |#5|)) (-15 -4125 ((-634 (-2 (|:| |val| (-121)) (|:| -3145 |#5|))) |#4| |#5|)) (-15 -3578 ((-634 |#5|) |#4| |#5|)) (-15 -2568 ((-634 (-2 (|:| |val| (-121)) (|:| -3145 |#5|))) |#4| |#5|)) (-15 -3361 ((-634 |#5|) |#4| |#5|)) (-15 -3889 ((-634 (-2 (|:| |val| (-121)) (|:| -3145 |#5|))) |#4| |#5|)) (-15 -1468 ((-634 |#5|) |#4| |#5|)) (-15 -3227 ((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#5|))) (-453) (-788) (-842) (-1061 |#1| |#2| |#3|) (-1066 |#1| |#2| |#3| |#4|)) (T -1098)) 
+((-3227 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-1468 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 *4)) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-3889 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3145 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-3361 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 *4)) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-2568 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3145 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-3578 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 *4)) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-4125 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3145 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-3889 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-4071 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-3939 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-3480 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-2 (|:| |val| (-634 *8)) (|:| -3145 *9)))) (-5 *5 (-121)) (-4 *8 (-1061 *6 *7 *4)) (-4 *9 (-1066 *6 *7 *4 *8)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *4 (-842)) (-5 *2 (-634 (-2 (|:| |val| *8) (|:| -3145 *9)))) (-5 *1 (-1098 *6 *7 *4 *8 *9)))) (-3480 (*1 *2 *3 *3 *4 *5 *5) (-12 (-5 *5 (-121)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *4)))) (-5 *1 (-1098 *6 *7 *8 *3 *4)) (-4 *4 (-1066 *6 *7 *8 *3)))) (-2139 (*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) (-1777 (*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-1098 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6)))) (-1798 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-1098 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) (-3398 (*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-1098 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6)))) (-1741 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-1098 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7))))) 
+(-10 -7 (-15 -1741 ((-1249) (-1143) (-1143) (-1143))) (-15 -3398 ((-1249))) (-15 -1798 ((-1249) (-1143) (-1143) (-1143))) (-15 -1777 ((-1249))) (-15 -2139 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) |#4| |#4| |#5|)) (-15 -3480 ((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#4| |#5| (-121) (-121))) (-15 -3480 ((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) |#3| (-121))) (-15 -3939 ((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#4| |#5|)) (-15 -4071 ((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#4| |#5|)) (-15 -3889 ((-121) |#4| |#5|)) (-15 -4125 ((-634 (-2 (|:| |val| (-121)) (|:| -3145 |#5|))) |#4| |#5|)) (-15 -3578 ((-634 |#5|) |#4| |#5|)) (-15 -2568 ((-634 (-2 (|:| |val| (-121)) (|:| -3145 |#5|))) |#4| |#5|)) (-15 -3361 ((-634 |#5|) |#4| |#5|)) (-15 -3889 ((-634 (-2 (|:| |val| (-121)) (|:| -3145 |#5|))) |#4| |#5|)) (-15 -1468 ((-634 |#5|) |#4| |#5|)) (-15 -3227 ((-634 (-2 (|:| |val| |#4|) (|:| -3145 |#5|))) |#4| |#5|))) 
+((-2449 (((-121) $ $) 7)) (-2213 (((-634 (-2 (|:| -4094 $) (|:| -2133 (-634 |#4|)))) (-634 |#4|)) 78)) (-2353 (((-634 $) (-634 |#4|)) 79) (((-634 $) (-634 |#4|) (-121)) 104)) (-2057 (((-634 |#3|) $) 32)) (-4141 (((-121) $) 25)) (-1794 (((-121) $) 16 (|has| |#1| (-558)))) (-4231 (((-121) |#4| $) 94) (((-121) $) 90)) (-3767 ((|#4| |#4| $) 85)) (-3045 (((-634 (-2 (|:| |val| |#4|) (|:| -3145 $))) |#4| $) 119)) (-3647 (((-2 (|:| |under| $) (|:| -4115 $) (|:| |upper| $)) $ |#3|) 26)) (-1667 (((-121) $ (-763)) 43)) (-2803 (($ (-1 (-121) |#4|) $) 64 (|has| $ (-6 -4521))) (((-3 |#4| "failed") $ |#3|) 72)) (-4490 (($) 44 T CONST)) (-4382 (((-121) $) 21 (|has| |#1| (-558)))) (-1880 (((-121) $ $) 23 (|has| |#1| (-558)))) (-2536 (((-121) $ $) 22 (|has| |#1| (-558)))) (-2343 (((-121) $) 24 (|has| |#1| (-558)))) (-2941 (((-634 |#4|) (-634 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 86)) (-3993 (((-634 |#4|) (-634 |#4|) $) 17 (|has| |#1| (-558)))) (-2727 (((-634 |#4|) (-634 |#4|) $) 18 (|has| |#1| (-558)))) (-3668 (((-3 $ "failed") (-634 |#4|)) 35)) (-2857 (($ (-634 |#4|)) 34)) (-3936 (((-3 $ "failed") $) 75)) (-3255 ((|#4| |#4| $) 82)) (-3926 (($ $) 67 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521))))) (-4330 (($ |#4| $) 66 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) |#4|) $) 63 (|has| $ (-6 -4521)))) (-2607 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-558)))) (-1359 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) 95)) (-3434 ((|#4| |#4| $) 80)) (-3094 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4521))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4521))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 87)) (-3158 (((-2 (|:| -4094 (-634 |#4|)) (|:| -2133 (-634 |#4|))) $) 98)) (-2451 (((-121) |#4| $) 129)) (-2978 (((-121) |#4| $) 126)) (-1792 (((-121) |#4| $) 130) (((-121) $) 127)) (-3317 (((-634 |#4|) $) 51 (|has| $ (-6 -4521)))) (-3764 (((-121) |#4| $) 97) (((-121) $) 96)) (-4001 ((|#3| $) 33)) (-3791 (((-121) $ (-763)) 42)) (-4406 (((-634 |#4|) $) 52 (|has| $ (-6 -4521)))) (-2551 (((-121) |#4| $) 54 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#4| |#4|) $) 46)) (-2249 (((-634 |#3|) $) 31)) (-1495 (((-121) |#3| $) 30)) (-3796 (((-121) $ (-763)) 41)) (-1893 (((-1143) $) 9)) (-1516 (((-3 |#4| (-634 $)) |#4| |#4| $) 121)) (-3137 (((-634 (-2 (|:| |val| |#4|) (|:| -3145 $))) |#4| |#4| $) 120)) (-4164 (((-3 |#4| "failed") $) 76)) (-3878 (((-634 $) |#4| $) 122)) (-3712 (((-3 (-121) (-634 $)) |#4| $) 125)) (-4266 (((-634 (-2 (|:| |val| (-121)) (|:| -3145 $))) |#4| $) 124) (((-121) |#4| $) 123)) (-1864 (((-634 $) |#4| $) 118) (((-634 $) (-634 |#4|) $) 117) (((-634 $) (-634 |#4|) (-634 $)) 116) (((-634 $) |#4| (-634 $)) 115)) (-3736 (($ |#4| $) 110) (($ (-634 |#4|) $) 109)) (-3882 (((-634 |#4|) $) 100)) (-2157 (((-121) |#4| $) 92) (((-121) $) 88)) (-1315 ((|#4| |#4| $) 83)) (-4342 (((-121) $ $) 103)) (-1440 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-558)))) (-3236 (((-121) |#4| $) 93) (((-121) $) 89)) (-1452 ((|#4| |#4| $) 84)) (-4025 (((-1108) $) 10)) (-3877 (((-3 |#4| "failed") $) 77)) (-2712 (((-3 |#4| "failed") (-1 (-121) |#4|) $) 60)) (-3413 (((-3 $ "failed") $ |#4|) 71)) (-2168 (($ $ |#4|) 70) (((-634 $) |#4| $) 108) (((-634 $) |#4| (-634 $)) 107) (((-634 $) (-634 |#4|) $) 106) (((-634 $) (-634 |#4|) (-634 $)) 105)) (-3951 (((-121) (-1 (-121) |#4|) $) 49 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 |#4|) (-634 |#4|)) 58 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) 56 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 (-288 |#4|))) 55 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-1702 (((-121) $ $) 37)) (-2436 (((-121) $) 40)) (-1990 (($) 39)) (-1836 (((-763) $) 99)) (-4170 (((-763) |#4| $) 53 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521)))) (((-763) (-1 (-121) |#4|) $) 50 (|has| $ (-6 -4521)))) (-3865 (($ $) 38)) (-4280 (((-541) $) 68 (|has| |#4| (-609 (-541))))) (-4289 (($ (-634 |#4|)) 59)) (-3206 (($ $ |#3|) 27)) (-2527 (($ $ |#3|) 29)) (-4392 (($ $) 81)) (-4332 (($ $ |#3|) 28)) (-2747 (((-850) $) 11) (((-634 |#4|) $) 36)) (-2524 (((-763) $) 69 (|has| |#3| (-370)))) (-2835 (((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4| |#4|)) 102) (((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) 101)) (-2145 (((-121) $ (-1 (-121) |#4| (-634 |#4|))) 91)) (-1977 (((-634 $) |#4| $) 114) (((-634 $) |#4| (-634 $)) 113) (((-634 $) (-634 |#4|) $) 112) (((-634 $) (-634 |#4|) (-634 $)) 111)) (-3437 (((-121) (-1 (-121) |#4|) $) 48 (|has| $ (-6 -4521)))) (-3321 (((-634 |#3|) $) 74)) (-3541 (((-121) |#4| $) 128)) (-1413 (((-121) |#3| $) 73)) (-1719 (((-121) $ $) 6)) (-1699 (((-763) $) 45 (|has| $ (-6 -4521))))) 
 (((-1099 |#1| |#2| |#3| |#4|) (-1275) (-453) (-788) (-842) (-1061 |t#1| |t#2| |t#3|)) (T -1099)) 
 NIL 
 (-13 (-1066 |t#1| |t#2| |t#3| |t#4|)) 
 (((-39) . T) ((-105) . T) ((-608 (-634 |#4|)) . T) ((-608 (-850)) . T) ((-154 |#4|) . T) ((-609 (-541)) |has| |#4| (-609 (-541))) ((-303 |#4|) -12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))) ((-499 |#4|) . T) ((-523 |#4| |#4|) -12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))) ((-977 |#1| |#2| |#3| |#4|) . T) ((-1066 |#1| |#2| |#3| |#4|) . T) ((-1090) . T) ((-1189 |#1| |#2| |#3| |#4|) . T) ((-1195) . T)) 
-((-1490 (((-634 (-568)) (-568) (-568) (-568)) 20)) (-2805 (((-634 (-568)) (-568) (-568) (-568)) 12)) (-3895 (((-634 (-568)) (-568) (-568) (-568)) 16)) (-2074 (((-568) (-568) (-568)) 9)) (-1694 (((-1244 (-568)) (-634 (-568)) (-1244 (-568)) (-568)) 44) (((-1244 (-568)) (-1244 (-568)) (-1244 (-568)) (-568)) 39)) (-4103 (((-634 (-568)) (-634 (-568)) (-634 (-568)) (-121)) 26)) (-3129 (((-679 (-568)) (-634 (-568)) (-634 (-568)) (-679 (-568))) 43)) (-2903 (((-679 (-568)) (-634 (-568)) (-634 (-568))) 31)) (-1364 (((-634 (-679 (-568))) (-634 (-568))) 33)) (-2559 (((-634 (-568)) (-634 (-568)) (-634 (-568)) (-679 (-568))) 46)) (-3745 (((-679 (-568)) (-634 (-568)) (-634 (-568)) (-634 (-568))) 54))) 
-(((-1100) (-10 -7 (-15 -3745 ((-679 (-568)) (-634 (-568)) (-634 (-568)) (-634 (-568)))) (-15 -2559 ((-634 (-568)) (-634 (-568)) (-634 (-568)) (-679 (-568)))) (-15 -1364 ((-634 (-679 (-568))) (-634 (-568)))) (-15 -2903 ((-679 (-568)) (-634 (-568)) (-634 (-568)))) (-15 -3129 ((-679 (-568)) (-634 (-568)) (-634 (-568)) (-679 (-568)))) (-15 -4103 ((-634 (-568)) (-634 (-568)) (-634 (-568)) (-121))) (-15 -1694 ((-1244 (-568)) (-1244 (-568)) (-1244 (-568)) (-568))) (-15 -1694 ((-1244 (-568)) (-634 (-568)) (-1244 (-568)) (-568))) (-15 -2074 ((-568) (-568) (-568))) (-15 -3895 ((-634 (-568)) (-568) (-568) (-568))) (-15 -2805 ((-634 (-568)) (-568) (-568) (-568))) (-15 -1490 ((-634 (-568)) (-568) (-568) (-568))))) (T -1100)) 
-((-1490 (*1 *2 *3 *3 *3) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1100)) (-5 *3 (-568)))) (-2805 (*1 *2 *3 *3 *3) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1100)) (-5 *3 (-568)))) (-3895 (*1 *2 *3 *3 *3) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1100)) (-5 *3 (-568)))) (-2074 (*1 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1100)))) (-1694 (*1 *2 *3 *2 *4) (-12 (-5 *2 (-1244 (-568))) (-5 *3 (-634 (-568))) (-5 *4 (-568)) (-5 *1 (-1100)))) (-1694 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-1244 (-568))) (-5 *3 (-568)) (-5 *1 (-1100)))) (-4103 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-634 (-568))) (-5 *3 (-121)) (-5 *1 (-1100)))) (-3129 (*1 *2 *3 *3 *2) (-12 (-5 *2 (-679 (-568))) (-5 *3 (-634 (-568))) (-5 *1 (-1100)))) (-2903 (*1 *2 *3 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-679 (-568))) (-5 *1 (-1100)))) (-1364 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-634 (-679 (-568)))) (-5 *1 (-1100)))) (-2559 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-634 (-568))) (-5 *3 (-679 (-568))) (-5 *1 (-1100)))) (-3745 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-679 (-568))) (-5 *1 (-1100))))) 
-(-10 -7 (-15 -3745 ((-679 (-568)) (-634 (-568)) (-634 (-568)) (-634 (-568)))) (-15 -2559 ((-634 (-568)) (-634 (-568)) (-634 (-568)) (-679 (-568)))) (-15 -1364 ((-634 (-679 (-568))) (-634 (-568)))) (-15 -2903 ((-679 (-568)) (-634 (-568)) (-634 (-568)))) (-15 -3129 ((-679 (-568)) (-634 (-568)) (-634 (-568)) (-679 (-568)))) (-15 -4103 ((-634 (-568)) (-634 (-568)) (-634 (-568)) (-121))) (-15 -1694 ((-1244 (-568)) (-1244 (-568)) (-1244 (-568)) (-568))) (-15 -1694 ((-1244 (-568)) (-634 (-568)) (-1244 (-568)) (-568))) (-15 -2074 ((-568) (-568) (-568))) (-15 -3895 ((-634 (-568)) (-568) (-568) (-568))) (-15 -2805 ((-634 (-568)) (-568) (-568) (-568))) (-15 -1490 ((-634 (-568)) (-568) (-568) (-568)))) 
-((-1887 (($ $ (-917)) 12)) (** (($ $ (-917)) 10))) 
-(((-1101 |#1|) (-10 -8 (-15 -1887 (|#1| |#1| (-917))) (-15 ** (|#1| |#1| (-917)))) (-1102)) (T -1101)) 
-NIL 
-(-10 -8 (-15 -1887 (|#1| |#1| (-917))) (-15 ** (|#1| |#1| (-917)))) 
-((-2447 (((-121) $ $) 7)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-1887 (($ $ (-917)) 12)) (-1717 (((-121) $ $) 6)) (** (($ $ (-917)) 13)) (* (($ $ $) 14))) 
+((-2553 (((-634 (-568)) (-568) (-568) (-568)) 20)) (-3674 (((-634 (-568)) (-568) (-568) (-568)) 12)) (-2052 (((-634 (-568)) (-568) (-568) (-568)) 16)) (-3097 (((-568) (-568) (-568)) 9)) (-3575 (((-1244 (-568)) (-634 (-568)) (-1244 (-568)) (-568)) 44) (((-1244 (-568)) (-1244 (-568)) (-1244 (-568)) (-568)) 39)) (-3565 (((-634 (-568)) (-634 (-568)) (-634 (-568)) (-121)) 26)) (-2660 (((-679 (-568)) (-634 (-568)) (-634 (-568)) (-679 (-568))) 43)) (-2834 (((-679 (-568)) (-634 (-568)) (-634 (-568))) 31)) (-3781 (((-634 (-679 (-568))) (-634 (-568))) 33)) (-1920 (((-634 (-568)) (-634 (-568)) (-634 (-568)) (-679 (-568))) 46)) (-2583 (((-679 (-568)) (-634 (-568)) (-634 (-568)) (-634 (-568))) 54))) 
+(((-1100) (-10 -7 (-15 -2583 ((-679 (-568)) (-634 (-568)) (-634 (-568)) (-634 (-568)))) (-15 -1920 ((-634 (-568)) (-634 (-568)) (-634 (-568)) (-679 (-568)))) (-15 -3781 ((-634 (-679 (-568))) (-634 (-568)))) (-15 -2834 ((-679 (-568)) (-634 (-568)) (-634 (-568)))) (-15 -2660 ((-679 (-568)) (-634 (-568)) (-634 (-568)) (-679 (-568)))) (-15 -3565 ((-634 (-568)) (-634 (-568)) (-634 (-568)) (-121))) (-15 -3575 ((-1244 (-568)) (-1244 (-568)) (-1244 (-568)) (-568))) (-15 -3575 ((-1244 (-568)) (-634 (-568)) (-1244 (-568)) (-568))) (-15 -3097 ((-568) (-568) (-568))) (-15 -2052 ((-634 (-568)) (-568) (-568) (-568))) (-15 -3674 ((-634 (-568)) (-568) (-568) (-568))) (-15 -2553 ((-634 (-568)) (-568) (-568) (-568))))) (T -1100)) 
+((-2553 (*1 *2 *3 *3 *3) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1100)) (-5 *3 (-568)))) (-3674 (*1 *2 *3 *3 *3) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1100)) (-5 *3 (-568)))) (-2052 (*1 *2 *3 *3 *3) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1100)) (-5 *3 (-568)))) (-3097 (*1 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1100)))) (-3575 (*1 *2 *3 *2 *4) (-12 (-5 *2 (-1244 (-568))) (-5 *3 (-634 (-568))) (-5 *4 (-568)) (-5 *1 (-1100)))) (-3575 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-1244 (-568))) (-5 *3 (-568)) (-5 *1 (-1100)))) (-3565 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-634 (-568))) (-5 *3 (-121)) (-5 *1 (-1100)))) (-2660 (*1 *2 *3 *3 *2) (-12 (-5 *2 (-679 (-568))) (-5 *3 (-634 (-568))) (-5 *1 (-1100)))) (-2834 (*1 *2 *3 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-679 (-568))) (-5 *1 (-1100)))) (-3781 (*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-634 (-679 (-568)))) (-5 *1 (-1100)))) (-1920 (*1 *2 *2 *2 *3) (-12 (-5 *2 (-634 (-568))) (-5 *3 (-679 (-568))) (-5 *1 (-1100)))) (-2583 (*1 *2 *3 *3 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-679 (-568))) (-5 *1 (-1100))))) 
+(-10 -7 (-15 -2583 ((-679 (-568)) (-634 (-568)) (-634 (-568)) (-634 (-568)))) (-15 -1920 ((-634 (-568)) (-634 (-568)) (-634 (-568)) (-679 (-568)))) (-15 -3781 ((-634 (-679 (-568))) (-634 (-568)))) (-15 -2834 ((-679 (-568)) (-634 (-568)) (-634 (-568)))) (-15 -2660 ((-679 (-568)) (-634 (-568)) (-634 (-568)) (-679 (-568)))) (-15 -3565 ((-634 (-568)) (-634 (-568)) (-634 (-568)) (-121))) (-15 -3575 ((-1244 (-568)) (-1244 (-568)) (-1244 (-568)) (-568))) (-15 -3575 ((-1244 (-568)) (-634 (-568)) (-1244 (-568)) (-568))) (-15 -3097 ((-568) (-568) (-568))) (-15 -2052 ((-634 (-568)) (-568) (-568) (-568))) (-15 -3674 ((-634 (-568)) (-568) (-568) (-568))) (-15 -2553 ((-634 (-568)) (-568) (-568) (-568)))) 
+((-1889 (($ $ (-917)) 12)) (** (($ $ (-917)) 10))) 
+(((-1101 |#1|) (-10 -8 (-15 -1889 (|#1| |#1| (-917))) (-15 ** (|#1| |#1| (-917)))) (-1102)) (T -1101)) 
+NIL 
+(-10 -8 (-15 -1889 (|#1| |#1| (-917))) (-15 ** (|#1| |#1| (-917)))) 
+((-2449 (((-121) $ $) 7)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-1889 (($ $ (-917)) 12)) (-1719 (((-121) $ $) 6)) (** (($ $ (-917)) 13)) (* (($ $ $) 14))) 
 (((-1102) (-1275)) (T -1102)) 
-((* (*1 *1 *1 *1) (-4 *1 (-1102))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-1102)) (-5 *2 (-917)))) (-1887 (*1 *1 *1 *2) (-12 (-4 *1 (-1102)) (-5 *2 (-917))))) 
-(-13 (-1090) (-10 -8 (-15 * ($ $ $)) (-15 ** ($ $ (-917))) (-15 -1887 ($ $ (-917))))) 
+((* (*1 *1 *1 *1) (-4 *1 (-1102))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-1102)) (-5 *2 (-917)))) (-1889 (*1 *1 *1 *2) (-12 (-4 *1 (-1102)) (-5 *2 (-917))))) 
+(-13 (-1090) (-10 -8 (-15 * ($ $ $)) (-15 ** ($ $ (-917))) (-15 -1889 ($ $ (-917))))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL (|has| |#3| (-1090)))) (-2537 (((-121) $) NIL (|has| |#3| (-137)))) (-1394 (($ (-917)) NIL (|has| |#3| (-1047)))) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-1462 (($ $ $) NIL (|has| |#3| (-788)))) (-3134 (((-3 $ "failed") $ $) NIL (|has| |#3| (-137)))) (-2510 (((-121) $ (-763)) NIL)) (-3983 (((-763)) NIL (|has| |#3| (-370)))) (-3662 (((-568) $) NIL (|has| |#3| (-840)))) (-2436 ((|#3| $ (-568) |#3|) NIL (|has| $ (-6 -4520)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) NIL (-12 (|has| |#3| (-1037 (-568))) (|has| |#3| (-1090)))) (((-3 (-409 (-568)) "failed") $) NIL (-12 (|has| |#3| (-1037 (-409 (-568)))) (|has| |#3| (-1090)))) (((-3 |#3| "failed") $) NIL (|has| |#3| (-1090)))) (-2854 (((-568) $) NIL (-12 (|has| |#3| (-1037 (-568))) (|has| |#3| (-1090)))) (((-409 (-568)) $) NIL (-12 (|has| |#3| (-1037 (-409 (-568)))) (|has| |#3| (-1090)))) ((|#3| $) NIL (|has| |#3| (-1090)))) (-3164 (((-679 (-568)) (-679 $)) NIL (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047)))) (((-2 (|:| -2928 (-679 |#3|)) (|:| |vec| (-1244 |#3|))) (-679 $) (-1244 $)) NIL (|has| |#3| (-1047))) (((-679 |#3|) (-679 $)) NIL (|has| |#3| (-1047)))) (-2925 (((-3 $ "failed") $) NIL (|has| |#3| (-716)))) (-1731 (($) NIL (|has| |#3| (-370)))) (-3989 ((|#3| $ (-568) |#3|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#3| $ (-568)) 12)) (-2033 (((-121) $) NIL (|has| |#3| (-840)))) (-4360 (((-634 |#3|) $) NIL (|has| $ (-6 -4519)))) (-2735 (((-121) $) NIL (|has| |#3| (-716)))) (-2245 (((-121) $) NIL (|has| |#3| (-840)))) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) NIL (|has| (-568) (-842)))) (-2521 (($ $ $) NIL (-2198 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-1979 (((-634 |#3|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#3| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#3| (-1090))))) (-2223 (((-568) $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (-2198 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-3674 (($ (-1 |#3| |#3|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#3| |#3|) $) NIL)) (-3683 (((-917) $) NIL (|has| |#3| (-370)))) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (|has| |#3| (-1090)))) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4355 (($ (-917)) NIL (|has| |#3| (-370)))) (-4022 (((-1108) $) NIL (|has| |#3| (-1090)))) (-3876 ((|#3| $) NIL (|has| (-568) (-842)))) (-3724 (($ $ |#3|) NIL (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#3|))) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ (-288 |#3|)) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ |#3| |#3|) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ (-634 |#3|) (-634 |#3|)) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#3| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#3| (-1090))))) (-2041 (((-634 |#3|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#3| $ (-568) |#3|) NIL) ((|#3| $ (-568)) NIL)) (-3682 ((|#3| $ $) NIL (|has| |#3| (-1047)))) (-2039 (($ (-1244 |#3|)) NIL)) (-4321 (((-139)) NIL (|has| |#3| (-365)))) (-4189 (($ $) NIL (-12 (|has| |#3| (-225)) (|has| |#3| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#3| (-225)) (|has| |#3| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-1 |#3| |#3|) (-763)) NIL (|has| |#3| (-1047))) (($ $ (-1 |#3| |#3|)) NIL (|has| |#3| (-1047)))) (-4168 (((-763) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4519))) (((-763) |#3| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#3| (-1090))))) (-3863 (($ $) NIL)) (-2745 (((-1244 |#3|) $) NIL) (((-850) $) NIL (|has| |#3| (-1090))) (($ (-568)) NIL (-2198 (-12 (|has| |#3| (-1037 (-568))) (|has| |#3| (-1090))) (|has| |#3| (-1047)))) (($ (-409 (-568))) NIL (-12 (|has| |#3| (-1037 (-409 (-568)))) (|has| |#3| (-1090)))) (($ |#3|) NIL (|has| |#3| (-1090)))) (-4078 (((-763)) NIL (|has| |#3| (-1047)))) (-1319 (((-121) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4519)))) (-2897 (($ $) NIL (|has| |#3| (-840)))) (-1887 (($ $ (-763)) NIL (|has| |#3| (-716))) (($ $ (-917)) NIL (|has| |#3| (-716)))) (-3056 (($) NIL (|has| |#3| (-137)) CONST)) (-1556 (($) NIL (|has| |#3| (-716)) CONST)) (-3190 (($ $) NIL (-12 (|has| |#3| (-225)) (|has| |#3| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#3| (-225)) (|has| |#3| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-1 |#3| |#3|) (-763)) NIL (|has| |#3| (-1047))) (($ $ (-1 |#3| |#3|)) NIL (|has| |#3| (-1047)))) (-1751 (((-121) $ $) NIL (-2198 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-1738 (((-121) $ $) NIL (-2198 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-1717 (((-121) $ $) NIL (|has| |#3| (-1090)))) (-1745 (((-121) $ $) NIL (-2198 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-1732 (((-121) $ $) 17 (-2198 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-1779 (($ $ |#3|) NIL (|has| |#3| (-365)))) (-1773 (($ $ $) NIL (|has| |#3| (-1047))) (($ $) NIL (|has| |#3| (-1047)))) (-1767 (($ $ $) NIL (|has| |#3| (-25)))) (** (($ $ (-763)) NIL (|has| |#3| (-716))) (($ $ (-917)) NIL (|has| |#3| (-716)))) (* (($ (-568) $) NIL (|has| |#3| (-1047))) (($ $ $) NIL (|has| |#3| (-716))) (($ $ |#3|) NIL (|has| |#3| (-1047))) (($ |#3| $) NIL (|has| |#3| (-1047))) (($ (-763) $) NIL (|has| |#3| (-137))) (($ (-917) $) NIL (|has| |#3| (-25)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL (|has| |#3| (-1090)))) (-1819 (((-121) $) NIL (|has| |#3| (-137)))) (-4007 (($ (-917)) NIL (|has| |#3| (-1047)))) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-2409 (($ $ $) NIL (|has| |#3| (-788)))) (-2689 (((-3 $ "failed") $ $) NIL (|has| |#3| (-137)))) (-1667 (((-121) $ (-763)) NIL)) (-3986 (((-763)) NIL (|has| |#3| (-370)))) (-3337 (((-568) $) NIL (|has| |#3| (-840)))) (-2438 ((|#3| $ (-568) |#3|) NIL (|has| $ (-6 -4522)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) NIL (-12 (|has| |#3| (-1037 (-568))) (|has| |#3| (-1090)))) (((-3 (-409 (-568)) "failed") $) NIL (-12 (|has| |#3| (-1037 (-409 (-568)))) (|has| |#3| (-1090)))) (((-3 |#3| "failed") $) NIL (|has| |#3| (-1090)))) (-2857 (((-568) $) NIL (-12 (|has| |#3| (-1037 (-568))) (|has| |#3| (-1090)))) (((-409 (-568)) $) NIL (-12 (|has| |#3| (-1037 (-409 (-568)))) (|has| |#3| (-1090)))) ((|#3| $) NIL (|has| |#3| (-1090)))) (-1668 (((-679 (-568)) (-679 $)) NIL (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (-12 (|has| |#3| (-630 (-568))) (|has| |#3| (-1047)))) (((-2 (|:| -2908 (-679 |#3|)) (|:| |vec| (-1244 |#3|))) (-679 $) (-1244 $)) NIL (|has| |#3| (-1047))) (((-679 |#3|) (-679 $)) NIL (|has| |#3| (-1047)))) (-2902 (((-3 $ "failed") $) NIL (|has| |#3| (-716)))) (-1733 (($) NIL (|has| |#3| (-370)))) (-1292 ((|#3| $ (-568) |#3|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#3| $ (-568)) 12)) (-1436 (((-121) $) NIL (|has| |#3| (-840)))) (-3317 (((-634 |#3|) $) NIL (|has| $ (-6 -4521)))) (-1598 (((-121) $) NIL (|has| |#3| (-716)))) (-2859 (((-121) $) NIL (|has| |#3| (-840)))) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) NIL (|has| (-568) (-842)))) (-1732 (($ $ $) NIL (-2199 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-4406 (((-634 |#3|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#3| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#3| (-1090))))) (-3631 (((-568) $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (-2199 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-2253 (($ (-1 |#3| |#3|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#3| |#3|) $) NIL)) (-2291 (((-917) $) NIL (|has| |#3| (-370)))) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (|has| |#3| (-1090)))) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4357 (($ (-917)) NIL (|has| |#3| (-370)))) (-4025 (((-1108) $) NIL (|has| |#3| (-1090)))) (-3877 ((|#3| $) NIL (|has| (-568) (-842)))) (-2490 (($ $ |#3|) NIL (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#3|))) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ (-288 |#3|)) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ |#3| |#3|) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090)))) (($ $ (-634 |#3|) (-634 |#3|)) NIL (-12 (|has| |#3| (-303 |#3|)) (|has| |#3| (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#3| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#3| (-1090))))) (-1480 (((-634 |#3|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#3| $ (-568) |#3|) NIL) ((|#3| $ (-568)) NIL)) (-2286 ((|#3| $ $) NIL (|has| |#3| (-1047)))) (-2041 (($ (-1244 |#3|)) NIL)) (-3108 (((-139)) NIL (|has| |#3| (-365)))) (-4191 (($ $) NIL (-12 (|has| |#3| (-225)) (|has| |#3| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#3| (-225)) (|has| |#3| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-1 |#3| |#3|) (-763)) NIL (|has| |#3| (-1047))) (($ $ (-1 |#3| |#3|)) NIL (|has| |#3| (-1047)))) (-4170 (((-763) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4521))) (((-763) |#3| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#3| (-1090))))) (-3865 (($ $) NIL)) (-2747 (((-1244 |#3|) $) NIL) (((-850) $) NIL (|has| |#3| (-1090))) (($ (-568)) NIL (-2199 (-12 (|has| |#3| (-1037 (-568))) (|has| |#3| (-1090))) (|has| |#3| (-1047)))) (($ (-409 (-568))) NIL (-12 (|has| |#3| (-1037 (-409 (-568)))) (|has| |#3| (-1090)))) (($ |#3|) NIL (|has| |#3| (-1090)))) (-3425 (((-763)) NIL (|has| |#3| (-1047)))) (-3437 (((-121) (-1 (-121) |#3|) $) NIL (|has| $ (-6 -4521)))) (-2811 (($ $) NIL (|has| |#3| (-840)))) (-1889 (($ $ (-763)) NIL (|has| |#3| (-716))) (($ $ (-917)) NIL (|has| |#3| (-716)))) (-3058 (($) NIL (|has| |#3| (-137)) CONST)) (-1557 (($) NIL (|has| |#3| (-716)) CONST)) (-3192 (($ $) NIL (-12 (|has| |#3| (-225)) (|has| |#3| (-1047)))) (($ $ (-763)) NIL (-12 (|has| |#3| (-225)) (|has| |#3| (-1047)))) (($ $ (-1161)) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#3| (-895 (-1161))) (|has| |#3| (-1047)))) (($ $ (-1 |#3| |#3|) (-763)) NIL (|has| |#3| (-1047))) (($ $ (-1 |#3| |#3|)) NIL (|has| |#3| (-1047)))) (-1753 (((-121) $ $) NIL (-2199 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-1740 (((-121) $ $) NIL (-2199 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-1719 (((-121) $ $) NIL (|has| |#3| (-1090)))) (-1747 (((-121) $ $) NIL (-2199 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-1734 (((-121) $ $) 17 (-2199 (|has| |#3| (-788)) (|has| |#3| (-840))))) (-1781 (($ $ |#3|) NIL (|has| |#3| (-365)))) (-1775 (($ $ $) NIL (|has| |#3| (-1047))) (($ $) NIL (|has| |#3| (-1047)))) (-1769 (($ $ $) NIL (|has| |#3| (-25)))) (** (($ $ (-763)) NIL (|has| |#3| (-716))) (($ $ (-917)) NIL (|has| |#3| (-716)))) (* (($ (-568) $) NIL (|has| |#3| (-1047))) (($ $ $) NIL (|has| |#3| (-716))) (($ $ |#3|) NIL (|has| |#3| (-1047))) (($ |#3| $) NIL (|has| |#3| (-1047))) (($ (-763) $) NIL (|has| |#3| (-137))) (($ (-917) $) NIL (|has| |#3| (-25)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
 (((-1103 |#1| |#2| |#3|) (-230 |#1| |#3|) (-763) (-763) (-788)) (T -1103)) 
 NIL 
 (-230 |#1| |#3|) 
-((-4407 (((-634 (-1216 |#2| |#1|)) (-1216 |#2| |#1|) (-1216 |#2| |#1|)) 36)) (-1584 (((-568) (-1216 |#2| |#1|)) 67 (|has| |#1| (-453)))) (-4480 (((-568) (-1216 |#2| |#1|)) 53)) (-3888 (((-634 (-1216 |#2| |#1|)) (-1216 |#2| |#1|) (-1216 |#2| |#1|)) 44)) (-3178 (((-568) (-1216 |#2| |#1|) (-1216 |#2| |#1|)) 55 (|has| |#1| (-453)))) (-2696 (((-634 |#1|) (-1216 |#2| |#1|) (-1216 |#2| |#1|)) 47)) (-2090 (((-568) (-1216 |#2| |#1|) (-1216 |#2| |#1|)) 52))) 
-(((-1104 |#1| |#2|) (-10 -7 (-15 -4407 ((-634 (-1216 |#2| |#1|)) (-1216 |#2| |#1|) (-1216 |#2| |#1|))) (-15 -3888 ((-634 (-1216 |#2| |#1|)) (-1216 |#2| |#1|) (-1216 |#2| |#1|))) (-15 -2696 ((-634 |#1|) (-1216 |#2| |#1|) (-1216 |#2| |#1|))) (-15 -2090 ((-568) (-1216 |#2| |#1|) (-1216 |#2| |#1|))) (-15 -4480 ((-568) (-1216 |#2| |#1|))) (IF (|has| |#1| (-453)) (PROGN (-15 -3178 ((-568) (-1216 |#2| |#1|) (-1216 |#2| |#1|))) (-15 -1584 ((-568) (-1216 |#2| |#1|)))) |noBranch|)) (-815) (-1161)) (T -1104)) 
-((-1584 (*1 *2 *3) (-12 (-5 *3 (-1216 *5 *4)) (-4 *4 (-453)) (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-568)) (-5 *1 (-1104 *4 *5)))) (-3178 (*1 *2 *3 *3) (-12 (-5 *3 (-1216 *5 *4)) (-4 *4 (-453)) (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-568)) (-5 *1 (-1104 *4 *5)))) (-4480 (*1 *2 *3) (-12 (-5 *3 (-1216 *5 *4)) (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-568)) (-5 *1 (-1104 *4 *5)))) (-2090 (*1 *2 *3 *3) (-12 (-5 *3 (-1216 *5 *4)) (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-568)) (-5 *1 (-1104 *4 *5)))) (-2696 (*1 *2 *3 *3) (-12 (-5 *3 (-1216 *5 *4)) (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-634 *4)) (-5 *1 (-1104 *4 *5)))) (-3888 (*1 *2 *3 *3) (-12 (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-634 (-1216 *5 *4))) (-5 *1 (-1104 *4 *5)) (-5 *3 (-1216 *5 *4)))) (-4407 (*1 *2 *3 *3) (-12 (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-634 (-1216 *5 *4))) (-5 *1 (-1104 *4 *5)) (-5 *3 (-1216 *5 *4))))) 
-(-10 -7 (-15 -4407 ((-634 (-1216 |#2| |#1|)) (-1216 |#2| |#1|) (-1216 |#2| |#1|))) (-15 -3888 ((-634 (-1216 |#2| |#1|)) (-1216 |#2| |#1|) (-1216 |#2| |#1|))) (-15 -2696 ((-634 |#1|) (-1216 |#2| |#1|) (-1216 |#2| |#1|))) (-15 -2090 ((-568) (-1216 |#2| |#1|) (-1216 |#2| |#1|))) (-15 -4480 ((-568) (-1216 |#2| |#1|))) (IF (|has| |#1| (-453)) (PROGN (-15 -3178 ((-568) (-1216 |#2| |#1|) (-1216 |#2| |#1|))) (-15 -1584 ((-568) (-1216 |#2| |#1|)))) |noBranch|)) 
-((-3662 (((-3 (-568) "failed") |#2| (-1161) |#2| (-1143)) 16) (((-3 (-568) "failed") |#2| (-1161) (-835 |#2|)) 14) (((-3 (-568) "failed") |#2|) 51))) 
-(((-1105 |#1| |#2|) (-10 -7 (-15 -3662 ((-3 (-568) "failed") |#2|)) (-15 -3662 ((-3 (-568) "failed") |#2| (-1161) (-835 |#2|))) (-15 -3662 ((-3 (-568) "failed") |#2| (-1161) |#2| (-1143)))) (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)) (-453)) (-13 (-27) (-1181) (-432 |#1|))) (T -1105)) 
-((-3662 (*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-1143)) (-4 *6 (-13 (-558) (-842) (-1037 *2) (-630 *2) (-453))) (-5 *2 (-568)) (-5 *1 (-1105 *6 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *6))))) (-3662 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-835 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-558) (-842) (-1037 *2) (-630 *2) (-453))) (-5 *2 (-568)) (-5 *1 (-1105 *6 *3)))) (-3662 (*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-558) (-842) (-1037 *2) (-630 *2) (-453))) (-5 *2 (-568)) (-5 *1 (-1105 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4)))))) 
-(-10 -7 (-15 -3662 ((-3 (-568) "failed") |#2|)) (-15 -3662 ((-3 (-568) "failed") |#2| (-1161) (-835 |#2|))) (-15 -3662 ((-3 (-568) "failed") |#2| (-1161) |#2| (-1143)))) 
-((-3662 (((-3 (-568) "failed") (-409 (-953 |#1|)) (-1161) (-409 (-953 |#1|)) (-1143)) 34) (((-3 (-568) "failed") (-409 (-953 |#1|)) (-1161) (-835 (-409 (-953 |#1|)))) 29) (((-3 (-568) "failed") (-409 (-953 |#1|))) 12))) 
-(((-1106 |#1|) (-10 -7 (-15 -3662 ((-3 (-568) "failed") (-409 (-953 |#1|)))) (-15 -3662 ((-3 (-568) "failed") (-409 (-953 |#1|)) (-1161) (-835 (-409 (-953 |#1|))))) (-15 -3662 ((-3 (-568) "failed") (-409 (-953 |#1|)) (-1161) (-409 (-953 |#1|)) (-1143)))) (-453)) (T -1106)) 
-((-3662 (*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *3 (-409 (-953 *6))) (-5 *4 (-1161)) (-5 *5 (-1143)) (-4 *6 (-453)) (-5 *2 (-568)) (-5 *1 (-1106 *6)))) (-3662 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-835 (-409 (-953 *6)))) (-5 *3 (-409 (-953 *6))) (-4 *6 (-453)) (-5 *2 (-568)) (-5 *1 (-1106 *6)))) (-3662 (*1 *2 *3) (|partial| -12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-453)) (-5 *2 (-568)) (-5 *1 (-1106 *4))))) 
-(-10 -7 (-15 -3662 ((-3 (-568) "failed") (-409 (-953 |#1|)))) (-15 -3662 ((-3 (-568) "failed") (-409 (-953 |#1|)) (-1161) (-835 (-409 (-953 |#1|))))) (-15 -3662 ((-3 (-568) "failed") (-409 (-953 |#1|)) (-1161) (-409 (-953 |#1|)) (-1143)))) 
-((-4352 (((-310 (-568)) (-53)) 11))) 
-(((-1107) (-10 -7 (-15 -4352 ((-310 (-568)) (-53))))) (T -1107)) 
-((-4352 (*1 *2 *3) (-12 (-5 *3 (-53)) (-5 *2 (-310 (-568))) (-5 *1 (-1107))))) 
-(-10 -7 (-15 -4352 ((-310 (-568)) (-53)))) 
-((-2447 (((-121) $ $) NIL)) (-1611 (($ $) 41)) (-2537 (((-121) $) 65)) (-3091 (($ $ $) 48)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 84)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-1877 (($ $ $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2690 (($ $ $ $) 74)) (-4305 (($ $) NIL)) (-1678 (((-420 $) $) NIL)) (-1497 (((-121) $ $) NIL)) (-3662 (((-568) $) NIL)) (-1870 (($ $ $) 71)) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) NIL)) (-2854 (((-568) $) NIL)) (-2401 (($ $ $) 59)) (-3164 (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 78) (((-679 (-568)) (-679 $)) 28)) (-2925 (((-3 $ "failed") $) NIL)) (-1642 (((-3 (-409 (-568)) "failed") $) NIL)) (-2688 (((-121) $) NIL)) (-2425 (((-409 (-568)) $) NIL)) (-1731 (($) 81) (($ $) 82)) (-2412 (($ $ $) 58)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL)) (-3927 (((-121) $) NIL)) (-1457 (($ $ $ $) NIL)) (-1283 (($ $ $) 79)) (-2033 (((-121) $) NIL)) (-2413 (($ $ $) NIL)) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL)) (-2735 (((-121) $) 66)) (-1825 (((-121) $) 64)) (-3044 (($ $) 42)) (-3038 (((-3 $ "failed") $) NIL)) (-2245 (((-121) $) 75)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3326 (($ $ $ $) 72)) (-2521 (($ $ $) 68) (($) 39)) (-3268 (($ $ $) 67) (($) 38)) (-3651 (($ $) NIL)) (-3678 (($ $) 70)) (-2495 (($ $ $) NIL) (($ (-634 $)) NIL)) (-4487 (((-1143) $) NIL)) (-2110 (($ $ $) NIL)) (-4434 (($) NIL T CONST)) (-3850 (($ $) 50)) (-4022 (((-1108) $) NIL) (($ $) 69)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2721 (($ $ $) 62) (($ (-634 $)) NIL)) (-2427 (($ $) NIL)) (-3848 (((-420 $) $) NIL)) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL)) (-2595 (((-3 $ "failed") $ $) NIL)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-3277 (((-121) $) NIL)) (-2709 (((-763) $) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 61)) (-4189 (($ $ (-763)) NIL) (($ $) NIL)) (-2349 (($ $) 51)) (-3863 (($ $) NIL)) (-4278 (((-568) $) 32) (((-541) $) NIL) (((-887 (-568)) $) NIL) (((-381) $) NIL) (((-215) $) NIL)) (-2745 (((-850) $) 31) (($ (-568)) 80) (($ $) NIL) (($ (-568)) 80)) (-4078 (((-763)) NIL)) (-2791 (((-121) $ $) NIL)) (-2787 (($ $ $) NIL)) (-1461 (($) 37)) (-1826 (((-121) $ $) NIL)) (-4419 (($ $ $ $) 73)) (-2897 (($ $) 63)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-2430 (($ $ $) 44)) (-3056 (($) 35 T CONST)) (-3293 (($ $ $) 47)) (-1556 (($) 36 T CONST)) (-3754 (((-1143) $) 21) (((-1143) $ (-121)) 23) (((-1249) (-817) $) 24) (((-1249) (-817) $ (-121)) 25)) (-3251 (($ $) 45)) (-3190 (($ $ (-763)) NIL) (($ $) NIL)) (-3005 (($ $ $) 46)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 40)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 49)) (-2424 (($ $ $) 43)) (-1773 (($ $) 52) (($ $ $) 54)) (-1767 (($ $ $) 53)) (** (($ $ (-917)) NIL) (($ $ (-763)) 57)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 34) (($ $ $) 55))) 
-(((-1108) (-13 (-550) (-651) (-823) (-10 -8 (-6 -4506) (-6 -4511) (-6 -4507) (-15 -3268 ($)) (-15 -2521 ($)) (-15 -3044 ($ $)) (-15 -1611 ($ $)) (-15 -2424 ($ $ $)) (-15 -2430 ($ $ $)) (-15 -3091 ($ $ $)) (-15 -3251 ($ $)) (-15 -3005 ($ $ $)) (-15 -3293 ($ $ $))))) (T -1108)) 
-((-2430 (*1 *1 *1 *1) (-5 *1 (-1108))) (-2424 (*1 *1 *1 *1) (-5 *1 (-1108))) (-1611 (*1 *1 *1) (-5 *1 (-1108))) (-3268 (*1 *1) (-5 *1 (-1108))) (-2521 (*1 *1) (-5 *1 (-1108))) (-3044 (*1 *1 *1) (-5 *1 (-1108))) (-3091 (*1 *1 *1 *1) (-5 *1 (-1108))) (-3251 (*1 *1 *1) (-5 *1 (-1108))) (-3005 (*1 *1 *1 *1) (-5 *1 (-1108))) (-3293 (*1 *1 *1 *1) (-5 *1 (-1108)))) 
-(-13 (-550) (-651) (-823) (-10 -8 (-6 -4506) (-6 -4511) (-6 -4507) (-15 -3268 ($)) (-15 -2521 ($)) (-15 -3044 ($ $)) (-15 -1611 ($ $)) (-15 -2424 ($ $ $)) (-15 -2430 ($ $ $)) (-15 -3091 ($ $ $)) (-15 -3251 ($ $)) (-15 -3005 ($ $ $)) (-15 -3293 ($ $ $)))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2616 ((|#1| $) 41)) (-2510 (((-121) $ (-763)) 8)) (-2671 (($) 7 T CONST)) (-2918 ((|#1| |#1| $) 43)) (-2899 ((|#1| $) 42)) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) 9)) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35)) (-2166 (((-121) $ (-763)) 10)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-1890 ((|#1| $) 36)) (-4450 (($ |#1| $) 37)) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-1315 ((|#1| $) 38)) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-4154 (((-763) $) 40)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-2367 (($ (-634 |#1|)) 39)) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-1500 (((-634 (-1216 |#2| |#1|)) (-1216 |#2| |#1|) (-1216 |#2| |#1|)) 36)) (-4478 (((-568) (-1216 |#2| |#1|)) 67 (|has| |#1| (-453)))) (-1859 (((-568) (-1216 |#2| |#1|)) 53)) (-2028 (((-634 (-1216 |#2| |#1|)) (-1216 |#2| |#1|) (-1216 |#2| |#1|)) 44)) (-1735 (((-568) (-1216 |#2| |#1|) (-1216 |#2| |#1|)) 55 (|has| |#1| (-453)))) (-1394 (((-634 |#1|) (-1216 |#2| |#1|) (-1216 |#2| |#1|)) 47)) (-3153 (((-568) (-1216 |#2| |#1|) (-1216 |#2| |#1|)) 52))) 
+(((-1104 |#1| |#2|) (-10 -7 (-15 -1500 ((-634 (-1216 |#2| |#1|)) (-1216 |#2| |#1|) (-1216 |#2| |#1|))) (-15 -2028 ((-634 (-1216 |#2| |#1|)) (-1216 |#2| |#1|) (-1216 |#2| |#1|))) (-15 -1394 ((-634 |#1|) (-1216 |#2| |#1|) (-1216 |#2| |#1|))) (-15 -3153 ((-568) (-1216 |#2| |#1|) (-1216 |#2| |#1|))) (-15 -1859 ((-568) (-1216 |#2| |#1|))) (IF (|has| |#1| (-453)) (PROGN (-15 -1735 ((-568) (-1216 |#2| |#1|) (-1216 |#2| |#1|))) (-15 -4478 ((-568) (-1216 |#2| |#1|)))) |noBranch|)) (-815) (-1161)) (T -1104)) 
+((-4478 (*1 *2 *3) (-12 (-5 *3 (-1216 *5 *4)) (-4 *4 (-453)) (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-568)) (-5 *1 (-1104 *4 *5)))) (-1735 (*1 *2 *3 *3) (-12 (-5 *3 (-1216 *5 *4)) (-4 *4 (-453)) (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-568)) (-5 *1 (-1104 *4 *5)))) (-1859 (*1 *2 *3) (-12 (-5 *3 (-1216 *5 *4)) (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-568)) (-5 *1 (-1104 *4 *5)))) (-3153 (*1 *2 *3 *3) (-12 (-5 *3 (-1216 *5 *4)) (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-568)) (-5 *1 (-1104 *4 *5)))) (-1394 (*1 *2 *3 *3) (-12 (-5 *3 (-1216 *5 *4)) (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-634 *4)) (-5 *1 (-1104 *4 *5)))) (-2028 (*1 *2 *3 *3) (-12 (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-634 (-1216 *5 *4))) (-5 *1 (-1104 *4 *5)) (-5 *3 (-1216 *5 *4)))) (-1500 (*1 *2 *3 *3) (-12 (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-634 (-1216 *5 *4))) (-5 *1 (-1104 *4 *5)) (-5 *3 (-1216 *5 *4))))) 
+(-10 -7 (-15 -1500 ((-634 (-1216 |#2| |#1|)) (-1216 |#2| |#1|) (-1216 |#2| |#1|))) (-15 -2028 ((-634 (-1216 |#2| |#1|)) (-1216 |#2| |#1|) (-1216 |#2| |#1|))) (-15 -1394 ((-634 |#1|) (-1216 |#2| |#1|) (-1216 |#2| |#1|))) (-15 -3153 ((-568) (-1216 |#2| |#1|) (-1216 |#2| |#1|))) (-15 -1859 ((-568) (-1216 |#2| |#1|))) (IF (|has| |#1| (-453)) (PROGN (-15 -1735 ((-568) (-1216 |#2| |#1|) (-1216 |#2| |#1|))) (-15 -4478 ((-568) (-1216 |#2| |#1|)))) |noBranch|)) 
+((-3337 (((-3 (-568) "failed") |#2| (-1161) |#2| (-1143)) 16) (((-3 (-568) "failed") |#2| (-1161) (-835 |#2|)) 14) (((-3 (-568) "failed") |#2|) 51))) 
+(((-1105 |#1| |#2|) (-10 -7 (-15 -3337 ((-3 (-568) "failed") |#2|)) (-15 -3337 ((-3 (-568) "failed") |#2| (-1161) (-835 |#2|))) (-15 -3337 ((-3 (-568) "failed") |#2| (-1161) |#2| (-1143)))) (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)) (-453)) (-13 (-27) (-1181) (-432 |#1|))) (T -1105)) 
+((-3337 (*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-1143)) (-4 *6 (-13 (-558) (-842) (-1037 *2) (-630 *2) (-453))) (-5 *2 (-568)) (-5 *1 (-1105 *6 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *6))))) (-3337 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-835 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-558) (-842) (-1037 *2) (-630 *2) (-453))) (-5 *2 (-568)) (-5 *1 (-1105 *6 *3)))) (-3337 (*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-558) (-842) (-1037 *2) (-630 *2) (-453))) (-5 *2 (-568)) (-5 *1 (-1105 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4)))))) 
+(-10 -7 (-15 -3337 ((-3 (-568) "failed") |#2|)) (-15 -3337 ((-3 (-568) "failed") |#2| (-1161) (-835 |#2|))) (-15 -3337 ((-3 (-568) "failed") |#2| (-1161) |#2| (-1143)))) 
+((-3337 (((-3 (-568) "failed") (-409 (-953 |#1|)) (-1161) (-409 (-953 |#1|)) (-1143)) 34) (((-3 (-568) "failed") (-409 (-953 |#1|)) (-1161) (-835 (-409 (-953 |#1|)))) 29) (((-3 (-568) "failed") (-409 (-953 |#1|))) 12))) 
+(((-1106 |#1|) (-10 -7 (-15 -3337 ((-3 (-568) "failed") (-409 (-953 |#1|)))) (-15 -3337 ((-3 (-568) "failed") (-409 (-953 |#1|)) (-1161) (-835 (-409 (-953 |#1|))))) (-15 -3337 ((-3 (-568) "failed") (-409 (-953 |#1|)) (-1161) (-409 (-953 |#1|)) (-1143)))) (-453)) (T -1106)) 
+((-3337 (*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *3 (-409 (-953 *6))) (-5 *4 (-1161)) (-5 *5 (-1143)) (-4 *6 (-453)) (-5 *2 (-568)) (-5 *1 (-1106 *6)))) (-3337 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-835 (-409 (-953 *6)))) (-5 *3 (-409 (-953 *6))) (-4 *6 (-453)) (-5 *2 (-568)) (-5 *1 (-1106 *6)))) (-3337 (*1 *2 *3) (|partial| -12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-453)) (-5 *2 (-568)) (-5 *1 (-1106 *4))))) 
+(-10 -7 (-15 -3337 ((-3 (-568) "failed") (-409 (-953 |#1|)))) (-15 -3337 ((-3 (-568) "failed") (-409 (-953 |#1|)) (-1161) (-835 (-409 (-953 |#1|))))) (-15 -3337 ((-3 (-568) "failed") (-409 (-953 |#1|)) (-1161) (-409 (-953 |#1|)) (-1143)))) 
+((-3267 (((-310 (-568)) (-53)) 11))) 
+(((-1107) (-10 -7 (-15 -3267 ((-310 (-568)) (-53))))) (T -1107)) 
+((-3267 (*1 *2 *3) (-12 (-5 *3 (-53)) (-5 *2 (-310 (-568))) (-5 *1 (-1107))))) 
+(-10 -7 (-15 -3267 ((-310 (-568)) (-53)))) 
+((-2449 (((-121) $ $) NIL)) (-1613 (($ $) 41)) (-1819 (((-121) $) 65)) (-3093 (($ $ $) 48)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 84)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2519 (($ $ $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-1353 (($ $ $ $) 74)) (-3045 (($ $) NIL)) (-3498 (((-420 $) $) NIL)) (-2589 (((-121) $ $) NIL)) (-3337 (((-568) $) NIL)) (-1872 (($ $ $) 71)) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) NIL)) (-2857 (((-568) $) NIL)) (-2403 (($ $ $) 59)) (-1668 (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 78) (((-679 (-568)) (-679 $)) 28)) (-2902 (((-3 $ "failed") $) NIL)) (-3254 (((-3 (-409 (-568)) "failed") $) NIL)) (-1338 (((-121) $) NIL)) (-2394 (((-409 (-568)) $) NIL)) (-1733 (($) 81) (($ $) 82)) (-2414 (($ $ $) 58)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL)) (-2197 (((-121) $) NIL)) (-2382 (($ $ $ $) NIL)) (-3155 (($ $ $) 79)) (-1436 (((-121) $) NIL)) (-2341 (($ $ $) NIL)) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL)) (-1598 (((-121) $) 66)) (-2268 (((-121) $) 64)) (-3046 (($ $) 42)) (-2214 (((-3 $ "failed") $) NIL)) (-2859 (((-121) $) 75)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-4374 (($ $ $ $) 72)) (-1732 (($ $ $) 68) (($) 39)) (-2047 (($ $ $) 67) (($) 38)) (-3248 (($ $) NIL)) (-3680 (($ $) 70)) (-2498 (($ $ $) NIL) (($ (-634 $)) NIL)) (-1893 (((-1143) $) NIL)) (-3264 (($ $ $) NIL)) (-4436 (($) NIL T CONST)) (-1890 (($ $) 50)) (-4025 (((-1108) $) NIL) (($ $) 69)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL)) (-2723 (($ $ $) 62) (($ (-634 $)) NIL)) (-2406 (($ $) NIL)) (-3850 (((-420 $) $) NIL)) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL)) (-2597 (((-3 $ "failed") $ $) NIL)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL)) (-2080 (((-121) $) NIL)) (-1466 (((-763) $) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 61)) (-4191 (($ $ (-763)) NIL) (($ $) NIL)) (-3953 (($ $) 51)) (-3865 (($ $) NIL)) (-4280 (((-568) $) 32) (((-541) $) NIL) (((-887 (-568)) $) NIL) (((-381) $) NIL) (((-215) $) NIL)) (-2747 (((-850) $) 31) (($ (-568)) 80) (($ $) NIL) (($ (-568)) 80)) (-3425 (((-763)) NIL)) (-3600 (((-121) $ $) NIL)) (-3584 (($ $ $) NIL)) (-2404 (($) 37)) (-2273 (((-121) $ $) NIL)) (-1564 (($ $ $ $) 73)) (-2811 (($ $) 63)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-2432 (($ $ $) 44)) (-3058 (($) 35 T CONST)) (-3295 (($ $ $) 47)) (-1557 (($) 36 T CONST)) (-2628 (((-1143) $) 21) (((-1143) $ (-121)) 23) (((-1249) (-817) $) 24) (((-1249) (-817) $ (-121)) 25)) (-3253 (($ $) 45)) (-3192 (($ $ (-763)) NIL) (($ $) NIL)) (-3007 (($ $ $) 46)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 40)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 49)) (-2426 (($ $ $) 43)) (-1775 (($ $) 52) (($ $ $) 54)) (-1769 (($ $ $) 53)) (** (($ $ (-917)) NIL) (($ $ (-763)) 57)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 34) (($ $ $) 55))) 
+(((-1108) (-13 (-550) (-651) (-823) (-10 -8 (-6 -4508) (-6 -4513) (-6 -4509) (-15 -2047 ($)) (-15 -1732 ($)) (-15 -3046 ($ $)) (-15 -1613 ($ $)) (-15 -2426 ($ $ $)) (-15 -2432 ($ $ $)) (-15 -3093 ($ $ $)) (-15 -3253 ($ $)) (-15 -3007 ($ $ $)) (-15 -3295 ($ $ $))))) (T -1108)) 
+((-2432 (*1 *1 *1 *1) (-5 *1 (-1108))) (-2426 (*1 *1 *1 *1) (-5 *1 (-1108))) (-1613 (*1 *1 *1) (-5 *1 (-1108))) (-2047 (*1 *1) (-5 *1 (-1108))) (-1732 (*1 *1) (-5 *1 (-1108))) (-3046 (*1 *1 *1) (-5 *1 (-1108))) (-3093 (*1 *1 *1 *1) (-5 *1 (-1108))) (-3253 (*1 *1 *1) (-5 *1 (-1108))) (-3007 (*1 *1 *1 *1) (-5 *1 (-1108))) (-3295 (*1 *1 *1 *1) (-5 *1 (-1108)))) 
+(-13 (-550) (-651) (-823) (-10 -8 (-6 -4508) (-6 -4513) (-6 -4509) (-15 -2047 ($)) (-15 -1732 ($)) (-15 -3046 ($ $)) (-15 -1613 ($ $)) (-15 -2426 ($ $ $)) (-15 -2432 ($ $ $)) (-15 -3093 ($ $ $)) (-15 -3253 ($ $)) (-15 -3007 ($ $ $)) (-15 -3295 ($ $ $)))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2618 ((|#1| $) 41)) (-1667 (((-121) $ (-763)) 8)) (-4490 (($) 7 T CONST)) (-2885 ((|#1| |#1| $) 43)) (-2819 ((|#1| $) 42)) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) 9)) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35)) (-3796 (((-121) $ (-763)) 10)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-2580 ((|#1| $) 36)) (-1708 (($ |#1| $) 37)) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3403 ((|#1| $) 38)) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-4156 (((-763) $) 40)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-4074 (($ (-634 |#1|)) 39)) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-1109 |#1|) (-1275) (-1195)) (T -1109)) 
-((-2918 (*1 *2 *2 *1) (-12 (-4 *1 (-1109 *2)) (-4 *2 (-1195)))) (-2899 (*1 *2 *1) (-12 (-4 *1 (-1109 *2)) (-4 *2 (-1195)))) (-2616 (*1 *2 *1) (-12 (-4 *1 (-1109 *2)) (-4 *2 (-1195)))) (-4154 (*1 *2 *1) (-12 (-4 *1 (-1109 *3)) (-4 *3 (-1195)) (-5 *2 (-763))))) 
-(-13 (-111 |t#1|) (-10 -8 (-6 -4519) (-15 -2918 (|t#1| |t#1| $)) (-15 -2899 (|t#1| $)) (-15 -2616 (|t#1| $)) (-15 -4154 ((-763) $)))) 
+((-2885 (*1 *2 *2 *1) (-12 (-4 *1 (-1109 *2)) (-4 *2 (-1195)))) (-2819 (*1 *2 *1) (-12 (-4 *1 (-1109 *2)) (-4 *2 (-1195)))) (-2618 (*1 *2 *1) (-12 (-4 *1 (-1109 *2)) (-4 *2 (-1195)))) (-4156 (*1 *2 *1) (-12 (-4 *1 (-1109 *3)) (-4 *3 (-1195)) (-5 *2 (-763))))) 
+(-13 (-111 |t#1|) (-10 -8 (-6 -4521) (-15 -2885 (|t#1| |t#1| $)) (-15 -2819 (|t#1| $)) (-15 -2618 (|t#1| $)) (-15 -4156 ((-763) $)))) 
 (((-39) . T) ((-111 |#1|) . T) ((-105) |has| |#1| (-1090)) ((-608 (-850)) |has| |#1| (-1090)) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-1090) |has| |#1| (-1090)) ((-1195) . T)) 
-((-1932 ((|#3| $) 76)) (-3666 (((-3 (-568) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 |#3| "failed") $) 40)) (-2854 (((-568) $) NIL) (((-409 (-568)) $) NIL) ((|#3| $) 37)) (-3164 (((-679 (-568)) (-679 $)) NIL) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-2 (|:| -2928 (-679 |#3|)) (|:| |vec| (-1244 |#3|))) (-679 $) (-1244 $)) 73) (((-679 |#3|) (-679 $)) 65)) (-4189 (($ $ (-1 |#3| |#3|)) 19) (($ $ (-1 |#3| |#3|) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) NIL) (($ $ (-763)) NIL) (($ $) NIL)) (-3241 ((|#3| $) 78)) (-3815 ((|#4| $) 32)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ (-409 (-568))) NIL) (($ |#3|) 16)) (** (($ $ (-917)) NIL) (($ $ (-763)) 15) (($ $ (-568)) 82))) 
-(((-1110 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 ** (|#1| |#1| (-568))) (-15 -3241 (|#3| |#1|)) (-15 -1932 (|#3| |#1|)) (-15 -3815 (|#4| |#1|)) (-15 -3164 ((-679 |#3|) (-679 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 |#3|)) (|:| |vec| (-1244 |#3|))) (-679 |#1|) (-1244 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -3164 ((-679 (-568)) (-679 |#1|))) (-15 -2854 (|#3| |#1|)) (-15 -3666 ((-3 |#3| "failed") |#1|)) (-15 -2745 (|#1| |#3|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2854 ((-568) |#1|)) (-15 -4189 (|#1| |#1|)) (-15 -4189 (|#1| |#1| (-763))) (-15 -4189 (|#1| |#1| (-1161))) (-15 -4189 (|#1| |#1| (-634 (-1161)))) (-15 -4189 (|#1| |#1| (-1161) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -4189 (|#1| |#1| (-1 |#3| |#3|) (-763))) (-15 -4189 (|#1| |#1| (-1 |#3| |#3|))) (-15 -2745 (|#1| (-568))) (-15 ** (|#1| |#1| (-763))) (-15 ** (|#1| |#1| (-917))) (-15 -2745 ((-850) |#1|))) (-1111 |#2| |#3| |#4| |#5|) (-763) (-1047) (-230 |#2| |#3|) (-230 |#2| |#3|)) (T -1110)) 
+((-1934 ((|#3| $) 76)) (-3668 (((-3 (-568) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 |#3| "failed") $) 40)) (-2857 (((-568) $) NIL) (((-409 (-568)) $) NIL) ((|#3| $) 37)) (-1668 (((-679 (-568)) (-679 $)) NIL) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL) (((-2 (|:| -2908 (-679 |#3|)) (|:| |vec| (-1244 |#3|))) (-679 $) (-1244 $)) 73) (((-679 |#3|) (-679 $)) 65)) (-4191 (($ $ (-1 |#3| |#3|)) 19) (($ $ (-1 |#3| |#3|) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161)) NIL) (($ $ (-763)) NIL) (($ $) NIL)) (-1966 ((|#3| $) 78)) (-1760 ((|#4| $) 32)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ (-409 (-568))) NIL) (($ |#3|) 16)) (** (($ $ (-917)) NIL) (($ $ (-763)) 15) (($ $ (-568)) 82))) 
+(((-1110 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 ** (|#1| |#1| (-568))) (-15 -1966 (|#3| |#1|)) (-15 -1934 (|#3| |#1|)) (-15 -1760 (|#4| |#1|)) (-15 -1668 ((-679 |#3|) (-679 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 |#3|)) (|:| |vec| (-1244 |#3|))) (-679 |#1|) (-1244 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -1668 ((-679 (-568)) (-679 |#1|))) (-15 -2857 (|#3| |#1|)) (-15 -3668 ((-3 |#3| "failed") |#1|)) (-15 -2747 (|#1| |#3|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2857 ((-568) |#1|)) (-15 -4191 (|#1| |#1|)) (-15 -4191 (|#1| |#1| (-763))) (-15 -4191 (|#1| |#1| (-1161))) (-15 -4191 (|#1| |#1| (-634 (-1161)))) (-15 -4191 (|#1| |#1| (-1161) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -4191 (|#1| |#1| (-1 |#3| |#3|) (-763))) (-15 -4191 (|#1| |#1| (-1 |#3| |#3|))) (-15 -2747 (|#1| (-568))) (-15 ** (|#1| |#1| (-763))) (-15 ** (|#1| |#1| (-917))) (-15 -2747 ((-850) |#1|))) (-1111 |#2| |#3| |#4| |#5|) (-763) (-1047) (-230 |#2| |#3|) (-230 |#2| |#3|)) (T -1110)) 
 NIL 
-(-10 -8 (-15 ** (|#1| |#1| (-568))) (-15 -3241 (|#3| |#1|)) (-15 -1932 (|#3| |#1|)) (-15 -3815 (|#4| |#1|)) (-15 -3164 ((-679 |#3|) (-679 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 |#3|)) (|:| |vec| (-1244 |#3|))) (-679 |#1|) (-1244 |#1|))) (-15 -3164 ((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -3164 ((-679 (-568)) (-679 |#1|))) (-15 -2854 (|#3| |#1|)) (-15 -3666 ((-3 |#3| "failed") |#1|)) (-15 -2745 (|#1| |#3|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2854 ((-568) |#1|)) (-15 -4189 (|#1| |#1|)) (-15 -4189 (|#1| |#1| (-763))) (-15 -4189 (|#1| |#1| (-1161))) (-15 -4189 (|#1| |#1| (-634 (-1161)))) (-15 -4189 (|#1| |#1| (-1161) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -4189 (|#1| |#1| (-1 |#3| |#3|) (-763))) (-15 -4189 (|#1| |#1| (-1 |#3| |#3|))) (-15 -2745 (|#1| (-568))) (-15 ** (|#1| |#1| (-763))) (-15 ** (|#1| |#1| (-917))) (-15 -2745 ((-850) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-1932 ((|#2| $) 69)) (-1335 (((-121) $) 109)) (-3134 (((-3 $ "failed") $ $) 18)) (-2230 (((-121) $) 107)) (-2510 (((-121) $ (-763)) 99)) (-3422 (($ |#2|) 72)) (-2671 (($) 16 T CONST)) (-4167 (($ $) 126 (|has| |#2| (-301)))) (-1818 ((|#3| $ (-568)) 121)) (-3666 (((-3 (-568) "failed") $) 83 (|has| |#2| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) 81 (|has| |#2| (-1037 (-409 (-568))))) (((-3 |#2| "failed") $) 78)) (-2854 (((-568) $) 84 (|has| |#2| (-1037 (-568)))) (((-409 (-568)) $) 82 (|has| |#2| (-1037 (-409 (-568))))) ((|#2| $) 77)) (-3164 (((-679 (-568)) (-679 $)) 76 (|has| |#2| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 75 (|has| |#2| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) 74) (((-679 |#2|) (-679 $)) 73)) (-2925 (((-3 $ "failed") $) 33)) (-3700 (((-763) $) 127 (|has| |#2| (-558)))) (-2602 ((|#2| $ (-568) (-568)) 119)) (-4360 (((-634 |#2|) $) 92 (|has| $ (-6 -4519)))) (-2735 (((-121) $) 30)) (-2121 (((-763) $) 128 (|has| |#2| (-558)))) (-4272 (((-634 |#4|) $) 129 (|has| |#2| (-558)))) (-3043 (((-763) $) 115)) (-2555 (((-763) $) 116)) (-1737 (((-121) $ (-763)) 100)) (-3082 ((|#2| $) 64 (|has| |#2| (-6 (-4521 "*"))))) (-2087 (((-568) $) 111)) (-3364 (((-568) $) 113)) (-1979 (((-634 |#2|) $) 91 (|has| $ (-6 -4519)))) (-3109 (((-121) |#2| $) 89 (-12 (|has| |#2| (-1090)) (|has| $ (-6 -4519))))) (-1663 (((-568) $) 112)) (-2893 (((-568) $) 114)) (-2269 (($ (-634 (-634 |#2|))) 106)) (-3674 (($ (-1 |#2| |#2|) $) 96 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#2| |#2| |#2|) $ $) 123) (($ (-1 |#2| |#2|) $) 97)) (-3208 (((-634 (-634 |#2|)) $) 117)) (-2166 (((-121) $ (-763)) 101)) (-4487 (((-1143) $) 9)) (-3140 (((-3 $ "failed") $) 63 (|has| |#2| (-365)))) (-4022 (((-1108) $) 10)) (-2595 (((-3 $ "failed") $ |#2|) 124 (|has| |#2| (-558)))) (-1387 (((-121) (-1 (-121) |#2|) $) 94 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#2|))) 88 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) 87 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) 86 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) 85 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-3171 (((-121) $ $) 105)) (-3084 (((-121) $) 102)) (-3248 (($) 103)) (-2779 ((|#2| $ (-568) (-568) |#2|) 120) ((|#2| $ (-568) (-568)) 118)) (-4189 (($ $ (-1 |#2| |#2|)) 51) (($ $ (-1 |#2| |#2|) (-763)) 50) (($ $ (-634 (-1161)) (-634 (-763))) 43 (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) 42 (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) 41 (|has| |#2| (-895 (-1161)))) (($ $ (-1161)) 40 (|has| |#2| (-895 (-1161)))) (($ $ (-763)) 38 (|has| |#2| (-225))) (($ $) 36 (|has| |#2| (-225)))) (-3241 ((|#2| $) 68)) (-2282 (($ (-634 |#2|)) 71)) (-1960 (((-121) $) 108)) (-3815 ((|#3| $) 70)) (-2465 ((|#2| $) 65 (|has| |#2| (-6 (-4521 "*"))))) (-4168 (((-763) (-1 (-121) |#2|) $) 93 (|has| $ (-6 -4519))) (((-763) |#2| $) 90 (-12 (|has| |#2| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 104)) (-3731 ((|#4| $ (-568)) 122)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ (-409 (-568))) 80 (|has| |#2| (-1037 (-409 (-568))))) (($ |#2|) 79)) (-4078 (((-763)) 28)) (-1319 (((-121) (-1 (-121) |#2|) $) 95 (|has| $ (-6 -4519)))) (-1910 (((-121) $) 110)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $ (-1 |#2| |#2|)) 49) (($ $ (-1 |#2| |#2|) (-763)) 48) (($ $ (-634 (-1161)) (-634 (-763))) 47 (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) 46 (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) 45 (|has| |#2| (-895 (-1161)))) (($ $ (-1161)) 44 (|has| |#2| (-895 (-1161)))) (($ $ (-763)) 39 (|has| |#2| (-225))) (($ $) 37 (|has| |#2| (-225)))) (-1717 (((-121) $ $) 6)) (-1779 (($ $ |#2|) 125 (|has| |#2| (-365)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 62 (|has| |#2| (-365)))) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#2|) 131) (($ |#2| $) 130) ((|#4| $ |#4|) 67) ((|#3| |#3| $) 66)) (-1697 (((-763) $) 98 (|has| $ (-6 -4519))))) 
+(-10 -8 (-15 ** (|#1| |#1| (-568))) (-15 -1966 (|#3| |#1|)) (-15 -1934 (|#3| |#1|)) (-15 -1760 (|#4| |#1|)) (-15 -1668 ((-679 |#3|) (-679 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 |#3|)) (|:| |vec| (-1244 |#3|))) (-679 |#1|) (-1244 |#1|))) (-15 -1668 ((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 |#1|) (-1244 |#1|))) (-15 -1668 ((-679 (-568)) (-679 |#1|))) (-15 -2857 (|#3| |#1|)) (-15 -3668 ((-3 |#3| "failed") |#1|)) (-15 -2747 (|#1| |#3|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2857 ((-568) |#1|)) (-15 -4191 (|#1| |#1|)) (-15 -4191 (|#1| |#1| (-763))) (-15 -4191 (|#1| |#1| (-1161))) (-15 -4191 (|#1| |#1| (-634 (-1161)))) (-15 -4191 (|#1| |#1| (-1161) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -4191 (|#1| |#1| (-1 |#3| |#3|) (-763))) (-15 -4191 (|#1| |#1| (-1 |#3| |#3|))) (-15 -2747 (|#1| (-568))) (-15 ** (|#1| |#1| (-763))) (-15 ** (|#1| |#1| (-917))) (-15 -2747 ((-850) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-1934 ((|#2| $) 69)) (-3560 (((-121) $) 109)) (-2689 (((-3 $ "failed") $ $) 18)) (-3691 (((-121) $) 107)) (-1667 (((-121) $ (-763)) 99)) (-1637 (($ |#2|) 72)) (-4490 (($) 16 T CONST)) (-3912 (($ $) 126 (|has| |#2| (-301)))) (-2228 ((|#3| $ (-568)) 121)) (-3668 (((-3 (-568) "failed") $) 83 (|has| |#2| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) 81 (|has| |#2| (-1037 (-409 (-568))))) (((-3 |#2| "failed") $) 78)) (-2857 (((-568) $) 84 (|has| |#2| (-1037 (-568)))) (((-409 (-568)) $) 82 (|has| |#2| (-1037 (-409 (-568))))) ((|#2| $) 77)) (-1668 (((-679 (-568)) (-679 $)) 76 (|has| |#2| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 75 (|has| |#2| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) 74) (((-679 |#2|) (-679 $)) 73)) (-2902 (((-3 $ "failed") $) 33)) (-2371 (((-763) $) 127 (|has| |#2| (-558)))) (-2069 ((|#2| $ (-568) (-568)) 119)) (-3317 (((-634 |#2|) $) 92 (|has| $ (-6 -4521)))) (-1598 (((-121) $) 30)) (-3344 (((-763) $) 128 (|has| |#2| (-558)))) (-2934 (((-634 |#4|) $) 129 (|has| |#2| (-558)))) (-2241 (((-763) $) 115)) (-1901 (((-763) $) 116)) (-3791 (((-121) $ (-763)) 100)) (-2424 ((|#2| $) 64 (|has| |#2| (-6 (-4523 "*"))))) (-3139 (((-568) $) 111)) (-1343 (((-568) $) 113)) (-4406 (((-634 |#2|) $) 91 (|has| $ (-6 -4521)))) (-2551 (((-121) |#2| $) 89 (-12 (|has| |#2| (-1090)) (|has| $ (-6 -4521))))) (-3405 (((-568) $) 112)) (-2801 (((-568) $) 114)) (-2271 (($ (-634 (-634 |#2|))) 106)) (-2253 (($ (-1 |#2| |#2|) $) 96 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#2| |#2| |#2|) $ $) 123) (($ (-1 |#2| |#2|) $) 97)) (-1843 (((-634 (-634 |#2|)) $) 117)) (-3796 (((-121) $ (-763)) 101)) (-1893 (((-1143) $) 9)) (-2715 (((-3 $ "failed") $) 63 (|has| |#2| (-365)))) (-4025 (((-1108) $) 10)) (-2597 (((-3 $ "failed") $ |#2|) 124 (|has| |#2| (-558)))) (-3951 (((-121) (-1 (-121) |#2|) $) 94 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#2|))) 88 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) 87 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) 86 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) 85 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-1702 (((-121) $ $) 105)) (-2436 (((-121) $) 102)) (-1990 (($) 103)) (-2781 ((|#2| $ (-568) (-568) |#2|) 120) ((|#2| $ (-568) (-568)) 118)) (-4191 (($ $ (-1 |#2| |#2|)) 51) (($ $ (-1 |#2| |#2|) (-763)) 50) (($ $ (-634 (-1161)) (-634 (-763))) 43 (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) 42 (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) 41 (|has| |#2| (-895 (-1161)))) (($ $ (-1161)) 40 (|has| |#2| (-895 (-1161)))) (($ $ (-763)) 38 (|has| |#2| (-225))) (($ $) 36 (|has| |#2| (-225)))) (-1966 ((|#2| $) 68)) (-3499 (($ (-634 |#2|)) 71)) (-4322 (((-121) $) 108)) (-1760 ((|#3| $) 70)) (-2591 ((|#2| $) 65 (|has| |#2| (-6 (-4523 "*"))))) (-4170 (((-763) (-1 (-121) |#2|) $) 93 (|has| $ (-6 -4521))) (((-763) |#2| $) 90 (-12 (|has| |#2| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 104)) (-2522 ((|#4| $ (-568)) 122)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ (-409 (-568))) 80 (|has| |#2| (-1037 (-409 (-568))))) (($ |#2|) 79)) (-3425 (((-763)) 28)) (-3437 (((-121) (-1 (-121) |#2|) $) 95 (|has| $ (-6 -4521)))) (-2675 (((-121) $) 110)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $ (-1 |#2| |#2|)) 49) (($ $ (-1 |#2| |#2|) (-763)) 48) (($ $ (-634 (-1161)) (-634 (-763))) 47 (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) 46 (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) 45 (|has| |#2| (-895 (-1161)))) (($ $ (-1161)) 44 (|has| |#2| (-895 (-1161)))) (($ $ (-763)) 39 (|has| |#2| (-225))) (($ $) 37 (|has| |#2| (-225)))) (-1719 (((-121) $ $) 6)) (-1781 (($ $ |#2|) 125 (|has| |#2| (-365)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 62 (|has| |#2| (-365)))) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#2|) 131) (($ |#2| $) 130) ((|#4| $ |#4|) 67) ((|#3| |#3| $) 66)) (-1699 (((-763) $) 98 (|has| $ (-6 -4521))))) 
 (((-1111 |#1| |#2| |#3| |#4|) (-1275) (-763) (-1047) (-230 |t#1| |t#2|) (-230 |t#1| |t#2|)) (T -1111)) 
-((-3422 (*1 *1 *2) (-12 (-4 *2 (-1047)) (-4 *1 (-1111 *3 *2 *4 *5)) (-4 *4 (-230 *3 *2)) (-4 *5 (-230 *3 *2)))) (-2282 (*1 *1 *2) (-12 (-5 *2 (-634 *4)) (-4 *4 (-1047)) (-4 *1 (-1111 *3 *4 *5 *6)) (-4 *5 (-230 *3 *4)) (-4 *6 (-230 *3 *4)))) (-3815 (*1 *2 *1) (-12 (-4 *1 (-1111 *3 *4 *2 *5)) (-4 *4 (-1047)) (-4 *5 (-230 *3 *4)) (-4 *2 (-230 *3 *4)))) (-1932 (*1 *2 *1) (-12 (-4 *1 (-1111 *3 *2 *4 *5)) (-4 *4 (-230 *3 *2)) (-4 *5 (-230 *3 *2)) (-4 *2 (-1047)))) (-3241 (*1 *2 *1) (-12 (-4 *1 (-1111 *3 *2 *4 *5)) (-4 *4 (-230 *3 *2)) (-4 *5 (-230 *3 *2)) (-4 *2 (-1047)))) (* (*1 *2 *1 *2) (-12 (-4 *1 (-1111 *3 *4 *5 *2)) (-4 *4 (-1047)) (-4 *5 (-230 *3 *4)) (-4 *2 (-230 *3 *4)))) (* (*1 *2 *2 *1) (-12 (-4 *1 (-1111 *3 *4 *2 *5)) (-4 *4 (-1047)) (-4 *2 (-230 *3 *4)) (-4 *5 (-230 *3 *4)))) (-2465 (*1 *2 *1) (-12 (-4 *1 (-1111 *3 *2 *4 *5)) (-4 *4 (-230 *3 *2)) (-4 *5 (-230 *3 *2)) (|has| *2 (-6 (-4521 "*"))) (-4 *2 (-1047)))) (-3082 (*1 *2 *1) (-12 (-4 *1 (-1111 *3 *2 *4 *5)) (-4 *4 (-230 *3 *2)) (-4 *5 (-230 *3 *2)) (|has| *2 (-6 (-4521 "*"))) (-4 *2 (-1047)))) (-3140 (*1 *1 *1) (|partial| -12 (-4 *1 (-1111 *2 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-230 *2 *3)) (-4 *5 (-230 *2 *3)) (-4 *3 (-365)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-1111 *3 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-230 *3 *4)) (-4 *6 (-230 *3 *4)) (-4 *4 (-365))))) 
-(-13 (-223 |t#2|) (-120 |t#2| |t#2|) (-1050 |t#1| |t#1| |t#2| |t#3| |t#4|) (-413 |t#2|) (-379 |t#2|) (-10 -8 (IF (|has| |t#2| (-172)) (-6 (-707 |t#2|)) |noBranch|) (-15 -3422 ($ |t#2|)) (-15 -2282 ($ (-634 |t#2|))) (-15 -3815 (|t#3| $)) (-15 -1932 (|t#2| $)) (-15 -3241 (|t#2| $)) (-15 * (|t#4| $ |t#4|)) (-15 * (|t#3| |t#3| $)) (IF (|has| |t#2| (-6 (-4521 "*"))) (PROGN (-6 (-43 |t#2|)) (-15 -2465 (|t#2| $)) (-15 -3082 (|t#2| $))) |noBranch|) (IF (|has| |t#2| (-365)) (PROGN (-15 -3140 ((-3 $ "failed") $)) (-15 ** ($ $ (-568)))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-39) . T) ((-43 |#2|) |has| |#2| (-6 (-4521 "*"))) ((-105) . T) ((-120 |#2| |#2|) . T) ((-137) . T) ((-608 (-850)) . T) ((-223 |#2|) . T) ((-225) |has| |#2| (-225)) ((-303 |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) ((-379 |#2|) . T) ((-413 |#2|) . T) ((-499 |#2|) . T) ((-523 |#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) ((-637 |#2|) . T) ((-637 $) . T) ((-630 (-568)) |has| |#2| (-630 (-568))) ((-630 |#2|) . T) ((-707 |#2|) -2198 (|has| |#2| (-172)) (|has| |#2| (-6 (-4521 "*")))) ((-716) . T) ((-895 (-1161)) |has| |#2| (-895 (-1161))) ((-1050 |#1| |#1| |#2| |#3| |#4|) . T) ((-1037 (-409 (-568))) |has| |#2| (-1037 (-409 (-568)))) ((-1037 (-568)) |has| |#2| (-1037 (-568))) ((-1037 |#2|) . T) ((-1053 |#2|) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1195) . T)) 
-((-2931 ((|#4| |#4|) 67)) (-1308 ((|#4| |#4|) 62)) (-1689 (((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -3746 (-634 |#3|))) |#4| |#3|) 75)) (-1939 (((-2 (|:| |Smith| |#4|) (|:| |leftEqMat| |#4|) (|:| |rightEqMat| |#4|)) |#4|) 66)) (-3137 (((-2 (|:| |Hermite| |#4|) (|:| |eqMat| |#4|)) |#4|) 64))) 
-(((-1112 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1308 (|#4| |#4|)) (-15 -3137 ((-2 (|:| |Hermite| |#4|) (|:| |eqMat| |#4|)) |#4|)) (-15 -2931 (|#4| |#4|)) (-15 -1939 ((-2 (|:| |Smith| |#4|) (|:| |leftEqMat| |#4|) (|:| |rightEqMat| |#4|)) |#4|)) (-15 -1689 ((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -3746 (-634 |#3|))) |#4| |#3|))) (-301) (-375 |#1|) (-375 |#1|) (-677 |#1| |#2| |#3|)) (T -1112)) 
-((-1689 (*1 *2 *3 *4) (-12 (-4 *5 (-301)) (-4 *6 (-375 *5)) (-4 *4 (-375 *5)) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -3746 (-634 *4)))) (-5 *1 (-1112 *5 *6 *4 *3)) (-4 *3 (-677 *5 *6 *4)))) (-1939 (*1 *2 *3) (-12 (-4 *4 (-301)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-2 (|:| |Smith| *3) (|:| |leftEqMat| *3) (|:| |rightEqMat| *3))) (-5 *1 (-1112 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) (-2931 (*1 *2 *2) (-12 (-4 *3 (-301)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-1112 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) (-3137 (*1 *2 *3) (-12 (-4 *4 (-301)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-2 (|:| |Hermite| *3) (|:| |eqMat| *3))) (-5 *1 (-1112 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) (-1308 (*1 *2 *2) (-12 (-4 *3 (-301)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-1112 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5))))) 
-(-10 -7 (-15 -1308 (|#4| |#4|)) (-15 -3137 ((-2 (|:| |Hermite| |#4|) (|:| |eqMat| |#4|)) |#4|)) (-15 -2931 (|#4| |#4|)) (-15 -1939 ((-2 (|:| |Smith| |#4|) (|:| |leftEqMat| |#4|) (|:| |rightEqMat| |#4|)) |#4|)) (-15 -1689 ((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -3746 (-634 |#3|))) |#4| |#3|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 17)) (-2055 (((-634 |#2|) $) 160)) (-3839 (((-1157 $) $ |#2|) 54) (((-1157 |#1|) $) 43)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 110 (|has| |#1| (-558)))) (-2227 (($ $) 112 (|has| |#1| (-558)))) (-1573 (((-121) $) 114 (|has| |#1| (-558)))) (-2773 (((-763) $) NIL) (((-763) $ (-634 |#2|)) 193)) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-4305 (($ $) NIL (|has| |#1| (-453)))) (-1678 (((-420 $) $) NIL (|has| |#1| (-453)))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) 157) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 |#2| "failed") $) NIL)) (-2854 ((|#1| $) 155) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#1| (-1037 (-568)))) ((|#2| $) NIL)) (-4265 (($ $ $ |#2|) NIL (|has| |#1| (-172)))) (-2114 (($ $) 197)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) 82)) (-3250 (($ $) NIL (|has| |#1| (-453))) (($ $ |#2|) NIL (|has| |#1| (-453)))) (-2108 (((-634 $) $) NIL)) (-3927 (((-121) $) NIL (|has| |#1| (-904)))) (-3088 (($ $ |#1| (-534 |#2|) $) NIL)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| |#1| (-881 (-381))) (|has| |#2| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| |#1| (-881 (-568))) (|has| |#2| (-881 (-568)))))) (-2735 (((-121) $) 19)) (-4178 (((-763) $) 26)) (-2051 (($ (-1157 |#1|) |#2|) 48) (($ (-1157 $) |#2|) 64)) (-2976 (((-634 $) $) NIL)) (-3921 (((-121) $) 31)) (-2047 (($ |#1| (-534 |#2|)) 71) (($ $ |#2| (-763)) 52) (($ $ (-634 |#2|) (-634 (-763))) NIL)) (-3379 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $ |#2|) NIL)) (-2144 (((-534 |#2|) $) 187) (((-763) $ |#2|) 188) (((-634 (-763)) $ (-634 |#2|)) 189)) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-3842 (($ (-1 (-534 |#2|) (-534 |#2|)) $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) 122)) (-2244 (((-3 |#2| "failed") $) 162)) (-2097 (($ $) 196)) (-2102 ((|#1| $) 37)) (-2495 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-4487 (((-1143) $) NIL)) (-3324 (((-3 (-634 $) "failed") $) NIL)) (-1794 (((-3 (-634 $) "failed") $) NIL)) (-3751 (((-3 (-2 (|:| |var| |#2|) (|:| -3438 (-763))) "failed") $) NIL)) (-4022 (((-1108) $) NIL)) (-2086 (((-121) $) 32)) (-2091 ((|#1| $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 140 (|has| |#1| (-453)))) (-2721 (($ (-634 $)) 145 (|has| |#1| (-453))) (($ $ $) 132 (|has| |#1| (-453)))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3848 (((-420 $) $) NIL (|has| |#1| (-904)))) (-2595 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558))) (((-3 $ "failed") $ $) 120 (|has| |#1| (-558)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ |#2| |#1|) 165) (($ $ (-634 |#2|) (-634 |#1|)) 178) (($ $ |#2| $) 164) (($ $ (-634 |#2|) (-634 $)) 177)) (-2217 (($ $ |#2|) NIL (|has| |#1| (-172)))) (-4189 (($ $ |#2|) 195) (($ $ (-634 |#2|)) NIL) (($ $ |#2| (-763)) NIL) (($ $ (-634 |#2|) (-634 (-763))) NIL)) (-3206 (((-534 |#2|) $) 183) (((-763) $ |#2|) 179) (((-634 (-763)) $ (-634 |#2|)) 181)) (-4278 (((-887 (-381)) $) NIL (-12 (|has| |#1| (-609 (-887 (-381)))) (|has| |#2| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| |#1| (-609 (-887 (-568)))) (|has| |#2| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| |#1| (-609 (-541))) (|has| |#2| (-609 (-541)))))) (-3367 ((|#1| $) 128 (|has| |#1| (-453))) (($ $ |#2|) 131 (|has| |#1| (-453)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#1| (-904))))) (-2745 (((-850) $) 151) (($ (-568)) 76) (($ |#1|) 77) (($ |#2|) 28) (($ $) NIL (|has| |#1| (-558))) (($ (-409 (-568))) NIL (-2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568))))))) (-1302 (((-634 |#1|) $) 154)) (-2604 ((|#1| $ (-534 |#2|)) 73) (($ $ |#2| (-763)) NIL) (($ $ (-634 |#2|) (-634 (-763))) NIL)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-4078 (((-763)) 79)) (-4171 (($ $ $ (-763)) NIL (|has| |#1| (-172)))) (-1826 (((-121) $ $) 117 (|has| |#1| (-558)))) (-1887 (($ $ (-917)) 102) (($ $ (-763)) 104)) (-3056 (($) 12 T CONST)) (-1556 (($) 14 T CONST)) (-3190 (($ $ |#2|) NIL) (($ $ (-634 |#2|)) NIL) (($ $ |#2| (-763)) NIL) (($ $ (-634 |#2|) (-634 (-763))) NIL)) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) 97)) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1779 (($ $ |#1|) 126 (|has| |#1| (-365)))) (-1773 (($ $) 85) (($ $ $) 95)) (-1767 (($ $ $) 49)) (** (($ $ (-917)) 103) (($ $ (-763)) 100)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 88) (($ $ $) 65) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) 90) (($ $ |#1|) NIL))) 
+((-1637 (*1 *1 *2) (-12 (-4 *2 (-1047)) (-4 *1 (-1111 *3 *2 *4 *5)) (-4 *4 (-230 *3 *2)) (-4 *5 (-230 *3 *2)))) (-3499 (*1 *1 *2) (-12 (-5 *2 (-634 *4)) (-4 *4 (-1047)) (-4 *1 (-1111 *3 *4 *5 *6)) (-4 *5 (-230 *3 *4)) (-4 *6 (-230 *3 *4)))) (-1760 (*1 *2 *1) (-12 (-4 *1 (-1111 *3 *4 *2 *5)) (-4 *4 (-1047)) (-4 *5 (-230 *3 *4)) (-4 *2 (-230 *3 *4)))) (-1934 (*1 *2 *1) (-12 (-4 *1 (-1111 *3 *2 *4 *5)) (-4 *4 (-230 *3 *2)) (-4 *5 (-230 *3 *2)) (-4 *2 (-1047)))) (-1966 (*1 *2 *1) (-12 (-4 *1 (-1111 *3 *2 *4 *5)) (-4 *4 (-230 *3 *2)) (-4 *5 (-230 *3 *2)) (-4 *2 (-1047)))) (* (*1 *2 *1 *2) (-12 (-4 *1 (-1111 *3 *4 *5 *2)) (-4 *4 (-1047)) (-4 *5 (-230 *3 *4)) (-4 *2 (-230 *3 *4)))) (* (*1 *2 *2 *1) (-12 (-4 *1 (-1111 *3 *4 *2 *5)) (-4 *4 (-1047)) (-4 *2 (-230 *3 *4)) (-4 *5 (-230 *3 *4)))) (-2591 (*1 *2 *1) (-12 (-4 *1 (-1111 *3 *2 *4 *5)) (-4 *4 (-230 *3 *2)) (-4 *5 (-230 *3 *2)) (|has| *2 (-6 (-4523 "*"))) (-4 *2 (-1047)))) (-2424 (*1 *2 *1) (-12 (-4 *1 (-1111 *3 *2 *4 *5)) (-4 *4 (-230 *3 *2)) (-4 *5 (-230 *3 *2)) (|has| *2 (-6 (-4523 "*"))) (-4 *2 (-1047)))) (-2715 (*1 *1 *1) (|partial| -12 (-4 *1 (-1111 *2 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-230 *2 *3)) (-4 *5 (-230 *2 *3)) (-4 *3 (-365)))) (** (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-1111 *3 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-230 *3 *4)) (-4 *6 (-230 *3 *4)) (-4 *4 (-365))))) 
+(-13 (-223 |t#2|) (-120 |t#2| |t#2|) (-1050 |t#1| |t#1| |t#2| |t#3| |t#4|) (-413 |t#2|) (-379 |t#2|) (-10 -8 (IF (|has| |t#2| (-172)) (-6 (-707 |t#2|)) |noBranch|) (-15 -1637 ($ |t#2|)) (-15 -3499 ($ (-634 |t#2|))) (-15 -1760 (|t#3| $)) (-15 -1934 (|t#2| $)) (-15 -1966 (|t#2| $)) (-15 * (|t#4| $ |t#4|)) (-15 * (|t#3| |t#3| $)) (IF (|has| |t#2| (-6 (-4523 "*"))) (PROGN (-6 (-43 |t#2|)) (-15 -2591 (|t#2| $)) (-15 -2424 (|t#2| $))) |noBranch|) (IF (|has| |t#2| (-365)) (PROGN (-15 -2715 ((-3 $ "failed") $)) (-15 ** ($ $ (-568)))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-39) . T) ((-43 |#2|) |has| |#2| (-6 (-4523 "*"))) ((-105) . T) ((-120 |#2| |#2|) . T) ((-137) . T) ((-608 (-850)) . T) ((-223 |#2|) . T) ((-225) |has| |#2| (-225)) ((-303 |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) ((-379 |#2|) . T) ((-413 |#2|) . T) ((-499 |#2|) . T) ((-523 |#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) ((-637 |#2|) . T) ((-637 $) . T) ((-630 (-568)) |has| |#2| (-630 (-568))) ((-630 |#2|) . T) ((-707 |#2|) -2199 (|has| |#2| (-172)) (|has| |#2| (-6 (-4523 "*")))) ((-716) . T) ((-895 (-1161)) |has| |#2| (-895 (-1161))) ((-1050 |#1| |#1| |#2| |#3| |#4|) . T) ((-1037 (-409 (-568))) |has| |#2| (-1037 (-409 (-568)))) ((-1037 (-568)) |has| |#2| (-1037 (-568))) ((-1037 |#2|) . T) ((-1053 |#2|) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1195) . T)) 
+((-2915 ((|#4| |#4|) 67)) (-3346 ((|#4| |#4|) 62)) (-3554 (((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2588 (-634 |#3|))) |#4| |#3|) 75)) (-4223 (((-2 (|:| |Smith| |#4|) (|:| |leftEqMat| |#4|) (|:| |rightEqMat| |#4|)) |#4|) 66)) (-2702 (((-2 (|:| |Hermite| |#4|) (|:| |eqMat| |#4|)) |#4|) 64))) 
+(((-1112 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3346 (|#4| |#4|)) (-15 -2702 ((-2 (|:| |Hermite| |#4|) (|:| |eqMat| |#4|)) |#4|)) (-15 -2915 (|#4| |#4|)) (-15 -4223 ((-2 (|:| |Smith| |#4|) (|:| |leftEqMat| |#4|) (|:| |rightEqMat| |#4|)) |#4|)) (-15 -3554 ((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2588 (-634 |#3|))) |#4| |#3|))) (-301) (-375 |#1|) (-375 |#1|) (-677 |#1| |#2| |#3|)) (T -1112)) 
+((-3554 (*1 *2 *3 *4) (-12 (-4 *5 (-301)) (-4 *6 (-375 *5)) (-4 *4 (-375 *5)) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2588 (-634 *4)))) (-5 *1 (-1112 *5 *6 *4 *3)) (-4 *3 (-677 *5 *6 *4)))) (-4223 (*1 *2 *3) (-12 (-4 *4 (-301)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-2 (|:| |Smith| *3) (|:| |leftEqMat| *3) (|:| |rightEqMat| *3))) (-5 *1 (-1112 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) (-2915 (*1 *2 *2) (-12 (-4 *3 (-301)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-1112 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) (-2702 (*1 *2 *3) (-12 (-4 *4 (-301)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-2 (|:| |Hermite| *3) (|:| |eqMat| *3))) (-5 *1 (-1112 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) (-3346 (*1 *2 *2) (-12 (-4 *3 (-301)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-1112 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5))))) 
+(-10 -7 (-15 -3346 (|#4| |#4|)) (-15 -2702 ((-2 (|:| |Hermite| |#4|) (|:| |eqMat| |#4|)) |#4|)) (-15 -2915 (|#4| |#4|)) (-15 -4223 ((-2 (|:| |Smith| |#4|) (|:| |leftEqMat| |#4|) (|:| |rightEqMat| |#4|)) |#4|)) (-15 -3554 ((-2 (|:| |particular| (-3 |#3| "failed")) (|:| -2588 (-634 |#3|))) |#4| |#3|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 17)) (-2057 (((-634 |#2|) $) 160)) (-3840 (((-1157 $) $ |#2|) 54) (((-1157 |#1|) $) 43)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 110 (|has| |#1| (-558)))) (-3661 (($ $) 112 (|has| |#1| (-558)))) (-4426 (((-121) $) 114 (|has| |#1| (-558)))) (-3528 (((-763) $) NIL) (((-763) $ (-634 |#2|)) 193)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3045 (($ $) NIL (|has| |#1| (-453)))) (-3498 (((-420 $) $) NIL (|has| |#1| (-453)))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) 157) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 |#2| "failed") $) NIL)) (-2857 ((|#1| $) 155) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#1| (-1037 (-568)))) ((|#2| $) NIL)) (-2910 (($ $ $ |#2|) NIL (|has| |#1| (-172)))) (-2116 (($ $) 197)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) 82)) (-1998 (($ $) NIL (|has| |#1| (-453))) (($ $ |#2|) NIL (|has| |#1| (-453)))) (-2110 (((-634 $) $) NIL)) (-2197 (((-121) $) NIL (|has| |#1| (-904)))) (-2453 (($ $ |#1| (-534 |#2|) $) NIL)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| |#1| (-881 (-381))) (|has| |#2| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| |#1| (-881 (-568))) (|has| |#2| (-881 (-568)))))) (-1598 (((-121) $) 19)) (-3971 (((-763) $) 26)) (-2053 (($ (-1157 |#1|) |#2|) 48) (($ (-1157 $) |#2|) 64)) (-3062 (((-634 $) $) NIL)) (-2171 (((-121) $) 31)) (-2049 (($ |#1| (-534 |#2|)) 71) (($ $ |#2| (-763)) 52) (($ $ (-634 |#2|) (-634 (-763))) NIL)) (-1438 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $ |#2|) NIL)) (-3524 (((-534 |#2|) $) 187) (((-763) $ |#2|) 188) (((-634 (-763)) $ (-634 |#2|)) 189)) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-1865 (($ (-1 (-534 |#2|) (-534 |#2|)) $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) 122)) (-2817 (((-3 |#2| "failed") $) 162)) (-2099 (($ $) 196)) (-2104 ((|#1| $) 37)) (-2498 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-1893 (((-1143) $) NIL)) (-4362 (((-3 (-634 $) "failed") $) NIL)) (-2112 (((-3 (-634 $) "failed") $) NIL)) (-2617 (((-3 (-2 (|:| |var| |#2|) (|:| -3483 (-763))) "failed") $) NIL)) (-4025 (((-1108) $) NIL)) (-2088 (((-121) $) 32)) (-2093 ((|#1| $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 140 (|has| |#1| (-453)))) (-2723 (($ (-634 $)) 145 (|has| |#1| (-453))) (($ $ $) 132 (|has| |#1| (-453)))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3850 (((-420 $) $) NIL (|has| |#1| (-904)))) (-2597 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558))) (((-3 $ "failed") $ $) 120 (|has| |#1| (-558)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ |#2| |#1|) 165) (($ $ (-634 |#2|) (-634 |#1|)) 178) (($ $ |#2| $) 164) (($ $ (-634 |#2|) (-634 $)) 177)) (-3440 (($ $ |#2|) NIL (|has| |#1| (-172)))) (-4191 (($ $ |#2|) 195) (($ $ (-634 |#2|)) NIL) (($ $ |#2| (-763)) NIL) (($ $ (-634 |#2|) (-634 (-763))) NIL)) (-1836 (((-534 |#2|) $) 183) (((-763) $ |#2|) 179) (((-634 (-763)) $ (-634 |#2|)) 181)) (-4280 (((-887 (-381)) $) NIL (-12 (|has| |#1| (-609 (-887 (-381)))) (|has| |#2| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| |#1| (-609 (-887 (-568)))) (|has| |#2| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| |#1| (-609 (-541))) (|has| |#2| (-609 (-541)))))) (-1364 ((|#1| $) 128 (|has| |#1| (-453))) (($ $ |#2|) 131 (|has| |#1| (-453)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#1| (-904))))) (-2747 (((-850) $) 151) (($ (-568)) 76) (($ |#1|) 77) (($ |#2|) 28) (($ $) NIL (|has| |#1| (-558))) (($ (-409 (-568))) NIL (-2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568))))))) (-3304 (((-634 |#1|) $) 154)) (-2079 ((|#1| $ (-534 |#2|)) 73) (($ $ |#2| (-763)) NIL) (($ $ (-634 |#2|) (-634 (-763))) NIL)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-3425 (((-763)) 79)) (-3925 (($ $ $ (-763)) NIL (|has| |#1| (-172)))) (-2273 (((-121) $ $) 117 (|has| |#1| (-558)))) (-1889 (($ $ (-917)) 102) (($ $ (-763)) 104)) (-3058 (($) 12 T CONST)) (-1557 (($) 14 T CONST)) (-3192 (($ $ |#2|) NIL) (($ $ (-634 |#2|)) NIL) (($ $ |#2| (-763)) NIL) (($ $ (-634 |#2|) (-634 (-763))) NIL)) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) 97)) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1781 (($ $ |#1|) 126 (|has| |#1| (-365)))) (-1775 (($ $) 85) (($ $ $) 95)) (-1769 (($ $ $) 49)) (** (($ $ (-917)) 103) (($ $ (-763)) 100)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 88) (($ $ $) 65) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) 90) (($ $ |#1|) NIL))) 
 (((-1113 |#1| |#2|) (-950 |#1| (-534 |#2|) |#2|) (-1047) (-842)) (T -1113)) 
 NIL 
 (-950 |#1| (-534 |#2|) |#2|) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2055 (((-634 |#2|) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-1982 (($ $) 154 (|has| |#1| (-43 (-409 (-568)))))) (-1933 (($ $) 130 (|has| |#1| (-43 (-409 (-568)))))) (-3134 (((-3 $ "failed") $ $) NIL)) (-1902 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1974 (($ $) 150 (|has| |#1| (-43 (-409 (-568)))))) (-2786 (($ $) 126 (|has| |#1| (-43 (-409 (-568)))))) (-1990 (($ $) 158 (|has| |#1| (-43 (-409 (-568)))))) (-1941 (($ $) 134 (|has| |#1| (-43 (-409 (-568)))))) (-2671 (($) NIL T CONST)) (-2114 (($ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1367 (((-953 |#1|) $ (-763)) NIL) (((-953 |#1|) $ (-763) (-763)) NIL)) (-3992 (((-121) $) NIL)) (-1897 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4477 (((-763) $ |#2|) NIL) (((-763) $ |#2| (-763)) NIL)) (-2735 (((-121) $) NIL)) (-4044 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3921 (((-121) $) NIL)) (-2047 (($ $ (-634 |#2|) (-634 (-534 |#2|))) NIL) (($ $ |#2| (-534 |#2|)) NIL) (($ |#1| (-534 |#2|)) NIL) (($ $ |#2| (-763)) 71) (($ $ (-634 |#2|) (-634 (-763))) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-4416 (($ $) 124 (|has| |#1| (-43 (-409 (-568)))))) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-4487 (((-1143) $) NIL)) (-3837 (($ $ |#2|) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ |#2| |#1|) 177 (|has| |#1| (-43 (-409 (-568)))))) (-4022 (((-1108) $) NIL)) (-2225 (($ (-1 $) |#2| |#1|) 176 (|has| |#1| (-43 (-409 (-568)))))) (-1807 (($ $ (-763)) 15)) (-2595 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-1892 (($ $) 122 (|has| |#1| (-43 (-409 (-568)))))) (-1339 (($ $ |#2| $) 109) (($ $ (-634 |#2|) (-634 $)) 102) (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL)) (-4189 (($ $ |#2|) 111) (($ $ (-634 |#2|)) NIL) (($ $ |#2| (-763)) NIL) (($ $ (-634 |#2|) (-634 (-763))) NIL)) (-3206 (((-534 |#2|) $) NIL)) (-4441 (((-1 (-1141 |#3|) |#3|) (-634 |#2|) (-634 (-1141 |#3|))) 92)) (-1994 (($ $) 160 (|has| |#1| (-43 (-409 (-568)))))) (-1945 (($ $) 136 (|has| |#1| (-43 (-409 (-568)))))) (-1986 (($ $) 156 (|has| |#1| (-43 (-409 (-568)))))) (-1937 (($ $) 132 (|has| |#1| (-43 (-409 (-568)))))) (-1978 (($ $) 152 (|has| |#1| (-43 (-409 (-568)))))) (-2790 (($ $) 128 (|has| |#1| (-43 (-409 (-568)))))) (-1811 (($ $) 17)) (-2745 (((-850) $) 192) (($ (-568)) NIL) (($ |#1|) 59 (|has| |#1| (-172))) (($ $) NIL (|has| |#1| (-558))) (($ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#2|) 78) (($ |#3|) 76)) (-2604 ((|#1| $ (-534 |#2|)) 57) (($ $ |#2| (-763)) NIL) (($ $ (-634 |#2|) (-634 (-763))) 50) ((|#3| $ (-763)) 42)) (-4371 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-4078 (((-763)) NIL)) (-2006 (($ $) 166 (|has| |#1| (-43 (-409 (-568)))))) (-1958 (($ $) 142 (|has| |#1| (-43 (-409 (-568)))))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1998 (($ $) 162 (|has| |#1| (-43 (-409 (-568)))))) (-1949 (($ $) 138 (|has| |#1| (-43 (-409 (-568)))))) (-2014 (($ $) 170 (|has| |#1| (-43 (-409 (-568)))))) (-1966 (($ $) 146 (|has| |#1| (-43 (-409 (-568)))))) (-4023 (($ $) 172 (|has| |#1| (-43 (-409 (-568)))))) (-1970 (($ $) 148 (|has| |#1| (-43 (-409 (-568)))))) (-2010 (($ $) 168 (|has| |#1| (-43 (-409 (-568)))))) (-1962 (($ $) 144 (|has| |#1| (-43 (-409 (-568)))))) (-2002 (($ $) 164 (|has| |#1| (-43 (-409 (-568)))))) (-1953 (($ $) 140 (|has| |#1| (-43 (-409 (-568)))))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 18 T CONST)) (-1556 (($) 10 T CONST)) (-3190 (($ $ |#2|) NIL) (($ $ (-634 |#2|)) NIL) (($ $ |#2| (-763)) NIL) (($ $ (-634 |#2|) (-634 (-763))) NIL)) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ |#1|) 194 (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) 74)) (** (($ $ (-917)) NIL) (($ $ (-763)) 83) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 114 (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 73) (($ $ (-409 (-568))) 119 (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) 117 (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) 62) (($ $ |#1|) 63) (($ |#3| $) 61))) 
-(((-1114 |#1| |#2| |#3|) (-13 (-730 |#1| |#2|) (-10 -8 (-15 -2604 (|#3| $ (-763))) (-15 -2745 ($ |#2|)) (-15 -2745 ($ |#3|)) (-15 * ($ |#3| $)) (-15 -4441 ((-1 (-1141 |#3|) |#3|) (-634 |#2|) (-634 (-1141 |#3|)))) (IF (|has| |#1| (-43 (-409 (-568)))) (PROGN (-15 -3837 ($ $ |#2| |#1|)) (-15 -2225 ($ (-1 $) |#2| |#1|))) |noBranch|))) (-1047) (-842) (-950 |#1| (-534 |#2|) |#2|)) (T -1114)) 
-((-2604 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *2 (-950 *4 (-534 *5) *5)) (-5 *1 (-1114 *4 *5 *2)) (-4 *4 (-1047)) (-4 *5 (-842)))) (-2745 (*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *2 (-842)) (-5 *1 (-1114 *3 *2 *4)) (-4 *4 (-950 *3 (-534 *2) *2)))) (-2745 (*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-842)) (-5 *1 (-1114 *3 *4 *2)) (-4 *2 (-950 *3 (-534 *4) *4)))) (* (*1 *1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-842)) (-5 *1 (-1114 *3 *4 *2)) (-4 *2 (-950 *3 (-534 *4) *4)))) (-4441 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-634 (-1141 *7))) (-4 *6 (-842)) (-4 *7 (-950 *5 (-534 *6) *6)) (-4 *5 (-1047)) (-5 *2 (-1 (-1141 *7) *7)) (-5 *1 (-1114 *5 *6 *7)))) (-3837 (*1 *1 *1 *2 *3) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-4 *2 (-842)) (-5 *1 (-1114 *3 *2 *4)) (-4 *4 (-950 *3 (-534 *2) *2)))) (-2225 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1 (-1114 *4 *3 *5))) (-4 *4 (-43 (-409 (-568)))) (-4 *4 (-1047)) (-4 *3 (-842)) (-5 *1 (-1114 *4 *3 *5)) (-4 *5 (-950 *4 (-534 *3) *3))))) 
-(-13 (-730 |#1| |#2|) (-10 -8 (-15 -2604 (|#3| $ (-763))) (-15 -2745 ($ |#2|)) (-15 -2745 ($ |#3|)) (-15 * ($ |#3| $)) (-15 -4441 ((-1 (-1141 |#3|) |#3|) (-634 |#2|) (-634 (-1141 |#3|)))) (IF (|has| |#1| (-43 (-409 (-568)))) (PROGN (-15 -3837 ($ $ |#2| |#1|)) (-15 -2225 ($ (-1 $) |#2| |#1|))) |noBranch|))) 
-((-2447 (((-121) $ $) 7)) (-2387 (((-634 (-2 (|:| -4092 $) (|:| -1798 (-634 |#4|)))) (-634 |#4|)) 78)) (-2415 (((-634 $) (-634 |#4|)) 79) (((-634 $) (-634 |#4|) (-121)) 104)) (-2055 (((-634 |#3|) $) 32)) (-4211 (((-121) $) 25)) (-3824 (((-121) $) 16 (|has| |#1| (-558)))) (-3300 (((-121) |#4| $) 94) (((-121) $) 90)) (-2819 ((|#4| |#4| $) 85)) (-4305 (((-634 (-2 (|:| |val| |#4|) (|:| -3001 $))) |#4| $) 119)) (-3644 (((-2 (|:| |under| $) (|:| -1519 $) (|:| |upper| $)) $ |#3|) 26)) (-2510 (((-121) $ (-763)) 43)) (-2801 (($ (-1 (-121) |#4|) $) 64 (|has| $ (-6 -4519))) (((-3 |#4| "failed") $ |#3|) 72)) (-2671 (($) 44 T CONST)) (-1565 (((-121) $) 21 (|has| |#1| (-558)))) (-3846 (((-121) $ $) 23 (|has| |#1| (-558)))) (-3106 (((-121) $ $) 22 (|has| |#1| (-558)))) (-3695 (((-121) $) 24 (|has| |#1| (-558)))) (-4275 (((-634 |#4|) (-634 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 86)) (-2355 (((-634 |#4|) (-634 |#4|) $) 17 (|has| |#1| (-558)))) (-2492 (((-634 |#4|) (-634 |#4|) $) 18 (|has| |#1| (-558)))) (-3666 (((-3 $ "failed") (-634 |#4|)) 35)) (-2854 (($ (-634 |#4|)) 34)) (-3935 (((-3 $ "failed") $) 75)) (-2062 ((|#4| |#4| $) 82)) (-3924 (($ $) 67 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519))))) (-4328 (($ |#4| $) 66 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) |#4|) $) 63 (|has| $ (-6 -4519)))) (-1500 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-558)))) (-1281 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) 95)) (-4079 ((|#4| |#4| $) 80)) (-3092 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4519))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4519))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 87)) (-3635 (((-2 (|:| -4092 (-634 |#4|)) (|:| -1798 (-634 |#4|))) $) 98)) (-1862 (((-121) |#4| $) 129)) (-4286 (((-121) |#4| $) 126)) (-3193 (((-121) |#4| $) 130) (((-121) $) 127)) (-4360 (((-634 |#4|) $) 51 (|has| $ (-6 -4519)))) (-1362 (((-121) |#4| $) 97) (((-121) $) 96)) (-2356 ((|#3| $) 33)) (-1737 (((-121) $ (-763)) 42)) (-1979 (((-634 |#4|) $) 52 (|has| $ (-6 -4519)))) (-3109 (((-121) |#4| $) 54 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#4| |#4|) $) 46)) (-1432 (((-634 |#3|) $) 31)) (-3392 (((-121) |#3| $) 30)) (-2166 (((-121) $ (-763)) 41)) (-4487 (((-1143) $) 9)) (-2717 (((-3 |#4| (-634 $)) |#4| |#4| $) 121)) (-4330 (((-634 (-2 (|:| |val| |#4|) (|:| -3001 $))) |#4| |#4| $) 120)) (-4162 (((-3 |#4| "failed") $) 76)) (-2335 (((-634 $) |#4| $) 122)) (-1719 (((-3 (-121) (-634 $)) |#4| $) 125)) (-2632 (((-634 (-2 (|:| |val| (-121)) (|:| -3001 $))) |#4| $) 124) (((-121) |#4| $) 123)) (-3212 (((-634 $) |#4| $) 118) (((-634 $) (-634 |#4|) $) 117) (((-634 $) (-634 |#4|) (-634 $)) 116) (((-634 $) |#4| (-634 $)) 115)) (-3473 (($ |#4| $) 110) (($ (-634 |#4|) $) 109)) (-1377 (((-634 |#4|) $) 100)) (-1415 (((-121) |#4| $) 92) (((-121) $) 88)) (-2682 ((|#4| |#4| $) 83)) (-2644 (((-121) $ $) 103)) (-2705 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-558)))) (-4347 (((-121) |#4| $) 93) (((-121) $) 89)) (-4025 ((|#4| |#4| $) 84)) (-4022 (((-1108) $) 10)) (-3876 (((-3 |#4| "failed") $) 77)) (-3775 (((-3 |#4| "failed") (-1 (-121) |#4|) $) 60)) (-1665 (((-3 $ "failed") $ |#4|) 71)) (-1807 (($ $ |#4|) 70) (((-634 $) |#4| $) 108) (((-634 $) |#4| (-634 $)) 107) (((-634 $) (-634 |#4|) $) 106) (((-634 $) (-634 |#4|) (-634 $)) 105)) (-1387 (((-121) (-1 (-121) |#4|) $) 49 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 |#4|) (-634 |#4|)) 58 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) 56 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 (-288 |#4|))) 55 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-3171 (((-121) $ $) 37)) (-3084 (((-121) $) 40)) (-3248 (($) 39)) (-3206 (((-763) $) 99)) (-4168 (((-763) |#4| $) 53 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519)))) (((-763) (-1 (-121) |#4|) $) 50 (|has| $ (-6 -4519)))) (-3863 (($ $) 38)) (-4278 (((-541) $) 68 (|has| |#4| (-609 (-541))))) (-4287 (($ (-634 |#4|)) 59)) (-1290 (($ $ |#3|) 27)) (-3732 (($ $ |#3|) 29)) (-1567 (($ $) 81)) (-3944 (($ $ |#3|) 28)) (-2745 (((-850) $) 11) (((-634 |#4|) $) 36)) (-1878 (((-763) $) 69 (|has| |#3| (-370)))) (-3556 (((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4| |#4|)) 102) (((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) 101)) (-3292 (((-121) $ (-1 (-121) |#4| (-634 |#4|))) 91)) (-2574 (((-634 $) |#4| $) 114) (((-634 $) |#4| (-634 $)) 113) (((-634 $) (-634 |#4|) $) 112) (((-634 $) (-634 |#4|) (-634 $)) 111)) (-1319 (((-121) (-1 (-121) |#4|) $) 48 (|has| $ (-6 -4519)))) (-2739 (((-634 |#3|) $) 74)) (-2288 (((-121) |#4| $) 128)) (-4390 (((-121) |#3| $) 73)) (-1717 (((-121) $ $) 6)) (-1697 (((-763) $) 45 (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2057 (((-634 |#2|) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-1984 (($ $) 154 (|has| |#1| (-43 (-409 (-568)))))) (-1935 (($ $) 130 (|has| |#1| (-43 (-409 (-568)))))) (-2689 (((-3 $ "failed") $ $) NIL)) (-1904 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1976 (($ $) 150 (|has| |#1| (-43 (-409 (-568)))))) (-2788 (($ $) 126 (|has| |#1| (-43 (-409 (-568)))))) (-1992 (($ $) 158 (|has| |#1| (-43 (-409 (-568)))))) (-1943 (($ $) 134 (|has| |#1| (-43 (-409 (-568)))))) (-4490 (($) NIL T CONST)) (-2116 (($ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-3808 (((-953 |#1|) $ (-763)) NIL) (((-953 |#1|) $ (-763) (-763)) NIL)) (-1302 (((-121) $) NIL)) (-1899 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1844 (((-763) $ |#2|) NIL) (((-763) $ |#2| (-763)) NIL)) (-1598 (((-121) $) NIL)) (-1550 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2171 (((-121) $) NIL)) (-2049 (($ $ (-634 |#2|) (-634 (-534 |#2|))) NIL) (($ $ |#2| (-534 |#2|)) NIL) (($ |#1| (-534 |#2|)) NIL) (($ $ |#2| (-763)) 71) (($ $ (-634 |#2|) (-634 (-763))) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-4418 (($ $) 124 (|has| |#1| (-43 (-409 (-568)))))) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-1893 (((-1143) $) NIL)) (-1845 (($ $ |#2|) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ |#2| |#1|) 177 (|has| |#1| (-43 (-409 (-568)))))) (-4025 (((-1108) $) NIL)) (-3648 (($ (-1 $) |#2| |#1|) 176 (|has| |#1| (-43 (-409 (-568)))))) (-2168 (($ $ (-763)) 15)) (-2597 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-1894 (($ $) 122 (|has| |#1| (-43 (-409 (-568)))))) (-1339 (($ $ |#2| $) 109) (($ $ (-634 |#2|) (-634 $)) 102) (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL)) (-4191 (($ $ |#2|) 111) (($ $ (-634 |#2|)) NIL) (($ $ |#2| (-763)) NIL) (($ $ (-634 |#2|) (-634 (-763))) NIL)) (-1836 (((-534 |#2|) $) NIL)) (-1660 (((-1 (-1141 |#3|) |#3|) (-634 |#2|) (-634 (-1141 |#3|))) 92)) (-1996 (($ $) 160 (|has| |#1| (-43 (-409 (-568)))))) (-1947 (($ $) 136 (|has| |#1| (-43 (-409 (-568)))))) (-1988 (($ $) 156 (|has| |#1| (-43 (-409 (-568)))))) (-1939 (($ $) 132 (|has| |#1| (-43 (-409 (-568)))))) (-1980 (($ $) 152 (|has| |#1| (-43 (-409 (-568)))))) (-2792 (($ $) 128 (|has| |#1| (-43 (-409 (-568)))))) (-2188 (($ $) 17)) (-2747 (((-850) $) 192) (($ (-568)) NIL) (($ |#1|) 59 (|has| |#1| (-172))) (($ $) NIL (|has| |#1| (-558))) (($ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#2|) 78) (($ |#3|) 76)) (-2079 ((|#1| $ (-534 |#2|)) 57) (($ $ |#2| (-763)) NIL) (($ $ (-634 |#2|) (-634 (-763))) 50) ((|#3| $ (-763)) 42)) (-3385 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-3425 (((-763)) NIL)) (-2008 (($ $) 166 (|has| |#1| (-43 (-409 (-568)))))) (-1959 (($ $) 142 (|has| |#1| (-43 (-409 (-568)))))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2000 (($ $) 162 (|has| |#1| (-43 (-409 (-568)))))) (-1951 (($ $) 138 (|has| |#1| (-43 (-409 (-568)))))) (-2016 (($ $) 170 (|has| |#1| (-43 (-409 (-568)))))) (-1968 (($ $) 146 (|has| |#1| (-43 (-409 (-568)))))) (-1439 (($ $) 172 (|has| |#1| (-43 (-409 (-568)))))) (-1972 (($ $) 148 (|has| |#1| (-43 (-409 (-568)))))) (-2012 (($ $) 168 (|has| |#1| (-43 (-409 (-568)))))) (-1964 (($ $) 144 (|has| |#1| (-43 (-409 (-568)))))) (-2004 (($ $) 164 (|has| |#1| (-43 (-409 (-568)))))) (-1955 (($ $) 140 (|has| |#1| (-43 (-409 (-568)))))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 18 T CONST)) (-1557 (($) 10 T CONST)) (-3192 (($ $ |#2|) NIL) (($ $ (-634 |#2|)) NIL) (($ $ |#2| (-763)) NIL) (($ $ (-634 |#2|) (-634 (-763))) NIL)) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ |#1|) 194 (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) 74)) (** (($ $ (-917)) NIL) (($ $ (-763)) 83) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 114 (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 73) (($ $ (-409 (-568))) 119 (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) 117 (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) 62) (($ $ |#1|) 63) (($ |#3| $) 61))) 
+(((-1114 |#1| |#2| |#3|) (-13 (-730 |#1| |#2|) (-10 -8 (-15 -2079 (|#3| $ (-763))) (-15 -2747 ($ |#2|)) (-15 -2747 ($ |#3|)) (-15 * ($ |#3| $)) (-15 -1660 ((-1 (-1141 |#3|) |#3|) (-634 |#2|) (-634 (-1141 |#3|)))) (IF (|has| |#1| (-43 (-409 (-568)))) (PROGN (-15 -1845 ($ $ |#2| |#1|)) (-15 -3648 ($ (-1 $) |#2| |#1|))) |noBranch|))) (-1047) (-842) (-950 |#1| (-534 |#2|) |#2|)) (T -1114)) 
+((-2079 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *2 (-950 *4 (-534 *5) *5)) (-5 *1 (-1114 *4 *5 *2)) (-4 *4 (-1047)) (-4 *5 (-842)))) (-2747 (*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *2 (-842)) (-5 *1 (-1114 *3 *2 *4)) (-4 *4 (-950 *3 (-534 *2) *2)))) (-2747 (*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-842)) (-5 *1 (-1114 *3 *4 *2)) (-4 *2 (-950 *3 (-534 *4) *4)))) (* (*1 *1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-842)) (-5 *1 (-1114 *3 *4 *2)) (-4 *2 (-950 *3 (-534 *4) *4)))) (-1660 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-634 (-1141 *7))) (-4 *6 (-842)) (-4 *7 (-950 *5 (-534 *6) *6)) (-4 *5 (-1047)) (-5 *2 (-1 (-1141 *7) *7)) (-5 *1 (-1114 *5 *6 *7)))) (-1845 (*1 *1 *1 *2 *3) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-4 *2 (-842)) (-5 *1 (-1114 *3 *2 *4)) (-4 *4 (-950 *3 (-534 *2) *2)))) (-3648 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1 (-1114 *4 *3 *5))) (-4 *4 (-43 (-409 (-568)))) (-4 *4 (-1047)) (-4 *3 (-842)) (-5 *1 (-1114 *4 *3 *5)) (-4 *5 (-950 *4 (-534 *3) *3))))) 
+(-13 (-730 |#1| |#2|) (-10 -8 (-15 -2079 (|#3| $ (-763))) (-15 -2747 ($ |#2|)) (-15 -2747 ($ |#3|)) (-15 * ($ |#3| $)) (-15 -1660 ((-1 (-1141 |#3|) |#3|) (-634 |#2|) (-634 (-1141 |#3|)))) (IF (|has| |#1| (-43 (-409 (-568)))) (PROGN (-15 -1845 ($ $ |#2| |#1|)) (-15 -3648 ($ (-1 $) |#2| |#1|))) |noBranch|))) 
+((-2449 (((-121) $ $) 7)) (-2213 (((-634 (-2 (|:| -4094 $) (|:| -2133 (-634 |#4|)))) (-634 |#4|)) 78)) (-2353 (((-634 $) (-634 |#4|)) 79) (((-634 $) (-634 |#4|) (-121)) 104)) (-2057 (((-634 |#3|) $) 32)) (-4141 (((-121) $) 25)) (-1794 (((-121) $) 16 (|has| |#1| (-558)))) (-4231 (((-121) |#4| $) 94) (((-121) $) 90)) (-3767 ((|#4| |#4| $) 85)) (-3045 (((-634 (-2 (|:| |val| |#4|) (|:| -3145 $))) |#4| $) 119)) (-3647 (((-2 (|:| |under| $) (|:| -4115 $) (|:| |upper| $)) $ |#3|) 26)) (-1667 (((-121) $ (-763)) 43)) (-2803 (($ (-1 (-121) |#4|) $) 64 (|has| $ (-6 -4521))) (((-3 |#4| "failed") $ |#3|) 72)) (-4490 (($) 44 T CONST)) (-4382 (((-121) $) 21 (|has| |#1| (-558)))) (-1880 (((-121) $ $) 23 (|has| |#1| (-558)))) (-2536 (((-121) $ $) 22 (|has| |#1| (-558)))) (-2343 (((-121) $) 24 (|has| |#1| (-558)))) (-2941 (((-634 |#4|) (-634 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 86)) (-3993 (((-634 |#4|) (-634 |#4|) $) 17 (|has| |#1| (-558)))) (-2727 (((-634 |#4|) (-634 |#4|) $) 18 (|has| |#1| (-558)))) (-3668 (((-3 $ "failed") (-634 |#4|)) 35)) (-2857 (($ (-634 |#4|)) 34)) (-3936 (((-3 $ "failed") $) 75)) (-3255 ((|#4| |#4| $) 82)) (-3926 (($ $) 67 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521))))) (-4330 (($ |#4| $) 66 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) |#4|) $) 63 (|has| $ (-6 -4521)))) (-2607 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-558)))) (-1359 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) 95)) (-3434 ((|#4| |#4| $) 80)) (-3094 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4521))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4521))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 87)) (-3158 (((-2 (|:| -4094 (-634 |#4|)) (|:| -2133 (-634 |#4|))) $) 98)) (-2451 (((-121) |#4| $) 129)) (-2978 (((-121) |#4| $) 126)) (-1792 (((-121) |#4| $) 130) (((-121) $) 127)) (-3317 (((-634 |#4|) $) 51 (|has| $ (-6 -4521)))) (-3764 (((-121) |#4| $) 97) (((-121) $) 96)) (-4001 ((|#3| $) 33)) (-3791 (((-121) $ (-763)) 42)) (-4406 (((-634 |#4|) $) 52 (|has| $ (-6 -4521)))) (-2551 (((-121) |#4| $) 54 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#4| |#4|) $) 46)) (-2249 (((-634 |#3|) $) 31)) (-1495 (((-121) |#3| $) 30)) (-3796 (((-121) $ (-763)) 41)) (-1893 (((-1143) $) 9)) (-1516 (((-3 |#4| (-634 $)) |#4| |#4| $) 121)) (-3137 (((-634 (-2 (|:| |val| |#4|) (|:| -3145 $))) |#4| |#4| $) 120)) (-4164 (((-3 |#4| "failed") $) 76)) (-3878 (((-634 $) |#4| $) 122)) (-3712 (((-3 (-121) (-634 $)) |#4| $) 125)) (-4266 (((-634 (-2 (|:| |val| (-121)) (|:| -3145 $))) |#4| $) 124) (((-121) |#4| $) 123)) (-1864 (((-634 $) |#4| $) 118) (((-634 $) (-634 |#4|) $) 117) (((-634 $) (-634 |#4|) (-634 $)) 116) (((-634 $) |#4| (-634 $)) 115)) (-3736 (($ |#4| $) 110) (($ (-634 |#4|) $) 109)) (-3882 (((-634 |#4|) $) 100)) (-2157 (((-121) |#4| $) 92) (((-121) $) 88)) (-1315 ((|#4| |#4| $) 83)) (-4342 (((-121) $ $) 103)) (-1440 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-558)))) (-3236 (((-121) |#4| $) 93) (((-121) $) 89)) (-1452 ((|#4| |#4| $) 84)) (-4025 (((-1108) $) 10)) (-3877 (((-3 |#4| "failed") $) 77)) (-2712 (((-3 |#4| "failed") (-1 (-121) |#4|) $) 60)) (-3413 (((-3 $ "failed") $ |#4|) 71)) (-2168 (($ $ |#4|) 70) (((-634 $) |#4| $) 108) (((-634 $) |#4| (-634 $)) 107) (((-634 $) (-634 |#4|) $) 106) (((-634 $) (-634 |#4|) (-634 $)) 105)) (-3951 (((-121) (-1 (-121) |#4|) $) 49 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 |#4|) (-634 |#4|)) 58 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) 56 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 (-288 |#4|))) 55 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-1702 (((-121) $ $) 37)) (-2436 (((-121) $) 40)) (-1990 (($) 39)) (-1836 (((-763) $) 99)) (-4170 (((-763) |#4| $) 53 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521)))) (((-763) (-1 (-121) |#4|) $) 50 (|has| $ (-6 -4521)))) (-3865 (($ $) 38)) (-4280 (((-541) $) 68 (|has| |#4| (-609 (-541))))) (-4289 (($ (-634 |#4|)) 59)) (-3206 (($ $ |#3|) 27)) (-2527 (($ $ |#3|) 29)) (-4392 (($ $) 81)) (-4332 (($ $ |#3|) 28)) (-2747 (((-850) $) 11) (((-634 |#4|) $) 36)) (-2524 (((-763) $) 69 (|has| |#3| (-370)))) (-2835 (((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4| |#4|)) 102) (((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) 101)) (-2145 (((-121) $ (-1 (-121) |#4| (-634 |#4|))) 91)) (-1977 (((-634 $) |#4| $) 114) (((-634 $) |#4| (-634 $)) 113) (((-634 $) (-634 |#4|) $) 112) (((-634 $) (-634 |#4|) (-634 $)) 111)) (-3437 (((-121) (-1 (-121) |#4|) $) 48 (|has| $ (-6 -4521)))) (-3321 (((-634 |#3|) $) 74)) (-3541 (((-121) |#4| $) 128)) (-1413 (((-121) |#3| $) 73)) (-1719 (((-121) $ $) 6)) (-1699 (((-763) $) 45 (|has| $ (-6 -4521))))) 
 (((-1115 |#1| |#2| |#3| |#4|) (-1275) (-453) (-788) (-842) (-1061 |t#1| |t#2| |t#3|)) (T -1115)) 
 NIL 
 (-13 (-1099 |t#1| |t#2| |t#3| |t#4|) (-779 |t#1| |t#2| |t#3| |t#4|)) 
 (((-39) . T) ((-105) . T) ((-608 (-634 |#4|)) . T) ((-608 (-850)) . T) ((-154 |#4|) . T) ((-609 (-541)) |has| |#4| (-609 (-541))) ((-303 |#4|) -12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))) ((-499 |#4|) . T) ((-523 |#4| |#4|) -12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))) ((-779 |#1| |#2| |#3| |#4|) . T) ((-977 |#1| |#2| |#3| |#4|) . T) ((-1066 |#1| |#2| |#3| |#4|) . T) ((-1090) . T) ((-1099 |#1| |#2| |#3| |#4|) . T) ((-1189 |#1| |#2| |#3| |#4|) . T) ((-1195) . T)) 
-((-4351 (((-634 |#2|) |#1|) 12)) (-3040 (((-634 |#2|) |#2| |#2| |#2| |#2| |#2|) 37) (((-634 |#2|) |#1|) 47)) (-2975 (((-634 |#2|) |#2| |#2| |#2|) 35) (((-634 |#2|) |#1|) 45)) (-4314 ((|#2| |#1|) 42)) (-2551 (((-2 (|:| |solns| (-634 |#2|)) (|:| |maps| (-634 (-2 (|:| |arg| |#2|) (|:| |res| |#2|))))) |#1| (-1 |#2| |#2|)) 16)) (-2205 (((-634 |#2|) |#2| |#2|) 34) (((-634 |#2|) |#1|) 44)) (-2475 (((-634 |#2|) |#2| |#2| |#2| |#2|) 36) (((-634 |#2|) |#1|) 46)) (-2567 ((|#2| |#2| |#2| |#2| |#2| |#2|) 41)) (-2974 ((|#2| |#2| |#2| |#2|) 39)) (-3334 ((|#2| |#2| |#2|) 38)) (-1621 ((|#2| |#2| |#2| |#2| |#2|) 40))) 
-(((-1116 |#1| |#2|) (-10 -7 (-15 -4351 ((-634 |#2|) |#1|)) (-15 -4314 (|#2| |#1|)) (-15 -2551 ((-2 (|:| |solns| (-634 |#2|)) (|:| |maps| (-634 (-2 (|:| |arg| |#2|) (|:| |res| |#2|))))) |#1| (-1 |#2| |#2|))) (-15 -2205 ((-634 |#2|) |#1|)) (-15 -2975 ((-634 |#2|) |#1|)) (-15 -2475 ((-634 |#2|) |#1|)) (-15 -3040 ((-634 |#2|) |#1|)) (-15 -2205 ((-634 |#2|) |#2| |#2|)) (-15 -2975 ((-634 |#2|) |#2| |#2| |#2|)) (-15 -2475 ((-634 |#2|) |#2| |#2| |#2| |#2|)) (-15 -3040 ((-634 |#2|) |#2| |#2| |#2| |#2| |#2|)) (-15 -3334 (|#2| |#2| |#2|)) (-15 -2974 (|#2| |#2| |#2| |#2|)) (-15 -1621 (|#2| |#2| |#2| |#2| |#2|)) (-15 -2567 (|#2| |#2| |#2| |#2| |#2| |#2|))) (-1219 |#2|) (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (T -1116)) 
-((-2567 (*1 *2 *2 *2 *2 *2 *2) (-12 (-4 *2 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *1 (-1116 *3 *2)) (-4 *3 (-1219 *2)))) (-1621 (*1 *2 *2 *2 *2 *2) (-12 (-4 *2 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *1 (-1116 *3 *2)) (-4 *3 (-1219 *2)))) (-2974 (*1 *2 *2 *2 *2) (-12 (-4 *2 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *1 (-1116 *3 *2)) (-4 *3 (-1219 *2)))) (-3334 (*1 *2 *2 *2) (-12 (-4 *2 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *1 (-1116 *3 *2)) (-4 *3 (-1219 *2)))) (-3040 (*1 *2 *3 *3 *3 *3 *3) (-12 (-4 *3 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *3)) (-5 *1 (-1116 *4 *3)) (-4 *4 (-1219 *3)))) (-2475 (*1 *2 *3 *3 *3 *3) (-12 (-4 *3 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *3)) (-5 *1 (-1116 *4 *3)) (-4 *4 (-1219 *3)))) (-2975 (*1 *2 *3 *3 *3) (-12 (-4 *3 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *3)) (-5 *1 (-1116 *4 *3)) (-4 *4 (-1219 *3)))) (-2205 (*1 *2 *3 *3) (-12 (-4 *3 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *3)) (-5 *1 (-1116 *4 *3)) (-4 *4 (-1219 *3)))) (-3040 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *4)) (-5 *1 (-1116 *3 *4)) (-4 *3 (-1219 *4)))) (-2475 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *4)) (-5 *1 (-1116 *3 *4)) (-4 *3 (-1219 *4)))) (-2975 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *4)) (-5 *1 (-1116 *3 *4)) (-4 *3 (-1219 *4)))) (-2205 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *4)) (-5 *1 (-1116 *3 *4)) (-4 *3 (-1219 *4)))) (-2551 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *5 *5)) (-4 *5 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-2 (|:| |solns| (-634 *5)) (|:| |maps| (-634 (-2 (|:| |arg| *5) (|:| |res| *5)))))) (-5 *1 (-1116 *3 *5)) (-4 *3 (-1219 *5)))) (-4314 (*1 *2 *3) (-12 (-4 *2 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *1 (-1116 *3 *2)) (-4 *3 (-1219 *2)))) (-4351 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *4)) (-5 *1 (-1116 *3 *4)) (-4 *3 (-1219 *4))))) 
-(-10 -7 (-15 -4351 ((-634 |#2|) |#1|)) (-15 -4314 (|#2| |#1|)) (-15 -2551 ((-2 (|:| |solns| (-634 |#2|)) (|:| |maps| (-634 (-2 (|:| |arg| |#2|) (|:| |res| |#2|))))) |#1| (-1 |#2| |#2|))) (-15 -2205 ((-634 |#2|) |#1|)) (-15 -2975 ((-634 |#2|) |#1|)) (-15 -2475 ((-634 |#2|) |#1|)) (-15 -3040 ((-634 |#2|) |#1|)) (-15 -2205 ((-634 |#2|) |#2| |#2|)) (-15 -2975 ((-634 |#2|) |#2| |#2| |#2|)) (-15 -2475 ((-634 |#2|) |#2| |#2| |#2| |#2|)) (-15 -3040 ((-634 |#2|) |#2| |#2| |#2| |#2| |#2|)) (-15 -3334 (|#2| |#2| |#2|)) (-15 -2974 (|#2| |#2| |#2| |#2|)) (-15 -1621 (|#2| |#2| |#2| |#2| |#2|)) (-15 -2567 (|#2| |#2| |#2| |#2| |#2| |#2|))) 
-((-3599 (((-634 (-634 (-288 (-310 |#1|)))) (-634 (-288 (-409 (-953 |#1|))))) 94) (((-634 (-634 (-288 (-310 |#1|)))) (-634 (-288 (-409 (-953 |#1|)))) (-634 (-1161))) 93) (((-634 (-634 (-288 (-310 |#1|)))) (-634 (-409 (-953 |#1|)))) 91) (((-634 (-634 (-288 (-310 |#1|)))) (-634 (-409 (-953 |#1|))) (-634 (-1161))) 89) (((-634 (-288 (-310 |#1|))) (-288 (-409 (-953 |#1|)))) 75) (((-634 (-288 (-310 |#1|))) (-288 (-409 (-953 |#1|))) (-1161)) 76) (((-634 (-288 (-310 |#1|))) (-409 (-953 |#1|))) 70) (((-634 (-288 (-310 |#1|))) (-409 (-953 |#1|)) (-1161)) 59)) (-2252 (((-634 (-634 (-310 |#1|))) (-634 (-409 (-953 |#1|))) (-634 (-1161))) 87) (((-634 (-310 |#1|)) (-409 (-953 |#1|)) (-1161)) 43)) (-1468 (((-1150 (-634 (-310 |#1|)) (-634 (-288 (-310 |#1|)))) (-409 (-953 |#1|)) (-1161)) 97) (((-1150 (-634 (-310 |#1|)) (-634 (-288 (-310 |#1|)))) (-288 (-409 (-953 |#1|))) (-1161)) 96))) 
-(((-1117 |#1|) (-10 -7 (-15 -3599 ((-634 (-288 (-310 |#1|))) (-409 (-953 |#1|)) (-1161))) (-15 -3599 ((-634 (-288 (-310 |#1|))) (-409 (-953 |#1|)))) (-15 -3599 ((-634 (-288 (-310 |#1|))) (-288 (-409 (-953 |#1|))) (-1161))) (-15 -3599 ((-634 (-288 (-310 |#1|))) (-288 (-409 (-953 |#1|))))) (-15 -3599 ((-634 (-634 (-288 (-310 |#1|)))) (-634 (-409 (-953 |#1|))) (-634 (-1161)))) (-15 -3599 ((-634 (-634 (-288 (-310 |#1|)))) (-634 (-409 (-953 |#1|))))) (-15 -3599 ((-634 (-634 (-288 (-310 |#1|)))) (-634 (-288 (-409 (-953 |#1|)))) (-634 (-1161)))) (-15 -3599 ((-634 (-634 (-288 (-310 |#1|)))) (-634 (-288 (-409 (-953 |#1|)))))) (-15 -2252 ((-634 (-310 |#1|)) (-409 (-953 |#1|)) (-1161))) (-15 -2252 ((-634 (-634 (-310 |#1|))) (-634 (-409 (-953 |#1|))) (-634 (-1161)))) (-15 -1468 ((-1150 (-634 (-310 |#1|)) (-634 (-288 (-310 |#1|)))) (-288 (-409 (-953 |#1|))) (-1161))) (-15 -1468 ((-1150 (-634 (-310 |#1|)) (-634 (-288 (-310 |#1|)))) (-409 (-953 |#1|)) (-1161)))) (-13 (-301) (-842) (-150))) (T -1117)) 
-((-1468 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-1150 (-634 (-310 *5)) (-634 (-288 (-310 *5))))) (-5 *1 (-1117 *5)))) (-1468 (*1 *2 *3 *4) (-12 (-5 *3 (-288 (-409 (-953 *5)))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-1150 (-634 (-310 *5)) (-634 (-288 (-310 *5))))) (-5 *1 (-1117 *5)))) (-2252 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 *5)))) (-5 *4 (-634 (-1161))) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-634 (-310 *5)))) (-5 *1 (-1117 *5)))) (-2252 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-310 *5))) (-5 *1 (-1117 *5)))) (-3599 (*1 *2 *3) (-12 (-5 *3 (-634 (-288 (-409 (-953 *4))))) (-4 *4 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-634 (-288 (-310 *4))))) (-5 *1 (-1117 *4)))) (-3599 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-288 (-409 (-953 *5))))) (-5 *4 (-634 (-1161))) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-634 (-288 (-310 *5))))) (-5 *1 (-1117 *5)))) (-3599 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 *4)))) (-4 *4 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-634 (-288 (-310 *4))))) (-5 *1 (-1117 *4)))) (-3599 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 *5)))) (-5 *4 (-634 (-1161))) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-634 (-288 (-310 *5))))) (-5 *1 (-1117 *5)))) (-3599 (*1 *2 *3) (-12 (-5 *3 (-288 (-409 (-953 *4)))) (-4 *4 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-288 (-310 *4)))) (-5 *1 (-1117 *4)))) (-3599 (*1 *2 *3 *4) (-12 (-5 *3 (-288 (-409 (-953 *5)))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-288 (-310 *5)))) (-5 *1 (-1117 *5)))) (-3599 (*1 *2 *3) (-12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-288 (-310 *4)))) (-5 *1 (-1117 *4)))) (-3599 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-288 (-310 *5)))) (-5 *1 (-1117 *5))))) 
-(-10 -7 (-15 -3599 ((-634 (-288 (-310 |#1|))) (-409 (-953 |#1|)) (-1161))) (-15 -3599 ((-634 (-288 (-310 |#1|))) (-409 (-953 |#1|)))) (-15 -3599 ((-634 (-288 (-310 |#1|))) (-288 (-409 (-953 |#1|))) (-1161))) (-15 -3599 ((-634 (-288 (-310 |#1|))) (-288 (-409 (-953 |#1|))))) (-15 -3599 ((-634 (-634 (-288 (-310 |#1|)))) (-634 (-409 (-953 |#1|))) (-634 (-1161)))) (-15 -3599 ((-634 (-634 (-288 (-310 |#1|)))) (-634 (-409 (-953 |#1|))))) (-15 -3599 ((-634 (-634 (-288 (-310 |#1|)))) (-634 (-288 (-409 (-953 |#1|)))) (-634 (-1161)))) (-15 -3599 ((-634 (-634 (-288 (-310 |#1|)))) (-634 (-288 (-409 (-953 |#1|)))))) (-15 -2252 ((-634 (-310 |#1|)) (-409 (-953 |#1|)) (-1161))) (-15 -2252 ((-634 (-634 (-310 |#1|))) (-634 (-409 (-953 |#1|))) (-634 (-1161)))) (-15 -1468 ((-1150 (-634 (-310 |#1|)) (-634 (-288 (-310 |#1|)))) (-288 (-409 (-953 |#1|))) (-1161))) (-15 -1468 ((-1150 (-634 (-310 |#1|)) (-634 (-288 (-310 |#1|)))) (-409 (-953 |#1|)) (-1161)))) 
-((-1654 (((-409 (-1157 (-310 |#1|))) (-1244 (-310 |#1|)) (-409 (-1157 (-310 |#1|))) (-568)) 27)) (-2827 (((-409 (-1157 (-310 |#1|))) (-409 (-1157 (-310 |#1|))) (-409 (-1157 (-310 |#1|))) (-409 (-1157 (-310 |#1|)))) 39))) 
-(((-1118 |#1|) (-10 -7 (-15 -2827 ((-409 (-1157 (-310 |#1|))) (-409 (-1157 (-310 |#1|))) (-409 (-1157 (-310 |#1|))) (-409 (-1157 (-310 |#1|))))) (-15 -1654 ((-409 (-1157 (-310 |#1|))) (-1244 (-310 |#1|)) (-409 (-1157 (-310 |#1|))) (-568)))) (-13 (-558) (-842))) (T -1118)) 
-((-1654 (*1 *2 *3 *2 *4) (-12 (-5 *2 (-409 (-1157 (-310 *5)))) (-5 *3 (-1244 (-310 *5))) (-5 *4 (-568)) (-4 *5 (-13 (-558) (-842))) (-5 *1 (-1118 *5)))) (-2827 (*1 *2 *2 *2 *2) (-12 (-5 *2 (-409 (-1157 (-310 *3)))) (-4 *3 (-13 (-558) (-842))) (-5 *1 (-1118 *3))))) 
-(-10 -7 (-15 -2827 ((-409 (-1157 (-310 |#1|))) (-409 (-1157 (-310 |#1|))) (-409 (-1157 (-310 |#1|))) (-409 (-1157 (-310 |#1|))))) (-15 -1654 ((-409 (-1157 (-310 |#1|))) (-1244 (-310 |#1|)) (-409 (-1157 (-310 |#1|))) (-568)))) 
-((-4351 (((-634 (-634 (-288 (-310 |#1|)))) (-634 (-288 (-310 |#1|))) (-634 (-1161))) 216) (((-634 (-288 (-310 |#1|))) (-310 |#1|) (-1161)) 20) (((-634 (-288 (-310 |#1|))) (-288 (-310 |#1|)) (-1161)) 26) (((-634 (-288 (-310 |#1|))) (-288 (-310 |#1|))) 25) (((-634 (-288 (-310 |#1|))) (-310 |#1|)) 21))) 
-(((-1119 |#1|) (-10 -7 (-15 -4351 ((-634 (-288 (-310 |#1|))) (-310 |#1|))) (-15 -4351 ((-634 (-288 (-310 |#1|))) (-288 (-310 |#1|)))) (-15 -4351 ((-634 (-288 (-310 |#1|))) (-288 (-310 |#1|)) (-1161))) (-15 -4351 ((-634 (-288 (-310 |#1|))) (-310 |#1|) (-1161))) (-15 -4351 ((-634 (-634 (-288 (-310 |#1|)))) (-634 (-288 (-310 |#1|))) (-634 (-1161))))) (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (T -1119)) 
-((-4351 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-1161))) (-4 *5 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-634 (-288 (-310 *5))))) (-5 *1 (-1119 *5)) (-5 *3 (-634 (-288 (-310 *5)))))) (-4351 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-288 (-310 *5)))) (-5 *1 (-1119 *5)) (-5 *3 (-310 *5)))) (-4351 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-288 (-310 *5)))) (-5 *1 (-1119 *5)) (-5 *3 (-288 (-310 *5))))) (-4351 (*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-288 (-310 *4)))) (-5 *1 (-1119 *4)) (-5 *3 (-288 (-310 *4))))) (-4351 (*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-288 (-310 *4)))) (-5 *1 (-1119 *4)) (-5 *3 (-310 *4))))) 
-(-10 -7 (-15 -4351 ((-634 (-288 (-310 |#1|))) (-310 |#1|))) (-15 -4351 ((-634 (-288 (-310 |#1|))) (-288 (-310 |#1|)))) (-15 -4351 ((-634 (-288 (-310 |#1|))) (-288 (-310 |#1|)) (-1161))) (-15 -4351 ((-634 (-288 (-310 |#1|))) (-310 |#1|) (-1161))) (-15 -4351 ((-634 (-634 (-288 (-310 |#1|)))) (-634 (-288 (-310 |#1|))) (-634 (-1161))))) 
-((-3478 ((|#2| |#2|) 20 (|has| |#1| (-842))) ((|#2| |#2| (-1 (-121) |#1| |#1|)) 16)) (-1334 ((|#2| |#2|) 19 (|has| |#1| (-842))) ((|#2| |#2| (-1 (-121) |#1| |#1|)) 15))) 
-(((-1120 |#1| |#2|) (-10 -7 (-15 -1334 (|#2| |#2| (-1 (-121) |#1| |#1|))) (-15 -3478 (|#2| |#2| (-1 (-121) |#1| |#1|))) (IF (|has| |#1| (-842)) (PROGN (-15 -1334 (|#2| |#2|)) (-15 -3478 (|#2| |#2|))) |noBranch|)) (-1195) (-13 (-601 (-568) |#1|) (-10 -7 (-6 -4519) (-6 -4520)))) (T -1120)) 
-((-3478 (*1 *2 *2) (-12 (-4 *3 (-842)) (-4 *3 (-1195)) (-5 *1 (-1120 *3 *2)) (-4 *2 (-13 (-601 (-568) *3) (-10 -7 (-6 -4519) (-6 -4520)))))) (-1334 (*1 *2 *2) (-12 (-4 *3 (-842)) (-4 *3 (-1195)) (-5 *1 (-1120 *3 *2)) (-4 *2 (-13 (-601 (-568) *3) (-10 -7 (-6 -4519) (-6 -4520)))))) (-3478 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1195)) (-5 *1 (-1120 *4 *2)) (-4 *2 (-13 (-601 (-568) *4) (-10 -7 (-6 -4519) (-6 -4520)))))) (-1334 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1195)) (-5 *1 (-1120 *4 *2)) (-4 *2 (-13 (-601 (-568) *4) (-10 -7 (-6 -4519) (-6 -4520))))))) 
-(-10 -7 (-15 -1334 (|#2| |#2| (-1 (-121) |#1| |#1|))) (-15 -3478 (|#2| |#2| (-1 (-121) |#1| |#1|))) (IF (|has| |#1| (-842)) (PROGN (-15 -1334 (|#2| |#2|)) (-15 -3478 (|#2| |#2|))) |noBranch|)) 
-((-2447 (((-121) $ $) NIL)) (-2141 (((-1149 3 |#1|) $) 105)) (-3672 (((-121) $) 72)) (-3949 (($ $ (-634 (-944 |#1|))) 20) (($ $ (-634 (-634 |#1|))) 75) (($ (-634 (-944 |#1|))) 74) (((-634 (-944 |#1|)) $) 73)) (-2296 (((-121) $) 41)) (-4203 (($ $ (-944 |#1|)) 46) (($ $ (-634 |#1|)) 51) (($ $ (-763)) 53) (($ (-944 |#1|)) 47) (((-944 |#1|) $) 45)) (-1443 (((-2 (|:| -1526 (-763)) (|:| |curves| (-763)) (|:| |polygons| (-763)) (|:| |constructs| (-763))) $) 103)) (-1572 (((-763) $) 26)) (-3900 (((-763) $) 25)) (-1524 (($ $ (-763) (-944 |#1|)) 39)) (-2054 (((-121) $) 82)) (-3713 (($ $ (-634 (-634 (-944 |#1|))) (-634 (-171)) (-171)) 89) (($ $ (-634 (-634 (-634 |#1|))) (-634 (-171)) (-171)) 91) (($ $ (-634 (-634 (-944 |#1|))) (-121) (-121)) 85) (($ $ (-634 (-634 (-634 |#1|))) (-121) (-121)) 93) (($ (-634 (-634 (-944 |#1|)))) 86) (($ (-634 (-634 (-944 |#1|))) (-121) (-121)) 87) (((-634 (-634 (-944 |#1|))) $) 84)) (-1347 (($ (-634 $)) 28) (($ $ $) 29)) (-3049 (((-634 (-171)) $) 101)) (-2386 (((-634 (-944 |#1|)) $) 96)) (-2304 (((-634 (-634 (-171))) $) 100)) (-2626 (((-634 (-634 (-634 (-944 |#1|)))) $) NIL)) (-2417 (((-634 (-634 (-634 (-763)))) $) 98)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-1597 (((-763) $ (-634 (-944 |#1|))) 37)) (-3883 (((-121) $) 54)) (-4430 (($ $ (-634 (-944 |#1|))) 56) (($ $ (-634 (-634 |#1|))) 62) (($ (-634 (-944 |#1|))) 57) (((-634 (-944 |#1|)) $) 55)) (-4132 (($) 23) (($ (-1149 3 |#1|)) 24)) (-3863 (($ $) 35)) (-2697 (((-634 $) $) 34)) (-3950 (($ (-634 $)) 31)) (-1923 (((-634 $) $) 33)) (-2745 (((-850) $) 109)) (-1488 (((-121) $) 64)) (-1984 (($ $ (-634 (-944 |#1|))) 66) (($ $ (-634 (-634 |#1|))) 69) (($ (-634 (-944 |#1|))) 67) (((-634 (-944 |#1|)) $) 65)) (-1644 (($ $) 104)) (-1717 (((-121) $ $) NIL))) 
+((-3259 (((-634 |#2|) |#1|) 12)) (-2225 (((-634 |#2|) |#2| |#2| |#2| |#2| |#2|) 37) (((-634 |#2|) |#1|) 47)) (-3056 (((-634 |#2|) |#2| |#2| |#2|) 35) (((-634 |#2|) |#1|) 45)) (-3075 ((|#2| |#1|) 42)) (-1882 (((-2 (|:| |solns| (-634 |#2|)) (|:| |maps| (-634 (-2 (|:| |arg| |#2|) (|:| |res| |#2|))))) |#1| (-1 |#2| |#2|)) 16)) (-3163 (((-634 |#2|) |#2| |#2|) 34) (((-634 |#2|) |#1|) 44)) (-2643 (((-634 |#2|) |#2| |#2| |#2| |#2|) 36) (((-634 |#2|) |#1|) 46)) (-1952 ((|#2| |#2| |#2| |#2| |#2| |#2|) 41)) (-3053 ((|#2| |#2| |#2| |#2|) 39)) (-4419 ((|#2| |#2| |#2|) 38)) (-1460 ((|#2| |#2| |#2| |#2| |#2|) 40))) 
+(((-1116 |#1| |#2|) (-10 -7 (-15 -3259 ((-634 |#2|) |#1|)) (-15 -3075 (|#2| |#1|)) (-15 -1882 ((-2 (|:| |solns| (-634 |#2|)) (|:| |maps| (-634 (-2 (|:| |arg| |#2|) (|:| |res| |#2|))))) |#1| (-1 |#2| |#2|))) (-15 -3163 ((-634 |#2|) |#1|)) (-15 -3056 ((-634 |#2|) |#1|)) (-15 -2643 ((-634 |#2|) |#1|)) (-15 -2225 ((-634 |#2|) |#1|)) (-15 -3163 ((-634 |#2|) |#2| |#2|)) (-15 -3056 ((-634 |#2|) |#2| |#2| |#2|)) (-15 -2643 ((-634 |#2|) |#2| |#2| |#2| |#2|)) (-15 -2225 ((-634 |#2|) |#2| |#2| |#2| |#2| |#2|)) (-15 -4419 (|#2| |#2| |#2|)) (-15 -3053 (|#2| |#2| |#2| |#2|)) (-15 -1460 (|#2| |#2| |#2| |#2| |#2|)) (-15 -1952 (|#2| |#2| |#2| |#2| |#2| |#2|))) (-1219 |#2|) (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (T -1116)) 
+((-1952 (*1 *2 *2 *2 *2 *2 *2) (-12 (-4 *2 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *1 (-1116 *3 *2)) (-4 *3 (-1219 *2)))) (-1460 (*1 *2 *2 *2 *2 *2) (-12 (-4 *2 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *1 (-1116 *3 *2)) (-4 *3 (-1219 *2)))) (-3053 (*1 *2 *2 *2 *2) (-12 (-4 *2 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *1 (-1116 *3 *2)) (-4 *3 (-1219 *2)))) (-4419 (*1 *2 *2 *2) (-12 (-4 *2 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *1 (-1116 *3 *2)) (-4 *3 (-1219 *2)))) (-2225 (*1 *2 *3 *3 *3 *3 *3) (-12 (-4 *3 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *3)) (-5 *1 (-1116 *4 *3)) (-4 *4 (-1219 *3)))) (-2643 (*1 *2 *3 *3 *3 *3) (-12 (-4 *3 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *3)) (-5 *1 (-1116 *4 *3)) (-4 *4 (-1219 *3)))) (-3056 (*1 *2 *3 *3 *3) (-12 (-4 *3 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *3)) (-5 *1 (-1116 *4 *3)) (-4 *4 (-1219 *3)))) (-3163 (*1 *2 *3 *3) (-12 (-4 *3 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *3)) (-5 *1 (-1116 *4 *3)) (-4 *4 (-1219 *3)))) (-2225 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *4)) (-5 *1 (-1116 *3 *4)) (-4 *3 (-1219 *4)))) (-2643 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *4)) (-5 *1 (-1116 *3 *4)) (-4 *3 (-1219 *4)))) (-3056 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *4)) (-5 *1 (-1116 *3 *4)) (-4 *3 (-1219 *4)))) (-3163 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *4)) (-5 *1 (-1116 *3 *4)) (-4 *3 (-1219 *4)))) (-1882 (*1 *2 *3 *4) (-12 (-5 *4 (-1 *5 *5)) (-4 *5 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-2 (|:| |solns| (-634 *5)) (|:| |maps| (-634 (-2 (|:| |arg| *5) (|:| |res| *5)))))) (-5 *1 (-1116 *3 *5)) (-4 *3 (-1219 *5)))) (-3075 (*1 *2 *3) (-12 (-4 *2 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *1 (-1116 *3 *2)) (-4 *3 (-1219 *2)))) (-3259 (*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *4)) (-5 *1 (-1116 *3 *4)) (-4 *3 (-1219 *4))))) 
+(-10 -7 (-15 -3259 ((-634 |#2|) |#1|)) (-15 -3075 (|#2| |#1|)) (-15 -1882 ((-2 (|:| |solns| (-634 |#2|)) (|:| |maps| (-634 (-2 (|:| |arg| |#2|) (|:| |res| |#2|))))) |#1| (-1 |#2| |#2|))) (-15 -3163 ((-634 |#2|) |#1|)) (-15 -3056 ((-634 |#2|) |#1|)) (-15 -2643 ((-634 |#2|) |#1|)) (-15 -2225 ((-634 |#2|) |#1|)) (-15 -3163 ((-634 |#2|) |#2| |#2|)) (-15 -3056 ((-634 |#2|) |#2| |#2| |#2|)) (-15 -2643 ((-634 |#2|) |#2| |#2| |#2| |#2|)) (-15 -2225 ((-634 |#2|) |#2| |#2| |#2| |#2| |#2|)) (-15 -4419 (|#2| |#2| |#2|)) (-15 -3053 (|#2| |#2| |#2| |#2|)) (-15 -1460 (|#2| |#2| |#2| |#2| |#2|)) (-15 -1952 (|#2| |#2| |#2| |#2| |#2| |#2|))) 
+((-3001 (((-634 (-634 (-288 (-310 |#1|)))) (-634 (-288 (-409 (-953 |#1|))))) 94) (((-634 (-634 (-288 (-310 |#1|)))) (-634 (-288 (-409 (-953 |#1|)))) (-634 (-1161))) 93) (((-634 (-634 (-288 (-310 |#1|)))) (-634 (-409 (-953 |#1|)))) 91) (((-634 (-634 (-288 (-310 |#1|)))) (-634 (-409 (-953 |#1|))) (-634 (-1161))) 89) (((-634 (-288 (-310 |#1|))) (-288 (-409 (-953 |#1|)))) 75) (((-634 (-288 (-310 |#1|))) (-288 (-409 (-953 |#1|))) (-1161)) 76) (((-634 (-288 (-310 |#1|))) (-409 (-953 |#1|))) 70) (((-634 (-288 (-310 |#1|))) (-409 (-953 |#1|)) (-1161)) 59)) (-3279 (((-634 (-634 (-310 |#1|))) (-634 (-409 (-953 |#1|))) (-634 (-1161))) 87) (((-634 (-310 |#1|)) (-409 (-953 |#1|)) (-1161)) 43)) (-2444 (((-1150 (-634 (-310 |#1|)) (-634 (-288 (-310 |#1|)))) (-409 (-953 |#1|)) (-1161)) 97) (((-1150 (-634 (-310 |#1|)) (-634 (-288 (-310 |#1|)))) (-288 (-409 (-953 |#1|))) (-1161)) 96))) 
+(((-1117 |#1|) (-10 -7 (-15 -3001 ((-634 (-288 (-310 |#1|))) (-409 (-953 |#1|)) (-1161))) (-15 -3001 ((-634 (-288 (-310 |#1|))) (-409 (-953 |#1|)))) (-15 -3001 ((-634 (-288 (-310 |#1|))) (-288 (-409 (-953 |#1|))) (-1161))) (-15 -3001 ((-634 (-288 (-310 |#1|))) (-288 (-409 (-953 |#1|))))) (-15 -3001 ((-634 (-634 (-288 (-310 |#1|)))) (-634 (-409 (-953 |#1|))) (-634 (-1161)))) (-15 -3001 ((-634 (-634 (-288 (-310 |#1|)))) (-634 (-409 (-953 |#1|))))) (-15 -3001 ((-634 (-634 (-288 (-310 |#1|)))) (-634 (-288 (-409 (-953 |#1|)))) (-634 (-1161)))) (-15 -3001 ((-634 (-634 (-288 (-310 |#1|)))) (-634 (-288 (-409 (-953 |#1|)))))) (-15 -3279 ((-634 (-310 |#1|)) (-409 (-953 |#1|)) (-1161))) (-15 -3279 ((-634 (-634 (-310 |#1|))) (-634 (-409 (-953 |#1|))) (-634 (-1161)))) (-15 -2444 ((-1150 (-634 (-310 |#1|)) (-634 (-288 (-310 |#1|)))) (-288 (-409 (-953 |#1|))) (-1161))) (-15 -2444 ((-1150 (-634 (-310 |#1|)) (-634 (-288 (-310 |#1|)))) (-409 (-953 |#1|)) (-1161)))) (-13 (-301) (-842) (-150))) (T -1117)) 
+((-2444 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-1150 (-634 (-310 *5)) (-634 (-288 (-310 *5))))) (-5 *1 (-1117 *5)))) (-2444 (*1 *2 *3 *4) (-12 (-5 *3 (-288 (-409 (-953 *5)))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-1150 (-634 (-310 *5)) (-634 (-288 (-310 *5))))) (-5 *1 (-1117 *5)))) (-3279 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 *5)))) (-5 *4 (-634 (-1161))) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-634 (-310 *5)))) (-5 *1 (-1117 *5)))) (-3279 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-310 *5))) (-5 *1 (-1117 *5)))) (-3001 (*1 *2 *3) (-12 (-5 *3 (-634 (-288 (-409 (-953 *4))))) (-4 *4 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-634 (-288 (-310 *4))))) (-5 *1 (-1117 *4)))) (-3001 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-288 (-409 (-953 *5))))) (-5 *4 (-634 (-1161))) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-634 (-288 (-310 *5))))) (-5 *1 (-1117 *5)))) (-3001 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 *4)))) (-4 *4 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-634 (-288 (-310 *4))))) (-5 *1 (-1117 *4)))) (-3001 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 *5)))) (-5 *4 (-634 (-1161))) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-634 (-288 (-310 *5))))) (-5 *1 (-1117 *5)))) (-3001 (*1 *2 *3) (-12 (-5 *3 (-288 (-409 (-953 *4)))) (-4 *4 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-288 (-310 *4)))) (-5 *1 (-1117 *4)))) (-3001 (*1 *2 *3 *4) (-12 (-5 *3 (-288 (-409 (-953 *5)))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-288 (-310 *5)))) (-5 *1 (-1117 *5)))) (-3001 (*1 *2 *3) (-12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-288 (-310 *4)))) (-5 *1 (-1117 *4)))) (-3001 (*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-288 (-310 *5)))) (-5 *1 (-1117 *5))))) 
+(-10 -7 (-15 -3001 ((-634 (-288 (-310 |#1|))) (-409 (-953 |#1|)) (-1161))) (-15 -3001 ((-634 (-288 (-310 |#1|))) (-409 (-953 |#1|)))) (-15 -3001 ((-634 (-288 (-310 |#1|))) (-288 (-409 (-953 |#1|))) (-1161))) (-15 -3001 ((-634 (-288 (-310 |#1|))) (-288 (-409 (-953 |#1|))))) (-15 -3001 ((-634 (-634 (-288 (-310 |#1|)))) (-634 (-409 (-953 |#1|))) (-634 (-1161)))) (-15 -3001 ((-634 (-634 (-288 (-310 |#1|)))) (-634 (-409 (-953 |#1|))))) (-15 -3001 ((-634 (-634 (-288 (-310 |#1|)))) (-634 (-288 (-409 (-953 |#1|)))) (-634 (-1161)))) (-15 -3001 ((-634 (-634 (-288 (-310 |#1|)))) (-634 (-288 (-409 (-953 |#1|)))))) (-15 -3279 ((-634 (-310 |#1|)) (-409 (-953 |#1|)) (-1161))) (-15 -3279 ((-634 (-634 (-310 |#1|))) (-634 (-409 (-953 |#1|))) (-634 (-1161)))) (-15 -2444 ((-1150 (-634 (-310 |#1|)) (-634 (-288 (-310 |#1|)))) (-288 (-409 (-953 |#1|))) (-1161))) (-15 -2444 ((-1150 (-634 (-310 |#1|)) (-634 (-288 (-310 |#1|)))) (-409 (-953 |#1|)) (-1161)))) 
+((-3340 (((-409 (-1157 (-310 |#1|))) (-1244 (-310 |#1|)) (-409 (-1157 (-310 |#1|))) (-568)) 27)) (-3820 (((-409 (-1157 (-310 |#1|))) (-409 (-1157 (-310 |#1|))) (-409 (-1157 (-310 |#1|))) (-409 (-1157 (-310 |#1|)))) 39))) 
+(((-1118 |#1|) (-10 -7 (-15 -3820 ((-409 (-1157 (-310 |#1|))) (-409 (-1157 (-310 |#1|))) (-409 (-1157 (-310 |#1|))) (-409 (-1157 (-310 |#1|))))) (-15 -3340 ((-409 (-1157 (-310 |#1|))) (-1244 (-310 |#1|)) (-409 (-1157 (-310 |#1|))) (-568)))) (-13 (-558) (-842))) (T -1118)) 
+((-3340 (*1 *2 *3 *2 *4) (-12 (-5 *2 (-409 (-1157 (-310 *5)))) (-5 *3 (-1244 (-310 *5))) (-5 *4 (-568)) (-4 *5 (-13 (-558) (-842))) (-5 *1 (-1118 *5)))) (-3820 (*1 *2 *2 *2 *2) (-12 (-5 *2 (-409 (-1157 (-310 *3)))) (-4 *3 (-13 (-558) (-842))) (-5 *1 (-1118 *3))))) 
+(-10 -7 (-15 -3820 ((-409 (-1157 (-310 |#1|))) (-409 (-1157 (-310 |#1|))) (-409 (-1157 (-310 |#1|))) (-409 (-1157 (-310 |#1|))))) (-15 -3340 ((-409 (-1157 (-310 |#1|))) (-1244 (-310 |#1|)) (-409 (-1157 (-310 |#1|))) (-568)))) 
+((-3259 (((-634 (-634 (-288 (-310 |#1|)))) (-634 (-288 (-310 |#1|))) (-634 (-1161))) 216) (((-634 (-288 (-310 |#1|))) (-310 |#1|) (-1161)) 20) (((-634 (-288 (-310 |#1|))) (-288 (-310 |#1|)) (-1161)) 26) (((-634 (-288 (-310 |#1|))) (-288 (-310 |#1|))) 25) (((-634 (-288 (-310 |#1|))) (-310 |#1|)) 21))) 
+(((-1119 |#1|) (-10 -7 (-15 -3259 ((-634 (-288 (-310 |#1|))) (-310 |#1|))) (-15 -3259 ((-634 (-288 (-310 |#1|))) (-288 (-310 |#1|)))) (-15 -3259 ((-634 (-288 (-310 |#1|))) (-288 (-310 |#1|)) (-1161))) (-15 -3259 ((-634 (-288 (-310 |#1|))) (-310 |#1|) (-1161))) (-15 -3259 ((-634 (-634 (-288 (-310 |#1|)))) (-634 (-288 (-310 |#1|))) (-634 (-1161))))) (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (T -1119)) 
+((-3259 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-1161))) (-4 *5 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-634 (-288 (-310 *5))))) (-5 *1 (-1119 *5)) (-5 *3 (-634 (-288 (-310 *5)))))) (-3259 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-288 (-310 *5)))) (-5 *1 (-1119 *5)) (-5 *3 (-310 *5)))) (-3259 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-288 (-310 *5)))) (-5 *1 (-1119 *5)) (-5 *3 (-288 (-310 *5))))) (-3259 (*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-288 (-310 *4)))) (-5 *1 (-1119 *4)) (-5 *3 (-288 (-310 *4))))) (-3259 (*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-288 (-310 *4)))) (-5 *1 (-1119 *4)) (-5 *3 (-310 *4))))) 
+(-10 -7 (-15 -3259 ((-634 (-288 (-310 |#1|))) (-310 |#1|))) (-15 -3259 ((-634 (-288 (-310 |#1|))) (-288 (-310 |#1|)))) (-15 -3259 ((-634 (-288 (-310 |#1|))) (-288 (-310 |#1|)) (-1161))) (-15 -3259 ((-634 (-288 (-310 |#1|))) (-310 |#1|) (-1161))) (-15 -3259 ((-634 (-634 (-288 (-310 |#1|)))) (-634 (-288 (-310 |#1|))) (-634 (-1161))))) 
+((-3765 ((|#2| |#2|) 20 (|has| |#1| (-842))) ((|#2| |#2| (-1 (-121) |#1| |#1|)) 16)) (-3553 ((|#2| |#2|) 19 (|has| |#1| (-842))) ((|#2| |#2| (-1 (-121) |#1| |#1|)) 15))) 
+(((-1120 |#1| |#2|) (-10 -7 (-15 -3553 (|#2| |#2| (-1 (-121) |#1| |#1|))) (-15 -3765 (|#2| |#2| (-1 (-121) |#1| |#1|))) (IF (|has| |#1| (-842)) (PROGN (-15 -3553 (|#2| |#2|)) (-15 -3765 (|#2| |#2|))) |noBranch|)) (-1195) (-13 (-601 (-568) |#1|) (-10 -7 (-6 -4521) (-6 -4522)))) (T -1120)) 
+((-3765 (*1 *2 *2) (-12 (-4 *3 (-842)) (-4 *3 (-1195)) (-5 *1 (-1120 *3 *2)) (-4 *2 (-13 (-601 (-568) *3) (-10 -7 (-6 -4521) (-6 -4522)))))) (-3553 (*1 *2 *2) (-12 (-4 *3 (-842)) (-4 *3 (-1195)) (-5 *1 (-1120 *3 *2)) (-4 *2 (-13 (-601 (-568) *3) (-10 -7 (-6 -4521) (-6 -4522)))))) (-3765 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1195)) (-5 *1 (-1120 *4 *2)) (-4 *2 (-13 (-601 (-568) *4) (-10 -7 (-6 -4521) (-6 -4522)))))) (-3553 (*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1195)) (-5 *1 (-1120 *4 *2)) (-4 *2 (-13 (-601 (-568) *4) (-10 -7 (-6 -4521) (-6 -4522))))))) 
+(-10 -7 (-15 -3553 (|#2| |#2| (-1 (-121) |#1| |#1|))) (-15 -3765 (|#2| |#2| (-1 (-121) |#1| |#1|))) (IF (|has| |#1| (-842)) (PROGN (-15 -3553 (|#2| |#2|)) (-15 -3765 (|#2| |#2|))) |noBranch|)) 
+((-2449 (((-121) $ $) NIL)) (-3503 (((-1149 3 |#1|) $) 105)) (-2248 (((-121) $) 72)) (-4356 (($ $ (-634 (-944 |#1|))) 20) (($ $ (-634 (-634 |#1|))) 75) (($ (-634 (-944 |#1|))) 74) (((-634 (-944 |#1|)) $) 73)) (-3599 (((-121) $) 41)) (-4098 (($ $ (-944 |#1|)) 46) (($ $ (-634 |#1|)) 51) (($ $ (-763)) 53) (($ (-944 |#1|)) 47) (((-944 |#1|) $) 45)) (-2308 (((-2 (|:| -4158 (-763)) (|:| |curves| (-763)) (|:| |polygons| (-763)) (|:| |constructs| (-763))) $) 103)) (-4421 (((-763) $) 26)) (-2066 (((-763) $) 25)) (-4143 (($ $ (-763) (-944 |#1|)) 39)) (-1542 (((-121) $) 82)) (-2437 (($ $ (-634 (-634 (-944 |#1|))) (-634 (-171)) (-171)) 89) (($ $ (-634 (-634 (-634 |#1|))) (-634 (-171)) (-171)) 91) (($ $ (-634 (-634 (-944 |#1|))) (-121) (-121)) 85) (($ $ (-634 (-634 (-634 |#1|))) (-121) (-121)) 93) (($ (-634 (-634 (-944 |#1|)))) 86) (($ (-634 (-634 (-944 |#1|))) (-121) (-121)) 87) (((-634 (-634 (-944 |#1|))) $) 84)) (-3645 (($ (-634 $)) 28) (($ $ $) 29)) (-2264 (((-634 (-171)) $) 101)) (-2207 (((-634 (-944 |#1|)) $) 96)) (-3664 (((-634 (-634 (-171))) $) 100)) (-4236 (((-634 (-634 (-634 (-944 |#1|)))) $) NIL)) (-2364 (((-634 (-634 (-634 (-763)))) $) 98)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-1313 (((-763) $ (-634 (-944 |#1|))) 37)) (-2011 (((-121) $) 54)) (-1615 (($ $ (-634 (-944 |#1|))) 56) (($ $ (-634 (-634 |#1|))) 62) (($ (-634 (-944 |#1|))) 57) (((-634 (-944 |#1|)) $) 55)) (-3716 (($) 23) (($ (-1149 3 |#1|)) 24)) (-3865 (($ $) 35)) (-1400 (((-634 $) $) 34)) (-4363 (($ (-634 $)) 31)) (-4144 (((-634 $) $) 33)) (-2747 (((-850) $) 109)) (-2543 (((-121) $) 64)) (-4427 (($ $ (-634 (-944 |#1|))) 66) (($ $ (-634 (-634 |#1|))) 69) (($ (-634 (-944 |#1|))) 67) (((-634 (-944 |#1|)) $) 65)) (-3270 (($ $) 104)) (-1719 (((-121) $ $) NIL))) 
 (((-1121 |#1|) (-1122 |#1|) (-1047)) (T -1121)) 
 NIL 
 (-1122 |#1|) 
-((-2447 (((-121) $ $) 7)) (-2141 (((-1149 3 |#1|) $) 12)) (-3672 (((-121) $) 28)) (-3949 (($ $ (-634 (-944 |#1|))) 32) (($ $ (-634 (-634 |#1|))) 31) (($ (-634 (-944 |#1|))) 30) (((-634 (-944 |#1|)) $) 29)) (-2296 (((-121) $) 43)) (-4203 (($ $ (-944 |#1|)) 48) (($ $ (-634 |#1|)) 47) (($ $ (-763)) 46) (($ (-944 |#1|)) 45) (((-944 |#1|) $) 44)) (-1443 (((-2 (|:| -1526 (-763)) (|:| |curves| (-763)) (|:| |polygons| (-763)) (|:| |constructs| (-763))) $) 14)) (-1572 (((-763) $) 57)) (-3900 (((-763) $) 58)) (-1524 (($ $ (-763) (-944 |#1|)) 49)) (-2054 (((-121) $) 20)) (-3713 (($ $ (-634 (-634 (-944 |#1|))) (-634 (-171)) (-171)) 27) (($ $ (-634 (-634 (-634 |#1|))) (-634 (-171)) (-171)) 26) (($ $ (-634 (-634 (-944 |#1|))) (-121) (-121)) 25) (($ $ (-634 (-634 (-634 |#1|))) (-121) (-121)) 24) (($ (-634 (-634 (-944 |#1|)))) 23) (($ (-634 (-634 (-944 |#1|))) (-121) (-121)) 22) (((-634 (-634 (-944 |#1|))) $) 21)) (-1347 (($ (-634 $)) 56) (($ $ $) 55)) (-3049 (((-634 (-171)) $) 15)) (-2386 (((-634 (-944 |#1|)) $) 19)) (-2304 (((-634 (-634 (-171))) $) 16)) (-2626 (((-634 (-634 (-634 (-944 |#1|)))) $) 17)) (-2417 (((-634 (-634 (-634 (-763)))) $) 18)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-1597 (((-763) $ (-634 (-944 |#1|))) 50)) (-3883 (((-121) $) 38)) (-4430 (($ $ (-634 (-944 |#1|))) 42) (($ $ (-634 (-634 |#1|))) 41) (($ (-634 (-944 |#1|))) 40) (((-634 (-944 |#1|)) $) 39)) (-4132 (($) 60) (($ (-1149 3 |#1|)) 59)) (-3863 (($ $) 51)) (-2697 (((-634 $) $) 52)) (-3950 (($ (-634 $)) 54)) (-1923 (((-634 $) $) 53)) (-2745 (((-850) $) 11)) (-1488 (((-121) $) 33)) (-1984 (($ $ (-634 (-944 |#1|))) 37) (($ $ (-634 (-634 |#1|))) 36) (($ (-634 (-944 |#1|))) 35) (((-634 (-944 |#1|)) $) 34)) (-1644 (($ $) 13)) (-1717 (((-121) $ $) 6))) 
+((-2449 (((-121) $ $) 7)) (-3503 (((-1149 3 |#1|) $) 12)) (-2248 (((-121) $) 28)) (-4356 (($ $ (-634 (-944 |#1|))) 32) (($ $ (-634 (-634 |#1|))) 31) (($ (-634 (-944 |#1|))) 30) (((-634 (-944 |#1|)) $) 29)) (-3599 (((-121) $) 43)) (-4098 (($ $ (-944 |#1|)) 48) (($ $ (-634 |#1|)) 47) (($ $ (-763)) 46) (($ (-944 |#1|)) 45) (((-944 |#1|) $) 44)) (-2308 (((-2 (|:| -4158 (-763)) (|:| |curves| (-763)) (|:| |polygons| (-763)) (|:| |constructs| (-763))) $) 14)) (-4421 (((-763) $) 57)) (-2066 (((-763) $) 58)) (-4143 (($ $ (-763) (-944 |#1|)) 49)) (-1542 (((-121) $) 20)) (-2437 (($ $ (-634 (-634 (-944 |#1|))) (-634 (-171)) (-171)) 27) (($ $ (-634 (-634 (-634 |#1|))) (-634 (-171)) (-171)) 26) (($ $ (-634 (-634 (-944 |#1|))) (-121) (-121)) 25) (($ $ (-634 (-634 (-634 |#1|))) (-121) (-121)) 24) (($ (-634 (-634 (-944 |#1|)))) 23) (($ (-634 (-634 (-944 |#1|))) (-121) (-121)) 22) (((-634 (-634 (-944 |#1|))) $) 21)) (-3645 (($ (-634 $)) 56) (($ $ $) 55)) (-2264 (((-634 (-171)) $) 15)) (-2207 (((-634 (-944 |#1|)) $) 19)) (-3664 (((-634 (-634 (-171))) $) 16)) (-4236 (((-634 (-634 (-634 (-944 |#1|)))) $) 17)) (-2364 (((-634 (-634 (-634 (-763)))) $) 18)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-1313 (((-763) $ (-634 (-944 |#1|))) 50)) (-2011 (((-121) $) 38)) (-1615 (($ $ (-634 (-944 |#1|))) 42) (($ $ (-634 (-634 |#1|))) 41) (($ (-634 (-944 |#1|))) 40) (((-634 (-944 |#1|)) $) 39)) (-3716 (($) 60) (($ (-1149 3 |#1|)) 59)) (-3865 (($ $) 51)) (-1400 (((-634 $) $) 52)) (-4363 (($ (-634 $)) 54)) (-4144 (((-634 $) $) 53)) (-2747 (((-850) $) 11)) (-2543 (((-121) $) 33)) (-4427 (($ $ (-634 (-944 |#1|))) 37) (($ $ (-634 (-634 |#1|))) 36) (($ (-634 (-944 |#1|))) 35) (((-634 (-944 |#1|)) $) 34)) (-3270 (($ $) 13)) (-1719 (((-121) $ $) 6))) 
 (((-1122 |#1|) (-1275) (-1047)) (T -1122)) 
-((-2745 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-850)))) (-4132 (*1 *1) (-12 (-4 *1 (-1122 *2)) (-4 *2 (-1047)))) (-4132 (*1 *1 *2) (-12 (-5 *2 (-1149 3 *3)) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) (-3900 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-763)))) (-1572 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-763)))) (-1347 (*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) (-1347 (*1 *1 *1 *1) (-12 (-4 *1 (-1122 *2)) (-4 *2 (-1047)))) (-3950 (*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) (-1923 (*1 *2 *1) (-12 (-4 *3 (-1047)) (-5 *2 (-634 *1)) (-4 *1 (-1122 *3)))) (-2697 (*1 *2 *1) (-12 (-4 *3 (-1047)) (-5 *2 (-634 *1)) (-4 *1 (-1122 *3)))) (-3863 (*1 *1 *1) (-12 (-4 *1 (-1122 *2)) (-4 *2 (-1047)))) (-1597 (*1 *2 *1 *3) (-12 (-5 *3 (-634 (-944 *4))) (-4 *1 (-1122 *4)) (-4 *4 (-1047)) (-5 *2 (-763)))) (-1524 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *3 (-944 *4)) (-4 *1 (-1122 *4)) (-4 *4 (-1047)))) (-4203 (*1 *1 *1 *2) (-12 (-5 *2 (-944 *3)) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) (-4203 (*1 *1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) (-4203 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) (-4203 (*1 *1 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) (-4203 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-944 *3)))) (-2296 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-121)))) (-4430 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) (-4430 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) (-4430 (*1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) (-4430 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-944 *3))))) (-3883 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-121)))) (-1984 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) (-1984 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) (-1984 (*1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) (-1984 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-944 *3))))) (-1488 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-121)))) (-3949 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) (-3949 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) (-3949 (*1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) (-3949 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-944 *3))))) (-3672 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-121)))) (-3713 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-634 (-634 (-944 *5)))) (-5 *3 (-634 (-171))) (-5 *4 (-171)) (-4 *1 (-1122 *5)) (-4 *5 (-1047)))) (-3713 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-634 (-634 (-634 *5)))) (-5 *3 (-634 (-171))) (-5 *4 (-171)) (-4 *1 (-1122 *5)) (-4 *5 (-1047)))) (-3713 (*1 *1 *1 *2 *3 *3) (-12 (-5 *2 (-634 (-634 (-944 *4)))) (-5 *3 (-121)) (-4 *1 (-1122 *4)) (-4 *4 (-1047)))) (-3713 (*1 *1 *1 *2 *3 *3) (-12 (-5 *2 (-634 (-634 (-634 *4)))) (-5 *3 (-121)) (-4 *1 (-1122 *4)) (-4 *4 (-1047)))) (-3713 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 (-944 *3)))) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) (-3713 (*1 *1 *2 *3 *3) (-12 (-5 *2 (-634 (-634 (-944 *4)))) (-5 *3 (-121)) (-4 *4 (-1047)) (-4 *1 (-1122 *4)))) (-3713 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-634 (-944 *3)))))) (-2054 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-121)))) (-2386 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-944 *3))))) (-2417 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-634 (-634 (-763))))))) (-2626 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-634 (-634 (-944 *3))))))) (-2304 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-634 (-171)))))) (-3049 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-171))))) (-1443 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -1526 (-763)) (|:| |curves| (-763)) (|:| |polygons| (-763)) (|:| |constructs| (-763)))))) (-1644 (*1 *1 *1) (-12 (-4 *1 (-1122 *2)) (-4 *2 (-1047)))) (-2141 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-1149 3 *3))))) 
-(-13 (-1090) (-10 -8 (-15 -4132 ($)) (-15 -4132 ($ (-1149 3 |t#1|))) (-15 -3900 ((-763) $)) (-15 -1572 ((-763) $)) (-15 -1347 ($ (-634 $))) (-15 -1347 ($ $ $)) (-15 -3950 ($ (-634 $))) (-15 -1923 ((-634 $) $)) (-15 -2697 ((-634 $) $)) (-15 -3863 ($ $)) (-15 -1597 ((-763) $ (-634 (-944 |t#1|)))) (-15 -1524 ($ $ (-763) (-944 |t#1|))) (-15 -4203 ($ $ (-944 |t#1|))) (-15 -4203 ($ $ (-634 |t#1|))) (-15 -4203 ($ $ (-763))) (-15 -4203 ($ (-944 |t#1|))) (-15 -4203 ((-944 |t#1|) $)) (-15 -2296 ((-121) $)) (-15 -4430 ($ $ (-634 (-944 |t#1|)))) (-15 -4430 ($ $ (-634 (-634 |t#1|)))) (-15 -4430 ($ (-634 (-944 |t#1|)))) (-15 -4430 ((-634 (-944 |t#1|)) $)) (-15 -3883 ((-121) $)) (-15 -1984 ($ $ (-634 (-944 |t#1|)))) (-15 -1984 ($ $ (-634 (-634 |t#1|)))) (-15 -1984 ($ (-634 (-944 |t#1|)))) (-15 -1984 ((-634 (-944 |t#1|)) $)) (-15 -1488 ((-121) $)) (-15 -3949 ($ $ (-634 (-944 |t#1|)))) (-15 -3949 ($ $ (-634 (-634 |t#1|)))) (-15 -3949 ($ (-634 (-944 |t#1|)))) (-15 -3949 ((-634 (-944 |t#1|)) $)) (-15 -3672 ((-121) $)) (-15 -3713 ($ $ (-634 (-634 (-944 |t#1|))) (-634 (-171)) (-171))) (-15 -3713 ($ $ (-634 (-634 (-634 |t#1|))) (-634 (-171)) (-171))) (-15 -3713 ($ $ (-634 (-634 (-944 |t#1|))) (-121) (-121))) (-15 -3713 ($ $ (-634 (-634 (-634 |t#1|))) (-121) (-121))) (-15 -3713 ($ (-634 (-634 (-944 |t#1|))))) (-15 -3713 ($ (-634 (-634 (-944 |t#1|))) (-121) (-121))) (-15 -3713 ((-634 (-634 (-944 |t#1|))) $)) (-15 -2054 ((-121) $)) (-15 -2386 ((-634 (-944 |t#1|)) $)) (-15 -2417 ((-634 (-634 (-634 (-763)))) $)) (-15 -2626 ((-634 (-634 (-634 (-944 |t#1|)))) $)) (-15 -2304 ((-634 (-634 (-171))) $)) (-15 -3049 ((-634 (-171)) $)) (-15 -1443 ((-2 (|:| -1526 (-763)) (|:| |curves| (-763)) (|:| |polygons| (-763)) (|:| |constructs| (-763))) $)) (-15 -1644 ($ $)) (-15 -2141 ((-1149 3 |t#1|) $)) (-15 -2745 ((-850) $)))) 
+((-2747 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-850)))) (-3716 (*1 *1) (-12 (-4 *1 (-1122 *2)) (-4 *2 (-1047)))) (-3716 (*1 *1 *2) (-12 (-5 *2 (-1149 3 *3)) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) (-2066 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-763)))) (-4421 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-763)))) (-3645 (*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) (-3645 (*1 *1 *1 *1) (-12 (-4 *1 (-1122 *2)) (-4 *2 (-1047)))) (-4363 (*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) (-4144 (*1 *2 *1) (-12 (-4 *3 (-1047)) (-5 *2 (-634 *1)) (-4 *1 (-1122 *3)))) (-1400 (*1 *2 *1) (-12 (-4 *3 (-1047)) (-5 *2 (-634 *1)) (-4 *1 (-1122 *3)))) (-3865 (*1 *1 *1) (-12 (-4 *1 (-1122 *2)) (-4 *2 (-1047)))) (-1313 (*1 *2 *1 *3) (-12 (-5 *3 (-634 (-944 *4))) (-4 *1 (-1122 *4)) (-4 *4 (-1047)) (-5 *2 (-763)))) (-4143 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *3 (-944 *4)) (-4 *1 (-1122 *4)) (-4 *4 (-1047)))) (-4098 (*1 *1 *1 *2) (-12 (-5 *2 (-944 *3)) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) (-4098 (*1 *1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) (-4098 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) (-4098 (*1 *1 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) (-4098 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-944 *3)))) (-3599 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-121)))) (-1615 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) (-1615 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) (-1615 (*1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) (-1615 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-944 *3))))) (-2011 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-121)))) (-4427 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) (-4427 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) (-4427 (*1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) (-4427 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-944 *3))))) (-2543 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-121)))) (-4356 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) (-4356 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) (-4356 (*1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) (-4356 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-944 *3))))) (-2248 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-121)))) (-2437 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-634 (-634 (-944 *5)))) (-5 *3 (-634 (-171))) (-5 *4 (-171)) (-4 *1 (-1122 *5)) (-4 *5 (-1047)))) (-2437 (*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-634 (-634 (-634 *5)))) (-5 *3 (-634 (-171))) (-5 *4 (-171)) (-4 *1 (-1122 *5)) (-4 *5 (-1047)))) (-2437 (*1 *1 *1 *2 *3 *3) (-12 (-5 *2 (-634 (-634 (-944 *4)))) (-5 *3 (-121)) (-4 *1 (-1122 *4)) (-4 *4 (-1047)))) (-2437 (*1 *1 *1 *2 *3 *3) (-12 (-5 *2 (-634 (-634 (-634 *4)))) (-5 *3 (-121)) (-4 *1 (-1122 *4)) (-4 *4 (-1047)))) (-2437 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 (-944 *3)))) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) (-2437 (*1 *1 *2 *3 *3) (-12 (-5 *2 (-634 (-634 (-944 *4)))) (-5 *3 (-121)) (-4 *4 (-1047)) (-4 *1 (-1122 *4)))) (-2437 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-634 (-944 *3)))))) (-1542 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-121)))) (-2207 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-944 *3))))) (-2364 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-634 (-634 (-763))))))) (-4236 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-634 (-634 (-944 *3))))))) (-3664 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-634 (-171)))))) (-2264 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-171))))) (-2308 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -4158 (-763)) (|:| |curves| (-763)) (|:| |polygons| (-763)) (|:| |constructs| (-763)))))) (-3270 (*1 *1 *1) (-12 (-4 *1 (-1122 *2)) (-4 *2 (-1047)))) (-3503 (*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-1149 3 *3))))) 
+(-13 (-1090) (-10 -8 (-15 -3716 ($)) (-15 -3716 ($ (-1149 3 |t#1|))) (-15 -2066 ((-763) $)) (-15 -4421 ((-763) $)) (-15 -3645 ($ (-634 $))) (-15 -3645 ($ $ $)) (-15 -4363 ($ (-634 $))) (-15 -4144 ((-634 $) $)) (-15 -1400 ((-634 $) $)) (-15 -3865 ($ $)) (-15 -1313 ((-763) $ (-634 (-944 |t#1|)))) (-15 -4143 ($ $ (-763) (-944 |t#1|))) (-15 -4098 ($ $ (-944 |t#1|))) (-15 -4098 ($ $ (-634 |t#1|))) (-15 -4098 ($ $ (-763))) (-15 -4098 ($ (-944 |t#1|))) (-15 -4098 ((-944 |t#1|) $)) (-15 -3599 ((-121) $)) (-15 -1615 ($ $ (-634 (-944 |t#1|)))) (-15 -1615 ($ $ (-634 (-634 |t#1|)))) (-15 -1615 ($ (-634 (-944 |t#1|)))) (-15 -1615 ((-634 (-944 |t#1|)) $)) (-15 -2011 ((-121) $)) (-15 -4427 ($ $ (-634 (-944 |t#1|)))) (-15 -4427 ($ $ (-634 (-634 |t#1|)))) (-15 -4427 ($ (-634 (-944 |t#1|)))) (-15 -4427 ((-634 (-944 |t#1|)) $)) (-15 -2543 ((-121) $)) (-15 -4356 ($ $ (-634 (-944 |t#1|)))) (-15 -4356 ($ $ (-634 (-634 |t#1|)))) (-15 -4356 ($ (-634 (-944 |t#1|)))) (-15 -4356 ((-634 (-944 |t#1|)) $)) (-15 -2248 ((-121) $)) (-15 -2437 ($ $ (-634 (-634 (-944 |t#1|))) (-634 (-171)) (-171))) (-15 -2437 ($ $ (-634 (-634 (-634 |t#1|))) (-634 (-171)) (-171))) (-15 -2437 ($ $ (-634 (-634 (-944 |t#1|))) (-121) (-121))) (-15 -2437 ($ $ (-634 (-634 (-634 |t#1|))) (-121) (-121))) (-15 -2437 ($ (-634 (-634 (-944 |t#1|))))) (-15 -2437 ($ (-634 (-634 (-944 |t#1|))) (-121) (-121))) (-15 -2437 ((-634 (-634 (-944 |t#1|))) $)) (-15 -1542 ((-121) $)) (-15 -2207 ((-634 (-944 |t#1|)) $)) (-15 -2364 ((-634 (-634 (-634 (-763)))) $)) (-15 -4236 ((-634 (-634 (-634 (-944 |t#1|)))) $)) (-15 -3664 ((-634 (-634 (-171))) $)) (-15 -2264 ((-634 (-171)) $)) (-15 -2308 ((-2 (|:| -4158 (-763)) (|:| |curves| (-763)) (|:| |polygons| (-763)) (|:| |constructs| (-763))) $)) (-15 -3270 ($ $)) (-15 -3503 ((-1149 3 |t#1|) $)) (-15 -2747 ((-850) $)))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-3920 (((-1249) (-634 (-850))) 23) (((-1249) (-850)) 22)) (-3071 (((-1249) (-634 (-850))) 21) (((-1249) (-850)) 20)) (-4128 (((-1249) (-634 (-850))) 19) (((-1249) (-850)) 11) (((-1249) (-1143) (-850)) 17))) 
-(((-1123) (-10 -7 (-15 -4128 ((-1249) (-1143) (-850))) (-15 -4128 ((-1249) (-850))) (-15 -3071 ((-1249) (-850))) (-15 -3920 ((-1249) (-850))) (-15 -4128 ((-1249) (-634 (-850)))) (-15 -3071 ((-1249) (-634 (-850)))) (-15 -3920 ((-1249) (-634 (-850)))))) (T -1123)) 
-((-3920 (*1 *2 *3) (-12 (-5 *3 (-634 (-850))) (-5 *2 (-1249)) (-5 *1 (-1123)))) (-3071 (*1 *2 *3) (-12 (-5 *3 (-634 (-850))) (-5 *2 (-1249)) (-5 *1 (-1123)))) (-4128 (*1 *2 *3) (-12 (-5 *3 (-634 (-850))) (-5 *2 (-1249)) (-5 *1 (-1123)))) (-3920 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1249)) (-5 *1 (-1123)))) (-3071 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1249)) (-5 *1 (-1123)))) (-4128 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1249)) (-5 *1 (-1123)))) (-4128 (*1 *2 *3 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-850)) (-5 *2 (-1249)) (-5 *1 (-1123))))) 
-(-10 -7 (-15 -4128 ((-1249) (-1143) (-850))) (-15 -4128 ((-1249) (-850))) (-15 -3071 ((-1249) (-850))) (-15 -3920 ((-1249) (-850))) (-15 -4128 ((-1249) (-634 (-850)))) (-15 -3071 ((-1249) (-634 (-850)))) (-15 -3920 ((-1249) (-634 (-850))))) 
-((-1303 (($ $ $) 10)) (-1847 (($ $) 9)) (-3657 (($ $ $) 13)) (-2375 (($ $ $) 15)) (-1369 (($ $ $) 12)) (-3737 (($ $ $) 14)) (-3828 (($ $) 17)) (-2357 (($ $) 16)) (-2897 (($ $) 6)) (-3929 (($ $ $) 11) (($ $) 7)) (-3792 (($ $ $) 8))) 
+((-2166 (((-1249) (-634 (-850))) 23) (((-1249) (-850)) 22)) (-2365 (((-1249) (-634 (-850))) 21) (((-1249) (-850)) 20)) (-4130 (((-1249) (-634 (-850))) 19) (((-1249) (-850)) 11) (((-1249) (-1143) (-850)) 17))) 
+(((-1123) (-10 -7 (-15 -4130 ((-1249) (-1143) (-850))) (-15 -4130 ((-1249) (-850))) (-15 -2365 ((-1249) (-850))) (-15 -2166 ((-1249) (-850))) (-15 -4130 ((-1249) (-634 (-850)))) (-15 -2365 ((-1249) (-634 (-850)))) (-15 -2166 ((-1249) (-634 (-850)))))) (T -1123)) 
+((-2166 (*1 *2 *3) (-12 (-5 *3 (-634 (-850))) (-5 *2 (-1249)) (-5 *1 (-1123)))) (-2365 (*1 *2 *3) (-12 (-5 *3 (-634 (-850))) (-5 *2 (-1249)) (-5 *1 (-1123)))) (-4130 (*1 *2 *3) (-12 (-5 *3 (-634 (-850))) (-5 *2 (-1249)) (-5 *1 (-1123)))) (-2166 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1249)) (-5 *1 (-1123)))) (-2365 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1249)) (-5 *1 (-1123)))) (-4130 (*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1249)) (-5 *1 (-1123)))) (-4130 (*1 *2 *3 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-850)) (-5 *2 (-1249)) (-5 *1 (-1123))))) 
+(-10 -7 (-15 -4130 ((-1249) (-1143) (-850))) (-15 -4130 ((-1249) (-850))) (-15 -2365 ((-1249) (-850))) (-15 -2166 ((-1249) (-850))) (-15 -4130 ((-1249) (-634 (-850)))) (-15 -2365 ((-1249) (-634 (-850)))) (-15 -2166 ((-1249) (-634 (-850))))) 
+((-3311 (($ $ $) 10)) (-2383 (($ $) 9)) (-3301 (($ $ $) 13)) (-2149 (($ $ $) 15)) (-3826 (($ $ $) 12)) (-2547 (($ $ $) 14)) (-1813 (($ $) 17)) (-4009 (($ $) 16)) (-2811 (($ $) 6)) (-2209 (($ $ $) 11) (($ $) 7)) (-2768 (($ $ $) 8))) 
 (((-1124) (-1275)) (T -1124)) 
-((-3828 (*1 *1 *1) (-4 *1 (-1124))) (-2357 (*1 *1 *1) (-4 *1 (-1124))) (-2375 (*1 *1 *1 *1) (-4 *1 (-1124))) (-3737 (*1 *1 *1 *1) (-4 *1 (-1124))) (-3657 (*1 *1 *1 *1) (-4 *1 (-1124))) (-1369 (*1 *1 *1 *1) (-4 *1 (-1124))) (-3929 (*1 *1 *1 *1) (-4 *1 (-1124))) (-1303 (*1 *1 *1 *1) (-4 *1 (-1124))) (-1847 (*1 *1 *1) (-4 *1 (-1124))) (-3792 (*1 *1 *1 *1) (-4 *1 (-1124))) (-3929 (*1 *1 *1) (-4 *1 (-1124))) (-2897 (*1 *1 *1) (-4 *1 (-1124)))) 
-(-13 (-10 -8 (-15 -2897 ($ $)) (-15 -3929 ($ $)) (-15 -3792 ($ $ $)) (-15 -1847 ($ $)) (-15 -1303 ($ $ $)) (-15 -3929 ($ $ $)) (-15 -1369 ($ $ $)) (-15 -3657 ($ $ $)) (-15 -3737 ($ $ $)) (-15 -2375 ($ $ $)) (-15 -2357 ($ $)) (-15 -3828 ($ $)))) 
-((-2447 (((-121) $ $) 41)) (-2850 ((|#1| $) 15)) (-3800 (((-121) $ $ (-1 (-121) |#2| |#2|)) 36)) (-2812 (((-121) $) 17)) (-3865 (($ $ |#1|) 28)) (-4234 (($ $ (-121)) 30)) (-4334 (($ $) 31)) (-2453 (($ $ |#2|) 29)) (-4487 (((-1143) $) NIL)) (-3912 (((-121) $ $ (-1 (-121) |#1| |#1|) (-1 (-121) |#2| |#2|)) 35)) (-4022 (((-1108) $) NIL)) (-3084 (((-121) $) 14)) (-3248 (($) 10)) (-3863 (($ $) 27)) (-4287 (($ |#1| |#2| (-121)) 18) (($ |#1| |#2|) 19) (($ (-2 (|:| |val| |#1|) (|:| -3001 |#2|))) 21) (((-634 $) (-634 (-2 (|:| |val| |#1|) (|:| -3001 |#2|)))) 24) (((-634 $) |#1| (-634 |#2|)) 26)) (-2213 ((|#2| $) 16)) (-2745 (((-850) $) 50)) (-1717 (((-121) $ $) 39))) 
-(((-1125 |#1| |#2|) (-13 (-1090) (-10 -8 (-15 -3248 ($)) (-15 -3084 ((-121) $)) (-15 -2850 (|#1| $)) (-15 -2213 (|#2| $)) (-15 -2812 ((-121) $)) (-15 -4287 ($ |#1| |#2| (-121))) (-15 -4287 ($ |#1| |#2|)) (-15 -4287 ($ (-2 (|:| |val| |#1|) (|:| -3001 |#2|)))) (-15 -4287 ((-634 $) (-634 (-2 (|:| |val| |#1|) (|:| -3001 |#2|))))) (-15 -4287 ((-634 $) |#1| (-634 |#2|))) (-15 -3863 ($ $)) (-15 -3865 ($ $ |#1|)) (-15 -2453 ($ $ |#2|)) (-15 -4234 ($ $ (-121))) (-15 -4334 ($ $)) (-15 -3912 ((-121) $ $ (-1 (-121) |#1| |#1|) (-1 (-121) |#2| |#2|))) (-15 -3800 ((-121) $ $ (-1 (-121) |#2| |#2|))))) (-13 (-1090) (-39)) (-13 (-1090) (-39))) (T -1125)) 
-((-3248 (*1 *1) (-12 (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) (-3084 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))))) (-2850 (*1 *2 *1) (-12 (-4 *2 (-13 (-1090) (-39))) (-5 *1 (-1125 *2 *3)) (-4 *3 (-13 (-1090) (-39))))) (-2213 (*1 *2 *1) (-12 (-4 *2 (-13 (-1090) (-39))) (-5 *1 (-1125 *3 *2)) (-4 *3 (-13 (-1090) (-39))))) (-2812 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))))) (-4287 (*1 *1 *2 *3 *4) (-12 (-5 *4 (-121)) (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) (-4287 (*1 *1 *2 *3) (-12 (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) (-4287 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |val| *3) (|:| -3001 *4))) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))) (-5 *1 (-1125 *3 *4)))) (-4287 (*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| |val| *4) (|:| -3001 *5)))) (-4 *4 (-13 (-1090) (-39))) (-4 *5 (-13 (-1090) (-39))) (-5 *2 (-634 (-1125 *4 *5))) (-5 *1 (-1125 *4 *5)))) (-4287 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *5)) (-4 *5 (-13 (-1090) (-39))) (-5 *2 (-634 (-1125 *3 *5))) (-5 *1 (-1125 *3 *5)) (-4 *3 (-13 (-1090) (-39))))) (-3863 (*1 *1 *1) (-12 (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) (-3865 (*1 *1 *1 *2) (-12 (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) (-2453 (*1 *1 *1 *2) (-12 (-5 *1 (-1125 *3 *2)) (-4 *3 (-13 (-1090) (-39))) (-4 *2 (-13 (-1090) (-39))))) (-4234 (*1 *1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))))) (-4334 (*1 *1 *1) (-12 (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) (-3912 (*1 *2 *1 *1 *3 *4) (-12 (-5 *3 (-1 (-121) *5 *5)) (-5 *4 (-1 (-121) *6 *6)) (-4 *5 (-13 (-1090) (-39))) (-4 *6 (-13 (-1090) (-39))) (-5 *2 (-121)) (-5 *1 (-1125 *5 *6)))) (-3800 (*1 *2 *1 *1 *3) (-12 (-5 *3 (-1 (-121) *5 *5)) (-4 *5 (-13 (-1090) (-39))) (-5 *2 (-121)) (-5 *1 (-1125 *4 *5)) (-4 *4 (-13 (-1090) (-39)))))) 
-(-13 (-1090) (-10 -8 (-15 -3248 ($)) (-15 -3084 ((-121) $)) (-15 -2850 (|#1| $)) (-15 -2213 (|#2| $)) (-15 -2812 ((-121) $)) (-15 -4287 ($ |#1| |#2| (-121))) (-15 -4287 ($ |#1| |#2|)) (-15 -4287 ($ (-2 (|:| |val| |#1|) (|:| -3001 |#2|)))) (-15 -4287 ((-634 $) (-634 (-2 (|:| |val| |#1|) (|:| -3001 |#2|))))) (-15 -4287 ((-634 $) |#1| (-634 |#2|))) (-15 -3863 ($ $)) (-15 -3865 ($ $ |#1|)) (-15 -2453 ($ $ |#2|)) (-15 -4234 ($ $ (-121))) (-15 -4334 ($ $)) (-15 -3912 ((-121) $ $ (-1 (-121) |#1| |#1|) (-1 (-121) |#2| |#2|))) (-15 -3800 ((-121) $ $ (-1 (-121) |#2| |#2|))))) 
-((-2447 (((-121) $ $) NIL (|has| (-1125 |#1| |#2|) (-1090)))) (-2850 (((-1125 |#1| |#2|) $) 25)) (-1956 (($ $) 75)) (-4115 (((-121) (-1125 |#1| |#2|) $ (-1 (-121) |#2| |#2|)) 84)) (-4109 (($ $ $ (-634 (-1125 |#1| |#2|))) 89) (($ $ $ (-634 (-1125 |#1| |#2|)) (-1 (-121) |#2| |#2|)) 90)) (-2510 (((-121) $ (-763)) NIL)) (-1659 (((-1125 |#1| |#2|) $ (-1125 |#1| |#2|)) 42 (|has| $ (-6 -4520)))) (-2436 (((-1125 |#1| |#2|) $ "value" (-1125 |#1| |#2|)) NIL (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) 40 (|has| $ (-6 -4520)))) (-2671 (($) NIL T CONST)) (-3477 (((-634 (-2 (|:| |val| |#1|) (|:| -3001 |#2|))) $) 79)) (-3405 (($ (-1125 |#1| |#2|) $) 38)) (-4328 (($ (-1125 |#1| |#2|) $) 30)) (-4360 (((-634 (-1125 |#1| |#2|)) $) NIL (|has| $ (-6 -4519)))) (-2287 (((-634 $) $) 50)) (-3166 (((-121) (-1125 |#1| |#2|) $) 81)) (-1700 (((-121) $ $) NIL (|has| (-1125 |#1| |#2|) (-1090)))) (-1737 (((-121) $ (-763)) NIL)) (-1979 (((-634 (-1125 |#1| |#2|)) $) 54 (|has| $ (-6 -4519)))) (-3109 (((-121) (-1125 |#1| |#2|) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-1125 |#1| |#2|) (-1090))))) (-3674 (($ (-1 (-1125 |#1| |#2|) (-1125 |#1| |#2|)) $) 46 (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-1125 |#1| |#2|) (-1125 |#1| |#2|)) $) 45)) (-2166 (((-121) $ (-763)) NIL)) (-2869 (((-634 (-1125 |#1| |#2|)) $) 52)) (-1651 (((-121) $) 41)) (-4487 (((-1143) $) NIL (|has| (-1125 |#1| |#2|) (-1090)))) (-4022 (((-1108) $) NIL (|has| (-1125 |#1| |#2|) (-1090)))) (-3239 (((-3 $ "failed") $) 74)) (-1387 (((-121) (-1 (-121) (-1125 |#1| |#2|)) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-1125 |#1| |#2|)))) NIL (-12 (|has| (-1125 |#1| |#2|) (-303 (-1125 |#1| |#2|))) (|has| (-1125 |#1| |#2|) (-1090)))) (($ $ (-288 (-1125 |#1| |#2|))) NIL (-12 (|has| (-1125 |#1| |#2|) (-303 (-1125 |#1| |#2|))) (|has| (-1125 |#1| |#2|) (-1090)))) (($ $ (-1125 |#1| |#2|) (-1125 |#1| |#2|)) NIL (-12 (|has| (-1125 |#1| |#2|) (-303 (-1125 |#1| |#2|))) (|has| (-1125 |#1| |#2|) (-1090)))) (($ $ (-634 (-1125 |#1| |#2|)) (-634 (-1125 |#1| |#2|))) NIL (-12 (|has| (-1125 |#1| |#2|) (-303 (-1125 |#1| |#2|))) (|has| (-1125 |#1| |#2|) (-1090))))) (-3171 (((-121) $ $) 49)) (-3084 (((-121) $) 22)) (-3248 (($) 24)) (-2779 (((-1125 |#1| |#2|) $ "value") NIL)) (-4075 (((-568) $ $) NIL)) (-3790 (((-121) $) 43)) (-4168 (((-763) (-1 (-121) (-1125 |#1| |#2|)) $) NIL (|has| $ (-6 -4519))) (((-763) (-1125 |#1| |#2|) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-1125 |#1| |#2|) (-1090))))) (-3863 (($ $) 48)) (-4287 (($ (-1125 |#1| |#2|)) 9) (($ |#1| |#2| (-634 $)) 12) (($ |#1| |#2| (-634 (-1125 |#1| |#2|))) 14) (($ |#1| |#2| |#1| (-634 |#2|)) 17)) (-2221 (((-634 |#2|) $) 80)) (-2745 (((-850) $) 72 (|has| (-1125 |#1| |#2|) (-1090)))) (-4339 (((-634 $) $) 28)) (-3491 (((-121) $ $) NIL (|has| (-1125 |#1| |#2|) (-1090)))) (-1319 (((-121) (-1 (-121) (-1125 |#1| |#2|)) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 63 (|has| (-1125 |#1| |#2|) (-1090)))) (-1697 (((-763) $) 57 (|has| $ (-6 -4519))))) 
-(((-1126 |#1| |#2|) (-13 (-1010 (-1125 |#1| |#2|)) (-10 -8 (-6 -4520) (-6 -4519) (-15 -3239 ((-3 $ "failed") $)) (-15 -1956 ($ $)) (-15 -4287 ($ (-1125 |#1| |#2|))) (-15 -4287 ($ |#1| |#2| (-634 $))) (-15 -4287 ($ |#1| |#2| (-634 (-1125 |#1| |#2|)))) (-15 -4287 ($ |#1| |#2| |#1| (-634 |#2|))) (-15 -2221 ((-634 |#2|) $)) (-15 -3477 ((-634 (-2 (|:| |val| |#1|) (|:| -3001 |#2|))) $)) (-15 -3166 ((-121) (-1125 |#1| |#2|) $)) (-15 -4115 ((-121) (-1125 |#1| |#2|) $ (-1 (-121) |#2| |#2|))) (-15 -4328 ($ (-1125 |#1| |#2|) $)) (-15 -3405 ($ (-1125 |#1| |#2|) $)) (-15 -4109 ($ $ $ (-634 (-1125 |#1| |#2|)))) (-15 -4109 ($ $ $ (-634 (-1125 |#1| |#2|)) (-1 (-121) |#2| |#2|))))) (-13 (-1090) (-39)) (-13 (-1090) (-39))) (T -1126)) 
-((-3239 (*1 *1 *1) (|partial| -12 (-5 *1 (-1126 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) (-1956 (*1 *1 *1) (-12 (-5 *1 (-1126 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) (-4287 (*1 *1 *2) (-12 (-5 *2 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))) (-5 *1 (-1126 *3 *4)))) (-4287 (*1 *1 *2 *3 *4) (-12 (-5 *4 (-634 (-1126 *2 *3))) (-5 *1 (-1126 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) (-4287 (*1 *1 *2 *3 *4) (-12 (-5 *4 (-634 (-1125 *2 *3))) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))) (-5 *1 (-1126 *2 *3)))) (-4287 (*1 *1 *2 *3 *2 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-13 (-1090) (-39))) (-5 *1 (-1126 *2 *3)) (-4 *2 (-13 (-1090) (-39))))) (-2221 (*1 *2 *1) (-12 (-5 *2 (-634 *4)) (-5 *1 (-1126 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))))) (-3477 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *4)))) (-5 *1 (-1126 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))))) (-3166 (*1 *2 *3 *1) (-12 (-5 *3 (-1125 *4 *5)) (-4 *4 (-13 (-1090) (-39))) (-4 *5 (-13 (-1090) (-39))) (-5 *2 (-121)) (-5 *1 (-1126 *4 *5)))) (-4115 (*1 *2 *3 *1 *4) (-12 (-5 *3 (-1125 *5 *6)) (-5 *4 (-1 (-121) *6 *6)) (-4 *5 (-13 (-1090) (-39))) (-4 *6 (-13 (-1090) (-39))) (-5 *2 (-121)) (-5 *1 (-1126 *5 *6)))) (-4328 (*1 *1 *2 *1) (-12 (-5 *2 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))) (-5 *1 (-1126 *3 *4)))) (-3405 (*1 *1 *2 *1) (-12 (-5 *2 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))) (-5 *1 (-1126 *3 *4)))) (-4109 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-634 (-1125 *3 *4))) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))) (-5 *1 (-1126 *3 *4)))) (-4109 (*1 *1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1125 *4 *5))) (-5 *3 (-1 (-121) *5 *5)) (-4 *4 (-13 (-1090) (-39))) (-4 *5 (-13 (-1090) (-39))) (-5 *1 (-1126 *4 *5))))) 
-(-13 (-1010 (-1125 |#1| |#2|)) (-10 -8 (-6 -4520) (-6 -4519) (-15 -3239 ((-3 $ "failed") $)) (-15 -1956 ($ $)) (-15 -4287 ($ (-1125 |#1| |#2|))) (-15 -4287 ($ |#1| |#2| (-634 $))) (-15 -4287 ($ |#1| |#2| (-634 (-1125 |#1| |#2|)))) (-15 -4287 ($ |#1| |#2| |#1| (-634 |#2|))) (-15 -2221 ((-634 |#2|) $)) (-15 -3477 ((-634 (-2 (|:| |val| |#1|) (|:| -3001 |#2|))) $)) (-15 -3166 ((-121) (-1125 |#1| |#2|) $)) (-15 -4115 ((-121) (-1125 |#1| |#2|) $ (-1 (-121) |#2| |#2|))) (-15 -4328 ($ (-1125 |#1| |#2|) $)) (-15 -3405 ($ (-1125 |#1| |#2|) $)) (-15 -4109 ($ $ $ (-634 (-1125 |#1| |#2|)))) (-15 -4109 ($ $ $ (-634 (-1125 |#1| |#2|)) (-1 (-121) |#2| |#2|))))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2870 (($ $) NIL)) (-1932 ((|#2| $) NIL)) (-1335 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-3436 (($ (-679 |#2|)) 45)) (-2230 (((-121) $) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-3422 (($ |#2|) 9)) (-2671 (($) NIL T CONST)) (-4167 (($ $) 58 (|has| |#2| (-301)))) (-1818 (((-232 |#1| |#2|) $ (-568)) 31)) (-3666 (((-3 (-568) "failed") $) NIL (|has| |#2| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-3 |#2| "failed") $) NIL)) (-2854 (((-568) $) NIL (|has| |#2| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#2| (-1037 (-409 (-568))))) ((|#2| $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL) (((-679 |#2|) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) 72)) (-3700 (((-763) $) 60 (|has| |#2| (-558)))) (-2602 ((|#2| $ (-568) (-568)) NIL)) (-4360 (((-634 |#2|) $) NIL (|has| $ (-6 -4519)))) (-2735 (((-121) $) NIL)) (-2121 (((-763) $) 62 (|has| |#2| (-558)))) (-4272 (((-634 (-232 |#1| |#2|)) $) 66 (|has| |#2| (-558)))) (-3043 (((-763) $) NIL)) (-2555 (((-763) $) NIL)) (-1737 (((-121) $ (-763)) NIL)) (-3082 ((|#2| $) 56 (|has| |#2| (-6 (-4521 "*"))))) (-2087 (((-568) $) NIL)) (-3364 (((-568) $) NIL)) (-1979 (((-634 |#2|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-1663 (((-568) $) NIL)) (-2893 (((-568) $) NIL)) (-2269 (($ (-634 (-634 |#2|))) 26)) (-3674 (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#2| |#2| |#2|) $ $) NIL) (($ (-1 |#2| |#2|) $) NIL)) (-3208 (((-634 (-634 |#2|)) $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL)) (-3140 (((-3 $ "failed") $) 69 (|has| |#2| (-365)))) (-4022 (((-1108) $) NIL)) (-2595 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-558)))) (-1387 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#2| $ (-568) (-568) |#2|) NIL) ((|#2| $ (-568) (-568)) NIL)) (-4189 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-763)) NIL (|has| |#2| (-225))) (($ $) NIL (|has| |#2| (-225)))) (-3241 ((|#2| $) NIL)) (-2282 (($ (-634 |#2|)) 40)) (-1960 (((-121) $) NIL)) (-3815 (((-232 |#1| |#2|) $) NIL)) (-2465 ((|#2| $) 54 (|has| |#2| (-6 (-4521 "*"))))) (-4168 (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-3863 (($ $) NIL)) (-4278 (((-541) $) 81 (|has| |#2| (-609 (-541))))) (-3731 (((-232 |#1| |#2|) $ (-568)) 33)) (-2745 (((-850) $) 36) (($ (-568)) NIL) (($ (-409 (-568))) NIL (|has| |#2| (-1037 (-409 (-568))))) (($ |#2|) NIL) (((-679 |#2|) $) 42)) (-4078 (((-763)) 17)) (-1319 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-1910 (((-121) $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 11 T CONST)) (-1556 (($) 14 T CONST)) (-3190 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-763)) NIL (|has| |#2| (-225))) (($ $) NIL (|has| |#2| (-225)))) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ |#2|) NIL (|has| |#2| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) 52) (($ $ (-568)) 71 (|has| |#2| (-365)))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) NIL) (((-232 |#1| |#2|) $ (-232 |#1| |#2|)) 48) (((-232 |#1| |#2|) (-232 |#1| |#2|) $) 50)) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-1127 |#1| |#2|) (-13 (-1111 |#1| |#2| (-232 |#1| |#2|) (-232 |#1| |#2|)) (-608 (-679 |#2|)) (-10 -8 (-15 -2870 ($ $)) (-15 -3436 ($ (-679 |#2|))) (-15 -2745 ((-679 |#2|) $)) (IF (|has| |#2| (-6 (-4521 "*"))) (-6 -4508) |noBranch|) (IF (|has| |#2| (-6 (-4521 "*"))) (IF (|has| |#2| (-6 -4516)) (-6 -4516) |noBranch|) |noBranch|) (IF (|has| |#2| (-609 (-541))) (-6 (-609 (-541))) |noBranch|))) (-763) (-1047)) (T -1127)) 
-((-2745 (*1 *2 *1) (-12 (-5 *2 (-679 *4)) (-5 *1 (-1127 *3 *4)) (-14 *3 (-763)) (-4 *4 (-1047)))) (-2870 (*1 *1 *1) (-12 (-5 *1 (-1127 *2 *3)) (-14 *2 (-763)) (-4 *3 (-1047)))) (-3436 (*1 *1 *2) (-12 (-5 *2 (-679 *4)) (-4 *4 (-1047)) (-5 *1 (-1127 *3 *4)) (-14 *3 (-763))))) 
-(-13 (-1111 |#1| |#2| (-232 |#1| |#2|) (-232 |#1| |#2|)) (-608 (-679 |#2|)) (-10 -8 (-15 -2870 ($ $)) (-15 -3436 ($ (-679 |#2|))) (-15 -2745 ((-679 |#2|) $)) (IF (|has| |#2| (-6 (-4521 "*"))) (-6 -4508) |noBranch|) (IF (|has| |#2| (-6 (-4521 "*"))) (IF (|has| |#2| (-6 -4516)) (-6 -4516) |noBranch|) |noBranch|) (IF (|has| |#2| (-609 (-541))) (-6 (-609 (-541))) |noBranch|))) 
-((-2072 (($ $) 19)) (-4403 (($ $ (-147)) 10) (($ $ (-142)) 14)) (-3766 (((-121) $ $) 24)) (-2003 (($ $) 17)) (-2779 (((-147) $ (-568) (-147)) NIL) (((-147) $ (-568)) NIL) (($ $ (-1210 (-568))) NIL) (($ $ $) 29)) (-2745 (($ (-147)) 27) (((-850) $) NIL))) 
-(((-1128 |#1|) (-10 -8 (-15 -2745 ((-850) |#1|)) (-15 -2779 (|#1| |#1| |#1|)) (-15 -4403 (|#1| |#1| (-142))) (-15 -4403 (|#1| |#1| (-147))) (-15 -2745 (|#1| (-147))) (-15 -3766 ((-121) |#1| |#1|)) (-15 -2072 (|#1| |#1|)) (-15 -2003 (|#1| |#1|)) (-15 -2779 (|#1| |#1| (-1210 (-568)))) (-15 -2779 ((-147) |#1| (-568))) (-15 -2779 ((-147) |#1| (-568) (-147)))) (-1129)) (T -1128)) 
-NIL 
-(-10 -8 (-15 -2745 ((-850) |#1|)) (-15 -2779 (|#1| |#1| |#1|)) (-15 -4403 (|#1| |#1| (-142))) (-15 -4403 (|#1| |#1| (-147))) (-15 -2745 (|#1| (-147))) (-15 -3766 ((-121) |#1| |#1|)) (-15 -2072 (|#1| |#1|)) (-15 -2003 (|#1| |#1|)) (-15 -2779 (|#1| |#1| (-1210 (-568)))) (-15 -2779 ((-147) |#1| (-568))) (-15 -2779 ((-147) |#1| (-568) (-147)))) 
-((-2447 (((-121) $ $) 18 (|has| (-147) (-1090)))) (-1873 (($ $) 113)) (-2072 (($ $) 114)) (-4403 (($ $ (-147)) 101) (($ $ (-142)) 100)) (-1868 (((-1249) $ (-568) (-568)) 37 (|has| $ (-6 -4520)))) (-3673 (((-121) $ $) 111)) (-3760 (((-121) $ $ (-568)) 110)) (-3969 (((-634 $) $ (-147)) 103) (((-634 $) $ (-142)) 102)) (-2016 (((-121) (-1 (-121) (-147) (-147)) $) 91) (((-121) $) 85 (|has| (-147) (-842)))) (-3908 (($ (-1 (-121) (-147) (-147)) $) 82 (|has| $ (-6 -4520))) (($ $) 81 (-12 (|has| (-147) (-842)) (|has| $ (-6 -4520))))) (-3644 (($ (-1 (-121) (-147) (-147)) $) 92) (($ $) 86 (|has| (-147) (-842)))) (-2510 (((-121) $ (-763)) 8)) (-2436 (((-147) $ (-568) (-147)) 49 (|has| $ (-6 -4520))) (((-147) $ (-1210 (-568)) (-147)) 53 (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) (-147)) $) 70 (|has| $ (-6 -4519)))) (-2671 (($) 7 T CONST)) (-1869 (($ $ (-147)) 97) (($ $ (-142)) 96)) (-1578 (($ $) 83 (|has| $ (-6 -4520)))) (-3943 (($ $) 93)) (-1386 (($ $ (-1210 (-568)) $) 107)) (-3924 (($ $) 73 (-12 (|has| (-147) (-1090)) (|has| $ (-6 -4519))))) (-4328 (($ (-147) $) 72 (-12 (|has| (-147) (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) (-147)) $) 69 (|has| $ (-6 -4519)))) (-3092 (((-147) (-1 (-147) (-147) (-147)) $ (-147) (-147)) 71 (-12 (|has| (-147) (-1090)) (|has| $ (-6 -4519)))) (((-147) (-1 (-147) (-147) (-147)) $ (-147)) 68 (|has| $ (-6 -4519))) (((-147) (-1 (-147) (-147) (-147)) $) 67 (|has| $ (-6 -4519)))) (-3989 (((-147) $ (-568) (-147)) 50 (|has| $ (-6 -4520)))) (-2602 (((-147) $ (-568)) 48)) (-3766 (((-121) $ $) 112)) (-2764 (((-568) (-1 (-121) (-147)) $) 90) (((-568) (-147) $) 89 (|has| (-147) (-1090))) (((-568) (-147) $ (-568)) 88 (|has| (-147) (-1090))) (((-568) $ $ (-568)) 106) (((-568) (-142) $ (-568)) 105)) (-4360 (((-634 (-147)) $) 30 (|has| $ (-6 -4519)))) (-1849 (($ (-763) (-147)) 64)) (-1737 (((-121) $ (-763)) 9)) (-1881 (((-568) $) 40 (|has| (-568) (-842)))) (-2521 (($ $ $) 80 (|has| (-147) (-842)))) (-1347 (($ (-1 (-121) (-147) (-147)) $ $) 94) (($ $ $) 87 (|has| (-147) (-842)))) (-1979 (((-634 (-147)) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) (-147) $) 27 (-12 (|has| (-147) (-1090)) (|has| $ (-6 -4519))))) (-2223 (((-568) $) 41 (|has| (-568) (-842)))) (-3268 (($ $ $) 79 (|has| (-147) (-842)))) (-4062 (((-121) $ $ (-147)) 108)) (-2661 (((-763) $ $ (-147)) 109)) (-3674 (($ (-1 (-147) (-147)) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-147) (-147)) $) 35) (($ (-1 (-147) (-147) (-147)) $ $) 59)) (-2496 (($ $) 115)) (-2003 (($ $) 116)) (-2166 (((-121) $ (-763)) 10)) (-3382 (($ $ (-147)) 99) (($ $ (-142)) 98)) (-4487 (((-1143) $) 22 (|has| (-147) (-1090)))) (-4122 (($ (-147) $ (-568)) 55) (($ $ $ (-568)) 54)) (-4174 (((-634 (-568)) $) 43)) (-3578 (((-121) (-568) $) 44)) (-4022 (((-1108) $) 21 (|has| (-147) (-1090)))) (-3876 (((-147) $) 39 (|has| (-568) (-842)))) (-3775 (((-3 (-147) "failed") (-1 (-121) (-147)) $) 66)) (-3724 (($ $ (-147)) 38 (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) (-147)) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-147)))) 26 (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-288 (-147))) 25 (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-147) (-147)) 24 (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-634 (-147)) (-634 (-147))) 23 (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090))))) (-3171 (((-121) $ $) 14)) (-4467 (((-121) (-147) $) 42 (-12 (|has| $ (-6 -4519)) (|has| (-147) (-1090))))) (-2041 (((-634 (-147)) $) 45)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 (((-147) $ (-568) (-147)) 47) (((-147) $ (-568)) 46) (($ $ (-1210 (-568))) 58) (($ $ $) 95)) (-2826 (($ $ (-568)) 57) (($ $ (-1210 (-568))) 56)) (-4168 (((-763) (-1 (-121) (-147)) $) 31 (|has| $ (-6 -4519))) (((-763) (-147) $) 28 (-12 (|has| (-147) (-1090)) (|has| $ (-6 -4519))))) (-2256 (($ $ $ (-568)) 84 (|has| $ (-6 -4520)))) (-3863 (($ $) 13)) (-4278 (((-541) $) 74 (|has| (-147) (-609 (-541))))) (-4287 (($ (-634 (-147))) 65)) (-2768 (($ $ (-147)) 63) (($ (-147) $) 62) (($ $ $) 61) (($ (-634 $)) 60)) (-2745 (($ (-147)) 104) (((-850) $) 20 (|has| (-147) (-1090)))) (-1319 (((-121) (-1 (-121) (-147)) $) 33 (|has| $ (-6 -4519)))) (-1751 (((-121) $ $) 77 (|has| (-147) (-842)))) (-1738 (((-121) $ $) 76 (|has| (-147) (-842)))) (-1717 (((-121) $ $) 19 (|has| (-147) (-1090)))) (-1745 (((-121) $ $) 78 (|has| (-147) (-842)))) (-1732 (((-121) $ $) 75 (|has| (-147) (-842)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-1813 (*1 *1 *1) (-4 *1 (-1124))) (-4009 (*1 *1 *1) (-4 *1 (-1124))) (-2149 (*1 *1 *1 *1) (-4 *1 (-1124))) (-2547 (*1 *1 *1 *1) (-4 *1 (-1124))) (-3301 (*1 *1 *1 *1) (-4 *1 (-1124))) (-3826 (*1 *1 *1 *1) (-4 *1 (-1124))) (-2209 (*1 *1 *1 *1) (-4 *1 (-1124))) (-3311 (*1 *1 *1 *1) (-4 *1 (-1124))) (-2383 (*1 *1 *1) (-4 *1 (-1124))) (-2768 (*1 *1 *1 *1) (-4 *1 (-1124))) (-2209 (*1 *1 *1) (-4 *1 (-1124))) (-2811 (*1 *1 *1) (-4 *1 (-1124)))) 
+(-13 (-10 -8 (-15 -2811 ($ $)) (-15 -2209 ($ $)) (-15 -2768 ($ $ $)) (-15 -2383 ($ $)) (-15 -3311 ($ $ $)) (-15 -2209 ($ $ $)) (-15 -3826 ($ $ $)) (-15 -3301 ($ $ $)) (-15 -2547 ($ $ $)) (-15 -2149 ($ $ $)) (-15 -4009 ($ $)) (-15 -1813 ($ $)))) 
+((-2449 (((-121) $ $) 41)) (-2852 ((|#1| $) 15)) (-1686 (((-121) $ $ (-1 (-121) |#2| |#2|)) 36)) (-2814 (((-121) $) 17)) (-1946 (($ $ |#1|) 28)) (-2816 (($ $ (-121)) 30)) (-3154 (($ $) 31)) (-2535 (($ $ |#2|) 29)) (-1893 (((-1143) $) NIL)) (-2126 (((-121) $ $ (-1 (-121) |#1| |#1|) (-1 (-121) |#2| |#2|)) 35)) (-4025 (((-1108) $) NIL)) (-2436 (((-121) $) 14)) (-1990 (($) 10)) (-3865 (($ $) 27)) (-4289 (($ |#1| |#2| (-121)) 18) (($ |#1| |#2|) 19) (($ (-2 (|:| |val| |#1|) (|:| -3145 |#2|))) 21) (((-634 $) (-634 (-2 (|:| |val| |#1|) (|:| -3145 |#2|)))) 24) (((-634 $) |#1| (-634 |#2|)) 26)) (-2215 ((|#2| $) 16)) (-2747 (((-850) $) 50)) (-1719 (((-121) $ $) 39))) 
+(((-1125 |#1| |#2|) (-13 (-1090) (-10 -8 (-15 -1990 ($)) (-15 -2436 ((-121) $)) (-15 -2852 (|#1| $)) (-15 -2215 (|#2| $)) (-15 -2814 ((-121) $)) (-15 -4289 ($ |#1| |#2| (-121))) (-15 -4289 ($ |#1| |#2|)) (-15 -4289 ($ (-2 (|:| |val| |#1|) (|:| -3145 |#2|)))) (-15 -4289 ((-634 $) (-634 (-2 (|:| |val| |#1|) (|:| -3145 |#2|))))) (-15 -4289 ((-634 $) |#1| (-634 |#2|))) (-15 -3865 ($ $)) (-15 -1946 ($ $ |#1|)) (-15 -2535 ($ $ |#2|)) (-15 -2816 ($ $ (-121))) (-15 -3154 ($ $)) (-15 -2126 ((-121) $ $ (-1 (-121) |#1| |#1|) (-1 (-121) |#2| |#2|))) (-15 -1686 ((-121) $ $ (-1 (-121) |#2| |#2|))))) (-13 (-1090) (-39)) (-13 (-1090) (-39))) (T -1125)) 
+((-1990 (*1 *1) (-12 (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) (-2436 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))))) (-2852 (*1 *2 *1) (-12 (-4 *2 (-13 (-1090) (-39))) (-5 *1 (-1125 *2 *3)) (-4 *3 (-13 (-1090) (-39))))) (-2215 (*1 *2 *1) (-12 (-4 *2 (-13 (-1090) (-39))) (-5 *1 (-1125 *3 *2)) (-4 *3 (-13 (-1090) (-39))))) (-2814 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))))) (-4289 (*1 *1 *2 *3 *4) (-12 (-5 *4 (-121)) (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) (-4289 (*1 *1 *2 *3) (-12 (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) (-4289 (*1 *1 *2) (-12 (-5 *2 (-2 (|:| |val| *3) (|:| -3145 *4))) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))) (-5 *1 (-1125 *3 *4)))) (-4289 (*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| |val| *4) (|:| -3145 *5)))) (-4 *4 (-13 (-1090) (-39))) (-4 *5 (-13 (-1090) (-39))) (-5 *2 (-634 (-1125 *4 *5))) (-5 *1 (-1125 *4 *5)))) (-4289 (*1 *2 *3 *4) (-12 (-5 *4 (-634 *5)) (-4 *5 (-13 (-1090) (-39))) (-5 *2 (-634 (-1125 *3 *5))) (-5 *1 (-1125 *3 *5)) (-4 *3 (-13 (-1090) (-39))))) (-3865 (*1 *1 *1) (-12 (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) (-1946 (*1 *1 *1 *2) (-12 (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) (-2535 (*1 *1 *1 *2) (-12 (-5 *1 (-1125 *3 *2)) (-4 *3 (-13 (-1090) (-39))) (-4 *2 (-13 (-1090) (-39))))) (-2816 (*1 *1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))))) (-3154 (*1 *1 *1) (-12 (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) (-2126 (*1 *2 *1 *1 *3 *4) (-12 (-5 *3 (-1 (-121) *5 *5)) (-5 *4 (-1 (-121) *6 *6)) (-4 *5 (-13 (-1090) (-39))) (-4 *6 (-13 (-1090) (-39))) (-5 *2 (-121)) (-5 *1 (-1125 *5 *6)))) (-1686 (*1 *2 *1 *1 *3) (-12 (-5 *3 (-1 (-121) *5 *5)) (-4 *5 (-13 (-1090) (-39))) (-5 *2 (-121)) (-5 *1 (-1125 *4 *5)) (-4 *4 (-13 (-1090) (-39)))))) 
+(-13 (-1090) (-10 -8 (-15 -1990 ($)) (-15 -2436 ((-121) $)) (-15 -2852 (|#1| $)) (-15 -2215 (|#2| $)) (-15 -2814 ((-121) $)) (-15 -4289 ($ |#1| |#2| (-121))) (-15 -4289 ($ |#1| |#2|)) (-15 -4289 ($ (-2 (|:| |val| |#1|) (|:| -3145 |#2|)))) (-15 -4289 ((-634 $) (-634 (-2 (|:| |val| |#1|) (|:| -3145 |#2|))))) (-15 -4289 ((-634 $) |#1| (-634 |#2|))) (-15 -3865 ($ $)) (-15 -1946 ($ $ |#1|)) (-15 -2535 ($ $ |#2|)) (-15 -2816 ($ $ (-121))) (-15 -3154 ($ $)) (-15 -2126 ((-121) $ $ (-1 (-121) |#1| |#1|) (-1 (-121) |#2| |#2|))) (-15 -1686 ((-121) $ $ (-1 (-121) |#2| |#2|))))) 
+((-2449 (((-121) $ $) NIL (|has| (-1125 |#1| |#2|) (-1090)))) (-2852 (((-1125 |#1| |#2|) $) 25)) (-4304 (($ $) 75)) (-3625 (((-121) (-1125 |#1| |#2|) $ (-1 (-121) |#2| |#2|)) 84)) (-3594 (($ $ $ (-634 (-1125 |#1| |#2|))) 89) (($ $ $ (-634 (-1125 |#1| |#2|)) (-1 (-121) |#2| |#2|)) 90)) (-1667 (((-121) $ (-763)) NIL)) (-3370 (((-1125 |#1| |#2|) $ (-1125 |#1| |#2|)) 42 (|has| $ (-6 -4522)))) (-2438 (((-1125 |#1| |#2|) $ "value" (-1125 |#1| |#2|)) NIL (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) 40 (|has| $ (-6 -4522)))) (-4490 (($) NIL T CONST)) (-3759 (((-634 (-2 (|:| |val| |#1|) (|:| -3145 |#2|))) $) 79)) (-1568 (($ (-1125 |#1| |#2|) $) 38)) (-4330 (($ (-1125 |#1| |#2|) $) 30)) (-3317 (((-634 (-1125 |#1| |#2|)) $) NIL (|has| $ (-6 -4521)))) (-3534 (((-634 $) $) 50)) (-1679 (((-121) (-1125 |#1| |#2|) $) 81)) (-3606 (((-121) $ $) NIL (|has| (-1125 |#1| |#2|) (-1090)))) (-3791 (((-121) $ (-763)) NIL)) (-4406 (((-634 (-1125 |#1| |#2|)) $) 54 (|has| $ (-6 -4521)))) (-2551 (((-121) (-1125 |#1| |#2|) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-1125 |#1| |#2|) (-1090))))) (-2253 (($ (-1 (-1125 |#1| |#2|) (-1125 |#1| |#2|)) $) 46 (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-1125 |#1| |#2|) (-1125 |#1| |#2|)) $) 45)) (-3796 (((-121) $ (-763)) NIL)) (-4081 (((-634 (-1125 |#1| |#2|)) $) 52)) (-3319 (((-121) $) 41)) (-1893 (((-1143) $) NIL (|has| (-1125 |#1| |#2|) (-1090)))) (-4025 (((-1108) $) NIL (|has| (-1125 |#1| |#2|) (-1090)))) (-1957 (((-3 $ "failed") $) 74)) (-3951 (((-121) (-1 (-121) (-1125 |#1| |#2|)) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-1125 |#1| |#2|)))) NIL (-12 (|has| (-1125 |#1| |#2|) (-303 (-1125 |#1| |#2|))) (|has| (-1125 |#1| |#2|) (-1090)))) (($ $ (-288 (-1125 |#1| |#2|))) NIL (-12 (|has| (-1125 |#1| |#2|) (-303 (-1125 |#1| |#2|))) (|has| (-1125 |#1| |#2|) (-1090)))) (($ $ (-1125 |#1| |#2|) (-1125 |#1| |#2|)) NIL (-12 (|has| (-1125 |#1| |#2|) (-303 (-1125 |#1| |#2|))) (|has| (-1125 |#1| |#2|) (-1090)))) (($ $ (-634 (-1125 |#1| |#2|)) (-634 (-1125 |#1| |#2|))) NIL (-12 (|has| (-1125 |#1| |#2|) (-303 (-1125 |#1| |#2|))) (|has| (-1125 |#1| |#2|) (-1090))))) (-1702 (((-121) $ $) 49)) (-2436 (((-121) $) 22)) (-1990 (($) 24)) (-2781 (((-1125 |#1| |#2|) $ "value") NIL)) (-1665 (((-568) $ $) NIL)) (-2763 (((-121) $) 43)) (-4170 (((-763) (-1 (-121) (-1125 |#1| |#2|)) $) NIL (|has| $ (-6 -4521))) (((-763) (-1125 |#1| |#2|) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-1125 |#1| |#2|) (-1090))))) (-3865 (($ $) 48)) (-4289 (($ (-1125 |#1| |#2|)) 9) (($ |#1| |#2| (-634 $)) 12) (($ |#1| |#2| (-634 (-1125 |#1| |#2|))) 14) (($ |#1| |#2| |#1| (-634 |#2|)) 17)) (-3482 (((-634 |#2|) $) 80)) (-2747 (((-850) $) 72 (|has| (-1125 |#1| |#2|) (-1090)))) (-3180 (((-634 $) $) 28)) (-3873 (((-121) $ $) NIL (|has| (-1125 |#1| |#2|) (-1090)))) (-3437 (((-121) (-1 (-121) (-1125 |#1| |#2|)) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 63 (|has| (-1125 |#1| |#2|) (-1090)))) (-1699 (((-763) $) 57 (|has| $ (-6 -4521))))) 
+(((-1126 |#1| |#2|) (-13 (-1010 (-1125 |#1| |#2|)) (-10 -8 (-6 -4522) (-6 -4521) (-15 -1957 ((-3 $ "failed") $)) (-15 -4304 ($ $)) (-15 -4289 ($ (-1125 |#1| |#2|))) (-15 -4289 ($ |#1| |#2| (-634 $))) (-15 -4289 ($ |#1| |#2| (-634 (-1125 |#1| |#2|)))) (-15 -4289 ($ |#1| |#2| |#1| (-634 |#2|))) (-15 -3482 ((-634 |#2|) $)) (-15 -3759 ((-634 (-2 (|:| |val| |#1|) (|:| -3145 |#2|))) $)) (-15 -1679 ((-121) (-1125 |#1| |#2|) $)) (-15 -3625 ((-121) (-1125 |#1| |#2|) $ (-1 (-121) |#2| |#2|))) (-15 -4330 ($ (-1125 |#1| |#2|) $)) (-15 -1568 ($ (-1125 |#1| |#2|) $)) (-15 -3594 ($ $ $ (-634 (-1125 |#1| |#2|)))) (-15 -3594 ($ $ $ (-634 (-1125 |#1| |#2|)) (-1 (-121) |#2| |#2|))))) (-13 (-1090) (-39)) (-13 (-1090) (-39))) (T -1126)) 
+((-1957 (*1 *1 *1) (|partial| -12 (-5 *1 (-1126 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) (-4304 (*1 *1 *1) (-12 (-5 *1 (-1126 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) (-4289 (*1 *1 *2) (-12 (-5 *2 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))) (-5 *1 (-1126 *3 *4)))) (-4289 (*1 *1 *2 *3 *4) (-12 (-5 *4 (-634 (-1126 *2 *3))) (-5 *1 (-1126 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) (-4289 (*1 *1 *2 *3 *4) (-12 (-5 *4 (-634 (-1125 *2 *3))) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))) (-5 *1 (-1126 *2 *3)))) (-4289 (*1 *1 *2 *3 *2 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-13 (-1090) (-39))) (-5 *1 (-1126 *2 *3)) (-4 *2 (-13 (-1090) (-39))))) (-3482 (*1 *2 *1) (-12 (-5 *2 (-634 *4)) (-5 *1 (-1126 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))))) (-3759 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *4)))) (-5 *1 (-1126 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))))) (-1679 (*1 *2 *3 *1) (-12 (-5 *3 (-1125 *4 *5)) (-4 *4 (-13 (-1090) (-39))) (-4 *5 (-13 (-1090) (-39))) (-5 *2 (-121)) (-5 *1 (-1126 *4 *5)))) (-3625 (*1 *2 *3 *1 *4) (-12 (-5 *3 (-1125 *5 *6)) (-5 *4 (-1 (-121) *6 *6)) (-4 *5 (-13 (-1090) (-39))) (-4 *6 (-13 (-1090) (-39))) (-5 *2 (-121)) (-5 *1 (-1126 *5 *6)))) (-4330 (*1 *1 *2 *1) (-12 (-5 *2 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))) (-5 *1 (-1126 *3 *4)))) (-1568 (*1 *1 *2 *1) (-12 (-5 *2 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))) (-5 *1 (-1126 *3 *4)))) (-3594 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-634 (-1125 *3 *4))) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))) (-5 *1 (-1126 *3 *4)))) (-3594 (*1 *1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1125 *4 *5))) (-5 *3 (-1 (-121) *5 *5)) (-4 *4 (-13 (-1090) (-39))) (-4 *5 (-13 (-1090) (-39))) (-5 *1 (-1126 *4 *5))))) 
+(-13 (-1010 (-1125 |#1| |#2|)) (-10 -8 (-6 -4522) (-6 -4521) (-15 -1957 ((-3 $ "failed") $)) (-15 -4304 ($ $)) (-15 -4289 ($ (-1125 |#1| |#2|))) (-15 -4289 ($ |#1| |#2| (-634 $))) (-15 -4289 ($ |#1| |#2| (-634 (-1125 |#1| |#2|)))) (-15 -4289 ($ |#1| |#2| |#1| (-634 |#2|))) (-15 -3482 ((-634 |#2|) $)) (-15 -3759 ((-634 (-2 (|:| |val| |#1|) (|:| -3145 |#2|))) $)) (-15 -1679 ((-121) (-1125 |#1| |#2|) $)) (-15 -3625 ((-121) (-1125 |#1| |#2|) $ (-1 (-121) |#2| |#2|))) (-15 -4330 ($ (-1125 |#1| |#2|) $)) (-15 -1568 ($ (-1125 |#1| |#2|) $)) (-15 -3594 ($ $ $ (-634 (-1125 |#1| |#2|)))) (-15 -3594 ($ $ $ (-634 (-1125 |#1| |#2|)) (-1 (-121) |#2| |#2|))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-4089 (($ $) NIL)) (-1934 ((|#2| $) NIL)) (-3560 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3465 (($ (-679 |#2|)) 45)) (-3691 (((-121) $) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-1637 (($ |#2|) 9)) (-4490 (($) NIL T CONST)) (-3912 (($ $) 58 (|has| |#2| (-301)))) (-2228 (((-232 |#1| |#2|) $ (-568)) 31)) (-3668 (((-3 (-568) "failed") $) NIL (|has| |#2| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-3 |#2| "failed") $) NIL)) (-2857 (((-568) $) NIL (|has| |#2| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#2| (-1037 (-409 (-568))))) ((|#2| $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL) (((-679 |#2|) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) 72)) (-2371 (((-763) $) 60 (|has| |#2| (-558)))) (-2069 ((|#2| $ (-568) (-568)) NIL)) (-3317 (((-634 |#2|) $) NIL (|has| $ (-6 -4521)))) (-1598 (((-121) $) NIL)) (-3344 (((-763) $) 62 (|has| |#2| (-558)))) (-2934 (((-634 (-232 |#1| |#2|)) $) 66 (|has| |#2| (-558)))) (-2241 (((-763) $) NIL)) (-1901 (((-763) $) NIL)) (-3791 (((-121) $ (-763)) NIL)) (-2424 ((|#2| $) 56 (|has| |#2| (-6 (-4523 "*"))))) (-3139 (((-568) $) NIL)) (-1343 (((-568) $) NIL)) (-4406 (((-634 |#2|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-3405 (((-568) $) NIL)) (-2801 (((-568) $) NIL)) (-2271 (($ (-634 (-634 |#2|))) 26)) (-2253 (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#2| |#2| |#2|) $ $) NIL) (($ (-1 |#2| |#2|) $) NIL)) (-1843 (((-634 (-634 |#2|)) $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL)) (-2715 (((-3 $ "failed") $) 69 (|has| |#2| (-365)))) (-4025 (((-1108) $) NIL)) (-2597 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-558)))) (-3951 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#2| $ (-568) (-568) |#2|) NIL) ((|#2| $ (-568) (-568)) NIL)) (-4191 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-763)) NIL (|has| |#2| (-225))) (($ $) NIL (|has| |#2| (-225)))) (-1966 ((|#2| $) NIL)) (-3499 (($ (-634 |#2|)) 40)) (-4322 (((-121) $) NIL)) (-1760 (((-232 |#1| |#2|) $) NIL)) (-2591 ((|#2| $) 54 (|has| |#2| (-6 (-4523 "*"))))) (-4170 (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-3865 (($ $) NIL)) (-4280 (((-541) $) 81 (|has| |#2| (-609 (-541))))) (-2522 (((-232 |#1| |#2|) $ (-568)) 33)) (-2747 (((-850) $) 36) (($ (-568)) NIL) (($ (-409 (-568))) NIL (|has| |#2| (-1037 (-409 (-568))))) (($ |#2|) NIL) (((-679 |#2|) $) 42)) (-3425 (((-763)) 17)) (-3437 (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-2675 (((-121) $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 11 T CONST)) (-1557 (($) 14 T CONST)) (-3192 (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-763)) NIL (|has| |#2| (-225))) (($ $) NIL (|has| |#2| (-225)))) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ |#2|) NIL (|has| |#2| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) 52) (($ $ (-568)) 71 (|has| |#2| (-365)))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#2|) NIL) (($ |#2| $) NIL) (((-232 |#1| |#2|) $ (-232 |#1| |#2|)) 48) (((-232 |#1| |#2|) (-232 |#1| |#2|) $) 50)) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-1127 |#1| |#2|) (-13 (-1111 |#1| |#2| (-232 |#1| |#2|) (-232 |#1| |#2|)) (-608 (-679 |#2|)) (-10 -8 (-15 -4089 ($ $)) (-15 -3465 ($ (-679 |#2|))) (-15 -2747 ((-679 |#2|) $)) (IF (|has| |#2| (-6 (-4523 "*"))) (-6 -4510) |noBranch|) (IF (|has| |#2| (-6 (-4523 "*"))) (IF (|has| |#2| (-6 -4518)) (-6 -4518) |noBranch|) |noBranch|) (IF (|has| |#2| (-609 (-541))) (-6 (-609 (-541))) |noBranch|))) (-763) (-1047)) (T -1127)) 
+((-2747 (*1 *2 *1) (-12 (-5 *2 (-679 *4)) (-5 *1 (-1127 *3 *4)) (-14 *3 (-763)) (-4 *4 (-1047)))) (-4089 (*1 *1 *1) (-12 (-5 *1 (-1127 *2 *3)) (-14 *2 (-763)) (-4 *3 (-1047)))) (-3465 (*1 *1 *2) (-12 (-5 *2 (-679 *4)) (-4 *4 (-1047)) (-5 *1 (-1127 *3 *4)) (-14 *3 (-763))))) 
+(-13 (-1111 |#1| |#2| (-232 |#1| |#2|) (-232 |#1| |#2|)) (-608 (-679 |#2|)) (-10 -8 (-15 -4089 ($ $)) (-15 -3465 ($ (-679 |#2|))) (-15 -2747 ((-679 |#2|) $)) (IF (|has| |#2| (-6 (-4523 "*"))) (-6 -4510) |noBranch|) (IF (|has| |#2| (-6 (-4523 "*"))) (IF (|has| |#2| (-6 -4518)) (-6 -4518) |noBranch|) |noBranch|) (IF (|has| |#2| (-609 (-541))) (-6 (-609 (-541))) |noBranch|))) 
+((-3083 (($ $) 19)) (-1474 (($ $ (-147)) 10) (($ $ (-142)) 14)) (-3768 (((-121) $ $) 24)) (-4499 (($ $) 17)) (-2781 (((-147) $ (-568) (-147)) NIL) (((-147) $ (-568)) NIL) (($ $ (-1210 (-568))) NIL) (($ $ $) 29)) (-2747 (($ (-147)) 27) (((-850) $) NIL))) 
+(((-1128 |#1|) (-10 -8 (-15 -2747 ((-850) |#1|)) (-15 -2781 (|#1| |#1| |#1|)) (-15 -1474 (|#1| |#1| (-142))) (-15 -1474 (|#1| |#1| (-147))) (-15 -2747 (|#1| (-147))) (-15 -3768 ((-121) |#1| |#1|)) (-15 -3083 (|#1| |#1|)) (-15 -4499 (|#1| |#1|)) (-15 -2781 (|#1| |#1| (-1210 (-568)))) (-15 -2781 ((-147) |#1| (-568))) (-15 -2781 ((-147) |#1| (-568) (-147)))) (-1129)) (T -1128)) 
+NIL 
+(-10 -8 (-15 -2747 ((-850) |#1|)) (-15 -2781 (|#1| |#1| |#1|)) (-15 -1474 (|#1| |#1| (-142))) (-15 -1474 (|#1| |#1| (-147))) (-15 -2747 (|#1| (-147))) (-15 -3768 ((-121) |#1| |#1|)) (-15 -3083 (|#1| |#1|)) (-15 -4499 (|#1| |#1|)) (-15 -2781 (|#1| |#1| (-1210 (-568)))) (-15 -2781 ((-147) |#1| (-568))) (-15 -2781 ((-147) |#1| (-568) (-147)))) 
+((-2449 (((-121) $ $) 18 (|has| (-147) (-1090)))) (-2499 (($ $) 113)) (-3083 (($ $) 114)) (-1474 (($ $ (-147)) 101) (($ $ (-142)) 100)) (-2481 (((-1249) $ (-568) (-568)) 37 (|has| $ (-6 -4522)))) (-3675 (((-121) $ $) 111)) (-3762 (((-121) $ $ (-568)) 110)) (-4446 (((-634 $) $ (-147)) 103) (((-634 $) $ (-142)) 102)) (-1324 (((-121) (-1 (-121) (-147) (-147)) $) 91) (((-121) $) 85 (|has| (-147) (-842)))) (-2109 (($ (-1 (-121) (-147) (-147)) $) 82 (|has| $ (-6 -4522))) (($ $) 81 (-12 (|has| (-147) (-842)) (|has| $ (-6 -4522))))) (-3647 (($ (-1 (-121) (-147) (-147)) $) 92) (($ $) 86 (|has| (-147) (-842)))) (-1667 (((-121) $ (-763)) 8)) (-2438 (((-147) $ (-568) (-147)) 49 (|has| $ (-6 -4522))) (((-147) $ (-1210 (-568)) (-147)) 53 (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) (-147)) $) 70 (|has| $ (-6 -4521)))) (-4490 (($) 7 T CONST)) (-1871 (($ $ (-147)) 97) (($ $ (-142)) 96)) (-4452 (($ $) 83 (|has| $ (-6 -4522)))) (-3945 (($ $) 93)) (-3943 (($ $ (-1210 (-568)) $) 107)) (-3926 (($ $) 73 (-12 (|has| (-147) (-1090)) (|has| $ (-6 -4521))))) (-4330 (($ (-147) $) 72 (-12 (|has| (-147) (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) (-147)) $) 69 (|has| $ (-6 -4521)))) (-3094 (((-147) (-1 (-147) (-147) (-147)) $ (-147) (-147)) 71 (-12 (|has| (-147) (-1090)) (|has| $ (-6 -4521)))) (((-147) (-1 (-147) (-147) (-147)) $ (-147)) 68 (|has| $ (-6 -4521))) (((-147) (-1 (-147) (-147) (-147)) $) 67 (|has| $ (-6 -4521)))) (-1292 (((-147) $ (-568) (-147)) 50 (|has| $ (-6 -4522)))) (-2069 (((-147) $ (-568)) 48)) (-3768 (((-121) $ $) 112)) (-2766 (((-568) (-1 (-121) (-147)) $) 90) (((-568) (-147) $) 89 (|has| (-147) (-1090))) (((-568) (-147) $ (-568)) 88 (|has| (-147) (-1090))) (((-568) $ $ (-568)) 106) (((-568) (-142) $ (-568)) 105)) (-3317 (((-634 (-147)) $) 30 (|has| $ (-6 -4521)))) (-1851 (($ (-763) (-147)) 64)) (-3791 (((-121) $ (-763)) 9)) (-2539 (((-568) $) 40 (|has| (-568) (-842)))) (-1732 (($ $ $) 80 (|has| (-147) (-842)))) (-3645 (($ (-1 (-121) (-147) (-147)) $ $) 94) (($ $ $) 87 (|has| (-147) (-842)))) (-4406 (((-634 (-147)) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) (-147) $) 27 (-12 (|has| (-147) (-1090)) (|has| $ (-6 -4521))))) (-3631 (((-568) $) 41 (|has| (-568) (-842)))) (-2047 (($ $ $) 79 (|has| (-147) (-842)))) (-4065 (((-121) $ $ (-147)) 108)) (-4439 (((-763) $ $ (-147)) 109)) (-2253 (($ (-1 (-147) (-147)) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-147) (-147)) $) 35) (($ (-1 (-147) (-147) (-147)) $ $) 59)) (-2739 (($ $) 115)) (-4499 (($ $) 116)) (-3796 (((-121) $ (-763)) 10)) (-3384 (($ $ (-147)) 99) (($ $ (-142)) 98)) (-1893 (((-1143) $) 22 (|has| (-147) (-1090)))) (-4124 (($ (-147) $ (-568)) 55) (($ $ $ (-568)) 54)) (-3948 (((-634 (-568)) $) 43)) (-2916 (((-121) (-568) $) 44)) (-4025 (((-1108) $) 21 (|has| (-147) (-1090)))) (-3877 (((-147) $) 39 (|has| (-568) (-842)))) (-2712 (((-3 (-147) "failed") (-1 (-121) (-147)) $) 66)) (-2490 (($ $ (-147)) 38 (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) (-147)) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-147)))) 26 (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-288 (-147))) 25 (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-147) (-147)) 24 (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-634 (-147)) (-634 (-147))) 23 (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090))))) (-1702 (((-121) $ $) 14)) (-1801 (((-121) (-147) $) 42 (-12 (|has| $ (-6 -4521)) (|has| (-147) (-1090))))) (-1480 (((-634 (-147)) $) 45)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 (((-147) $ (-568) (-147)) 47) (((-147) $ (-568)) 46) (($ $ (-1210 (-568))) 58) (($ $ $) 95)) (-2828 (($ $ (-568)) 57) (($ $ (-1210 (-568))) 56)) (-4170 (((-763) (-1 (-121) (-147)) $) 31 (|has| $ (-6 -4521))) (((-763) (-147) $) 28 (-12 (|has| (-147) (-1090)) (|has| $ (-6 -4521))))) (-3306 (($ $ $ (-568)) 84 (|has| $ (-6 -4522)))) (-3865 (($ $) 13)) (-4280 (((-541) $) 74 (|has| (-147) (-609 (-541))))) (-4289 (($ (-634 (-147))) 65)) (-2770 (($ $ (-147)) 63) (($ (-147) $) 62) (($ $ $) 61) (($ (-634 $)) 60)) (-2747 (($ (-147)) 104) (((-850) $) 20 (|has| (-147) (-1090)))) (-3437 (((-121) (-1 (-121) (-147)) $) 33 (|has| $ (-6 -4521)))) (-1753 (((-121) $ $) 77 (|has| (-147) (-842)))) (-1740 (((-121) $ $) 76 (|has| (-147) (-842)))) (-1719 (((-121) $ $) 19 (|has| (-147) (-1090)))) (-1747 (((-121) $ $) 78 (|has| (-147) (-842)))) (-1734 (((-121) $ $) 75 (|has| (-147) (-842)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-1129) (-1275)) (T -1129)) 
-((-2003 (*1 *1 *1) (-4 *1 (-1129))) (-2496 (*1 *1 *1) (-4 *1 (-1129))) (-2072 (*1 *1 *1) (-4 *1 (-1129))) (-1873 (*1 *1 *1) (-4 *1 (-1129))) (-3766 (*1 *2 *1 *1) (-12 (-4 *1 (-1129)) (-5 *2 (-121)))) (-3673 (*1 *2 *1 *1) (-12 (-4 *1 (-1129)) (-5 *2 (-121)))) (-3760 (*1 *2 *1 *1 *3) (-12 (-4 *1 (-1129)) (-5 *3 (-568)) (-5 *2 (-121)))) (-2661 (*1 *2 *1 *1 *3) (-12 (-4 *1 (-1129)) (-5 *3 (-147)) (-5 *2 (-763)))) (-4062 (*1 *2 *1 *1 *3) (-12 (-4 *1 (-1129)) (-5 *3 (-147)) (-5 *2 (-121)))) (-1386 (*1 *1 *1 *2 *1) (-12 (-4 *1 (-1129)) (-5 *2 (-1210 (-568))))) (-2764 (*1 *2 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-568)))) (-2764 (*1 *2 *3 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-568)) (-5 *3 (-142)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-147)) (-4 *1 (-1129)))) (-3969 (*1 *2 *1 *3) (-12 (-5 *3 (-147)) (-5 *2 (-634 *1)) (-4 *1 (-1129)))) (-3969 (*1 *2 *1 *3) (-12 (-5 *3 (-142)) (-5 *2 (-634 *1)) (-4 *1 (-1129)))) (-4403 (*1 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-147)))) (-4403 (*1 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-142)))) (-3382 (*1 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-147)))) (-3382 (*1 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-142)))) (-1869 (*1 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-147)))) (-1869 (*1 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-142)))) (-2779 (*1 *1 *1 *1) (-4 *1 (-1129)))) 
-(-13 (-19 (-147)) (-10 -8 (-15 -2003 ($ $)) (-15 -2496 ($ $)) (-15 -2072 ($ $)) (-15 -1873 ($ $)) (-15 -3766 ((-121) $ $)) (-15 -3673 ((-121) $ $)) (-15 -3760 ((-121) $ $ (-568))) (-15 -2661 ((-763) $ $ (-147))) (-15 -4062 ((-121) $ $ (-147))) (-15 -1386 ($ $ (-1210 (-568)) $)) (-15 -2764 ((-568) $ $ (-568))) (-15 -2764 ((-568) (-142) $ (-568))) (-15 -2745 ($ (-147))) (-15 -3969 ((-634 $) $ (-147))) (-15 -3969 ((-634 $) $ (-142))) (-15 -4403 ($ $ (-147))) (-15 -4403 ($ $ (-142))) (-15 -3382 ($ $ (-147))) (-15 -3382 ($ $ (-142))) (-15 -1869 ($ $ (-147))) (-15 -1869 ($ $ (-142))) (-15 -2779 ($ $ $)))) 
-(((-39) . T) ((-105) -2198 (|has| (-147) (-1090)) (|has| (-147) (-842))) ((-608 (-850)) -2198 (|has| (-147) (-1090)) (|has| (-147) (-842))) ((-154 (-147)) . T) ((-609 (-541)) |has| (-147) (-609 (-541))) ((-281 (-568) (-147)) . T) ((-283 (-568) (-147)) . T) ((-303 (-147)) -12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090))) ((-375 (-147)) . T) ((-499 (-147)) . T) ((-601 (-568) (-147)) . T) ((-523 (-147) (-147)) -12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090))) ((-640 (-147)) . T) ((-19 (-147)) . T) ((-842) |has| (-147) (-842)) ((-1090) -2198 (|has| (-147) (-1090)) (|has| (-147) (-842))) ((-1195) . T)) 
-((-3404 (((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-634 |#4|) (-634 |#5|) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) (-763)) 93)) (-2497 (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5|) 54) (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5| (-763)) 53)) (-1277 (((-1249) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-763)) 85)) (-4032 (((-763) (-634 |#4|) (-634 |#5|)) 27)) (-4475 (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5|) 56) (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5| (-763)) 55) (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5| (-763) (-121)) 57)) (-2847 (((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121) (-121) (-121) (-121)) 76) (((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121)) 77)) (-4278 (((-1143) (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) 80)) (-1677 (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5|) 52)) (-4295 (((-763) (-634 |#4|) (-634 |#5|)) 19))) 
-(((-1130 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -4295 ((-763) (-634 |#4|) (-634 |#5|))) (-15 -4032 ((-763) (-634 |#4|) (-634 |#5|))) (-15 -1677 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5|)) (-15 -2497 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5| (-763))) (-15 -2497 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5|)) (-15 -4475 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5| (-763) (-121))) (-15 -4475 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5| (-763))) (-15 -4475 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5|)) (-15 -2847 ((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121))) (-15 -2847 ((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121) (-121) (-121) (-121))) (-15 -3404 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-634 |#4|) (-634 |#5|) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) (-763))) (-15 -4278 ((-1143) (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|)))) (-15 -1277 ((-1249) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-763)))) (-453) (-788) (-842) (-1061 |#1| |#2| |#3|) (-1099 |#1| |#2| |#3| |#4|)) (T -1130)) 
-((-1277 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-2 (|:| |val| (-634 *8)) (|:| -3001 *9)))) (-5 *4 (-763)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1099 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-1249)) (-5 *1 (-1130 *5 *6 *7 *8 *9)))) (-4278 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |val| (-634 *7)) (|:| -3001 *8))) (-4 *7 (-1061 *4 *5 *6)) (-4 *8 (-1099 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1143)) (-5 *1 (-1130 *4 *5 *6 *7 *8)))) (-3404 (*1 *2 *3 *4 *2 *5 *6) (-12 (-5 *5 (-2 (|:| |done| (-634 *11)) (|:| |todo| (-634 (-2 (|:| |val| *3) (|:| -3001 *11)))))) (-5 *6 (-763)) (-5 *2 (-634 (-2 (|:| |val| (-634 *10)) (|:| -3001 *11)))) (-5 *3 (-634 *10)) (-5 *4 (-634 *11)) (-4 *10 (-1061 *7 *8 *9)) (-4 *11 (-1099 *7 *8 *9 *10)) (-4 *7 (-453)) (-4 *8 (-788)) (-4 *9 (-842)) (-5 *1 (-1130 *7 *8 *9 *10 *11)))) (-2847 (*1 *2 *3 *2 *4 *4 *4 *4 *4) (-12 (-5 *2 (-634 *9)) (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1099 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1130 *5 *6 *7 *8 *9)))) (-2847 (*1 *2 *3 *2 *4 *4) (-12 (-5 *2 (-634 *9)) (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1099 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1130 *5 *6 *7 *8 *9)))) (-4475 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1130 *5 *6 *7 *3 *4)) (-4 *4 (-1099 *5 *6 *7 *3)))) (-4475 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-763)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1130 *6 *7 *8 *3 *4)) (-4 *4 (-1099 *6 *7 *8 *3)))) (-4475 (*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-763)) (-5 *6 (-121)) (-4 *7 (-453)) (-4 *8 (-788)) (-4 *9 (-842)) (-4 *3 (-1061 *7 *8 *9)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1130 *7 *8 *9 *3 *4)) (-4 *4 (-1099 *7 *8 *9 *3)))) (-2497 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1130 *5 *6 *7 *3 *4)) (-4 *4 (-1099 *5 *6 *7 *3)))) (-2497 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-763)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1130 *6 *7 *8 *3 *4)) (-4 *4 (-1099 *6 *7 *8 *3)))) (-1677 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1130 *5 *6 *7 *3 *4)) (-4 *4 (-1099 *5 *6 *7 *3)))) (-4032 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 *9)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1099 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-763)) (-5 *1 (-1130 *5 *6 *7 *8 *9)))) (-4295 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 *9)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1099 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-763)) (-5 *1 (-1130 *5 *6 *7 *8 *9))))) 
-(-10 -7 (-15 -4295 ((-763) (-634 |#4|) (-634 |#5|))) (-15 -4032 ((-763) (-634 |#4|) (-634 |#5|))) (-15 -1677 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5|)) (-15 -2497 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5| (-763))) (-15 -2497 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5|)) (-15 -4475 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5| (-763) (-121))) (-15 -4475 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5| (-763))) (-15 -4475 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) |#4| |#5|)) (-15 -2847 ((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121))) (-15 -2847 ((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121) (-121) (-121) (-121))) (-15 -3404 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-634 |#4|) (-634 |#5|) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))))) (-763))) (-15 -4278 ((-1143) (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|)))) (-15 -1277 ((-1249) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3001 |#5|))) (-763)))) 
-((-2447 (((-121) $ $) NIL)) (-2387 (((-634 (-2 (|:| -4092 $) (|:| -1798 (-634 |#4|)))) (-634 |#4|)) NIL)) (-2415 (((-634 $) (-634 |#4|)) 109) (((-634 $) (-634 |#4|) (-121)) 110) (((-634 $) (-634 |#4|) (-121) (-121)) 108) (((-634 $) (-634 |#4|) (-121) (-121) (-121) (-121)) 111)) (-2055 (((-634 |#3|) $) NIL)) (-4211 (((-121) $) NIL)) (-3824 (((-121) $) NIL (|has| |#1| (-558)))) (-3300 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-2819 ((|#4| |#4| $) NIL)) (-4305 (((-634 (-2 (|:| |val| |#4|) (|:| -3001 $))) |#4| $) 83)) (-3644 (((-2 (|:| |under| $) (|:| -1519 $) (|:| |upper| $)) $ |#3|) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-2801 (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519))) (((-3 |#4| "failed") $ |#3|) 61)) (-2671 (($) NIL T CONST)) (-1565 (((-121) $) 26 (|has| |#1| (-558)))) (-3846 (((-121) $ $) NIL (|has| |#1| (-558)))) (-3106 (((-121) $ $) NIL (|has| |#1| (-558)))) (-3695 (((-121) $) NIL (|has| |#1| (-558)))) (-4275 (((-634 |#4|) (-634 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-2355 (((-634 |#4|) (-634 |#4|) $) NIL (|has| |#1| (-558)))) (-2492 (((-634 |#4|) (-634 |#4|) $) NIL (|has| |#1| (-558)))) (-3666 (((-3 $ "failed") (-634 |#4|)) NIL)) (-2854 (($ (-634 |#4|)) NIL)) (-3935 (((-3 $ "failed") $) 39)) (-2062 ((|#4| |#4| $) 64)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090))))) (-4328 (($ |#4| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090)))) (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-1500 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 77 (|has| |#1| (-558)))) (-1281 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) NIL)) (-4079 ((|#4| |#4| $) NIL)) (-3092 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) NIL (|has| $ (-6 -4519))) ((|#4| (-1 |#4| |#4| |#4|) $) NIL (|has| $ (-6 -4519))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-3635 (((-2 (|:| -4092 (-634 |#4|)) (|:| -1798 (-634 |#4|))) $) NIL)) (-1862 (((-121) |#4| $) NIL)) (-4286 (((-121) |#4| $) NIL)) (-3193 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-1796 (((-2 (|:| |val| (-634 |#4|)) (|:| |towers| (-634 $))) (-634 |#4|) (-121) (-121)) 123)) (-4360 (((-634 |#4|) $) 16 (|has| $ (-6 -4519)))) (-1362 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-2356 ((|#3| $) 33)) (-1737 (((-121) $ (-763)) NIL)) (-1979 (((-634 |#4|) $) 17 (|has| $ (-6 -4519)))) (-3109 (((-121) |#4| $) 25 (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090))))) (-3674 (($ (-1 |#4| |#4|) $) 23 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#4| |#4|) $) 21)) (-1432 (((-634 |#3|) $) NIL)) (-3392 (((-121) |#3| $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL)) (-2717 (((-3 |#4| (-634 $)) |#4| |#4| $) NIL)) (-4330 (((-634 (-2 (|:| |val| |#4|) (|:| -3001 $))) |#4| |#4| $) 102)) (-4162 (((-3 |#4| "failed") $) 37)) (-2335 (((-634 $) |#4| $) 87)) (-1719 (((-3 (-121) (-634 $)) |#4| $) NIL)) (-2632 (((-634 (-2 (|:| |val| (-121)) (|:| -3001 $))) |#4| $) 97) (((-121) |#4| $) 52)) (-3212 (((-634 $) |#4| $) 106) (((-634 $) (-634 |#4|) $) NIL) (((-634 $) (-634 |#4|) (-634 $)) 107) (((-634 $) |#4| (-634 $)) NIL)) (-2099 (((-634 $) (-634 |#4|) (-121) (-121) (-121)) 118)) (-3473 (($ |#4| $) 74) (($ (-634 |#4|) $) 75) (((-634 $) |#4| $ (-121) (-121) (-121) (-121) (-121)) 73)) (-1377 (((-634 |#4|) $) NIL)) (-1415 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-2682 ((|#4| |#4| $) NIL)) (-2644 (((-121) $ $) NIL)) (-2705 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-558)))) (-4347 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-4025 ((|#4| |#4| $) NIL)) (-4022 (((-1108) $) NIL)) (-3876 (((-3 |#4| "failed") $) 35)) (-3775 (((-3 |#4| "failed") (-1 (-121) |#4|) $) NIL)) (-1665 (((-3 $ "failed") $ |#4|) 47)) (-1807 (($ $ |#4|) NIL) (((-634 $) |#4| $) 89) (((-634 $) |#4| (-634 $)) NIL) (((-634 $) (-634 |#4|) $) NIL) (((-634 $) (-634 |#4|) (-634 $)) 85)) (-1387 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 |#4|) (-634 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 (-288 |#4|))) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) 15)) (-3248 (($) 13)) (-3206 (((-763) $) NIL)) (-4168 (((-763) |#4| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090)))) (((-763) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-3863 (($ $) 12)) (-4278 (((-541) $) NIL (|has| |#4| (-609 (-541))))) (-4287 (($ (-634 |#4|)) 20)) (-1290 (($ $ |#3|) 42)) (-3732 (($ $ |#3|) 43)) (-1567 (($ $) NIL)) (-3944 (($ $ |#3|) NIL)) (-2745 (((-850) $) 31) (((-634 |#4|) $) 40)) (-1878 (((-763) $) NIL (|has| |#3| (-370)))) (-3556 (((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4| |#4|)) NIL) (((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-3292 (((-121) $ (-1 (-121) |#4| (-634 |#4|))) NIL)) (-2574 (((-634 $) |#4| $) 53) (((-634 $) |#4| (-634 $)) NIL) (((-634 $) (-634 |#4|) $) NIL) (((-634 $) (-634 |#4|) (-634 $)) NIL)) (-1319 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-2739 (((-634 |#3|) $) NIL)) (-2288 (((-121) |#4| $) NIL)) (-4390 (((-121) |#3| $) 60)) (-1717 (((-121) $ $) NIL)) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-1131 |#1| |#2| |#3| |#4|) (-13 (-1099 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3473 ((-634 $) |#4| $ (-121) (-121) (-121) (-121) (-121))) (-15 -2415 ((-634 $) (-634 |#4|) (-121) (-121))) (-15 -2415 ((-634 $) (-634 |#4|) (-121) (-121) (-121) (-121))) (-15 -2099 ((-634 $) (-634 |#4|) (-121) (-121) (-121))) (-15 -1796 ((-2 (|:| |val| (-634 |#4|)) (|:| |towers| (-634 $))) (-634 |#4|) (-121) (-121))))) (-453) (-788) (-842) (-1061 |#1| |#2| |#3|)) (T -1131)) 
-((-3473 (*1 *2 *3 *1 *4 *4 *4 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1131 *5 *6 *7 *3))) (-5 *1 (-1131 *5 *6 *7 *3)) (-4 *3 (-1061 *5 *6 *7)))) (-2415 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1131 *5 *6 *7 *8))) (-5 *1 (-1131 *5 *6 *7 *8)))) (-2415 (*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1131 *5 *6 *7 *8))) (-5 *1 (-1131 *5 *6 *7 *8)))) (-2099 (*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1131 *5 *6 *7 *8))) (-5 *1 (-1131 *5 *6 *7 *8)))) (-1796 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |val| (-634 *8)) (|:| |towers| (-634 (-1131 *5 *6 *7 *8))))) (-5 *1 (-1131 *5 *6 *7 *8)) (-5 *3 (-634 *8))))) 
-(-13 (-1099 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3473 ((-634 $) |#4| $ (-121) (-121) (-121) (-121) (-121))) (-15 -2415 ((-634 $) (-634 |#4|) (-121) (-121))) (-15 -2415 ((-634 $) (-634 |#4|) (-121) (-121) (-121) (-121))) (-15 -2099 ((-634 $) (-634 |#4|) (-121) (-121) (-121))) (-15 -1796 ((-2 (|:| |val| (-634 |#4|)) (|:| |towers| (-634 $))) (-634 |#4|) (-121) (-121))))) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2616 ((|#1| $) 28)) (-1472 (($ (-634 |#1|)) 33)) (-2510 (((-121) $ (-763)) NIL)) (-2671 (($) NIL T CONST)) (-2918 ((|#1| |#1| $) 30)) (-2899 ((|#1| $) 26)) (-4360 (((-634 |#1|) $) 34 (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) NIL)) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3674 (($ (-1 |#1| |#1|) $) 39 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 37)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-1890 ((|#1| $) 29)) (-4450 (($ |#1| $) 31)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-1315 ((|#1| $) 27)) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) 24)) (-3248 (($) 32)) (-4154 (((-763) $) 22)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) 20)) (-2745 (((-850) $) 17 (|has| |#1| (-1090)))) (-2367 (($ (-634 |#1|)) NIL)) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 12 (|has| |#1| (-1090)))) (-1697 (((-763) $) 23 (|has| $ (-6 -4519))))) 
-(((-1132 |#1|) (-13 (-1109 |#1|) (-10 -8 (-15 -1472 ($ (-634 |#1|))) (-15 -2899 (|#1| $)) (-15 -1315 (|#1| $)) (-15 -2918 (|#1| |#1| $)) (-15 -4450 ($ |#1| $)) (-15 -1890 (|#1| $)) (-15 -2616 (|#1| $)) (-15 -4154 ((-763) $)) (-15 -2166 ((-121) $ (-763))) (-15 -1737 ((-121) $ (-763))) (-15 -2510 ((-121) $ (-763))) (-15 -2367 ($ (-634 |#1|))) (-15 -3084 ((-121) $)) (-15 -3248 ($)) (-15 -2671 ($)) (-15 -3863 ($ $)) (-15 -3171 ((-121) $ $)) (-15 -2795 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4520)) (-15 -3674 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-15 -4487 ((-1143) $)) (-15 -4022 ((-1108) $)) (-15 -2745 ((-850) $)) (-15 -1717 ((-121) $ $)) (-15 -2447 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4519)) (PROGN (-15 -1387 ((-121) (-1 (-121) |#1|) $)) (-15 -1319 ((-121) (-1 (-121) |#1|) $)) (-15 -4168 ((-763) (-1 (-121) |#1|) $)) (-15 -1697 ((-763) $)) (-15 -4360 ((-634 |#1|) $)) (-15 -1979 ((-634 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4519)) (IF (|has| |#1| (-1090)) (PROGN (-15 -3109 ((-121) |#1| $)) (-15 -4168 ((-763) |#1| $))) |noBranch|) |noBranch|))) (-1090)) (T -1132)) 
-((-3171 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)))) (-3863 (*1 *1 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) (-3248 (*1 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) (-3084 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)))) (-2166 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1132 *4)) (-4 *4 (-1090)))) (-1737 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1132 *4)) (-4 *4 (-1090)))) (-2510 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1132 *4)) (-4 *4 (-1090)))) (-2671 (*1 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) (-1697 (*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-763)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)))) (-2795 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-1132 *3)))) (-3674 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4520)) (-4 *3 (-1090)) (-5 *1 (-1132 *3)))) (-1319 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-1132 *4)))) (-1387 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-1132 *4)))) (-4168 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-763)) (-5 *1 (-1132 *4)))) (-4360 (*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-634 *3)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)))) (-1979 (*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-634 *3)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)))) (-4168 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-763)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-3109 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-121)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-4487 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-4022 (*1 *2 *1) (-12 (-5 *2 (-1108)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-1717 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2447 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2367 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-1132 *3)))) (-1315 (*1 *2 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) (-4450 (*1 *1 *2 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) (-1890 (*1 *2 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) (-2918 (*1 *2 *2 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) (-2899 (*1 *2 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) (-2616 (*1 *2 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) (-4154 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)))) (-1472 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-1132 *3))))) 
-(-13 (-1109 |#1|) (-10 -8 (-15 -1472 ($ (-634 |#1|))) (-15 -2899 (|#1| $)) (-15 -1315 (|#1| $)) (-15 -2918 (|#1| |#1| $)) (-15 -4450 ($ |#1| $)) (-15 -1890 (|#1| $)) (-15 -2616 (|#1| $)) (-15 -4154 ((-763) $)) (-15 -2166 ((-121) $ (-763))) (-15 -1737 ((-121) $ (-763))) (-15 -2510 ((-121) $ (-763))) (-15 -2367 ($ (-634 |#1|))) (-15 -3084 ((-121) $)) (-15 -3248 ($)) (-15 -2671 ($)) (-15 -3863 ($ $)) (-15 -3171 ((-121) $ $)) (-15 -2795 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4520)) (-15 -3674 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-15 -4487 ((-1143) $)) (-15 -4022 ((-1108) $)) (-15 -2745 ((-850) $)) (-15 -1717 ((-121) $ $)) (-15 -2447 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4519)) (PROGN (-15 -1387 ((-121) (-1 (-121) |#1|) $)) (-15 -1319 ((-121) (-1 (-121) |#1|) $)) (-15 -4168 ((-763) (-1 (-121) |#1|) $)) (-15 -1697 ((-763) $)) (-15 -4360 ((-634 |#1|) $)) (-15 -1979 ((-634 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4519)) (IF (|has| |#1| (-1090)) (PROGN (-15 -3109 ((-121) |#1| $)) (-15 -4168 ((-763) |#1| $))) |noBranch|) |noBranch|))) 
-((-2436 ((|#2| $ "value" |#2|) NIL) ((|#2| $ "first" |#2|) NIL) (($ $ "rest" $) NIL) ((|#2| $ "last" |#2|) NIL) ((|#2| $ (-1210 (-568)) |#2|) 43) ((|#2| $ (-568) |#2|) 40)) (-1601 (((-121) $) 11)) (-3674 (($ (-1 |#2| |#2|) $) 38)) (-3876 ((|#2| $) NIL) (($ $ (-763)) 16)) (-3724 (($ $ |#2|) 39)) (-1786 (((-121) $) 10)) (-2779 ((|#2| $ "value") NIL) ((|#2| $ "first") NIL) (($ $ "rest") NIL) ((|#2| $ "last") NIL) (($ $ (-1210 (-568))) 30) ((|#2| $ (-568)) 22) ((|#2| $ (-568) |#2|) NIL)) (-3845 (($ $ $) 46) (($ $ |#2|) NIL)) (-2768 (($ $ $) 32) (($ |#2| $) NIL) (($ (-634 $)) 35) (($ $ |#2|) NIL))) 
-(((-1133 |#1| |#2|) (-10 -8 (-15 -1601 ((-121) |#1|)) (-15 -1786 ((-121) |#1|)) (-15 -2436 (|#2| |#1| (-568) |#2|)) (-15 -2779 (|#2| |#1| (-568) |#2|)) (-15 -2779 (|#2| |#1| (-568))) (-15 -3724 (|#1| |#1| |#2|)) (-15 -2768 (|#1| |#1| |#2|)) (-15 -2768 (|#1| (-634 |#1|))) (-15 -2779 (|#1| |#1| (-1210 (-568)))) (-15 -2436 (|#2| |#1| (-1210 (-568)) |#2|)) (-15 -2436 (|#2| |#1| "last" |#2|)) (-15 -2436 (|#1| |#1| "rest" |#1|)) (-15 -2436 (|#2| |#1| "first" |#2|)) (-15 -3845 (|#1| |#1| |#2|)) (-15 -3845 (|#1| |#1| |#1|)) (-15 -2779 (|#2| |#1| "last")) (-15 -2779 (|#1| |#1| "rest")) (-15 -3876 (|#1| |#1| (-763))) (-15 -2779 (|#2| |#1| "first")) (-15 -3876 (|#2| |#1|)) (-15 -2768 (|#1| |#2| |#1|)) (-15 -2768 (|#1| |#1| |#1|)) (-15 -2436 (|#2| |#1| "value" |#2|)) (-15 -2779 (|#2| |#1| "value")) (-15 -3674 (|#1| (-1 |#2| |#2|) |#1|))) (-1134 |#2|) (-1195)) (T -1133)) 
-NIL 
-(-10 -8 (-15 -1601 ((-121) |#1|)) (-15 -1786 ((-121) |#1|)) (-15 -2436 (|#2| |#1| (-568) |#2|)) (-15 -2779 (|#2| |#1| (-568) |#2|)) (-15 -2779 (|#2| |#1| (-568))) (-15 -3724 (|#1| |#1| |#2|)) (-15 -2768 (|#1| |#1| |#2|)) (-15 -2768 (|#1| (-634 |#1|))) (-15 -2779 (|#1| |#1| (-1210 (-568)))) (-15 -2436 (|#2| |#1| (-1210 (-568)) |#2|)) (-15 -2436 (|#2| |#1| "last" |#2|)) (-15 -2436 (|#1| |#1| "rest" |#1|)) (-15 -2436 (|#2| |#1| "first" |#2|)) (-15 -3845 (|#1| |#1| |#2|)) (-15 -3845 (|#1| |#1| |#1|)) (-15 -2779 (|#2| |#1| "last")) (-15 -2779 (|#1| |#1| "rest")) (-15 -3876 (|#1| |#1| (-763))) (-15 -2779 (|#2| |#1| "first")) (-15 -3876 (|#2| |#1|)) (-15 -2768 (|#1| |#2| |#1|)) (-15 -2768 (|#1| |#1| |#1|)) (-15 -2436 (|#2| |#1| "value" |#2|)) (-15 -2779 (|#2| |#1| "value")) (-15 -3674 (|#1| (-1 |#2| |#2|) |#1|))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2850 ((|#1| $) 45)) (-2235 ((|#1| $) 62)) (-2796 (($ $) 64)) (-1868 (((-1249) $ (-568) (-568)) 94 (|has| $ (-6 -4520)))) (-3910 (($ $ (-568)) 49 (|has| $ (-6 -4520)))) (-2510 (((-121) $ (-763)) 8)) (-1659 ((|#1| $ |#1|) 36 (|has| $ (-6 -4520)))) (-3869 (($ $ $) 53 (|has| $ (-6 -4520)))) (-2395 ((|#1| $ |#1|) 51 (|has| $ (-6 -4520)))) (-2517 ((|#1| $ |#1|) 55 (|has| $ (-6 -4520)))) (-2436 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4520))) ((|#1| $ "first" |#1|) 54 (|has| $ (-6 -4520))) (($ $ "rest" $) 52 (|has| $ (-6 -4520))) ((|#1| $ "last" |#1|) 50 (|has| $ (-6 -4520))) ((|#1| $ (-1210 (-568)) |#1|) 114 (|has| $ (-6 -4520))) ((|#1| $ (-568) |#1|) 83 (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) 38 (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) |#1|) $) 99 (|has| $ (-6 -4519)))) (-1679 ((|#1| $) 63)) (-2671 (($) 7 T CONST)) (-3935 (($ $) 70) (($ $ (-763)) 68)) (-3924 (($ $) 96 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-4328 (($ (-1 (-121) |#1|) $) 100 (|has| $ (-6 -4519))) (($ |#1| $) 97 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $) 102 (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 101 (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 98 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3989 ((|#1| $ (-568) |#1|) 82 (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-568)) 84)) (-1601 (((-121) $) 80)) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-2287 (((-634 $) $) 47)) (-1700 (((-121) $ $) 39 (|has| |#1| (-1090)))) (-1849 (($ (-763) |#1|) 105)) (-1737 (((-121) $ (-763)) 9)) (-1881 (((-568) $) 92 (|has| (-568) (-842)))) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-2223 (((-568) $) 91 (|has| (-568) (-842)))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 108)) (-2166 (((-121) $ (-763)) 10)) (-2869 (((-634 |#1|) $) 42)) (-1651 (((-121) $) 46)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4162 ((|#1| $) 67) (($ $ (-763)) 65)) (-4122 (($ $ $ (-568)) 113) (($ |#1| $ (-568)) 112)) (-4174 (((-634 (-568)) $) 89)) (-3578 (((-121) (-568) $) 88)) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3876 ((|#1| $) 73) (($ $ (-763)) 71)) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 103)) (-3724 (($ $ |#1|) 93 (|has| $ (-6 -4520)))) (-1786 (((-121) $) 81)) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-4467 (((-121) |#1| $) 90 (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) 87)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 ((|#1| $ "value") 44) ((|#1| $ "first") 72) (($ $ "rest") 69) ((|#1| $ "last") 66) (($ $ (-1210 (-568))) 109) ((|#1| $ (-568)) 86) ((|#1| $ (-568) |#1|) 85)) (-4075 (((-568) $ $) 41)) (-2826 (($ $ (-1210 (-568))) 111) (($ $ (-568)) 110)) (-3790 (((-121) $) 43)) (-2340 (($ $) 59)) (-2714 (($ $) 56 (|has| $ (-6 -4520)))) (-2775 (((-763) $) 60)) (-3335 (($ $) 61)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-4278 (((-541) $) 95 (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) 104)) (-3845 (($ $ $) 58 (|has| $ (-6 -4520))) (($ $ |#1|) 57 (|has| $ (-6 -4520)))) (-2768 (($ $ $) 75) (($ |#1| $) 74) (($ (-634 $)) 107) (($ $ |#1|) 106)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-4339 (((-634 $) $) 48)) (-3491 (((-121) $ $) 40 (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-4499 (*1 *1 *1) (-4 *1 (-1129))) (-2739 (*1 *1 *1) (-4 *1 (-1129))) (-3083 (*1 *1 *1) (-4 *1 (-1129))) (-2499 (*1 *1 *1) (-4 *1 (-1129))) (-3768 (*1 *2 *1 *1) (-12 (-4 *1 (-1129)) (-5 *2 (-121)))) (-3675 (*1 *2 *1 *1) (-12 (-4 *1 (-1129)) (-5 *2 (-121)))) (-3762 (*1 *2 *1 *1 *3) (-12 (-4 *1 (-1129)) (-5 *3 (-568)) (-5 *2 (-121)))) (-4439 (*1 *2 *1 *1 *3) (-12 (-4 *1 (-1129)) (-5 *3 (-147)) (-5 *2 (-763)))) (-4065 (*1 *2 *1 *1 *3) (-12 (-4 *1 (-1129)) (-5 *3 (-147)) (-5 *2 (-121)))) (-3943 (*1 *1 *1 *2 *1) (-12 (-4 *1 (-1129)) (-5 *2 (-1210 (-568))))) (-2766 (*1 *2 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-568)))) (-2766 (*1 *2 *3 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-568)) (-5 *3 (-142)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-147)) (-4 *1 (-1129)))) (-4446 (*1 *2 *1 *3) (-12 (-5 *3 (-147)) (-5 *2 (-634 *1)) (-4 *1 (-1129)))) (-4446 (*1 *2 *1 *3) (-12 (-5 *3 (-142)) (-5 *2 (-634 *1)) (-4 *1 (-1129)))) (-1474 (*1 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-147)))) (-1474 (*1 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-142)))) (-3384 (*1 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-147)))) (-3384 (*1 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-142)))) (-1871 (*1 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-147)))) (-1871 (*1 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-142)))) (-2781 (*1 *1 *1 *1) (-4 *1 (-1129)))) 
+(-13 (-19 (-147)) (-10 -8 (-15 -4499 ($ $)) (-15 -2739 ($ $)) (-15 -3083 ($ $)) (-15 -2499 ($ $)) (-15 -3768 ((-121) $ $)) (-15 -3675 ((-121) $ $)) (-15 -3762 ((-121) $ $ (-568))) (-15 -4439 ((-763) $ $ (-147))) (-15 -4065 ((-121) $ $ (-147))) (-15 -3943 ($ $ (-1210 (-568)) $)) (-15 -2766 ((-568) $ $ (-568))) (-15 -2766 ((-568) (-142) $ (-568))) (-15 -2747 ($ (-147))) (-15 -4446 ((-634 $) $ (-147))) (-15 -4446 ((-634 $) $ (-142))) (-15 -1474 ($ $ (-147))) (-15 -1474 ($ $ (-142))) (-15 -3384 ($ $ (-147))) (-15 -3384 ($ $ (-142))) (-15 -1871 ($ $ (-147))) (-15 -1871 ($ $ (-142))) (-15 -2781 ($ $ $)))) 
+(((-39) . T) ((-105) -2199 (|has| (-147) (-1090)) (|has| (-147) (-842))) ((-608 (-850)) -2199 (|has| (-147) (-1090)) (|has| (-147) (-842))) ((-154 (-147)) . T) ((-609 (-541)) |has| (-147) (-609 (-541))) ((-281 (-568) (-147)) . T) ((-283 (-568) (-147)) . T) ((-303 (-147)) -12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090))) ((-375 (-147)) . T) ((-499 (-147)) . T) ((-601 (-568) (-147)) . T) ((-523 (-147) (-147)) -12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090))) ((-640 (-147)) . T) ((-19 (-147)) . T) ((-842) |has| (-147) (-842)) ((-1090) -2199 (|has| (-147) (-1090)) (|has| (-147) (-842))) ((-1195) . T)) 
+((-1561 (((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-634 |#4|) (-634 |#5|) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) (-763)) 93)) (-2742 (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5|) 54) (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5| (-763)) 53)) (-1277 (((-1249) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-763)) 85)) (-1490 (((-763) (-634 |#4|) (-634 |#5|)) 27)) (-1837 (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5|) 56) (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5| (-763)) 55) (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5| (-763) (-121)) 57)) (-3946 (((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121) (-121) (-121) (-121)) 76) (((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121)) 77)) (-4280 (((-1143) (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) 80)) (-3489 (((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5|) 52)) (-3006 (((-763) (-634 |#4|) (-634 |#5|)) 19))) 
+(((-1130 |#1| |#2| |#3| |#4| |#5|) (-10 -7 (-15 -3006 ((-763) (-634 |#4|) (-634 |#5|))) (-15 -1490 ((-763) (-634 |#4|) (-634 |#5|))) (-15 -3489 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5|)) (-15 -2742 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5| (-763))) (-15 -2742 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5|)) (-15 -1837 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5| (-763) (-121))) (-15 -1837 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5| (-763))) (-15 -1837 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5|)) (-15 -3946 ((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121))) (-15 -3946 ((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121) (-121) (-121) (-121))) (-15 -1561 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-634 |#4|) (-634 |#5|) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) (-763))) (-15 -4280 ((-1143) (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|)))) (-15 -1277 ((-1249) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-763)))) (-453) (-788) (-842) (-1061 |#1| |#2| |#3|) (-1099 |#1| |#2| |#3| |#4|)) (T -1130)) 
+((-1277 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-2 (|:| |val| (-634 *8)) (|:| -3145 *9)))) (-5 *4 (-763)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1099 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-1249)) (-5 *1 (-1130 *5 *6 *7 *8 *9)))) (-4280 (*1 *2 *3) (-12 (-5 *3 (-2 (|:| |val| (-634 *7)) (|:| -3145 *8))) (-4 *7 (-1061 *4 *5 *6)) (-4 *8 (-1099 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1143)) (-5 *1 (-1130 *4 *5 *6 *7 *8)))) (-1561 (*1 *2 *3 *4 *2 *5 *6) (-12 (-5 *5 (-2 (|:| |done| (-634 *11)) (|:| |todo| (-634 (-2 (|:| |val| *3) (|:| -3145 *11)))))) (-5 *6 (-763)) (-5 *2 (-634 (-2 (|:| |val| (-634 *10)) (|:| -3145 *11)))) (-5 *3 (-634 *10)) (-5 *4 (-634 *11)) (-4 *10 (-1061 *7 *8 *9)) (-4 *11 (-1099 *7 *8 *9 *10)) (-4 *7 (-453)) (-4 *8 (-788)) (-4 *9 (-842)) (-5 *1 (-1130 *7 *8 *9 *10 *11)))) (-3946 (*1 *2 *3 *2 *4 *4 *4 *4 *4) (-12 (-5 *2 (-634 *9)) (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1099 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1130 *5 *6 *7 *8 *9)))) (-3946 (*1 *2 *3 *2 *4 *4) (-12 (-5 *2 (-634 *9)) (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1099 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1130 *5 *6 *7 *8 *9)))) (-1837 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1130 *5 *6 *7 *3 *4)) (-4 *4 (-1099 *5 *6 *7 *3)))) (-1837 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-763)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1130 *6 *7 *8 *3 *4)) (-4 *4 (-1099 *6 *7 *8 *3)))) (-1837 (*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-763)) (-5 *6 (-121)) (-4 *7 (-453)) (-4 *8 (-788)) (-4 *9 (-842)) (-4 *3 (-1061 *7 *8 *9)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1130 *7 *8 *9 *3 *4)) (-4 *4 (-1099 *7 *8 *9 *3)))) (-2742 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1130 *5 *6 *7 *3 *4)) (-4 *4 (-1099 *5 *6 *7 *3)))) (-2742 (*1 *2 *3 *4 *5) (-12 (-5 *5 (-763)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1130 *6 *7 *8 *3 *4)) (-4 *4 (-1099 *6 *7 *8 *3)))) (-3489 (*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1130 *5 *6 *7 *3 *4)) (-4 *4 (-1099 *5 *6 *7 *3)))) (-1490 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 *9)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1099 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-763)) (-5 *1 (-1130 *5 *6 *7 *8 *9)))) (-3006 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 *9)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1099 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-763)) (-5 *1 (-1130 *5 *6 *7 *8 *9))))) 
+(-10 -7 (-15 -3006 ((-763) (-634 |#4|) (-634 |#5|))) (-15 -1490 ((-763) (-634 |#4|) (-634 |#5|))) (-15 -3489 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5|)) (-15 -2742 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5| (-763))) (-15 -2742 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5|)) (-15 -1837 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5| (-763) (-121))) (-15 -1837 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5| (-763))) (-15 -1837 ((-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) |#4| |#5|)) (-15 -3946 ((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121))) (-15 -3946 ((-634 |#5|) (-634 |#4|) (-634 |#5|) (-121) (-121) (-121) (-121) (-121))) (-15 -1561 ((-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-634 |#4|) (-634 |#5|) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-2 (|:| |done| (-634 |#5|)) (|:| |todo| (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))))) (-763))) (-15 -4280 ((-1143) (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|)))) (-15 -1277 ((-1249) (-634 (-2 (|:| |val| (-634 |#4|)) (|:| -3145 |#5|))) (-763)))) 
+((-2449 (((-121) $ $) NIL)) (-2213 (((-634 (-2 (|:| -4094 $) (|:| -2133 (-634 |#4|)))) (-634 |#4|)) NIL)) (-2353 (((-634 $) (-634 |#4|)) 109) (((-634 $) (-634 |#4|) (-121)) 110) (((-634 $) (-634 |#4|) (-121) (-121)) 108) (((-634 $) (-634 |#4|) (-121) (-121) (-121) (-121)) 111)) (-2057 (((-634 |#3|) $) NIL)) (-4141 (((-121) $) NIL)) (-1794 (((-121) $) NIL (|has| |#1| (-558)))) (-4231 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-3767 ((|#4| |#4| $) NIL)) (-3045 (((-634 (-2 (|:| |val| |#4|) (|:| -3145 $))) |#4| $) 83)) (-3647 (((-2 (|:| |under| $) (|:| -4115 $) (|:| |upper| $)) $ |#3|) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-2803 (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521))) (((-3 |#4| "failed") $ |#3|) 61)) (-4490 (($) NIL T CONST)) (-4382 (((-121) $) 26 (|has| |#1| (-558)))) (-1880 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2536 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2343 (((-121) $) NIL (|has| |#1| (-558)))) (-2941 (((-634 |#4|) (-634 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-3993 (((-634 |#4|) (-634 |#4|) $) NIL (|has| |#1| (-558)))) (-2727 (((-634 |#4|) (-634 |#4|) $) NIL (|has| |#1| (-558)))) (-3668 (((-3 $ "failed") (-634 |#4|)) NIL)) (-2857 (($ (-634 |#4|)) NIL)) (-3936 (((-3 $ "failed") $) 39)) (-3255 ((|#4| |#4| $) 64)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090))))) (-4330 (($ |#4| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090)))) (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-2607 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 77 (|has| |#1| (-558)))) (-1359 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) NIL)) (-3434 ((|#4| |#4| $) NIL)) (-3094 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) NIL (|has| $ (-6 -4521))) ((|#4| (-1 |#4| |#4| |#4|) $) NIL (|has| $ (-6 -4521))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-3158 (((-2 (|:| -4094 (-634 |#4|)) (|:| -2133 (-634 |#4|))) $) NIL)) (-2451 (((-121) |#4| $) NIL)) (-2978 (((-121) |#4| $) NIL)) (-1792 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-2123 (((-2 (|:| |val| (-634 |#4|)) (|:| |towers| (-634 $))) (-634 |#4|) (-121) (-121)) 123)) (-3317 (((-634 |#4|) $) 16 (|has| $ (-6 -4521)))) (-3764 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-4001 ((|#3| $) 33)) (-3791 (((-121) $ (-763)) NIL)) (-4406 (((-634 |#4|) $) 17 (|has| $ (-6 -4521)))) (-2551 (((-121) |#4| $) 25 (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090))))) (-2253 (($ (-1 |#4| |#4|) $) 23 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#4| |#4|) $) 21)) (-2249 (((-634 |#3|) $) NIL)) (-1495 (((-121) |#3| $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL)) (-1516 (((-3 |#4| (-634 $)) |#4| |#4| $) NIL)) (-3137 (((-634 (-2 (|:| |val| |#4|) (|:| -3145 $))) |#4| |#4| $) 102)) (-4164 (((-3 |#4| "failed") $) 37)) (-3878 (((-634 $) |#4| $) 87)) (-3712 (((-3 (-121) (-634 $)) |#4| $) NIL)) (-4266 (((-634 (-2 (|:| |val| (-121)) (|:| -3145 $))) |#4| $) 97) (((-121) |#4| $) 52)) (-1864 (((-634 $) |#4| $) 106) (((-634 $) (-634 |#4|) $) NIL) (((-634 $) (-634 |#4|) (-634 $)) 107) (((-634 $) |#4| (-634 $)) NIL)) (-3196 (((-634 $) (-634 |#4|) (-121) (-121) (-121)) 118)) (-3736 (($ |#4| $) 74) (($ (-634 |#4|) $) 75) (((-634 $) |#4| $ (-121) (-121) (-121) (-121) (-121)) 73)) (-3882 (((-634 |#4|) $) NIL)) (-2157 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-1315 ((|#4| |#4| $) NIL)) (-4342 (((-121) $ $) NIL)) (-1440 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-558)))) (-3236 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-1452 ((|#4| |#4| $) NIL)) (-4025 (((-1108) $) NIL)) (-3877 (((-3 |#4| "failed") $) 35)) (-2712 (((-3 |#4| "failed") (-1 (-121) |#4|) $) NIL)) (-3413 (((-3 $ "failed") $ |#4|) 47)) (-2168 (($ $ |#4|) NIL) (((-634 $) |#4| $) 89) (((-634 $) |#4| (-634 $)) NIL) (((-634 $) (-634 |#4|) $) NIL) (((-634 $) (-634 |#4|) (-634 $)) 85)) (-3951 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 |#4|) (-634 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 (-288 |#4|))) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) 15)) (-1990 (($) 13)) (-1836 (((-763) $) NIL)) (-4170 (((-763) |#4| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090)))) (((-763) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-3865 (($ $) 12)) (-4280 (((-541) $) NIL (|has| |#4| (-609 (-541))))) (-4289 (($ (-634 |#4|)) 20)) (-3206 (($ $ |#3|) 42)) (-2527 (($ $ |#3|) 43)) (-4392 (($ $) NIL)) (-4332 (($ $ |#3|) NIL)) (-2747 (((-850) $) 31) (((-634 |#4|) $) 40)) (-2524 (((-763) $) NIL (|has| |#3| (-370)))) (-2835 (((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4| |#4|)) NIL) (((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-2145 (((-121) $ (-1 (-121) |#4| (-634 |#4|))) NIL)) (-1977 (((-634 $) |#4| $) 53) (((-634 $) |#4| (-634 $)) NIL) (((-634 $) (-634 |#4|) $) NIL) (((-634 $) (-634 |#4|) (-634 $)) NIL)) (-3437 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-3321 (((-634 |#3|) $) NIL)) (-3541 (((-121) |#4| $) NIL)) (-1413 (((-121) |#3| $) 60)) (-1719 (((-121) $ $) NIL)) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-1131 |#1| |#2| |#3| |#4|) (-13 (-1099 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3736 ((-634 $) |#4| $ (-121) (-121) (-121) (-121) (-121))) (-15 -2353 ((-634 $) (-634 |#4|) (-121) (-121))) (-15 -2353 ((-634 $) (-634 |#4|) (-121) (-121) (-121) (-121))) (-15 -3196 ((-634 $) (-634 |#4|) (-121) (-121) (-121))) (-15 -2123 ((-2 (|:| |val| (-634 |#4|)) (|:| |towers| (-634 $))) (-634 |#4|) (-121) (-121))))) (-453) (-788) (-842) (-1061 |#1| |#2| |#3|)) (T -1131)) 
+((-3736 (*1 *2 *3 *1 *4 *4 *4 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1131 *5 *6 *7 *3))) (-5 *1 (-1131 *5 *6 *7 *3)) (-4 *3 (-1061 *5 *6 *7)))) (-2353 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1131 *5 *6 *7 *8))) (-5 *1 (-1131 *5 *6 *7 *8)))) (-2353 (*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1131 *5 *6 *7 *8))) (-5 *1 (-1131 *5 *6 *7 *8)))) (-3196 (*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1131 *5 *6 *7 *8))) (-5 *1 (-1131 *5 *6 *7 *8)))) (-2123 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |val| (-634 *8)) (|:| |towers| (-634 (-1131 *5 *6 *7 *8))))) (-5 *1 (-1131 *5 *6 *7 *8)) (-5 *3 (-634 *8))))) 
+(-13 (-1099 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3736 ((-634 $) |#4| $ (-121) (-121) (-121) (-121) (-121))) (-15 -2353 ((-634 $) (-634 |#4|) (-121) (-121))) (-15 -2353 ((-634 $) (-634 |#4|) (-121) (-121) (-121) (-121))) (-15 -3196 ((-634 $) (-634 |#4|) (-121) (-121) (-121))) (-15 -2123 ((-2 (|:| |val| (-634 |#4|)) (|:| |towers| (-634 $))) (-634 |#4|) (-121) (-121))))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2618 ((|#1| $) 28)) (-2468 (($ (-634 |#1|)) 33)) (-1667 (((-121) $ (-763)) NIL)) (-4490 (($) NIL T CONST)) (-2885 ((|#1| |#1| $) 30)) (-2819 ((|#1| $) 26)) (-3317 (((-634 |#1|) $) 34 (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) NIL)) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-2253 (($ (-1 |#1| |#1|) $) 39 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 37)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-2580 ((|#1| $) 29)) (-1708 (($ |#1| $) 31)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3403 ((|#1| $) 27)) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) 24)) (-1990 (($) 32)) (-4156 (((-763) $) 22)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) 20)) (-2747 (((-850) $) 17 (|has| |#1| (-1090)))) (-4074 (($ (-634 |#1|)) NIL)) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 12 (|has| |#1| (-1090)))) (-1699 (((-763) $) 23 (|has| $ (-6 -4521))))) 
+(((-1132 |#1|) (-13 (-1109 |#1|) (-10 -8 (-15 -2468 ($ (-634 |#1|))) (-15 -2819 (|#1| $)) (-15 -3403 (|#1| $)) (-15 -2885 (|#1| |#1| $)) (-15 -1708 ($ |#1| $)) (-15 -2580 (|#1| $)) (-15 -2618 (|#1| $)) (-15 -4156 ((-763) $)) (-15 -3796 ((-121) $ (-763))) (-15 -3791 ((-121) $ (-763))) (-15 -1667 ((-121) $ (-763))) (-15 -4074 ($ (-634 |#1|))) (-15 -2436 ((-121) $)) (-15 -1990 ($)) (-15 -4490 ($)) (-15 -3865 ($ $)) (-15 -1702 ((-121) $ $)) (-15 -2797 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4522)) (-15 -2253 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-15 -1893 ((-1143) $)) (-15 -4025 ((-1108) $)) (-15 -2747 ((-850) $)) (-15 -1719 ((-121) $ $)) (-15 -2449 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4521)) (PROGN (-15 -3951 ((-121) (-1 (-121) |#1|) $)) (-15 -3437 ((-121) (-1 (-121) |#1|) $)) (-15 -4170 ((-763) (-1 (-121) |#1|) $)) (-15 -1699 ((-763) $)) (-15 -3317 ((-634 |#1|) $)) (-15 -4406 ((-634 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4521)) (IF (|has| |#1| (-1090)) (PROGN (-15 -2551 ((-121) |#1| $)) (-15 -4170 ((-763) |#1| $))) |noBranch|) |noBranch|))) (-1090)) (T -1132)) 
+((-1702 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)))) (-3865 (*1 *1 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) (-1990 (*1 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) (-2436 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)))) (-3796 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1132 *4)) (-4 *4 (-1090)))) (-3791 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1132 *4)) (-4 *4 (-1090)))) (-1667 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1132 *4)) (-4 *4 (-1090)))) (-4490 (*1 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) (-1699 (*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-763)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)))) (-2797 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-1132 *3)))) (-2253 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4522)) (-4 *3 (-1090)) (-5 *1 (-1132 *3)))) (-3437 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-1132 *4)))) (-3951 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-1132 *4)))) (-4170 (*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-763)) (-5 *1 (-1132 *4)))) (-3317 (*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-634 *3)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)))) (-4406 (*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-634 *3)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)))) (-4170 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-763)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2551 (*1 *2 *3 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-121)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-1893 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-4025 (*1 *2 *1) (-12 (-5 *2 (-1108)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-1719 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-2449 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) (-4074 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-1132 *3)))) (-3403 (*1 *2 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) (-1708 (*1 *1 *2 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) (-2580 (*1 *2 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) (-2885 (*1 *2 *2 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) (-2819 (*1 *2 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) (-2618 (*1 *2 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) (-4156 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)))) (-2468 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-1132 *3))))) 
+(-13 (-1109 |#1|) (-10 -8 (-15 -2468 ($ (-634 |#1|))) (-15 -2819 (|#1| $)) (-15 -3403 (|#1| $)) (-15 -2885 (|#1| |#1| $)) (-15 -1708 ($ |#1| $)) (-15 -2580 (|#1| $)) (-15 -2618 (|#1| $)) (-15 -4156 ((-763) $)) (-15 -3796 ((-121) $ (-763))) (-15 -3791 ((-121) $ (-763))) (-15 -1667 ((-121) $ (-763))) (-15 -4074 ($ (-634 |#1|))) (-15 -2436 ((-121) $)) (-15 -1990 ($)) (-15 -4490 ($)) (-15 -3865 ($ $)) (-15 -1702 ((-121) $ $)) (-15 -2797 ($ (-1 |#1| |#1|) $)) (IF (|has| $ (-6 -4522)) (-15 -2253 ($ (-1 |#1| |#1|) $)) |noBranch|) (IF (|has| |#1| (-1090)) (PROGN (-15 -1893 ((-1143) $)) (-15 -4025 ((-1108) $)) (-15 -2747 ((-850) $)) (-15 -1719 ((-121) $ $)) (-15 -2449 ((-121) $ $))) |noBranch|) (IF (|has| $ (-6 -4521)) (PROGN (-15 -3951 ((-121) (-1 (-121) |#1|) $)) (-15 -3437 ((-121) (-1 (-121) |#1|) $)) (-15 -4170 ((-763) (-1 (-121) |#1|) $)) (-15 -1699 ((-763) $)) (-15 -3317 ((-634 |#1|) $)) (-15 -4406 ((-634 |#1|) $))) |noBranch|) (IF (|has| $ (-6 -4521)) (IF (|has| |#1| (-1090)) (PROGN (-15 -2551 ((-121) |#1| $)) (-15 -4170 ((-763) |#1| $))) |noBranch|) |noBranch|))) 
+((-2438 ((|#2| $ "value" |#2|) NIL) ((|#2| $ "first" |#2|) NIL) (($ $ "rest" $) NIL) ((|#2| $ "last" |#2|) NIL) ((|#2| $ (-1210 (-568)) |#2|) 43) ((|#2| $ (-568) |#2|) 40)) (-1340 (((-121) $) 11)) (-2253 (($ (-1 |#2| |#2|) $) 38)) (-3877 ((|#2| $) NIL) (($ $ (-763)) 16)) (-2490 (($ $ |#2|) 39)) (-4049 (((-121) $) 10)) (-2781 ((|#2| $ "value") NIL) ((|#2| $ "first") NIL) (($ $ "rest") NIL) ((|#2| $ "last") NIL) (($ $ (-1210 (-568))) 30) ((|#2| $ (-568)) 22) ((|#2| $ (-568) |#2|) NIL)) (-1876 (($ $ $) 46) (($ $ |#2|) NIL)) (-2770 (($ $ $) 32) (($ |#2| $) NIL) (($ (-634 $)) 35) (($ $ |#2|) NIL))) 
+(((-1133 |#1| |#2|) (-10 -8 (-15 -1340 ((-121) |#1|)) (-15 -4049 ((-121) |#1|)) (-15 -2438 (|#2| |#1| (-568) |#2|)) (-15 -2781 (|#2| |#1| (-568) |#2|)) (-15 -2781 (|#2| |#1| (-568))) (-15 -2490 (|#1| |#1| |#2|)) (-15 -2770 (|#1| |#1| |#2|)) (-15 -2770 (|#1| (-634 |#1|))) (-15 -2781 (|#1| |#1| (-1210 (-568)))) (-15 -2438 (|#2| |#1| (-1210 (-568)) |#2|)) (-15 -2438 (|#2| |#1| "last" |#2|)) (-15 -2438 (|#1| |#1| "rest" |#1|)) (-15 -2438 (|#2| |#1| "first" |#2|)) (-15 -1876 (|#1| |#1| |#2|)) (-15 -1876 (|#1| |#1| |#1|)) (-15 -2781 (|#2| |#1| "last")) (-15 -2781 (|#1| |#1| "rest")) (-15 -3877 (|#1| |#1| (-763))) (-15 -2781 (|#2| |#1| "first")) (-15 -3877 (|#2| |#1|)) (-15 -2770 (|#1| |#2| |#1|)) (-15 -2770 (|#1| |#1| |#1|)) (-15 -2438 (|#2| |#1| "value" |#2|)) (-15 -2781 (|#2| |#1| "value")) (-15 -2253 (|#1| (-1 |#2| |#2|) |#1|))) (-1134 |#2|) (-1195)) (T -1133)) 
+NIL 
+(-10 -8 (-15 -1340 ((-121) |#1|)) (-15 -4049 ((-121) |#1|)) (-15 -2438 (|#2| |#1| (-568) |#2|)) (-15 -2781 (|#2| |#1| (-568) |#2|)) (-15 -2781 (|#2| |#1| (-568))) (-15 -2490 (|#1| |#1| |#2|)) (-15 -2770 (|#1| |#1| |#2|)) (-15 -2770 (|#1| (-634 |#1|))) (-15 -2781 (|#1| |#1| (-1210 (-568)))) (-15 -2438 (|#2| |#1| (-1210 (-568)) |#2|)) (-15 -2438 (|#2| |#1| "last" |#2|)) (-15 -2438 (|#1| |#1| "rest" |#1|)) (-15 -2438 (|#2| |#1| "first" |#2|)) (-15 -1876 (|#1| |#1| |#2|)) (-15 -1876 (|#1| |#1| |#1|)) (-15 -2781 (|#2| |#1| "last")) (-15 -2781 (|#1| |#1| "rest")) (-15 -3877 (|#1| |#1| (-763))) (-15 -2781 (|#2| |#1| "first")) (-15 -3877 (|#2| |#1|)) (-15 -2770 (|#1| |#2| |#1|)) (-15 -2770 (|#1| |#1| |#1|)) (-15 -2438 (|#2| |#1| "value" |#2|)) (-15 -2781 (|#2| |#1| "value")) (-15 -2253 (|#1| (-1 |#2| |#2|) |#1|))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2852 ((|#1| $) 45)) (-2237 ((|#1| $) 62)) (-3623 (($ $) 64)) (-2481 (((-1249) $ (-568) (-568)) 94 (|has| $ (-6 -4522)))) (-2121 (($ $ (-568)) 49 (|has| $ (-6 -4522)))) (-1667 (((-121) $ (-763)) 8)) (-3370 ((|#1| $ |#1|) 36 (|has| $ (-6 -4522)))) (-1958 (($ $ $) 53 (|has| $ (-6 -4522)))) (-2257 ((|#1| $ |#1|) 51 (|has| $ (-6 -4522)))) (-1706 ((|#1| $ |#1|) 55 (|has| $ (-6 -4522)))) (-2438 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4522))) ((|#1| $ "first" |#1|) 54 (|has| $ (-6 -4522))) (($ $ "rest" $) 52 (|has| $ (-6 -4522))) ((|#1| $ "last" |#1|) 50 (|has| $ (-6 -4522))) ((|#1| $ (-1210 (-568)) |#1|) 114 (|has| $ (-6 -4522))) ((|#1| $ (-568) |#1|) 83 (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) 38 (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) |#1|) $) 99 (|has| $ (-6 -4521)))) (-1681 ((|#1| $) 63)) (-4490 (($) 7 T CONST)) (-3936 (($ $) 70) (($ $ (-763)) 68)) (-3926 (($ $) 96 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-4330 (($ (-1 (-121) |#1|) $) 100 (|has| $ (-6 -4521))) (($ |#1| $) 97 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $) 102 (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 101 (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 98 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-1292 ((|#1| $ (-568) |#1|) 82 (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-568)) 84)) (-1340 (((-121) $) 80)) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-3534 (((-634 $) $) 47)) (-3606 (((-121) $ $) 39 (|has| |#1| (-1090)))) (-1851 (($ (-763) |#1|) 105)) (-3791 (((-121) $ (-763)) 9)) (-2539 (((-568) $) 92 (|has| (-568) (-842)))) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3631 (((-568) $) 91 (|has| (-568) (-842)))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 108)) (-3796 (((-121) $ (-763)) 10)) (-4081 (((-634 |#1|) $) 42)) (-3319 (((-121) $) 46)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4164 ((|#1| $) 67) (($ $ (-763)) 65)) (-4124 (($ $ $ (-568)) 113) (($ |#1| $ (-568)) 112)) (-3948 (((-634 (-568)) $) 89)) (-2916 (((-121) (-568) $) 88)) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3877 ((|#1| $) 73) (($ $ (-763)) 71)) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 103)) (-2490 (($ $ |#1|) 93 (|has| $ (-6 -4522)))) (-4049 (((-121) $) 81)) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-1801 (((-121) |#1| $) 90 (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) 87)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 ((|#1| $ "value") 44) ((|#1| $ "first") 72) (($ $ "rest") 69) ((|#1| $ "last") 66) (($ $ (-1210 (-568))) 109) ((|#1| $ (-568)) 86) ((|#1| $ (-568) |#1|) 85)) (-1665 (((-568) $ $) 41)) (-2828 (($ $ (-1210 (-568))) 111) (($ $ (-568)) 110)) (-2763 (((-121) $) 43)) (-3903 (($ $) 59)) (-1499 (($ $) 56 (|has| $ (-6 -4522)))) (-3535 (((-763) $) 60)) (-4424 (($ $) 61)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-4280 (((-541) $) 95 (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) 104)) (-1876 (($ $ $) 58 (|has| $ (-6 -4522))) (($ $ |#1|) 57 (|has| $ (-6 -4522)))) (-2770 (($ $ $) 75) (($ |#1| $) 74) (($ (-634 $)) 107) (($ $ |#1|) 106)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-3180 (((-634 $) $) 48)) (-3873 (((-121) $ $) 40 (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-1134 |#1|) (-1275) (-1195)) (T -1134)) 
-((-1786 (*1 *2 *1) (-12 (-4 *1 (-1134 *3)) (-4 *3 (-1195)) (-5 *2 (-121)))) (-1601 (*1 *2 *1) (-12 (-4 *1 (-1134 *3)) (-4 *3 (-1195)) (-5 *2 (-121))))) 
-(-13 (-1231 |t#1|) (-640 |t#1|) (-10 -8 (-15 -1786 ((-121) $)) (-15 -1601 ((-121) $)))) 
+((-4049 (*1 *2 *1) (-12 (-4 *1 (-1134 *3)) (-4 *3 (-1195)) (-5 *2 (-121)))) (-1340 (*1 *2 *1) (-12 (-4 *1 (-1134 *3)) (-4 *3 (-1195)) (-5 *2 (-121))))) 
+(-13 (-1231 |t#1|) (-640 |t#1|) (-10 -8 (-15 -4049 ((-121) $)) (-15 -1340 ((-121) $)))) 
 (((-39) . T) ((-105) |has| |#1| (-1090)) ((-608 (-850)) |has| |#1| (-1090)) ((-154 |#1|) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-281 (-568) |#1|) . T) ((-283 (-568) |#1|) . T) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-601 (-568) |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-640 |#1|) . T) ((-1010 |#1|) . T) ((-1090) |has| |#1| (-1090)) ((-1195) . T) ((-1231 |#1|) . T)) 
-((-2447 (((-121) $ $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-2986 (($) NIL) (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-1868 (((-1249) $ |#1| |#1|) NIL (|has| $ (-6 -4520)))) (-2510 (((-121) $ (-763)) NIL)) (-2436 ((|#2| $ |#1| |#2|) NIL)) (-3507 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-2674 (((-3 |#2| "failed") |#1| $) NIL)) (-2671 (($) NIL T CONST)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-3405 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (|has| $ (-6 -4519))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-3 |#2| "failed") |#1| $) NIL)) (-4328 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-3092 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (|has| $ (-6 -4519))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-3989 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#2| $ |#1|) NIL)) (-4360 (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-634 |#2|) $) NIL (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) NIL)) (-1881 ((|#1| $) NIL (|has| |#1| (-842)))) (-1979 (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-634 |#2|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-2223 ((|#1| $) NIL (|has| |#1| (-842)))) (-3674 (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4520))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-1946 (((-634 |#1|) $) NIL)) (-3548 (((-121) |#1| $) NIL)) (-1890 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-4450 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-4174 (((-634 |#1|) $) NIL)) (-3578 (((-121) |#1| $) NIL)) (-4022 (((-1108) $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-3876 ((|#2| $) NIL (|has| |#1| (-842)))) (-3775 (((-3 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) "failed") (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL)) (-3724 (($ $ |#2|) NIL (|has| $ (-6 -4520)))) (-1315 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-1387 (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-2041 (((-634 |#2|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL)) (-2085 (($) NIL) (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-4168 (((-763) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-763) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090)))) (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-609 (-541))))) (-4287 (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-2745 (((-850) $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-2367 (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-1319 (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-2988 (($) NIL) (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-2481 (((-1249) $ |#1| |#1|) NIL (|has| $ (-6 -4522)))) (-1667 (((-121) $ (-763)) NIL)) (-2438 ((|#2| $ |#1| |#2|) NIL)) (-3963 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-2678 (((-3 |#2| "failed") |#1| $) NIL)) (-4490 (($) NIL T CONST)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-1568 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (|has| $ (-6 -4521))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-3 |#2| "failed") |#1| $) NIL)) (-4330 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-3094 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (|has| $ (-6 -4521))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-1292 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#2| $ |#1|) NIL)) (-3317 (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-634 |#2|) $) NIL (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) NIL)) (-2539 ((|#1| $) NIL (|has| |#1| (-842)))) (-4406 (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-634 |#2|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-3631 ((|#1| $) NIL (|has| |#1| (-842)))) (-2253 (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4522))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-4253 (((-634 |#1|) $) NIL)) (-2807 (((-121) |#1| $) NIL)) (-2580 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-1708 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-3948 (((-634 |#1|) $) NIL)) (-2916 (((-121) |#1| $) NIL)) (-4025 (((-1108) $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-3877 ((|#2| $) NIL (|has| |#1| (-842)))) (-2712 (((-3 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) "failed") (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL)) (-2490 (($ $ |#2|) NIL (|has| $ (-6 -4522)))) (-3403 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-3951 (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-1480 (((-634 |#2|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL)) (-3132 (($) NIL) (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-4170 (((-763) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-763) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090)))) (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-609 (-541))))) (-4289 (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-2747 (((-850) $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-4074 (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-3437 (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
 (((-1135 |#1| |#2| |#3|) (-1172 |#1| |#2|) (-1090) (-1090) |#2|) (T -1135)) 
 NIL 
 (-1172 |#1| |#2|) 
-((-2447 (((-121) $ $) 7)) (-3038 (((-3 $ "failed") $) 12)) (-4487 (((-1143) $) 9)) (-4434 (($) 13 T CONST)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11)) (-1717 (((-121) $ $) 6))) 
+((-2449 (((-121) $ $) 7)) (-2214 (((-3 $ "failed") $) 12)) (-1893 (((-1143) $) 9)) (-4436 (($) 13 T CONST)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11)) (-1719 (((-121) $ $) 6))) 
 (((-1136) (-1275)) (T -1136)) 
-((-4434 (*1 *1) (-4 *1 (-1136))) (-3038 (*1 *1 *1) (|partial| -4 *1 (-1136)))) 
-(-13 (-1090) (-10 -8 (-15 -4434 ($) -3495) (-15 -3038 ((-3 $ "failed") $)))) 
+((-4436 (*1 *1) (-4 *1 (-1136))) (-2214 (*1 *1 *1) (|partial| -4 *1 (-1136)))) 
+(-13 (-1090) (-10 -8 (-15 -4436 ($) -3497) (-15 -2214 ((-3 $ "failed") $)))) 
 (((-105) . T) ((-608 (-850)) . T) ((-1090) . T)) 
-((-2049 (((-1141 |#1|) (-1141 |#1|)) 17)) (-1975 (((-1141 |#1|) (-1141 |#1|)) 13)) (-4216 (((-1141 |#1|) (-1141 |#1|) (-568) (-568)) 20)) (-2710 (((-1141 |#1|) (-1141 |#1|)) 15))) 
-(((-1137 |#1|) (-10 -7 (-15 -1975 ((-1141 |#1|) (-1141 |#1|))) (-15 -2710 ((-1141 |#1|) (-1141 |#1|))) (-15 -2049 ((-1141 |#1|) (-1141 |#1|))) (-15 -4216 ((-1141 |#1|) (-1141 |#1|) (-568) (-568)))) (-13 (-558) (-150))) (T -1137)) 
-((-4216 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-1141 *4)) (-5 *3 (-568)) (-4 *4 (-13 (-558) (-150))) (-5 *1 (-1137 *4)))) (-2049 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-13 (-558) (-150))) (-5 *1 (-1137 *3)))) (-2710 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-13 (-558) (-150))) (-5 *1 (-1137 *3)))) (-1975 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-13 (-558) (-150))) (-5 *1 (-1137 *3))))) 
-(-10 -7 (-15 -1975 ((-1141 |#1|) (-1141 |#1|))) (-15 -2710 ((-1141 |#1|) (-1141 |#1|))) (-15 -2049 ((-1141 |#1|) (-1141 |#1|))) (-15 -4216 ((-1141 |#1|) (-1141 |#1|) (-568) (-568)))) 
-((-2768 (((-1141 |#1|) (-1141 (-1141 |#1|))) 15))) 
-(((-1138 |#1|) (-10 -7 (-15 -2768 ((-1141 |#1|) (-1141 (-1141 |#1|))))) (-1195)) (T -1138)) 
-((-2768 (*1 *2 *3) (-12 (-5 *3 (-1141 (-1141 *4))) (-5 *2 (-1141 *4)) (-5 *1 (-1138 *4)) (-4 *4 (-1195))))) 
-(-10 -7 (-15 -2768 ((-1141 |#1|) (-1141 (-1141 |#1|))))) 
-((-2512 (((-1141 |#2|) |#2| (-1 |#2| |#1| |#2|) (-1141 |#1|)) 25)) (-3092 ((|#2| |#2| (-1 |#2| |#1| |#2|) (-1141 |#1|)) 26)) (-2795 (((-1141 |#2|) (-1 |#2| |#1|) (-1141 |#1|)) 16))) 
-(((-1139 |#1| |#2|) (-10 -7 (-15 -2795 ((-1141 |#2|) (-1 |#2| |#1|) (-1141 |#1|))) (-15 -2512 ((-1141 |#2|) |#2| (-1 |#2| |#1| |#2|) (-1141 |#1|))) (-15 -3092 (|#2| |#2| (-1 |#2| |#1| |#2|) (-1141 |#1|)))) (-1195) (-1195)) (T -1139)) 
-((-3092 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-1141 *5)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-1139 *5 *2)))) (-2512 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *3 *6 *3)) (-5 *5 (-1141 *6)) (-4 *6 (-1195)) (-4 *3 (-1195)) (-5 *2 (-1141 *3)) (-5 *1 (-1139 *6 *3)))) (-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1141 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1141 *6)) (-5 *1 (-1139 *5 *6))))) 
-(-10 -7 (-15 -2795 ((-1141 |#2|) (-1 |#2| |#1|) (-1141 |#1|))) (-15 -2512 ((-1141 |#2|) |#2| (-1 |#2| |#1| |#2|) (-1141 |#1|))) (-15 -3092 (|#2| |#2| (-1 |#2| |#1| |#2|) (-1141 |#1|)))) 
-((-2795 (((-1141 |#3|) (-1 |#3| |#1| |#2|) (-1141 |#1|) (-1141 |#2|)) 21))) 
-(((-1140 |#1| |#2| |#3|) (-10 -7 (-15 -2795 ((-1141 |#3|) (-1 |#3| |#1| |#2|) (-1141 |#1|) (-1141 |#2|)))) (-1195) (-1195) (-1195)) (T -1140)) 
-((-2795 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-1141 *6)) (-5 *5 (-1141 *7)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-4 *8 (-1195)) (-5 *2 (-1141 *8)) (-5 *1 (-1140 *6 *7 *8))))) 
-(-10 -7 (-15 -2795 ((-1141 |#3|) (-1 |#3| |#1| |#2|) (-1141 |#1|) (-1141 |#2|)))) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2850 ((|#1| $) NIL)) (-2235 ((|#1| $) NIL)) (-2796 (($ $) 48)) (-1868 (((-1249) $ (-568) (-568)) 73 (|has| $ (-6 -4520)))) (-3910 (($ $ (-568)) 107 (|has| $ (-6 -4520)))) (-2510 (((-121) $ (-763)) NIL)) (-3388 (((-850) $) 37 (|has| |#1| (-1090)))) (-1340 (((-121)) 38 (|has| |#1| (-1090)))) (-1659 ((|#1| $ |#1|) NIL (|has| $ (-6 -4520)))) (-3869 (($ $ $) 95 (|has| $ (-6 -4520))) (($ $ (-568) $) 117)) (-2395 ((|#1| $ |#1|) 104 (|has| $ (-6 -4520)))) (-2517 ((|#1| $ |#1|) 99 (|has| $ (-6 -4520)))) (-2436 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4520))) ((|#1| $ "first" |#1|) 101 (|has| $ (-6 -4520))) (($ $ "rest" $) 103 (|has| $ (-6 -4520))) ((|#1| $ "last" |#1|) 106 (|has| $ (-6 -4520))) ((|#1| $ (-1210 (-568)) |#1|) 86 (|has| $ (-6 -4520))) ((|#1| $ (-568) |#1|) 52 (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) NIL (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) |#1|) $) 55)) (-1679 ((|#1| $) NIL)) (-2671 (($) NIL T CONST)) (-1496 (($ $) 14)) (-3935 (($ $) 28) (($ $ (-763)) 85)) (-3516 (((-121) (-634 |#1|) $) 112 (|has| |#1| (-1090)))) (-2116 (($ (-634 |#1|)) 109)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-4328 (($ |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) 54)) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3989 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-568)) NIL)) (-1601 (((-121) $) NIL)) (-4360 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3494 (((-1249) (-568) $) 116 (|has| |#1| (-1090)))) (-3836 (((-763) $) 114)) (-2287 (((-634 $) $) NIL)) (-1700 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1849 (($ (-763) |#1|) NIL)) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) NIL (|has| (-568) (-842)))) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2223 (((-568) $) NIL (|has| (-568) (-842)))) (-3674 (($ (-1 |#1| |#1|) $) 70 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 60) (($ (-1 |#1| |#1| |#1|) $ $) 64)) (-2166 (((-121) $ (-763)) NIL)) (-2869 (((-634 |#1|) $) NIL)) (-1651 (((-121) $) NIL)) (-2892 (($ $) 87)) (-3851 (((-121) $) 13)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4162 ((|#1| $) NIL) (($ $ (-763)) NIL)) (-4122 (($ $ $ (-568)) NIL) (($ |#1| $ (-568)) NIL)) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) 71)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-2781 (($ (-1 |#1|)) 119) (($ (-1 |#1| |#1|) |#1|) 120)) (-3121 ((|#1| $) 10)) (-3876 ((|#1| $) 27) (($ $ (-763)) 46)) (-2930 (((-2 (|:| |cycle?| (-121)) (|:| -3390 (-763)) (|:| |period| (-763))) (-763) $) 24)) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-2794 (($ (-1 (-121) |#1|) $) 121)) (-2798 (($ (-1 (-121) |#1|) $) 122)) (-3724 (($ $ |#1|) 65 (|has| $ (-6 -4520)))) (-1807 (($ $ (-568)) 31)) (-1786 (((-121) $) 69)) (-1368 (((-121) $) 12)) (-3552 (((-121) $) 113)) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 20)) (-4467 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) NIL)) (-3084 (((-121) $) 15)) (-3248 (($) 40)) (-2779 ((|#1| $ "value") NIL) ((|#1| $ "first") NIL) (($ $ "rest") NIL) ((|#1| $ "last") NIL) (($ $ (-1210 (-568))) NIL) ((|#1| $ (-568)) 51) ((|#1| $ (-568) |#1|) NIL)) (-4075 (((-568) $ $) 45)) (-2826 (($ $ (-1210 (-568))) NIL) (($ $ (-568)) NIL)) (-4493 (($ (-1 $)) 44)) (-3790 (((-121) $) 66)) (-2340 (($ $) 67)) (-2714 (($ $) 96 (|has| $ (-6 -4520)))) (-2775 (((-763) $) NIL)) (-3335 (($ $) NIL)) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) 41)) (-4278 (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) 50)) (-3853 (($ |#1| $) 94)) (-3845 (($ $ $) 97 (|has| $ (-6 -4520))) (($ $ |#1|) 98 (|has| $ (-6 -4520)))) (-2768 (($ $ $) 75) (($ |#1| $) 42) (($ (-634 $)) 80) (($ $ |#1|) 74)) (-1811 (($ $) 47)) (-2745 (((-850) $) 39 (|has| |#1| (-1090))) (($ (-634 |#1|)) 108)) (-4339 (((-634 $) $) NIL)) (-3491 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 111 (|has| |#1| (-1090)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-1141 |#1|) (-13 (-665 |#1|) (-10 -8 (-6 -4520) (-15 -2745 ($ (-634 |#1|))) (-15 -2116 ($ (-634 |#1|))) (IF (|has| |#1| (-1090)) (-15 -3516 ((-121) (-634 |#1|) $)) |noBranch|) (-15 -2930 ((-2 (|:| |cycle?| (-121)) (|:| -3390 (-763)) (|:| |period| (-763))) (-763) $)) (-15 -4493 ($ (-1 $))) (-15 -3853 ($ |#1| $)) (IF (|has| |#1| (-1090)) (PROGN (-15 -3494 ((-1249) (-568) $)) (-15 -3388 ((-850) $)) (-15 -1340 ((-121)))) |noBranch|) (-15 -3869 ($ $ (-568) $)) (-15 -2781 ($ (-1 |#1|))) (-15 -2781 ($ (-1 |#1| |#1|) |#1|)) (-15 -2794 ($ (-1 (-121) |#1|) $)) (-15 -2798 ($ (-1 (-121) |#1|) $)))) (-1195)) (T -1141)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-1141 *3)))) (-2116 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-1141 *3)))) (-3516 (*1 *2 *3 *1) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1090)) (-4 *4 (-1195)) (-5 *2 (-121)) (-5 *1 (-1141 *4)))) (-2930 (*1 *2 *3 *1) (-12 (-5 *2 (-2 (|:| |cycle?| (-121)) (|:| -3390 (-763)) (|:| |period| (-763)))) (-5 *1 (-1141 *4)) (-4 *4 (-1195)) (-5 *3 (-763)))) (-4493 (*1 *1 *2) (-12 (-5 *2 (-1 (-1141 *3))) (-5 *1 (-1141 *3)) (-4 *3 (-1195)))) (-3853 (*1 *1 *2 *1) (-12 (-5 *1 (-1141 *2)) (-4 *2 (-1195)))) (-3494 (*1 *2 *3 *1) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-1141 *4)) (-4 *4 (-1090)) (-4 *4 (-1195)))) (-3388 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1141 *3)) (-4 *3 (-1090)) (-4 *3 (-1195)))) (-1340 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1141 *3)) (-4 *3 (-1090)) (-4 *3 (-1195)))) (-3869 (*1 *1 *1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1141 *3)) (-4 *3 (-1195)))) (-2781 (*1 *1 *2) (-12 (-5 *2 (-1 *3)) (-4 *3 (-1195)) (-5 *1 (-1141 *3)))) (-2781 (*1 *1 *2 *3) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1195)) (-5 *1 (-1141 *3)))) (-2794 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1195)) (-5 *1 (-1141 *3)))) (-2798 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1195)) (-5 *1 (-1141 *3))))) 
-(-13 (-665 |#1|) (-10 -8 (-6 -4520) (-15 -2745 ($ (-634 |#1|))) (-15 -2116 ($ (-634 |#1|))) (IF (|has| |#1| (-1090)) (-15 -3516 ((-121) (-634 |#1|) $)) |noBranch|) (-15 -2930 ((-2 (|:| |cycle?| (-121)) (|:| -3390 (-763)) (|:| |period| (-763))) (-763) $)) (-15 -4493 ($ (-1 $))) (-15 -3853 ($ |#1| $)) (IF (|has| |#1| (-1090)) (PROGN (-15 -3494 ((-1249) (-568) $)) (-15 -3388 ((-850) $)) (-15 -1340 ((-121)))) |noBranch|) (-15 -3869 ($ $ (-568) $)) (-15 -2781 ($ (-1 |#1|))) (-15 -2781 ($ (-1 |#1| |#1|) |#1|)) (-15 -2794 ($ (-1 (-121) |#1|) $)) (-15 -2798 ($ (-1 (-121) |#1|) $)))) 
-((-2447 (((-121) $ $) 18)) (-1873 (($ $) 113)) (-2072 (($ $) 114)) (-4403 (($ $ (-147)) 101) (($ $ (-142)) 100)) (-1868 (((-1249) $ (-568) (-568)) 37 (|has| $ (-6 -4520)))) (-3673 (((-121) $ $) 111)) (-3760 (((-121) $ $ (-568)) 110)) (-1742 (($ (-568)) 118)) (-3969 (((-634 $) $ (-147)) 103) (((-634 $) $ (-142)) 102)) (-2016 (((-121) (-1 (-121) (-147) (-147)) $) 91) (((-121) $) 85 (|has| (-147) (-842)))) (-3908 (($ (-1 (-121) (-147) (-147)) $) 82 (|has| $ (-6 -4520))) (($ $) 81 (-12 (|has| (-147) (-842)) (|has| $ (-6 -4520))))) (-3644 (($ (-1 (-121) (-147) (-147)) $) 92) (($ $) 86 (|has| (-147) (-842)))) (-2510 (((-121) $ (-763)) 8)) (-2436 (((-147) $ (-568) (-147)) 49 (|has| $ (-6 -4520))) (((-147) $ (-1210 (-568)) (-147)) 53 (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) (-147)) $) 70 (|has| $ (-6 -4519)))) (-2671 (($) 7 T CONST)) (-1869 (($ $ (-147)) 97) (($ $ (-142)) 96)) (-1578 (($ $) 83 (|has| $ (-6 -4520)))) (-3943 (($ $) 93)) (-1386 (($ $ (-1210 (-568)) $) 107)) (-3924 (($ $) 73 (-12 (|has| (-147) (-1090)) (|has| $ (-6 -4519))))) (-4328 (($ (-147) $) 72 (-12 (|has| (-147) (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) (-147)) $) 69 (|has| $ (-6 -4519)))) (-3092 (((-147) (-1 (-147) (-147) (-147)) $ (-147) (-147)) 71 (-12 (|has| (-147) (-1090)) (|has| $ (-6 -4519)))) (((-147) (-1 (-147) (-147) (-147)) $ (-147)) 68 (|has| $ (-6 -4519))) (((-147) (-1 (-147) (-147) (-147)) $) 67 (|has| $ (-6 -4519)))) (-3989 (((-147) $ (-568) (-147)) 50 (|has| $ (-6 -4520)))) (-2602 (((-147) $ (-568)) 48)) (-3766 (((-121) $ $) 112)) (-2764 (((-568) (-1 (-121) (-147)) $) 90) (((-568) (-147) $) 89 (|has| (-147) (-1090))) (((-568) (-147) $ (-568)) 88 (|has| (-147) (-1090))) (((-568) $ $ (-568)) 106) (((-568) (-142) $ (-568)) 105)) (-4360 (((-634 (-147)) $) 30 (|has| $ (-6 -4519)))) (-1849 (($ (-763) (-147)) 64)) (-1737 (((-121) $ (-763)) 9)) (-1881 (((-568) $) 40 (|has| (-568) (-842)))) (-2521 (($ $ $) 80 (|has| (-147) (-842)))) (-1347 (($ (-1 (-121) (-147) (-147)) $ $) 94) (($ $ $) 87 (|has| (-147) (-842)))) (-1979 (((-634 (-147)) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) (-147) $) 27 (-12 (|has| (-147) (-1090)) (|has| $ (-6 -4519))))) (-2223 (((-568) $) 41 (|has| (-568) (-842)))) (-3268 (($ $ $) 79 (|has| (-147) (-842)))) (-4062 (((-121) $ $ (-147)) 108)) (-2661 (((-763) $ $ (-147)) 109)) (-3674 (($ (-1 (-147) (-147)) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-147) (-147)) $) 35) (($ (-1 (-147) (-147) (-147)) $ $) 59)) (-2496 (($ $) 115)) (-2003 (($ $) 116)) (-2166 (((-121) $ (-763)) 10)) (-3382 (($ $ (-147)) 99) (($ $ (-142)) 98)) (-4487 (((-1143) $) 22)) (-4122 (($ (-147) $ (-568)) 55) (($ $ $ (-568)) 54)) (-4174 (((-634 (-568)) $) 43)) (-3578 (((-121) (-568) $) 44)) (-4022 (((-1108) $) 21)) (-3876 (((-147) $) 39 (|has| (-568) (-842)))) (-3775 (((-3 (-147) "failed") (-1 (-121) (-147)) $) 66)) (-3724 (($ $ (-147)) 38 (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) (-147)) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-147)))) 26 (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-288 (-147))) 25 (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-147) (-147)) 24 (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-634 (-147)) (-634 (-147))) 23 (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090))))) (-3171 (((-121) $ $) 14)) (-4467 (((-121) (-147) $) 42 (-12 (|has| $ (-6 -4519)) (|has| (-147) (-1090))))) (-2041 (((-634 (-147)) $) 45)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 (((-147) $ (-568) (-147)) 47) (((-147) $ (-568)) 46) (($ $ (-1210 (-568))) 58) (($ $ $) 95)) (-2826 (($ $ (-568)) 57) (($ $ (-1210 (-568))) 56)) (-4168 (((-763) (-1 (-121) (-147)) $) 31 (|has| $ (-6 -4519))) (((-763) (-147) $) 28 (-12 (|has| (-147) (-1090)) (|has| $ (-6 -4519))))) (-2256 (($ $ $ (-568)) 84 (|has| $ (-6 -4520)))) (-3863 (($ $) 13)) (-4278 (((-541) $) 74 (|has| (-147) (-609 (-541))))) (-4287 (($ (-634 (-147))) 65)) (-2768 (($ $ (-147)) 63) (($ (-147) $) 62) (($ $ $) 61) (($ (-634 $)) 60)) (-2745 (($ (-147)) 104) (((-850) $) 20)) (-1319 (((-121) (-1 (-121) (-147)) $) 33 (|has| $ (-6 -4519)))) (-3754 (((-1143) $) 122) (((-1143) $ (-121)) 121) (((-1249) (-817) $) 120) (((-1249) (-817) $ (-121)) 119)) (-1751 (((-121) $ $) 77 (|has| (-147) (-842)))) (-1738 (((-121) $ $) 76 (|has| (-147) (-842)))) (-1717 (((-121) $ $) 19)) (-1745 (((-121) $ $) 78 (|has| (-147) (-842)))) (-1732 (((-121) $ $) 75 (|has| (-147) (-842)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-1517 (((-1141 |#1|) (-1141 |#1|)) 17)) (-4388 (((-1141 |#1|) (-1141 |#1|)) 13)) (-4169 (((-1141 |#1|) (-1141 |#1|) (-568) (-568)) 20)) (-1471 (((-1141 |#1|) (-1141 |#1|)) 15))) 
+(((-1137 |#1|) (-10 -7 (-15 -4388 ((-1141 |#1|) (-1141 |#1|))) (-15 -1471 ((-1141 |#1|) (-1141 |#1|))) (-15 -1517 ((-1141 |#1|) (-1141 |#1|))) (-15 -4169 ((-1141 |#1|) (-1141 |#1|) (-568) (-568)))) (-13 (-558) (-150))) (T -1137)) 
+((-4169 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-1141 *4)) (-5 *3 (-568)) (-4 *4 (-13 (-558) (-150))) (-5 *1 (-1137 *4)))) (-1517 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-13 (-558) (-150))) (-5 *1 (-1137 *3)))) (-1471 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-13 (-558) (-150))) (-5 *1 (-1137 *3)))) (-4388 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-13 (-558) (-150))) (-5 *1 (-1137 *3))))) 
+(-10 -7 (-15 -4388 ((-1141 |#1|) (-1141 |#1|))) (-15 -1471 ((-1141 |#1|) (-1141 |#1|))) (-15 -1517 ((-1141 |#1|) (-1141 |#1|))) (-15 -4169 ((-1141 |#1|) (-1141 |#1|) (-568) (-568)))) 
+((-2770 (((-1141 |#1|) (-1141 (-1141 |#1|))) 15))) 
+(((-1138 |#1|) (-10 -7 (-15 -2770 ((-1141 |#1|) (-1141 (-1141 |#1|))))) (-1195)) (T -1138)) 
+((-2770 (*1 *2 *3) (-12 (-5 *3 (-1141 (-1141 *4))) (-5 *2 (-1141 *4)) (-5 *1 (-1138 *4)) (-4 *4 (-1195))))) 
+(-10 -7 (-15 -2770 ((-1141 |#1|) (-1141 (-1141 |#1|))))) 
+((-1678 (((-1141 |#2|) |#2| (-1 |#2| |#1| |#2|) (-1141 |#1|)) 25)) (-3094 ((|#2| |#2| (-1 |#2| |#1| |#2|) (-1141 |#1|)) 26)) (-2797 (((-1141 |#2|) (-1 |#2| |#1|) (-1141 |#1|)) 16))) 
+(((-1139 |#1| |#2|) (-10 -7 (-15 -2797 ((-1141 |#2|) (-1 |#2| |#1|) (-1141 |#1|))) (-15 -1678 ((-1141 |#2|) |#2| (-1 |#2| |#1| |#2|) (-1141 |#1|))) (-15 -3094 (|#2| |#2| (-1 |#2| |#1| |#2|) (-1141 |#1|)))) (-1195) (-1195)) (T -1139)) 
+((-3094 (*1 *2 *2 *3 *4) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-1141 *5)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-1139 *5 *2)))) (-1678 (*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *3 *6 *3)) (-5 *5 (-1141 *6)) (-4 *6 (-1195)) (-4 *3 (-1195)) (-5 *2 (-1141 *3)) (-5 *1 (-1139 *6 *3)))) (-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1141 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1141 *6)) (-5 *1 (-1139 *5 *6))))) 
+(-10 -7 (-15 -2797 ((-1141 |#2|) (-1 |#2| |#1|) (-1141 |#1|))) (-15 -1678 ((-1141 |#2|) |#2| (-1 |#2| |#1| |#2|) (-1141 |#1|))) (-15 -3094 (|#2| |#2| (-1 |#2| |#1| |#2|) (-1141 |#1|)))) 
+((-2797 (((-1141 |#3|) (-1 |#3| |#1| |#2|) (-1141 |#1|) (-1141 |#2|)) 21))) 
+(((-1140 |#1| |#2| |#3|) (-10 -7 (-15 -2797 ((-1141 |#3|) (-1 |#3| |#1| |#2|) (-1141 |#1|) (-1141 |#2|)))) (-1195) (-1195) (-1195)) (T -1140)) 
+((-2797 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-1141 *6)) (-5 *5 (-1141 *7)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-4 *8 (-1195)) (-5 *2 (-1141 *8)) (-5 *1 (-1140 *6 *7 *8))))) 
+(-10 -7 (-15 -2797 ((-1141 |#3|) (-1 |#3| |#1| |#2|) (-1141 |#1|) (-1141 |#2|)))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2852 ((|#1| $) NIL)) (-2237 ((|#1| $) NIL)) (-3623 (($ $) 48)) (-2481 (((-1249) $ (-568) (-568)) 73 (|has| $ (-6 -4522)))) (-2121 (($ $ (-568)) 107 (|has| $ (-6 -4522)))) (-1667 (((-121) $ (-763)) NIL)) (-1482 (((-850) $) 37 (|has| |#1| (-1090)))) (-3589 (((-121)) 38 (|has| |#1| (-1090)))) (-3370 ((|#1| $ |#1|) NIL (|has| $ (-6 -4522)))) (-1958 (($ $ $) 95 (|has| $ (-6 -4522))) (($ $ (-568) $) 117)) (-2257 ((|#1| $ |#1|) 104 (|has| $ (-6 -4522)))) (-1706 ((|#1| $ |#1|) 99 (|has| $ (-6 -4522)))) (-2438 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4522))) ((|#1| $ "first" |#1|) 101 (|has| $ (-6 -4522))) (($ $ "rest" $) 103 (|has| $ (-6 -4522))) ((|#1| $ "last" |#1|) 106 (|has| $ (-6 -4522))) ((|#1| $ (-1210 (-568)) |#1|) 86 (|has| $ (-6 -4522))) ((|#1| $ (-568) |#1|) 52 (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) NIL (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) |#1|) $) 55)) (-1681 ((|#1| $) NIL)) (-4490 (($) NIL T CONST)) (-2584 (($ $) 14)) (-3936 (($ $) 28) (($ $ (-763)) 85)) (-4034 (((-121) (-634 |#1|) $) 112 (|has| |#1| (-1090)))) (-3308 (($ (-634 |#1|)) 109)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-4330 (($ |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) 54)) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1292 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-568)) NIL)) (-1340 (((-121) $) NIL)) (-3317 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-3496 (((-1249) (-568) $) 116 (|has| |#1| (-1090)))) (-1841 (((-763) $) 114)) (-3534 (((-634 $) $) NIL)) (-3606 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1851 (($ (-763) |#1|) NIL)) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) NIL (|has| (-568) (-842)))) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3631 (((-568) $) NIL (|has| (-568) (-842)))) (-2253 (($ (-1 |#1| |#1|) $) 70 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 60) (($ (-1 |#1| |#1| |#1|) $ $) 64)) (-3796 (((-121) $ (-763)) NIL)) (-4081 (((-634 |#1|) $) NIL)) (-3319 (((-121) $) NIL)) (-2798 (($ $) 87)) (-1898 (((-121) $) 13)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4164 ((|#1| $) NIL) (($ $ (-763)) NIL)) (-4124 (($ $ $ (-568)) NIL) (($ |#1| $ (-568)) NIL)) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) 71)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-2783 (($ (-1 |#1|)) 119) (($ (-1 |#1| |#1|) |#1|) 120)) (-2616 ((|#1| $) 10)) (-3877 ((|#1| $) 27) (($ $ (-763)) 46)) (-2912 (((-2 (|:| |cycle?| (-121)) (|:| -3392 (-763)) (|:| |period| (-763))) (-763) $) 24)) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-2796 (($ (-1 (-121) |#1|) $) 121)) (-2800 (($ (-1 (-121) |#1|) $) 122)) (-2490 (($ $ |#1|) 65 (|has| $ (-6 -4522)))) (-2168 (($ $ (-568)) 31)) (-4049 (((-121) $) 69)) (-3817 (((-121) $) 12)) (-2818 (((-121) $) 113)) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 20)) (-1801 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) NIL)) (-2436 (((-121) $) 15)) (-1990 (($) 40)) (-2781 ((|#1| $ "value") NIL) ((|#1| $ "first") NIL) (($ $ "rest") NIL) ((|#1| $ "last") NIL) (($ $ (-1210 (-568))) NIL) ((|#1| $ (-568)) 51) ((|#1| $ (-568) |#1|) NIL)) (-1665 (((-568) $ $) 45)) (-2828 (($ $ (-1210 (-568))) NIL) (($ $ (-568)) NIL)) (-1922 (($ (-1 $)) 44)) (-2763 (((-121) $) 66)) (-3903 (($ $) 67)) (-1499 (($ $) 96 (|has| $ (-6 -4522)))) (-3535 (((-763) $) NIL)) (-4424 (($ $) NIL)) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) 41)) (-4280 (((-541) $) NIL (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) 50)) (-3856 (($ |#1| $) 94)) (-1876 (($ $ $) 97 (|has| $ (-6 -4522))) (($ $ |#1|) 98 (|has| $ (-6 -4522)))) (-2770 (($ $ $) 75) (($ |#1| $) 42) (($ (-634 $)) 80) (($ $ |#1|) 74)) (-2188 (($ $) 47)) (-2747 (((-850) $) 39 (|has| |#1| (-1090))) (($ (-634 |#1|)) 108)) (-3180 (((-634 $) $) NIL)) (-3873 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 111 (|has| |#1| (-1090)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-1141 |#1|) (-13 (-665 |#1|) (-10 -8 (-6 -4522) (-15 -2747 ($ (-634 |#1|))) (-15 -3308 ($ (-634 |#1|))) (IF (|has| |#1| (-1090)) (-15 -4034 ((-121) (-634 |#1|) $)) |noBranch|) (-15 -2912 ((-2 (|:| |cycle?| (-121)) (|:| -3392 (-763)) (|:| |period| (-763))) (-763) $)) (-15 -1922 ($ (-1 $))) (-15 -3856 ($ |#1| $)) (IF (|has| |#1| (-1090)) (PROGN (-15 -3496 ((-1249) (-568) $)) (-15 -1482 ((-850) $)) (-15 -3589 ((-121)))) |noBranch|) (-15 -1958 ($ $ (-568) $)) (-15 -2783 ($ (-1 |#1|))) (-15 -2783 ($ (-1 |#1| |#1|) |#1|)) (-15 -2796 ($ (-1 (-121) |#1|) $)) (-15 -2800 ($ (-1 (-121) |#1|) $)))) (-1195)) (T -1141)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-1141 *3)))) (-3308 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-1141 *3)))) (-4034 (*1 *2 *3 *1) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1090)) (-4 *4 (-1195)) (-5 *2 (-121)) (-5 *1 (-1141 *4)))) (-2912 (*1 *2 *3 *1) (-12 (-5 *2 (-2 (|:| |cycle?| (-121)) (|:| -3392 (-763)) (|:| |period| (-763)))) (-5 *1 (-1141 *4)) (-4 *4 (-1195)) (-5 *3 (-763)))) (-1922 (*1 *1 *2) (-12 (-5 *2 (-1 (-1141 *3))) (-5 *1 (-1141 *3)) (-4 *3 (-1195)))) (-3856 (*1 *1 *2 *1) (-12 (-5 *1 (-1141 *2)) (-4 *2 (-1195)))) (-3496 (*1 *2 *3 *1) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-1141 *4)) (-4 *4 (-1090)) (-4 *4 (-1195)))) (-1482 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1141 *3)) (-4 *3 (-1090)) (-4 *3 (-1195)))) (-3589 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1141 *3)) (-4 *3 (-1090)) (-4 *3 (-1195)))) (-1958 (*1 *1 *1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1141 *3)) (-4 *3 (-1195)))) (-2783 (*1 *1 *2) (-12 (-5 *2 (-1 *3)) (-4 *3 (-1195)) (-5 *1 (-1141 *3)))) (-2783 (*1 *1 *2 *3) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1195)) (-5 *1 (-1141 *3)))) (-2796 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1195)) (-5 *1 (-1141 *3)))) (-2800 (*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1195)) (-5 *1 (-1141 *3))))) 
+(-13 (-665 |#1|) (-10 -8 (-6 -4522) (-15 -2747 ($ (-634 |#1|))) (-15 -3308 ($ (-634 |#1|))) (IF (|has| |#1| (-1090)) (-15 -4034 ((-121) (-634 |#1|) $)) |noBranch|) (-15 -2912 ((-2 (|:| |cycle?| (-121)) (|:| -3392 (-763)) (|:| |period| (-763))) (-763) $)) (-15 -1922 ($ (-1 $))) (-15 -3856 ($ |#1| $)) (IF (|has| |#1| (-1090)) (PROGN (-15 -3496 ((-1249) (-568) $)) (-15 -1482 ((-850) $)) (-15 -3589 ((-121)))) |noBranch|) (-15 -1958 ($ $ (-568) $)) (-15 -2783 ($ (-1 |#1|))) (-15 -2783 ($ (-1 |#1| |#1|) |#1|)) (-15 -2796 ($ (-1 (-121) |#1|) $)) (-15 -2800 ($ (-1 (-121) |#1|) $)))) 
+((-2449 (((-121) $ $) 18)) (-2499 (($ $) 113)) (-3083 (($ $) 114)) (-1474 (($ $ (-147)) 101) (($ $ (-142)) 100)) (-2481 (((-1249) $ (-568) (-568)) 37 (|has| $ (-6 -4522)))) (-3675 (((-121) $ $) 111)) (-3762 (((-121) $ $ (-568)) 110)) (-1744 (($ (-568)) 118)) (-4446 (((-634 $) $ (-147)) 103) (((-634 $) $ (-142)) 102)) (-1324 (((-121) (-1 (-121) (-147) (-147)) $) 91) (((-121) $) 85 (|has| (-147) (-842)))) (-2109 (($ (-1 (-121) (-147) (-147)) $) 82 (|has| $ (-6 -4522))) (($ $) 81 (-12 (|has| (-147) (-842)) (|has| $ (-6 -4522))))) (-3647 (($ (-1 (-121) (-147) (-147)) $) 92) (($ $) 86 (|has| (-147) (-842)))) (-1667 (((-121) $ (-763)) 8)) (-2438 (((-147) $ (-568) (-147)) 49 (|has| $ (-6 -4522))) (((-147) $ (-1210 (-568)) (-147)) 53 (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) (-147)) $) 70 (|has| $ (-6 -4521)))) (-4490 (($) 7 T CONST)) (-1871 (($ $ (-147)) 97) (($ $ (-142)) 96)) (-4452 (($ $) 83 (|has| $ (-6 -4522)))) (-3945 (($ $) 93)) (-3943 (($ $ (-1210 (-568)) $) 107)) (-3926 (($ $) 73 (-12 (|has| (-147) (-1090)) (|has| $ (-6 -4521))))) (-4330 (($ (-147) $) 72 (-12 (|has| (-147) (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) (-147)) $) 69 (|has| $ (-6 -4521)))) (-3094 (((-147) (-1 (-147) (-147) (-147)) $ (-147) (-147)) 71 (-12 (|has| (-147) (-1090)) (|has| $ (-6 -4521)))) (((-147) (-1 (-147) (-147) (-147)) $ (-147)) 68 (|has| $ (-6 -4521))) (((-147) (-1 (-147) (-147) (-147)) $) 67 (|has| $ (-6 -4521)))) (-1292 (((-147) $ (-568) (-147)) 50 (|has| $ (-6 -4522)))) (-2069 (((-147) $ (-568)) 48)) (-3768 (((-121) $ $) 112)) (-2766 (((-568) (-1 (-121) (-147)) $) 90) (((-568) (-147) $) 89 (|has| (-147) (-1090))) (((-568) (-147) $ (-568)) 88 (|has| (-147) (-1090))) (((-568) $ $ (-568)) 106) (((-568) (-142) $ (-568)) 105)) (-3317 (((-634 (-147)) $) 30 (|has| $ (-6 -4521)))) (-1851 (($ (-763) (-147)) 64)) (-3791 (((-121) $ (-763)) 9)) (-2539 (((-568) $) 40 (|has| (-568) (-842)))) (-1732 (($ $ $) 80 (|has| (-147) (-842)))) (-3645 (($ (-1 (-121) (-147) (-147)) $ $) 94) (($ $ $) 87 (|has| (-147) (-842)))) (-4406 (((-634 (-147)) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) (-147) $) 27 (-12 (|has| (-147) (-1090)) (|has| $ (-6 -4521))))) (-3631 (((-568) $) 41 (|has| (-568) (-842)))) (-2047 (($ $ $) 79 (|has| (-147) (-842)))) (-4065 (((-121) $ $ (-147)) 108)) (-4439 (((-763) $ $ (-147)) 109)) (-2253 (($ (-1 (-147) (-147)) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-147) (-147)) $) 35) (($ (-1 (-147) (-147) (-147)) $ $) 59)) (-2739 (($ $) 115)) (-4499 (($ $) 116)) (-3796 (((-121) $ (-763)) 10)) (-3384 (($ $ (-147)) 99) (($ $ (-142)) 98)) (-1893 (((-1143) $) 22)) (-4124 (($ (-147) $ (-568)) 55) (($ $ $ (-568)) 54)) (-3948 (((-634 (-568)) $) 43)) (-2916 (((-121) (-568) $) 44)) (-4025 (((-1108) $) 21)) (-3877 (((-147) $) 39 (|has| (-568) (-842)))) (-2712 (((-3 (-147) "failed") (-1 (-121) (-147)) $) 66)) (-2490 (($ $ (-147)) 38 (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) (-147)) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-147)))) 26 (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-288 (-147))) 25 (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-147) (-147)) 24 (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-634 (-147)) (-634 (-147))) 23 (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090))))) (-1702 (((-121) $ $) 14)) (-1801 (((-121) (-147) $) 42 (-12 (|has| $ (-6 -4521)) (|has| (-147) (-1090))))) (-1480 (((-634 (-147)) $) 45)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 (((-147) $ (-568) (-147)) 47) (((-147) $ (-568)) 46) (($ $ (-1210 (-568))) 58) (($ $ $) 95)) (-2828 (($ $ (-568)) 57) (($ $ (-1210 (-568))) 56)) (-4170 (((-763) (-1 (-121) (-147)) $) 31 (|has| $ (-6 -4521))) (((-763) (-147) $) 28 (-12 (|has| (-147) (-1090)) (|has| $ (-6 -4521))))) (-3306 (($ $ $ (-568)) 84 (|has| $ (-6 -4522)))) (-3865 (($ $) 13)) (-4280 (((-541) $) 74 (|has| (-147) (-609 (-541))))) (-4289 (($ (-634 (-147))) 65)) (-2770 (($ $ (-147)) 63) (($ (-147) $) 62) (($ $ $) 61) (($ (-634 $)) 60)) (-2747 (($ (-147)) 104) (((-850) $) 20)) (-3437 (((-121) (-1 (-121) (-147)) $) 33 (|has| $ (-6 -4521)))) (-2628 (((-1143) $) 122) (((-1143) $ (-121)) 121) (((-1249) (-817) $) 120) (((-1249) (-817) $ (-121)) 119)) (-1753 (((-121) $ $) 77 (|has| (-147) (-842)))) (-1740 (((-121) $ $) 76 (|has| (-147) (-842)))) (-1719 (((-121) $ $) 19)) (-1747 (((-121) $ $) 78 (|has| (-147) (-842)))) (-1734 (((-121) $ $) 75 (|has| (-147) (-842)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-1142) (-1275)) (T -1142)) 
-((-1742 (*1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-1142))))) 
-(-13 (-1129) (-1090) (-823) (-10 -8 (-15 -1742 ($ (-568))))) 
+((-1744 (*1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-1142))))) 
+(-13 (-1129) (-1090) (-823) (-10 -8 (-15 -1744 ($ (-568))))) 
 (((-39) . T) ((-105) . T) ((-608 (-850)) . T) ((-154 (-147)) . T) ((-609 (-541)) |has| (-147) (-609 (-541))) ((-281 (-568) (-147)) . T) ((-283 (-568) (-147)) . T) ((-303 (-147)) -12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090))) ((-375 (-147)) . T) ((-499 (-147)) . T) ((-601 (-568) (-147)) . T) ((-523 (-147) (-147)) -12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090))) ((-640 (-147)) . T) ((-19 (-147)) . T) ((-823) . T) ((-842) |has| (-147) (-842)) ((-1090) . T) ((-1129) . T) ((-1195) . T)) 
-((-2447 (((-121) $ $) NIL)) (-1873 (($ $) NIL)) (-2072 (($ $) NIL)) (-4403 (($ $ (-147)) NIL) (($ $ (-142)) NIL)) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-3673 (((-121) $ $) NIL)) (-3760 (((-121) $ $ (-568)) NIL)) (-1742 (($ (-568)) 7)) (-3969 (((-634 $) $ (-147)) NIL) (((-634 $) $ (-142)) NIL)) (-2016 (((-121) (-1 (-121) (-147) (-147)) $) NIL) (((-121) $) NIL (|has| (-147) (-842)))) (-3908 (($ (-1 (-121) (-147) (-147)) $) NIL (|has| $ (-6 -4520))) (($ $) NIL (-12 (|has| $ (-6 -4520)) (|has| (-147) (-842))))) (-3644 (($ (-1 (-121) (-147) (-147)) $) NIL) (($ $) NIL (|has| (-147) (-842)))) (-2510 (((-121) $ (-763)) NIL)) (-2436 (((-147) $ (-568) (-147)) NIL (|has| $ (-6 -4520))) (((-147) $ (-1210 (-568)) (-147)) NIL (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4519)))) (-2671 (($) NIL T CONST)) (-1869 (($ $ (-147)) NIL) (($ $ (-142)) NIL)) (-1578 (($ $) NIL (|has| $ (-6 -4520)))) (-3943 (($ $) NIL)) (-1386 (($ $ (-1210 (-568)) $) NIL)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-147) (-1090))))) (-4328 (($ (-147) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-147) (-1090)))) (($ (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4519)))) (-3092 (((-147) (-1 (-147) (-147) (-147)) $ (-147) (-147)) NIL (-12 (|has| $ (-6 -4519)) (|has| (-147) (-1090)))) (((-147) (-1 (-147) (-147) (-147)) $ (-147)) NIL (|has| $ (-6 -4519))) (((-147) (-1 (-147) (-147) (-147)) $) NIL (|has| $ (-6 -4519)))) (-3989 (((-147) $ (-568) (-147)) NIL (|has| $ (-6 -4520)))) (-2602 (((-147) $ (-568)) NIL)) (-3766 (((-121) $ $) NIL)) (-2764 (((-568) (-1 (-121) (-147)) $) NIL) (((-568) (-147) $) NIL (|has| (-147) (-1090))) (((-568) (-147) $ (-568)) NIL (|has| (-147) (-1090))) (((-568) $ $ (-568)) NIL) (((-568) (-142) $ (-568)) NIL)) (-4360 (((-634 (-147)) $) NIL (|has| $ (-6 -4519)))) (-1849 (($ (-763) (-147)) NIL)) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) NIL (|has| (-568) (-842)))) (-2521 (($ $ $) NIL (|has| (-147) (-842)))) (-1347 (($ (-1 (-121) (-147) (-147)) $ $) NIL) (($ $ $) NIL (|has| (-147) (-842)))) (-1979 (((-634 (-147)) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) (-147) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-147) (-1090))))) (-2223 (((-568) $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (|has| (-147) (-842)))) (-4062 (((-121) $ $ (-147)) NIL)) (-2661 (((-763) $ $ (-147)) NIL)) (-3674 (($ (-1 (-147) (-147)) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-147) (-147)) $) NIL) (($ (-1 (-147) (-147) (-147)) $ $) NIL)) (-2496 (($ $) NIL)) (-2003 (($ $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-3382 (($ $ (-147)) NIL) (($ $ (-142)) NIL)) (-4487 (((-1143) $) NIL)) (-4122 (($ (-147) $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4022 (((-1108) $) NIL)) (-3876 (((-147) $) NIL (|has| (-568) (-842)))) (-3775 (((-3 (-147) "failed") (-1 (-121) (-147)) $) NIL)) (-3724 (($ $ (-147)) NIL (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-147)))) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-288 (-147))) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-147) (-147)) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-634 (-147)) (-634 (-147))) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) (-147) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-147) (-1090))))) (-2041 (((-634 (-147)) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 (((-147) $ (-568) (-147)) NIL) (((-147) $ (-568)) NIL) (($ $ (-1210 (-568))) NIL) (($ $ $) NIL)) (-2826 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-4168 (((-763) (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4519))) (((-763) (-147) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-147) (-1090))))) (-2256 (($ $ $ (-568)) NIL (|has| $ (-6 -4520)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| (-147) (-609 (-541))))) (-4287 (($ (-634 (-147))) NIL)) (-2768 (($ $ (-147)) NIL) (($ (-147) $) NIL) (($ $ $) NIL) (($ (-634 $)) NIL)) (-2745 (($ (-147)) NIL) (((-850) $) NIL)) (-1319 (((-121) (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4519)))) (-3754 (((-1143) $) 18) (((-1143) $ (-121)) 20) (((-1249) (-817) $) 21) (((-1249) (-817) $ (-121)) 22)) (-1751 (((-121) $ $) NIL (|has| (-147) (-842)))) (-1738 (((-121) $ $) NIL (|has| (-147) (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| (-147) (-842)))) (-1732 (((-121) $ $) NIL (|has| (-147) (-842)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL)) (-2499 (($ $) NIL)) (-3083 (($ $) NIL)) (-1474 (($ $ (-147)) NIL) (($ $ (-142)) NIL)) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-3675 (((-121) $ $) NIL)) (-3762 (((-121) $ $ (-568)) NIL)) (-1744 (($ (-568)) 7)) (-4446 (((-634 $) $ (-147)) NIL) (((-634 $) $ (-142)) NIL)) (-1324 (((-121) (-1 (-121) (-147) (-147)) $) NIL) (((-121) $) NIL (|has| (-147) (-842)))) (-2109 (($ (-1 (-121) (-147) (-147)) $) NIL (|has| $ (-6 -4522))) (($ $) NIL (-12 (|has| $ (-6 -4522)) (|has| (-147) (-842))))) (-3647 (($ (-1 (-121) (-147) (-147)) $) NIL) (($ $) NIL (|has| (-147) (-842)))) (-1667 (((-121) $ (-763)) NIL)) (-2438 (((-147) $ (-568) (-147)) NIL (|has| $ (-6 -4522))) (((-147) $ (-1210 (-568)) (-147)) NIL (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4521)))) (-4490 (($) NIL T CONST)) (-1871 (($ $ (-147)) NIL) (($ $ (-142)) NIL)) (-4452 (($ $) NIL (|has| $ (-6 -4522)))) (-3945 (($ $) NIL)) (-3943 (($ $ (-1210 (-568)) $) NIL)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-147) (-1090))))) (-4330 (($ (-147) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-147) (-1090)))) (($ (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4521)))) (-3094 (((-147) (-1 (-147) (-147) (-147)) $ (-147) (-147)) NIL (-12 (|has| $ (-6 -4521)) (|has| (-147) (-1090)))) (((-147) (-1 (-147) (-147) (-147)) $ (-147)) NIL (|has| $ (-6 -4521))) (((-147) (-1 (-147) (-147) (-147)) $) NIL (|has| $ (-6 -4521)))) (-1292 (((-147) $ (-568) (-147)) NIL (|has| $ (-6 -4522)))) (-2069 (((-147) $ (-568)) NIL)) (-3768 (((-121) $ $) NIL)) (-2766 (((-568) (-1 (-121) (-147)) $) NIL) (((-568) (-147) $) NIL (|has| (-147) (-1090))) (((-568) (-147) $ (-568)) NIL (|has| (-147) (-1090))) (((-568) $ $ (-568)) NIL) (((-568) (-142) $ (-568)) NIL)) (-3317 (((-634 (-147)) $) NIL (|has| $ (-6 -4521)))) (-1851 (($ (-763) (-147)) NIL)) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) NIL (|has| (-568) (-842)))) (-1732 (($ $ $) NIL (|has| (-147) (-842)))) (-3645 (($ (-1 (-121) (-147) (-147)) $ $) NIL) (($ $ $) NIL (|has| (-147) (-842)))) (-4406 (((-634 (-147)) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) (-147) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-147) (-1090))))) (-3631 (((-568) $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (|has| (-147) (-842)))) (-4065 (((-121) $ $ (-147)) NIL)) (-4439 (((-763) $ $ (-147)) NIL)) (-2253 (($ (-1 (-147) (-147)) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-147) (-147)) $) NIL) (($ (-1 (-147) (-147) (-147)) $ $) NIL)) (-2739 (($ $) NIL)) (-4499 (($ $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-3384 (($ $ (-147)) NIL) (($ $ (-142)) NIL)) (-1893 (((-1143) $) NIL)) (-4124 (($ (-147) $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4025 (((-1108) $) NIL)) (-3877 (((-147) $) NIL (|has| (-568) (-842)))) (-2712 (((-3 (-147) "failed") (-1 (-121) (-147)) $) NIL)) (-2490 (($ $ (-147)) NIL (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-147)))) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-288 (-147))) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-147) (-147)) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090)))) (($ $ (-634 (-147)) (-634 (-147))) NIL (-12 (|has| (-147) (-303 (-147))) (|has| (-147) (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) (-147) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-147) (-1090))))) (-1480 (((-634 (-147)) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 (((-147) $ (-568) (-147)) NIL) (((-147) $ (-568)) NIL) (($ $ (-1210 (-568))) NIL) (($ $ $) NIL)) (-2828 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-4170 (((-763) (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4521))) (((-763) (-147) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-147) (-1090))))) (-3306 (($ $ $ (-568)) NIL (|has| $ (-6 -4522)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| (-147) (-609 (-541))))) (-4289 (($ (-634 (-147))) NIL)) (-2770 (($ $ (-147)) NIL) (($ (-147) $) NIL) (($ $ $) NIL) (($ (-634 $)) NIL)) (-2747 (($ (-147)) NIL) (((-850) $) NIL)) (-3437 (((-121) (-1 (-121) (-147)) $) NIL (|has| $ (-6 -4521)))) (-2628 (((-1143) $) 18) (((-1143) $ (-121)) 20) (((-1249) (-817) $) 21) (((-1249) (-817) $ (-121)) 22)) (-1753 (((-121) $ $) NIL (|has| (-147) (-842)))) (-1740 (((-121) $ $) NIL (|has| (-147) (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| (-147) (-842)))) (-1734 (((-121) $ $) NIL (|has| (-147) (-842)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
 (((-1143) (-1142)) (T -1143)) 
 NIL 
 (-1142) 
-((-2447 (((-121) $ $) NIL (-2198 (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090)) (|has| |#1| (-1090))))) (-2986 (($) NIL) (($ (-634 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)))) NIL)) (-1868 (((-1249) $ (-1143) (-1143)) NIL (|has| $ (-6 -4520)))) (-2510 (((-121) $ (-763)) NIL)) (-2436 ((|#1| $ (-1143) |#1|) NIL)) (-3507 (($ (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL (|has| $ (-6 -4519)))) (-2674 (((-3 |#1| "failed") (-1143) $) NIL)) (-2671 (($) NIL T CONST)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090))))) (-3405 (($ (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) $) NIL (|has| $ (-6 -4519))) (($ (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL (|has| $ (-6 -4519))) (((-3 |#1| "failed") (-1143) $) NIL)) (-4328 (($ (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090)))) (($ (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL (|has| $ (-6 -4519)))) (-3092 (((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $ (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090)))) (((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $ (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) NIL (|has| $ (-6 -4519))) (((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL (|has| $ (-6 -4519)))) (-3989 ((|#1| $ (-1143) |#1|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-1143)) NIL)) (-4360 (((-634 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL (|has| $ (-6 -4519))) (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-1143) $) NIL (|has| (-1143) (-842)))) (-1979 (((-634 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL (|has| $ (-6 -4519))) (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090)))) (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2223 (((-1143) $) NIL (|has| (-1143) (-842)))) (-3674 (($ (-1 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL (|has| $ (-6 -4520))) (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL) (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (-2198 (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090)) (|has| |#1| (-1090))))) (-1946 (((-634 (-1143)) $) NIL)) (-3548 (((-121) (-1143) $) NIL)) (-1890 (((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) $) NIL)) (-4450 (($ (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) $) NIL)) (-4174 (((-634 (-1143)) $) NIL)) (-3578 (((-121) (-1143) $) NIL)) (-4022 (((-1108) $) NIL (-2198 (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090)) (|has| |#1| (-1090))))) (-3876 ((|#1| $) NIL (|has| (-1143) (-842)))) (-3775 (((-3 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) "failed") (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL)) (-3724 (($ $ |#1|) NIL (|has| $ (-6 -4520)))) (-1315 (((-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) $) NIL)) (-1387 (((-121) (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))))) NIL (-12 (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-303 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)))) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090)))) (($ $ (-288 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)))) NIL (-12 (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-303 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)))) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090)))) (($ $ (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) NIL (-12 (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-303 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)))) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090)))) (($ $ (-634 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) (-634 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)))) NIL (-12 (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-303 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)))) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#1| $ (-1143)) NIL) ((|#1| $ (-1143) |#1|) NIL)) (-2085 (($) NIL) (($ (-634 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)))) NIL)) (-4168 (((-763) (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL (|has| $ (-6 -4519))) (((-763) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090)))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-609 (-541))))) (-4287 (($ (-634 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)))) NIL)) (-2745 (((-850) $) NIL (-2198 (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090)) (|has| |#1| (-1090))))) (-2367 (($ (-634 (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)))) NIL)) (-1319 (((-121) (-1 (-121) (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|))) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) NIL (-2198 (|has| (-2 (|:| -3649 (-1143)) (|:| -4083 |#1|)) (-1090)) (|has| |#1| (-1090))))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-1144 |#1|) (-13 (-1172 (-1143) |#1|) (-10 -7 (-6 -4519))) (-1090)) (T -1144)) 
-NIL 
-(-13 (-1172 (-1143) |#1|) (-10 -7 (-6 -4519))) 
-((-2129 (((-1141 |#1|) (-1141 |#1|)) 77)) (-2925 (((-3 (-1141 |#1|) "failed") (-1141 |#1|)) 37)) (-1973 (((-1141 |#1|) (-409 (-568)) (-1141 |#1|)) 117 (|has| |#1| (-43 (-409 (-568)))))) (-3741 (((-1141 |#1|) |#1| (-1141 |#1|)) 121 (|has| |#1| (-365)))) (-2011 (((-1141 |#1|) (-1141 |#1|)) 90)) (-2509 (((-1141 (-568)) (-568)) 57)) (-1976 (((-1141 |#1|) (-1141 (-1141 |#1|))) 108 (|has| |#1| (-43 (-409 (-568)))))) (-2651 (((-1141 |#1|) (-568) (-568) (-1141 |#1|)) 95)) (-2354 (((-1141 |#1|) |#1| (-568)) 45)) (-1276 (((-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) 60)) (-3095 (((-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) 119 (|has| |#1| (-365)))) (-3358 (((-1141 |#1|) |#1| (-1 (-1141 |#1|))) 107 (|has| |#1| (-43 (-409 (-568)))))) (-3749 (((-1141 |#1|) (-1 |#1| (-568)) |#1| (-1 (-1141 |#1|))) 120 (|has| |#1| (-365)))) (-3730 (((-1141 |#1|) (-1141 |#1|)) 89)) (-2608 (((-1141 |#1|) (-1141 |#1|)) 76)) (-4053 (((-1141 |#1|) (-568) (-568) (-1141 |#1|)) 96)) (-3837 (((-1141 |#1|) |#1| (-1141 |#1|)) 105 (|has| |#1| (-43 (-409 (-568)))))) (-2185 (((-1141 (-568)) (-568)) 56)) (-2178 (((-1141 |#1|) |#1|) 59)) (-2224 (((-1141 |#1|) (-1141 |#1|) (-568) (-568)) 92)) (-3771 (((-1141 |#1|) (-1 |#1| (-568)) (-1141 |#1|)) 66)) (-2595 (((-3 (-1141 |#1|) "failed") (-1141 |#1|) (-1141 |#1|)) 35)) (-2372 (((-1141 |#1|) (-1141 |#1|)) 91)) (-1339 (((-1141 |#1|) (-1141 |#1|) |#1|) 71)) (-2023 (((-1141 |#1|) (-1141 |#1|)) 62)) (-1474 (((-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) 72)) (-2745 (((-1141 |#1|) |#1|) 67)) (-3099 (((-1141 |#1|) (-1141 (-1141 |#1|))) 82)) (-1779 (((-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) 36)) (-1773 (((-1141 |#1|) (-1141 |#1|)) 21) (((-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) 23)) (-1767 (((-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) 17)) (* (((-1141 |#1|) (-1141 |#1|) |#1|) 29) (((-1141 |#1|) |#1| (-1141 |#1|)) 26) (((-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) 27))) 
-(((-1145 |#1|) (-10 -7 (-15 -1767 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -1773 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -1773 ((-1141 |#1|) (-1141 |#1|))) (-15 * ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 * ((-1141 |#1|) |#1| (-1141 |#1|))) (-15 * ((-1141 |#1|) (-1141 |#1|) |#1|)) (-15 -2595 ((-3 (-1141 |#1|) "failed") (-1141 |#1|) (-1141 |#1|))) (-15 -1779 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -2925 ((-3 (-1141 |#1|) "failed") (-1141 |#1|))) (-15 -2354 ((-1141 |#1|) |#1| (-568))) (-15 -2185 ((-1141 (-568)) (-568))) (-15 -2509 ((-1141 (-568)) (-568))) (-15 -2178 ((-1141 |#1|) |#1|)) (-15 -1276 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -2023 ((-1141 |#1|) (-1141 |#1|))) (-15 -3771 ((-1141 |#1|) (-1 |#1| (-568)) (-1141 |#1|))) (-15 -2745 ((-1141 |#1|) |#1|)) (-15 -1339 ((-1141 |#1|) (-1141 |#1|) |#1|)) (-15 -1474 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -2608 ((-1141 |#1|) (-1141 |#1|))) (-15 -2129 ((-1141 |#1|) (-1141 |#1|))) (-15 -3099 ((-1141 |#1|) (-1141 (-1141 |#1|)))) (-15 -3730 ((-1141 |#1|) (-1141 |#1|))) (-15 -2011 ((-1141 |#1|) (-1141 |#1|))) (-15 -2372 ((-1141 |#1|) (-1141 |#1|))) (-15 -2224 ((-1141 |#1|) (-1141 |#1|) (-568) (-568))) (-15 -2651 ((-1141 |#1|) (-568) (-568) (-1141 |#1|))) (-15 -4053 ((-1141 |#1|) (-568) (-568) (-1141 |#1|))) (IF (|has| |#1| (-43 (-409 (-568)))) (PROGN (-15 -3837 ((-1141 |#1|) |#1| (-1141 |#1|))) (-15 -3358 ((-1141 |#1|) |#1| (-1 (-1141 |#1|)))) (-15 -1976 ((-1141 |#1|) (-1141 (-1141 |#1|)))) (-15 -1973 ((-1141 |#1|) (-409 (-568)) (-1141 |#1|)))) |noBranch|) (IF (|has| |#1| (-365)) (PROGN (-15 -3095 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -3749 ((-1141 |#1|) (-1 |#1| (-568)) |#1| (-1 (-1141 |#1|)))) (-15 -3741 ((-1141 |#1|) |#1| (-1141 |#1|)))) |noBranch|)) (-1047)) (T -1145)) 
-((-3741 (*1 *2 *3 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-3749 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *4 (-568))) (-5 *5 (-1 (-1141 *4))) (-4 *4 (-365)) (-4 *4 (-1047)) (-5 *2 (-1141 *4)) (-5 *1 (-1145 *4)))) (-3095 (*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-1973 (*1 *2 *3 *2) (-12 (-5 *2 (-1141 *4)) (-4 *4 (-43 *3)) (-4 *4 (-1047)) (-5 *3 (-409 (-568))) (-5 *1 (-1145 *4)))) (-1976 (*1 *2 *3) (-12 (-5 *3 (-1141 (-1141 *4))) (-5 *2 (-1141 *4)) (-5 *1 (-1145 *4)) (-4 *4 (-43 (-409 (-568)))) (-4 *4 (-1047)))) (-3358 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-1141 *3))) (-5 *2 (-1141 *3)) (-5 *1 (-1145 *3)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)))) (-3837 (*1 *2 *3 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-4053 (*1 *2 *3 *3 *2) (-12 (-5 *2 (-1141 *4)) (-5 *3 (-568)) (-4 *4 (-1047)) (-5 *1 (-1145 *4)))) (-2651 (*1 *2 *3 *3 *2) (-12 (-5 *2 (-1141 *4)) (-5 *3 (-568)) (-4 *4 (-1047)) (-5 *1 (-1145 *4)))) (-2224 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-1141 *4)) (-5 *3 (-568)) (-4 *4 (-1047)) (-5 *1 (-1145 *4)))) (-2372 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-2011 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-3730 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-3099 (*1 *2 *3) (-12 (-5 *3 (-1141 (-1141 *4))) (-5 *2 (-1141 *4)) (-5 *1 (-1145 *4)) (-4 *4 (-1047)))) (-2129 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-2608 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-1474 (*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-1339 (*1 *2 *2 *3) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-2745 (*1 *2 *3) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-1145 *3)) (-4 *3 (-1047)))) (-3771 (*1 *2 *3 *2) (-12 (-5 *2 (-1141 *4)) (-5 *3 (-1 *4 (-568))) (-4 *4 (-1047)) (-5 *1 (-1145 *4)))) (-2023 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-1276 (*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-2178 (*1 *2 *3) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-1145 *3)) (-4 *3 (-1047)))) (-2509 (*1 *2 *3) (-12 (-5 *2 (-1141 (-568))) (-5 *1 (-1145 *4)) (-4 *4 (-1047)) (-5 *3 (-568)))) (-2185 (*1 *2 *3) (-12 (-5 *2 (-1141 (-568))) (-5 *1 (-1145 *4)) (-4 *4 (-1047)) (-5 *3 (-568)))) (-2354 (*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-5 *2 (-1141 *3)) (-5 *1 (-1145 *3)) (-4 *3 (-1047)))) (-2925 (*1 *2 *2) (|partial| -12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-1779 (*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-2595 (*1 *2 *2 *2) (|partial| -12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (* (*1 *2 *2 *3) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (* (*1 *2 *3 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (* (*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-1773 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-1773 (*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-1767 (*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3))))) 
-(-10 -7 (-15 -1767 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -1773 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -1773 ((-1141 |#1|) (-1141 |#1|))) (-15 * ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 * ((-1141 |#1|) |#1| (-1141 |#1|))) (-15 * ((-1141 |#1|) (-1141 |#1|) |#1|)) (-15 -2595 ((-3 (-1141 |#1|) "failed") (-1141 |#1|) (-1141 |#1|))) (-15 -1779 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -2925 ((-3 (-1141 |#1|) "failed") (-1141 |#1|))) (-15 -2354 ((-1141 |#1|) |#1| (-568))) (-15 -2185 ((-1141 (-568)) (-568))) (-15 -2509 ((-1141 (-568)) (-568))) (-15 -2178 ((-1141 |#1|) |#1|)) (-15 -1276 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -2023 ((-1141 |#1|) (-1141 |#1|))) (-15 -3771 ((-1141 |#1|) (-1 |#1| (-568)) (-1141 |#1|))) (-15 -2745 ((-1141 |#1|) |#1|)) (-15 -1339 ((-1141 |#1|) (-1141 |#1|) |#1|)) (-15 -1474 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -2608 ((-1141 |#1|) (-1141 |#1|))) (-15 -2129 ((-1141 |#1|) (-1141 |#1|))) (-15 -3099 ((-1141 |#1|) (-1141 (-1141 |#1|)))) (-15 -3730 ((-1141 |#1|) (-1141 |#1|))) (-15 -2011 ((-1141 |#1|) (-1141 |#1|))) (-15 -2372 ((-1141 |#1|) (-1141 |#1|))) (-15 -2224 ((-1141 |#1|) (-1141 |#1|) (-568) (-568))) (-15 -2651 ((-1141 |#1|) (-568) (-568) (-1141 |#1|))) (-15 -4053 ((-1141 |#1|) (-568) (-568) (-1141 |#1|))) (IF (|has| |#1| (-43 (-409 (-568)))) (PROGN (-15 -3837 ((-1141 |#1|) |#1| (-1141 |#1|))) (-15 -3358 ((-1141 |#1|) |#1| (-1 (-1141 |#1|)))) (-15 -1976 ((-1141 |#1|) (-1141 (-1141 |#1|)))) (-15 -1973 ((-1141 |#1|) (-409 (-568)) (-1141 |#1|)))) |noBranch|) (IF (|has| |#1| (-365)) (PROGN (-15 -3095 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -3749 ((-1141 |#1|) (-1 |#1| (-568)) |#1| (-1 (-1141 |#1|)))) (-15 -3741 ((-1141 |#1|) |#1| (-1141 |#1|)))) |noBranch|)) 
-((-1982 (((-1141 |#1|) (-1141 |#1|)) 57)) (-1933 (((-1141 |#1|) (-1141 |#1|)) 39)) (-1974 (((-1141 |#1|) (-1141 |#1|)) 53)) (-2786 (((-1141 |#1|) (-1141 |#1|)) 35)) (-1990 (((-1141 |#1|) (-1141 |#1|)) 60)) (-1941 (((-1141 |#1|) (-1141 |#1|)) 42)) (-4416 (((-1141 |#1|) (-1141 |#1|)) 31)) (-1892 (((-1141 |#1|) (-1141 |#1|)) 27)) (-1994 (((-1141 |#1|) (-1141 |#1|)) 61)) (-1945 (((-1141 |#1|) (-1141 |#1|)) 43)) (-1986 (((-1141 |#1|) (-1141 |#1|)) 58)) (-1937 (((-1141 |#1|) (-1141 |#1|)) 40)) (-1978 (((-1141 |#1|) (-1141 |#1|)) 55)) (-2790 (((-1141 |#1|) (-1141 |#1|)) 37)) (-2006 (((-1141 |#1|) (-1141 |#1|)) 65)) (-1958 (((-1141 |#1|) (-1141 |#1|)) 47)) (-1998 (((-1141 |#1|) (-1141 |#1|)) 63)) (-1949 (((-1141 |#1|) (-1141 |#1|)) 45)) (-2014 (((-1141 |#1|) (-1141 |#1|)) 68)) (-1966 (((-1141 |#1|) (-1141 |#1|)) 50)) (-4023 (((-1141 |#1|) (-1141 |#1|)) 69)) (-1970 (((-1141 |#1|) (-1141 |#1|)) 51)) (-2010 (((-1141 |#1|) (-1141 |#1|)) 67)) (-1962 (((-1141 |#1|) (-1141 |#1|)) 49)) (-2002 (((-1141 |#1|) (-1141 |#1|)) 66)) (-1953 (((-1141 |#1|) (-1141 |#1|)) 48)) (** (((-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) 33))) 
-(((-1146 |#1|) (-10 -7 (-15 -1892 ((-1141 |#1|) (-1141 |#1|))) (-15 -4416 ((-1141 |#1|) (-1141 |#1|))) (-15 ** ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -2786 ((-1141 |#1|) (-1141 |#1|))) (-15 -2790 ((-1141 |#1|) (-1141 |#1|))) (-15 -1933 ((-1141 |#1|) (-1141 |#1|))) (-15 -1937 ((-1141 |#1|) (-1141 |#1|))) (-15 -1941 ((-1141 |#1|) (-1141 |#1|))) (-15 -1945 ((-1141 |#1|) (-1141 |#1|))) (-15 -1949 ((-1141 |#1|) (-1141 |#1|))) (-15 -1953 ((-1141 |#1|) (-1141 |#1|))) (-15 -1958 ((-1141 |#1|) (-1141 |#1|))) (-15 -1962 ((-1141 |#1|) (-1141 |#1|))) (-15 -1966 ((-1141 |#1|) (-1141 |#1|))) (-15 -1970 ((-1141 |#1|) (-1141 |#1|))) (-15 -1974 ((-1141 |#1|) (-1141 |#1|))) (-15 -1978 ((-1141 |#1|) (-1141 |#1|))) (-15 -1982 ((-1141 |#1|) (-1141 |#1|))) (-15 -1986 ((-1141 |#1|) (-1141 |#1|))) (-15 -1990 ((-1141 |#1|) (-1141 |#1|))) (-15 -1994 ((-1141 |#1|) (-1141 |#1|))) (-15 -1998 ((-1141 |#1|) (-1141 |#1|))) (-15 -2002 ((-1141 |#1|) (-1141 |#1|))) (-15 -2006 ((-1141 |#1|) (-1141 |#1|))) (-15 -2010 ((-1141 |#1|) (-1141 |#1|))) (-15 -2014 ((-1141 |#1|) (-1141 |#1|))) (-15 -4023 ((-1141 |#1|) (-1141 |#1|)))) (-43 (-409 (-568)))) (T -1146)) 
-((-4023 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-2014 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-2010 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-2006 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-2002 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1998 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1994 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1990 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1986 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1982 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1978 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1974 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1970 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1966 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1962 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1958 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1953 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1949 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1945 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1941 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1937 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1933 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-2790 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-2786 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (** (*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-4416 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1892 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3))))) 
-(-10 -7 (-15 -1892 ((-1141 |#1|) (-1141 |#1|))) (-15 -4416 ((-1141 |#1|) (-1141 |#1|))) (-15 ** ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -2786 ((-1141 |#1|) (-1141 |#1|))) (-15 -2790 ((-1141 |#1|) (-1141 |#1|))) (-15 -1933 ((-1141 |#1|) (-1141 |#1|))) (-15 -1937 ((-1141 |#1|) (-1141 |#1|))) (-15 -1941 ((-1141 |#1|) (-1141 |#1|))) (-15 -1945 ((-1141 |#1|) (-1141 |#1|))) (-15 -1949 ((-1141 |#1|) (-1141 |#1|))) (-15 -1953 ((-1141 |#1|) (-1141 |#1|))) (-15 -1958 ((-1141 |#1|) (-1141 |#1|))) (-15 -1962 ((-1141 |#1|) (-1141 |#1|))) (-15 -1966 ((-1141 |#1|) (-1141 |#1|))) (-15 -1970 ((-1141 |#1|) (-1141 |#1|))) (-15 -1974 ((-1141 |#1|) (-1141 |#1|))) (-15 -1978 ((-1141 |#1|) (-1141 |#1|))) (-15 -1982 ((-1141 |#1|) (-1141 |#1|))) (-15 -1986 ((-1141 |#1|) (-1141 |#1|))) (-15 -1990 ((-1141 |#1|) (-1141 |#1|))) (-15 -1994 ((-1141 |#1|) (-1141 |#1|))) (-15 -1998 ((-1141 |#1|) (-1141 |#1|))) (-15 -2002 ((-1141 |#1|) (-1141 |#1|))) (-15 -2006 ((-1141 |#1|) (-1141 |#1|))) (-15 -2010 ((-1141 |#1|) (-1141 |#1|))) (-15 -2014 ((-1141 |#1|) (-1141 |#1|))) (-15 -4023 ((-1141 |#1|) (-1141 |#1|)))) 
-((-1982 (((-1141 |#1|) (-1141 |#1|)) 100)) (-1933 (((-1141 |#1|) (-1141 |#1|)) 64)) (-2127 (((-2 (|:| -1974 (-1141 |#1|)) (|:| -1978 (-1141 |#1|))) (-1141 |#1|)) 96)) (-1974 (((-1141 |#1|) (-1141 |#1|)) 97)) (-1431 (((-2 (|:| -2786 (-1141 |#1|)) (|:| -2790 (-1141 |#1|))) (-1141 |#1|)) 53)) (-2786 (((-1141 |#1|) (-1141 |#1|)) 54)) (-1990 (((-1141 |#1|) (-1141 |#1|)) 102)) (-1941 (((-1141 |#1|) (-1141 |#1|)) 71)) (-4416 (((-1141 |#1|) (-1141 |#1|)) 39)) (-1892 (((-1141 |#1|) (-1141 |#1|)) 36)) (-1994 (((-1141 |#1|) (-1141 |#1|)) 103)) (-1945 (((-1141 |#1|) (-1141 |#1|)) 72)) (-1986 (((-1141 |#1|) (-1141 |#1|)) 101)) (-1937 (((-1141 |#1|) (-1141 |#1|)) 67)) (-1978 (((-1141 |#1|) (-1141 |#1|)) 98)) (-2790 (((-1141 |#1|) (-1141 |#1|)) 55)) (-2006 (((-1141 |#1|) (-1141 |#1|)) 111)) (-1958 (((-1141 |#1|) (-1141 |#1|)) 86)) (-1998 (((-1141 |#1|) (-1141 |#1|)) 105)) (-1949 (((-1141 |#1|) (-1141 |#1|)) 82)) (-2014 (((-1141 |#1|) (-1141 |#1|)) 115)) (-1966 (((-1141 |#1|) (-1141 |#1|)) 90)) (-4023 (((-1141 |#1|) (-1141 |#1|)) 117)) (-1970 (((-1141 |#1|) (-1141 |#1|)) 92)) (-2010 (((-1141 |#1|) (-1141 |#1|)) 113)) (-1962 (((-1141 |#1|) (-1141 |#1|)) 88)) (-2002 (((-1141 |#1|) (-1141 |#1|)) 107)) (-1953 (((-1141 |#1|) (-1141 |#1|)) 84)) (** (((-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) 40))) 
-(((-1147 |#1|) (-10 -7 (-15 -1892 ((-1141 |#1|) (-1141 |#1|))) (-15 -4416 ((-1141 |#1|) (-1141 |#1|))) (-15 ** ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -1431 ((-2 (|:| -2786 (-1141 |#1|)) (|:| -2790 (-1141 |#1|))) (-1141 |#1|))) (-15 -2786 ((-1141 |#1|) (-1141 |#1|))) (-15 -2790 ((-1141 |#1|) (-1141 |#1|))) (-15 -1933 ((-1141 |#1|) (-1141 |#1|))) (-15 -1937 ((-1141 |#1|) (-1141 |#1|))) (-15 -1941 ((-1141 |#1|) (-1141 |#1|))) (-15 -1945 ((-1141 |#1|) (-1141 |#1|))) (-15 -1949 ((-1141 |#1|) (-1141 |#1|))) (-15 -1953 ((-1141 |#1|) (-1141 |#1|))) (-15 -1958 ((-1141 |#1|) (-1141 |#1|))) (-15 -1962 ((-1141 |#1|) (-1141 |#1|))) (-15 -1966 ((-1141 |#1|) (-1141 |#1|))) (-15 -1970 ((-1141 |#1|) (-1141 |#1|))) (-15 -2127 ((-2 (|:| -1974 (-1141 |#1|)) (|:| -1978 (-1141 |#1|))) (-1141 |#1|))) (-15 -1974 ((-1141 |#1|) (-1141 |#1|))) (-15 -1978 ((-1141 |#1|) (-1141 |#1|))) (-15 -1982 ((-1141 |#1|) (-1141 |#1|))) (-15 -1986 ((-1141 |#1|) (-1141 |#1|))) (-15 -1990 ((-1141 |#1|) (-1141 |#1|))) (-15 -1994 ((-1141 |#1|) (-1141 |#1|))) (-15 -1998 ((-1141 |#1|) (-1141 |#1|))) (-15 -2002 ((-1141 |#1|) (-1141 |#1|))) (-15 -2006 ((-1141 |#1|) (-1141 |#1|))) (-15 -2010 ((-1141 |#1|) (-1141 |#1|))) (-15 -2014 ((-1141 |#1|) (-1141 |#1|))) (-15 -4023 ((-1141 |#1|) (-1141 |#1|)))) (-43 (-409 (-568)))) (T -1147)) 
-((-4023 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-2014 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-2010 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-2006 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-2002 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1998 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1994 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1990 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1986 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1982 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1978 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1974 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-2127 (*1 *2 *3) (-12 (-4 *4 (-43 (-409 (-568)))) (-5 *2 (-2 (|:| -1974 (-1141 *4)) (|:| -1978 (-1141 *4)))) (-5 *1 (-1147 *4)) (-5 *3 (-1141 *4)))) (-1970 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1966 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1962 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1958 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1953 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1949 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1945 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1941 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1937 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1933 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-2790 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-2786 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1431 (*1 *2 *3) (-12 (-4 *4 (-43 (-409 (-568)))) (-5 *2 (-2 (|:| -2786 (-1141 *4)) (|:| -2790 (-1141 *4)))) (-5 *1 (-1147 *4)) (-5 *3 (-1141 *4)))) (** (*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-4416 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1892 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3))))) 
-(-10 -7 (-15 -1892 ((-1141 |#1|) (-1141 |#1|))) (-15 -4416 ((-1141 |#1|) (-1141 |#1|))) (-15 ** ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -1431 ((-2 (|:| -2786 (-1141 |#1|)) (|:| -2790 (-1141 |#1|))) (-1141 |#1|))) (-15 -2786 ((-1141 |#1|) (-1141 |#1|))) (-15 -2790 ((-1141 |#1|) (-1141 |#1|))) (-15 -1933 ((-1141 |#1|) (-1141 |#1|))) (-15 -1937 ((-1141 |#1|) (-1141 |#1|))) (-15 -1941 ((-1141 |#1|) (-1141 |#1|))) (-15 -1945 ((-1141 |#1|) (-1141 |#1|))) (-15 -1949 ((-1141 |#1|) (-1141 |#1|))) (-15 -1953 ((-1141 |#1|) (-1141 |#1|))) (-15 -1958 ((-1141 |#1|) (-1141 |#1|))) (-15 -1962 ((-1141 |#1|) (-1141 |#1|))) (-15 -1966 ((-1141 |#1|) (-1141 |#1|))) (-15 -1970 ((-1141 |#1|) (-1141 |#1|))) (-15 -2127 ((-2 (|:| -1974 (-1141 |#1|)) (|:| -1978 (-1141 |#1|))) (-1141 |#1|))) (-15 -1974 ((-1141 |#1|) (-1141 |#1|))) (-15 -1978 ((-1141 |#1|) (-1141 |#1|))) (-15 -1982 ((-1141 |#1|) (-1141 |#1|))) (-15 -1986 ((-1141 |#1|) (-1141 |#1|))) (-15 -1990 ((-1141 |#1|) (-1141 |#1|))) (-15 -1994 ((-1141 |#1|) (-1141 |#1|))) (-15 -1998 ((-1141 |#1|) (-1141 |#1|))) (-15 -2002 ((-1141 |#1|) (-1141 |#1|))) (-15 -2006 ((-1141 |#1|) (-1141 |#1|))) (-15 -2010 ((-1141 |#1|) (-1141 |#1|))) (-15 -2014 ((-1141 |#1|) (-1141 |#1|))) (-15 -4023 ((-1141 |#1|) (-1141 |#1|)))) 
-((-1971 (((-958 |#2|) |#2| |#2|) 35)) (-3250 ((|#2| |#2| |#1|) 19 (|has| |#1| (-301))))) 
-(((-1148 |#1| |#2|) (-10 -7 (-15 -1971 ((-958 |#2|) |#2| |#2|)) (IF (|has| |#1| (-301)) (-15 -3250 (|#2| |#2| |#1|)) |noBranch|)) (-558) (-1219 |#1|)) (T -1148)) 
-((-3250 (*1 *2 *2 *3) (-12 (-4 *3 (-301)) (-4 *3 (-558)) (-5 *1 (-1148 *3 *2)) (-4 *2 (-1219 *3)))) (-1971 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-958 *3)) (-5 *1 (-1148 *4 *3)) (-4 *3 (-1219 *4))))) 
-(-10 -7 (-15 -1971 ((-958 |#2|) |#2| |#2|)) (IF (|has| |#1| (-301)) (-15 -3250 (|#2| |#2| |#1|)) |noBranch|)) 
-((-2447 (((-121) $ $) NIL)) (-1409 (($ $ (-634 (-763))) 66)) (-2141 (($) 25)) (-1684 (($ $) 41)) (-1619 (((-634 $) $) 50)) (-2793 (((-121) $) 16)) (-2804 (((-634 (-944 |#2|)) $) 73)) (-4492 (($ $) 67)) (-2680 (((-763) $) 36)) (-1849 (($) 24)) (-2026 (($ $ (-634 (-763)) (-944 |#2|)) 59) (($ $ (-634 (-763)) (-763)) 60) (($ $ (-763) (-944 |#2|)) 62)) (-1347 (($ $ $) 47) (($ (-634 $)) 49)) (-2467 (((-763) $) 74)) (-1651 (((-121) $) 15)) (-4487 (((-1143) $) NIL)) (-2171 (((-121) $) 17)) (-4022 (((-1108) $) NIL)) (-3221 (((-171) $) 72)) (-2103 (((-944 |#2|) $) 68)) (-1365 (((-763) $) 69)) (-4055 (((-121) $) 71)) (-1900 (($ $ (-634 (-763)) (-171)) 65)) (-2778 (($ $) 42)) (-2745 (((-850) $) 84)) (-2877 (($ $ (-634 (-763)) (-121)) 64)) (-4339 (((-634 $) $) 11)) (-3309 (($ $ (-763)) 35)) (-1400 (($ $) 31)) (-2835 (($ $ $ (-944 |#2|) (-763)) 55)) (-1758 (($ $ (-944 |#2|)) 54)) (-4470 (($ $ (-634 (-763)) (-944 |#2|)) 53) (($ $ (-634 (-763)) (-763)) 57) (((-763) $ (-944 |#2|)) 58)) (-1717 (((-121) $ $) 78))) 
-(((-1149 |#1| |#2|) (-13 (-1090) (-10 -8 (-15 -1651 ((-121) $)) (-15 -2793 ((-121) $)) (-15 -2171 ((-121) $)) (-15 -1849 ($)) (-15 -2141 ($)) (-15 -1400 ($ $)) (-15 -3309 ($ $ (-763))) (-15 -4339 ((-634 $) $)) (-15 -2680 ((-763) $)) (-15 -1684 ($ $)) (-15 -2778 ($ $)) (-15 -1347 ($ $ $)) (-15 -1347 ($ (-634 $))) (-15 -1619 ((-634 $) $)) (-15 -4470 ($ $ (-634 (-763)) (-944 |#2|))) (-15 -1758 ($ $ (-944 |#2|))) (-15 -2835 ($ $ $ (-944 |#2|) (-763))) (-15 -2026 ($ $ (-634 (-763)) (-944 |#2|))) (-15 -4470 ($ $ (-634 (-763)) (-763))) (-15 -2026 ($ $ (-634 (-763)) (-763))) (-15 -4470 ((-763) $ (-944 |#2|))) (-15 -2026 ($ $ (-763) (-944 |#2|))) (-15 -2877 ($ $ (-634 (-763)) (-121))) (-15 -1900 ($ $ (-634 (-763)) (-171))) (-15 -1409 ($ $ (-634 (-763)))) (-15 -2103 ((-944 |#2|) $)) (-15 -1365 ((-763) $)) (-15 -4055 ((-121) $)) (-15 -3221 ((-171) $)) (-15 -2467 ((-763) $)) (-15 -4492 ($ $)) (-15 -2804 ((-634 (-944 |#2|)) $)))) (-917) (-1047)) (T -1149)) 
-((-1651 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-2793 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-2171 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-1849 (*1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047)))) (-2141 (*1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047)))) (-1400 (*1 *1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047)))) (-3309 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-4339 (*1 *2 *1) (-12 (-5 *2 (-634 (-1149 *3 *4))) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-2680 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-1684 (*1 *1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047)))) (-2778 (*1 *1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047)))) (-1347 (*1 *1 *1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047)))) (-1347 (*1 *1 *2) (-12 (-5 *2 (-634 (-1149 *3 *4))) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-1619 (*1 *2 *1) (-12 (-5 *2 (-634 (-1149 *3 *4))) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-4470 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-944 *5)) (-4 *5 (-1047)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)))) (-1758 (*1 *1 *1 *2) (-12 (-5 *2 (-944 *4)) (-4 *4 (-1047)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)))) (-2835 (*1 *1 *1 *1 *2 *3) (-12 (-5 *2 (-944 *5)) (-5 *3 (-763)) (-4 *5 (-1047)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)))) (-2026 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-944 *5)) (-4 *5 (-1047)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)))) (-4470 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-763)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)) (-4 *5 (-1047)))) (-2026 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-763)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)) (-4 *5 (-1047)))) (-4470 (*1 *2 *1 *3) (-12 (-5 *3 (-944 *5)) (-4 *5 (-1047)) (-5 *2 (-763)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)))) (-2026 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *3 (-944 *5)) (-4 *5 (-1047)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)))) (-2877 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-121)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)) (-4 *5 (-1047)))) (-1900 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-171)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)) (-4 *5 (-1047)))) (-1409 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-763))) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-2103 (*1 *2 *1) (-12 (-5 *2 (-944 *4)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-1365 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-4055 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-3221 (*1 *2 *1) (-12 (-5 *2 (-171)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-2467 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-4492 (*1 *1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047)))) (-2804 (*1 *2 *1) (-12 (-5 *2 (-634 (-944 *4))) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
-(-13 (-1090) (-10 -8 (-15 -1651 ((-121) $)) (-15 -2793 ((-121) $)) (-15 -2171 ((-121) $)) (-15 -1849 ($)) (-15 -2141 ($)) (-15 -1400 ($ $)) (-15 -3309 ($ $ (-763))) (-15 -4339 ((-634 $) $)) (-15 -2680 ((-763) $)) (-15 -1684 ($ $)) (-15 -2778 ($ $)) (-15 -1347 ($ $ $)) (-15 -1347 ($ (-634 $))) (-15 -1619 ((-634 $) $)) (-15 -4470 ($ $ (-634 (-763)) (-944 |#2|))) (-15 -1758 ($ $ (-944 |#2|))) (-15 -2835 ($ $ $ (-944 |#2|) (-763))) (-15 -2026 ($ $ (-634 (-763)) (-944 |#2|))) (-15 -4470 ($ $ (-634 (-763)) (-763))) (-15 -2026 ($ $ (-634 (-763)) (-763))) (-15 -4470 ((-763) $ (-944 |#2|))) (-15 -2026 ($ $ (-763) (-944 |#2|))) (-15 -2877 ($ $ (-634 (-763)) (-121))) (-15 -1900 ($ $ (-634 (-763)) (-171))) (-15 -1409 ($ $ (-634 (-763)))) (-15 -2103 ((-944 |#2|) $)) (-15 -1365 ((-763) $)) (-15 -4055 ((-121) $)) (-15 -3221 ((-171) $)) (-15 -2467 ((-763) $)) (-15 -4492 ($ $)) (-15 -2804 ((-634 (-944 |#2|)) $)))) 
-((-2447 (((-121) $ $) NIL)) (-2107 ((|#2| $) 11)) (-1466 ((|#1| $) 10)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-4287 (($ |#1| |#2|) 9)) (-2745 (((-850) $) 16)) (-1717 (((-121) $ $) NIL))) 
-(((-1150 |#1| |#2|) (-13 (-1090) (-10 -8 (-15 -4287 ($ |#1| |#2|)) (-15 -1466 (|#1| $)) (-15 -2107 (|#2| $)))) (-1090) (-1090)) (T -1150)) 
-((-4287 (*1 *1 *2 *3) (-12 (-5 *1 (-1150 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090)))) (-1466 (*1 *2 *1) (-12 (-4 *2 (-1090)) (-5 *1 (-1150 *2 *3)) (-4 *3 (-1090)))) (-2107 (*1 *2 *1) (-12 (-4 *2 (-1090)) (-5 *1 (-1150 *3 *2)) (-4 *3 (-1090))))) 
-(-13 (-1090) (-10 -8 (-15 -4287 ($ |#1| |#2|)) (-15 -1466 (|#1| $)) (-15 -2107 (|#2| $)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-1492 (((-1159 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-301)) (|has| |#1| (-365))))) (-2055 (((-634 (-1075)) $) NIL)) (-1305 (((-1161) $) 11)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558))))) (-2227 (($ $) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558))))) (-1573 (((-121) $) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558))))) (-2617 (($ $ (-568)) NIL) (($ $ (-568) (-568)) 66)) (-2583 (((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL)) (-3613 (((-1159 |#1| |#2| |#3|) $) 36)) (-4016 (((-3 (-1159 |#1| |#2| |#3|) "failed") $) 29)) (-2065 (((-1159 |#1| |#2| |#3|) $) 30)) (-1982 (($ $) 107 (|has| |#1| (-43 (-409 (-568)))))) (-1933 (($ $) 83 (|has| |#1| (-43 (-409 (-568)))))) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))))) (-4305 (($ $) NIL (|has| |#1| (-365)))) (-1678 (((-420 $) $) NIL (|has| |#1| (-365)))) (-1902 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))))) (-1497 (((-121) $ $) NIL (|has| |#1| (-365)))) (-1974 (($ $) 103 (|has| |#1| (-43 (-409 (-568)))))) (-2786 (($ $) 79 (|has| |#1| (-43 (-409 (-568)))))) (-3662 (((-568) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))))) (-3728 (($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) NIL)) (-1990 (($ $) 111 (|has| |#1| (-43 (-409 (-568)))))) (-1941 (($ $) 87 (|has| |#1| (-43 (-409 (-568)))))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-1159 |#1| |#2| |#3|) "failed") $) 31) (((-3 (-1161) "failed") $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-1037 (-1161))) (|has| |#1| (-365)))) (((-3 (-409 (-568)) "failed") $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-1037 (-568))) (|has| |#1| (-365)))) (((-3 (-568) "failed") $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-1037 (-568))) (|has| |#1| (-365))))) (-2854 (((-1159 |#1| |#2| |#3|) $) 131) (((-1161) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-1037 (-1161))) (|has| |#1| (-365)))) (((-409 (-568)) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-1037 (-568))) (|has| |#1| (-365)))) (((-568) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-1037 (-568))) (|has| |#1| (-365))))) (-1429 (($ $) 34) (($ (-568) $) 35)) (-2401 (($ $ $) NIL (|has| |#1| (-365)))) (-2114 (($ $) NIL)) (-3164 (((-679 (-1159 |#1| |#2| |#3|)) (-679 $)) NIL (|has| |#1| (-365))) (((-2 (|:| -2928 (-679 (-1159 |#1| |#2| |#3|))) (|:| |vec| (-1244 (-1159 |#1| |#2| |#3|)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-365))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-630 (-568))) (|has| |#1| (-365)))) (((-679 (-568)) (-679 $)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-630 (-568))) (|has| |#1| (-365))))) (-2925 (((-3 $ "failed") $) 48)) (-4446 (((-409 (-953 |#1|)) $ (-568)) 65 (|has| |#1| (-558))) (((-409 (-953 |#1|)) $ (-568) (-568)) 67 (|has| |#1| (-558)))) (-1731 (($) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-550)) (|has| |#1| (-365))))) (-2412 (($ $ $) NIL (|has| |#1| (-365)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-3927 (((-121) $) NIL (|has| |#1| (-365)))) (-2033 (((-121) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))))) (-3992 (((-121) $) 25)) (-1897 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-881 (-568))) (|has| |#1| (-365)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-881 (-381))) (|has| |#1| (-365))))) (-4477 (((-568) $) NIL) (((-568) $ (-568)) 24)) (-2735 (((-121) $) NIL)) (-1332 (($ $) NIL (|has| |#1| (-365)))) (-2317 (((-1159 |#1| |#2| |#3|) $) 38 (|has| |#1| (-365)))) (-4044 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3038 (((-3 $ "failed") $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-1136)) (|has| |#1| (-365))))) (-2245 (((-121) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))))) (-3536 (($ $ (-917)) NIL)) (-1716 (($ (-1 |#1| (-568)) $) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| (-568)) 18) (($ $ (-1075) (-568)) NIL) (($ $ (-634 (-1075)) (-634 (-568))) NIL)) (-2521 (($ $ $) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-3268 (($ $ $) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-2795 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 (-1159 |#1| |#2| |#3|) (-1159 |#1| |#2| |#3|)) $) NIL (|has| |#1| (-365)))) (-4416 (($ $) 72 (|has| |#1| (-43 (-409 (-568)))))) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-2495 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-2070 (($ (-568) (-1159 |#1| |#2| |#3|)) 33)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL (|has| |#1| (-365)))) (-3837 (($ $) 70 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) NIL (-2198 (-12 (|has| |#1| (-15 -3837 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2055 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181))))) (($ $ (-1240 |#2|)) 71 (|has| |#1| (-43 (-409 (-568)))))) (-4434 (($) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-1136)) (|has| |#1| (-365))) CONST)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-365)))) (-2721 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-3880 (($ $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-301)) (|has| |#1| (-365))))) (-1519 (((-1159 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-550)) (|has| |#1| (-365))))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))))) (-3848 (((-420 $) $) NIL (|has| |#1| (-365)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-365)))) (-1807 (($ $ (-568)) 145)) (-2595 (((-3 $ "failed") $ $) 49 (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558))))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1892 (($ $) 73 (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-568))))) (($ $ (-1161) (-1159 |#1| |#2| |#3|)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-523 (-1161) (-1159 |#1| |#2| |#3|))) (|has| |#1| (-365)))) (($ $ (-634 (-1161)) (-634 (-1159 |#1| |#2| |#3|))) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-523 (-1161) (-1159 |#1| |#2| |#3|))) (|has| |#1| (-365)))) (($ $ (-634 (-288 (-1159 |#1| |#2| |#3|)))) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-303 (-1159 |#1| |#2| |#3|))) (|has| |#1| (-365)))) (($ $ (-288 (-1159 |#1| |#2| |#3|))) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-303 (-1159 |#1| |#2| |#3|))) (|has| |#1| (-365)))) (($ $ (-1159 |#1| |#2| |#3|) (-1159 |#1| |#2| |#3|)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-303 (-1159 |#1| |#2| |#3|))) (|has| |#1| (-365)))) (($ $ (-634 (-1159 |#1| |#2| |#3|)) (-634 (-1159 |#1| |#2| |#3|))) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-303 (-1159 |#1| |#2| |#3|))) (|has| |#1| (-365))))) (-2709 (((-763) $) NIL (|has| |#1| (-365)))) (-2779 ((|#1| $ (-568)) NIL) (($ $ $) 54 (|has| (-568) (-1102))) (($ $ (-1159 |#1| |#2| |#3|)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-281 (-1159 |#1| |#2| |#3|) (-1159 |#1| |#2| |#3|))) (|has| |#1| (-365))))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-365)))) (-4189 (($ $ (-1 (-1159 |#1| |#2| |#3|) (-1159 |#1| |#2| |#3|))) NIL (|has| |#1| (-365))) (($ $ (-1 (-1159 |#1| |#2| |#3|) (-1159 |#1| |#2| |#3|)) (-763)) NIL (|has| |#1| (-365))) (($ $ (-1240 |#2|)) 51) (($ $ (-763)) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $) 50 (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161) (-763)) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-634 (-1161))) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161)) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))))) (-3013 (($ $) NIL (|has| |#1| (-365)))) (-2324 (((-1159 |#1| |#2| |#3|) $) 41 (|has| |#1| (-365)))) (-3206 (((-568) $) 37)) (-1994 (($ $) 113 (|has| |#1| (-43 (-409 (-568)))))) (-1945 (($ $) 89 (|has| |#1| (-43 (-409 (-568)))))) (-1986 (($ $) 109 (|has| |#1| (-43 (-409 (-568)))))) (-1937 (($ $) 85 (|has| |#1| (-43 (-409 (-568)))))) (-1978 (($ $) 105 (|has| |#1| (-43 (-409 (-568)))))) (-2790 (($ $) 81 (|has| |#1| (-43 (-409 (-568)))))) (-4278 (((-541) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-609 (-541))) (|has| |#1| (-365)))) (((-381) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-1021)) (|has| |#1| (-365)))) (((-215) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-1021)) (|has| |#1| (-365)))) (((-887 (-381)) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-609 (-887 (-381)))) (|has| |#1| (-365)))) (((-887 (-568)) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-609 (-887 (-568)))) (|has| |#1| (-365))))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))))) (-1811 (($ $) NIL)) (-2745 (((-850) $) 149) (($ (-568)) NIL) (($ |#1|) NIL (|has| |#1| (-172))) (($ (-1159 |#1| |#2| |#3|)) 27) (($ (-1240 |#2|)) 23) (($ (-1161)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-1037 (-1161))) (|has| |#1| (-365)))) (($ $) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558)))) (($ (-409 (-568))) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-1037 (-568))) (|has| |#1| (-365))) (|has| |#1| (-43 (-409 (-568))))))) (-2604 ((|#1| $ (-568)) 68)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-148)) (|has| |#1| (-365))) (|has| |#1| (-148))))) (-4078 (((-763)) NIL)) (-1374 ((|#1| $) 12)) (-2285 (((-1159 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-550)) (|has| |#1| (-365))))) (-2006 (($ $) 119 (|has| |#1| (-43 (-409 (-568)))))) (-1958 (($ $) 95 (|has| |#1| (-43 (-409 (-568)))))) (-1826 (((-121) $ $) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558))))) (-1998 (($ $) 115 (|has| |#1| (-43 (-409 (-568)))))) (-1949 (($ $) 91 (|has| |#1| (-43 (-409 (-568)))))) (-2014 (($ $) 123 (|has| |#1| (-43 (-409 (-568)))))) (-1966 (($ $) 99 (|has| |#1| (-43 (-409 (-568)))))) (-3996 ((|#1| $ (-568)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-568)))) (|has| |#1| (-15 -2745 (|#1| (-1161))))))) (-4023 (($ $) 125 (|has| |#1| (-43 (-409 (-568)))))) (-1970 (($ $) 101 (|has| |#1| (-43 (-409 (-568)))))) (-2010 (($ $) 121 (|has| |#1| (-43 (-409 (-568)))))) (-1962 (($ $) 97 (|has| |#1| (-43 (-409 (-568)))))) (-2002 (($ $) 117 (|has| |#1| (-43 (-409 (-568)))))) (-1953 (($ $) 93 (|has| |#1| (-43 (-409 (-568)))))) (-2897 (($ $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (-3056 (($) 20 T CONST)) (-1556 (($) 16 T CONST)) (-3190 (($ $ (-1 (-1159 |#1| |#2| |#3|) (-1159 |#1| |#2| |#3|))) NIL (|has| |#1| (-365))) (($ $ (-1 (-1159 |#1| |#2| |#3|) (-1159 |#1| |#2| |#3|)) (-763)) NIL (|has| |#1| (-365))) (($ $ (-763)) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161) (-763)) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-634 (-1161))) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161)) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))))) (-1751 (((-121) $ $) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-1738 (((-121) $ $) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-1732 (((-121) $ $) NIL (-2198 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365))) (($ $ $) 44 (|has| |#1| (-365))) (($ (-1159 |#1| |#2| |#3|) (-1159 |#1| |#2| |#3|)) 45 (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) 21)) (** (($ $ (-917)) NIL) (($ $ (-763)) 53) (($ $ (-568)) NIL (|has| |#1| (-365))) (($ $ $) 74 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 128 (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 32) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ (-1159 |#1| |#2| |#3|)) 43 (|has| |#1| (-365))) (($ (-1159 |#1| |#2| |#3|) $) 42 (|has| |#1| (-365))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
-(((-1151 |#1| |#2| |#3|) (-13 (-1205 |#1| (-1159 |#1| |#2| |#3|)) (-10 -8 (-15 -2745 ($ (-1240 |#2|))) (-15 -4189 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -3837 ($ $ (-1240 |#2|))) |noBranch|))) (-1047) (-1161) |#1|) (T -1151)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1151 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-4189 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1151 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-3837 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1151 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3)))) 
-(-13 (-1205 |#1| (-1159 |#1| |#2| |#3|)) (-10 -8 (-15 -2745 ($ (-1240 |#2|))) (-15 -4189 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -3837 ($ $ (-1240 |#2|))) |noBranch|))) 
-((-2627 ((|#2| |#2| (-1082 |#2|)) 26) ((|#2| |#2| (-1161)) 28))) 
-(((-1152 |#1| |#2|) (-10 -7 (-15 -2627 (|#2| |#2| (-1161))) (-15 -2627 (|#2| |#2| (-1082 |#2|)))) (-13 (-558) (-842) (-1037 (-568)) (-630 (-568))) (-13 (-432 |#1|) (-161) (-27) (-1181))) (T -1152)) 
-((-2627 (*1 *2 *2 *3) (-12 (-5 *3 (-1082 *2)) (-4 *2 (-13 (-432 *4) (-161) (-27) (-1181))) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1152 *4 *2)))) (-2627 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1152 *4 *2)) (-4 *2 (-13 (-432 *4) (-161) (-27) (-1181)))))) 
-(-10 -7 (-15 -2627 (|#2| |#2| (-1161))) (-15 -2627 (|#2| |#2| (-1082 |#2|)))) 
-((-2627 (((-3 (-409 (-953 |#1|)) (-310 |#1|)) (-409 (-953 |#1|)) (-1082 (-409 (-953 |#1|)))) 30) (((-409 (-953 |#1|)) (-953 |#1|) (-1082 (-953 |#1|))) 44) (((-3 (-409 (-953 |#1|)) (-310 |#1|)) (-409 (-953 |#1|)) (-1161)) 32) (((-409 (-953 |#1|)) (-953 |#1|) (-1161)) 36))) 
-(((-1153 |#1|) (-10 -7 (-15 -2627 ((-409 (-953 |#1|)) (-953 |#1|) (-1161))) (-15 -2627 ((-3 (-409 (-953 |#1|)) (-310 |#1|)) (-409 (-953 |#1|)) (-1161))) (-15 -2627 ((-409 (-953 |#1|)) (-953 |#1|) (-1082 (-953 |#1|)))) (-15 -2627 ((-3 (-409 (-953 |#1|)) (-310 |#1|)) (-409 (-953 |#1|)) (-1082 (-409 (-953 |#1|)))))) (-13 (-558) (-842) (-1037 (-568)))) (T -1153)) 
-((-2627 (*1 *2 *3 *4) (-12 (-5 *4 (-1082 (-409 (-953 *5)))) (-5 *3 (-409 (-953 *5))) (-4 *5 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-3 *3 (-310 *5))) (-5 *1 (-1153 *5)))) (-2627 (*1 *2 *3 *4) (-12 (-5 *4 (-1082 (-953 *5))) (-5 *3 (-953 *5)) (-4 *5 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-409 *3)) (-5 *1 (-1153 *5)))) (-2627 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-3 (-409 (-953 *5)) (-310 *5))) (-5 *1 (-1153 *5)) (-5 *3 (-409 (-953 *5))))) (-2627 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-409 (-953 *5))) (-5 *1 (-1153 *5)) (-5 *3 (-953 *5))))) 
-(-10 -7 (-15 -2627 ((-409 (-953 |#1|)) (-953 |#1|) (-1161))) (-15 -2627 ((-3 (-409 (-953 |#1|)) (-310 |#1|)) (-409 (-953 |#1|)) (-1161))) (-15 -2627 ((-409 (-953 |#1|)) (-953 |#1|) (-1082 (-953 |#1|)))) (-15 -2627 ((-3 (-409 (-953 |#1|)) (-310 |#1|)) (-409 (-953 |#1|)) (-1082 (-409 (-953 |#1|)))))) 
-((-2795 (((-1157 |#2|) (-1 |#2| |#1|) (-1157 |#1|)) 13))) 
-(((-1154 |#1| |#2|) (-10 -7 (-15 -2795 ((-1157 |#2|) (-1 |#2| |#1|) (-1157 |#1|)))) (-1047) (-1047)) (T -1154)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1157 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-5 *2 (-1157 *6)) (-5 *1 (-1154 *5 *6))))) 
-(-10 -7 (-15 -2795 ((-1157 |#2|) (-1 |#2| |#1|) (-1157 |#1|)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2572 (((-1244 |#1|) $ (-763)) NIL)) (-2055 (((-634 (-1075)) $) NIL)) (-3197 (($ (-1157 |#1|)) NIL)) (-3839 (((-1157 $) $ (-1075)) NIL) (((-1157 |#1|) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-2773 (((-763) $) NIL) (((-763) $ (-634 (-1075))) NIL)) (-1982 (($ $) NIL (|has| |#1| (-1181)))) (-1933 (($ $) NIL (|has| |#1| (-1181)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-3809 (($ $ $) NIL (|has| |#1| (-558)))) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-4305 (($ $) NIL (|has| |#1| (-453)))) (-1678 (((-420 $) $) NIL (|has| |#1| (-453)))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-1497 (((-121) $ $) NIL (|has| |#1| (-365)))) (-1974 (($ $) NIL (|has| |#1| (-1181)))) (-2786 (($ $) 22 (|has| |#1| (-1181)))) (-3151 (($ $ (-763)) NIL)) (-3772 (($ $ (-763)) NIL)) (-1619 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#1| (-453)))) (-1990 (($ $) NIL (|has| |#1| (-1181)))) (-1941 (($ $) NIL (|has| |#1| (-1181)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-1075) "failed") $) NIL)) (-2854 ((|#1| $) NIL) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-1075) $) NIL)) (-4265 (($ $ $ (-1075)) NIL (|has| |#1| (-172))) ((|#1| $ $) NIL (|has| |#1| (-172)))) (-2401 (($ $ $) NIL (|has| |#1| (-365)))) (-2114 (($ $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-2412 (($ $ $) NIL (|has| |#1| (-365)))) (-3002 (($ $ $) NIL)) (-3581 (($ $ $) NIL (|has| |#1| (-558)))) (-4144 (((-2 (|:| -2348 |#1|) (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-558)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-3250 (($ $) NIL (|has| |#1| (-453))) (($ $ (-1075)) NIL (|has| |#1| (-453)))) (-2108 (((-634 $) $) NIL)) (-3927 (((-121) $) NIL (|has| |#1| (-904)))) (-3088 (($ $ |#1| (-763) $) NIL)) (-1897 (($) NIL (|has| |#1| (-1181)))) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-1075) (-881 (-381))) (|has| |#1| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-1075) (-881 (-568))) (|has| |#1| (-881 (-568)))))) (-4477 (((-763) $ $) NIL (|has| |#1| (-558)))) (-2735 (((-121) $) NIL)) (-4178 (((-763) $) NIL)) (-3038 (((-3 $ "failed") $) NIL (|has| |#1| (-1136)))) (-2051 (($ (-1157 |#1|) (-1075)) NIL) (($ (-1157 $) (-1075)) NIL)) (-3536 (($ $ (-763)) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-2976 (((-634 $) $) NIL)) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| (-763)) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-3379 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $ (-1075)) NIL) (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-2144 (((-763) $) NIL) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-3842 (($ (-1 (-763) (-763)) $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-3764 (((-1157 |#1|) $) NIL)) (-2244 (((-3 (-1075) "failed") $) NIL)) (-4416 (($ $) 18 (|has| |#1| (-1181)))) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-2495 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-4487 (((-1143) $) NIL)) (-1643 (((-2 (|:| -3961 $) (|:| -1500 $)) $ (-763)) NIL)) (-3324 (((-3 (-634 $) "failed") $) NIL)) (-1794 (((-3 (-634 $) "failed") $) NIL)) (-3751 (((-3 (-2 (|:| |var| (-1075)) (|:| -3438 (-763))) "failed") $) NIL)) (-3837 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4434 (($) NIL (|has| |#1| (-1136)) CONST)) (-4022 (((-1108) $) NIL)) (-2086 (((-121) $) 8)) (-2091 ((|#1| $) 9)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-453)))) (-2721 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3848 (((-420 $) $) NIL (|has| |#1| (-904)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-365)))) (-2595 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1892 (($ $) 20 (|has| |#1| (-1181)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-1075) |#1|) NIL) (($ $ (-634 (-1075)) (-634 |#1|)) NIL) (($ $ (-1075) $) NIL) (($ $ (-634 (-1075)) (-634 $)) NIL)) (-2709 (((-763) $) NIL (|has| |#1| (-365)))) (-2779 ((|#1| $ |#1|) NIL) (($ $ $) NIL) (((-409 $) (-409 $) (-409 $)) NIL (|has| |#1| (-558))) ((|#1| (-409 $) |#1|) NIL (|has| |#1| (-365))) (((-409 $) $ (-409 $)) NIL (|has| |#1| (-558)))) (-2167 (((-3 $ "failed") $ (-763)) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-365)))) (-2217 (($ $ (-1075)) NIL (|has| |#1| (-172))) ((|#1| $) NIL (|has| |#1| (-172)))) (-4189 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-1 |#1| |#1|) $) NIL)) (-3206 (((-763) $) NIL) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-1994 (($ $) NIL (|has| |#1| (-1181)))) (-1945 (($ $) NIL (|has| |#1| (-1181)))) (-1986 (($ $) NIL (|has| |#1| (-1181)))) (-1937 (($ $) NIL (|has| |#1| (-1181)))) (-1978 (($ $) NIL (|has| |#1| (-1181)))) (-2790 (($ $) 26 (|has| |#1| (-1181)))) (-4278 (((-887 (-381)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-1075) (-609 (-541))) (|has| |#1| (-609 (-541)))))) (-3367 ((|#1| $) NIL (|has| |#1| (-453))) (($ $ (-1075)) NIL (|has| |#1| (-453)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#1| (-904))))) (-3950 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558))) (((-3 (-409 $) "failed") (-409 $) $) NIL (|has| |#1| (-558)))) (-2745 (((-850) $) 13) (($ (-568)) NIL) (($ |#1|) 11) (($ (-1075)) NIL) (($ (-409 (-568))) NIL (-2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#1| (-558)))) (-1302 (((-634 |#1|) $) NIL)) (-2604 ((|#1| $ (-763)) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-4078 (((-763)) NIL)) (-4171 (($ $ $ (-763)) NIL (|has| |#1| (-172)))) (-2006 (($ $) NIL (|has| |#1| (-1181)))) (-1958 (($ $) NIL (|has| |#1| (-1181)))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1998 (($ $) NIL (|has| |#1| (-1181)))) (-1949 (($ $) 24 (|has| |#1| (-1181)))) (-2014 (($ $) NIL (|has| |#1| (-1181)))) (-1966 (($ $) NIL (|has| |#1| (-1181)))) (-4023 (($ $) NIL (|has| |#1| (-1181)))) (-1970 (($ $) NIL (|has| |#1| (-1181)))) (-2010 (($ $) NIL (|has| |#1| (-1181)))) (-1962 (($ $) NIL (|has| |#1| (-1181)))) (-2002 (($ $) NIL (|has| |#1| (-1181)))) (-1953 (($ $) 28 (|has| |#1| (-1181)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ $) NIL (|has| |#1| (-1181)))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
+((-2449 (((-121) $ $) NIL (-2199 (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090)) (|has| |#1| (-1090))))) (-2988 (($) NIL) (($ (-634 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)))) NIL)) (-2481 (((-1249) $ (-1143) (-1143)) NIL (|has| $ (-6 -4522)))) (-1667 (((-121) $ (-763)) NIL)) (-2438 ((|#1| $ (-1143) |#1|) NIL)) (-3963 (($ (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL (|has| $ (-6 -4521)))) (-2678 (((-3 |#1| "failed") (-1143) $) NIL)) (-4490 (($) NIL T CONST)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090))))) (-1568 (($ (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) $) NIL (|has| $ (-6 -4521))) (($ (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL (|has| $ (-6 -4521))) (((-3 |#1| "failed") (-1143) $) NIL)) (-4330 (($ (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090)))) (($ (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL (|has| $ (-6 -4521)))) (-3094 (((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $ (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090)))) (((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $ (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) NIL (|has| $ (-6 -4521))) (((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL (|has| $ (-6 -4521)))) (-1292 ((|#1| $ (-1143) |#1|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-1143)) NIL)) (-3317 (((-634 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL (|has| $ (-6 -4521))) (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-1143) $) NIL (|has| (-1143) (-842)))) (-4406 (((-634 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL (|has| $ (-6 -4521))) (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090)))) (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3631 (((-1143) $) NIL (|has| (-1143) (-842)))) (-2253 (($ (-1 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL (|has| $ (-6 -4522))) (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL) (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (-2199 (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090)) (|has| |#1| (-1090))))) (-4253 (((-634 (-1143)) $) NIL)) (-2807 (((-121) (-1143) $) NIL)) (-2580 (((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) $) NIL)) (-1708 (($ (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) $) NIL)) (-3948 (((-634 (-1143)) $) NIL)) (-2916 (((-121) (-1143) $) NIL)) (-4025 (((-1108) $) NIL (-2199 (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090)) (|has| |#1| (-1090))))) (-3877 ((|#1| $) NIL (|has| (-1143) (-842)))) (-2712 (((-3 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) "failed") (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL)) (-2490 (($ $ |#1|) NIL (|has| $ (-6 -4522)))) (-3403 (((-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) $) NIL)) (-3951 (((-121) (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))))) NIL (-12 (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-303 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)))) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090)))) (($ $ (-288 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)))) NIL (-12 (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-303 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)))) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090)))) (($ $ (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) NIL (-12 (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-303 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)))) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090)))) (($ $ (-634 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) (-634 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)))) NIL (-12 (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-303 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)))) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#1| $ (-1143)) NIL) ((|#1| $ (-1143) |#1|) NIL)) (-3132 (($) NIL) (($ (-634 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)))) NIL)) (-4170 (((-763) (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL (|has| $ (-6 -4521))) (((-763) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090)))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-609 (-541))))) (-4289 (($ (-634 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)))) NIL)) (-2747 (((-850) $) NIL (-2199 (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090)) (|has| |#1| (-1090))))) (-4074 (($ (-634 (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)))) NIL)) (-3437 (((-121) (-1 (-121) (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|))) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) NIL (-2199 (|has| (-2 (|:| -3651 (-1143)) (|:| -4085 |#1|)) (-1090)) (|has| |#1| (-1090))))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-1144 |#1|) (-13 (-1172 (-1143) |#1|) (-10 -7 (-6 -4521))) (-1090)) (T -1144)) 
+NIL 
+(-13 (-1172 (-1143) |#1|) (-10 -7 (-6 -4521))) 
+((-3409 (((-1141 |#1|) (-1141 |#1|)) 77)) (-2902 (((-3 (-1141 |#1|) "failed") (-1141 |#1|)) 37)) (-4383 (((-1141 |#1|) (-409 (-568)) (-1141 |#1|)) 117 (|has| |#1| (-43 (-409 (-568)))))) (-2567 (((-1141 |#1|) |#1| (-1141 |#1|)) 121 (|has| |#1| (-365)))) (-1304 (((-1141 |#1|) (-1141 |#1|)) 90)) (-1662 (((-1141 (-568)) (-568)) 57)) (-4393 (((-1141 |#1|) (-1141 (-1141 |#1|))) 108 (|has| |#1| (-43 (-409 (-568)))))) (-4384 (((-1141 |#1|) (-568) (-568) (-1141 |#1|)) 95)) (-2356 (((-1141 |#1|) |#1| (-568)) 45)) (-1330 (((-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) 60)) (-2483 (((-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) 119 (|has| |#1| (-365)))) (-1316 (((-1141 |#1|) |#1| (-1 (-1141 |#1|))) 107 (|has| |#1| (-43 (-409 (-568)))))) (-2606 (((-1141 |#1|) (-1 |#1| (-568)) |#1| (-1 (-1141 |#1|))) 120 (|has| |#1| (-365)))) (-2517 (((-1141 |#1|) (-1141 |#1|)) 89)) (-2101 (((-1141 |#1|) (-1141 |#1|)) 76)) (-1588 (((-1141 |#1|) (-568) (-568) (-1141 |#1|)) 96)) (-1845 (((-1141 |#1|) |#1| (-1141 |#1|)) 105 (|has| |#1| (-43 (-409 (-568)))))) (-2867 (((-1141 (-568)) (-568)) 56)) (-2473 (((-1141 |#1|) |#1|) 59)) (-3638 (((-1141 |#1|) (-1141 |#1|) (-568) (-568)) 92)) (-2694 (((-1141 |#1|) (-1 |#1| (-568)) (-1141 |#1|)) 66)) (-2597 (((-3 (-1141 |#1|) "failed") (-1141 |#1|) (-1141 |#1|)) 35)) (-4109 (((-1141 |#1|) (-1141 |#1|)) 91)) (-1339 (((-1141 |#1|) (-1141 |#1|) |#1|) 71)) (-1375 (((-1141 |#1|) (-1141 |#1|)) 62)) (-2480 (((-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) 72)) (-2747 (((-1141 |#1|) |#1|) 67)) (-2506 (((-1141 |#1|) (-1141 (-1141 |#1|))) 82)) (-1781 (((-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) 36)) (-1775 (((-1141 |#1|) (-1141 |#1|)) 21) (((-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) 23)) (-1769 (((-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) 17)) (* (((-1141 |#1|) (-1141 |#1|) |#1|) 29) (((-1141 |#1|) |#1| (-1141 |#1|)) 26) (((-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) 27))) 
+(((-1145 |#1|) (-10 -7 (-15 -1769 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -1775 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -1775 ((-1141 |#1|) (-1141 |#1|))) (-15 * ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 * ((-1141 |#1|) |#1| (-1141 |#1|))) (-15 * ((-1141 |#1|) (-1141 |#1|) |#1|)) (-15 -2597 ((-3 (-1141 |#1|) "failed") (-1141 |#1|) (-1141 |#1|))) (-15 -1781 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -2902 ((-3 (-1141 |#1|) "failed") (-1141 |#1|))) (-15 -2356 ((-1141 |#1|) |#1| (-568))) (-15 -2867 ((-1141 (-568)) (-568))) (-15 -1662 ((-1141 (-568)) (-568))) (-15 -2473 ((-1141 |#1|) |#1|)) (-15 -1330 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -1375 ((-1141 |#1|) (-1141 |#1|))) (-15 -2694 ((-1141 |#1|) (-1 |#1| (-568)) (-1141 |#1|))) (-15 -2747 ((-1141 |#1|) |#1|)) (-15 -1339 ((-1141 |#1|) (-1141 |#1|) |#1|)) (-15 -2480 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -2101 ((-1141 |#1|) (-1141 |#1|))) (-15 -3409 ((-1141 |#1|) (-1141 |#1|))) (-15 -2506 ((-1141 |#1|) (-1141 (-1141 |#1|)))) (-15 -2517 ((-1141 |#1|) (-1141 |#1|))) (-15 -1304 ((-1141 |#1|) (-1141 |#1|))) (-15 -4109 ((-1141 |#1|) (-1141 |#1|))) (-15 -3638 ((-1141 |#1|) (-1141 |#1|) (-568) (-568))) (-15 -4384 ((-1141 |#1|) (-568) (-568) (-1141 |#1|))) (-15 -1588 ((-1141 |#1|) (-568) (-568) (-1141 |#1|))) (IF (|has| |#1| (-43 (-409 (-568)))) (PROGN (-15 -1845 ((-1141 |#1|) |#1| (-1141 |#1|))) (-15 -1316 ((-1141 |#1|) |#1| (-1 (-1141 |#1|)))) (-15 -4393 ((-1141 |#1|) (-1141 (-1141 |#1|)))) (-15 -4383 ((-1141 |#1|) (-409 (-568)) (-1141 |#1|)))) |noBranch|) (IF (|has| |#1| (-365)) (PROGN (-15 -2483 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -2606 ((-1141 |#1|) (-1 |#1| (-568)) |#1| (-1 (-1141 |#1|)))) (-15 -2567 ((-1141 |#1|) |#1| (-1141 |#1|)))) |noBranch|)) (-1047)) (T -1145)) 
+((-2567 (*1 *2 *3 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-2606 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *4 (-568))) (-5 *5 (-1 (-1141 *4))) (-4 *4 (-365)) (-4 *4 (-1047)) (-5 *2 (-1141 *4)) (-5 *1 (-1145 *4)))) (-2483 (*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-4383 (*1 *2 *3 *2) (-12 (-5 *2 (-1141 *4)) (-4 *4 (-43 *3)) (-4 *4 (-1047)) (-5 *3 (-409 (-568))) (-5 *1 (-1145 *4)))) (-4393 (*1 *2 *3) (-12 (-5 *3 (-1141 (-1141 *4))) (-5 *2 (-1141 *4)) (-5 *1 (-1145 *4)) (-4 *4 (-43 (-409 (-568)))) (-4 *4 (-1047)))) (-1316 (*1 *2 *3 *4) (-12 (-5 *4 (-1 (-1141 *3))) (-5 *2 (-1141 *3)) (-5 *1 (-1145 *3)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)))) (-1845 (*1 *2 *3 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-1588 (*1 *2 *3 *3 *2) (-12 (-5 *2 (-1141 *4)) (-5 *3 (-568)) (-4 *4 (-1047)) (-5 *1 (-1145 *4)))) (-4384 (*1 *2 *3 *3 *2) (-12 (-5 *2 (-1141 *4)) (-5 *3 (-568)) (-4 *4 (-1047)) (-5 *1 (-1145 *4)))) (-3638 (*1 *2 *2 *3 *3) (-12 (-5 *2 (-1141 *4)) (-5 *3 (-568)) (-4 *4 (-1047)) (-5 *1 (-1145 *4)))) (-4109 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-1304 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-2517 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-2506 (*1 *2 *3) (-12 (-5 *3 (-1141 (-1141 *4))) (-5 *2 (-1141 *4)) (-5 *1 (-1145 *4)) (-4 *4 (-1047)))) (-3409 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-2101 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-2480 (*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-1339 (*1 *2 *2 *3) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-2747 (*1 *2 *3) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-1145 *3)) (-4 *3 (-1047)))) (-2694 (*1 *2 *3 *2) (-12 (-5 *2 (-1141 *4)) (-5 *3 (-1 *4 (-568))) (-4 *4 (-1047)) (-5 *1 (-1145 *4)))) (-1375 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-1330 (*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-2473 (*1 *2 *3) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-1145 *3)) (-4 *3 (-1047)))) (-1662 (*1 *2 *3) (-12 (-5 *2 (-1141 (-568))) (-5 *1 (-1145 *4)) (-4 *4 (-1047)) (-5 *3 (-568)))) (-2867 (*1 *2 *3) (-12 (-5 *2 (-1141 (-568))) (-5 *1 (-1145 *4)) (-4 *4 (-1047)) (-5 *3 (-568)))) (-2356 (*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-5 *2 (-1141 *3)) (-5 *1 (-1145 *3)) (-4 *3 (-1047)))) (-2902 (*1 *2 *2) (|partial| -12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-1781 (*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-2597 (*1 *2 *2 *2) (|partial| -12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (* (*1 *2 *2 *3) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (* (*1 *2 *3 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (* (*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-1775 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-1775 (*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) (-1769 (*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3))))) 
+(-10 -7 (-15 -1769 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -1775 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -1775 ((-1141 |#1|) (-1141 |#1|))) (-15 * ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 * ((-1141 |#1|) |#1| (-1141 |#1|))) (-15 * ((-1141 |#1|) (-1141 |#1|) |#1|)) (-15 -2597 ((-3 (-1141 |#1|) "failed") (-1141 |#1|) (-1141 |#1|))) (-15 -1781 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -2902 ((-3 (-1141 |#1|) "failed") (-1141 |#1|))) (-15 -2356 ((-1141 |#1|) |#1| (-568))) (-15 -2867 ((-1141 (-568)) (-568))) (-15 -1662 ((-1141 (-568)) (-568))) (-15 -2473 ((-1141 |#1|) |#1|)) (-15 -1330 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -1375 ((-1141 |#1|) (-1141 |#1|))) (-15 -2694 ((-1141 |#1|) (-1 |#1| (-568)) (-1141 |#1|))) (-15 -2747 ((-1141 |#1|) |#1|)) (-15 -1339 ((-1141 |#1|) (-1141 |#1|) |#1|)) (-15 -2480 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -2101 ((-1141 |#1|) (-1141 |#1|))) (-15 -3409 ((-1141 |#1|) (-1141 |#1|))) (-15 -2506 ((-1141 |#1|) (-1141 (-1141 |#1|)))) (-15 -2517 ((-1141 |#1|) (-1141 |#1|))) (-15 -1304 ((-1141 |#1|) (-1141 |#1|))) (-15 -4109 ((-1141 |#1|) (-1141 |#1|))) (-15 -3638 ((-1141 |#1|) (-1141 |#1|) (-568) (-568))) (-15 -4384 ((-1141 |#1|) (-568) (-568) (-1141 |#1|))) (-15 -1588 ((-1141 |#1|) (-568) (-568) (-1141 |#1|))) (IF (|has| |#1| (-43 (-409 (-568)))) (PROGN (-15 -1845 ((-1141 |#1|) |#1| (-1141 |#1|))) (-15 -1316 ((-1141 |#1|) |#1| (-1 (-1141 |#1|)))) (-15 -4393 ((-1141 |#1|) (-1141 (-1141 |#1|)))) (-15 -4383 ((-1141 |#1|) (-409 (-568)) (-1141 |#1|)))) |noBranch|) (IF (|has| |#1| (-365)) (PROGN (-15 -2483 ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -2606 ((-1141 |#1|) (-1 |#1| (-568)) |#1| (-1 (-1141 |#1|)))) (-15 -2567 ((-1141 |#1|) |#1| (-1141 |#1|)))) |noBranch|)) 
+((-1984 (((-1141 |#1|) (-1141 |#1|)) 57)) (-1935 (((-1141 |#1|) (-1141 |#1|)) 39)) (-1976 (((-1141 |#1|) (-1141 |#1|)) 53)) (-2788 (((-1141 |#1|) (-1141 |#1|)) 35)) (-1992 (((-1141 |#1|) (-1141 |#1|)) 60)) (-1943 (((-1141 |#1|) (-1141 |#1|)) 42)) (-4418 (((-1141 |#1|) (-1141 |#1|)) 31)) (-1894 (((-1141 |#1|) (-1141 |#1|)) 27)) (-1996 (((-1141 |#1|) (-1141 |#1|)) 61)) (-1947 (((-1141 |#1|) (-1141 |#1|)) 43)) (-1988 (((-1141 |#1|) (-1141 |#1|)) 58)) (-1939 (((-1141 |#1|) (-1141 |#1|)) 40)) (-1980 (((-1141 |#1|) (-1141 |#1|)) 55)) (-2792 (((-1141 |#1|) (-1141 |#1|)) 37)) (-2008 (((-1141 |#1|) (-1141 |#1|)) 65)) (-1959 (((-1141 |#1|) (-1141 |#1|)) 47)) (-2000 (((-1141 |#1|) (-1141 |#1|)) 63)) (-1951 (((-1141 |#1|) (-1141 |#1|)) 45)) (-2016 (((-1141 |#1|) (-1141 |#1|)) 68)) (-1968 (((-1141 |#1|) (-1141 |#1|)) 50)) (-1439 (((-1141 |#1|) (-1141 |#1|)) 69)) (-1972 (((-1141 |#1|) (-1141 |#1|)) 51)) (-2012 (((-1141 |#1|) (-1141 |#1|)) 67)) (-1964 (((-1141 |#1|) (-1141 |#1|)) 49)) (-2004 (((-1141 |#1|) (-1141 |#1|)) 66)) (-1955 (((-1141 |#1|) (-1141 |#1|)) 48)) (** (((-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) 33))) 
+(((-1146 |#1|) (-10 -7 (-15 -1894 ((-1141 |#1|) (-1141 |#1|))) (-15 -4418 ((-1141 |#1|) (-1141 |#1|))) (-15 ** ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -2788 ((-1141 |#1|) (-1141 |#1|))) (-15 -2792 ((-1141 |#1|) (-1141 |#1|))) (-15 -1935 ((-1141 |#1|) (-1141 |#1|))) (-15 -1939 ((-1141 |#1|) (-1141 |#1|))) (-15 -1943 ((-1141 |#1|) (-1141 |#1|))) (-15 -1947 ((-1141 |#1|) (-1141 |#1|))) (-15 -1951 ((-1141 |#1|) (-1141 |#1|))) (-15 -1955 ((-1141 |#1|) (-1141 |#1|))) (-15 -1959 ((-1141 |#1|) (-1141 |#1|))) (-15 -1964 ((-1141 |#1|) (-1141 |#1|))) (-15 -1968 ((-1141 |#1|) (-1141 |#1|))) (-15 -1972 ((-1141 |#1|) (-1141 |#1|))) (-15 -1976 ((-1141 |#1|) (-1141 |#1|))) (-15 -1980 ((-1141 |#1|) (-1141 |#1|))) (-15 -1984 ((-1141 |#1|) (-1141 |#1|))) (-15 -1988 ((-1141 |#1|) (-1141 |#1|))) (-15 -1992 ((-1141 |#1|) (-1141 |#1|))) (-15 -1996 ((-1141 |#1|) (-1141 |#1|))) (-15 -2000 ((-1141 |#1|) (-1141 |#1|))) (-15 -2004 ((-1141 |#1|) (-1141 |#1|))) (-15 -2008 ((-1141 |#1|) (-1141 |#1|))) (-15 -2012 ((-1141 |#1|) (-1141 |#1|))) (-15 -2016 ((-1141 |#1|) (-1141 |#1|))) (-15 -1439 ((-1141 |#1|) (-1141 |#1|)))) (-43 (-409 (-568)))) (T -1146)) 
+((-1439 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-2016 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-2012 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-2008 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-2004 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-2000 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1996 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1992 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1988 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1984 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1980 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1976 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1972 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1968 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1964 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1959 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1955 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1951 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1947 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1943 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1939 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1935 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-2792 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-2788 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (** (*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-4418 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) (-1894 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3))))) 
+(-10 -7 (-15 -1894 ((-1141 |#1|) (-1141 |#1|))) (-15 -4418 ((-1141 |#1|) (-1141 |#1|))) (-15 ** ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -2788 ((-1141 |#1|) (-1141 |#1|))) (-15 -2792 ((-1141 |#1|) (-1141 |#1|))) (-15 -1935 ((-1141 |#1|) (-1141 |#1|))) (-15 -1939 ((-1141 |#1|) (-1141 |#1|))) (-15 -1943 ((-1141 |#1|) (-1141 |#1|))) (-15 -1947 ((-1141 |#1|) (-1141 |#1|))) (-15 -1951 ((-1141 |#1|) (-1141 |#1|))) (-15 -1955 ((-1141 |#1|) (-1141 |#1|))) (-15 -1959 ((-1141 |#1|) (-1141 |#1|))) (-15 -1964 ((-1141 |#1|) (-1141 |#1|))) (-15 -1968 ((-1141 |#1|) (-1141 |#1|))) (-15 -1972 ((-1141 |#1|) (-1141 |#1|))) (-15 -1976 ((-1141 |#1|) (-1141 |#1|))) (-15 -1980 ((-1141 |#1|) (-1141 |#1|))) (-15 -1984 ((-1141 |#1|) (-1141 |#1|))) (-15 -1988 ((-1141 |#1|) (-1141 |#1|))) (-15 -1992 ((-1141 |#1|) (-1141 |#1|))) (-15 -1996 ((-1141 |#1|) (-1141 |#1|))) (-15 -2000 ((-1141 |#1|) (-1141 |#1|))) (-15 -2004 ((-1141 |#1|) (-1141 |#1|))) (-15 -2008 ((-1141 |#1|) (-1141 |#1|))) (-15 -2012 ((-1141 |#1|) (-1141 |#1|))) (-15 -2016 ((-1141 |#1|) (-1141 |#1|))) (-15 -1439 ((-1141 |#1|) (-1141 |#1|)))) 
+((-1984 (((-1141 |#1|) (-1141 |#1|)) 100)) (-1935 (((-1141 |#1|) (-1141 |#1|)) 64)) (-3391 (((-2 (|:| -1976 (-1141 |#1|)) (|:| -1980 (-1141 |#1|))) (-1141 |#1|)) 96)) (-1976 (((-1141 |#1|) (-1141 |#1|)) 97)) (-2243 (((-2 (|:| -2788 (-1141 |#1|)) (|:| -2792 (-1141 |#1|))) (-1141 |#1|)) 53)) (-2788 (((-1141 |#1|) (-1141 |#1|)) 54)) (-1992 (((-1141 |#1|) (-1141 |#1|)) 102)) (-1943 (((-1141 |#1|) (-1141 |#1|)) 71)) (-4418 (((-1141 |#1|) (-1141 |#1|)) 39)) (-1894 (((-1141 |#1|) (-1141 |#1|)) 36)) (-1996 (((-1141 |#1|) (-1141 |#1|)) 103)) (-1947 (((-1141 |#1|) (-1141 |#1|)) 72)) (-1988 (((-1141 |#1|) (-1141 |#1|)) 101)) (-1939 (((-1141 |#1|) (-1141 |#1|)) 67)) (-1980 (((-1141 |#1|) (-1141 |#1|)) 98)) (-2792 (((-1141 |#1|) (-1141 |#1|)) 55)) (-2008 (((-1141 |#1|) (-1141 |#1|)) 111)) (-1959 (((-1141 |#1|) (-1141 |#1|)) 86)) (-2000 (((-1141 |#1|) (-1141 |#1|)) 105)) (-1951 (((-1141 |#1|) (-1141 |#1|)) 82)) (-2016 (((-1141 |#1|) (-1141 |#1|)) 115)) (-1968 (((-1141 |#1|) (-1141 |#1|)) 90)) (-1439 (((-1141 |#1|) (-1141 |#1|)) 117)) (-1972 (((-1141 |#1|) (-1141 |#1|)) 92)) (-2012 (((-1141 |#1|) (-1141 |#1|)) 113)) (-1964 (((-1141 |#1|) (-1141 |#1|)) 88)) (-2004 (((-1141 |#1|) (-1141 |#1|)) 107)) (-1955 (((-1141 |#1|) (-1141 |#1|)) 84)) (** (((-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) 40))) 
+(((-1147 |#1|) (-10 -7 (-15 -1894 ((-1141 |#1|) (-1141 |#1|))) (-15 -4418 ((-1141 |#1|) (-1141 |#1|))) (-15 ** ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -2243 ((-2 (|:| -2788 (-1141 |#1|)) (|:| -2792 (-1141 |#1|))) (-1141 |#1|))) (-15 -2788 ((-1141 |#1|) (-1141 |#1|))) (-15 -2792 ((-1141 |#1|) (-1141 |#1|))) (-15 -1935 ((-1141 |#1|) (-1141 |#1|))) (-15 -1939 ((-1141 |#1|) (-1141 |#1|))) (-15 -1943 ((-1141 |#1|) (-1141 |#1|))) (-15 -1947 ((-1141 |#1|) (-1141 |#1|))) (-15 -1951 ((-1141 |#1|) (-1141 |#1|))) (-15 -1955 ((-1141 |#1|) (-1141 |#1|))) (-15 -1959 ((-1141 |#1|) (-1141 |#1|))) (-15 -1964 ((-1141 |#1|) (-1141 |#1|))) (-15 -1968 ((-1141 |#1|) (-1141 |#1|))) (-15 -1972 ((-1141 |#1|) (-1141 |#1|))) (-15 -3391 ((-2 (|:| -1976 (-1141 |#1|)) (|:| -1980 (-1141 |#1|))) (-1141 |#1|))) (-15 -1976 ((-1141 |#1|) (-1141 |#1|))) (-15 -1980 ((-1141 |#1|) (-1141 |#1|))) (-15 -1984 ((-1141 |#1|) (-1141 |#1|))) (-15 -1988 ((-1141 |#1|) (-1141 |#1|))) (-15 -1992 ((-1141 |#1|) (-1141 |#1|))) (-15 -1996 ((-1141 |#1|) (-1141 |#1|))) (-15 -2000 ((-1141 |#1|) (-1141 |#1|))) (-15 -2004 ((-1141 |#1|) (-1141 |#1|))) (-15 -2008 ((-1141 |#1|) (-1141 |#1|))) (-15 -2012 ((-1141 |#1|) (-1141 |#1|))) (-15 -2016 ((-1141 |#1|) (-1141 |#1|))) (-15 -1439 ((-1141 |#1|) (-1141 |#1|)))) (-43 (-409 (-568)))) (T -1147)) 
+((-1439 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-2016 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-2012 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-2008 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-2004 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-2000 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1996 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1992 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1988 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1984 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1980 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1976 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-3391 (*1 *2 *3) (-12 (-4 *4 (-43 (-409 (-568)))) (-5 *2 (-2 (|:| -1976 (-1141 *4)) (|:| -1980 (-1141 *4)))) (-5 *1 (-1147 *4)) (-5 *3 (-1141 *4)))) (-1972 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1968 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1964 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1959 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1955 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1951 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1947 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1943 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1939 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1935 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-2792 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-2788 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-2243 (*1 *2 *3) (-12 (-4 *4 (-43 (-409 (-568)))) (-5 *2 (-2 (|:| -2788 (-1141 *4)) (|:| -2792 (-1141 *4)))) (-5 *1 (-1147 *4)) (-5 *3 (-1141 *4)))) (** (*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-4418 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) (-1894 (*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3))))) 
+(-10 -7 (-15 -1894 ((-1141 |#1|) (-1141 |#1|))) (-15 -4418 ((-1141 |#1|) (-1141 |#1|))) (-15 ** ((-1141 |#1|) (-1141 |#1|) (-1141 |#1|))) (-15 -2243 ((-2 (|:| -2788 (-1141 |#1|)) (|:| -2792 (-1141 |#1|))) (-1141 |#1|))) (-15 -2788 ((-1141 |#1|) (-1141 |#1|))) (-15 -2792 ((-1141 |#1|) (-1141 |#1|))) (-15 -1935 ((-1141 |#1|) (-1141 |#1|))) (-15 -1939 ((-1141 |#1|) (-1141 |#1|))) (-15 -1943 ((-1141 |#1|) (-1141 |#1|))) (-15 -1947 ((-1141 |#1|) (-1141 |#1|))) (-15 -1951 ((-1141 |#1|) (-1141 |#1|))) (-15 -1955 ((-1141 |#1|) (-1141 |#1|))) (-15 -1959 ((-1141 |#1|) (-1141 |#1|))) (-15 -1964 ((-1141 |#1|) (-1141 |#1|))) (-15 -1968 ((-1141 |#1|) (-1141 |#1|))) (-15 -1972 ((-1141 |#1|) (-1141 |#1|))) (-15 -3391 ((-2 (|:| -1976 (-1141 |#1|)) (|:| -1980 (-1141 |#1|))) (-1141 |#1|))) (-15 -1976 ((-1141 |#1|) (-1141 |#1|))) (-15 -1980 ((-1141 |#1|) (-1141 |#1|))) (-15 -1984 ((-1141 |#1|) (-1141 |#1|))) (-15 -1988 ((-1141 |#1|) (-1141 |#1|))) (-15 -1992 ((-1141 |#1|) (-1141 |#1|))) (-15 -1996 ((-1141 |#1|) (-1141 |#1|))) (-15 -2000 ((-1141 |#1|) (-1141 |#1|))) (-15 -2004 ((-1141 |#1|) (-1141 |#1|))) (-15 -2008 ((-1141 |#1|) (-1141 |#1|))) (-15 -2012 ((-1141 |#1|) (-1141 |#1|))) (-15 -2016 ((-1141 |#1|) (-1141 |#1|))) (-15 -1439 ((-1141 |#1|) (-1141 |#1|)))) 
+((-4372 (((-958 |#2|) |#2| |#2|) 35)) (-1998 ((|#2| |#2| |#1|) 19 (|has| |#1| (-301))))) 
+(((-1148 |#1| |#2|) (-10 -7 (-15 -4372 ((-958 |#2|) |#2| |#2|)) (IF (|has| |#1| (-301)) (-15 -1998 (|#2| |#2| |#1|)) |noBranch|)) (-558) (-1219 |#1|)) (T -1148)) 
+((-1998 (*1 *2 *2 *3) (-12 (-4 *3 (-301)) (-4 *3 (-558)) (-5 *1 (-1148 *3 *2)) (-4 *2 (-1219 *3)))) (-4372 (*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-958 *3)) (-5 *1 (-1148 *4 *3)) (-4 *3 (-1219 *4))))) 
+(-10 -7 (-15 -4372 ((-958 |#2|) |#2| |#2|)) (IF (|has| |#1| (-301)) (-15 -1998 (|#2| |#2| |#1|)) |noBranch|)) 
+((-2449 (((-121) $ $) NIL)) (-1409 (($ $ (-634 (-763))) 66)) (-3503 (($) 25)) (-3526 (($ $) 41)) (-1448 (((-634 $) $) 50)) (-3616 (((-121) $) 16)) (-3665 (((-634 (-944 |#2|)) $) 73)) (-1916 (($ $) 67)) (-1305 (((-763) $) 36)) (-1851 (($) 24)) (-1393 (($ $ (-634 (-763)) (-944 |#2|)) 59) (($ $ (-634 (-763)) (-763)) 60) (($ $ (-763) (-944 |#2|)) 62)) (-3645 (($ $ $) 47) (($ (-634 $)) 49)) (-2469 (((-763) $) 74)) (-3319 (((-121) $) 15)) (-1893 (((-1143) $) NIL)) (-3841 (((-121) $) 17)) (-4025 (((-1108) $) NIL)) (-1892 (((-171) $) 72)) (-3219 (((-944 |#2|) $) 68)) (-3790 (((-763) $) 69)) (-1597 (((-121) $) 71)) (-2625 (($ $ (-634 (-763)) (-171)) 65)) (-3556 (($ $) 42)) (-2747 (((-850) $) 84)) (-4132 (($ $ (-634 (-763)) (-121)) 64)) (-3180 (((-634 $) $) 11)) (-4267 (($ $ (-763)) 35)) (-2084 (($ $) 31)) (-3879 (($ $ $ (-944 |#2|) (-763)) 55)) (-3902 (($ $ (-944 |#2|)) 54)) (-1816 (($ $ (-634 (-763)) (-944 |#2|)) 53) (($ $ (-634 (-763)) (-763)) 57) (((-763) $ (-944 |#2|)) 58)) (-1719 (((-121) $ $) 78))) 
+(((-1149 |#1| |#2|) (-13 (-1090) (-10 -8 (-15 -3319 ((-121) $)) (-15 -3616 ((-121) $)) (-15 -3841 ((-121) $)) (-15 -1851 ($)) (-15 -3503 ($)) (-15 -2084 ($ $)) (-15 -4267 ($ $ (-763))) (-15 -3180 ((-634 $) $)) (-15 -1305 ((-763) $)) (-15 -3526 ($ $)) (-15 -3556 ($ $)) (-15 -3645 ($ $ $)) (-15 -3645 ($ (-634 $))) (-15 -1448 ((-634 $) $)) (-15 -1816 ($ $ (-634 (-763)) (-944 |#2|))) (-15 -3902 ($ $ (-944 |#2|))) (-15 -3879 ($ $ $ (-944 |#2|) (-763))) (-15 -1393 ($ $ (-634 (-763)) (-944 |#2|))) (-15 -1816 ($ $ (-634 (-763)) (-763))) (-15 -1393 ($ $ (-634 (-763)) (-763))) (-15 -1816 ((-763) $ (-944 |#2|))) (-15 -1393 ($ $ (-763) (-944 |#2|))) (-15 -4132 ($ $ (-634 (-763)) (-121))) (-15 -2625 ($ $ (-634 (-763)) (-171))) (-15 -1409 ($ $ (-634 (-763)))) (-15 -3219 ((-944 |#2|) $)) (-15 -3790 ((-763) $)) (-15 -1597 ((-121) $)) (-15 -1892 ((-171) $)) (-15 -2469 ((-763) $)) (-15 -1916 ($ $)) (-15 -3665 ((-634 (-944 |#2|)) $)))) (-917) (-1047)) (T -1149)) 
+((-3319 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-3616 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-3841 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-1851 (*1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047)))) (-3503 (*1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047)))) (-2084 (*1 *1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047)))) (-4267 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-3180 (*1 *2 *1) (-12 (-5 *2 (-634 (-1149 *3 *4))) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-1305 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-3526 (*1 *1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047)))) (-3556 (*1 *1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047)))) (-3645 (*1 *1 *1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047)))) (-3645 (*1 *1 *2) (-12 (-5 *2 (-634 (-1149 *3 *4))) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-1448 (*1 *2 *1) (-12 (-5 *2 (-634 (-1149 *3 *4))) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-1816 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-944 *5)) (-4 *5 (-1047)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)))) (-3902 (*1 *1 *1 *2) (-12 (-5 *2 (-944 *4)) (-4 *4 (-1047)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)))) (-3879 (*1 *1 *1 *1 *2 *3) (-12 (-5 *2 (-944 *5)) (-5 *3 (-763)) (-4 *5 (-1047)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)))) (-1393 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-944 *5)) (-4 *5 (-1047)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)))) (-1816 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-763)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)) (-4 *5 (-1047)))) (-1393 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-763)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)) (-4 *5 (-1047)))) (-1816 (*1 *2 *1 *3) (-12 (-5 *3 (-944 *5)) (-4 *5 (-1047)) (-5 *2 (-763)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)))) (-1393 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *3 (-944 *5)) (-4 *5 (-1047)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)))) (-4132 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-121)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)) (-4 *5 (-1047)))) (-2625 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-171)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)) (-4 *5 (-1047)))) (-1409 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-763))) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-3219 (*1 *2 *1) (-12 (-5 *2 (-944 *4)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-3790 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-1597 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-1892 (*1 *2 *1) (-12 (-5 *2 (-171)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-2469 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) (-1916 (*1 *1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047)))) (-3665 (*1 *2 *1) (-12 (-5 *2 (-634 (-944 *4))) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
+(-13 (-1090) (-10 -8 (-15 -3319 ((-121) $)) (-15 -3616 ((-121) $)) (-15 -3841 ((-121) $)) (-15 -1851 ($)) (-15 -3503 ($)) (-15 -2084 ($ $)) (-15 -4267 ($ $ (-763))) (-15 -3180 ((-634 $) $)) (-15 -1305 ((-763) $)) (-15 -3526 ($ $)) (-15 -3556 ($ $)) (-15 -3645 ($ $ $)) (-15 -3645 ($ (-634 $))) (-15 -1448 ((-634 $) $)) (-15 -1816 ($ $ (-634 (-763)) (-944 |#2|))) (-15 -3902 ($ $ (-944 |#2|))) (-15 -3879 ($ $ $ (-944 |#2|) (-763))) (-15 -1393 ($ $ (-634 (-763)) (-944 |#2|))) (-15 -1816 ($ $ (-634 (-763)) (-763))) (-15 -1393 ($ $ (-634 (-763)) (-763))) (-15 -1816 ((-763) $ (-944 |#2|))) (-15 -1393 ($ $ (-763) (-944 |#2|))) (-15 -4132 ($ $ (-634 (-763)) (-121))) (-15 -2625 ($ $ (-634 (-763)) (-171))) (-15 -1409 ($ $ (-634 (-763)))) (-15 -3219 ((-944 |#2|) $)) (-15 -3790 ((-763) $)) (-15 -1597 ((-121) $)) (-15 -1892 ((-171) $)) (-15 -2469 ((-763) $)) (-15 -1916 ($ $)) (-15 -3665 ((-634 (-944 |#2|)) $)))) 
+((-2449 (((-121) $ $) NIL)) (-3250 ((|#2| $) 11)) (-2433 ((|#1| $) 10)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-4289 (($ |#1| |#2|) 9)) (-2747 (((-850) $) 16)) (-1719 (((-121) $ $) NIL))) 
+(((-1150 |#1| |#2|) (-13 (-1090) (-10 -8 (-15 -4289 ($ |#1| |#2|)) (-15 -2433 (|#1| $)) (-15 -3250 (|#2| $)))) (-1090) (-1090)) (T -1150)) 
+((-4289 (*1 *1 *2 *3) (-12 (-5 *1 (-1150 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090)))) (-2433 (*1 *2 *1) (-12 (-4 *2 (-1090)) (-5 *1 (-1150 *2 *3)) (-4 *3 (-1090)))) (-3250 (*1 *2 *1) (-12 (-4 *2 (-1090)) (-5 *1 (-1150 *3 *2)) (-4 *3 (-1090))))) 
+(-13 (-1090) (-10 -8 (-15 -4289 ($ |#1| |#2|)) (-15 -2433 (|#1| $)) (-15 -3250 (|#2| $)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2563 (((-1159 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-301)) (|has| |#1| (-365))))) (-2057 (((-634 (-1075)) $) NIL)) (-3325 (((-1161) $) 11)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558))))) (-3661 (($ $) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558))))) (-4426 (((-121) $) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558))))) (-4179 (($ $ (-568)) NIL) (($ $ (-568) (-568)) 66)) (-2013 (((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL)) (-3054 (((-1159 |#1| |#2| |#3|) $) 36)) (-1415 (((-3 (-1159 |#1| |#2| |#3|) "failed") $) 29)) (-2067 (((-1159 |#1| |#2| |#3|) $) 30)) (-1984 (($ $) 107 (|has| |#1| (-43 (-409 (-568)))))) (-1935 (($ $) 83 (|has| |#1| (-43 (-409 (-568)))))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))))) (-3045 (($ $) NIL (|has| |#1| (-365)))) (-3498 (((-420 $) $) NIL (|has| |#1| (-365)))) (-1904 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))))) (-2589 (((-121) $ $) NIL (|has| |#1| (-365)))) (-1976 (($ $) 103 (|has| |#1| (-43 (-409 (-568)))))) (-2788 (($ $) 79 (|has| |#1| (-43 (-409 (-568)))))) (-3337 (((-568) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))))) (-2512 (($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) NIL)) (-1992 (($ $) 111 (|has| |#1| (-43 (-409 (-568)))))) (-1943 (($ $) 87 (|has| |#1| (-43 (-409 (-568)))))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-1159 |#1| |#2| |#3|) "failed") $) 31) (((-3 (-1161) "failed") $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-1037 (-1161))) (|has| |#1| (-365)))) (((-3 (-409 (-568)) "failed") $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-1037 (-568))) (|has| |#1| (-365)))) (((-3 (-568) "failed") $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-1037 (-568))) (|has| |#1| (-365))))) (-2857 (((-1159 |#1| |#2| |#3|) $) 131) (((-1161) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-1037 (-1161))) (|has| |#1| (-365)))) (((-409 (-568)) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-1037 (-568))) (|has| |#1| (-365)))) (((-568) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-1037 (-568))) (|has| |#1| (-365))))) (-2232 (($ $) 34) (($ (-568) $) 35)) (-2403 (($ $ $) NIL (|has| |#1| (-365)))) (-2116 (($ $) NIL)) (-1668 (((-679 (-1159 |#1| |#2| |#3|)) (-679 $)) NIL (|has| |#1| (-365))) (((-2 (|:| -2908 (-679 (-1159 |#1| |#2| |#3|))) (|:| |vec| (-1244 (-1159 |#1| |#2| |#3|)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-365))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-630 (-568))) (|has| |#1| (-365)))) (((-679 (-568)) (-679 $)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-630 (-568))) (|has| |#1| (-365))))) (-2902 (((-3 $ "failed") $) 48)) (-1685 (((-409 (-953 |#1|)) $ (-568)) 65 (|has| |#1| (-558))) (((-409 (-953 |#1|)) $ (-568) (-568)) 67 (|has| |#1| (-558)))) (-1733 (($) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-550)) (|has| |#1| (-365))))) (-2414 (($ $ $) NIL (|has| |#1| (-365)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-2197 (((-121) $) NIL (|has| |#1| (-365)))) (-1436 (((-121) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))))) (-1302 (((-121) $) 25)) (-1899 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-881 (-568))) (|has| |#1| (-365)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-881 (-381))) (|has| |#1| (-365))))) (-1844 (((-568) $) NIL) (((-568) $ (-568)) 24)) (-1598 (((-121) $) NIL)) (-3539 (($ $) NIL (|has| |#1| (-365)))) (-2319 (((-1159 |#1| |#2| |#3|) $) 38 (|has| |#1| (-365)))) (-1550 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2214 (((-3 $ "failed") $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-1136)) (|has| |#1| (-365))))) (-2859 (((-121) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))))) (-4168 (($ $ (-917)) NIL)) (-3698 (($ (-1 |#1| (-568)) $) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| (-568)) 18) (($ $ (-1075) (-568)) NIL) (($ $ (-634 (-1075)) (-634 (-568))) NIL)) (-1732 (($ $ $) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-2047 (($ $ $) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-2797 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 (-1159 |#1| |#2| |#3|) (-1159 |#1| |#2| |#3|)) $) NIL (|has| |#1| (-365)))) (-4418 (($ $) 72 (|has| |#1| (-43 (-409 (-568)))))) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-2498 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-2072 (($ (-568) (-1159 |#1| |#2| |#3|)) 33)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL (|has| |#1| (-365)))) (-1845 (($ $) 70 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) NIL (-2199 (-12 (|has| |#1| (-15 -1845 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2057 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181))))) (($ $ (-1240 |#2|)) 71 (|has| |#1| (-43 (-409 (-568)))))) (-4436 (($) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-1136)) (|has| |#1| (-365))) CONST)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-365)))) (-2723 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-1999 (($ $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-301)) (|has| |#1| (-365))))) (-4115 (((-1159 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-550)) (|has| |#1| (-365))))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))))) (-3850 (((-420 $) $) NIL (|has| |#1| (-365)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-365)))) (-2168 (($ $ (-568)) 145)) (-2597 (((-3 $ "failed") $ $) 49 (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558))))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1894 (($ $) 73 (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-568))))) (($ $ (-1161) (-1159 |#1| |#2| |#3|)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-523 (-1161) (-1159 |#1| |#2| |#3|))) (|has| |#1| (-365)))) (($ $ (-634 (-1161)) (-634 (-1159 |#1| |#2| |#3|))) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-523 (-1161) (-1159 |#1| |#2| |#3|))) (|has| |#1| (-365)))) (($ $ (-634 (-288 (-1159 |#1| |#2| |#3|)))) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-303 (-1159 |#1| |#2| |#3|))) (|has| |#1| (-365)))) (($ $ (-288 (-1159 |#1| |#2| |#3|))) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-303 (-1159 |#1| |#2| |#3|))) (|has| |#1| (-365)))) (($ $ (-1159 |#1| |#2| |#3|) (-1159 |#1| |#2| |#3|)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-303 (-1159 |#1| |#2| |#3|))) (|has| |#1| (-365)))) (($ $ (-634 (-1159 |#1| |#2| |#3|)) (-634 (-1159 |#1| |#2| |#3|))) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-303 (-1159 |#1| |#2| |#3|))) (|has| |#1| (-365))))) (-1466 (((-763) $) NIL (|has| |#1| (-365)))) (-2781 ((|#1| $ (-568)) NIL) (($ $ $) 54 (|has| (-568) (-1102))) (($ $ (-1159 |#1| |#2| |#3|)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-281 (-1159 |#1| |#2| |#3|) (-1159 |#1| |#2| |#3|))) (|has| |#1| (-365))))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-365)))) (-4191 (($ $ (-1 (-1159 |#1| |#2| |#3|) (-1159 |#1| |#2| |#3|))) NIL (|has| |#1| (-365))) (($ $ (-1 (-1159 |#1| |#2| |#3|) (-1159 |#1| |#2| |#3|)) (-763)) NIL (|has| |#1| (-365))) (($ $ (-1240 |#2|)) 51) (($ $ (-763)) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $) 50 (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161) (-763)) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-634 (-1161))) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161)) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))))) (-3210 (($ $) NIL (|has| |#1| (-365)))) (-2326 (((-1159 |#1| |#2| |#3|) $) 41 (|has| |#1| (-365)))) (-1836 (((-568) $) 37)) (-1996 (($ $) 113 (|has| |#1| (-43 (-409 (-568)))))) (-1947 (($ $) 89 (|has| |#1| (-43 (-409 (-568)))))) (-1988 (($ $) 109 (|has| |#1| (-43 (-409 (-568)))))) (-1939 (($ $) 85 (|has| |#1| (-43 (-409 (-568)))))) (-1980 (($ $) 105 (|has| |#1| (-43 (-409 (-568)))))) (-2792 (($ $) 81 (|has| |#1| (-43 (-409 (-568)))))) (-4280 (((-541) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-609 (-541))) (|has| |#1| (-365)))) (((-381) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-1021)) (|has| |#1| (-365)))) (((-215) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-1021)) (|has| |#1| (-365)))) (((-887 (-381)) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-609 (-887 (-381)))) (|has| |#1| (-365)))) (((-887 (-568)) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-609 (-887 (-568)))) (|has| |#1| (-365))))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))))) (-2188 (($ $) NIL)) (-2747 (((-850) $) 149) (($ (-568)) NIL) (($ |#1|) NIL (|has| |#1| (-172))) (($ (-1159 |#1| |#2| |#3|)) 27) (($ (-1240 |#2|)) 23) (($ (-1161)) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-1037 (-1161))) (|has| |#1| (-365)))) (($ $) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558)))) (($ (-409 (-568))) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-1037 (-568))) (|has| |#1| (-365))) (|has| |#1| (-43 (-409 (-568))))))) (-2079 ((|#1| $ (-568)) 68)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-148)) (|has| |#1| (-365))) (|has| |#1| (-148))))) (-3425 (((-763)) NIL)) (-1374 ((|#1| $) 12)) (-3520 (((-1159 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-550)) (|has| |#1| (-365))))) (-2008 (($ $) 119 (|has| |#1| (-43 (-409 (-568)))))) (-1959 (($ $) 95 (|has| |#1| (-43 (-409 (-568)))))) (-2273 (((-121) $ $) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558))))) (-2000 (($ $) 115 (|has| |#1| (-43 (-409 (-568)))))) (-1951 (($ $) 91 (|has| |#1| (-43 (-409 (-568)))))) (-2016 (($ $) 123 (|has| |#1| (-43 (-409 (-568)))))) (-1968 (($ $) 99 (|has| |#1| (-43 (-409 (-568)))))) (-3999 ((|#1| $ (-568)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-568)))) (|has| |#1| (-15 -2747 (|#1| (-1161))))))) (-1439 (($ $) 125 (|has| |#1| (-43 (-409 (-568)))))) (-1972 (($ $) 101 (|has| |#1| (-43 (-409 (-568)))))) (-2012 (($ $) 121 (|has| |#1| (-43 (-409 (-568)))))) (-1964 (($ $) 97 (|has| |#1| (-43 (-409 (-568)))))) (-2004 (($ $) 117 (|has| |#1| (-43 (-409 (-568)))))) (-1955 (($ $) 93 (|has| |#1| (-43 (-409 (-568)))))) (-2811 (($ $) NIL (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (-3058 (($) 20 T CONST)) (-1557 (($) 16 T CONST)) (-3192 (($ $ (-1 (-1159 |#1| |#2| |#3|) (-1159 |#1| |#2| |#3|))) NIL (|has| |#1| (-365))) (($ $ (-1 (-1159 |#1| |#2| |#3|) (-1159 |#1| |#2| |#3|)) (-763)) NIL (|has| |#1| (-365))) (($ $ (-763)) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161) (-763)) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-634 (-1161))) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161)) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))))) (-1753 (((-121) $ $) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-1740 (((-121) $ $) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-1734 (((-121) $ $) NIL (-2199 (-12 (|has| (-1159 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1159 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365))) (($ $ $) 44 (|has| |#1| (-365))) (($ (-1159 |#1| |#2| |#3|) (-1159 |#1| |#2| |#3|)) 45 (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) 21)) (** (($ $ (-917)) NIL) (($ $ (-763)) 53) (($ $ (-568)) NIL (|has| |#1| (-365))) (($ $ $) 74 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 128 (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 32) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ (-1159 |#1| |#2| |#3|)) 43 (|has| |#1| (-365))) (($ (-1159 |#1| |#2| |#3|) $) 42 (|has| |#1| (-365))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
+(((-1151 |#1| |#2| |#3|) (-13 (-1205 |#1| (-1159 |#1| |#2| |#3|)) (-10 -8 (-15 -2747 ($ (-1240 |#2|))) (-15 -4191 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -1845 ($ $ (-1240 |#2|))) |noBranch|))) (-1047) (-1161) |#1|) (T -1151)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1151 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-4191 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1151 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-1845 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1151 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3)))) 
+(-13 (-1205 |#1| (-1159 |#1| |#2| |#3|)) (-10 -8 (-15 -2747 ($ (-1240 |#2|))) (-15 -4191 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -1845 ($ $ (-1240 |#2|))) |noBranch|))) 
+((-2630 ((|#2| |#2| (-1082 |#2|)) 26) ((|#2| |#2| (-1161)) 28))) 
+(((-1152 |#1| |#2|) (-10 -7 (-15 -2630 (|#2| |#2| (-1161))) (-15 -2630 (|#2| |#2| (-1082 |#2|)))) (-13 (-558) (-842) (-1037 (-568)) (-630 (-568))) (-13 (-432 |#1|) (-161) (-27) (-1181))) (T -1152)) 
+((-2630 (*1 *2 *2 *3) (-12 (-5 *3 (-1082 *2)) (-4 *2 (-13 (-432 *4) (-161) (-27) (-1181))) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1152 *4 *2)))) (-2630 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1152 *4 *2)) (-4 *2 (-13 (-432 *4) (-161) (-27) (-1181)))))) 
+(-10 -7 (-15 -2630 (|#2| |#2| (-1161))) (-15 -2630 (|#2| |#2| (-1082 |#2|)))) 
+((-2630 (((-3 (-409 (-953 |#1|)) (-310 |#1|)) (-409 (-953 |#1|)) (-1082 (-409 (-953 |#1|)))) 30) (((-409 (-953 |#1|)) (-953 |#1|) (-1082 (-953 |#1|))) 44) (((-3 (-409 (-953 |#1|)) (-310 |#1|)) (-409 (-953 |#1|)) (-1161)) 32) (((-409 (-953 |#1|)) (-953 |#1|) (-1161)) 36))) 
+(((-1153 |#1|) (-10 -7 (-15 -2630 ((-409 (-953 |#1|)) (-953 |#1|) (-1161))) (-15 -2630 ((-3 (-409 (-953 |#1|)) (-310 |#1|)) (-409 (-953 |#1|)) (-1161))) (-15 -2630 ((-409 (-953 |#1|)) (-953 |#1|) (-1082 (-953 |#1|)))) (-15 -2630 ((-3 (-409 (-953 |#1|)) (-310 |#1|)) (-409 (-953 |#1|)) (-1082 (-409 (-953 |#1|)))))) (-13 (-558) (-842) (-1037 (-568)))) (T -1153)) 
+((-2630 (*1 *2 *3 *4) (-12 (-5 *4 (-1082 (-409 (-953 *5)))) (-5 *3 (-409 (-953 *5))) (-4 *5 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-3 *3 (-310 *5))) (-5 *1 (-1153 *5)))) (-2630 (*1 *2 *3 *4) (-12 (-5 *4 (-1082 (-953 *5))) (-5 *3 (-953 *5)) (-4 *5 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-409 *3)) (-5 *1 (-1153 *5)))) (-2630 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-3 (-409 (-953 *5)) (-310 *5))) (-5 *1 (-1153 *5)) (-5 *3 (-409 (-953 *5))))) (-2630 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-409 (-953 *5))) (-5 *1 (-1153 *5)) (-5 *3 (-953 *5))))) 
+(-10 -7 (-15 -2630 ((-409 (-953 |#1|)) (-953 |#1|) (-1161))) (-15 -2630 ((-3 (-409 (-953 |#1|)) (-310 |#1|)) (-409 (-953 |#1|)) (-1161))) (-15 -2630 ((-409 (-953 |#1|)) (-953 |#1|) (-1082 (-953 |#1|)))) (-15 -2630 ((-3 (-409 (-953 |#1|)) (-310 |#1|)) (-409 (-953 |#1|)) (-1082 (-409 (-953 |#1|)))))) 
+((-2797 (((-1157 |#2|) (-1 |#2| |#1|) (-1157 |#1|)) 13))) 
+(((-1154 |#1| |#2|) (-10 -7 (-15 -2797 ((-1157 |#2|) (-1 |#2| |#1|) (-1157 |#1|)))) (-1047) (-1047)) (T -1154)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1157 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-5 *2 (-1157 *6)) (-5 *1 (-1154 *5 *6))))) 
+(-10 -7 (-15 -2797 ((-1157 |#2|) (-1 |#2| |#1|) (-1157 |#1|)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-1969 (((-1244 |#1|) $ (-763)) NIL)) (-2057 (((-634 (-1075)) $) NIL)) (-1807 (($ (-1157 |#1|)) NIL)) (-3840 (((-1157 $) $ (-1075)) NIL) (((-1157 |#1|) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-3528 (((-763) $) NIL) (((-763) $ (-634 (-1075))) NIL)) (-1984 (($ $) NIL (|has| |#1| (-1181)))) (-1935 (($ $) NIL (|has| |#1| (-1181)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-1736 (($ $ $) NIL (|has| |#1| (-558)))) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3045 (($ $) NIL (|has| |#1| (-453)))) (-3498 (((-420 $) $) NIL (|has| |#1| (-453)))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-2589 (((-121) $ $) NIL (|has| |#1| (-365)))) (-1976 (($ $) NIL (|has| |#1| (-1181)))) (-2788 (($ $) 22 (|has| |#1| (-1181)))) (-2752 (($ $ (-763)) NIL)) (-2699 (($ $ (-763)) NIL)) (-1448 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#1| (-453)))) (-1992 (($ $) NIL (|has| |#1| (-1181)))) (-1943 (($ $) NIL (|has| |#1| (-1181)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-1075) "failed") $) NIL)) (-2857 ((|#1| $) NIL) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-1075) $) NIL)) (-2910 (($ $ $ (-1075)) NIL (|has| |#1| (-172))) ((|#1| $ $) NIL (|has| |#1| (-172)))) (-2403 (($ $ $) NIL (|has| |#1| (-365)))) (-2116 (($ $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-2414 (($ $ $) NIL (|has| |#1| (-365)))) (-3152 (($ $ $) NIL)) (-2929 (($ $ $) NIL (|has| |#1| (-558)))) (-3777 (((-2 (|:| -2350 |#1|) (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-558)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-1998 (($ $) NIL (|has| |#1| (-453))) (($ $ (-1075)) NIL (|has| |#1| (-453)))) (-2110 (((-634 $) $) NIL)) (-2197 (((-121) $) NIL (|has| |#1| (-904)))) (-2453 (($ $ |#1| (-763) $) NIL)) (-1899 (($) NIL (|has| |#1| (-1181)))) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-1075) (-881 (-381))) (|has| |#1| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-1075) (-881 (-568))) (|has| |#1| (-881 (-568)))))) (-1844 (((-763) $ $) NIL (|has| |#1| (-558)))) (-1598 (((-121) $) NIL)) (-3971 (((-763) $) NIL)) (-2214 (((-3 $ "failed") $) NIL (|has| |#1| (-1136)))) (-2053 (($ (-1157 |#1|) (-1075)) NIL) (($ (-1157 $) (-1075)) NIL)) (-4168 (($ $ (-763)) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-3062 (((-634 $) $) NIL)) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| (-763)) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-1438 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $ (-1075)) NIL) (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-3524 (((-763) $) NIL) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-1865 (($ (-1 (-763) (-763)) $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-2671 (((-1157 |#1|) $) NIL)) (-2817 (((-3 (-1075) "failed") $) NIL)) (-4418 (($ $) 18 (|has| |#1| (-1181)))) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-2498 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-1893 (((-1143) $) NIL)) (-3262 (((-2 (|:| -4409 $) (|:| -2607 $)) $ (-763)) NIL)) (-4362 (((-3 (-634 $) "failed") $) NIL)) (-2112 (((-3 (-634 $) "failed") $) NIL)) (-2617 (((-3 (-2 (|:| |var| (-1075)) (|:| -3483 (-763))) "failed") $) NIL)) (-1845 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4436 (($) NIL (|has| |#1| (-1136)) CONST)) (-4025 (((-1108) $) NIL)) (-2088 (((-121) $) 8)) (-2093 ((|#1| $) 9)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-453)))) (-2723 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#1| (-904)))) (-3850 (((-420 $) $) NIL (|has| |#1| (-904)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-365)))) (-2597 (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1894 (($ $) 20 (|has| |#1| (-1181)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-1075) |#1|) NIL) (($ $ (-634 (-1075)) (-634 |#1|)) NIL) (($ $ (-1075) $) NIL) (($ $ (-634 (-1075)) (-634 $)) NIL)) (-1466 (((-763) $) NIL (|has| |#1| (-365)))) (-2781 ((|#1| $ |#1|) NIL) (($ $ $) NIL) (((-409 $) (-409 $) (-409 $)) NIL (|has| |#1| (-558))) ((|#1| (-409 $) |#1|) NIL (|has| |#1| (-365))) (((-409 $) $ (-409 $)) NIL (|has| |#1| (-558)))) (-3805 (((-3 $ "failed") $ (-763)) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-365)))) (-3440 (($ $ (-1075)) NIL (|has| |#1| (-172))) ((|#1| $) NIL (|has| |#1| (-172)))) (-4191 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-1 |#1| |#1|) $) NIL)) (-1836 (((-763) $) NIL) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-1996 (($ $) NIL (|has| |#1| (-1181)))) (-1947 (($ $) NIL (|has| |#1| (-1181)))) (-1988 (($ $) NIL (|has| |#1| (-1181)))) (-1939 (($ $) NIL (|has| |#1| (-1181)))) (-1980 (($ $) NIL (|has| |#1| (-1181)))) (-2792 (($ $) 26 (|has| |#1| (-1181)))) (-4280 (((-887 (-381)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-1075) (-609 (-541))) (|has| |#1| (-609 (-541)))))) (-1364 ((|#1| $) NIL (|has| |#1| (-453))) (($ $ (-1075)) NIL (|has| |#1| (-453)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#1| (-904))))) (-4363 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558))) (((-3 (-409 $) "failed") (-409 $) $) NIL (|has| |#1| (-558)))) (-2747 (((-850) $) 13) (($ (-568)) NIL) (($ |#1|) 11) (($ (-1075)) NIL) (($ (-409 (-568))) NIL (-2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#1| (-558)))) (-3304 (((-634 |#1|) $) NIL)) (-2079 ((|#1| $ (-763)) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-3425 (((-763)) NIL)) (-3925 (($ $ $ (-763)) NIL (|has| |#1| (-172)))) (-2008 (($ $) NIL (|has| |#1| (-1181)))) (-1959 (($ $) NIL (|has| |#1| (-1181)))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2000 (($ $) NIL (|has| |#1| (-1181)))) (-1951 (($ $) 24 (|has| |#1| (-1181)))) (-2016 (($ $) NIL (|has| |#1| (-1181)))) (-1968 (($ $) NIL (|has| |#1| (-1181)))) (-1439 (($ $) NIL (|has| |#1| (-1181)))) (-1972 (($ $) NIL (|has| |#1| (-1181)))) (-2012 (($ $) NIL (|has| |#1| (-1181)))) (-1964 (($ $) NIL (|has| |#1| (-1181)))) (-2004 (($ $) NIL (|has| |#1| (-1181)))) (-1955 (($ $) 28 (|has| |#1| (-1181)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ $) NIL (|has| |#1| (-1181)))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
 (((-1155 |#1|) (-13 (-1219 |#1|) (-10 -7 (IF (|has| |#1| (-1181)) (-6 (-1181)) |noBranch|))) (-1047)) (T -1155)) 
 NIL 
 (-13 (-1219 |#1|) (-10 -7 (IF (|has| |#1| (-1181)) (-6 (-1181)) |noBranch|))) 
-((-1678 (((-420 (-1157 (-409 |#4|))) (-1157 (-409 |#4|))) 50)) (-3848 (((-420 (-1157 (-409 |#4|))) (-1157 (-409 |#4|))) 51))) 
-(((-1156 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3848 ((-420 (-1157 (-409 |#4|))) (-1157 (-409 |#4|)))) (-15 -1678 ((-420 (-1157 (-409 |#4|))) (-1157 (-409 |#4|))))) (-788) (-842) (-453) (-950 |#3| |#1| |#2|)) (T -1156)) 
-((-1678 (*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-453)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-420 (-1157 (-409 *7)))) (-5 *1 (-1156 *4 *5 *6 *7)) (-5 *3 (-1157 (-409 *7))))) (-3848 (*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-453)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-420 (-1157 (-409 *7)))) (-5 *1 (-1156 *4 *5 *6 *7)) (-5 *3 (-1157 (-409 *7)))))) 
-(-10 -7 (-15 -3848 ((-420 (-1157 (-409 |#4|))) (-1157 (-409 |#4|)))) (-15 -1678 ((-420 (-1157 (-409 |#4|))) (-1157 (-409 |#4|))))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 30)) (-2572 (((-1244 |#1|) $ (-763)) NIL)) (-2055 (((-634 (-1075)) $) NIL)) (-3197 (($ (-1157 |#1|)) NIL)) (-3839 (((-1157 $) $ (-1075)) 59) (((-1157 |#1|) $) 48)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) 132 (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-2773 (((-763) $) NIL) (((-763) $ (-634 (-1075))) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-3809 (($ $ $) 126 (|has| |#1| (-558)))) (-1750 (((-420 (-1157 $)) (-1157 $)) 72 (|has| |#1| (-904)))) (-4305 (($ $) NIL (|has| |#1| (-453)))) (-1678 (((-420 $) $) NIL (|has| |#1| (-453)))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 92 (|has| |#1| (-904)))) (-1497 (((-121) $ $) NIL (|has| |#1| (-365)))) (-3151 (($ $ (-763)) 42)) (-3772 (($ $ (-763)) 43)) (-1619 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#1| (-453)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#1| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-1075) "failed") $) NIL)) (-2854 ((|#1| $) NIL) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-1075) $) NIL)) (-4265 (($ $ $ (-1075)) NIL (|has| |#1| (-172))) ((|#1| $ $) 128 (|has| |#1| (-172)))) (-2401 (($ $ $) NIL (|has| |#1| (-365)))) (-2114 (($ $) 57)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-2412 (($ $ $) NIL (|has| |#1| (-365)))) (-3002 (($ $ $) 104)) (-3581 (($ $ $) NIL (|has| |#1| (-558)))) (-4144 (((-2 (|:| -2348 |#1|) (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-558)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-3250 (($ $) 133 (|has| |#1| (-453))) (($ $ (-1075)) NIL (|has| |#1| (-453)))) (-2108 (((-634 $) $) NIL)) (-3927 (((-121) $) NIL (|has| |#1| (-904)))) (-3088 (($ $ |#1| (-763) $) 46)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-1075) (-881 (-381))) (|has| |#1| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-1075) (-881 (-568))) (|has| |#1| (-881 (-568)))))) (-3680 (((-850) $ (-850)) 117)) (-4477 (((-763) $ $) NIL (|has| |#1| (-558)))) (-2735 (((-121) $) 32)) (-4178 (((-763) $) NIL)) (-3038 (((-3 $ "failed") $) NIL (|has| |#1| (-1136)))) (-2051 (($ (-1157 |#1|) (-1075)) 50) (($ (-1157 $) (-1075)) 66)) (-3536 (($ $ (-763)) 34)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-2976 (((-634 $) $) NIL)) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| (-763)) 64) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-3379 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $ (-1075)) NIL) (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 121)) (-2144 (((-763) $) NIL) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-3842 (($ (-1 (-763) (-763)) $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-3764 (((-1157 |#1|) $) NIL)) (-2244 (((-3 (-1075) "failed") $) NIL)) (-2097 (($ $) NIL)) (-2102 ((|#1| $) 53)) (-2495 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-4487 (((-1143) $) NIL)) (-1643 (((-2 (|:| -3961 $) (|:| -1500 $)) $ (-763)) 41)) (-3324 (((-3 (-634 $) "failed") $) NIL)) (-1794 (((-3 (-634 $) "failed") $) NIL)) (-3751 (((-3 (-2 (|:| |var| (-1075)) (|:| -3438 (-763))) "failed") $) NIL)) (-3837 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4434 (($) NIL (|has| |#1| (-1136)) CONST)) (-4022 (((-1108) $) NIL)) (-2086 (((-121) $) 33)) (-2091 ((|#1| $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 80 (|has| |#1| (-453)))) (-2721 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) 135 (|has| |#1| (-453)))) (-4285 (($ $ (-763) |#1| $) 99)) (-2905 (((-420 (-1157 $)) (-1157 $)) 78 (|has| |#1| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) 77 (|has| |#1| (-904)))) (-3848 (((-420 $) $) 85 (|has| |#1| (-904)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-365)))) (-2595 (((-3 $ "failed") $ |#1|) 131 (|has| |#1| (-558))) (((-3 $ "failed") $ $) 100 (|has| |#1| (-558)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-1075) |#1|) NIL) (($ $ (-634 (-1075)) (-634 |#1|)) NIL) (($ $ (-1075) $) NIL) (($ $ (-634 (-1075)) (-634 $)) NIL)) (-2709 (((-763) $) NIL (|has| |#1| (-365)))) (-2779 ((|#1| $ |#1|) 119) (($ $ $) 120) (((-409 $) (-409 $) (-409 $)) NIL (|has| |#1| (-558))) ((|#1| (-409 $) |#1|) NIL (|has| |#1| (-365))) (((-409 $) $ (-409 $)) NIL (|has| |#1| (-558)))) (-2167 (((-3 $ "failed") $ (-763)) 37)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 137 (|has| |#1| (-365)))) (-2217 (($ $ (-1075)) NIL (|has| |#1| (-172))) ((|#1| $) 124 (|has| |#1| (-172)))) (-4189 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-1 |#1| |#1|) $) NIL)) (-3206 (((-763) $) 55) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-4278 (((-887 (-381)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-1075) (-609 (-541))) (|has| |#1| (-609 (-541)))))) (-3367 ((|#1| $) 130 (|has| |#1| (-453))) (($ $ (-1075)) NIL (|has| |#1| (-453)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#1| (-904))))) (-3950 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558))) (((-3 (-409 $) "failed") (-409 $) $) NIL (|has| |#1| (-558)))) (-2745 (((-850) $) 118) (($ (-568)) NIL) (($ |#1|) 54) (($ (-1075)) NIL) (($ (-409 (-568))) NIL (-2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#1| (-558)))) (-1302 (((-634 |#1|) $) NIL)) (-2604 ((|#1| $ (-763)) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-4078 (((-763)) NIL)) (-4171 (($ $ $ (-763)) 28 (|has| |#1| (-172)))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1887 (($ $ (-917)) 15) (($ $ (-763)) 16)) (-3056 (($) 17 T CONST)) (-1556 (($) 18 T CONST)) (-3190 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) 97)) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1779 (($ $ |#1|) 138 (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) 67)) (** (($ $ (-917)) 14) (($ $ (-763)) 12)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 27) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) 102) (($ $ |#1|) NIL))) 
-(((-1157 |#1|) (-13 (-1219 |#1|) (-10 -8 (-15 -3680 ((-850) $ (-850))) (-15 -4285 ($ $ (-763) |#1| $)))) (-1047)) (T -1157)) 
-((-3680 (*1 *2 *1 *2) (-12 (-5 *2 (-850)) (-5 *1 (-1157 *3)) (-4 *3 (-1047)))) (-4285 (*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1157 *3)) (-4 *3 (-1047))))) 
-(-13 (-1219 |#1|) (-10 -8 (-15 -3680 ((-850) $ (-850))) (-15 -4285 ($ $ (-763) |#1| $)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2055 (((-634 (-1075)) $) NIL)) (-1305 (((-1161) $) 11)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-2617 (($ $ (-409 (-568))) NIL) (($ $ (-409 (-568)) (-409 (-568))) NIL)) (-2583 (((-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|))) $) NIL)) (-1982 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1933 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL (|has| |#1| (-365)))) (-1678 (((-420 $) $) NIL (|has| |#1| (-365)))) (-1902 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1497 (((-121) $ $) NIL (|has| |#1| (-365)))) (-1974 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2786 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3728 (($ (-763) (-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|)))) NIL)) (-1990 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1941 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-1151 |#1| |#2| |#3|) "failed") $) 32) (((-3 (-1159 |#1| |#2| |#3|) "failed") $) 35)) (-2854 (((-1151 |#1| |#2| |#3|) $) NIL) (((-1159 |#1| |#2| |#3|) $) NIL)) (-2401 (($ $ $) NIL (|has| |#1| (-365)))) (-2114 (($ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3533 (((-409 (-568)) $) 55)) (-2412 (($ $ $) NIL (|has| |#1| (-365)))) (-2075 (($ (-409 (-568)) (-1151 |#1| |#2| |#3|)) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-3927 (((-121) $) NIL (|has| |#1| (-365)))) (-3992 (((-121) $) NIL)) (-1897 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4477 (((-409 (-568)) $) NIL) (((-409 (-568)) $ (-409 (-568))) NIL)) (-2735 (((-121) $) NIL)) (-4044 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3536 (($ $ (-917)) NIL) (($ $ (-409 (-568))) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| (-409 (-568))) 19) (($ $ (-1075) (-409 (-568))) NIL) (($ $ (-634 (-1075)) (-634 (-409 (-568)))) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-4416 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-2495 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-3429 (((-1151 |#1| |#2| |#3|) $) 40)) (-3074 (((-3 (-1151 |#1| |#2| |#3|) "failed") $) NIL)) (-2070 (((-1151 |#1| |#2| |#3|) $) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL (|has| |#1| (-365)))) (-3837 (($ $) 38 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) NIL (-2198 (-12 (|has| |#1| (-15 -3837 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2055 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181))))) (($ $ (-1240 |#2|)) 39 (|has| |#1| (-43 (-409 (-568)))))) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-365)))) (-2721 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-3848 (((-420 $) $) NIL (|has| |#1| (-365)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-365)))) (-1807 (($ $ (-409 (-568))) NIL)) (-2595 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1892 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))))) (-2709 (((-763) $) NIL (|has| |#1| (-365)))) (-2779 ((|#1| $ (-409 (-568))) NIL) (($ $ $) NIL (|has| (-409 (-568)) (-1102)))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-365)))) (-4189 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) 36 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $ (-1240 |#2|)) 37)) (-3206 (((-409 (-568)) $) NIL)) (-1994 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1945 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1986 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1937 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1978 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2790 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1811 (($ $) NIL)) (-2745 (((-850) $) 58) (($ (-568)) NIL) (($ |#1|) NIL (|has| |#1| (-172))) (($ (-1151 |#1| |#2| |#3|)) 29) (($ (-1159 |#1| |#2| |#3|)) 30) (($ (-1240 |#2|)) 25) (($ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $) NIL (|has| |#1| (-558)))) (-2604 ((|#1| $ (-409 (-568))) NIL)) (-4371 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-4078 (((-763)) NIL)) (-1374 ((|#1| $) 12)) (-2006 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1958 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1998 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1949 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2014 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1966 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3996 ((|#1| $ (-409 (-568))) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))) (|has| |#1| (-15 -2745 (|#1| (-1161))))))) (-4023 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1970 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2010 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1962 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2002 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1953 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (-3056 (($) 21 T CONST)) (-1556 (($) 16 T CONST)) (-3190 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) 23)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
-(((-1158 |#1| |#2| |#3|) (-13 (-1226 |#1| (-1151 |#1| |#2| |#3|)) (-1037 (-1159 |#1| |#2| |#3|)) (-10 -8 (-15 -2745 ($ (-1240 |#2|))) (-15 -4189 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -3837 ($ $ (-1240 |#2|))) |noBranch|))) (-1047) (-1161) |#1|) (T -1158)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1158 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-4189 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1158 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-3837 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1158 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3)))) 
-(-13 (-1226 |#1| (-1151 |#1| |#2| |#3|)) (-1037 (-1159 |#1| |#2| |#3|)) (-10 -8 (-15 -2745 ($ (-1240 |#2|))) (-15 -4189 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -3837 ($ $ (-1240 |#2|))) |noBranch|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 124)) (-2055 (((-634 (-1075)) $) NIL)) (-1305 (((-1161) $) 115)) (-3196 (((-1216 |#2| |#1|) $ (-763)) 62)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-2617 (($ $ (-763)) 78) (($ $ (-763) (-763)) 75)) (-2583 (((-1141 (-2 (|:| |k| (-763)) (|:| |c| |#1|))) $) 101)) (-1982 (($ $) 168 (|has| |#1| (-43 (-409 (-568)))))) (-1933 (($ $) 144 (|has| |#1| (-43 (-409 (-568)))))) (-3134 (((-3 $ "failed") $ $) NIL)) (-1902 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1974 (($ $) 164 (|has| |#1| (-43 (-409 (-568)))))) (-2786 (($ $) 140 (|has| |#1| (-43 (-409 (-568)))))) (-3728 (($ (-1141 (-2 (|:| |k| (-763)) (|:| |c| |#1|)))) 114) (($ (-1141 |#1|)) 109)) (-1990 (($ $) 172 (|has| |#1| (-43 (-409 (-568)))))) (-1941 (($ $) 148 (|has| |#1| (-43 (-409 (-568)))))) (-2671 (($) NIL T CONST)) (-2114 (($ $) NIL)) (-2925 (((-3 $ "failed") $) 23)) (-3490 (($ $) 26)) (-1367 (((-953 |#1|) $ (-763)) 74) (((-953 |#1|) $ (-763) (-763)) 76)) (-3992 (((-121) $) 119)) (-1897 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4477 (((-763) $) 121) (((-763) $ (-763)) 123)) (-2735 (((-121) $) NIL)) (-4044 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3536 (($ $ (-917)) NIL)) (-1716 (($ (-1 |#1| (-568)) $) NIL)) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| (-763)) 13) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-4416 (($ $) 130 (|has| |#1| (-43 (-409 (-568)))))) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-4487 (((-1143) $) NIL)) (-3837 (($ $) 128 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) NIL (-2198 (-12 (|has| |#1| (-15 -3837 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2055 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181))))) (($ $ (-1240 |#2|)) 129 (|has| |#1| (-43 (-409 (-568)))))) (-4022 (((-1108) $) NIL)) (-1807 (($ $ (-763)) 15)) (-2595 (((-3 $ "failed") $ $) 24 (|has| |#1| (-558)))) (-1892 (($ $) 132 (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-763)))))) (-2779 ((|#1| $ (-763)) 118) (($ $ $) 127 (|has| (-763) (-1102)))) (-4189 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $) 27 (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $ (-1240 |#2|)) 29)) (-3206 (((-763) $) NIL)) (-1994 (($ $) 174 (|has| |#1| (-43 (-409 (-568)))))) (-1945 (($ $) 150 (|has| |#1| (-43 (-409 (-568)))))) (-1986 (($ $) 170 (|has| |#1| (-43 (-409 (-568)))))) (-1937 (($ $) 146 (|has| |#1| (-43 (-409 (-568)))))) (-1978 (($ $) 166 (|has| |#1| (-43 (-409 (-568)))))) (-2790 (($ $) 142 (|has| |#1| (-43 (-409 (-568)))))) (-1811 (($ $) NIL)) (-2745 (((-850) $) 200) (($ (-568)) NIL) (($ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $) NIL (|has| |#1| (-558))) (($ |#1|) 125 (|has| |#1| (-172))) (($ (-1216 |#2| |#1|)) 50) (($ (-1240 |#2|)) 32)) (-1302 (((-1141 |#1|) $) 97)) (-2604 ((|#1| $ (-763)) 117)) (-4371 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-4078 (((-763)) NIL)) (-1374 ((|#1| $) 53)) (-2006 (($ $) 180 (|has| |#1| (-43 (-409 (-568)))))) (-1958 (($ $) 156 (|has| |#1| (-43 (-409 (-568)))))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1998 (($ $) 176 (|has| |#1| (-43 (-409 (-568)))))) (-1949 (($ $) 152 (|has| |#1| (-43 (-409 (-568)))))) (-2014 (($ $) 184 (|has| |#1| (-43 (-409 (-568)))))) (-1966 (($ $) 160 (|has| |#1| (-43 (-409 (-568)))))) (-3996 ((|#1| $ (-763)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-763)))) (|has| |#1| (-15 -2745 (|#1| (-1161))))))) (-4023 (($ $) 186 (|has| |#1| (-43 (-409 (-568)))))) (-1970 (($ $) 162 (|has| |#1| (-43 (-409 (-568)))))) (-2010 (($ $) 182 (|has| |#1| (-43 (-409 (-568)))))) (-1962 (($ $) 158 (|has| |#1| (-43 (-409 (-568)))))) (-2002 (($ $) 178 (|has| |#1| (-43 (-409 (-568)))))) (-1953 (($ $) 154 (|has| |#1| (-43 (-409 (-568)))))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 17 T CONST)) (-1556 (($) 19 T CONST)) (-3190 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) 193)) (-1767 (($ $ $) 31)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ |#1|) 197 (|has| |#1| (-365))) (($ $ $) 133 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 136 (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 131) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
-(((-1159 |#1| |#2| |#3|) (-13 (-1234 |#1|) (-10 -8 (-15 -2745 ($ (-1216 |#2| |#1|))) (-15 -3196 ((-1216 |#2| |#1|) $ (-763))) (-15 -2745 ($ (-1240 |#2|))) (-15 -4189 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -3837 ($ $ (-1240 |#2|))) |noBranch|))) (-1047) (-1161) |#1|) (T -1159)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1216 *4 *3)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3) (-5 *1 (-1159 *3 *4 *5)))) (-3196 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1216 *5 *4)) (-5 *1 (-1159 *4 *5 *6)) (-4 *4 (-1047)) (-14 *5 (-1161)) (-14 *6 *4))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1159 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-4189 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1159 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-3837 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1159 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3)))) 
-(-13 (-1234 |#1|) (-10 -8 (-15 -2745 ($ (-1216 |#2| |#1|))) (-15 -3196 ((-1216 |#2| |#1|) $ (-763))) (-15 -2745 ($ (-1240 |#2|))) (-15 -4189 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -3837 ($ $ (-1240 |#2|))) |noBranch|))) 
-((-2745 (((-850) $) 22) (($ (-1161)) 24)) (-2198 (($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $))) 35)) (-2192 (($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $))) 28) (($ $) 29)) (-2571 (($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $))) 30)) (-2684 (($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $))) 32)) (-2723 (($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $))) 31)) (-2774 (($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $))) 33)) (-2993 (($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $))) 36)) (-12 (($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $))) 34))) 
-(((-1160) (-13 (-608 (-850)) (-10 -8 (-15 -2745 ($ (-1161))) (-15 -2571 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2723 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2684 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2774 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2198 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2993 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -12 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2192 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2192 ($ $))))) (T -1160)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1160)))) (-2571 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160)))) (-2723 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160)))) (-2684 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160)))) (-2774 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160)))) (-2198 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160)))) (-2993 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160)))) (-12 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160)))) (-2192 (*1 *1 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160)))) (-2192 (*1 *1 *1) (-5 *1 (-1160)))) 
-(-13 (-608 (-850)) (-10 -8 (-15 -2745 ($ (-1161))) (-15 -2571 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2723 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2684 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2774 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2198 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2993 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -12 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2192 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2192 ($ $)))) 
-((-2447 (((-121) $ $) NIL)) (-3510 (($ $ (-634 (-850))) 58)) (-1389 (($ $ (-634 (-850))) 56)) (-1742 (((-1143) $) 82)) (-3687 (((-2 (|:| -2553 (-634 (-850))) (|:| -1462 (-634 (-850))) (|:| |presup| (-634 (-850))) (|:| -3785 (-634 (-850))) (|:| |args| (-634 (-850)))) $) 85)) (-2502 (((-121) $) 21)) (-3174 (($ $ (-634 (-634 (-850)))) 54) (($ $ (-2 (|:| -2553 (-634 (-850))) (|:| -1462 (-634 (-850))) (|:| |presup| (-634 (-850))) (|:| -3785 (-634 (-850))) (|:| |args| (-634 (-850))))) 80)) (-2671 (($) 122 T CONST)) (-1636 (((-1249)) 103)) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 65) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 71)) (-1849 (($) 92) (($ $) 98)) (-3391 (($ $) 81)) (-2521 (($ $ $) NIL)) (-3268 (($ $ $) NIL)) (-3896 (((-634 $) $) 104)) (-4487 (((-1143) $) 87)) (-4022 (((-1108) $) NIL)) (-2779 (($ $ (-634 (-850))) 57)) (-4278 (((-541) $) 45) (((-1161) $) 46) (((-887 (-568)) $) 75) (((-887 (-381)) $) 73)) (-2745 (((-850) $) 52) (($ (-1143)) 47)) (-1436 (($ $ (-634 (-850))) 59)) (-3754 (((-1143) $) 33) (((-1143) $ (-121)) 34) (((-1249) (-817) $) 35) (((-1249) (-817) $ (-121)) 36)) (-1751 (((-121) $ $) NIL)) (-1738 (((-121) $ $) NIL)) (-1717 (((-121) $ $) 48)) (-1745 (((-121) $ $) NIL)) (-1732 (((-121) $ $) 49))) 
-(((-1161) (-13 (-842) (-609 (-541)) (-823) (-609 (-1161)) (-609 (-887 (-568))) (-609 (-887 (-381))) (-881 (-568)) (-881 (-381)) (-10 -8 (-15 -1849 ($)) (-15 -1849 ($ $)) (-15 -1636 ((-1249))) (-15 -2745 ($ (-1143))) (-15 -3391 ($ $)) (-15 -2502 ((-121) $)) (-15 -3687 ((-2 (|:| -2553 (-634 (-850))) (|:| -1462 (-634 (-850))) (|:| |presup| (-634 (-850))) (|:| -3785 (-634 (-850))) (|:| |args| (-634 (-850)))) $)) (-15 -3174 ($ $ (-634 (-634 (-850))))) (-15 -3174 ($ $ (-2 (|:| -2553 (-634 (-850))) (|:| -1462 (-634 (-850))) (|:| |presup| (-634 (-850))) (|:| -3785 (-634 (-850))) (|:| |args| (-634 (-850)))))) (-15 -1389 ($ $ (-634 (-850)))) (-15 -3510 ($ $ (-634 (-850)))) (-15 -1436 ($ $ (-634 (-850)))) (-15 -2779 ($ $ (-634 (-850)))) (-15 -1742 ((-1143) $)) (-15 -3896 ((-634 $) $)) (-15 -2671 ($) -3495)))) (T -1161)) 
-((-1849 (*1 *1) (-5 *1 (-1161))) (-1849 (*1 *1 *1) (-5 *1 (-1161))) (-1636 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1161)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1161)))) (-3391 (*1 *1 *1) (-5 *1 (-1161))) (-2502 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1161)))) (-3687 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| -2553 (-634 (-850))) (|:| -1462 (-634 (-850))) (|:| |presup| (-634 (-850))) (|:| -3785 (-634 (-850))) (|:| |args| (-634 (-850))))) (-5 *1 (-1161)))) (-3174 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-634 (-850)))) (-5 *1 (-1161)))) (-3174 (*1 *1 *1 *2) (-12 (-5 *2 (-2 (|:| -2553 (-634 (-850))) (|:| -1462 (-634 (-850))) (|:| |presup| (-634 (-850))) (|:| -3785 (-634 (-850))) (|:| |args| (-634 (-850))))) (-5 *1 (-1161)))) (-1389 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-1161)))) (-3510 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-1161)))) (-1436 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-1161)))) (-2779 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-1161)))) (-1742 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-1161)))) (-3896 (*1 *2 *1) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-1161)))) (-2671 (*1 *1) (-5 *1 (-1161)))) 
-(-13 (-842) (-609 (-541)) (-823) (-609 (-1161)) (-609 (-887 (-568))) (-609 (-887 (-381))) (-881 (-568)) (-881 (-381)) (-10 -8 (-15 -1849 ($)) (-15 -1849 ($ $)) (-15 -1636 ((-1249))) (-15 -2745 ($ (-1143))) (-15 -3391 ($ $)) (-15 -2502 ((-121) $)) (-15 -3687 ((-2 (|:| -2553 (-634 (-850))) (|:| -1462 (-634 (-850))) (|:| |presup| (-634 (-850))) (|:| -3785 (-634 (-850))) (|:| |args| (-634 (-850)))) $)) (-15 -3174 ($ $ (-634 (-634 (-850))))) (-15 -3174 ($ $ (-2 (|:| -2553 (-634 (-850))) (|:| -1462 (-634 (-850))) (|:| |presup| (-634 (-850))) (|:| -3785 (-634 (-850))) (|:| |args| (-634 (-850)))))) (-15 -1389 ($ $ (-634 (-850)))) (-15 -3510 ($ $ (-634 (-850)))) (-15 -1436 ($ $ (-634 (-850)))) (-15 -2779 ($ $ (-634 (-850)))) (-15 -1742 ((-1143) $)) (-15 -3896 ((-634 $) $)) (-15 -2671 ($) -3495))) 
-((-2685 (((-1244 |#1|) |#1| (-917)) 16) (((-1244 |#1|) (-634 |#1|)) 20))) 
-(((-1162 |#1|) (-10 -7 (-15 -2685 ((-1244 |#1|) (-634 |#1|))) (-15 -2685 ((-1244 |#1|) |#1| (-917)))) (-1047)) (T -1162)) 
-((-2685 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-5 *2 (-1244 *3)) (-5 *1 (-1162 *3)) (-4 *3 (-1047)))) (-2685 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1047)) (-5 *2 (-1244 *4)) (-5 *1 (-1162 *4))))) 
-(-10 -7 (-15 -2685 ((-1244 |#1|) (-634 |#1|))) (-15 -2685 ((-1244 |#1|) |#1| (-917)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) NIL)) (-2854 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) NIL)) (-2114 (($ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3250 (($ $) NIL (|has| |#1| (-453)))) (-3088 (($ $ |#1| (-972) $) NIL)) (-2735 (((-121) $) NIL)) (-4178 (((-763) $) NIL)) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| (-972)) NIL)) (-2144 (((-972) $) NIL)) (-3842 (($ (-1 (-972) (-972)) $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2086 (((-121) $) NIL)) (-2091 ((|#1| $) NIL)) (-4285 (($ $ (-972) |#1| $) NIL (-12 (|has| (-972) (-137)) (|has| |#1| (-558))))) (-2595 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558))) (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558)))) (-3206 (((-972) $) NIL)) (-3367 ((|#1| $) NIL (|has| |#1| (-453)))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL (|has| |#1| (-558))) (($ |#1|) NIL) (($ (-409 (-568))) NIL (-2198 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568))))))) (-1302 (((-634 |#1|) $) NIL)) (-2604 ((|#1| $ (-972)) NIL)) (-4371 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-4078 (((-763)) NIL)) (-4171 (($ $ $ (-763)) NIL (|has| |#1| (-172)))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 9 T CONST)) (-1556 (($) 14 T CONST)) (-1717 (((-121) $ $) 16)) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) 19)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 20) (($ $ |#1|) NIL) (($ |#1| $) 13) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
-(((-1163 |#1|) (-13 (-324 |#1| (-972)) (-10 -8 (IF (|has| |#1| (-558)) (IF (|has| (-972) (-137)) (-15 -4285 ($ $ (-972) |#1| $)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4517)) (-6 -4517) |noBranch|))) (-1047)) (T -1163)) 
-((-4285 (*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-972)) (-4 *2 (-137)) (-5 *1 (-1163 *3)) (-4 *3 (-558)) (-4 *3 (-1047))))) 
-(-13 (-324 |#1| (-972)) (-10 -8 (IF (|has| |#1| (-558)) (IF (|has| (-972) (-137)) (-15 -4285 ($ $ (-972) |#1| $)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4517)) (-6 -4517) |noBranch|))) 
-((-1506 (((-1165) (-1161) $) 24)) (-3240 (($) 28)) (-4057 (((-3 (|:| |fst| (-436)) (|:| -3611 "void")) (-1161) $) 21)) (-2069 (((-1249) (-1161) (-3 (|:| |fst| (-436)) (|:| -3611 "void")) $) 40) (((-1249) (-1161) (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) 41) (((-1249) (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) 42)) (-3783 (((-1249) (-1161)) 57)) (-4283 (((-1249) (-1161) $) 54) (((-1249) (-1161)) 55) (((-1249)) 56)) (-2579 (((-1249) (-1161)) 36)) (-3330 (((-1161)) 35)) (-3248 (($) 33)) (-3813 (((-439) (-1161) (-439) (-1161) $) 44) (((-439) (-634 (-1161)) (-439) (-1161) $) 48) (((-439) (-1161) (-439)) 45) (((-439) (-1161) (-439) (-1161)) 49)) (-2508 (((-1161)) 34)) (-2745 (((-850) $) 27)) (-4457 (((-1249)) 29) (((-1249) (-1161)) 32)) (-1660 (((-634 (-1161)) (-1161) $) 23)) (-4063 (((-1249) (-1161) (-634 (-1161)) $) 37) (((-1249) (-1161) (-634 (-1161))) 38) (((-1249) (-634 (-1161))) 39))) 
-(((-1164) (-13 (-608 (-850)) (-10 -8 (-15 -3240 ($)) (-15 -4457 ((-1249))) (-15 -4457 ((-1249) (-1161))) (-15 -3813 ((-439) (-1161) (-439) (-1161) $)) (-15 -3813 ((-439) (-634 (-1161)) (-439) (-1161) $)) (-15 -3813 ((-439) (-1161) (-439))) (-15 -3813 ((-439) (-1161) (-439) (-1161))) (-15 -2579 ((-1249) (-1161))) (-15 -2508 ((-1161))) (-15 -3330 ((-1161))) (-15 -4063 ((-1249) (-1161) (-634 (-1161)) $)) (-15 -4063 ((-1249) (-1161) (-634 (-1161)))) (-15 -4063 ((-1249) (-634 (-1161)))) (-15 -2069 ((-1249) (-1161) (-3 (|:| |fst| (-436)) (|:| -3611 "void")) $)) (-15 -2069 ((-1249) (-1161) (-3 (|:| |fst| (-436)) (|:| -3611 "void")))) (-15 -2069 ((-1249) (-3 (|:| |fst| (-436)) (|:| -3611 "void")))) (-15 -4283 ((-1249) (-1161) $)) (-15 -4283 ((-1249) (-1161))) (-15 -4283 ((-1249))) (-15 -3783 ((-1249) (-1161))) (-15 -3248 ($)) (-15 -4057 ((-3 (|:| |fst| (-436)) (|:| -3611 "void")) (-1161) $)) (-15 -1660 ((-634 (-1161)) (-1161) $)) (-15 -1506 ((-1165) (-1161) $))))) (T -1164)) 
-((-3240 (*1 *1) (-5 *1 (-1164))) (-4457 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1164)))) (-4457 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164)))) (-3813 (*1 *2 *3 *2 *3 *1) (-12 (-5 *2 (-439)) (-5 *3 (-1161)) (-5 *1 (-1164)))) (-3813 (*1 *2 *3 *2 *4 *1) (-12 (-5 *2 (-439)) (-5 *3 (-634 (-1161))) (-5 *4 (-1161)) (-5 *1 (-1164)))) (-3813 (*1 *2 *3 *2) (-12 (-5 *2 (-439)) (-5 *3 (-1161)) (-5 *1 (-1164)))) (-3813 (*1 *2 *3 *2 *3) (-12 (-5 *2 (-439)) (-5 *3 (-1161)) (-5 *1 (-1164)))) (-2579 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164)))) (-2508 (*1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1164)))) (-3330 (*1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1164)))) (-4063 (*1 *2 *3 *4 *1) (-12 (-5 *4 (-634 (-1161))) (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164)))) (-4063 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-1161))) (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164)))) (-4063 (*1 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-5 *2 (-1249)) (-5 *1 (-1164)))) (-2069 (*1 *2 *3 *4 *1) (-12 (-5 *3 (-1161)) (-5 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-5 *2 (-1249)) (-5 *1 (-1164)))) (-2069 (*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-5 *2 (-1249)) (-5 *1 (-1164)))) (-2069 (*1 *2 *3) (-12 (-5 *3 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-5 *2 (-1249)) (-5 *1 (-1164)))) (-4283 (*1 *2 *3 *1) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164)))) (-4283 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164)))) (-4283 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1164)))) (-3783 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164)))) (-3248 (*1 *1) (-5 *1 (-1164))) (-4057 (*1 *2 *3 *1) (-12 (-5 *3 (-1161)) (-5 *2 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-5 *1 (-1164)))) (-1660 (*1 *2 *3 *1) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-1164)) (-5 *3 (-1161)))) (-1506 (*1 *2 *3 *1) (-12 (-5 *3 (-1161)) (-5 *2 (-1165)) (-5 *1 (-1164))))) 
-(-13 (-608 (-850)) (-10 -8 (-15 -3240 ($)) (-15 -4457 ((-1249))) (-15 -4457 ((-1249) (-1161))) (-15 -3813 ((-439) (-1161) (-439) (-1161) $)) (-15 -3813 ((-439) (-634 (-1161)) (-439) (-1161) $)) (-15 -3813 ((-439) (-1161) (-439))) (-15 -3813 ((-439) (-1161) (-439) (-1161))) (-15 -2579 ((-1249) (-1161))) (-15 -2508 ((-1161))) (-15 -3330 ((-1161))) (-15 -4063 ((-1249) (-1161) (-634 (-1161)) $)) (-15 -4063 ((-1249) (-1161) (-634 (-1161)))) (-15 -4063 ((-1249) (-634 (-1161)))) (-15 -2069 ((-1249) (-1161) (-3 (|:| |fst| (-436)) (|:| -3611 "void")) $)) (-15 -2069 ((-1249) (-1161) (-3 (|:| |fst| (-436)) (|:| -3611 "void")))) (-15 -2069 ((-1249) (-3 (|:| |fst| (-436)) (|:| -3611 "void")))) (-15 -4283 ((-1249) (-1161) $)) (-15 -4283 ((-1249) (-1161))) (-15 -4283 ((-1249))) (-15 -3783 ((-1249) (-1161))) (-15 -3248 ($)) (-15 -4057 ((-3 (|:| |fst| (-436)) (|:| -3611 "void")) (-1161) $)) (-15 -1660 ((-634 (-1161)) (-1161) $)) (-15 -1506 ((-1165) (-1161) $)))) 
-((-1635 (((-634 (-634 (-3 (|:| -3391 (-1161)) (|:| |bounds| (-634 (-3 (|:| S (-1161)) (|:| P (-953 (-568))))))))) $) 57)) (-2478 (((-634 (-3 (|:| -3391 (-1161)) (|:| |bounds| (-634 (-3 (|:| S (-1161)) (|:| P (-953 (-568)))))))) (-436) $) 40)) (-4099 (($ (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 (-439))))) 15)) (-3783 (((-1249) $) 65)) (-2939 (((-634 (-1161)) $) 20)) (-4332 (((-1094) $) 53)) (-2540 (((-439) (-1161) $) 27)) (-4156 (((-634 (-1161)) $) 30)) (-3248 (($) 17)) (-3813 (((-439) (-634 (-1161)) (-439) $) 25) (((-439) (-1161) (-439) $) 24)) (-2745 (((-850) $) 9) (((-1169 (-1161) (-439)) $) 11))) 
-(((-1165) (-13 (-608 (-850)) (-10 -8 (-15 -2745 ((-1169 (-1161) (-439)) $)) (-15 -3248 ($)) (-15 -3813 ((-439) (-634 (-1161)) (-439) $)) (-15 -3813 ((-439) (-1161) (-439) $)) (-15 -2540 ((-439) (-1161) $)) (-15 -2939 ((-634 (-1161)) $)) (-15 -2478 ((-634 (-3 (|:| -3391 (-1161)) (|:| |bounds| (-634 (-3 (|:| S (-1161)) (|:| P (-953 (-568)))))))) (-436) $)) (-15 -4156 ((-634 (-1161)) $)) (-15 -1635 ((-634 (-634 (-3 (|:| -3391 (-1161)) (|:| |bounds| (-634 (-3 (|:| S (-1161)) (|:| P (-953 (-568))))))))) $)) (-15 -4332 ((-1094) $)) (-15 -3783 ((-1249) $)) (-15 -4099 ($ (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 (-439))))))))) (T -1165)) 
-((-2745 (*1 *2 *1) (-12 (-5 *2 (-1169 (-1161) (-439))) (-5 *1 (-1165)))) (-3248 (*1 *1) (-5 *1 (-1165))) (-3813 (*1 *2 *3 *2 *1) (-12 (-5 *2 (-439)) (-5 *3 (-634 (-1161))) (-5 *1 (-1165)))) (-3813 (*1 *2 *3 *2 *1) (-12 (-5 *2 (-439)) (-5 *3 (-1161)) (-5 *1 (-1165)))) (-2540 (*1 *2 *3 *1) (-12 (-5 *3 (-1161)) (-5 *2 (-439)) (-5 *1 (-1165)))) (-2939 (*1 *2 *1) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-1165)))) (-2478 (*1 *2 *3 *1) (-12 (-5 *3 (-436)) (-5 *2 (-634 (-3 (|:| -3391 (-1161)) (|:| |bounds| (-634 (-3 (|:| S (-1161)) (|:| P (-953 (-568))))))))) (-5 *1 (-1165)))) (-4156 (*1 *2 *1) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-1165)))) (-1635 (*1 *2 *1) (-12 (-5 *2 (-634 (-634 (-3 (|:| -3391 (-1161)) (|:| |bounds| (-634 (-3 (|:| S (-1161)) (|:| P (-953 (-568)))))))))) (-5 *1 (-1165)))) (-4332 (*1 *2 *1) (-12 (-5 *2 (-1094)) (-5 *1 (-1165)))) (-3783 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-1165)))) (-4099 (*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 (-439))))) (-5 *1 (-1165))))) 
-(-13 (-608 (-850)) (-10 -8 (-15 -2745 ((-1169 (-1161) (-439)) $)) (-15 -3248 ($)) (-15 -3813 ((-439) (-634 (-1161)) (-439) $)) (-15 -3813 ((-439) (-1161) (-439) $)) (-15 -2540 ((-439) (-1161) $)) (-15 -2939 ((-634 (-1161)) $)) (-15 -2478 ((-634 (-3 (|:| -3391 (-1161)) (|:| |bounds| (-634 (-3 (|:| S (-1161)) (|:| P (-953 (-568)))))))) (-436) $)) (-15 -4156 ((-634 (-1161)) $)) (-15 -1635 ((-634 (-634 (-3 (|:| -3391 (-1161)) (|:| |bounds| (-634 (-3 (|:| S (-1161)) (|:| P (-953 (-568))))))))) $)) (-15 -4332 ((-1094) $)) (-15 -3783 ((-1249) $)) (-15 -4099 ($ (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 (-439)))))))) 
-((-4227 (((-634 (-634 (-953 |#1|))) (-634 (-409 (-953 |#1|))) (-634 (-1161))) 55)) (-4351 (((-634 (-288 (-409 (-953 |#1|)))) (-288 (-409 (-953 |#1|)))) 66) (((-634 (-288 (-409 (-953 |#1|)))) (-409 (-953 |#1|))) 62) (((-634 (-288 (-409 (-953 |#1|)))) (-288 (-409 (-953 |#1|))) (-1161)) 67) (((-634 (-288 (-409 (-953 |#1|)))) (-409 (-953 |#1|)) (-1161)) 61) (((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-288 (-409 (-953 |#1|))))) 91) (((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-409 (-953 |#1|)))) 90) (((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-288 (-409 (-953 |#1|)))) (-634 (-1161))) 92) (((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-409 (-953 |#1|))) (-634 (-1161))) 89))) 
-(((-1166 |#1|) (-10 -7 (-15 -4351 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-409 (-953 |#1|))) (-634 (-1161)))) (-15 -4351 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-288 (-409 (-953 |#1|)))) (-634 (-1161)))) (-15 -4351 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-409 (-953 |#1|))))) (-15 -4351 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-288 (-409 (-953 |#1|)))))) (-15 -4351 ((-634 (-288 (-409 (-953 |#1|)))) (-409 (-953 |#1|)) (-1161))) (-15 -4351 ((-634 (-288 (-409 (-953 |#1|)))) (-288 (-409 (-953 |#1|))) (-1161))) (-15 -4351 ((-634 (-288 (-409 (-953 |#1|)))) (-409 (-953 |#1|)))) (-15 -4351 ((-634 (-288 (-409 (-953 |#1|)))) (-288 (-409 (-953 |#1|))))) (-15 -4227 ((-634 (-634 (-953 |#1|))) (-634 (-409 (-953 |#1|))) (-634 (-1161))))) (-558)) (T -1166)) 
-((-4227 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 *5)))) (-5 *4 (-634 (-1161))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-953 *5)))) (-5 *1 (-1166 *5)))) (-4351 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 (-288 (-409 (-953 *4))))) (-5 *1 (-1166 *4)) (-5 *3 (-288 (-409 (-953 *4)))))) (-4351 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 (-288 (-409 (-953 *4))))) (-5 *1 (-1166 *4)) (-5 *3 (-409 (-953 *4))))) (-4351 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-558)) (-5 *2 (-634 (-288 (-409 (-953 *5))))) (-5 *1 (-1166 *5)) (-5 *3 (-288 (-409 (-953 *5)))))) (-4351 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-558)) (-5 *2 (-634 (-288 (-409 (-953 *5))))) (-5 *1 (-1166 *5)) (-5 *3 (-409 (-953 *5))))) (-4351 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *4)))))) (-5 *1 (-1166 *4)) (-5 *3 (-634 (-288 (-409 (-953 *4))))))) (-4351 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 *4)))) (-4 *4 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *4)))))) (-5 *1 (-1166 *4)))) (-4351 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-1161))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *5)))))) (-5 *1 (-1166 *5)) (-5 *3 (-634 (-288 (-409 (-953 *5))))))) (-4351 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 *5)))) (-5 *4 (-634 (-1161))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *5)))))) (-5 *1 (-1166 *5))))) 
-(-10 -7 (-15 -4351 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-409 (-953 |#1|))) (-634 (-1161)))) (-15 -4351 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-288 (-409 (-953 |#1|)))) (-634 (-1161)))) (-15 -4351 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-409 (-953 |#1|))))) (-15 -4351 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-288 (-409 (-953 |#1|)))))) (-15 -4351 ((-634 (-288 (-409 (-953 |#1|)))) (-409 (-953 |#1|)) (-1161))) (-15 -4351 ((-634 (-288 (-409 (-953 |#1|)))) (-288 (-409 (-953 |#1|))) (-1161))) (-15 -4351 ((-634 (-288 (-409 (-953 |#1|)))) (-409 (-953 |#1|)))) (-15 -4351 ((-634 (-288 (-409 (-953 |#1|)))) (-288 (-409 (-953 |#1|))))) (-15 -4227 ((-634 (-634 (-953 |#1|))) (-634 (-409 (-953 |#1|))) (-634 (-1161))))) 
-((-2544 (((-634 (-634 |#1|)) (-634 (-634 |#1|)) (-634 (-634 (-634 |#1|)))) 38)) (-3952 (((-634 (-634 (-634 |#1|))) (-634 (-634 |#1|))) 24)) (-4421 (((-1168 (-634 |#1|)) (-634 |#1|)) 34)) (-2493 (((-634 (-634 |#1|)) (-634 |#1|)) 30)) (-1475 (((-2 (|:| |f1| (-634 |#1|)) (|:| |f2| (-634 (-634 (-634 |#1|)))) (|:| |f3| (-634 (-634 |#1|))) (|:| |f4| (-634 (-634 (-634 |#1|))))) (-634 (-634 (-634 |#1|)))) 37)) (-1596 (((-2 (|:| |f1| (-634 |#1|)) (|:| |f2| (-634 (-634 (-634 |#1|)))) (|:| |f3| (-634 (-634 |#1|))) (|:| |f4| (-634 (-634 (-634 |#1|))))) (-634 |#1|) (-634 (-634 (-634 |#1|))) (-634 (-634 |#1|)) (-634 (-634 (-634 |#1|))) (-634 (-634 (-634 |#1|))) (-634 (-634 (-634 |#1|)))) 36)) (-3152 (((-634 (-634 |#1|)) (-634 (-634 |#1|))) 28)) (-3140 (((-634 |#1|) (-634 |#1|)) 31)) (-4074 (((-634 (-634 (-634 |#1|))) (-634 |#1|) (-634 (-634 (-634 |#1|)))) 18)) (-2516 (((-634 (-634 (-634 |#1|))) (-1 (-121) |#1| |#1|) (-634 |#1|) (-634 (-634 (-634 |#1|)))) 15)) (-2677 (((-2 (|:| |fs| (-121)) (|:| |sd| (-634 |#1|)) (|:| |td| (-634 (-634 |#1|)))) (-1 (-121) |#1| |#1|) (-634 |#1|) (-634 (-634 |#1|))) 13)) (-1734 (((-634 (-634 |#1|)) (-634 (-634 (-634 |#1|)))) 39)) (-2174 (((-634 (-634 |#1|)) (-1168 (-634 |#1|))) 41))) 
-(((-1167 |#1|) (-10 -7 (-15 -2677 ((-2 (|:| |fs| (-121)) (|:| |sd| (-634 |#1|)) (|:| |td| (-634 (-634 |#1|)))) (-1 (-121) |#1| |#1|) (-634 |#1|) (-634 (-634 |#1|)))) (-15 -2516 ((-634 (-634 (-634 |#1|))) (-1 (-121) |#1| |#1|) (-634 |#1|) (-634 (-634 (-634 |#1|))))) (-15 -4074 ((-634 (-634 (-634 |#1|))) (-634 |#1|) (-634 (-634 (-634 |#1|))))) (-15 -2544 ((-634 (-634 |#1|)) (-634 (-634 |#1|)) (-634 (-634 (-634 |#1|))))) (-15 -1734 ((-634 (-634 |#1|)) (-634 (-634 (-634 |#1|))))) (-15 -2174 ((-634 (-634 |#1|)) (-1168 (-634 |#1|)))) (-15 -3952 ((-634 (-634 (-634 |#1|))) (-634 (-634 |#1|)))) (-15 -4421 ((-1168 (-634 |#1|)) (-634 |#1|))) (-15 -3152 ((-634 (-634 |#1|)) (-634 (-634 |#1|)))) (-15 -2493 ((-634 (-634 |#1|)) (-634 |#1|))) (-15 -3140 ((-634 |#1|) (-634 |#1|))) (-15 -1596 ((-2 (|:| |f1| (-634 |#1|)) (|:| |f2| (-634 (-634 (-634 |#1|)))) (|:| |f3| (-634 (-634 |#1|))) (|:| |f4| (-634 (-634 (-634 |#1|))))) (-634 |#1|) (-634 (-634 (-634 |#1|))) (-634 (-634 |#1|)) (-634 (-634 (-634 |#1|))) (-634 (-634 (-634 |#1|))) (-634 (-634 (-634 |#1|))))) (-15 -1475 ((-2 (|:| |f1| (-634 |#1|)) (|:| |f2| (-634 (-634 (-634 |#1|)))) (|:| |f3| (-634 (-634 |#1|))) (|:| |f4| (-634 (-634 (-634 |#1|))))) (-634 (-634 (-634 |#1|)))))) (-842)) (T -1167)) 
-((-1475 (*1 *2 *3) (-12 (-4 *4 (-842)) (-5 *2 (-2 (|:| |f1| (-634 *4)) (|:| |f2| (-634 (-634 (-634 *4)))) (|:| |f3| (-634 (-634 *4))) (|:| |f4| (-634 (-634 (-634 *4)))))) (-5 *1 (-1167 *4)) (-5 *3 (-634 (-634 (-634 *4)))))) (-1596 (*1 *2 *3 *4 *5 *4 *4 *4) (-12 (-4 *6 (-842)) (-5 *3 (-634 *6)) (-5 *5 (-634 *3)) (-5 *2 (-2 (|:| |f1| *3) (|:| |f2| (-634 *5)) (|:| |f3| *5) (|:| |f4| (-634 *5)))) (-5 *1 (-1167 *6)) (-5 *4 (-634 *5)))) (-3140 (*1 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-1167 *3)))) (-2493 (*1 *2 *3) (-12 (-4 *4 (-842)) (-5 *2 (-634 (-634 *4))) (-5 *1 (-1167 *4)) (-5 *3 (-634 *4)))) (-3152 (*1 *2 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-842)) (-5 *1 (-1167 *3)))) (-4421 (*1 *2 *3) (-12 (-4 *4 (-842)) (-5 *2 (-1168 (-634 *4))) (-5 *1 (-1167 *4)) (-5 *3 (-634 *4)))) (-3952 (*1 *2 *3) (-12 (-4 *4 (-842)) (-5 *2 (-634 (-634 (-634 *4)))) (-5 *1 (-1167 *4)) (-5 *3 (-634 (-634 *4))))) (-2174 (*1 *2 *3) (-12 (-5 *3 (-1168 (-634 *4))) (-4 *4 (-842)) (-5 *2 (-634 (-634 *4))) (-5 *1 (-1167 *4)))) (-1734 (*1 *2 *3) (-12 (-5 *3 (-634 (-634 (-634 *4)))) (-5 *2 (-634 (-634 *4))) (-5 *1 (-1167 *4)) (-4 *4 (-842)))) (-2544 (*1 *2 *2 *3) (-12 (-5 *3 (-634 (-634 (-634 *4)))) (-5 *2 (-634 (-634 *4))) (-4 *4 (-842)) (-5 *1 (-1167 *4)))) (-4074 (*1 *2 *3 *2) (-12 (-5 *2 (-634 (-634 (-634 *4)))) (-5 *3 (-634 *4)) (-4 *4 (-842)) (-5 *1 (-1167 *4)))) (-2516 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-634 (-634 (-634 *5)))) (-5 *3 (-1 (-121) *5 *5)) (-5 *4 (-634 *5)) (-4 *5 (-842)) (-5 *1 (-1167 *5)))) (-2677 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-121) *6 *6)) (-4 *6 (-842)) (-5 *4 (-634 *6)) (-5 *2 (-2 (|:| |fs| (-121)) (|:| |sd| *4) (|:| |td| (-634 *4)))) (-5 *1 (-1167 *6)) (-5 *5 (-634 *4))))) 
-(-10 -7 (-15 -2677 ((-2 (|:| |fs| (-121)) (|:| |sd| (-634 |#1|)) (|:| |td| (-634 (-634 |#1|)))) (-1 (-121) |#1| |#1|) (-634 |#1|) (-634 (-634 |#1|)))) (-15 -2516 ((-634 (-634 (-634 |#1|))) (-1 (-121) |#1| |#1|) (-634 |#1|) (-634 (-634 (-634 |#1|))))) (-15 -4074 ((-634 (-634 (-634 |#1|))) (-634 |#1|) (-634 (-634 (-634 |#1|))))) (-15 -2544 ((-634 (-634 |#1|)) (-634 (-634 |#1|)) (-634 (-634 (-634 |#1|))))) (-15 -1734 ((-634 (-634 |#1|)) (-634 (-634 (-634 |#1|))))) (-15 -2174 ((-634 (-634 |#1|)) (-1168 (-634 |#1|)))) (-15 -3952 ((-634 (-634 (-634 |#1|))) (-634 (-634 |#1|)))) (-15 -4421 ((-1168 (-634 |#1|)) (-634 |#1|))) (-15 -3152 ((-634 (-634 |#1|)) (-634 (-634 |#1|)))) (-15 -2493 ((-634 (-634 |#1|)) (-634 |#1|))) (-15 -3140 ((-634 |#1|) (-634 |#1|))) (-15 -1596 ((-2 (|:| |f1| (-634 |#1|)) (|:| |f2| (-634 (-634 (-634 |#1|)))) (|:| |f3| (-634 (-634 |#1|))) (|:| |f4| (-634 (-634 (-634 |#1|))))) (-634 |#1|) (-634 (-634 (-634 |#1|))) (-634 (-634 |#1|)) (-634 (-634 (-634 |#1|))) (-634 (-634 (-634 |#1|))) (-634 (-634 (-634 |#1|))))) (-15 -1475 ((-2 (|:| |f1| (-634 |#1|)) (|:| |f2| (-634 (-634 (-634 |#1|)))) (|:| |f3| (-634 (-634 |#1|))) (|:| |f4| (-634 (-634 (-634 |#1|))))) (-634 (-634 (-634 |#1|)))))) 
-((-2472 (($ (-634 (-634 |#1|))) 9)) (-3208 (((-634 (-634 |#1|)) $) 10)) (-2745 (((-850) $) 25))) 
-(((-1168 |#1|) (-10 -8 (-15 -2472 ($ (-634 (-634 |#1|)))) (-15 -3208 ((-634 (-634 |#1|)) $)) (-15 -2745 ((-850) $))) (-1090)) (T -1168)) 
-((-2745 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1168 *3)) (-4 *3 (-1090)))) (-3208 (*1 *2 *1) (-12 (-5 *2 (-634 (-634 *3))) (-5 *1 (-1168 *3)) (-4 *3 (-1090)))) (-2472 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-1090)) (-5 *1 (-1168 *3))))) 
-(-10 -8 (-15 -2472 ($ (-634 (-634 |#1|)))) (-15 -3208 ((-634 (-634 |#1|)) $)) (-15 -2745 ((-850) $))) 
-((-2447 (((-121) $ $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-2986 (($) NIL) (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-1868 (((-1249) $ |#1| |#1|) NIL (|has| $ (-6 -4520)))) (-2510 (((-121) $ (-763)) NIL)) (-2436 ((|#2| $ |#1| |#2|) NIL)) (-3507 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-2674 (((-3 |#2| "failed") |#1| $) NIL)) (-2671 (($) NIL T CONST)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-3405 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (|has| $ (-6 -4519))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-3 |#2| "failed") |#1| $) NIL)) (-4328 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-3092 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (|has| $ (-6 -4519))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519)))) (-3989 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#2| $ |#1|) NIL)) (-4360 (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-634 |#2|) $) NIL (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) NIL)) (-1881 ((|#1| $) NIL (|has| |#1| (-842)))) (-1979 (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-634 |#2|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-2223 ((|#1| $) NIL (|has| |#1| (-842)))) (-3674 (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4520))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-1946 (((-634 |#1|) $) NIL)) (-3548 (((-121) |#1| $) NIL)) (-1890 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-4450 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-4174 (((-634 |#1|) $) NIL)) (-3578 (((-121) |#1| $) NIL)) (-4022 (((-1108) $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-3876 ((|#2| $) NIL (|has| |#1| (-842)))) (-3775 (((-3 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) "failed") (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL)) (-3724 (($ $ |#2|) NIL (|has| $ (-6 -4520)))) (-1315 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL)) (-1387 (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-2041 (((-634 |#2|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL)) (-2085 (($) NIL) (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-4168 (((-763) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-763) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) NIL (-12 (|has| $ (-6 -4519)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090)))) (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-609 (-541))))) (-4287 (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-2745 (((-850) $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-2367 (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) NIL)) (-1319 (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) NIL (|has| $ (-6 -4519))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) NIL (-2198 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-1169 |#1| |#2|) (-13 (-1172 |#1| |#2|) (-10 -7 (-6 -4519))) (-1090) (-1090)) (T -1169)) 
-NIL 
-(-13 (-1172 |#1| |#2|) (-10 -7 (-6 -4519))) 
-((-2056 ((|#1| (-634 |#1|)) 32)) (-3576 ((|#1| |#1| (-568)) 18)) (-3411 (((-1157 |#1|) |#1| (-917)) 15))) 
-(((-1170 |#1|) (-10 -7 (-15 -2056 (|#1| (-634 |#1|))) (-15 -3411 ((-1157 |#1|) |#1| (-917))) (-15 -3576 (|#1| |#1| (-568)))) (-365)) (T -1170)) 
-((-3576 (*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-1170 *2)) (-4 *2 (-365)))) (-3411 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-5 *2 (-1157 *3)) (-5 *1 (-1170 *3)) (-4 *3 (-365)))) (-2056 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-5 *1 (-1170 *2)) (-4 *2 (-365))))) 
-(-10 -7 (-15 -2056 (|#1| (-634 |#1|))) (-15 -3411 ((-1157 |#1|) |#1| (-917))) (-15 -3576 (|#1| |#1| (-568)))) 
-((-2986 (($) 10) (($ (-634 (-2 (|:| -3649 |#2|) (|:| -4083 |#3|)))) 14)) (-3405 (($ (-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) $) 60) (($ (-1 (-121) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) $) NIL) (((-3 |#3| "failed") |#2| $) NIL)) (-4360 (((-634 (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) $) 39) (((-634 |#3|) $) 41)) (-3674 (($ (-1 (-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) $) 52) (($ (-1 |#3| |#3|) $) 33)) (-2795 (($ (-1 (-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) $) 50) (($ (-1 |#3| |#3|) $) NIL) (($ (-1 |#3| |#3| |#3|) $ $) 38)) (-1890 (((-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) $) 53)) (-4450 (($ (-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) $) 16)) (-4174 (((-634 |#2|) $) 19)) (-3578 (((-121) |#2| $) 58)) (-3775 (((-3 (-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) "failed") (-1 (-121) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) $) 57)) (-1315 (((-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) $) 62)) (-1387 (((-121) (-1 (-121) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) $) NIL) (((-121) (-1 (-121) |#3|) $) 65)) (-2041 (((-634 |#3|) $) 43)) (-2779 ((|#3| $ |#2|) 30) ((|#3| $ |#2| |#3|) 31)) (-4168 (((-763) (-1 (-121) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) $) NIL) (((-763) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) $) NIL) (((-763) |#3| $) NIL) (((-763) (-1 (-121) |#3|) $) 66)) (-2745 (((-850) $) 27)) (-1319 (((-121) (-1 (-121) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) $) NIL) (((-121) (-1 (-121) |#3|) $) 64)) (-1717 (((-121) $ $) 48))) 
-(((-1171 |#1| |#2| |#3|) (-10 -8 (-15 -1717 ((-121) |#1| |#1|)) (-15 -2745 ((-850) |#1|)) (-15 -2795 (|#1| (-1 |#3| |#3| |#3|) |#1| |#1|)) (-15 -2986 (|#1| (-634 (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))))) (-15 -2986 (|#1|)) (-15 -2795 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -3674 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -1319 ((-121) (-1 (-121) |#3|) |#1|)) (-15 -1387 ((-121) (-1 (-121) |#3|) |#1|)) (-15 -4168 ((-763) (-1 (-121) |#3|) |#1|)) (-15 -4360 ((-634 |#3|) |#1|)) (-15 -4168 ((-763) |#3| |#1|)) (-15 -2779 (|#3| |#1| |#2| |#3|)) (-15 -2779 (|#3| |#1| |#2|)) (-15 -2041 ((-634 |#3|) |#1|)) (-15 -3578 ((-121) |#2| |#1|)) (-15 -4174 ((-634 |#2|) |#1|)) (-15 -3405 ((-3 |#3| "failed") |#2| |#1|)) (-15 -3405 (|#1| (-1 (-121) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) |#1|)) (-15 -3405 (|#1| (-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) |#1|)) (-15 -3775 ((-3 (-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) "failed") (-1 (-121) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) |#1|)) (-15 -1890 ((-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) |#1|)) (-15 -4450 (|#1| (-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) |#1|)) (-15 -1315 ((-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) |#1|)) (-15 -4168 ((-763) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) |#1|)) (-15 -4360 ((-634 (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) |#1|)) (-15 -4168 ((-763) (-1 (-121) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) |#1|)) (-15 -1387 ((-121) (-1 (-121) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) |#1|)) (-15 -1319 ((-121) (-1 (-121) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) |#1|)) (-15 -3674 (|#1| (-1 (-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) |#1|)) (-15 -2795 (|#1| (-1 (-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) |#1|))) (-1172 |#2| |#3|) (-1090) (-1090)) (T -1171)) 
-NIL 
-(-10 -8 (-15 -1717 ((-121) |#1| |#1|)) (-15 -2745 ((-850) |#1|)) (-15 -2795 (|#1| (-1 |#3| |#3| |#3|) |#1| |#1|)) (-15 -2986 (|#1| (-634 (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))))) (-15 -2986 (|#1|)) (-15 -2795 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -3674 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -1319 ((-121) (-1 (-121) |#3|) |#1|)) (-15 -1387 ((-121) (-1 (-121) |#3|) |#1|)) (-15 -4168 ((-763) (-1 (-121) |#3|) |#1|)) (-15 -4360 ((-634 |#3|) |#1|)) (-15 -4168 ((-763) |#3| |#1|)) (-15 -2779 (|#3| |#1| |#2| |#3|)) (-15 -2779 (|#3| |#1| |#2|)) (-15 -2041 ((-634 |#3|) |#1|)) (-15 -3578 ((-121) |#2| |#1|)) (-15 -4174 ((-634 |#2|) |#1|)) (-15 -3405 ((-3 |#3| "failed") |#2| |#1|)) (-15 -3405 (|#1| (-1 (-121) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) |#1|)) (-15 -3405 (|#1| (-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) |#1|)) (-15 -3775 ((-3 (-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) "failed") (-1 (-121) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) |#1|)) (-15 -1890 ((-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) |#1|)) (-15 -4450 (|#1| (-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) |#1|)) (-15 -1315 ((-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) |#1|)) (-15 -4168 ((-763) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) |#1|)) (-15 -4360 ((-634 (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) |#1|)) (-15 -4168 ((-763) (-1 (-121) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) |#1|)) (-15 -1387 ((-121) (-1 (-121) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) |#1|)) (-15 -1319 ((-121) (-1 (-121) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) |#1|)) (-15 -3674 (|#1| (-1 (-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) |#1|)) (-15 -2795 (|#1| (-1 (-2 (|:| -3649 |#2|) (|:| -4083 |#3|)) (-2 (|:| -3649 |#2|) (|:| -4083 |#3|))) |#1|))) 
-((-2447 (((-121) $ $) 18 (-2198 (|has| |#2| (-1090)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-2986 (($) 66) (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) 65)) (-1868 (((-1249) $ |#1| |#1|) 93 (|has| $ (-6 -4520)))) (-2510 (((-121) $ (-763)) 8)) (-2436 ((|#2| $ |#1| |#2|) 67)) (-3507 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 42 (|has| $ (-6 -4519)))) (-2801 (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 52 (|has| $ (-6 -4519)))) (-2674 (((-3 |#2| "failed") |#1| $) 57)) (-2671 (($) 7 T CONST)) (-3924 (($ $) 55 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| $ (-6 -4519))))) (-3405 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 44 (|has| $ (-6 -4519))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 43 (|has| $ (-6 -4519))) (((-3 |#2| "failed") |#1| $) 58)) (-4328 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 54 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 51 (|has| $ (-6 -4519)))) (-3092 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 53 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| $ (-6 -4519)))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 50 (|has| $ (-6 -4519))) (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 49 (|has| $ (-6 -4519)))) (-3989 ((|#2| $ |#1| |#2|) 81 (|has| $ (-6 -4520)))) (-2602 ((|#2| $ |#1|) 82)) (-4360 (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 30 (|has| $ (-6 -4519))) (((-634 |#2|) $) 73 (|has| $ (-6 -4519)))) (-1737 (((-121) $ (-763)) 9)) (-1881 ((|#1| $) 90 (|has| |#1| (-842)))) (-1979 (((-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 29 (|has| $ (-6 -4519))) (((-634 |#2|) $) 74 (|has| $ (-6 -4519)))) (-3109 (((-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 27 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| $ (-6 -4519)))) (((-121) |#2| $) 76 (-12 (|has| |#2| (-1090)) (|has| $ (-6 -4519))))) (-2223 ((|#1| $) 89 (|has| |#1| (-842)))) (-3674 (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 34 (|has| $ (-6 -4520))) (($ (-1 |#2| |#2|) $) 69 (|has| $ (-6 -4520)))) (-2795 (($ (-1 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 35) (($ (-1 |#2| |#2|) $) 68) (($ (-1 |#2| |#2| |#2|) $ $) 64)) (-2166 (((-121) $ (-763)) 10)) (-4487 (((-1143) $) 22 (-2198 (|has| |#2| (-1090)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-1946 (((-634 |#1|) $) 59)) (-3548 (((-121) |#1| $) 60)) (-1890 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 36)) (-4450 (($ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 37)) (-4174 (((-634 |#1|) $) 87)) (-3578 (((-121) |#1| $) 86)) (-4022 (((-1108) $) 21 (-2198 (|has| |#2| (-1090)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-3876 ((|#2| $) 91 (|has| |#1| (-842)))) (-3775 (((-3 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) "failed") (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 48)) (-3724 (($ $ |#2|) 92 (|has| $ (-6 -4520)))) (-1315 (((-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 38)) (-1387 (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 32 (|has| $ (-6 -4519))) (((-121) (-1 (-121) |#2|) $) 71 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))))) 26 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) 25 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) 24 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) 23 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) 80 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) 79 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) 78 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 (-288 |#2|))) 77 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-3171 (((-121) $ $) 14)) (-4467 (((-121) |#2| $) 88 (-12 (|has| $ (-6 -4519)) (|has| |#2| (-1090))))) (-2041 (((-634 |#2|) $) 85)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 ((|#2| $ |#1|) 84) ((|#2| $ |#1| |#2|) 83)) (-2085 (($) 46) (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) 45)) (-4168 (((-763) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 31 (|has| $ (-6 -4519))) (((-763) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) $) 28 (-12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090)) (|has| $ (-6 -4519)))) (((-763) |#2| $) 75 (-12 (|has| |#2| (-1090)) (|has| $ (-6 -4519)))) (((-763) (-1 (-121) |#2|) $) 72 (|has| $ (-6 -4519)))) (-3863 (($ $) 13)) (-4278 (((-541) $) 56 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-609 (-541))))) (-4287 (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) 47)) (-2745 (((-850) $) 20 (-2198 (|has| |#2| (-1090)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-2367 (($ (-634 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) 39)) (-1319 (((-121) (-1 (-121) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) $) 33 (|has| $ (-6 -4519))) (((-121) (-1 (-121) |#2|) $) 70 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (-2198 (|has| |#2| (-1090)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-3498 (((-420 (-1157 (-409 |#4|))) (-1157 (-409 |#4|))) 50)) (-3850 (((-420 (-1157 (-409 |#4|))) (-1157 (-409 |#4|))) 51))) 
+(((-1156 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3850 ((-420 (-1157 (-409 |#4|))) (-1157 (-409 |#4|)))) (-15 -3498 ((-420 (-1157 (-409 |#4|))) (-1157 (-409 |#4|))))) (-788) (-842) (-453) (-950 |#3| |#1| |#2|)) (T -1156)) 
+((-3498 (*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-453)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-420 (-1157 (-409 *7)))) (-5 *1 (-1156 *4 *5 *6 *7)) (-5 *3 (-1157 (-409 *7))))) (-3850 (*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-453)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-420 (-1157 (-409 *7)))) (-5 *1 (-1156 *4 *5 *6 *7)) (-5 *3 (-1157 (-409 *7)))))) 
+(-10 -7 (-15 -3850 ((-420 (-1157 (-409 |#4|))) (-1157 (-409 |#4|)))) (-15 -3498 ((-420 (-1157 (-409 |#4|))) (-1157 (-409 |#4|))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 30)) (-1969 (((-1244 |#1|) $ (-763)) NIL)) (-2057 (((-634 (-1075)) $) NIL)) (-1807 (($ (-1157 |#1|)) NIL)) (-3840 (((-1157 $) $ (-1075)) 59) (((-1157 |#1|) $) 48)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) 132 (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-3528 (((-763) $) NIL) (((-763) $ (-634 (-1075))) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-1736 (($ $ $) 126 (|has| |#1| (-558)))) (-3863 (((-420 (-1157 $)) (-1157 $)) 72 (|has| |#1| (-904)))) (-3045 (($ $) NIL (|has| |#1| (-453)))) (-3498 (((-420 $) $) NIL (|has| |#1| (-453)))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 92 (|has| |#1| (-904)))) (-2589 (((-121) $ $) NIL (|has| |#1| (-365)))) (-2752 (($ $ (-763)) 42)) (-2699 (($ $ (-763)) 43)) (-1448 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#1| (-453)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#1| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-1075) "failed") $) NIL)) (-2857 ((|#1| $) NIL) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-1075) $) NIL)) (-2910 (($ $ $ (-1075)) NIL (|has| |#1| (-172))) ((|#1| $ $) 128 (|has| |#1| (-172)))) (-2403 (($ $ $) NIL (|has| |#1| (-365)))) (-2116 (($ $) 57)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) NIL) (((-679 |#1|) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-2414 (($ $ $) NIL (|has| |#1| (-365)))) (-3152 (($ $ $) 104)) (-2929 (($ $ $) NIL (|has| |#1| (-558)))) (-3777 (((-2 (|:| -2350 |#1|) (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-558)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-1998 (($ $) 133 (|has| |#1| (-453))) (($ $ (-1075)) NIL (|has| |#1| (-453)))) (-2110 (((-634 $) $) NIL)) (-2197 (((-121) $) NIL (|has| |#1| (-904)))) (-2453 (($ $ |#1| (-763) $) 46)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-1075) (-881 (-381))) (|has| |#1| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-1075) (-881 (-568))) (|has| |#1| (-881 (-568)))))) (-2276 (((-850) $ (-850)) 117)) (-1844 (((-763) $ $) NIL (|has| |#1| (-558)))) (-1598 (((-121) $) 32)) (-3971 (((-763) $) NIL)) (-2214 (((-3 $ "failed") $) NIL (|has| |#1| (-1136)))) (-2053 (($ (-1157 |#1|) (-1075)) 50) (($ (-1157 $) (-1075)) 66)) (-4168 (($ $ (-763)) 34)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-3062 (((-634 $) $) NIL)) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| (-763)) 64) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-1438 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $ (-1075)) NIL) (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 121)) (-3524 (((-763) $) NIL) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-1865 (($ (-1 (-763) (-763)) $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-2671 (((-1157 |#1|) $) NIL)) (-2817 (((-3 (-1075) "failed") $) NIL)) (-2099 (($ $) NIL)) (-2104 ((|#1| $) 53)) (-2498 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) NIL (|has| |#1| (-453)))) (-1893 (((-1143) $) NIL)) (-3262 (((-2 (|:| -4409 $) (|:| -2607 $)) $ (-763)) 41)) (-4362 (((-3 (-634 $) "failed") $) NIL)) (-2112 (((-3 (-634 $) "failed") $) NIL)) (-2617 (((-3 (-2 (|:| |var| (-1075)) (|:| -3483 (-763))) "failed") $) NIL)) (-1845 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4436 (($) NIL (|has| |#1| (-1136)) CONST)) (-4025 (((-1108) $) NIL)) (-2088 (((-121) $) 33)) (-2093 ((|#1| $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 80 (|has| |#1| (-453)))) (-2723 (($ (-634 $)) NIL (|has| |#1| (-453))) (($ $ $) 135 (|has| |#1| (-453)))) (-2973 (($ $ (-763) |#1| $) 99)) (-2841 (((-420 (-1157 $)) (-1157 $)) 78 (|has| |#1| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) 77 (|has| |#1| (-904)))) (-3850 (((-420 $) $) 85 (|has| |#1| (-904)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-365)))) (-2597 (((-3 $ "failed") $ |#1|) 131 (|has| |#1| (-558))) (((-3 $ "failed") $ $) 100 (|has| |#1| (-558)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-1075) |#1|) NIL) (($ $ (-634 (-1075)) (-634 |#1|)) NIL) (($ $ (-1075) $) NIL) (($ $ (-634 (-1075)) (-634 $)) NIL)) (-1466 (((-763) $) NIL (|has| |#1| (-365)))) (-2781 ((|#1| $ |#1|) 119) (($ $ $) 120) (((-409 $) (-409 $) (-409 $)) NIL (|has| |#1| (-558))) ((|#1| (-409 $) |#1|) NIL (|has| |#1| (-365))) (((-409 $) $ (-409 $)) NIL (|has| |#1| (-558)))) (-3805 (((-3 $ "failed") $ (-763)) 37)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 137 (|has| |#1| (-365)))) (-3440 (($ $ (-1075)) NIL (|has| |#1| (-172))) ((|#1| $) 124 (|has| |#1| (-172)))) (-4191 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL) (($ $ (-1 |#1| |#1|) $) NIL)) (-1836 (((-763) $) 55) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-4280 (((-887 (-381)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-1075) (-609 (-541))) (|has| |#1| (-609 (-541)))))) (-1364 ((|#1| $) 130 (|has| |#1| (-453))) (($ $ (-1075)) NIL (|has| |#1| (-453)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#1| (-904))))) (-4363 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558))) (((-3 (-409 $) "failed") (-409 $) $) NIL (|has| |#1| (-558)))) (-2747 (((-850) $) 118) (($ (-568)) NIL) (($ |#1|) 54) (($ (-1075)) NIL) (($ (-409 (-568))) NIL (-2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#1| (-558)))) (-3304 (((-634 |#1|) $) NIL)) (-2079 ((|#1| $ (-763)) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-3425 (((-763)) NIL)) (-3925 (($ $ $ (-763)) 28 (|has| |#1| (-172)))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1889 (($ $ (-917)) 15) (($ $ (-763)) 16)) (-3058 (($) 17 T CONST)) (-1557 (($) 18 T CONST)) (-3192 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) NIL) (($ $ (-1 |#1| |#1|)) NIL)) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) 97)) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1781 (($ $ |#1|) 138 (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) 67)) (** (($ $ (-917)) 14) (($ $ (-763)) 12)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 27) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) 102) (($ $ |#1|) NIL))) 
+(((-1157 |#1|) (-13 (-1219 |#1|) (-10 -8 (-15 -2276 ((-850) $ (-850))) (-15 -2973 ($ $ (-763) |#1| $)))) (-1047)) (T -1157)) 
+((-2276 (*1 *2 *1 *2) (-12 (-5 *2 (-850)) (-5 *1 (-1157 *3)) (-4 *3 (-1047)))) (-2973 (*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1157 *3)) (-4 *3 (-1047))))) 
+(-13 (-1219 |#1|) (-10 -8 (-15 -2276 ((-850) $ (-850))) (-15 -2973 ($ $ (-763) |#1| $)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2057 (((-634 (-1075)) $) NIL)) (-3325 (((-1161) $) 11)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-4179 (($ $ (-409 (-568))) NIL) (($ $ (-409 (-568)) (-409 (-568))) NIL)) (-2013 (((-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|))) $) NIL)) (-1984 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1935 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL (|has| |#1| (-365)))) (-3498 (((-420 $) $) NIL (|has| |#1| (-365)))) (-1904 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2589 (((-121) $ $) NIL (|has| |#1| (-365)))) (-1976 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2788 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2512 (($ (-763) (-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|)))) NIL)) (-1992 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1943 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-1151 |#1| |#2| |#3|) "failed") $) 32) (((-3 (-1159 |#1| |#2| |#3|) "failed") $) 35)) (-2857 (((-1151 |#1| |#2| |#3|) $) NIL) (((-1159 |#1| |#2| |#3|) $) NIL)) (-2403 (($ $ $) NIL (|has| |#1| (-365)))) (-2116 (($ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-4147 (((-409 (-568)) $) 55)) (-2414 (($ $ $) NIL (|has| |#1| (-365)))) (-2077 (($ (-409 (-568)) (-1151 |#1| |#2| |#3|)) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-2197 (((-121) $) NIL (|has| |#1| (-365)))) (-1302 (((-121) $) NIL)) (-1899 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1844 (((-409 (-568)) $) NIL) (((-409 (-568)) $ (-409 (-568))) NIL)) (-1598 (((-121) $) NIL)) (-1550 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4168 (($ $ (-917)) NIL) (($ $ (-409 (-568))) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| (-409 (-568))) 19) (($ $ (-1075) (-409 (-568))) NIL) (($ $ (-634 (-1075)) (-634 (-409 (-568)))) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-4418 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-2498 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-3408 (((-1151 |#1| |#2| |#3|) $) 40)) (-2380 (((-3 (-1151 |#1| |#2| |#3|) "failed") $) NIL)) (-2072 (((-1151 |#1| |#2| |#3|) $) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL (|has| |#1| (-365)))) (-1845 (($ $) 38 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) NIL (-2199 (-12 (|has| |#1| (-15 -1845 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2057 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181))))) (($ $ (-1240 |#2|)) 39 (|has| |#1| (-43 (-409 (-568)))))) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-365)))) (-2723 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-3850 (((-420 $) $) NIL (|has| |#1| (-365)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-365)))) (-2168 (($ $ (-409 (-568))) NIL)) (-2597 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1894 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))))) (-1466 (((-763) $) NIL (|has| |#1| (-365)))) (-2781 ((|#1| $ (-409 (-568))) NIL) (($ $ $) NIL (|has| (-409 (-568)) (-1102)))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-365)))) (-4191 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) 36 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $ (-1240 |#2|)) 37)) (-1836 (((-409 (-568)) $) NIL)) (-1996 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1947 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1988 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1939 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1980 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2792 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2188 (($ $) NIL)) (-2747 (((-850) $) 58) (($ (-568)) NIL) (($ |#1|) NIL (|has| |#1| (-172))) (($ (-1151 |#1| |#2| |#3|)) 29) (($ (-1159 |#1| |#2| |#3|)) 30) (($ (-1240 |#2|)) 25) (($ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $) NIL (|has| |#1| (-558)))) (-2079 ((|#1| $ (-409 (-568))) NIL)) (-3385 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-3425 (((-763)) NIL)) (-1374 ((|#1| $) 12)) (-2008 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1959 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2000 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1951 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2016 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1968 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3999 ((|#1| $ (-409 (-568))) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))) (|has| |#1| (-15 -2747 (|#1| (-1161))))))) (-1439 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1972 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2012 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1964 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2004 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1955 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (-3058 (($) 21 T CONST)) (-1557 (($) 16 T CONST)) (-3192 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) 23)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
+(((-1158 |#1| |#2| |#3|) (-13 (-1226 |#1| (-1151 |#1| |#2| |#3|)) (-1037 (-1159 |#1| |#2| |#3|)) (-10 -8 (-15 -2747 ($ (-1240 |#2|))) (-15 -4191 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -1845 ($ $ (-1240 |#2|))) |noBranch|))) (-1047) (-1161) |#1|) (T -1158)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1158 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-4191 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1158 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-1845 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1158 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3)))) 
+(-13 (-1226 |#1| (-1151 |#1| |#2| |#3|)) (-1037 (-1159 |#1| |#2| |#3|)) (-10 -8 (-15 -2747 ($ (-1240 |#2|))) (-15 -4191 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -1845 ($ $ (-1240 |#2|))) |noBranch|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 124)) (-2057 (((-634 (-1075)) $) NIL)) (-3325 (((-1161) $) 115)) (-1802 (((-1216 |#2| |#1|) $ (-763)) 62)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-4179 (($ $ (-763)) 78) (($ $ (-763) (-763)) 75)) (-2013 (((-1141 (-2 (|:| |k| (-763)) (|:| |c| |#1|))) $) 101)) (-1984 (($ $) 168 (|has| |#1| (-43 (-409 (-568)))))) (-1935 (($ $) 144 (|has| |#1| (-43 (-409 (-568)))))) (-2689 (((-3 $ "failed") $ $) NIL)) (-1904 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1976 (($ $) 164 (|has| |#1| (-43 (-409 (-568)))))) (-2788 (($ $) 140 (|has| |#1| (-43 (-409 (-568)))))) (-2512 (($ (-1141 (-2 (|:| |k| (-763)) (|:| |c| |#1|)))) 114) (($ (-1141 |#1|)) 109)) (-1992 (($ $) 172 (|has| |#1| (-43 (-409 (-568)))))) (-1943 (($ $) 148 (|has| |#1| (-43 (-409 (-568)))))) (-4490 (($) NIL T CONST)) (-2116 (($ $) NIL)) (-2902 (((-3 $ "failed") $) 23)) (-3866 (($ $) 26)) (-3808 (((-953 |#1|) $ (-763)) 74) (((-953 |#1|) $ (-763) (-763)) 76)) (-1302 (((-121) $) 119)) (-1899 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1844 (((-763) $) 121) (((-763) $ (-763)) 123)) (-1598 (((-121) $) NIL)) (-1550 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4168 (($ $ (-917)) NIL)) (-3698 (($ (-1 |#1| (-568)) $) NIL)) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| (-763)) 13) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-4418 (($ $) 130 (|has| |#1| (-43 (-409 (-568)))))) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-1893 (((-1143) $) NIL)) (-1845 (($ $) 128 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) NIL (-2199 (-12 (|has| |#1| (-15 -1845 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2057 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181))))) (($ $ (-1240 |#2|)) 129 (|has| |#1| (-43 (-409 (-568)))))) (-4025 (((-1108) $) NIL)) (-2168 (($ $ (-763)) 15)) (-2597 (((-3 $ "failed") $ $) 24 (|has| |#1| (-558)))) (-1894 (($ $) 132 (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-763)))))) (-2781 ((|#1| $ (-763)) 118) (($ $ $) 127 (|has| (-763) (-1102)))) (-4191 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $) 27 (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $ (-1240 |#2|)) 29)) (-1836 (((-763) $) NIL)) (-1996 (($ $) 174 (|has| |#1| (-43 (-409 (-568)))))) (-1947 (($ $) 150 (|has| |#1| (-43 (-409 (-568)))))) (-1988 (($ $) 170 (|has| |#1| (-43 (-409 (-568)))))) (-1939 (($ $) 146 (|has| |#1| (-43 (-409 (-568)))))) (-1980 (($ $) 166 (|has| |#1| (-43 (-409 (-568)))))) (-2792 (($ $) 142 (|has| |#1| (-43 (-409 (-568)))))) (-2188 (($ $) NIL)) (-2747 (((-850) $) 200) (($ (-568)) NIL) (($ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $) NIL (|has| |#1| (-558))) (($ |#1|) 125 (|has| |#1| (-172))) (($ (-1216 |#2| |#1|)) 50) (($ (-1240 |#2|)) 32)) (-3304 (((-1141 |#1|) $) 97)) (-2079 ((|#1| $ (-763)) 117)) (-3385 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-3425 (((-763)) NIL)) (-1374 ((|#1| $) 53)) (-2008 (($ $) 180 (|has| |#1| (-43 (-409 (-568)))))) (-1959 (($ $) 156 (|has| |#1| (-43 (-409 (-568)))))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2000 (($ $) 176 (|has| |#1| (-43 (-409 (-568)))))) (-1951 (($ $) 152 (|has| |#1| (-43 (-409 (-568)))))) (-2016 (($ $) 184 (|has| |#1| (-43 (-409 (-568)))))) (-1968 (($ $) 160 (|has| |#1| (-43 (-409 (-568)))))) (-3999 ((|#1| $ (-763)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-763)))) (|has| |#1| (-15 -2747 (|#1| (-1161))))))) (-1439 (($ $) 186 (|has| |#1| (-43 (-409 (-568)))))) (-1972 (($ $) 162 (|has| |#1| (-43 (-409 (-568)))))) (-2012 (($ $) 182 (|has| |#1| (-43 (-409 (-568)))))) (-1964 (($ $) 158 (|has| |#1| (-43 (-409 (-568)))))) (-2004 (($ $) 178 (|has| |#1| (-43 (-409 (-568)))))) (-1955 (($ $) 154 (|has| |#1| (-43 (-409 (-568)))))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 17 T CONST)) (-1557 (($) 19 T CONST)) (-3192 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) 193)) (-1769 (($ $ $) 31)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ |#1|) 197 (|has| |#1| (-365))) (($ $ $) 133 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 136 (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 131) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
+(((-1159 |#1| |#2| |#3|) (-13 (-1234 |#1|) (-10 -8 (-15 -2747 ($ (-1216 |#2| |#1|))) (-15 -1802 ((-1216 |#2| |#1|) $ (-763))) (-15 -2747 ($ (-1240 |#2|))) (-15 -4191 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -1845 ($ $ (-1240 |#2|))) |noBranch|))) (-1047) (-1161) |#1|) (T -1159)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1216 *4 *3)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3) (-5 *1 (-1159 *3 *4 *5)))) (-1802 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1216 *5 *4)) (-5 *1 (-1159 *4 *5 *6)) (-4 *4 (-1047)) (-14 *5 (-1161)) (-14 *6 *4))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1159 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-4191 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1159 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-1845 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1159 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3)))) 
+(-13 (-1234 |#1|) (-10 -8 (-15 -2747 ($ (-1216 |#2| |#1|))) (-15 -1802 ((-1216 |#2| |#1|) $ (-763))) (-15 -2747 ($ (-1240 |#2|))) (-15 -4191 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -1845 ($ $ (-1240 |#2|))) |noBranch|))) 
+((-2747 (((-850) $) 22) (($ (-1161)) 24)) (-2199 (($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $))) 35)) (-2194 (($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $))) 28) (($ $) 29)) (-2573 (($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $))) 30)) (-2687 (($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $))) 32)) (-2725 (($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $))) 31)) (-2777 (($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $))) 33)) (-2995 (($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $))) 36)) (-12 (($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $))) 34))) 
+(((-1160) (-13 (-608 (-850)) (-10 -8 (-15 -2747 ($ (-1161))) (-15 -2573 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2725 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2687 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2777 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2199 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2995 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -12 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2194 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2194 ($ $))))) (T -1160)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1160)))) (-2573 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160)))) (-2725 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160)))) (-2687 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160)))) (-2777 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160)))) (-2199 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160)))) (-2995 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160)))) (-12 (*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160)))) (-2194 (*1 *1 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160)))) (-2194 (*1 *1 *1) (-5 *1 (-1160)))) 
+(-13 (-608 (-850)) (-10 -8 (-15 -2747 ($ (-1161))) (-15 -2573 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2725 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2687 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2777 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2199 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2995 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -12 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)) (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2194 ($ (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| $)))) (-15 -2194 ($ $)))) 
+((-2449 (((-121) $ $) NIL)) (-3987 (($ $ (-634 (-850))) 58)) (-3966 (($ $ (-634 (-850))) 56)) (-1744 (((-1143) $) 82)) (-3689 (((-2 (|:| -1891 (-634 (-850))) (|:| -2409 (-634 (-850))) (|:| |presup| (-634 (-850))) (|:| -2749 (-634 (-850))) (|:| |args| (-634 (-850)))) $) 85)) (-1631 (((-121) $) 21)) (-3176 (($ $ (-634 (-634 (-850)))) 54) (($ $ (-2 (|:| -1891 (-634 (-850))) (|:| -2409 (-634 (-850))) (|:| |presup| (-634 (-850))) (|:| -2749 (-634 (-850))) (|:| |args| (-634 (-850))))) 80)) (-4490 (($) 122 T CONST)) (-3215 (((-1249)) 103)) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 65) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 71)) (-1851 (($) 92) (($ $) 98)) (-3393 (($ $) 81)) (-1732 (($ $ $) NIL)) (-2047 (($ $ $) NIL)) (-3897 (((-634 $) $) 104)) (-1893 (((-1143) $) 87)) (-4025 (((-1108) $) NIL)) (-2781 (($ $ (-634 (-850))) 57)) (-4280 (((-541) $) 45) (((-1161) $) 46) (((-887 (-568)) $) 75) (((-887 (-381)) $) 73)) (-2747 (((-850) $) 52) (($ (-1143)) 47)) (-2272 (($ $ (-634 (-850))) 59)) (-2628 (((-1143) $) 33) (((-1143) $ (-121)) 34) (((-1249) (-817) $) 35) (((-1249) (-817) $ (-121)) 36)) (-1753 (((-121) $ $) NIL)) (-1740 (((-121) $ $) NIL)) (-1719 (((-121) $ $) 48)) (-1747 (((-121) $ $) NIL)) (-1734 (((-121) $ $) 49))) 
+(((-1161) (-13 (-842) (-609 (-541)) (-823) (-609 (-1161)) (-609 (-887 (-568))) (-609 (-887 (-381))) (-881 (-568)) (-881 (-381)) (-10 -8 (-15 -1851 ($)) (-15 -1851 ($ $)) (-15 -3215 ((-1249))) (-15 -2747 ($ (-1143))) (-15 -3393 ($ $)) (-15 -1631 ((-121) $)) (-15 -3689 ((-2 (|:| -1891 (-634 (-850))) (|:| -2409 (-634 (-850))) (|:| |presup| (-634 (-850))) (|:| -2749 (-634 (-850))) (|:| |args| (-634 (-850)))) $)) (-15 -3176 ($ $ (-634 (-634 (-850))))) (-15 -3176 ($ $ (-2 (|:| -1891 (-634 (-850))) (|:| -2409 (-634 (-850))) (|:| |presup| (-634 (-850))) (|:| -2749 (-634 (-850))) (|:| |args| (-634 (-850)))))) (-15 -3966 ($ $ (-634 (-850)))) (-15 -3987 ($ $ (-634 (-850)))) (-15 -2272 ($ $ (-634 (-850)))) (-15 -2781 ($ $ (-634 (-850)))) (-15 -1744 ((-1143) $)) (-15 -3897 ((-634 $) $)) (-15 -4490 ($) -3497)))) (T -1161)) 
+((-1851 (*1 *1) (-5 *1 (-1161))) (-1851 (*1 *1 *1) (-5 *1 (-1161))) (-3215 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1161)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1161)))) (-3393 (*1 *1 *1) (-5 *1 (-1161))) (-1631 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1161)))) (-3689 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| -1891 (-634 (-850))) (|:| -2409 (-634 (-850))) (|:| |presup| (-634 (-850))) (|:| -2749 (-634 (-850))) (|:| |args| (-634 (-850))))) (-5 *1 (-1161)))) (-3176 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-634 (-850)))) (-5 *1 (-1161)))) (-3176 (*1 *1 *1 *2) (-12 (-5 *2 (-2 (|:| -1891 (-634 (-850))) (|:| -2409 (-634 (-850))) (|:| |presup| (-634 (-850))) (|:| -2749 (-634 (-850))) (|:| |args| (-634 (-850))))) (-5 *1 (-1161)))) (-3966 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-1161)))) (-3987 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-1161)))) (-2272 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-1161)))) (-2781 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-1161)))) (-1744 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-1161)))) (-3897 (*1 *2 *1) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-1161)))) (-4490 (*1 *1) (-5 *1 (-1161)))) 
+(-13 (-842) (-609 (-541)) (-823) (-609 (-1161)) (-609 (-887 (-568))) (-609 (-887 (-381))) (-881 (-568)) (-881 (-381)) (-10 -8 (-15 -1851 ($)) (-15 -1851 ($ $)) (-15 -3215 ((-1249))) (-15 -2747 ($ (-1143))) (-15 -3393 ($ $)) (-15 -1631 ((-121) $)) (-15 -3689 ((-2 (|:| -1891 (-634 (-850))) (|:| -2409 (-634 (-850))) (|:| |presup| (-634 (-850))) (|:| -2749 (-634 (-850))) (|:| |args| (-634 (-850)))) $)) (-15 -3176 ($ $ (-634 (-634 (-850))))) (-15 -3176 ($ $ (-2 (|:| -1891 (-634 (-850))) (|:| -2409 (-634 (-850))) (|:| |presup| (-634 (-850))) (|:| -2749 (-634 (-850))) (|:| |args| (-634 (-850)))))) (-15 -3966 ($ $ (-634 (-850)))) (-15 -3987 ($ $ (-634 (-850)))) (-15 -2272 ($ $ (-634 (-850)))) (-15 -2781 ($ $ (-634 (-850)))) (-15 -1744 ((-1143) $)) (-15 -3897 ((-634 $) $)) (-15 -4490 ($) -3497))) 
+((-1321 (((-1244 |#1|) |#1| (-917)) 16) (((-1244 |#1|) (-634 |#1|)) 20))) 
+(((-1162 |#1|) (-10 -7 (-15 -1321 ((-1244 |#1|) (-634 |#1|))) (-15 -1321 ((-1244 |#1|) |#1| (-917)))) (-1047)) (T -1162)) 
+((-1321 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-5 *2 (-1244 *3)) (-5 *1 (-1162 *3)) (-4 *3 (-1047)))) (-1321 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1047)) (-5 *2 (-1244 *4)) (-5 *1 (-1162 *4))))) 
+(-10 -7 (-15 -1321 ((-1244 |#1|) (-634 |#1|))) (-15 -1321 ((-1244 |#1|) |#1| (-917)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) NIL (|has| |#1| (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#1| (-1037 (-409 (-568))))) (((-3 |#1| "failed") $) NIL)) (-2857 (((-568) $) NIL (|has| |#1| (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| |#1| (-1037 (-409 (-568))))) ((|#1| $) NIL)) (-2116 (($ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1998 (($ $) NIL (|has| |#1| (-453)))) (-2453 (($ $ |#1| (-972) $) NIL)) (-1598 (((-121) $) NIL)) (-3971 (((-763) $) NIL)) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| (-972)) NIL)) (-3524 (((-972) $) NIL)) (-1865 (($ (-1 (-972) (-972)) $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2088 (((-121) $) NIL)) (-2093 ((|#1| $) NIL)) (-2973 (($ $ (-972) |#1| $) NIL (-12 (|has| (-972) (-137)) (|has| |#1| (-558))))) (-2597 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558))) (((-3 $ "failed") $ |#1|) NIL (|has| |#1| (-558)))) (-1836 (((-972) $) NIL)) (-1364 ((|#1| $) NIL (|has| |#1| (-453)))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ $) NIL (|has| |#1| (-558))) (($ |#1|) NIL) (($ (-409 (-568))) NIL (-2199 (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-1037 (-409 (-568))))))) (-3304 (((-634 |#1|) $) NIL)) (-2079 ((|#1| $ (-972)) NIL)) (-3385 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-3425 (((-763)) NIL)) (-3925 (($ $ $ (-763)) NIL (|has| |#1| (-172)))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 9 T CONST)) (-1557 (($) 14 T CONST)) (-1719 (((-121) $ $) 16)) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) 19)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 20) (($ $ |#1|) NIL) (($ |#1| $) 13) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
+(((-1163 |#1|) (-13 (-324 |#1| (-972)) (-10 -8 (IF (|has| |#1| (-558)) (IF (|has| (-972) (-137)) (-15 -2973 ($ $ (-972) |#1| $)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4519)) (-6 -4519) |noBranch|))) (-1047)) (T -1163)) 
+((-2973 (*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-972)) (-4 *2 (-137)) (-5 *1 (-1163 *3)) (-4 *3 (-558)) (-4 *3 (-1047))))) 
+(-13 (-324 |#1| (-972)) (-10 -8 (IF (|has| |#1| (-558)) (IF (|has| (-972) (-137)) (-15 -2973 ($ $ (-972) |#1| $)) |noBranch|) |noBranch|) (IF (|has| |#1| (-6 -4519)) (-6 -4519) |noBranch|))) 
+((-2641 (((-1165) (-1161) $) 24)) (-1962 (($) 28)) (-1605 (((-3 (|:| |fst| (-436)) (|:| -3613 "void")) (-1161) $) 21)) (-3086 (((-1249) (-1161) (-3 (|:| |fst| (-436)) (|:| -3613 "void")) $) 40) (((-1249) (-1161) (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) 41) (((-1249) (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) 42)) (-2741 (((-1249) (-1161)) 57)) (-2967 (((-1249) (-1161) $) 54) (((-1249) (-1161)) 55) (((-1249)) 56)) (-1997 (((-1249) (-1161)) 36)) (-4395 (((-1161)) 35)) (-1990 (($) 33)) (-3815 (((-439) (-1161) (-439) (-1161) $) 44) (((-439) (-634 (-1161)) (-439) (-1161) $) 48) (((-439) (-1161) (-439)) 45) (((-439) (-1161) (-439) (-1161)) 49)) (-1658 (((-1161)) 34)) (-2747 (((-850) $) 27)) (-1754 (((-1249)) 29) (((-1249) (-1161)) 32)) (-3379 (((-634 (-1161)) (-1161) $) 23)) (-1622 (((-1249) (-1161) (-634 (-1161)) $) 37) (((-1249) (-1161) (-634 (-1161))) 38) (((-1249) (-634 (-1161))) 39))) 
+(((-1164) (-13 (-608 (-850)) (-10 -8 (-15 -1962 ($)) (-15 -1754 ((-1249))) (-15 -1754 ((-1249) (-1161))) (-15 -3815 ((-439) (-1161) (-439) (-1161) $)) (-15 -3815 ((-439) (-634 (-1161)) (-439) (-1161) $)) (-15 -3815 ((-439) (-1161) (-439))) (-15 -3815 ((-439) (-1161) (-439) (-1161))) (-15 -1997 ((-1249) (-1161))) (-15 -1658 ((-1161))) (-15 -4395 ((-1161))) (-15 -1622 ((-1249) (-1161) (-634 (-1161)) $)) (-15 -1622 ((-1249) (-1161) (-634 (-1161)))) (-15 -1622 ((-1249) (-634 (-1161)))) (-15 -3086 ((-1249) (-1161) (-3 (|:| |fst| (-436)) (|:| -3613 "void")) $)) (-15 -3086 ((-1249) (-1161) (-3 (|:| |fst| (-436)) (|:| -3613 "void")))) (-15 -3086 ((-1249) (-3 (|:| |fst| (-436)) (|:| -3613 "void")))) (-15 -2967 ((-1249) (-1161) $)) (-15 -2967 ((-1249) (-1161))) (-15 -2967 ((-1249))) (-15 -2741 ((-1249) (-1161))) (-15 -1990 ($)) (-15 -1605 ((-3 (|:| |fst| (-436)) (|:| -3613 "void")) (-1161) $)) (-15 -3379 ((-634 (-1161)) (-1161) $)) (-15 -2641 ((-1165) (-1161) $))))) (T -1164)) 
+((-1962 (*1 *1) (-5 *1 (-1164))) (-1754 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1164)))) (-1754 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164)))) (-3815 (*1 *2 *3 *2 *3 *1) (-12 (-5 *2 (-439)) (-5 *3 (-1161)) (-5 *1 (-1164)))) (-3815 (*1 *2 *3 *2 *4 *1) (-12 (-5 *2 (-439)) (-5 *3 (-634 (-1161))) (-5 *4 (-1161)) (-5 *1 (-1164)))) (-3815 (*1 *2 *3 *2) (-12 (-5 *2 (-439)) (-5 *3 (-1161)) (-5 *1 (-1164)))) (-3815 (*1 *2 *3 *2 *3) (-12 (-5 *2 (-439)) (-5 *3 (-1161)) (-5 *1 (-1164)))) (-1997 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164)))) (-1658 (*1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1164)))) (-4395 (*1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1164)))) (-1622 (*1 *2 *3 *4 *1) (-12 (-5 *4 (-634 (-1161))) (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164)))) (-1622 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-1161))) (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164)))) (-1622 (*1 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-5 *2 (-1249)) (-5 *1 (-1164)))) (-3086 (*1 *2 *3 *4 *1) (-12 (-5 *3 (-1161)) (-5 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-5 *2 (-1249)) (-5 *1 (-1164)))) (-3086 (*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-5 *2 (-1249)) (-5 *1 (-1164)))) (-3086 (*1 *2 *3) (-12 (-5 *3 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-5 *2 (-1249)) (-5 *1 (-1164)))) (-2967 (*1 *2 *3 *1) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164)))) (-2967 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164)))) (-2967 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1164)))) (-2741 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164)))) (-1990 (*1 *1) (-5 *1 (-1164))) (-1605 (*1 *2 *3 *1) (-12 (-5 *3 (-1161)) (-5 *2 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-5 *1 (-1164)))) (-3379 (*1 *2 *3 *1) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-1164)) (-5 *3 (-1161)))) (-2641 (*1 *2 *3 *1) (-12 (-5 *3 (-1161)) (-5 *2 (-1165)) (-5 *1 (-1164))))) 
+(-13 (-608 (-850)) (-10 -8 (-15 -1962 ($)) (-15 -1754 ((-1249))) (-15 -1754 ((-1249) (-1161))) (-15 -3815 ((-439) (-1161) (-439) (-1161) $)) (-15 -3815 ((-439) (-634 (-1161)) (-439) (-1161) $)) (-15 -3815 ((-439) (-1161) (-439))) (-15 -3815 ((-439) (-1161) (-439) (-1161))) (-15 -1997 ((-1249) (-1161))) (-15 -1658 ((-1161))) (-15 -4395 ((-1161))) (-15 -1622 ((-1249) (-1161) (-634 (-1161)) $)) (-15 -1622 ((-1249) (-1161) (-634 (-1161)))) (-15 -1622 ((-1249) (-634 (-1161)))) (-15 -3086 ((-1249) (-1161) (-3 (|:| |fst| (-436)) (|:| -3613 "void")) $)) (-15 -3086 ((-1249) (-1161) (-3 (|:| |fst| (-436)) (|:| -3613 "void")))) (-15 -3086 ((-1249) (-3 (|:| |fst| (-436)) (|:| -3613 "void")))) (-15 -2967 ((-1249) (-1161) $)) (-15 -2967 ((-1249) (-1161))) (-15 -2967 ((-1249))) (-15 -2741 ((-1249) (-1161))) (-15 -1990 ($)) (-15 -1605 ((-3 (|:| |fst| (-436)) (|:| -3613 "void")) (-1161) $)) (-15 -3379 ((-634 (-1161)) (-1161) $)) (-15 -2641 ((-1165) (-1161) $)))) 
+((-3208 (((-634 (-634 (-3 (|:| -3393 (-1161)) (|:| |bounds| (-634 (-3 (|:| S (-1161)) (|:| P (-953 (-568))))))))) $) 57)) (-2659 (((-634 (-3 (|:| -3393 (-1161)) (|:| |bounds| (-634 (-3 (|:| S (-1161)) (|:| P (-953 (-568)))))))) (-436) $) 40)) (-4101 (($ (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 (-439))))) 15)) (-2741 (((-1249) $) 65)) (-2943 (((-634 (-1161)) $) 20)) (-3143 (((-1094) $) 53)) (-1831 (((-439) (-1161) $) 27)) (-3848 (((-634 (-1161)) $) 30)) (-1990 (($) 17)) (-3815 (((-439) (-634 (-1161)) (-439) $) 25) (((-439) (-1161) (-439) $) 24)) (-2747 (((-850) $) 9) (((-1169 (-1161) (-439)) $) 11))) 
+(((-1165) (-13 (-608 (-850)) (-10 -8 (-15 -2747 ((-1169 (-1161) (-439)) $)) (-15 -1990 ($)) (-15 -3815 ((-439) (-634 (-1161)) (-439) $)) (-15 -3815 ((-439) (-1161) (-439) $)) (-15 -1831 ((-439) (-1161) $)) (-15 -2943 ((-634 (-1161)) $)) (-15 -2659 ((-634 (-3 (|:| -3393 (-1161)) (|:| |bounds| (-634 (-3 (|:| S (-1161)) (|:| P (-953 (-568)))))))) (-436) $)) (-15 -3848 ((-634 (-1161)) $)) (-15 -3208 ((-634 (-634 (-3 (|:| -3393 (-1161)) (|:| |bounds| (-634 (-3 (|:| S (-1161)) (|:| P (-953 (-568))))))))) $)) (-15 -3143 ((-1094) $)) (-15 -2741 ((-1249) $)) (-15 -4101 ($ (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 (-439))))))))) (T -1165)) 
+((-2747 (*1 *2 *1) (-12 (-5 *2 (-1169 (-1161) (-439))) (-5 *1 (-1165)))) (-1990 (*1 *1) (-5 *1 (-1165))) (-3815 (*1 *2 *3 *2 *1) (-12 (-5 *2 (-439)) (-5 *3 (-634 (-1161))) (-5 *1 (-1165)))) (-3815 (*1 *2 *3 *2 *1) (-12 (-5 *2 (-439)) (-5 *3 (-1161)) (-5 *1 (-1165)))) (-1831 (*1 *2 *3 *1) (-12 (-5 *3 (-1161)) (-5 *2 (-439)) (-5 *1 (-1165)))) (-2943 (*1 *2 *1) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-1165)))) (-2659 (*1 *2 *3 *1) (-12 (-5 *3 (-436)) (-5 *2 (-634 (-3 (|:| -3393 (-1161)) (|:| |bounds| (-634 (-3 (|:| S (-1161)) (|:| P (-953 (-568))))))))) (-5 *1 (-1165)))) (-3848 (*1 *2 *1) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-1165)))) (-3208 (*1 *2 *1) (-12 (-5 *2 (-634 (-634 (-3 (|:| -3393 (-1161)) (|:| |bounds| (-634 (-3 (|:| S (-1161)) (|:| P (-953 (-568)))))))))) (-5 *1 (-1165)))) (-3143 (*1 *2 *1) (-12 (-5 *2 (-1094)) (-5 *1 (-1165)))) (-2741 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-1165)))) (-4101 (*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 (-439))))) (-5 *1 (-1165))))) 
+(-13 (-608 (-850)) (-10 -8 (-15 -2747 ((-1169 (-1161) (-439)) $)) (-15 -1990 ($)) (-15 -3815 ((-439) (-634 (-1161)) (-439) $)) (-15 -3815 ((-439) (-1161) (-439) $)) (-15 -1831 ((-439) (-1161) $)) (-15 -2943 ((-634 (-1161)) $)) (-15 -2659 ((-634 (-3 (|:| -3393 (-1161)) (|:| |bounds| (-634 (-3 (|:| S (-1161)) (|:| P (-953 (-568)))))))) (-436) $)) (-15 -3848 ((-634 (-1161)) $)) (-15 -3208 ((-634 (-634 (-3 (|:| -3393 (-1161)) (|:| |bounds| (-634 (-3 (|:| S (-1161)) (|:| P (-953 (-568))))))))) $)) (-15 -3143 ((-1094) $)) (-15 -2741 ((-1249) $)) (-15 -4101 ($ (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 (-439)))))))) 
+((-4226 (((-634 (-634 (-953 |#1|))) (-634 (-409 (-953 |#1|))) (-634 (-1161))) 55)) (-3259 (((-634 (-288 (-409 (-953 |#1|)))) (-288 (-409 (-953 |#1|)))) 66) (((-634 (-288 (-409 (-953 |#1|)))) (-409 (-953 |#1|))) 62) (((-634 (-288 (-409 (-953 |#1|)))) (-288 (-409 (-953 |#1|))) (-1161)) 67) (((-634 (-288 (-409 (-953 |#1|)))) (-409 (-953 |#1|)) (-1161)) 61) (((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-288 (-409 (-953 |#1|))))) 91) (((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-409 (-953 |#1|)))) 90) (((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-288 (-409 (-953 |#1|)))) (-634 (-1161))) 92) (((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-409 (-953 |#1|))) (-634 (-1161))) 89))) 
+(((-1166 |#1|) (-10 -7 (-15 -3259 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-409 (-953 |#1|))) (-634 (-1161)))) (-15 -3259 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-288 (-409 (-953 |#1|)))) (-634 (-1161)))) (-15 -3259 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-409 (-953 |#1|))))) (-15 -3259 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-288 (-409 (-953 |#1|)))))) (-15 -3259 ((-634 (-288 (-409 (-953 |#1|)))) (-409 (-953 |#1|)) (-1161))) (-15 -3259 ((-634 (-288 (-409 (-953 |#1|)))) (-288 (-409 (-953 |#1|))) (-1161))) (-15 -3259 ((-634 (-288 (-409 (-953 |#1|)))) (-409 (-953 |#1|)))) (-15 -3259 ((-634 (-288 (-409 (-953 |#1|)))) (-288 (-409 (-953 |#1|))))) (-15 -4226 ((-634 (-634 (-953 |#1|))) (-634 (-409 (-953 |#1|))) (-634 (-1161))))) (-558)) (T -1166)) 
+((-4226 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 *5)))) (-5 *4 (-634 (-1161))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-953 *5)))) (-5 *1 (-1166 *5)))) (-3259 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 (-288 (-409 (-953 *4))))) (-5 *1 (-1166 *4)) (-5 *3 (-288 (-409 (-953 *4)))))) (-3259 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 (-288 (-409 (-953 *4))))) (-5 *1 (-1166 *4)) (-5 *3 (-409 (-953 *4))))) (-3259 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-558)) (-5 *2 (-634 (-288 (-409 (-953 *5))))) (-5 *1 (-1166 *5)) (-5 *3 (-288 (-409 (-953 *5)))))) (-3259 (*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-558)) (-5 *2 (-634 (-288 (-409 (-953 *5))))) (-5 *1 (-1166 *5)) (-5 *3 (-409 (-953 *5))))) (-3259 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *4)))))) (-5 *1 (-1166 *4)) (-5 *3 (-634 (-288 (-409 (-953 *4))))))) (-3259 (*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 *4)))) (-4 *4 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *4)))))) (-5 *1 (-1166 *4)))) (-3259 (*1 *2 *3 *4) (-12 (-5 *4 (-634 (-1161))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *5)))))) (-5 *1 (-1166 *5)) (-5 *3 (-634 (-288 (-409 (-953 *5))))))) (-3259 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 *5)))) (-5 *4 (-634 (-1161))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *5)))))) (-5 *1 (-1166 *5))))) 
+(-10 -7 (-15 -3259 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-409 (-953 |#1|))) (-634 (-1161)))) (-15 -3259 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-288 (-409 (-953 |#1|)))) (-634 (-1161)))) (-15 -3259 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-409 (-953 |#1|))))) (-15 -3259 ((-634 (-634 (-288 (-409 (-953 |#1|))))) (-634 (-288 (-409 (-953 |#1|)))))) (-15 -3259 ((-634 (-288 (-409 (-953 |#1|)))) (-409 (-953 |#1|)) (-1161))) (-15 -3259 ((-634 (-288 (-409 (-953 |#1|)))) (-288 (-409 (-953 |#1|))) (-1161))) (-15 -3259 ((-634 (-288 (-409 (-953 |#1|)))) (-409 (-953 |#1|)))) (-15 -3259 ((-634 (-288 (-409 (-953 |#1|)))) (-288 (-409 (-953 |#1|))))) (-15 -4226 ((-634 (-634 (-953 |#1|))) (-634 (-409 (-953 |#1|))) (-634 (-1161))))) 
+((-1848 (((-634 (-634 |#1|)) (-634 (-634 |#1|)) (-634 (-634 (-634 |#1|)))) 38)) (-4369 (((-634 (-634 (-634 |#1|))) (-634 (-634 |#1|))) 24)) (-1577 (((-1168 (-634 |#1|)) (-634 |#1|)) 34)) (-2731 (((-634 (-634 |#1|)) (-634 |#1|)) 30)) (-2486 (((-2 (|:| |f1| (-634 |#1|)) (|:| |f2| (-634 (-634 (-634 |#1|)))) (|:| |f3| (-634 (-634 |#1|))) (|:| |f4| (-634 (-634 (-634 |#1|))))) (-634 (-634 (-634 |#1|)))) 37)) (-1308 (((-2 (|:| |f1| (-634 |#1|)) (|:| |f2| (-634 (-634 (-634 |#1|)))) (|:| |f3| (-634 (-634 |#1|))) (|:| |f4| (-634 (-634 (-634 |#1|))))) (-634 |#1|) (-634 (-634 (-634 |#1|))) (-634 (-634 |#1|)) (-634 (-634 (-634 |#1|))) (-634 (-634 (-634 |#1|))) (-634 (-634 (-634 |#1|)))) 36)) (-2755 (((-634 (-634 |#1|)) (-634 (-634 |#1|))) 28)) (-2715 (((-634 |#1|) (-634 |#1|)) 31)) (-1661 (((-634 (-634 (-634 |#1|))) (-634 |#1|) (-634 (-634 (-634 |#1|)))) 18)) (-1701 (((-634 (-634 (-634 |#1|))) (-1 (-121) |#1| |#1|) (-634 |#1|) (-634 (-634 (-634 |#1|)))) 15)) (-1290 (((-2 (|:| |fs| (-121)) (|:| |sd| (-634 |#1|)) (|:| |td| (-634 (-634 |#1|)))) (-1 (-121) |#1| |#1|) (-634 |#1|) (-634 (-634 |#1|))) 13)) (-3773 (((-634 (-634 |#1|)) (-634 (-634 (-634 |#1|)))) 39)) (-3867 (((-634 (-634 |#1|)) (-1168 (-634 |#1|))) 41))) 
+(((-1167 |#1|) (-10 -7 (-15 -1290 ((-2 (|:| |fs| (-121)) (|:| |sd| (-634 |#1|)) (|:| |td| (-634 (-634 |#1|)))) (-1 (-121) |#1| |#1|) (-634 |#1|) (-634 (-634 |#1|)))) (-15 -1701 ((-634 (-634 (-634 |#1|))) (-1 (-121) |#1| |#1|) (-634 |#1|) (-634 (-634 (-634 |#1|))))) (-15 -1661 ((-634 (-634 (-634 |#1|))) (-634 |#1|) (-634 (-634 (-634 |#1|))))) (-15 -1848 ((-634 (-634 |#1|)) (-634 (-634 |#1|)) (-634 (-634 (-634 |#1|))))) (-15 -3773 ((-634 (-634 |#1|)) (-634 (-634 (-634 |#1|))))) (-15 -3867 ((-634 (-634 |#1|)) (-1168 (-634 |#1|)))) (-15 -4369 ((-634 (-634 (-634 |#1|))) (-634 (-634 |#1|)))) (-15 -1577 ((-1168 (-634 |#1|)) (-634 |#1|))) (-15 -2755 ((-634 (-634 |#1|)) (-634 (-634 |#1|)))) (-15 -2731 ((-634 (-634 |#1|)) (-634 |#1|))) (-15 -2715 ((-634 |#1|) (-634 |#1|))) (-15 -1308 ((-2 (|:| |f1| (-634 |#1|)) (|:| |f2| (-634 (-634 (-634 |#1|)))) (|:| |f3| (-634 (-634 |#1|))) (|:| |f4| (-634 (-634 (-634 |#1|))))) (-634 |#1|) (-634 (-634 (-634 |#1|))) (-634 (-634 |#1|)) (-634 (-634 (-634 |#1|))) (-634 (-634 (-634 |#1|))) (-634 (-634 (-634 |#1|))))) (-15 -2486 ((-2 (|:| |f1| (-634 |#1|)) (|:| |f2| (-634 (-634 (-634 |#1|)))) (|:| |f3| (-634 (-634 |#1|))) (|:| |f4| (-634 (-634 (-634 |#1|))))) (-634 (-634 (-634 |#1|)))))) (-842)) (T -1167)) 
+((-2486 (*1 *2 *3) (-12 (-4 *4 (-842)) (-5 *2 (-2 (|:| |f1| (-634 *4)) (|:| |f2| (-634 (-634 (-634 *4)))) (|:| |f3| (-634 (-634 *4))) (|:| |f4| (-634 (-634 (-634 *4)))))) (-5 *1 (-1167 *4)) (-5 *3 (-634 (-634 (-634 *4)))))) (-1308 (*1 *2 *3 *4 *5 *4 *4 *4) (-12 (-4 *6 (-842)) (-5 *3 (-634 *6)) (-5 *5 (-634 *3)) (-5 *2 (-2 (|:| |f1| *3) (|:| |f2| (-634 *5)) (|:| |f3| *5) (|:| |f4| (-634 *5)))) (-5 *1 (-1167 *6)) (-5 *4 (-634 *5)))) (-2715 (*1 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-1167 *3)))) (-2731 (*1 *2 *3) (-12 (-4 *4 (-842)) (-5 *2 (-634 (-634 *4))) (-5 *1 (-1167 *4)) (-5 *3 (-634 *4)))) (-2755 (*1 *2 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-842)) (-5 *1 (-1167 *3)))) (-1577 (*1 *2 *3) (-12 (-4 *4 (-842)) (-5 *2 (-1168 (-634 *4))) (-5 *1 (-1167 *4)) (-5 *3 (-634 *4)))) (-4369 (*1 *2 *3) (-12 (-4 *4 (-842)) (-5 *2 (-634 (-634 (-634 *4)))) (-5 *1 (-1167 *4)) (-5 *3 (-634 (-634 *4))))) (-3867 (*1 *2 *3) (-12 (-5 *3 (-1168 (-634 *4))) (-4 *4 (-842)) (-5 *2 (-634 (-634 *4))) (-5 *1 (-1167 *4)))) (-3773 (*1 *2 *3) (-12 (-5 *3 (-634 (-634 (-634 *4)))) (-5 *2 (-634 (-634 *4))) (-5 *1 (-1167 *4)) (-4 *4 (-842)))) (-1848 (*1 *2 *2 *3) (-12 (-5 *3 (-634 (-634 (-634 *4)))) (-5 *2 (-634 (-634 *4))) (-4 *4 (-842)) (-5 *1 (-1167 *4)))) (-1661 (*1 *2 *3 *2) (-12 (-5 *2 (-634 (-634 (-634 *4)))) (-5 *3 (-634 *4)) (-4 *4 (-842)) (-5 *1 (-1167 *4)))) (-1701 (*1 *2 *3 *4 *2) (-12 (-5 *2 (-634 (-634 (-634 *5)))) (-5 *3 (-1 (-121) *5 *5)) (-5 *4 (-634 *5)) (-4 *5 (-842)) (-5 *1 (-1167 *5)))) (-1290 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-121) *6 *6)) (-4 *6 (-842)) (-5 *4 (-634 *6)) (-5 *2 (-2 (|:| |fs| (-121)) (|:| |sd| *4) (|:| |td| (-634 *4)))) (-5 *1 (-1167 *6)) (-5 *5 (-634 *4))))) 
+(-10 -7 (-15 -1290 ((-2 (|:| |fs| (-121)) (|:| |sd| (-634 |#1|)) (|:| |td| (-634 (-634 |#1|)))) (-1 (-121) |#1| |#1|) (-634 |#1|) (-634 (-634 |#1|)))) (-15 -1701 ((-634 (-634 (-634 |#1|))) (-1 (-121) |#1| |#1|) (-634 |#1|) (-634 (-634 (-634 |#1|))))) (-15 -1661 ((-634 (-634 (-634 |#1|))) (-634 |#1|) (-634 (-634 (-634 |#1|))))) (-15 -1848 ((-634 (-634 |#1|)) (-634 (-634 |#1|)) (-634 (-634 (-634 |#1|))))) (-15 -3773 ((-634 (-634 |#1|)) (-634 (-634 (-634 |#1|))))) (-15 -3867 ((-634 (-634 |#1|)) (-1168 (-634 |#1|)))) (-15 -4369 ((-634 (-634 (-634 |#1|))) (-634 (-634 |#1|)))) (-15 -1577 ((-1168 (-634 |#1|)) (-634 |#1|))) (-15 -2755 ((-634 (-634 |#1|)) (-634 (-634 |#1|)))) (-15 -2731 ((-634 (-634 |#1|)) (-634 |#1|))) (-15 -2715 ((-634 |#1|) (-634 |#1|))) (-15 -1308 ((-2 (|:| |f1| (-634 |#1|)) (|:| |f2| (-634 (-634 (-634 |#1|)))) (|:| |f3| (-634 (-634 |#1|))) (|:| |f4| (-634 (-634 (-634 |#1|))))) (-634 |#1|) (-634 (-634 (-634 |#1|))) (-634 (-634 |#1|)) (-634 (-634 (-634 |#1|))) (-634 (-634 (-634 |#1|))) (-634 (-634 (-634 |#1|))))) (-15 -2486 ((-2 (|:| |f1| (-634 |#1|)) (|:| |f2| (-634 (-634 (-634 |#1|)))) (|:| |f3| (-634 (-634 |#1|))) (|:| |f4| (-634 (-634 (-634 |#1|))))) (-634 (-634 (-634 |#1|)))))) 
+((-2626 (($ (-634 (-634 |#1|))) 9)) (-1843 (((-634 (-634 |#1|)) $) 10)) (-2747 (((-850) $) 25))) 
+(((-1168 |#1|) (-10 -8 (-15 -2626 ($ (-634 (-634 |#1|)))) (-15 -1843 ((-634 (-634 |#1|)) $)) (-15 -2747 ((-850) $))) (-1090)) (T -1168)) 
+((-2747 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1168 *3)) (-4 *3 (-1090)))) (-1843 (*1 *2 *1) (-12 (-5 *2 (-634 (-634 *3))) (-5 *1 (-1168 *3)) (-4 *3 (-1090)))) (-2626 (*1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-1090)) (-5 *1 (-1168 *3))))) 
+(-10 -8 (-15 -2626 ($ (-634 (-634 |#1|)))) (-15 -1843 ((-634 (-634 |#1|)) $)) (-15 -2747 ((-850) $))) 
+((-2449 (((-121) $ $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-2988 (($) NIL) (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-2481 (((-1249) $ |#1| |#1|) NIL (|has| $ (-6 -4522)))) (-1667 (((-121) $ (-763)) NIL)) (-2438 ((|#2| $ |#1| |#2|) NIL)) (-3963 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-2678 (((-3 |#2| "failed") |#1| $) NIL)) (-4490 (($) NIL T CONST)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-1568 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (|has| $ (-6 -4521))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-3 |#2| "failed") |#1| $) NIL)) (-4330 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-3094 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (|has| $ (-6 -4521))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521)))) (-1292 ((|#2| $ |#1| |#2|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#2| $ |#1|) NIL)) (-3317 (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-634 |#2|) $) NIL (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) NIL)) (-2539 ((|#1| $) NIL (|has| |#1| (-842)))) (-4406 (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-634 |#2|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-3631 ((|#1| $) NIL (|has| |#1| (-842)))) (-2253 (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4522))) (($ (-1 |#2| |#2|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL) (($ (-1 |#2| |#2|) $) NIL) (($ (-1 |#2| |#2| |#2|) $ $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-4253 (((-634 |#1|) $) NIL)) (-2807 (((-121) |#1| $) NIL)) (-2580 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-1708 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-3948 (((-634 |#1|) $) NIL)) (-2916 (((-121) |#1| $) NIL)) (-4025 (((-1108) $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-3877 ((|#2| $) NIL (|has| |#1| (-842)))) (-2712 (((-3 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) "failed") (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL)) (-2490 (($ $ |#2|) NIL (|has| $ (-6 -4522)))) (-3403 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL)) (-3951 (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-1480 (((-634 |#2|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#2| $ |#1|) NIL) ((|#2| $ |#1| |#2|) NIL)) (-3132 (($) NIL) (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-4170 (((-763) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-763) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) NIL (-12 (|has| $ (-6 -4521)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (((-763) |#2| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090)))) (((-763) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-609 (-541))))) (-4289 (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-2747 (((-850) $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-4074 (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) NIL)) (-3437 (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) NIL (|has| $ (-6 -4521))) (((-121) (-1 (-121) |#2|) $) NIL (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) NIL (-2199 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| |#2| (-1090))))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-1169 |#1| |#2|) (-13 (-1172 |#1| |#2|) (-10 -7 (-6 -4521))) (-1090) (-1090)) (T -1169)) 
+NIL 
+(-13 (-1172 |#1| |#2|) (-10 -7 (-6 -4521))) 
+((-1547 ((|#1| (-634 |#1|)) 32)) (-2909 ((|#1| |#1| (-568)) 18)) (-1596 (((-1157 |#1|) |#1| (-917)) 15))) 
+(((-1170 |#1|) (-10 -7 (-15 -1547 (|#1| (-634 |#1|))) (-15 -1596 ((-1157 |#1|) |#1| (-917))) (-15 -2909 (|#1| |#1| (-568)))) (-365)) (T -1170)) 
+((-2909 (*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-1170 *2)) (-4 *2 (-365)))) (-1596 (*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-5 *2 (-1157 *3)) (-5 *1 (-1170 *3)) (-4 *3 (-365)))) (-1547 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-5 *1 (-1170 *2)) (-4 *2 (-365))))) 
+(-10 -7 (-15 -1547 (|#1| (-634 |#1|))) (-15 -1596 ((-1157 |#1|) |#1| (-917))) (-15 -2909 (|#1| |#1| (-568)))) 
+((-2988 (($) 10) (($ (-634 (-2 (|:| -3651 |#2|) (|:| -4085 |#3|)))) 14)) (-1568 (($ (-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) $) 60) (($ (-1 (-121) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) $) NIL) (((-3 |#3| "failed") |#2| $) NIL)) (-3317 (((-634 (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) $) 39) (((-634 |#3|) $) 41)) (-2253 (($ (-1 (-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) $) 52) (($ (-1 |#3| |#3|) $) 33)) (-2797 (($ (-1 (-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) $) 50) (($ (-1 |#3| |#3|) $) NIL) (($ (-1 |#3| |#3| |#3|) $ $) 38)) (-2580 (((-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) $) 53)) (-1708 (($ (-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) $) 16)) (-3948 (((-634 |#2|) $) 19)) (-2916 (((-121) |#2| $) 58)) (-2712 (((-3 (-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) "failed") (-1 (-121) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) $) 57)) (-3403 (((-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) $) 62)) (-3951 (((-121) (-1 (-121) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) $) NIL) (((-121) (-1 (-121) |#3|) $) 65)) (-1480 (((-634 |#3|) $) 43)) (-2781 ((|#3| $ |#2|) 30) ((|#3| $ |#2| |#3|) 31)) (-4170 (((-763) (-1 (-121) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) $) NIL) (((-763) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) $) NIL) (((-763) |#3| $) NIL) (((-763) (-1 (-121) |#3|) $) 66)) (-2747 (((-850) $) 27)) (-3437 (((-121) (-1 (-121) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) $) NIL) (((-121) (-1 (-121) |#3|) $) 64)) (-1719 (((-121) $ $) 48))) 
+(((-1171 |#1| |#2| |#3|) (-10 -8 (-15 -1719 ((-121) |#1| |#1|)) (-15 -2747 ((-850) |#1|)) (-15 -2797 (|#1| (-1 |#3| |#3| |#3|) |#1| |#1|)) (-15 -2988 (|#1| (-634 (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))))) (-15 -2988 (|#1|)) (-15 -2797 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -2253 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -3437 ((-121) (-1 (-121) |#3|) |#1|)) (-15 -3951 ((-121) (-1 (-121) |#3|) |#1|)) (-15 -4170 ((-763) (-1 (-121) |#3|) |#1|)) (-15 -3317 ((-634 |#3|) |#1|)) (-15 -4170 ((-763) |#3| |#1|)) (-15 -2781 (|#3| |#1| |#2| |#3|)) (-15 -2781 (|#3| |#1| |#2|)) (-15 -1480 ((-634 |#3|) |#1|)) (-15 -2916 ((-121) |#2| |#1|)) (-15 -3948 ((-634 |#2|) |#1|)) (-15 -1568 ((-3 |#3| "failed") |#2| |#1|)) (-15 -1568 (|#1| (-1 (-121) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) |#1|)) (-15 -1568 (|#1| (-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) |#1|)) (-15 -2712 ((-3 (-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) "failed") (-1 (-121) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) |#1|)) (-15 -2580 ((-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) |#1|)) (-15 -1708 (|#1| (-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) |#1|)) (-15 -3403 ((-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) |#1|)) (-15 -4170 ((-763) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) |#1|)) (-15 -3317 ((-634 (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) |#1|)) (-15 -4170 ((-763) (-1 (-121) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) |#1|)) (-15 -3951 ((-121) (-1 (-121) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) |#1|)) (-15 -3437 ((-121) (-1 (-121) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) |#1|)) (-15 -2253 (|#1| (-1 (-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) |#1|)) (-15 -2797 (|#1| (-1 (-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) |#1|))) (-1172 |#2| |#3|) (-1090) (-1090)) (T -1171)) 
+NIL 
+(-10 -8 (-15 -1719 ((-121) |#1| |#1|)) (-15 -2747 ((-850) |#1|)) (-15 -2797 (|#1| (-1 |#3| |#3| |#3|) |#1| |#1|)) (-15 -2988 (|#1| (-634 (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))))) (-15 -2988 (|#1|)) (-15 -2797 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -2253 (|#1| (-1 |#3| |#3|) |#1|)) (-15 -3437 ((-121) (-1 (-121) |#3|) |#1|)) (-15 -3951 ((-121) (-1 (-121) |#3|) |#1|)) (-15 -4170 ((-763) (-1 (-121) |#3|) |#1|)) (-15 -3317 ((-634 |#3|) |#1|)) (-15 -4170 ((-763) |#3| |#1|)) (-15 -2781 (|#3| |#1| |#2| |#3|)) (-15 -2781 (|#3| |#1| |#2|)) (-15 -1480 ((-634 |#3|) |#1|)) (-15 -2916 ((-121) |#2| |#1|)) (-15 -3948 ((-634 |#2|) |#1|)) (-15 -1568 ((-3 |#3| "failed") |#2| |#1|)) (-15 -1568 (|#1| (-1 (-121) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) |#1|)) (-15 -1568 (|#1| (-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) |#1|)) (-15 -2712 ((-3 (-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) "failed") (-1 (-121) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) |#1|)) (-15 -2580 ((-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) |#1|)) (-15 -1708 (|#1| (-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) |#1|)) (-15 -3403 ((-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) |#1|)) (-15 -4170 ((-763) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) |#1|)) (-15 -3317 ((-634 (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) |#1|)) (-15 -4170 ((-763) (-1 (-121) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) |#1|)) (-15 -3951 ((-121) (-1 (-121) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) |#1|)) (-15 -3437 ((-121) (-1 (-121) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) |#1|)) (-15 -2253 (|#1| (-1 (-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) |#1|)) (-15 -2797 (|#1| (-1 (-2 (|:| -3651 |#2|) (|:| -4085 |#3|)) (-2 (|:| -3651 |#2|) (|:| -4085 |#3|))) |#1|))) 
+((-2449 (((-121) $ $) 18 (-2199 (|has| |#2| (-1090)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-2988 (($) 66) (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) 65)) (-2481 (((-1249) $ |#1| |#1|) 93 (|has| $ (-6 -4522)))) (-1667 (((-121) $ (-763)) 8)) (-2438 ((|#2| $ |#1| |#2|) 67)) (-3963 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 42 (|has| $ (-6 -4521)))) (-2803 (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 52 (|has| $ (-6 -4521)))) (-2678 (((-3 |#2| "failed") |#1| $) 57)) (-4490 (($) 7 T CONST)) (-3926 (($ $) 55 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| $ (-6 -4521))))) (-1568 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 44 (|has| $ (-6 -4521))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 43 (|has| $ (-6 -4521))) (((-3 |#2| "failed") |#1| $) 58)) (-4330 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 54 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 51 (|has| $ (-6 -4521)))) (-3094 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 53 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| $ (-6 -4521)))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 50 (|has| $ (-6 -4521))) (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 49 (|has| $ (-6 -4521)))) (-1292 ((|#2| $ |#1| |#2|) 81 (|has| $ (-6 -4522)))) (-2069 ((|#2| $ |#1|) 82)) (-3317 (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 30 (|has| $ (-6 -4521))) (((-634 |#2|) $) 73 (|has| $ (-6 -4521)))) (-3791 (((-121) $ (-763)) 9)) (-2539 ((|#1| $) 90 (|has| |#1| (-842)))) (-4406 (((-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 29 (|has| $ (-6 -4521))) (((-634 |#2|) $) 74 (|has| $ (-6 -4521)))) (-2551 (((-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 27 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| $ (-6 -4521)))) (((-121) |#2| $) 76 (-12 (|has| |#2| (-1090)) (|has| $ (-6 -4521))))) (-3631 ((|#1| $) 89 (|has| |#1| (-842)))) (-2253 (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 34 (|has| $ (-6 -4522))) (($ (-1 |#2| |#2|) $) 69 (|has| $ (-6 -4522)))) (-2797 (($ (-1 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 35) (($ (-1 |#2| |#2|) $) 68) (($ (-1 |#2| |#2| |#2|) $ $) 64)) (-3796 (((-121) $ (-763)) 10)) (-1893 (((-1143) $) 22 (-2199 (|has| |#2| (-1090)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-4253 (((-634 |#1|) $) 59)) (-2807 (((-121) |#1| $) 60)) (-2580 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 36)) (-1708 (($ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 37)) (-3948 (((-634 |#1|) $) 87)) (-2916 (((-121) |#1| $) 86)) (-4025 (((-1108) $) 21 (-2199 (|has| |#2| (-1090)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-3877 ((|#2| $) 91 (|has| |#1| (-842)))) (-2712 (((-3 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) "failed") (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 48)) (-2490 (($ $ |#2|) 92 (|has| $ (-6 -4522)))) (-3403 (((-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 38)) (-3951 (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 32 (|has| $ (-6 -4521))) (((-121) (-1 (-121) |#2|) $) 71 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))))) 26 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-288 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) 25 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) 24 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) 23 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)))) (($ $ (-634 |#2|) (-634 |#2|)) 80 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ |#2| |#2|) 79 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-288 |#2|)) 78 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090)))) (($ $ (-634 (-288 |#2|))) 77 (-12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))))) (-1702 (((-121) $ $) 14)) (-1801 (((-121) |#2| $) 88 (-12 (|has| $ (-6 -4521)) (|has| |#2| (-1090))))) (-1480 (((-634 |#2|) $) 85)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 ((|#2| $ |#1|) 84) ((|#2| $ |#1| |#2|) 83)) (-3132 (($) 46) (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) 45)) (-4170 (((-763) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 31 (|has| $ (-6 -4521))) (((-763) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) $) 28 (-12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090)) (|has| $ (-6 -4521)))) (((-763) |#2| $) 75 (-12 (|has| |#2| (-1090)) (|has| $ (-6 -4521)))) (((-763) (-1 (-121) |#2|) $) 72 (|has| $ (-6 -4521)))) (-3865 (($ $) 13)) (-4280 (((-541) $) 56 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-609 (-541))))) (-4289 (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) 47)) (-2747 (((-850) $) 20 (-2199 (|has| |#2| (-1090)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-4074 (($ (-634 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) 39)) (-3437 (((-121) (-1 (-121) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) $) 33 (|has| $ (-6 -4521))) (((-121) (-1 (-121) |#2|) $) 70 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (-2199 (|has| |#2| (-1090)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-1172 |#1| |#2|) (-1275) (-1090) (-1090)) (T -1172)) 
-((-2436 (*1 *2 *1 *3 *2) (-12 (-4 *1 (-1172 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090)))) (-2986 (*1 *1) (-12 (-4 *1 (-1172 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090)))) (-2986 (*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3649 *3) (|:| -4083 *4)))) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *1 (-1172 *3 *4)))) (-2795 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *4 *4 *4)) (-4 *1 (-1172 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090))))) 
-(-13 (-605 |t#1| |t#2|) (-601 |t#1| |t#2|) (-10 -8 (-15 -2436 (|t#2| $ |t#1| |t#2|)) (-15 -2986 ($)) (-15 -2986 ($ (-634 (-2 (|:| -3649 |t#1|) (|:| -4083 |t#2|))))) (-15 -2795 ($ (-1 |t#2| |t#2| |t#2|) $ $)))) 
-(((-39) . T) ((-111 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-105) -2198 (|has| |#2| (-1090)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))) ((-608 (-850)) -2198 (|has| |#2| (-1090)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))) ((-154 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-609 (-541)) |has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-609 (-541))) ((-221 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-227 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-281 |#1| |#2|) . T) ((-283 |#1| |#2|) . T) ((-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) -12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))) ((-303 |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) ((-499 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) . T) ((-499 |#2|) . T) ((-601 |#1| |#2|) . T) ((-523 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-2 (|:| -3649 |#1|) (|:| -4083 |#2|))) -12 (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-303 (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)))) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))) ((-523 |#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) ((-605 |#1| |#2|) . T) ((-1090) -2198 (|has| |#2| (-1090)) (|has| (-2 (|:| -3649 |#1|) (|:| -4083 |#2|)) (-1090))) ((-1195) . T)) 
-((-3460 (((-121)) 24)) (-4384 (((-1249) (-1143)) 26)) (-2248 (((-121)) 36)) (-4417 (((-1249)) 34)) (-4160 (((-1249) (-1143) (-1143)) 25)) (-1420 (((-121)) 37)) (-4450 (((-1249) |#1| |#2|) 44)) (-1609 (((-1249)) 20)) (-3608 (((-3 |#2| "failed") |#1|) 42)) (-4277 (((-1249)) 35))) 
-(((-1173 |#1| |#2|) (-10 -7 (-15 -1609 ((-1249))) (-15 -4160 ((-1249) (-1143) (-1143))) (-15 -4384 ((-1249) (-1143))) (-15 -4417 ((-1249))) (-15 -4277 ((-1249))) (-15 -3460 ((-121))) (-15 -2248 ((-121))) (-15 -1420 ((-121))) (-15 -3608 ((-3 |#2| "failed") |#1|)) (-15 -4450 ((-1249) |#1| |#2|))) (-1090) (-1090)) (T -1173)) 
-((-4450 (*1 *2 *3 *4) (-12 (-5 *2 (-1249)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)))) (-3608 (*1 *2 *3) (|partial| -12 (-4 *2 (-1090)) (-5 *1 (-1173 *3 *2)) (-4 *3 (-1090)))) (-1420 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)))) (-2248 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)))) (-3460 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)))) (-4277 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)))) (-4417 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)))) (-4384 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1173 *4 *5)) (-4 *4 (-1090)) (-4 *5 (-1090)))) (-4160 (*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1173 *4 *5)) (-4 *4 (-1090)) (-4 *5 (-1090)))) (-1609 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090))))) 
-(-10 -7 (-15 -1609 ((-1249))) (-15 -4160 ((-1249) (-1143) (-1143))) (-15 -4384 ((-1249) (-1143))) (-15 -4417 ((-1249))) (-15 -4277 ((-1249))) (-15 -3460 ((-121))) (-15 -2248 ((-121))) (-15 -1420 ((-121))) (-15 -3608 ((-3 |#2| "failed") |#1|)) (-15 -4450 ((-1249) |#1| |#2|))) 
-((-1792 (((-1143) (-1143)) 18)) (-3616 (((-57) (-1143)) 21))) 
-(((-1174) (-10 -7 (-15 -3616 ((-57) (-1143))) (-15 -1792 ((-1143) (-1143))))) (T -1174)) 
-((-1792 (*1 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1174)))) (-3616 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-57)) (-5 *1 (-1174))))) 
-(-10 -7 (-15 -3616 ((-57) (-1143))) (-15 -1792 ((-1143) (-1143)))) 
-((-2745 (((-1176) |#1|) 11))) 
-(((-1175 |#1|) (-10 -7 (-15 -2745 ((-1176) |#1|))) (-1090)) (T -1175)) 
-((-2745 (*1 *2 *3) (-12 (-5 *2 (-1176)) (-5 *1 (-1175 *3)) (-4 *3 (-1090))))) 
-(-10 -7 (-15 -2745 ((-1176) |#1|))) 
-((-2447 (((-121) $ $) NIL)) (-3394 (((-634 (-1143)) $) 33)) (-2271 (((-634 (-1143)) $ (-634 (-1143))) 36)) (-1688 (((-634 (-1143)) $ (-634 (-1143))) 35)) (-3371 (((-634 (-1143)) $ (-634 (-1143))) 37)) (-1538 (((-634 (-1143)) $) 32)) (-1849 (($) 22)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-3224 (((-634 (-1143)) $) 34)) (-4125 (((-1249) $ (-568)) 29) (((-1249) $) 30)) (-4278 (($ (-850) (-568)) 26) (($ (-850) (-568) (-850)) NIL)) (-2745 (((-850) $) 39) (($ (-850)) 24)) (-1717 (((-121) $ $) NIL))) 
-(((-1176) (-13 (-1090) (-10 -8 (-15 -2745 ($ (-850))) (-15 -4278 ($ (-850) (-568))) (-15 -4278 ($ (-850) (-568) (-850))) (-15 -4125 ((-1249) $ (-568))) (-15 -4125 ((-1249) $)) (-15 -3224 ((-634 (-1143)) $)) (-15 -3394 ((-634 (-1143)) $)) (-15 -1849 ($)) (-15 -1538 ((-634 (-1143)) $)) (-15 -3371 ((-634 (-1143)) $ (-634 (-1143)))) (-15 -2271 ((-634 (-1143)) $ (-634 (-1143)))) (-15 -1688 ((-634 (-1143)) $ (-634 (-1143))))))) (T -1176)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-850)) (-5 *1 (-1176)))) (-4278 (*1 *1 *2 *3) (-12 (-5 *2 (-850)) (-5 *3 (-568)) (-5 *1 (-1176)))) (-4278 (*1 *1 *2 *3 *2) (-12 (-5 *2 (-850)) (-5 *3 (-568)) (-5 *1 (-1176)))) (-4125 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-1176)))) (-4125 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-1176)))) (-3224 (*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176)))) (-3394 (*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176)))) (-1849 (*1 *1) (-5 *1 (-1176))) (-1538 (*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176)))) (-3371 (*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176)))) (-2271 (*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176)))) (-1688 (*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176))))) 
-(-13 (-1090) (-10 -8 (-15 -2745 ($ (-850))) (-15 -4278 ($ (-850) (-568))) (-15 -4278 ($ (-850) (-568) (-850))) (-15 -4125 ((-1249) $ (-568))) (-15 -4125 ((-1249) $)) (-15 -3224 ((-634 (-1143)) $)) (-15 -3394 ((-634 (-1143)) $)) (-15 -1849 ($)) (-15 -1538 ((-634 (-1143)) $)) (-15 -3371 ((-634 (-1143)) $ (-634 (-1143)))) (-15 -2271 ((-634 (-1143)) $ (-634 (-1143)))) (-15 -1688 ((-634 (-1143)) $ (-634 (-1143)))))) 
-((-2447 (((-121) $ $) NIL)) (-1406 (((-1143) $ (-1143)) 15) (((-1143) $) 14)) (-1705 (((-1143) $ (-1143)) 13)) (-2511 (($ $ (-1143)) NIL)) (-2457 (((-3 (-1143) "failed") $) 11)) (-3225 (((-1143) $) 8)) (-3861 (((-3 (-1143) "failed") $) 12)) (-3327 (((-1143) $) 9)) (-1798 (($ (-390)) NIL) (($ (-390) (-1143)) NIL)) (-3391 (((-390) $) NIL)) (-4487 (((-1143) $) NIL)) (-3305 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-4169 (((-1249) $) NIL)) (-4235 (((-121) $) 17)) (-2745 (((-850) $) NIL)) (-3637 (($ $) NIL)) (-1717 (((-121) $ $) NIL))) 
-(((-1177) (-13 (-366 (-390) (-1143)) (-10 -8 (-15 -1406 ((-1143) $ (-1143))) (-15 -1406 ((-1143) $)) (-15 -3225 ((-1143) $)) (-15 -2457 ((-3 (-1143) "failed") $)) (-15 -3861 ((-3 (-1143) "failed") $)) (-15 -4235 ((-121) $))))) (T -1177)) 
-((-1406 (*1 *2 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1177)))) (-1406 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-1177)))) (-3225 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-1177)))) (-2457 (*1 *2 *1) (|partial| -12 (-5 *2 (-1143)) (-5 *1 (-1177)))) (-3861 (*1 *2 *1) (|partial| -12 (-5 *2 (-1143)) (-5 *1 (-1177)))) (-4235 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1177))))) 
-(-13 (-366 (-390) (-1143)) (-10 -8 (-15 -1406 ((-1143) $ (-1143))) (-15 -1406 ((-1143) $)) (-15 -3225 ((-1143) $)) (-15 -2457 ((-3 (-1143) "failed") $)) (-15 -3861 ((-3 (-1143) "failed") $)) (-15 -4235 ((-121) $)))) 
-((-3662 (((-3 (-568) "failed") |#1|) 19)) (-1712 (((-3 (-568) "failed") |#1|) 13)) (-2923 (((-568) (-1143)) 28))) 
-(((-1178 |#1|) (-10 -7 (-15 -3662 ((-3 (-568) "failed") |#1|)) (-15 -1712 ((-3 (-568) "failed") |#1|)) (-15 -2923 ((-568) (-1143)))) (-1047)) (T -1178)) 
-((-2923 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-568)) (-5 *1 (-1178 *4)) (-4 *4 (-1047)))) (-1712 (*1 *2 *3) (|partial| -12 (-5 *2 (-568)) (-5 *1 (-1178 *3)) (-4 *3 (-1047)))) (-3662 (*1 *2 *3) (|partial| -12 (-5 *2 (-568)) (-5 *1 (-1178 *3)) (-4 *3 (-1047))))) 
-(-10 -7 (-15 -3662 ((-3 (-568) "failed") |#1|)) (-15 -1712 ((-3 (-568) "failed") |#1|)) (-15 -2923 ((-568) (-1143)))) 
-((-2079 (((-1121 (-215))) 8))) 
-(((-1179) (-10 -7 (-15 -2079 ((-1121 (-215)))))) (T -1179)) 
-((-2079 (*1 *2) (-12 (-5 *2 (-1121 (-215))) (-5 *1 (-1179))))) 
-(-10 -7 (-15 -2079 ((-1121 (-215))))) 
-((-1897 (($) 11)) (-2006 (($ $) 35)) (-1998 (($ $) 33)) (-1949 (($ $) 25)) (-2014 (($ $) 17)) (-4023 (($ $) 15)) (-2010 (($ $) 19)) (-1962 (($ $) 30)) (-2002 (($ $) 34)) (-1953 (($ $) 29))) 
-(((-1180 |#1|) (-10 -8 (-15 -1897 (|#1|)) (-15 -2006 (|#1| |#1|)) (-15 -1998 (|#1| |#1|)) (-15 -2014 (|#1| |#1|)) (-15 -4023 (|#1| |#1|)) (-15 -2010 (|#1| |#1|)) (-15 -2002 (|#1| |#1|)) (-15 -1949 (|#1| |#1|)) (-15 -1962 (|#1| |#1|)) (-15 -1953 (|#1| |#1|))) (-1181)) (T -1180)) 
-NIL 
-(-10 -8 (-15 -1897 (|#1|)) (-15 -2006 (|#1| |#1|)) (-15 -1998 (|#1| |#1|)) (-15 -2014 (|#1| |#1|)) (-15 -4023 (|#1| |#1|)) (-15 -2010 (|#1| |#1|)) (-15 -2002 (|#1| |#1|)) (-15 -1949 (|#1| |#1|)) (-15 -1962 (|#1| |#1|)) (-15 -1953 (|#1| |#1|))) 
-((-1982 (($ $) 26)) (-1933 (($ $) 11)) (-1974 (($ $) 27)) (-2786 (($ $) 10)) (-1990 (($ $) 28)) (-1941 (($ $) 9)) (-1897 (($) 16)) (-4416 (($ $) 19)) (-1892 (($ $) 18)) (-1994 (($ $) 29)) (-1945 (($ $) 8)) (-1986 (($ $) 30)) (-1937 (($ $) 7)) (-1978 (($ $) 31)) (-2790 (($ $) 6)) (-2006 (($ $) 20)) (-1958 (($ $) 32)) (-1998 (($ $) 21)) (-1949 (($ $) 33)) (-2014 (($ $) 22)) (-1966 (($ $) 34)) (-4023 (($ $) 23)) (-1970 (($ $) 35)) (-2010 (($ $) 24)) (-1962 (($ $) 36)) (-2002 (($ $) 25)) (-1953 (($ $) 37)) (** (($ $ $) 17))) 
+((-2438 (*1 *2 *1 *3 *2) (-12 (-4 *1 (-1172 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090)))) (-2988 (*1 *1) (-12 (-4 *1 (-1172 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090)))) (-2988 (*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3651 *3) (|:| -4085 *4)))) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *1 (-1172 *3 *4)))) (-2797 (*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *4 *4 *4)) (-4 *1 (-1172 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090))))) 
+(-13 (-605 |t#1| |t#2|) (-601 |t#1| |t#2|) (-10 -8 (-15 -2438 (|t#2| $ |t#1| |t#2|)) (-15 -2988 ($)) (-15 -2988 ($ (-634 (-2 (|:| -3651 |t#1|) (|:| -4085 |t#2|))))) (-15 -2797 ($ (-1 |t#2| |t#2| |t#2|) $ $)))) 
+(((-39) . T) ((-111 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-105) -2199 (|has| |#2| (-1090)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))) ((-608 (-850)) -2199 (|has| |#2| (-1090)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))) ((-154 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-609 (-541)) |has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-609 (-541))) ((-221 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-227 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-281 |#1| |#2|) . T) ((-283 |#1| |#2|) . T) ((-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) -12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))) ((-303 |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) ((-499 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) . T) ((-499 |#2|) . T) ((-601 |#1| |#2|) . T) ((-523 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-2 (|:| -3651 |#1|) (|:| -4085 |#2|))) -12 (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-303 (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)))) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))) ((-523 |#2| |#2|) -12 (|has| |#2| (-303 |#2|)) (|has| |#2| (-1090))) ((-605 |#1| |#2|) . T) ((-1090) -2199 (|has| |#2| (-1090)) (|has| (-2 (|:| -3651 |#1|) (|:| -4085 |#2|)) (-1090))) ((-1195) . T)) 
+((-3640 (((-121)) 24)) (-1376 (((-1249) (-1143)) 26)) (-2884 (((-121)) 36)) (-1553 (((-1249)) 34)) (-3881 (((-1249) (-1143) (-1143)) 25)) (-2181 (((-121)) 37)) (-1708 (((-1249) |#1| |#2|) 44)) (-1392 (((-1249)) 20)) (-3037 (((-3 |#2| "failed") |#1|) 42)) (-2949 (((-1249)) 35))) 
+(((-1173 |#1| |#2|) (-10 -7 (-15 -1392 ((-1249))) (-15 -3881 ((-1249) (-1143) (-1143))) (-15 -1376 ((-1249) (-1143))) (-15 -1553 ((-1249))) (-15 -2949 ((-1249))) (-15 -3640 ((-121))) (-15 -2884 ((-121))) (-15 -2181 ((-121))) (-15 -3037 ((-3 |#2| "failed") |#1|)) (-15 -1708 ((-1249) |#1| |#2|))) (-1090) (-1090)) (T -1173)) 
+((-1708 (*1 *2 *3 *4) (-12 (-5 *2 (-1249)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)))) (-3037 (*1 *2 *3) (|partial| -12 (-4 *2 (-1090)) (-5 *1 (-1173 *3 *2)) (-4 *3 (-1090)))) (-2181 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)))) (-2884 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)))) (-3640 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)))) (-2949 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)))) (-1553 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)))) (-1376 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1173 *4 *5)) (-4 *4 (-1090)) (-4 *5 (-1090)))) (-3881 (*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1173 *4 *5)) (-4 *4 (-1090)) (-4 *5 (-1090)))) (-1392 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090))))) 
+(-10 -7 (-15 -1392 ((-1249))) (-15 -3881 ((-1249) (-1143) (-1143))) (-15 -1376 ((-1249) (-1143))) (-15 -1553 ((-1249))) (-15 -2949 ((-1249))) (-15 -3640 ((-121))) (-15 -2884 ((-121))) (-15 -2181 ((-121))) (-15 -3037 ((-3 |#2| "failed") |#1|)) (-15 -1708 ((-1249) |#1| |#2|))) 
+((-2106 (((-1143) (-1143)) 18)) (-3067 (((-57) (-1143)) 21))) 
+(((-1174) (-10 -7 (-15 -3067 ((-57) (-1143))) (-15 -2106 ((-1143) (-1143))))) (T -1174)) 
+((-2106 (*1 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1174)))) (-3067 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-57)) (-5 *1 (-1174))))) 
+(-10 -7 (-15 -3067 ((-57) (-1143))) (-15 -2106 ((-1143) (-1143)))) 
+((-2747 (((-1176) |#1|) 11))) 
+(((-1175 |#1|) (-10 -7 (-15 -2747 ((-1176) |#1|))) (-1090)) (T -1175)) 
+((-2747 (*1 *2 *3) (-12 (-5 *2 (-1176)) (-5 *1 (-1175 *3)) (-4 *3 (-1090))))) 
+(-10 -7 (-15 -2747 ((-1176) |#1|))) 
+((-2449 (((-121) $ $) NIL)) (-3397 (((-634 (-1143)) $) 33)) (-3406 (((-634 (-1143)) $ (-634 (-1143))) 36)) (-3547 (((-634 (-1143)) $ (-634 (-1143))) 35)) (-1389 (((-634 (-1143)) $ (-634 (-1143))) 37)) (-4228 (((-634 (-1143)) $) 32)) (-1851 (($) 22)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-1907 (((-634 (-1143)) $) 34)) (-4127 (((-1249) $ (-568)) 29) (((-1249) $) 30)) (-4280 (($ (-850) (-568)) 26) (($ (-850) (-568) (-850)) NIL)) (-2747 (((-850) $) 39) (($ (-850)) 24)) (-1719 (((-121) $ $) NIL))) 
+(((-1176) (-13 (-1090) (-10 -8 (-15 -2747 ($ (-850))) (-15 -4280 ($ (-850) (-568))) (-15 -4280 ($ (-850) (-568) (-850))) (-15 -4127 ((-1249) $ (-568))) (-15 -4127 ((-1249) $)) (-15 -1907 ((-634 (-1143)) $)) (-15 -3397 ((-634 (-1143)) $)) (-15 -1851 ($)) (-15 -4228 ((-634 (-1143)) $)) (-15 -1389 ((-634 (-1143)) $ (-634 (-1143)))) (-15 -3406 ((-634 (-1143)) $ (-634 (-1143)))) (-15 -3547 ((-634 (-1143)) $ (-634 (-1143))))))) (T -1176)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-850)) (-5 *1 (-1176)))) (-4280 (*1 *1 *2 *3) (-12 (-5 *2 (-850)) (-5 *3 (-568)) (-5 *1 (-1176)))) (-4280 (*1 *1 *2 *3 *2) (-12 (-5 *2 (-850)) (-5 *3 (-568)) (-5 *1 (-1176)))) (-4127 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-1176)))) (-4127 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-1176)))) (-1907 (*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176)))) (-3397 (*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176)))) (-1851 (*1 *1) (-5 *1 (-1176))) (-4228 (*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176)))) (-1389 (*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176)))) (-3406 (*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176)))) (-3547 (*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176))))) 
+(-13 (-1090) (-10 -8 (-15 -2747 ($ (-850))) (-15 -4280 ($ (-850) (-568))) (-15 -4280 ($ (-850) (-568) (-850))) (-15 -4127 ((-1249) $ (-568))) (-15 -4127 ((-1249) $)) (-15 -1907 ((-634 (-1143)) $)) (-15 -3397 ((-634 (-1143)) $)) (-15 -1851 ($)) (-15 -4228 ((-634 (-1143)) $)) (-15 -1389 ((-634 (-1143)) $ (-634 (-1143)))) (-15 -3406 ((-634 (-1143)) $ (-634 (-1143)))) (-15 -3547 ((-634 (-1143)) $ (-634 (-1143)))))) 
+((-2449 (((-121) $ $) NIL)) (-2117 (((-1143) $ (-1143)) 15) (((-1143) $) 14)) (-3637 (((-1143) $ (-1143)) 13)) (-1672 (($ $ (-1143)) NIL)) (-2555 (((-3 (-1143) "failed") $) 11)) (-1911 (((-1143) $) 8)) (-1933 (((-3 (-1143) "failed") $) 12)) (-4379 (((-1143) $) 9)) (-2133 (($ (-390)) NIL) (($ (-390) (-1143)) NIL)) (-3393 (((-390) $) NIL)) (-1893 (((-1143) $) NIL)) (-4249 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-3919 (((-1249) $) NIL)) (-2821 (((-121) $) 17)) (-2747 (((-850) $) NIL)) (-3171 (($ $) NIL)) (-1719 (((-121) $ $) NIL))) 
+(((-1177) (-13 (-366 (-390) (-1143)) (-10 -8 (-15 -2117 ((-1143) $ (-1143))) (-15 -2117 ((-1143) $)) (-15 -1911 ((-1143) $)) (-15 -2555 ((-3 (-1143) "failed") $)) (-15 -1933 ((-3 (-1143) "failed") $)) (-15 -2821 ((-121) $))))) (T -1177)) 
+((-2117 (*1 *2 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1177)))) (-2117 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-1177)))) (-1911 (*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-1177)))) (-2555 (*1 *2 *1) (|partial| -12 (-5 *2 (-1143)) (-5 *1 (-1177)))) (-1933 (*1 *2 *1) (|partial| -12 (-5 *2 (-1143)) (-5 *1 (-1177)))) (-2821 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1177))))) 
+(-13 (-366 (-390) (-1143)) (-10 -8 (-15 -2117 ((-1143) $ (-1143))) (-15 -2117 ((-1143) $)) (-15 -1911 ((-1143) $)) (-15 -2555 ((-3 (-1143) "failed") $)) (-15 -1933 ((-3 (-1143) "failed") $)) (-15 -2821 ((-121) $)))) 
+((-3337 (((-3 (-568) "failed") |#1|) 19)) (-3681 (((-3 (-568) "failed") |#1|) 13)) (-2899 (((-568) (-1143)) 28))) 
+(((-1178 |#1|) (-10 -7 (-15 -3337 ((-3 (-568) "failed") |#1|)) (-15 -3681 ((-3 (-568) "failed") |#1|)) (-15 -2899 ((-568) (-1143)))) (-1047)) (T -1178)) 
+((-2899 (*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-568)) (-5 *1 (-1178 *4)) (-4 *4 (-1047)))) (-3681 (*1 *2 *3) (|partial| -12 (-5 *2 (-568)) (-5 *1 (-1178 *3)) (-4 *3 (-1047)))) (-3337 (*1 *2 *3) (|partial| -12 (-5 *2 (-568)) (-5 *1 (-1178 *3)) (-4 *3 (-1047))))) 
+(-10 -7 (-15 -3337 ((-3 (-568) "failed") |#1|)) (-15 -3681 ((-3 (-568) "failed") |#1|)) (-15 -2899 ((-568) (-1143)))) 
+((-3117 (((-1121 (-215))) 8))) 
+(((-1179) (-10 -7 (-15 -3117 ((-1121 (-215)))))) (T -1179)) 
+((-3117 (*1 *2) (-12 (-5 *2 (-1121 (-215))) (-5 *1 (-1179))))) 
+(-10 -7 (-15 -3117 ((-1121 (-215))))) 
+((-1899 (($) 11)) (-2008 (($ $) 35)) (-2000 (($ $) 33)) (-1951 (($ $) 25)) (-2016 (($ $) 17)) (-1439 (($ $) 15)) (-2012 (($ $) 19)) (-1964 (($ $) 30)) (-2004 (($ $) 34)) (-1955 (($ $) 29))) 
+(((-1180 |#1|) (-10 -8 (-15 -1899 (|#1|)) (-15 -2008 (|#1| |#1|)) (-15 -2000 (|#1| |#1|)) (-15 -2016 (|#1| |#1|)) (-15 -1439 (|#1| |#1|)) (-15 -2012 (|#1| |#1|)) (-15 -2004 (|#1| |#1|)) (-15 -1951 (|#1| |#1|)) (-15 -1964 (|#1| |#1|)) (-15 -1955 (|#1| |#1|))) (-1181)) (T -1180)) 
+NIL 
+(-10 -8 (-15 -1899 (|#1|)) (-15 -2008 (|#1| |#1|)) (-15 -2000 (|#1| |#1|)) (-15 -2016 (|#1| |#1|)) (-15 -1439 (|#1| |#1|)) (-15 -2012 (|#1| |#1|)) (-15 -2004 (|#1| |#1|)) (-15 -1951 (|#1| |#1|)) (-15 -1964 (|#1| |#1|)) (-15 -1955 (|#1| |#1|))) 
+((-1984 (($ $) 26)) (-1935 (($ $) 11)) (-1976 (($ $) 27)) (-2788 (($ $) 10)) (-1992 (($ $) 28)) (-1943 (($ $) 9)) (-1899 (($) 16)) (-4418 (($ $) 19)) (-1894 (($ $) 18)) (-1996 (($ $) 29)) (-1947 (($ $) 8)) (-1988 (($ $) 30)) (-1939 (($ $) 7)) (-1980 (($ $) 31)) (-2792 (($ $) 6)) (-2008 (($ $) 20)) (-1959 (($ $) 32)) (-2000 (($ $) 21)) (-1951 (($ $) 33)) (-2016 (($ $) 22)) (-1968 (($ $) 34)) (-1439 (($ $) 23)) (-1972 (($ $) 35)) (-2012 (($ $) 24)) (-1964 (($ $) 36)) (-2004 (($ $) 25)) (-1955 (($ $) 37)) (** (($ $ $) 17))) 
 (((-1181) (-1275)) (T -1181)) 
-((-1897 (*1 *1) (-4 *1 (-1181)))) 
-(-13 (-1184) (-98) (-502) (-40) (-279) (-10 -8 (-15 -1897 ($)))) 
+((-1899 (*1 *1) (-4 *1 (-1181)))) 
+(-13 (-1184) (-98) (-502) (-40) (-279) (-10 -8 (-15 -1899 ($)))) 
 (((-40) . T) ((-98) . T) ((-279) . T) ((-502) . T) ((-1184) . T)) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2850 ((|#1| $) 17)) (-3399 (($ |#1| (-634 $)) 23) (($ (-634 |#1|)) 27) (($ |#1|) 25)) (-2510 (((-121) $ (-763)) 46)) (-1659 ((|#1| $ |#1|) 14 (|has| $ (-6 -4520)))) (-2436 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) 13 (|has| $ (-6 -4520)))) (-2671 (($) NIL T CONST)) (-4360 (((-634 |#1|) $) 50 (|has| $ (-6 -4519)))) (-2287 (((-634 $) $) 41)) (-1700 (((-121) $ $) 32 (|has| |#1| (-1090)))) (-1737 (((-121) $ (-763)) 39)) (-1979 (((-634 |#1|) $) 51 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 49 (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3674 (($ (-1 |#1| |#1|) $) 24 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 22)) (-2166 (((-121) $ (-763)) 38)) (-2869 (((-634 |#1|) $) 36)) (-1651 (((-121) $) 35)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-1387 (((-121) (-1 (-121) |#1|) $) 48 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 73)) (-3084 (((-121) $) 9)) (-3248 (($) 10)) (-2779 ((|#1| $ "value") NIL)) (-4075 (((-568) $ $) 31)) (-1566 (((-634 $) $) 57)) (-3022 (((-121) $ $) 75)) (-2856 (((-634 $) $) 70)) (-4310 (($ $) 71)) (-3790 (((-121) $) 54)) (-4168 (((-763) (-1 (-121) |#1|) $) 20 (|has| $ (-6 -4519))) (((-763) |#1| $) 16 (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-3863 (($ $) 56)) (-2745 (((-850) $) 59 (|has| |#1| (-1090)))) (-4339 (((-634 $) $) 12)) (-3491 (((-121) $ $) 29 (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) 47 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 28 (|has| |#1| (-1090)))) (-1697 (((-763) $) 37 (|has| $ (-6 -4519))))) 
-(((-1182 |#1|) (-13 (-1010 |#1|) (-10 -8 (-6 -4519) (-6 -4520) (-15 -3399 ($ |#1| (-634 $))) (-15 -3399 ($ (-634 |#1|))) (-15 -3399 ($ |#1|)) (-15 -3790 ((-121) $)) (-15 -4310 ($ $)) (-15 -2856 ((-634 $) $)) (-15 -3022 ((-121) $ $)) (-15 -1566 ((-634 $) $)))) (-1090)) (T -1182)) 
-((-3790 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1182 *3)) (-4 *3 (-1090)))) (-3399 (*1 *1 *2 *3) (-12 (-5 *3 (-634 (-1182 *2))) (-5 *1 (-1182 *2)) (-4 *2 (-1090)))) (-3399 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-1182 *3)))) (-3399 (*1 *1 *2) (-12 (-5 *1 (-1182 *2)) (-4 *2 (-1090)))) (-4310 (*1 *1 *1) (-12 (-5 *1 (-1182 *2)) (-4 *2 (-1090)))) (-2856 (*1 *2 *1) (-12 (-5 *2 (-634 (-1182 *3))) (-5 *1 (-1182 *3)) (-4 *3 (-1090)))) (-3022 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1182 *3)) (-4 *3 (-1090)))) (-1566 (*1 *2 *1) (-12 (-5 *2 (-634 (-1182 *3))) (-5 *1 (-1182 *3)) (-4 *3 (-1090))))) 
-(-13 (-1010 |#1|) (-10 -8 (-6 -4519) (-6 -4520) (-15 -3399 ($ |#1| (-634 $))) (-15 -3399 ($ (-634 |#1|))) (-15 -3399 ($ |#1|)) (-15 -3790 ((-121) $)) (-15 -4310 ($ $)) (-15 -2856 ((-634 $) $)) (-15 -3022 ((-121) $ $)) (-15 -1566 ((-634 $) $)))) 
-((-1933 (($ $) 15)) (-1941 (($ $) 12)) (-1945 (($ $) 10)) (-1937 (($ $) 17))) 
-(((-1183 |#1|) (-10 -8 (-15 -1937 (|#1| |#1|)) (-15 -1945 (|#1| |#1|)) (-15 -1941 (|#1| |#1|)) (-15 -1933 (|#1| |#1|))) (-1184)) (T -1183)) 
-NIL 
-(-10 -8 (-15 -1937 (|#1| |#1|)) (-15 -1945 (|#1| |#1|)) (-15 -1941 (|#1| |#1|)) (-15 -1933 (|#1| |#1|))) 
-((-1933 (($ $) 11)) (-2786 (($ $) 10)) (-1941 (($ $) 9)) (-1945 (($ $) 8)) (-1937 (($ $) 7)) (-2790 (($ $) 6))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2852 ((|#1| $) 17)) (-1533 (($ |#1| (-634 $)) 23) (($ (-634 |#1|)) 27) (($ |#1|) 25)) (-1667 (((-121) $ (-763)) 46)) (-3370 ((|#1| $ |#1|) 14 (|has| $ (-6 -4522)))) (-2438 ((|#1| $ "value" |#1|) NIL (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) 13 (|has| $ (-6 -4522)))) (-4490 (($) NIL T CONST)) (-3317 (((-634 |#1|) $) 50 (|has| $ (-6 -4521)))) (-3534 (((-634 $) $) 41)) (-3606 (((-121) $ $) 32 (|has| |#1| (-1090)))) (-3791 (((-121) $ (-763)) 39)) (-4406 (((-634 |#1|) $) 51 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 49 (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-2253 (($ (-1 |#1| |#1|) $) 24 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 22)) (-3796 (((-121) $ (-763)) 38)) (-4081 (((-634 |#1|) $) 36)) (-3319 (((-121) $) 35)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3951 (((-121) (-1 (-121) |#1|) $) 48 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 73)) (-2436 (((-121) $) 9)) (-1990 (($) 10)) (-2781 ((|#1| $ "value") NIL)) (-1665 (((-568) $ $) 31)) (-4387 (((-634 $) $) 57)) (-3265 (((-121) $ $) 75)) (-4002 (((-634 $) $) 70)) (-3064 (($ $) 71)) (-2763 (((-121) $) 54)) (-4170 (((-763) (-1 (-121) |#1|) $) 20 (|has| $ (-6 -4521))) (((-763) |#1| $) 16 (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3865 (($ $) 56)) (-2747 (((-850) $) 59 (|has| |#1| (-1090)))) (-3180 (((-634 $) $) 12)) (-3873 (((-121) $ $) 29 (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) 47 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 28 (|has| |#1| (-1090)))) (-1699 (((-763) $) 37 (|has| $ (-6 -4521))))) 
+(((-1182 |#1|) (-13 (-1010 |#1|) (-10 -8 (-6 -4521) (-6 -4522) (-15 -1533 ($ |#1| (-634 $))) (-15 -1533 ($ (-634 |#1|))) (-15 -1533 ($ |#1|)) (-15 -2763 ((-121) $)) (-15 -3064 ($ $)) (-15 -4002 ((-634 $) $)) (-15 -3265 ((-121) $ $)) (-15 -4387 ((-634 $) $)))) (-1090)) (T -1182)) 
+((-2763 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1182 *3)) (-4 *3 (-1090)))) (-1533 (*1 *1 *2 *3) (-12 (-5 *3 (-634 (-1182 *2))) (-5 *1 (-1182 *2)) (-4 *2 (-1090)))) (-1533 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-1182 *3)))) (-1533 (*1 *1 *2) (-12 (-5 *1 (-1182 *2)) (-4 *2 (-1090)))) (-3064 (*1 *1 *1) (-12 (-5 *1 (-1182 *2)) (-4 *2 (-1090)))) (-4002 (*1 *2 *1) (-12 (-5 *2 (-634 (-1182 *3))) (-5 *1 (-1182 *3)) (-4 *3 (-1090)))) (-3265 (*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1182 *3)) (-4 *3 (-1090)))) (-4387 (*1 *2 *1) (-12 (-5 *2 (-634 (-1182 *3))) (-5 *1 (-1182 *3)) (-4 *3 (-1090))))) 
+(-13 (-1010 |#1|) (-10 -8 (-6 -4521) (-6 -4522) (-15 -1533 ($ |#1| (-634 $))) (-15 -1533 ($ (-634 |#1|))) (-15 -1533 ($ |#1|)) (-15 -2763 ((-121) $)) (-15 -3064 ($ $)) (-15 -4002 ((-634 $) $)) (-15 -3265 ((-121) $ $)) (-15 -4387 ((-634 $) $)))) 
+((-1935 (($ $) 15)) (-1943 (($ $) 12)) (-1947 (($ $) 10)) (-1939 (($ $) 17))) 
+(((-1183 |#1|) (-10 -8 (-15 -1939 (|#1| |#1|)) (-15 -1947 (|#1| |#1|)) (-15 -1943 (|#1| |#1|)) (-15 -1935 (|#1| |#1|))) (-1184)) (T -1183)) 
+NIL 
+(-10 -8 (-15 -1939 (|#1| |#1|)) (-15 -1947 (|#1| |#1|)) (-15 -1943 (|#1| |#1|)) (-15 -1935 (|#1| |#1|))) 
+((-1935 (($ $) 11)) (-2788 (($ $) 10)) (-1943 (($ $) 9)) (-1947 (($ $) 8)) (-1939 (($ $) 7)) (-2792 (($ $) 6))) 
 (((-1184) (-1275)) (T -1184)) 
-((-1933 (*1 *1 *1) (-4 *1 (-1184))) (-2786 (*1 *1 *1) (-4 *1 (-1184))) (-1941 (*1 *1 *1) (-4 *1 (-1184))) (-1945 (*1 *1 *1) (-4 *1 (-1184))) (-1937 (*1 *1 *1) (-4 *1 (-1184))) (-2790 (*1 *1 *1) (-4 *1 (-1184)))) 
-(-13 (-10 -8 (-15 -2790 ($ $)) (-15 -1937 ($ $)) (-15 -1945 ($ $)) (-15 -1941 ($ $)) (-15 -2786 ($ $)) (-15 -1933 ($ $)))) 
-((-3755 ((|#2| |#2|) 85)) (-2636 (((-121) |#2|) 25)) (-3857 ((|#2| |#2|) 29)) (-3866 ((|#2| |#2|) 31)) (-2818 ((|#2| |#2| (-1161)) 79) ((|#2| |#2|) 80)) (-3145 (((-169 |#2|) |#2|) 27)) (-2582 ((|#2| |#2| (-1161)) 81) ((|#2| |#2|) 82))) 
-(((-1185 |#1| |#2|) (-10 -7 (-15 -2818 (|#2| |#2|)) (-15 -2818 (|#2| |#2| (-1161))) (-15 -2582 (|#2| |#2|)) (-15 -2582 (|#2| |#2| (-1161))) (-15 -3755 (|#2| |#2|)) (-15 -3857 (|#2| |#2|)) (-15 -3866 (|#2| |#2|)) (-15 -2636 ((-121) |#2|)) (-15 -3145 ((-169 |#2|) |#2|))) (-13 (-453) (-842) (-1037 (-568)) (-630 (-568))) (-13 (-27) (-1181) (-432 |#1|))) (T -1185)) 
-((-3145 (*1 *2 *3) (-12 (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-169 *3)) (-5 *1 (-1185 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4))))) (-2636 (*1 *2 *3) (-12 (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-121)) (-5 *1 (-1185 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4))))) (-3866 (*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3))))) (-3857 (*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3))))) (-3755 (*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3))))) (-2582 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4))))) (-2582 (*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3))))) (-2818 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4))))) (-2818 (*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3)))))) 
-(-10 -7 (-15 -2818 (|#2| |#2|)) (-15 -2818 (|#2| |#2| (-1161))) (-15 -2582 (|#2| |#2|)) (-15 -2582 (|#2| |#2| (-1161))) (-15 -3755 (|#2| |#2|)) (-15 -3857 (|#2| |#2|)) (-15 -3866 (|#2| |#2|)) (-15 -2636 ((-121) |#2|)) (-15 -3145 ((-169 |#2|) |#2|))) 
-((-2149 ((|#4| |#4| |#1|) 27)) (-2300 ((|#4| |#4| |#1|) 28))) 
-(((-1186 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2149 (|#4| |#4| |#1|)) (-15 -2300 (|#4| |#4| |#1|))) (-558) (-375 |#1|) (-375 |#1|) (-677 |#1| |#2| |#3|)) (T -1186)) 
-((-2300 (*1 *2 *2 *3) (-12 (-4 *3 (-558)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-1186 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) (-2149 (*1 *2 *2 *3) (-12 (-4 *3 (-558)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-1186 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5))))) 
-(-10 -7 (-15 -2149 (|#4| |#4| |#1|)) (-15 -2300 (|#4| |#4| |#1|))) 
-((-3706 ((|#2| |#2|) 132)) (-2561 ((|#2| |#2|) 129)) (-3854 ((|#2| |#2|) 120)) (-2594 ((|#2| |#2|) 117)) (-2044 ((|#2| |#2|) 125)) (-2716 ((|#2| |#2|) 113)) (-1710 ((|#2| |#2|) 42)) (-2237 ((|#2| |#2|) 93)) (-4352 ((|#2| |#2|) 73)) (-2240 ((|#2| |#2|) 127)) (-3619 ((|#2| |#2|) 115)) (-2951 ((|#2| |#2|) 137)) (-4139 ((|#2| |#2|) 135)) (-3505 ((|#2| |#2|) 136)) (-1317 ((|#2| |#2|) 134)) (-1571 ((|#2| |#2|) 146)) (-4163 ((|#2| |#2|) 30 (-12 (|has| |#2| (-609 (-887 |#1|))) (|has| |#2| (-881 |#1|)) (|has| |#1| (-609 (-887 |#1|))) (|has| |#1| (-881 |#1|))))) (-4113 ((|#2| |#2|) 74)) (-3897 ((|#2| |#2|) 138)) (-2789 ((|#2| |#2|) 139)) (-2435 ((|#2| |#2|) 126)) (-4359 ((|#2| |#2|) 114)) (-3008 ((|#2| |#2|) 133)) (-2481 ((|#2| |#2|) 131)) (-3133 ((|#2| |#2|) 121)) (-3528 ((|#2| |#2|) 119)) (-3019 ((|#2| |#2|) 123)) (-1661 ((|#2| |#2|) 111))) 
-(((-1187 |#1| |#2|) (-10 -7 (-15 -2789 (|#2| |#2|)) (-15 -4352 (|#2| |#2|)) (-15 -1571 (|#2| |#2|)) (-15 -2237 (|#2| |#2|)) (-15 -1710 (|#2| |#2|)) (-15 -4113 (|#2| |#2|)) (-15 -3897 (|#2| |#2|)) (-15 -1661 (|#2| |#2|)) (-15 -3019 (|#2| |#2|)) (-15 -3133 (|#2| |#2|)) (-15 -3008 (|#2| |#2|)) (-15 -4359 (|#2| |#2|)) (-15 -2435 (|#2| |#2|)) (-15 -3619 (|#2| |#2|)) (-15 -2240 (|#2| |#2|)) (-15 -2716 (|#2| |#2|)) (-15 -2044 (|#2| |#2|)) (-15 -3854 (|#2| |#2|)) (-15 -3706 (|#2| |#2|)) (-15 -2594 (|#2| |#2|)) (-15 -2561 (|#2| |#2|)) (-15 -3528 (|#2| |#2|)) (-15 -2481 (|#2| |#2|)) (-15 -1317 (|#2| |#2|)) (-15 -4139 (|#2| |#2|)) (-15 -3505 (|#2| |#2|)) (-15 -2951 (|#2| |#2|)) (IF (|has| |#1| (-881 |#1|)) (IF (|has| |#1| (-609 (-887 |#1|))) (IF (|has| |#2| (-609 (-887 |#1|))) (IF (|has| |#2| (-881 |#1|)) (-15 -4163 (|#2| |#2|)) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) (-13 (-842) (-453)) (-13 (-432 |#1|) (-1181))) (T -1187)) 
-((-4163 (*1 *2 *2) (-12 (-4 *3 (-609 (-887 *3))) (-4 *3 (-881 *3)) (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-609 (-887 *3))) (-4 *2 (-881 *3)) (-4 *2 (-13 (-432 *3) (-1181))))) (-2951 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-3505 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-4139 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-1317 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-2481 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-3528 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-2561 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-2594 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-3706 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-3854 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-2044 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-2716 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-2240 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-3619 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-2435 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-4359 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-3008 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-3133 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-3019 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-1661 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-3897 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-4113 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-1710 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-2237 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-1571 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-4352 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-2789 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(-10 -7 (-15 -2789 (|#2| |#2|)) (-15 -4352 (|#2| |#2|)) (-15 -1571 (|#2| |#2|)) (-15 -2237 (|#2| |#2|)) (-15 -1710 (|#2| |#2|)) (-15 -4113 (|#2| |#2|)) (-15 -3897 (|#2| |#2|)) (-15 -1661 (|#2| |#2|)) (-15 -3019 (|#2| |#2|)) (-15 -3133 (|#2| |#2|)) (-15 -3008 (|#2| |#2|)) (-15 -4359 (|#2| |#2|)) (-15 -2435 (|#2| |#2|)) (-15 -3619 (|#2| |#2|)) (-15 -2240 (|#2| |#2|)) (-15 -2716 (|#2| |#2|)) (-15 -2044 (|#2| |#2|)) (-15 -3854 (|#2| |#2|)) (-15 -3706 (|#2| |#2|)) (-15 -2594 (|#2| |#2|)) (-15 -2561 (|#2| |#2|)) (-15 -3528 (|#2| |#2|)) (-15 -2481 (|#2| |#2|)) (-15 -1317 (|#2| |#2|)) (-15 -4139 (|#2| |#2|)) (-15 -3505 (|#2| |#2|)) (-15 -2951 (|#2| |#2|)) (IF (|has| |#1| (-881 |#1|)) (IF (|has| |#1| (-609 (-887 |#1|))) (IF (|has| |#2| (-609 (-887 |#1|))) (IF (|has| |#2| (-881 |#1|)) (-15 -4163 (|#2| |#2|)) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) 
-((-3300 (((-121) |#5| $) 59) (((-121) $) 101)) (-2819 ((|#5| |#5| $) 74)) (-2801 (($ (-1 (-121) |#5|) $) NIL) (((-3 |#5| "failed") $ |#4|) 118)) (-4275 (((-634 |#5|) (-634 |#5|) $ (-1 |#5| |#5| |#5|) (-1 (-121) |#5| |#5|)) 72)) (-3666 (((-3 $ "failed") (-634 |#5|)) 125)) (-3935 (((-3 $ "failed") $) 111)) (-2062 ((|#5| |#5| $) 93)) (-1281 (((-121) |#5| $ (-1 (-121) |#5| |#5|)) 30)) (-4079 ((|#5| |#5| $) 97)) (-3092 ((|#5| (-1 |#5| |#5| |#5|) $ |#5| |#5|) NIL) ((|#5| (-1 |#5| |#5| |#5|) $ |#5|) NIL) ((|#5| (-1 |#5| |#5| |#5|) $) NIL) ((|#5| |#5| $ (-1 |#5| |#5| |#5|) (-1 (-121) |#5| |#5|)) 68)) (-3635 (((-2 (|:| -4092 (-634 |#5|)) (|:| -1798 (-634 |#5|))) $) 54)) (-1362 (((-121) |#5| $) 57) (((-121) $) 102)) (-2356 ((|#4| $) 107)) (-4162 (((-3 |#5| "failed") $) 109)) (-1377 (((-634 |#5|) $) 48)) (-1415 (((-121) |#5| $) 66) (((-121) $) 106)) (-2682 ((|#5| |#5| $) 80)) (-2644 (((-121) $ $) 26)) (-4347 (((-121) |#5| $) 62) (((-121) $) 104)) (-4025 ((|#5| |#5| $) 77)) (-3876 (((-3 |#5| "failed") $) 108)) (-1807 (($ $ |#5|) 126)) (-3206 (((-763) $) 51)) (-4287 (($ (-634 |#5|)) 123)) (-1290 (($ $ |#4|) 121)) (-3732 (($ $ |#4|) 120)) (-1567 (($ $) 119)) (-2745 (((-850) $) NIL) (((-634 |#5|) $) 112)) (-1878 (((-763) $) 129)) (-3556 (((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 |#5|))) "failed") (-634 |#5|) (-1 (-121) |#5| |#5|)) 42) (((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 |#5|))) "failed") (-634 |#5|) (-1 (-121) |#5|) (-1 (-121) |#5| |#5|)) 44)) (-3292 (((-121) $ (-1 (-121) |#5| (-634 |#5|))) 99)) (-2739 (((-634 |#4|) $) 114)) (-4390 (((-121) |#4| $) 117)) (-1717 (((-121) $ $) 19))) 
-(((-1188 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 -1878 ((-763) |#1|)) (-15 -1807 (|#1| |#1| |#5|)) (-15 -2801 ((-3 |#5| "failed") |#1| |#4|)) (-15 -4390 ((-121) |#4| |#1|)) (-15 -2739 ((-634 |#4|) |#1|)) (-15 -3935 ((-3 |#1| "failed") |#1|)) (-15 -4162 ((-3 |#5| "failed") |#1|)) (-15 -3876 ((-3 |#5| "failed") |#1|)) (-15 -4079 (|#5| |#5| |#1|)) (-15 -1567 (|#1| |#1|)) (-15 -2062 (|#5| |#5| |#1|)) (-15 -2682 (|#5| |#5| |#1|)) (-15 -4025 (|#5| |#5| |#1|)) (-15 -2819 (|#5| |#5| |#1|)) (-15 -4275 ((-634 |#5|) (-634 |#5|) |#1| (-1 |#5| |#5| |#5|) (-1 (-121) |#5| |#5|))) (-15 -3092 (|#5| |#5| |#1| (-1 |#5| |#5| |#5|) (-1 (-121) |#5| |#5|))) (-15 -1415 ((-121) |#1|)) (-15 -4347 ((-121) |#1|)) (-15 -3300 ((-121) |#1|)) (-15 -3292 ((-121) |#1| (-1 (-121) |#5| (-634 |#5|)))) (-15 -1415 ((-121) |#5| |#1|)) (-15 -4347 ((-121) |#5| |#1|)) (-15 -3300 ((-121) |#5| |#1|)) (-15 -1281 ((-121) |#5| |#1| (-1 (-121) |#5| |#5|))) (-15 -1362 ((-121) |#1|)) (-15 -1362 ((-121) |#5| |#1|)) (-15 -3635 ((-2 (|:| -4092 (-634 |#5|)) (|:| -1798 (-634 |#5|))) |#1|)) (-15 -3206 ((-763) |#1|)) (-15 -1377 ((-634 |#5|) |#1|)) (-15 -3556 ((-3 (-2 (|:| |bas| |#1|) (|:| -2616 (-634 |#5|))) "failed") (-634 |#5|) (-1 (-121) |#5|) (-1 (-121) |#5| |#5|))) (-15 -3556 ((-3 (-2 (|:| |bas| |#1|) (|:| -2616 (-634 |#5|))) "failed") (-634 |#5|) (-1 (-121) |#5| |#5|))) (-15 -2644 ((-121) |#1| |#1|)) (-15 -1290 (|#1| |#1| |#4|)) (-15 -3732 (|#1| |#1| |#4|)) (-15 -2356 (|#4| |#1|)) (-15 -3666 ((-3 |#1| "failed") (-634 |#5|))) (-15 -2745 ((-634 |#5|) |#1|)) (-15 -4287 (|#1| (-634 |#5|))) (-15 -3092 (|#5| (-1 |#5| |#5| |#5|) |#1|)) (-15 -3092 (|#5| (-1 |#5| |#5| |#5|) |#1| |#5|)) (-15 -2801 (|#1| (-1 (-121) |#5|) |#1|)) (-15 -3092 (|#5| (-1 |#5| |#5| |#5|) |#1| |#5| |#5|)) (-15 -2745 ((-850) |#1|)) (-15 -1717 ((-121) |#1| |#1|))) (-1189 |#2| |#3| |#4| |#5|) (-558) (-788) (-842) (-1061 |#2| |#3| |#4|)) (T -1188)) 
-NIL 
-(-10 -8 (-15 -1878 ((-763) |#1|)) (-15 -1807 (|#1| |#1| |#5|)) (-15 -2801 ((-3 |#5| "failed") |#1| |#4|)) (-15 -4390 ((-121) |#4| |#1|)) (-15 -2739 ((-634 |#4|) |#1|)) (-15 -3935 ((-3 |#1| "failed") |#1|)) (-15 -4162 ((-3 |#5| "failed") |#1|)) (-15 -3876 ((-3 |#5| "failed") |#1|)) (-15 -4079 (|#5| |#5| |#1|)) (-15 -1567 (|#1| |#1|)) (-15 -2062 (|#5| |#5| |#1|)) (-15 -2682 (|#5| |#5| |#1|)) (-15 -4025 (|#5| |#5| |#1|)) (-15 -2819 (|#5| |#5| |#1|)) (-15 -4275 ((-634 |#5|) (-634 |#5|) |#1| (-1 |#5| |#5| |#5|) (-1 (-121) |#5| |#5|))) (-15 -3092 (|#5| |#5| |#1| (-1 |#5| |#5| |#5|) (-1 (-121) |#5| |#5|))) (-15 -1415 ((-121) |#1|)) (-15 -4347 ((-121) |#1|)) (-15 -3300 ((-121) |#1|)) (-15 -3292 ((-121) |#1| (-1 (-121) |#5| (-634 |#5|)))) (-15 -1415 ((-121) |#5| |#1|)) (-15 -4347 ((-121) |#5| |#1|)) (-15 -3300 ((-121) |#5| |#1|)) (-15 -1281 ((-121) |#5| |#1| (-1 (-121) |#5| |#5|))) (-15 -1362 ((-121) |#1|)) (-15 -1362 ((-121) |#5| |#1|)) (-15 -3635 ((-2 (|:| -4092 (-634 |#5|)) (|:| -1798 (-634 |#5|))) |#1|)) (-15 -3206 ((-763) |#1|)) (-15 -1377 ((-634 |#5|) |#1|)) (-15 -3556 ((-3 (-2 (|:| |bas| |#1|) (|:| -2616 (-634 |#5|))) "failed") (-634 |#5|) (-1 (-121) |#5|) (-1 (-121) |#5| |#5|))) (-15 -3556 ((-3 (-2 (|:| |bas| |#1|) (|:| -2616 (-634 |#5|))) "failed") (-634 |#5|) (-1 (-121) |#5| |#5|))) (-15 -2644 ((-121) |#1| |#1|)) (-15 -1290 (|#1| |#1| |#4|)) (-15 -3732 (|#1| |#1| |#4|)) (-15 -2356 (|#4| |#1|)) (-15 -3666 ((-3 |#1| "failed") (-634 |#5|))) (-15 -2745 ((-634 |#5|) |#1|)) (-15 -4287 (|#1| (-634 |#5|))) (-15 -3092 (|#5| (-1 |#5| |#5| |#5|) |#1|)) (-15 -3092 (|#5| (-1 |#5| |#5| |#5|) |#1| |#5|)) (-15 -2801 (|#1| (-1 (-121) |#5|) |#1|)) (-15 -3092 (|#5| (-1 |#5| |#5| |#5|) |#1| |#5| |#5|)) (-15 -2745 ((-850) |#1|)) (-15 -1717 ((-121) |#1| |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2387 (((-634 (-2 (|:| -4092 $) (|:| -1798 (-634 |#4|)))) (-634 |#4|)) 78)) (-2415 (((-634 $) (-634 |#4|)) 79)) (-2055 (((-634 |#3|) $) 32)) (-4211 (((-121) $) 25)) (-3824 (((-121) $) 16 (|has| |#1| (-558)))) (-3300 (((-121) |#4| $) 94) (((-121) $) 90)) (-2819 ((|#4| |#4| $) 85)) (-3644 (((-2 (|:| |under| $) (|:| -1519 $) (|:| |upper| $)) $ |#3|) 26)) (-2510 (((-121) $ (-763)) 43)) (-2801 (($ (-1 (-121) |#4|) $) 64 (|has| $ (-6 -4519))) (((-3 |#4| "failed") $ |#3|) 72)) (-2671 (($) 44 T CONST)) (-1565 (((-121) $) 21 (|has| |#1| (-558)))) (-3846 (((-121) $ $) 23 (|has| |#1| (-558)))) (-3106 (((-121) $ $) 22 (|has| |#1| (-558)))) (-3695 (((-121) $) 24 (|has| |#1| (-558)))) (-4275 (((-634 |#4|) (-634 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 86)) (-2355 (((-634 |#4|) (-634 |#4|) $) 17 (|has| |#1| (-558)))) (-2492 (((-634 |#4|) (-634 |#4|) $) 18 (|has| |#1| (-558)))) (-3666 (((-3 $ "failed") (-634 |#4|)) 35)) (-2854 (($ (-634 |#4|)) 34)) (-3935 (((-3 $ "failed") $) 75)) (-2062 ((|#4| |#4| $) 82)) (-3924 (($ $) 67 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519))))) (-4328 (($ |#4| $) 66 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) |#4|) $) 63 (|has| $ (-6 -4519)))) (-1500 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-558)))) (-1281 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) 95)) (-4079 ((|#4| |#4| $) 80)) (-3092 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4519))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4519))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 87)) (-3635 (((-2 (|:| -4092 (-634 |#4|)) (|:| -1798 (-634 |#4|))) $) 98)) (-4360 (((-634 |#4|) $) 51 (|has| $ (-6 -4519)))) (-1362 (((-121) |#4| $) 97) (((-121) $) 96)) (-2356 ((|#3| $) 33)) (-1737 (((-121) $ (-763)) 42)) (-1979 (((-634 |#4|) $) 52 (|has| $ (-6 -4519)))) (-3109 (((-121) |#4| $) 54 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#4| |#4|) $) 46)) (-1432 (((-634 |#3|) $) 31)) (-3392 (((-121) |#3| $) 30)) (-2166 (((-121) $ (-763)) 41)) (-4487 (((-1143) $) 9)) (-4162 (((-3 |#4| "failed") $) 76)) (-1377 (((-634 |#4|) $) 100)) (-1415 (((-121) |#4| $) 92) (((-121) $) 88)) (-2682 ((|#4| |#4| $) 83)) (-2644 (((-121) $ $) 103)) (-2705 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-558)))) (-4347 (((-121) |#4| $) 93) (((-121) $) 89)) (-4025 ((|#4| |#4| $) 84)) (-4022 (((-1108) $) 10)) (-3876 (((-3 |#4| "failed") $) 77)) (-3775 (((-3 |#4| "failed") (-1 (-121) |#4|) $) 60)) (-1665 (((-3 $ "failed") $ |#4|) 71)) (-1807 (($ $ |#4|) 70)) (-1387 (((-121) (-1 (-121) |#4|) $) 49 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 |#4|) (-634 |#4|)) 58 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) 56 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 (-288 |#4|))) 55 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-3171 (((-121) $ $) 37)) (-3084 (((-121) $) 40)) (-3248 (($) 39)) (-3206 (((-763) $) 99)) (-4168 (((-763) |#4| $) 53 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4519)))) (((-763) (-1 (-121) |#4|) $) 50 (|has| $ (-6 -4519)))) (-3863 (($ $) 38)) (-4278 (((-541) $) 68 (|has| |#4| (-609 (-541))))) (-4287 (($ (-634 |#4|)) 59)) (-1290 (($ $ |#3|) 27)) (-3732 (($ $ |#3|) 29)) (-1567 (($ $) 81)) (-3944 (($ $ |#3|) 28)) (-2745 (((-850) $) 11) (((-634 |#4|) $) 36)) (-1878 (((-763) $) 69 (|has| |#3| (-370)))) (-3556 (((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4| |#4|)) 102) (((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) 101)) (-3292 (((-121) $ (-1 (-121) |#4| (-634 |#4|))) 91)) (-1319 (((-121) (-1 (-121) |#4|) $) 48 (|has| $ (-6 -4519)))) (-2739 (((-634 |#3|) $) 74)) (-4390 (((-121) |#3| $) 73)) (-1717 (((-121) $ $) 6)) (-1697 (((-763) $) 45 (|has| $ (-6 -4519))))) 
+((-1935 (*1 *1 *1) (-4 *1 (-1184))) (-2788 (*1 *1 *1) (-4 *1 (-1184))) (-1943 (*1 *1 *1) (-4 *1 (-1184))) (-1947 (*1 *1 *1) (-4 *1 (-1184))) (-1939 (*1 *1 *1) (-4 *1 (-1184))) (-2792 (*1 *1 *1) (-4 *1 (-1184)))) 
+(-13 (-10 -8 (-15 -2792 ($ $)) (-15 -1939 ($ $)) (-15 -1947 ($ $)) (-15 -1943 ($ $)) (-15 -2788 ($ $)) (-15 -1935 ($ $)))) 
+((-2634 ((|#2| |#2|) 85)) (-4293 (((-121) |#2|) 25)) (-3859 ((|#2| |#2|) 29)) (-3868 ((|#2| |#2|) 31)) (-3758 ((|#2| |#2| (-1161)) 79) ((|#2| |#2|) 80)) (-2732 (((-169 |#2|) |#2|) 27)) (-2009 ((|#2| |#2| (-1161)) 81) ((|#2| |#2|) 82))) 
+(((-1185 |#1| |#2|) (-10 -7 (-15 -3758 (|#2| |#2|)) (-15 -3758 (|#2| |#2| (-1161))) (-15 -2009 (|#2| |#2|)) (-15 -2009 (|#2| |#2| (-1161))) (-15 -2634 (|#2| |#2|)) (-15 -3859 (|#2| |#2|)) (-15 -3868 (|#2| |#2|)) (-15 -4293 ((-121) |#2|)) (-15 -2732 ((-169 |#2|) |#2|))) (-13 (-453) (-842) (-1037 (-568)) (-630 (-568))) (-13 (-27) (-1181) (-432 |#1|))) (T -1185)) 
+((-2732 (*1 *2 *3) (-12 (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-169 *3)) (-5 *1 (-1185 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4))))) (-4293 (*1 *2 *3) (-12 (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-121)) (-5 *1 (-1185 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4))))) (-3868 (*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3))))) (-3859 (*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3))))) (-2634 (*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3))))) (-2009 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4))))) (-2009 (*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3))))) (-3758 (*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4))))) (-3758 (*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3)))))) 
+(-10 -7 (-15 -3758 (|#2| |#2|)) (-15 -3758 (|#2| |#2| (-1161))) (-15 -2009 (|#2| |#2|)) (-15 -2009 (|#2| |#2| (-1161))) (-15 -2634 (|#2| |#2|)) (-15 -3859 (|#2| |#2|)) (-15 -3868 (|#2| |#2|)) (-15 -4293 ((-121) |#2|)) (-15 -2732 ((-169 |#2|) |#2|))) 
+((-3559 ((|#4| |#4| |#1|) 27)) (-3630 ((|#4| |#4| |#1|) 28))) 
+(((-1186 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3559 (|#4| |#4| |#1|)) (-15 -3630 (|#4| |#4| |#1|))) (-558) (-375 |#1|) (-375 |#1|) (-677 |#1| |#2| |#3|)) (T -1186)) 
+((-3630 (*1 *2 *2 *3) (-12 (-4 *3 (-558)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-1186 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) (-3559 (*1 *2 *2 *3) (-12 (-4 *3 (-558)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-1186 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5))))) 
+(-10 -7 (-15 -3559 (|#4| |#4| |#1|)) (-15 -3630 (|#4| |#4| |#1|))) 
+((-2396 ((|#2| |#2|) 132)) (-1927 ((|#2| |#2|) 129)) (-1908 ((|#2| |#2|) 120)) (-2050 ((|#2| |#2|) 117)) (-1493 ((|#2| |#2|) 125)) (-1512 ((|#2| |#2|) 113)) (-3663 ((|#2| |#2|) 42)) (-2720 ((|#2| |#2|) 93)) (-3267 ((|#2| |#2|) 73)) (-2738 ((|#2| |#2|) 127)) (-3079 ((|#2| |#2|) 115)) (-2986 ((|#2| |#2|) 137)) (-3752 ((|#2| |#2|) 135)) (-3947 ((|#2| |#2|) 136)) (-3420 ((|#2| |#2|) 134)) (-4416 ((|#2| |#2|) 146)) (-3887 ((|#2| |#2|) 30 (-12 (|has| |#2| (-609 (-887 |#1|))) (|has| |#2| (-881 |#1|)) (|has| |#1| (-609 (-887 |#1|))) (|has| |#1| (-881 |#1|))))) (-3610 ((|#2| |#2|) 74)) (-2056 ((|#2| |#2|) 138)) (-2791 ((|#2| |#2|) 139)) (-2446 ((|#2| |#2|) 126)) (-3309 ((|#2| |#2|) 114)) (-3178 ((|#2| |#2|) 133)) (-2676 ((|#2| |#2|) 131)) (-2683 ((|#2| |#2|) 121)) (-4111 ((|#2| |#2|) 119)) (-3249 ((|#2| |#2|) 123)) (-3388 ((|#2| |#2|) 111))) 
+(((-1187 |#1| |#2|) (-10 -7 (-15 -2791 (|#2| |#2|)) (-15 -3267 (|#2| |#2|)) (-15 -4416 (|#2| |#2|)) (-15 -2720 (|#2| |#2|)) (-15 -3663 (|#2| |#2|)) (-15 -3610 (|#2| |#2|)) (-15 -2056 (|#2| |#2|)) (-15 -3388 (|#2| |#2|)) (-15 -3249 (|#2| |#2|)) (-15 -2683 (|#2| |#2|)) (-15 -3178 (|#2| |#2|)) (-15 -3309 (|#2| |#2|)) (-15 -2446 (|#2| |#2|)) (-15 -3079 (|#2| |#2|)) (-15 -2738 (|#2| |#2|)) (-15 -1512 (|#2| |#2|)) (-15 -1493 (|#2| |#2|)) (-15 -1908 (|#2| |#2|)) (-15 -2396 (|#2| |#2|)) (-15 -2050 (|#2| |#2|)) (-15 -1927 (|#2| |#2|)) (-15 -4111 (|#2| |#2|)) (-15 -2676 (|#2| |#2|)) (-15 -3420 (|#2| |#2|)) (-15 -3752 (|#2| |#2|)) (-15 -3947 (|#2| |#2|)) (-15 -2986 (|#2| |#2|)) (IF (|has| |#1| (-881 |#1|)) (IF (|has| |#1| (-609 (-887 |#1|))) (IF (|has| |#2| (-609 (-887 |#1|))) (IF (|has| |#2| (-881 |#1|)) (-15 -3887 (|#2| |#2|)) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) (-13 (-842) (-453)) (-13 (-432 |#1|) (-1181))) (T -1187)) 
+((-3887 (*1 *2 *2) (-12 (-4 *3 (-609 (-887 *3))) (-4 *3 (-881 *3)) (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-609 (-887 *3))) (-4 *2 (-881 *3)) (-4 *2 (-13 (-432 *3) (-1181))))) (-2986 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-3947 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-3752 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-3420 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-2676 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-4111 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-1927 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-2050 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-2396 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-1908 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-1493 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-1512 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-2738 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-3079 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-2446 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-3309 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-3178 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-2683 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-3249 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-3388 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-2056 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-3610 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-3663 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-2720 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-4416 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-3267 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) (-2791 (*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(-10 -7 (-15 -2791 (|#2| |#2|)) (-15 -3267 (|#2| |#2|)) (-15 -4416 (|#2| |#2|)) (-15 -2720 (|#2| |#2|)) (-15 -3663 (|#2| |#2|)) (-15 -3610 (|#2| |#2|)) (-15 -2056 (|#2| |#2|)) (-15 -3388 (|#2| |#2|)) (-15 -3249 (|#2| |#2|)) (-15 -2683 (|#2| |#2|)) (-15 -3178 (|#2| |#2|)) (-15 -3309 (|#2| |#2|)) (-15 -2446 (|#2| |#2|)) (-15 -3079 (|#2| |#2|)) (-15 -2738 (|#2| |#2|)) (-15 -1512 (|#2| |#2|)) (-15 -1493 (|#2| |#2|)) (-15 -1908 (|#2| |#2|)) (-15 -2396 (|#2| |#2|)) (-15 -2050 (|#2| |#2|)) (-15 -1927 (|#2| |#2|)) (-15 -4111 (|#2| |#2|)) (-15 -2676 (|#2| |#2|)) (-15 -3420 (|#2| |#2|)) (-15 -3752 (|#2| |#2|)) (-15 -3947 (|#2| |#2|)) (-15 -2986 (|#2| |#2|)) (IF (|has| |#1| (-881 |#1|)) (IF (|has| |#1| (-609 (-887 |#1|))) (IF (|has| |#2| (-609 (-887 |#1|))) (IF (|has| |#2| (-881 |#1|)) (-15 -3887 (|#2| |#2|)) |noBranch|) |noBranch|) |noBranch|) |noBranch|)) 
+((-4231 (((-121) |#5| $) 59) (((-121) $) 101)) (-3767 ((|#5| |#5| $) 74)) (-2803 (($ (-1 (-121) |#5|) $) NIL) (((-3 |#5| "failed") $ |#4|) 118)) (-2941 (((-634 |#5|) (-634 |#5|) $ (-1 |#5| |#5| |#5|) (-1 (-121) |#5| |#5|)) 72)) (-3668 (((-3 $ "failed") (-634 |#5|)) 125)) (-3936 (((-3 $ "failed") $) 111)) (-3255 ((|#5| |#5| $) 93)) (-1359 (((-121) |#5| $ (-1 (-121) |#5| |#5|)) 30)) (-3434 ((|#5| |#5| $) 97)) (-3094 ((|#5| (-1 |#5| |#5| |#5|) $ |#5| |#5|) NIL) ((|#5| (-1 |#5| |#5| |#5|) $ |#5|) NIL) ((|#5| (-1 |#5| |#5| |#5|) $) NIL) ((|#5| |#5| $ (-1 |#5| |#5| |#5|) (-1 (-121) |#5| |#5|)) 68)) (-3158 (((-2 (|:| -4094 (-634 |#5|)) (|:| -2133 (-634 |#5|))) $) 54)) (-3764 (((-121) |#5| $) 57) (((-121) $) 102)) (-4001 ((|#4| $) 107)) (-4164 (((-3 |#5| "failed") $) 109)) (-3882 (((-634 |#5|) $) 48)) (-2157 (((-121) |#5| $) 66) (((-121) $) 106)) (-1315 ((|#5| |#5| $) 80)) (-4342 (((-121) $ $) 26)) (-3236 (((-121) |#5| $) 62) (((-121) $) 104)) (-1452 ((|#5| |#5| $) 77)) (-3877 (((-3 |#5| "failed") $) 108)) (-2168 (($ $ |#5|) 126)) (-1836 (((-763) $) 51)) (-4289 (($ (-634 |#5|)) 123)) (-3206 (($ $ |#4|) 121)) (-2527 (($ $ |#4|) 120)) (-4392 (($ $) 119)) (-2747 (((-850) $) NIL) (((-634 |#5|) $) 112)) (-2524 (((-763) $) 129)) (-2835 (((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 |#5|))) "failed") (-634 |#5|) (-1 (-121) |#5| |#5|)) 42) (((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 |#5|))) "failed") (-634 |#5|) (-1 (-121) |#5|) (-1 (-121) |#5| |#5|)) 44)) (-2145 (((-121) $ (-1 (-121) |#5| (-634 |#5|))) 99)) (-3321 (((-634 |#4|) $) 114)) (-1413 (((-121) |#4| $) 117)) (-1719 (((-121) $ $) 19))) 
+(((-1188 |#1| |#2| |#3| |#4| |#5|) (-10 -8 (-15 -2524 ((-763) |#1|)) (-15 -2168 (|#1| |#1| |#5|)) (-15 -2803 ((-3 |#5| "failed") |#1| |#4|)) (-15 -1413 ((-121) |#4| |#1|)) (-15 -3321 ((-634 |#4|) |#1|)) (-15 -3936 ((-3 |#1| "failed") |#1|)) (-15 -4164 ((-3 |#5| "failed") |#1|)) (-15 -3877 ((-3 |#5| "failed") |#1|)) (-15 -3434 (|#5| |#5| |#1|)) (-15 -4392 (|#1| |#1|)) (-15 -3255 (|#5| |#5| |#1|)) (-15 -1315 (|#5| |#5| |#1|)) (-15 -1452 (|#5| |#5| |#1|)) (-15 -3767 (|#5| |#5| |#1|)) (-15 -2941 ((-634 |#5|) (-634 |#5|) |#1| (-1 |#5| |#5| |#5|) (-1 (-121) |#5| |#5|))) (-15 -3094 (|#5| |#5| |#1| (-1 |#5| |#5| |#5|) (-1 (-121) |#5| |#5|))) (-15 -2157 ((-121) |#1|)) (-15 -3236 ((-121) |#1|)) (-15 -4231 ((-121) |#1|)) (-15 -2145 ((-121) |#1| (-1 (-121) |#5| (-634 |#5|)))) (-15 -2157 ((-121) |#5| |#1|)) (-15 -3236 ((-121) |#5| |#1|)) (-15 -4231 ((-121) |#5| |#1|)) (-15 -1359 ((-121) |#5| |#1| (-1 (-121) |#5| |#5|))) (-15 -3764 ((-121) |#1|)) (-15 -3764 ((-121) |#5| |#1|)) (-15 -3158 ((-2 (|:| -4094 (-634 |#5|)) (|:| -2133 (-634 |#5|))) |#1|)) (-15 -1836 ((-763) |#1|)) (-15 -3882 ((-634 |#5|) |#1|)) (-15 -2835 ((-3 (-2 (|:| |bas| |#1|) (|:| -2618 (-634 |#5|))) "failed") (-634 |#5|) (-1 (-121) |#5|) (-1 (-121) |#5| |#5|))) (-15 -2835 ((-3 (-2 (|:| |bas| |#1|) (|:| -2618 (-634 |#5|))) "failed") (-634 |#5|) (-1 (-121) |#5| |#5|))) (-15 -4342 ((-121) |#1| |#1|)) (-15 -3206 (|#1| |#1| |#4|)) (-15 -2527 (|#1| |#1| |#4|)) (-15 -4001 (|#4| |#1|)) (-15 -3668 ((-3 |#1| "failed") (-634 |#5|))) (-15 -2747 ((-634 |#5|) |#1|)) (-15 -4289 (|#1| (-634 |#5|))) (-15 -3094 (|#5| (-1 |#5| |#5| |#5|) |#1|)) (-15 -3094 (|#5| (-1 |#5| |#5| |#5|) |#1| |#5|)) (-15 -2803 (|#1| (-1 (-121) |#5|) |#1|)) (-15 -3094 (|#5| (-1 |#5| |#5| |#5|) |#1| |#5| |#5|)) (-15 -2747 ((-850) |#1|)) (-15 -1719 ((-121) |#1| |#1|))) (-1189 |#2| |#3| |#4| |#5|) (-558) (-788) (-842) (-1061 |#2| |#3| |#4|)) (T -1188)) 
+NIL 
+(-10 -8 (-15 -2524 ((-763) |#1|)) (-15 -2168 (|#1| |#1| |#5|)) (-15 -2803 ((-3 |#5| "failed") |#1| |#4|)) (-15 -1413 ((-121) |#4| |#1|)) (-15 -3321 ((-634 |#4|) |#1|)) (-15 -3936 ((-3 |#1| "failed") |#1|)) (-15 -4164 ((-3 |#5| "failed") |#1|)) (-15 -3877 ((-3 |#5| "failed") |#1|)) (-15 -3434 (|#5| |#5| |#1|)) (-15 -4392 (|#1| |#1|)) (-15 -3255 (|#5| |#5| |#1|)) (-15 -1315 (|#5| |#5| |#1|)) (-15 -1452 (|#5| |#5| |#1|)) (-15 -3767 (|#5| |#5| |#1|)) (-15 -2941 ((-634 |#5|) (-634 |#5|) |#1| (-1 |#5| |#5| |#5|) (-1 (-121) |#5| |#5|))) (-15 -3094 (|#5| |#5| |#1| (-1 |#5| |#5| |#5|) (-1 (-121) |#5| |#5|))) (-15 -2157 ((-121) |#1|)) (-15 -3236 ((-121) |#1|)) (-15 -4231 ((-121) |#1|)) (-15 -2145 ((-121) |#1| (-1 (-121) |#5| (-634 |#5|)))) (-15 -2157 ((-121) |#5| |#1|)) (-15 -3236 ((-121) |#5| |#1|)) (-15 -4231 ((-121) |#5| |#1|)) (-15 -1359 ((-121) |#5| |#1| (-1 (-121) |#5| |#5|))) (-15 -3764 ((-121) |#1|)) (-15 -3764 ((-121) |#5| |#1|)) (-15 -3158 ((-2 (|:| -4094 (-634 |#5|)) (|:| -2133 (-634 |#5|))) |#1|)) (-15 -1836 ((-763) |#1|)) (-15 -3882 ((-634 |#5|) |#1|)) (-15 -2835 ((-3 (-2 (|:| |bas| |#1|) (|:| -2618 (-634 |#5|))) "failed") (-634 |#5|) (-1 (-121) |#5|) (-1 (-121) |#5| |#5|))) (-15 -2835 ((-3 (-2 (|:| |bas| |#1|) (|:| -2618 (-634 |#5|))) "failed") (-634 |#5|) (-1 (-121) |#5| |#5|))) (-15 -4342 ((-121) |#1| |#1|)) (-15 -3206 (|#1| |#1| |#4|)) (-15 -2527 (|#1| |#1| |#4|)) (-15 -4001 (|#4| |#1|)) (-15 -3668 ((-3 |#1| "failed") (-634 |#5|))) (-15 -2747 ((-634 |#5|) |#1|)) (-15 -4289 (|#1| (-634 |#5|))) (-15 -3094 (|#5| (-1 |#5| |#5| |#5|) |#1|)) (-15 -3094 (|#5| (-1 |#5| |#5| |#5|) |#1| |#5|)) (-15 -2803 (|#1| (-1 (-121) |#5|) |#1|)) (-15 -3094 (|#5| (-1 |#5| |#5| |#5|) |#1| |#5| |#5|)) (-15 -2747 ((-850) |#1|)) (-15 -1719 ((-121) |#1| |#1|))) 
+((-2449 (((-121) $ $) 7)) (-2213 (((-634 (-2 (|:| -4094 $) (|:| -2133 (-634 |#4|)))) (-634 |#4|)) 78)) (-2353 (((-634 $) (-634 |#4|)) 79)) (-2057 (((-634 |#3|) $) 32)) (-4141 (((-121) $) 25)) (-1794 (((-121) $) 16 (|has| |#1| (-558)))) (-4231 (((-121) |#4| $) 94) (((-121) $) 90)) (-3767 ((|#4| |#4| $) 85)) (-3647 (((-2 (|:| |under| $) (|:| -4115 $) (|:| |upper| $)) $ |#3|) 26)) (-1667 (((-121) $ (-763)) 43)) (-2803 (($ (-1 (-121) |#4|) $) 64 (|has| $ (-6 -4521))) (((-3 |#4| "failed") $ |#3|) 72)) (-4490 (($) 44 T CONST)) (-4382 (((-121) $) 21 (|has| |#1| (-558)))) (-1880 (((-121) $ $) 23 (|has| |#1| (-558)))) (-2536 (((-121) $ $) 22 (|has| |#1| (-558)))) (-2343 (((-121) $) 24 (|has| |#1| (-558)))) (-2941 (((-634 |#4|) (-634 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 86)) (-3993 (((-634 |#4|) (-634 |#4|) $) 17 (|has| |#1| (-558)))) (-2727 (((-634 |#4|) (-634 |#4|) $) 18 (|has| |#1| (-558)))) (-3668 (((-3 $ "failed") (-634 |#4|)) 35)) (-2857 (($ (-634 |#4|)) 34)) (-3936 (((-3 $ "failed") $) 75)) (-3255 ((|#4| |#4| $) 82)) (-3926 (($ $) 67 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521))))) (-4330 (($ |#4| $) 66 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) |#4|) $) 63 (|has| $ (-6 -4521)))) (-2607 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) 19 (|has| |#1| (-558)))) (-1359 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) 95)) (-3434 ((|#4| |#4| $) 80)) (-3094 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) 65 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) 62 (|has| $ (-6 -4521))) ((|#4| (-1 |#4| |#4| |#4|) $) 61 (|has| $ (-6 -4521))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 87)) (-3158 (((-2 (|:| -4094 (-634 |#4|)) (|:| -2133 (-634 |#4|))) $) 98)) (-3317 (((-634 |#4|) $) 51 (|has| $ (-6 -4521)))) (-3764 (((-121) |#4| $) 97) (((-121) $) 96)) (-4001 ((|#3| $) 33)) (-3791 (((-121) $ (-763)) 42)) (-4406 (((-634 |#4|) $) 52 (|has| $ (-6 -4521)))) (-2551 (((-121) |#4| $) 54 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#4| |#4|) $) 47 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#4| |#4|) $) 46)) (-2249 (((-634 |#3|) $) 31)) (-1495 (((-121) |#3| $) 30)) (-3796 (((-121) $ (-763)) 41)) (-1893 (((-1143) $) 9)) (-4164 (((-3 |#4| "failed") $) 76)) (-3882 (((-634 |#4|) $) 100)) (-2157 (((-121) |#4| $) 92) (((-121) $) 88)) (-1315 ((|#4| |#4| $) 83)) (-4342 (((-121) $ $) 103)) (-1440 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) 20 (|has| |#1| (-558)))) (-3236 (((-121) |#4| $) 93) (((-121) $) 89)) (-1452 ((|#4| |#4| $) 84)) (-4025 (((-1108) $) 10)) (-3877 (((-3 |#4| "failed") $) 77)) (-2712 (((-3 |#4| "failed") (-1 (-121) |#4|) $) 60)) (-3413 (((-3 $ "failed") $ |#4|) 71)) (-2168 (($ $ |#4|) 70)) (-3951 (((-121) (-1 (-121) |#4|) $) 49 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 |#4|) (-634 |#4|)) 58 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) 57 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) 56 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 (-288 |#4|))) 55 (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-1702 (((-121) $ $) 37)) (-2436 (((-121) $) 40)) (-1990 (($) 39)) (-1836 (((-763) $) 99)) (-4170 (((-763) |#4| $) 53 (-12 (|has| |#4| (-1090)) (|has| $ (-6 -4521)))) (((-763) (-1 (-121) |#4|) $) 50 (|has| $ (-6 -4521)))) (-3865 (($ $) 38)) (-4280 (((-541) $) 68 (|has| |#4| (-609 (-541))))) (-4289 (($ (-634 |#4|)) 59)) (-3206 (($ $ |#3|) 27)) (-2527 (($ $ |#3|) 29)) (-4392 (($ $) 81)) (-4332 (($ $ |#3|) 28)) (-2747 (((-850) $) 11) (((-634 |#4|) $) 36)) (-2524 (((-763) $) 69 (|has| |#3| (-370)))) (-2835 (((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4| |#4|)) 102) (((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) 101)) (-2145 (((-121) $ (-1 (-121) |#4| (-634 |#4|))) 91)) (-3437 (((-121) (-1 (-121) |#4|) $) 48 (|has| $ (-6 -4521)))) (-3321 (((-634 |#3|) $) 74)) (-1413 (((-121) |#3| $) 73)) (-1719 (((-121) $ $) 6)) (-1699 (((-763) $) 45 (|has| $ (-6 -4521))))) 
 (((-1189 |#1| |#2| |#3| |#4|) (-1275) (-558) (-788) (-842) (-1061 |t#1| |t#2| |t#3|)) (T -1189)) 
-((-2644 (*1 *2 *1 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) (-3556 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1 (-121) *8 *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-2 (|:| |bas| *1) (|:| -2616 (-634 *8)))) (-5 *3 (-634 *8)) (-4 *1 (-1189 *5 *6 *7 *8)))) (-3556 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1 (-121) *9)) (-5 *5 (-1 (-121) *9 *9)) (-4 *9 (-1061 *6 *7 *8)) (-4 *6 (-558)) (-4 *7 (-788)) (-4 *8 (-842)) (-5 *2 (-2 (|:| |bas| *1) (|:| -2616 (-634 *9)))) (-5 *3 (-634 *9)) (-4 *1 (-1189 *6 *7 *8 *9)))) (-1377 (*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-634 *6)))) (-3206 (*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-763)))) (-3635 (*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-2 (|:| -4092 (-634 *6)) (|:| -1798 (-634 *6)))))) (-1362 (*1 *2 *3 *1) (-12 (-4 *1 (-1189 *4 *5 *6 *3)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121)))) (-1362 (*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) (-1281 (*1 *2 *3 *1 *4) (-12 (-5 *4 (-1 (-121) *3 *3)) (-4 *1 (-1189 *5 *6 *7 *3)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-121)))) (-3300 (*1 *2 *3 *1) (-12 (-4 *1 (-1189 *4 *5 *6 *3)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121)))) (-4347 (*1 *2 *3 *1) (-12 (-4 *1 (-1189 *4 *5 *6 *3)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121)))) (-1415 (*1 *2 *3 *1) (-12 (-4 *1 (-1189 *4 *5 *6 *3)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121)))) (-3292 (*1 *2 *1 *3) (-12 (-5 *3 (-1 (-121) *7 (-634 *7))) (-4 *1 (-1189 *4 *5 *6 *7)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)))) (-3300 (*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) (-4347 (*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) (-1415 (*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) (-3092 (*1 *2 *2 *1 *3 *4) (-12 (-5 *3 (-1 *2 *2 *2)) (-5 *4 (-1 (-121) *2 *2)) (-4 *1 (-1189 *5 *6 *7 *2)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *2 (-1061 *5 *6 *7)))) (-4275 (*1 *2 *2 *1 *3 *4) (-12 (-5 *2 (-634 *8)) (-5 *3 (-1 *8 *8 *8)) (-5 *4 (-1 (-121) *8 *8)) (-4 *1 (-1189 *5 *6 *7 *8)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)))) (-2819 (*1 *2 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) (-4025 (*1 *2 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) (-2682 (*1 *2 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) (-2062 (*1 *2 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) (-1567 (*1 *1 *1) (-12 (-4 *1 (-1189 *2 *3 *4 *5)) (-4 *2 (-558)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-1061 *2 *3 *4)))) (-4079 (*1 *2 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) (-2415 (*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1189 *4 *5 *6 *7)))) (-2387 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-634 (-2 (|:| -4092 *1) (|:| -1798 (-634 *7))))) (-5 *3 (-634 *7)) (-4 *1 (-1189 *4 *5 *6 *7)))) (-3876 (*1 *2 *1) (|partial| -12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) (-4162 (*1 *2 *1) (|partial| -12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) (-3935 (*1 *1 *1) (|partial| -12 (-4 *1 (-1189 *2 *3 *4 *5)) (-4 *2 (-558)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-1061 *2 *3 *4)))) (-2739 (*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-634 *5)))) (-4390 (*1 *2 *3 *1) (-12 (-4 *1 (-1189 *4 *5 *3 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *3 (-842)) (-4 *6 (-1061 *4 *5 *3)) (-5 *2 (-121)))) (-2801 (*1 *2 *1 *3) (|partial| -12 (-4 *1 (-1189 *4 *5 *3 *2)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *3 (-842)) (-4 *2 (-1061 *4 *5 *3)))) (-1665 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) (-1807 (*1 *1 *1 *2) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) (-1878 (*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *5 (-370)) (-5 *2 (-763))))) 
-(-13 (-977 |t#1| |t#2| |t#3| |t#4|) (-10 -8 (-6 -4519) (-6 -4520) (-15 -2644 ((-121) $ $)) (-15 -3556 ((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 |t#4|))) "failed") (-634 |t#4|) (-1 (-121) |t#4| |t#4|))) (-15 -3556 ((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 |t#4|))) "failed") (-634 |t#4|) (-1 (-121) |t#4|) (-1 (-121) |t#4| |t#4|))) (-15 -1377 ((-634 |t#4|) $)) (-15 -3206 ((-763) $)) (-15 -3635 ((-2 (|:| -4092 (-634 |t#4|)) (|:| -1798 (-634 |t#4|))) $)) (-15 -1362 ((-121) |t#4| $)) (-15 -1362 ((-121) $)) (-15 -1281 ((-121) |t#4| $ (-1 (-121) |t#4| |t#4|))) (-15 -3300 ((-121) |t#4| $)) (-15 -4347 ((-121) |t#4| $)) (-15 -1415 ((-121) |t#4| $)) (-15 -3292 ((-121) $ (-1 (-121) |t#4| (-634 |t#4|)))) (-15 -3300 ((-121) $)) (-15 -4347 ((-121) $)) (-15 -1415 ((-121) $)) (-15 -3092 (|t#4| |t#4| $ (-1 |t#4| |t#4| |t#4|) (-1 (-121) |t#4| |t#4|))) (-15 -4275 ((-634 |t#4|) (-634 |t#4|) $ (-1 |t#4| |t#4| |t#4|) (-1 (-121) |t#4| |t#4|))) (-15 -2819 (|t#4| |t#4| $)) (-15 -4025 (|t#4| |t#4| $)) (-15 -2682 (|t#4| |t#4| $)) (-15 -2062 (|t#4| |t#4| $)) (-15 -1567 ($ $)) (-15 -4079 (|t#4| |t#4| $)) (-15 -2415 ((-634 $) (-634 |t#4|))) (-15 -2387 ((-634 (-2 (|:| -4092 $) (|:| -1798 (-634 |t#4|)))) (-634 |t#4|))) (-15 -3876 ((-3 |t#4| "failed") $)) (-15 -4162 ((-3 |t#4| "failed") $)) (-15 -3935 ((-3 $ "failed") $)) (-15 -2739 ((-634 |t#3|) $)) (-15 -4390 ((-121) |t#3| $)) (-15 -2801 ((-3 |t#4| "failed") $ |t#3|)) (-15 -1665 ((-3 $ "failed") $ |t#4|)) (-15 -1807 ($ $ |t#4|)) (IF (|has| |t#3| (-370)) (-15 -1878 ((-763) $)) |noBranch|))) 
+((-4342 (*1 *2 *1 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) (-2835 (*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1 (-121) *8 *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-2 (|:| |bas| *1) (|:| -2618 (-634 *8)))) (-5 *3 (-634 *8)) (-4 *1 (-1189 *5 *6 *7 *8)))) (-2835 (*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1 (-121) *9)) (-5 *5 (-1 (-121) *9 *9)) (-4 *9 (-1061 *6 *7 *8)) (-4 *6 (-558)) (-4 *7 (-788)) (-4 *8 (-842)) (-5 *2 (-2 (|:| |bas| *1) (|:| -2618 (-634 *9)))) (-5 *3 (-634 *9)) (-4 *1 (-1189 *6 *7 *8 *9)))) (-3882 (*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-634 *6)))) (-1836 (*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-763)))) (-3158 (*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-2 (|:| -4094 (-634 *6)) (|:| -2133 (-634 *6)))))) (-3764 (*1 *2 *3 *1) (-12 (-4 *1 (-1189 *4 *5 *6 *3)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121)))) (-3764 (*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) (-1359 (*1 *2 *3 *1 *4) (-12 (-5 *4 (-1 (-121) *3 *3)) (-4 *1 (-1189 *5 *6 *7 *3)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-121)))) (-4231 (*1 *2 *3 *1) (-12 (-4 *1 (-1189 *4 *5 *6 *3)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121)))) (-3236 (*1 *2 *3 *1) (-12 (-4 *1 (-1189 *4 *5 *6 *3)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121)))) (-2157 (*1 *2 *3 *1) (-12 (-4 *1 (-1189 *4 *5 *6 *3)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121)))) (-2145 (*1 *2 *1 *3) (-12 (-5 *3 (-1 (-121) *7 (-634 *7))) (-4 *1 (-1189 *4 *5 *6 *7)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)))) (-4231 (*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) (-3236 (*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) (-2157 (*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) (-3094 (*1 *2 *2 *1 *3 *4) (-12 (-5 *3 (-1 *2 *2 *2)) (-5 *4 (-1 (-121) *2 *2)) (-4 *1 (-1189 *5 *6 *7 *2)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *2 (-1061 *5 *6 *7)))) (-2941 (*1 *2 *2 *1 *3 *4) (-12 (-5 *2 (-634 *8)) (-5 *3 (-1 *8 *8 *8)) (-5 *4 (-1 (-121) *8 *8)) (-4 *1 (-1189 *5 *6 *7 *8)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)))) (-3767 (*1 *2 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) (-1452 (*1 *2 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) (-1315 (*1 *2 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) (-3255 (*1 *2 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) (-4392 (*1 *1 *1) (-12 (-4 *1 (-1189 *2 *3 *4 *5)) (-4 *2 (-558)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-1061 *2 *3 *4)))) (-3434 (*1 *2 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) (-2353 (*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1189 *4 *5 *6 *7)))) (-2213 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-634 (-2 (|:| -4094 *1) (|:| -2133 (-634 *7))))) (-5 *3 (-634 *7)) (-4 *1 (-1189 *4 *5 *6 *7)))) (-3877 (*1 *2 *1) (|partial| -12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) (-4164 (*1 *2 *1) (|partial| -12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) (-3936 (*1 *1 *1) (|partial| -12 (-4 *1 (-1189 *2 *3 *4 *5)) (-4 *2 (-558)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-1061 *2 *3 *4)))) (-3321 (*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-634 *5)))) (-1413 (*1 *2 *3 *1) (-12 (-4 *1 (-1189 *4 *5 *3 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *3 (-842)) (-4 *6 (-1061 *4 *5 *3)) (-5 *2 (-121)))) (-2803 (*1 *2 *1 *3) (|partial| -12 (-4 *1 (-1189 *4 *5 *3 *2)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *3 (-842)) (-4 *2 (-1061 *4 *5 *3)))) (-3413 (*1 *1 *1 *2) (|partial| -12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) (-2168 (*1 *1 *1 *2) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) (-2524 (*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *5 (-370)) (-5 *2 (-763))))) 
+(-13 (-977 |t#1| |t#2| |t#3| |t#4|) (-10 -8 (-6 -4521) (-6 -4522) (-15 -4342 ((-121) $ $)) (-15 -2835 ((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 |t#4|))) "failed") (-634 |t#4|) (-1 (-121) |t#4| |t#4|))) (-15 -2835 ((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 |t#4|))) "failed") (-634 |t#4|) (-1 (-121) |t#4|) (-1 (-121) |t#4| |t#4|))) (-15 -3882 ((-634 |t#4|) $)) (-15 -1836 ((-763) $)) (-15 -3158 ((-2 (|:| -4094 (-634 |t#4|)) (|:| -2133 (-634 |t#4|))) $)) (-15 -3764 ((-121) |t#4| $)) (-15 -3764 ((-121) $)) (-15 -1359 ((-121) |t#4| $ (-1 (-121) |t#4| |t#4|))) (-15 -4231 ((-121) |t#4| $)) (-15 -3236 ((-121) |t#4| $)) (-15 -2157 ((-121) |t#4| $)) (-15 -2145 ((-121) $ (-1 (-121) |t#4| (-634 |t#4|)))) (-15 -4231 ((-121) $)) (-15 -3236 ((-121) $)) (-15 -2157 ((-121) $)) (-15 -3094 (|t#4| |t#4| $ (-1 |t#4| |t#4| |t#4|) (-1 (-121) |t#4| |t#4|))) (-15 -2941 ((-634 |t#4|) (-634 |t#4|) $ (-1 |t#4| |t#4| |t#4|) (-1 (-121) |t#4| |t#4|))) (-15 -3767 (|t#4| |t#4| $)) (-15 -1452 (|t#4| |t#4| $)) (-15 -1315 (|t#4| |t#4| $)) (-15 -3255 (|t#4| |t#4| $)) (-15 -4392 ($ $)) (-15 -3434 (|t#4| |t#4| $)) (-15 -2353 ((-634 $) (-634 |t#4|))) (-15 -2213 ((-634 (-2 (|:| -4094 $) (|:| -2133 (-634 |t#4|)))) (-634 |t#4|))) (-15 -3877 ((-3 |t#4| "failed") $)) (-15 -4164 ((-3 |t#4| "failed") $)) (-15 -3936 ((-3 $ "failed") $)) (-15 -3321 ((-634 |t#3|) $)) (-15 -1413 ((-121) |t#3| $)) (-15 -2803 ((-3 |t#4| "failed") $ |t#3|)) (-15 -3413 ((-3 $ "failed") $ |t#4|)) (-15 -2168 ($ $ |t#4|)) (IF (|has| |t#3| (-370)) (-15 -2524 ((-763) $)) |noBranch|))) 
 (((-39) . T) ((-105) . T) ((-608 (-634 |#4|)) . T) ((-608 (-850)) . T) ((-154 |#4|) . T) ((-609 (-541)) |has| |#4| (-609 (-541))) ((-303 |#4|) -12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))) ((-499 |#4|) . T) ((-523 |#4| |#4|) -12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))) ((-977 |#1| |#2| |#3| |#4|) . T) ((-1090) . T) ((-1195) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2055 (((-634 (-1161)) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-1982 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1933 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3134 (((-3 $ "failed") $ $) NIL)) (-1902 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1974 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2786 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1990 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1941 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2671 (($) NIL T CONST)) (-2114 (($ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-1367 (((-953 |#1|) $ (-763)) 16) (((-953 |#1|) $ (-763) (-763)) NIL)) (-3992 (((-121) $) NIL)) (-1897 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4477 (((-763) $ (-1161)) NIL) (((-763) $ (-1161) (-763)) NIL)) (-2735 (((-121) $) NIL)) (-4044 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3921 (((-121) $) NIL)) (-2047 (($ $ (-634 (-1161)) (-634 (-534 (-1161)))) NIL) (($ $ (-1161) (-534 (-1161))) NIL) (($ |#1| (-534 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-4416 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-4487 (((-1143) $) NIL)) (-3837 (($ $ (-1161)) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161) |#1|) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4022 (((-1108) $) NIL)) (-2225 (($ (-1 $) (-1161) |#1|) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1807 (($ $ (-763)) NIL)) (-2595 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-1892 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1339 (($ $ (-1161) $) NIL) (($ $ (-634 (-1161)) (-634 $)) NIL) (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL)) (-4189 (($ $ (-1161)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL)) (-3206 (((-534 (-1161)) $) NIL)) (-1994 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1945 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1986 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1937 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1978 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2790 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1811 (($ $) NIL)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL (|has| |#1| (-172))) (($ $) NIL (|has| |#1| (-558))) (($ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-1161)) NIL) (($ (-953 |#1|)) NIL)) (-2604 ((|#1| $ (-534 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (((-953 |#1|) $ (-763)) NIL)) (-4371 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-4078 (((-763)) NIL)) (-2006 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1958 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1998 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1949 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2014 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1966 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4023 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1970 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2010 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1962 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2002 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1953 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $ (-1161)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL)) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
-(((-1190 |#1|) (-13 (-730 |#1| (-1161)) (-10 -8 (-15 -2604 ((-953 |#1|) $ (-763))) (-15 -2745 ($ (-1161))) (-15 -2745 ($ (-953 |#1|))) (IF (|has| |#1| (-43 (-409 (-568)))) (PROGN (-15 -3837 ($ $ (-1161) |#1|)) (-15 -2225 ($ (-1 $) (-1161) |#1|))) |noBranch|))) (-1047)) (T -1190)) 
-((-2604 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-953 *4)) (-5 *1 (-1190 *4)) (-4 *4 (-1047)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1190 *3)) (-4 *3 (-1047)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-953 *3)) (-4 *3 (-1047)) (-5 *1 (-1190 *3)))) (-3837 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *1 (-1190 *3)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)))) (-2225 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1 (-1190 *4))) (-5 *3 (-1161)) (-5 *1 (-1190 *4)) (-4 *4 (-43 (-409 (-568)))) (-4 *4 (-1047))))) 
-(-13 (-730 |#1| (-1161)) (-10 -8 (-15 -2604 ((-953 |#1|) $ (-763))) (-15 -2745 ($ (-1161))) (-15 -2745 ($ (-953 |#1|))) (IF (|has| |#1| (-43 (-409 (-568)))) (PROGN (-15 -3837 ($ $ (-1161) |#1|)) (-15 -2225 ($ (-1 $) (-1161) |#1|))) |noBranch|))) 
-((-3368 (($ |#1| (-634 (-634 (-944 (-215)))) (-121)) 15)) (-4353 (((-121) $ (-121)) 14)) (-3868 (((-121) $) 13)) (-3209 (((-634 (-634 (-944 (-215)))) $) 10)) (-1774 ((|#1| $) 8)) (-3336 (((-121) $) 12))) 
-(((-1191 |#1|) (-10 -8 (-15 -1774 (|#1| $)) (-15 -3209 ((-634 (-634 (-944 (-215)))) $)) (-15 -3336 ((-121) $)) (-15 -3868 ((-121) $)) (-15 -4353 ((-121) $ (-121))) (-15 -3368 ($ |#1| (-634 (-634 (-944 (-215)))) (-121)))) (-975)) (T -1191)) 
-((-3368 (*1 *1 *2 *3 *4) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *4 (-121)) (-5 *1 (-1191 *2)) (-4 *2 (-975)))) (-4353 (*1 *2 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1191 *3)) (-4 *3 (-975)))) (-3868 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1191 *3)) (-4 *3 (-975)))) (-3336 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1191 *3)) (-4 *3 (-975)))) (-3209 (*1 *2 *1) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *1 (-1191 *3)) (-4 *3 (-975)))) (-1774 (*1 *2 *1) (-12 (-5 *1 (-1191 *2)) (-4 *2 (-975))))) 
-(-10 -8 (-15 -1774 (|#1| $)) (-15 -3209 ((-634 (-634 (-944 (-215)))) $)) (-15 -3336 ((-121) $)) (-15 -3868 ((-121) $)) (-15 -4353 ((-121) $ (-121))) (-15 -3368 ($ |#1| (-634 (-634 (-944 (-215)))) (-121)))) 
-((-1394 (((-944 (-215)) (-944 (-215))) 25)) (-4203 (((-944 (-215)) (-215) (-215) (-215) (-215)) 10)) (-3583 (((-634 (-944 (-215))) (-944 (-215)) (-944 (-215)) (-944 (-215)) (-215) (-634 (-634 (-215)))) 35)) (-3682 (((-215) (-944 (-215)) (-944 (-215))) 21)) (-2748 (((-944 (-215)) (-944 (-215)) (-944 (-215))) 22)) (-3743 (((-634 (-634 (-215))) (-568)) 31)) (-1773 (((-944 (-215)) (-944 (-215)) (-944 (-215))) 20)) (-1767 (((-944 (-215)) (-944 (-215)) (-944 (-215))) 19)) (* (((-944 (-215)) (-215) (-944 (-215))) 18))) 
-(((-1192) (-10 -7 (-15 -4203 ((-944 (-215)) (-215) (-215) (-215) (-215))) (-15 * ((-944 (-215)) (-215) (-944 (-215)))) (-15 -1767 ((-944 (-215)) (-944 (-215)) (-944 (-215)))) (-15 -1773 ((-944 (-215)) (-944 (-215)) (-944 (-215)))) (-15 -3682 ((-215) (-944 (-215)) (-944 (-215)))) (-15 -2748 ((-944 (-215)) (-944 (-215)) (-944 (-215)))) (-15 -1394 ((-944 (-215)) (-944 (-215)))) (-15 -3743 ((-634 (-634 (-215))) (-568))) (-15 -3583 ((-634 (-944 (-215))) (-944 (-215)) (-944 (-215)) (-944 (-215)) (-215) (-634 (-634 (-215))))))) (T -1192)) 
-((-3583 (*1 *2 *3 *3 *3 *4 *5) (-12 (-5 *5 (-634 (-634 (-215)))) (-5 *4 (-215)) (-5 *2 (-634 (-944 *4))) (-5 *1 (-1192)) (-5 *3 (-944 *4)))) (-3743 (*1 *2 *3) (-12 (-5 *3 (-568)) (-5 *2 (-634 (-634 (-215)))) (-5 *1 (-1192)))) (-1394 (*1 *2 *2) (-12 (-5 *2 (-944 (-215))) (-5 *1 (-1192)))) (-2748 (*1 *2 *2 *2) (-12 (-5 *2 (-944 (-215))) (-5 *1 (-1192)))) (-3682 (*1 *2 *3 *3) (-12 (-5 *3 (-944 (-215))) (-5 *2 (-215)) (-5 *1 (-1192)))) (-1773 (*1 *2 *2 *2) (-12 (-5 *2 (-944 (-215))) (-5 *1 (-1192)))) (-1767 (*1 *2 *2 *2) (-12 (-5 *2 (-944 (-215))) (-5 *1 (-1192)))) (* (*1 *2 *3 *2) (-12 (-5 *2 (-944 (-215))) (-5 *3 (-215)) (-5 *1 (-1192)))) (-4203 (*1 *2 *3 *3 *3 *3) (-12 (-5 *2 (-944 (-215))) (-5 *1 (-1192)) (-5 *3 (-215))))) 
-(-10 -7 (-15 -4203 ((-944 (-215)) (-215) (-215) (-215) (-215))) (-15 * ((-944 (-215)) (-215) (-944 (-215)))) (-15 -1767 ((-944 (-215)) (-944 (-215)) (-944 (-215)))) (-15 -1773 ((-944 (-215)) (-944 (-215)) (-944 (-215)))) (-15 -3682 ((-215) (-944 (-215)) (-944 (-215)))) (-15 -2748 ((-944 (-215)) (-944 (-215)) (-944 (-215)))) (-15 -1394 ((-944 (-215)) (-944 (-215)))) (-15 -3743 ((-634 (-634 (-215))) (-568))) (-15 -3583 ((-634 (-944 (-215))) (-944 (-215)) (-944 (-215)) (-944 (-215)) (-215) (-634 (-634 (-215)))))) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2801 ((|#1| $ (-763)) 13)) (-3678 (((-763) $) 12)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-2745 (((-958 |#1|) $) 10) (($ (-958 |#1|)) 9) (((-850) $) 23 (|has| |#1| (-1090)))) (-1717 (((-121) $ $) 16 (|has| |#1| (-1090))))) 
-(((-1193 |#1|) (-13 (-608 (-958 |#1|)) (-10 -8 (-15 -2745 ($ (-958 |#1|))) (-15 -2801 (|#1| $ (-763))) (-15 -3678 ((-763) $)) (IF (|has| |#1| (-1090)) (-6 (-1090)) |noBranch|))) (-1195)) (T -1193)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-958 *3)) (-4 *3 (-1195)) (-5 *1 (-1193 *3)))) (-2801 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *1 (-1193 *2)) (-4 *2 (-1195)))) (-3678 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1193 *3)) (-4 *3 (-1195))))) 
-(-13 (-608 (-958 |#1|)) (-10 -8 (-15 -2745 ($ (-958 |#1|))) (-15 -2801 (|#1| $ (-763))) (-15 -3678 ((-763) $)) (IF (|has| |#1| (-1090)) (-6 (-1090)) |noBranch|))) 
-((-2298 (((-420 (-1157 (-1157 |#1|))) (-1157 (-1157 |#1|)) (-568)) 79)) (-3816 (((-420 (-1157 (-1157 |#1|))) (-1157 (-1157 |#1|))) 73)) (-3395 (((-420 (-1157 (-1157 |#1|))) (-1157 (-1157 |#1|))) 58))) 
-(((-1194 |#1|) (-10 -7 (-15 -3816 ((-420 (-1157 (-1157 |#1|))) (-1157 (-1157 |#1|)))) (-15 -3395 ((-420 (-1157 (-1157 |#1|))) (-1157 (-1157 |#1|)))) (-15 -2298 ((-420 (-1157 (-1157 |#1|))) (-1157 (-1157 |#1|)) (-568)))) (-350)) (T -1194)) 
-((-2298 (*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-350)) (-5 *2 (-420 (-1157 (-1157 *5)))) (-5 *1 (-1194 *5)) (-5 *3 (-1157 (-1157 *5))))) (-3395 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 (-1157 (-1157 *4)))) (-5 *1 (-1194 *4)) (-5 *3 (-1157 (-1157 *4))))) (-3816 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 (-1157 (-1157 *4)))) (-5 *1 (-1194 *4)) (-5 *3 (-1157 (-1157 *4)))))) 
-(-10 -7 (-15 -3816 ((-420 (-1157 (-1157 |#1|))) (-1157 (-1157 |#1|)))) (-15 -3395 ((-420 (-1157 (-1157 |#1|))) (-1157 (-1157 |#1|)))) (-15 -2298 ((-420 (-1157 (-1157 |#1|))) (-1157 (-1157 |#1|)) (-568)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2057 (((-634 (-1161)) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-1984 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1935 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2689 (((-3 $ "failed") $ $) NIL)) (-1904 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1976 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2788 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1992 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1943 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4490 (($) NIL T CONST)) (-2116 (($ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-3808 (((-953 |#1|) $ (-763)) 16) (((-953 |#1|) $ (-763) (-763)) NIL)) (-1302 (((-121) $) NIL)) (-1899 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1844 (((-763) $ (-1161)) NIL) (((-763) $ (-1161) (-763)) NIL)) (-1598 (((-121) $) NIL)) (-1550 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2171 (((-121) $) NIL)) (-2049 (($ $ (-634 (-1161)) (-634 (-534 (-1161)))) NIL) (($ $ (-1161) (-534 (-1161))) NIL) (($ |#1| (-534 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-4418 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-1893 (((-1143) $) NIL)) (-1845 (($ $ (-1161)) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161) |#1|) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4025 (((-1108) $) NIL)) (-3648 (($ (-1 $) (-1161) |#1|) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2168 (($ $ (-763)) NIL)) (-2597 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-1894 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1339 (($ $ (-1161) $) NIL) (($ $ (-634 (-1161)) (-634 $)) NIL) (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL)) (-4191 (($ $ (-1161)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL)) (-1836 (((-534 (-1161)) $) NIL)) (-1996 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1947 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1988 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1939 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1980 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2792 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2188 (($ $) NIL)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL (|has| |#1| (-172))) (($ $) NIL (|has| |#1| (-558))) (($ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-1161)) NIL) (($ (-953 |#1|)) NIL)) (-2079 ((|#1| $ (-534 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (((-953 |#1|) $ (-763)) NIL)) (-3385 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-3425 (((-763)) NIL)) (-2008 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1959 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2000 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1951 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2016 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1968 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1439 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1972 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2012 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1964 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2004 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1955 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $ (-1161)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL)) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) NIL) (($ $ |#1|) NIL))) 
+(((-1190 |#1|) (-13 (-730 |#1| (-1161)) (-10 -8 (-15 -2079 ((-953 |#1|) $ (-763))) (-15 -2747 ($ (-1161))) (-15 -2747 ($ (-953 |#1|))) (IF (|has| |#1| (-43 (-409 (-568)))) (PROGN (-15 -1845 ($ $ (-1161) |#1|)) (-15 -3648 ($ (-1 $) (-1161) |#1|))) |noBranch|))) (-1047)) (T -1190)) 
+((-2079 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-953 *4)) (-5 *1 (-1190 *4)) (-4 *4 (-1047)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1190 *3)) (-4 *3 (-1047)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-953 *3)) (-4 *3 (-1047)) (-5 *1 (-1190 *3)))) (-1845 (*1 *1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *1 (-1190 *3)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)))) (-3648 (*1 *1 *2 *3 *4) (-12 (-5 *2 (-1 (-1190 *4))) (-5 *3 (-1161)) (-5 *1 (-1190 *4)) (-4 *4 (-43 (-409 (-568)))) (-4 *4 (-1047))))) 
+(-13 (-730 |#1| (-1161)) (-10 -8 (-15 -2079 ((-953 |#1|) $ (-763))) (-15 -2747 ($ (-1161))) (-15 -2747 ($ (-953 |#1|))) (IF (|has| |#1| (-43 (-409 (-568)))) (PROGN (-15 -1845 ($ $ (-1161) |#1|)) (-15 -3648 ($ (-1 $) (-1161) |#1|))) |noBranch|))) 
+((-1370 (($ |#1| (-634 (-634 (-944 (-215)))) (-121)) 15)) (-3275 (((-121) $ (-121)) 14)) (-1954 (((-121) $) 13)) (-1849 (((-634 (-634 (-944 (-215)))) $) 10)) (-3984 ((|#1| $) 8)) (-4429 (((-121) $) 12))) 
+(((-1191 |#1|) (-10 -8 (-15 -3984 (|#1| $)) (-15 -1849 ((-634 (-634 (-944 (-215)))) $)) (-15 -4429 ((-121) $)) (-15 -1954 ((-121) $)) (-15 -3275 ((-121) $ (-121))) (-15 -1370 ($ |#1| (-634 (-634 (-944 (-215)))) (-121)))) (-975)) (T -1191)) 
+((-1370 (*1 *1 *2 *3 *4) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *4 (-121)) (-5 *1 (-1191 *2)) (-4 *2 (-975)))) (-3275 (*1 *2 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1191 *3)) (-4 *3 (-975)))) (-1954 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1191 *3)) (-4 *3 (-975)))) (-4429 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1191 *3)) (-4 *3 (-975)))) (-1849 (*1 *2 *1) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *1 (-1191 *3)) (-4 *3 (-975)))) (-3984 (*1 *2 *1) (-12 (-5 *1 (-1191 *2)) (-4 *2 (-975))))) 
+(-10 -8 (-15 -3984 (|#1| $)) (-15 -1849 ((-634 (-634 (-944 (-215)))) $)) (-15 -4429 ((-121) $)) (-15 -1954 ((-121) $)) (-15 -3275 ((-121) $ (-121))) (-15 -1370 ($ |#1| (-634 (-634 (-944 (-215)))) (-121)))) 
+((-4007 (((-944 (-215)) (-944 (-215))) 25)) (-4098 (((-944 (-215)) (-215) (-215) (-215) (-215)) 10)) (-2937 (((-634 (-944 (-215))) (-944 (-215)) (-944 (-215)) (-944 (-215)) (-215) (-634 (-634 (-215)))) 35)) (-2286 (((-215) (-944 (-215)) (-944 (-215))) 21)) (-3372 (((-944 (-215)) (-944 (-215)) (-944 (-215))) 22)) (-2578 (((-634 (-634 (-215))) (-568)) 31)) (-1775 (((-944 (-215)) (-944 (-215)) (-944 (-215))) 20)) (-1769 (((-944 (-215)) (-944 (-215)) (-944 (-215))) 19)) (* (((-944 (-215)) (-215) (-944 (-215))) 18))) 
+(((-1192) (-10 -7 (-15 -4098 ((-944 (-215)) (-215) (-215) (-215) (-215))) (-15 * ((-944 (-215)) (-215) (-944 (-215)))) (-15 -1769 ((-944 (-215)) (-944 (-215)) (-944 (-215)))) (-15 -1775 ((-944 (-215)) (-944 (-215)) (-944 (-215)))) (-15 -2286 ((-215) (-944 (-215)) (-944 (-215)))) (-15 -3372 ((-944 (-215)) (-944 (-215)) (-944 (-215)))) (-15 -4007 ((-944 (-215)) (-944 (-215)))) (-15 -2578 ((-634 (-634 (-215))) (-568))) (-15 -2937 ((-634 (-944 (-215))) (-944 (-215)) (-944 (-215)) (-944 (-215)) (-215) (-634 (-634 (-215))))))) (T -1192)) 
+((-2937 (*1 *2 *3 *3 *3 *4 *5) (-12 (-5 *5 (-634 (-634 (-215)))) (-5 *4 (-215)) (-5 *2 (-634 (-944 *4))) (-5 *1 (-1192)) (-5 *3 (-944 *4)))) (-2578 (*1 *2 *3) (-12 (-5 *3 (-568)) (-5 *2 (-634 (-634 (-215)))) (-5 *1 (-1192)))) (-4007 (*1 *2 *2) (-12 (-5 *2 (-944 (-215))) (-5 *1 (-1192)))) (-3372 (*1 *2 *2 *2) (-12 (-5 *2 (-944 (-215))) (-5 *1 (-1192)))) (-2286 (*1 *2 *3 *3) (-12 (-5 *3 (-944 (-215))) (-5 *2 (-215)) (-5 *1 (-1192)))) (-1775 (*1 *2 *2 *2) (-12 (-5 *2 (-944 (-215))) (-5 *1 (-1192)))) (-1769 (*1 *2 *2 *2) (-12 (-5 *2 (-944 (-215))) (-5 *1 (-1192)))) (* (*1 *2 *3 *2) (-12 (-5 *2 (-944 (-215))) (-5 *3 (-215)) (-5 *1 (-1192)))) (-4098 (*1 *2 *3 *3 *3 *3) (-12 (-5 *2 (-944 (-215))) (-5 *1 (-1192)) (-5 *3 (-215))))) 
+(-10 -7 (-15 -4098 ((-944 (-215)) (-215) (-215) (-215) (-215))) (-15 * ((-944 (-215)) (-215) (-944 (-215)))) (-15 -1769 ((-944 (-215)) (-944 (-215)) (-944 (-215)))) (-15 -1775 ((-944 (-215)) (-944 (-215)) (-944 (-215)))) (-15 -2286 ((-215) (-944 (-215)) (-944 (-215)))) (-15 -3372 ((-944 (-215)) (-944 (-215)) (-944 (-215)))) (-15 -4007 ((-944 (-215)) (-944 (-215)))) (-15 -2578 ((-634 (-634 (-215))) (-568))) (-15 -2937 ((-634 (-944 (-215))) (-944 (-215)) (-944 (-215)) (-944 (-215)) (-215) (-634 (-634 (-215)))))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2803 ((|#1| $ (-763)) 13)) (-3680 (((-763) $) 12)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-2747 (((-958 |#1|) $) 10) (($ (-958 |#1|)) 9) (((-850) $) 23 (|has| |#1| (-1090)))) (-1719 (((-121) $ $) 16 (|has| |#1| (-1090))))) 
+(((-1193 |#1|) (-13 (-608 (-958 |#1|)) (-10 -8 (-15 -2747 ($ (-958 |#1|))) (-15 -2803 (|#1| $ (-763))) (-15 -3680 ((-763) $)) (IF (|has| |#1| (-1090)) (-6 (-1090)) |noBranch|))) (-1195)) (T -1193)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-958 *3)) (-4 *3 (-1195)) (-5 *1 (-1193 *3)))) (-2803 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *1 (-1193 *2)) (-4 *2 (-1195)))) (-3680 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1193 *3)) (-4 *3 (-1195))))) 
+(-13 (-608 (-958 |#1|)) (-10 -8 (-15 -2747 ($ (-958 |#1|))) (-15 -2803 (|#1| $ (-763))) (-15 -3680 ((-763) $)) (IF (|has| |#1| (-1090)) (-6 (-1090)) |noBranch|))) 
+((-3615 (((-420 (-1157 (-1157 |#1|))) (-1157 (-1157 |#1|)) (-568)) 79)) (-1765 (((-420 (-1157 (-1157 |#1|))) (-1157 (-1157 |#1|))) 73)) (-1507 (((-420 (-1157 (-1157 |#1|))) (-1157 (-1157 |#1|))) 58))) 
+(((-1194 |#1|) (-10 -7 (-15 -1765 ((-420 (-1157 (-1157 |#1|))) (-1157 (-1157 |#1|)))) (-15 -1507 ((-420 (-1157 (-1157 |#1|))) (-1157 (-1157 |#1|)))) (-15 -3615 ((-420 (-1157 (-1157 |#1|))) (-1157 (-1157 |#1|)) (-568)))) (-350)) (T -1194)) 
+((-3615 (*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-350)) (-5 *2 (-420 (-1157 (-1157 *5)))) (-5 *1 (-1194 *5)) (-5 *3 (-1157 (-1157 *5))))) (-1507 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 (-1157 (-1157 *4)))) (-5 *1 (-1194 *4)) (-5 *3 (-1157 (-1157 *4))))) (-1765 (*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 (-1157 (-1157 *4)))) (-5 *1 (-1194 *4)) (-5 *3 (-1157 (-1157 *4)))))) 
+(-10 -7 (-15 -1765 ((-420 (-1157 (-1157 |#1|))) (-1157 (-1157 |#1|)))) (-15 -1507 ((-420 (-1157 (-1157 |#1|))) (-1157 (-1157 |#1|)))) (-15 -3615 ((-420 (-1157 (-1157 |#1|))) (-1157 (-1157 |#1|)) (-568)))) 
 NIL 
 (((-1195) (-1275)) (T -1195)) 
 NIL 
 (-13 (-10 -7 (-6 -3973))) 
-((-3636 (((-121)) 14)) (-2743 (((-1249) (-634 |#1|) (-634 |#1|)) 18) (((-1249) (-634 |#1|)) 19)) (-1737 (((-121) |#1| |#1|) 30 (|has| |#1| (-842)))) (-2166 (((-121) |#1| |#1| (-1 (-121) |#1| |#1|)) 26) (((-3 (-121) "failed") |#1| |#1|) 24)) (-4385 ((|#1| (-634 |#1|)) 31 (|has| |#1| (-842))) ((|#1| (-634 |#1|) (-1 (-121) |#1| |#1|)) 27)) (-2172 (((-2 (|:| -4100 (-634 |#1|)) (|:| -2971 (-634 |#1|)))) 16))) 
-(((-1196 |#1|) (-10 -7 (-15 -2743 ((-1249) (-634 |#1|))) (-15 -2743 ((-1249) (-634 |#1|) (-634 |#1|))) (-15 -2172 ((-2 (|:| -4100 (-634 |#1|)) (|:| -2971 (-634 |#1|))))) (-15 -2166 ((-3 (-121) "failed") |#1| |#1|)) (-15 -2166 ((-121) |#1| |#1| (-1 (-121) |#1| |#1|))) (-15 -4385 (|#1| (-634 |#1|) (-1 (-121) |#1| |#1|))) (-15 -3636 ((-121))) (IF (|has| |#1| (-842)) (PROGN (-15 -4385 (|#1| (-634 |#1|))) (-15 -1737 ((-121) |#1| |#1|))) |noBranch|)) (-1090)) (T -1196)) 
-((-1737 (*1 *2 *3 *3) (-12 (-5 *2 (-121)) (-5 *1 (-1196 *3)) (-4 *3 (-842)) (-4 *3 (-1090)))) (-4385 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-1090)) (-4 *2 (-842)) (-5 *1 (-1196 *2)))) (-3636 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1196 *3)) (-4 *3 (-1090)))) (-4385 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *2)) (-5 *4 (-1 (-121) *2 *2)) (-5 *1 (-1196 *2)) (-4 *2 (-1090)))) (-2166 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-1 (-121) *3 *3)) (-4 *3 (-1090)) (-5 *2 (-121)) (-5 *1 (-1196 *3)))) (-2166 (*1 *2 *3 *3) (|partial| -12 (-5 *2 (-121)) (-5 *1 (-1196 *3)) (-4 *3 (-1090)))) (-2172 (*1 *2) (-12 (-5 *2 (-2 (|:| -4100 (-634 *3)) (|:| -2971 (-634 *3)))) (-5 *1 (-1196 *3)) (-4 *3 (-1090)))) (-2743 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1090)) (-5 *2 (-1249)) (-5 *1 (-1196 *4)))) (-2743 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1090)) (-5 *2 (-1249)) (-5 *1 (-1196 *4))))) 
-(-10 -7 (-15 -2743 ((-1249) (-634 |#1|))) (-15 -2743 ((-1249) (-634 |#1|) (-634 |#1|))) (-15 -2172 ((-2 (|:| -4100 (-634 |#1|)) (|:| -2971 (-634 |#1|))))) (-15 -2166 ((-3 (-121) "failed") |#1| |#1|)) (-15 -2166 ((-121) |#1| |#1| (-1 (-121) |#1| |#1|))) (-15 -4385 (|#1| (-634 |#1|) (-1 (-121) |#1| |#1|))) (-15 -3636 ((-121))) (IF (|has| |#1| (-842)) (PROGN (-15 -4385 (|#1| (-634 |#1|))) (-15 -1737 ((-121) |#1| |#1|))) |noBranch|)) 
-((-1980 (((-1249) (-634 (-1161)) (-634 (-1161))) 12) (((-1249) (-634 (-1161))) 10)) (-2520 (((-1249)) 13)) (-1769 (((-2 (|:| -2971 (-634 (-1161))) (|:| -4100 (-634 (-1161))))) 17))) 
-(((-1197) (-10 -7 (-15 -1980 ((-1249) (-634 (-1161)))) (-15 -1980 ((-1249) (-634 (-1161)) (-634 (-1161)))) (-15 -1769 ((-2 (|:| -2971 (-634 (-1161))) (|:| -4100 (-634 (-1161)))))) (-15 -2520 ((-1249))))) (T -1197)) 
-((-2520 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1197)))) (-1769 (*1 *2) (-12 (-5 *2 (-2 (|:| -2971 (-634 (-1161))) (|:| -4100 (-634 (-1161))))) (-5 *1 (-1197)))) (-1980 (*1 *2 *3 *3) (-12 (-5 *3 (-634 (-1161))) (-5 *2 (-1249)) (-5 *1 (-1197)))) (-1980 (*1 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-5 *2 (-1249)) (-5 *1 (-1197))))) 
-(-10 -7 (-15 -1980 ((-1249) (-634 (-1161)))) (-15 -1980 ((-1249) (-634 (-1161)) (-634 (-1161)))) (-15 -1769 ((-2 (|:| -2971 (-634 (-1161))) (|:| -4100 (-634 (-1161)))))) (-15 -2520 ((-1249)))) 
-((-4305 (($ $) 16)) (-3927 (((-121) $) 23))) 
-(((-1198 |#1|) (-10 -8 (-15 -4305 (|#1| |#1|)) (-15 -3927 ((-121) |#1|))) (-1199)) (T -1198)) 
-NIL 
-(-10 -8 (-15 -4305 (|#1| |#1|)) (-15 -3927 ((-121) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-3134 (((-3 $ "failed") $ $) 18)) (-4305 (($ $) 49)) (-1678 (((-420 $) $) 50)) (-2671 (($) 16 T CONST)) (-2925 (((-3 $ "failed") $) 33)) (-3927 (((-121) $) 51)) (-2735 (((-121) $) 30)) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-3848 (((-420 $) $) 48)) (-2595 (((-3 $ "failed") $ $) 41)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42)) (-4078 (((-763)) 28)) (-1826 (((-121) $ $) 38)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
+((-3166 (((-121)) 14)) (-3349 (((-1249) (-634 |#1|) (-634 |#1|)) 18) (((-1249) (-634 |#1|)) 19)) (-3791 (((-121) |#1| |#1|) 30 (|has| |#1| (-842)))) (-3796 (((-121) |#1| |#1| (-1 (-121) |#1| |#1|)) 26) (((-3 (-121) "failed") |#1| |#1|) 24)) (-1382 ((|#1| (-634 |#1|)) 31 (|has| |#1| (-842))) ((|#1| (-634 |#1|) (-1 (-121) |#1| |#1|)) 27)) (-3849 (((-2 (|:| -3544 (-634 |#1|)) (|:| -3043 (-634 |#1|)))) 16))) 
+(((-1196 |#1|) (-10 -7 (-15 -3349 ((-1249) (-634 |#1|))) (-15 -3349 ((-1249) (-634 |#1|) (-634 |#1|))) (-15 -3849 ((-2 (|:| -3544 (-634 |#1|)) (|:| -3043 (-634 |#1|))))) (-15 -3796 ((-3 (-121) "failed") |#1| |#1|)) (-15 -3796 ((-121) |#1| |#1| (-1 (-121) |#1| |#1|))) (-15 -1382 (|#1| (-634 |#1|) (-1 (-121) |#1| |#1|))) (-15 -3166 ((-121))) (IF (|has| |#1| (-842)) (PROGN (-15 -1382 (|#1| (-634 |#1|))) (-15 -3791 ((-121) |#1| |#1|))) |noBranch|)) (-1090)) (T -1196)) 
+((-3791 (*1 *2 *3 *3) (-12 (-5 *2 (-121)) (-5 *1 (-1196 *3)) (-4 *3 (-842)) (-4 *3 (-1090)))) (-1382 (*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-1090)) (-4 *2 (-842)) (-5 *1 (-1196 *2)))) (-3166 (*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1196 *3)) (-4 *3 (-1090)))) (-1382 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *2)) (-5 *4 (-1 (-121) *2 *2)) (-5 *1 (-1196 *2)) (-4 *2 (-1090)))) (-3796 (*1 *2 *3 *3 *4) (-12 (-5 *4 (-1 (-121) *3 *3)) (-4 *3 (-1090)) (-5 *2 (-121)) (-5 *1 (-1196 *3)))) (-3796 (*1 *2 *3 *3) (|partial| -12 (-5 *2 (-121)) (-5 *1 (-1196 *3)) (-4 *3 (-1090)))) (-3849 (*1 *2) (-12 (-5 *2 (-2 (|:| -3544 (-634 *3)) (|:| -3043 (-634 *3)))) (-5 *1 (-1196 *3)) (-4 *3 (-1090)))) (-3349 (*1 *2 *3 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1090)) (-5 *2 (-1249)) (-5 *1 (-1196 *4)))) (-3349 (*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1090)) (-5 *2 (-1249)) (-5 *1 (-1196 *4))))) 
+(-10 -7 (-15 -3349 ((-1249) (-634 |#1|))) (-15 -3349 ((-1249) (-634 |#1|) (-634 |#1|))) (-15 -3849 ((-2 (|:| -3544 (-634 |#1|)) (|:| -3043 (-634 |#1|))))) (-15 -3796 ((-3 (-121) "failed") |#1| |#1|)) (-15 -3796 ((-121) |#1| |#1| (-1 (-121) |#1| |#1|))) (-15 -1382 (|#1| (-634 |#1|) (-1 (-121) |#1| |#1|))) (-15 -3166 ((-121))) (IF (|has| |#1| (-842)) (PROGN (-15 -1382 (|#1| (-634 |#1|))) (-15 -3791 ((-121) |#1| |#1|))) |noBranch|)) 
+((-4411 (((-1249) (-634 (-1161)) (-634 (-1161))) 12) (((-1249) (-634 (-1161))) 10)) (-1726 (((-1249)) 13)) (-3960 (((-2 (|:| -3043 (-634 (-1161))) (|:| -3544 (-634 (-1161))))) 17))) 
+(((-1197) (-10 -7 (-15 -4411 ((-1249) (-634 (-1161)))) (-15 -4411 ((-1249) (-634 (-1161)) (-634 (-1161)))) (-15 -3960 ((-2 (|:| -3043 (-634 (-1161))) (|:| -3544 (-634 (-1161)))))) (-15 -1726 ((-1249))))) (T -1197)) 
+((-1726 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1197)))) (-3960 (*1 *2) (-12 (-5 *2 (-2 (|:| -3043 (-634 (-1161))) (|:| -3544 (-634 (-1161))))) (-5 *1 (-1197)))) (-4411 (*1 *2 *3 *3) (-12 (-5 *3 (-634 (-1161))) (-5 *2 (-1249)) (-5 *1 (-1197)))) (-4411 (*1 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-5 *2 (-1249)) (-5 *1 (-1197))))) 
+(-10 -7 (-15 -4411 ((-1249) (-634 (-1161)))) (-15 -4411 ((-1249) (-634 (-1161)) (-634 (-1161)))) (-15 -3960 ((-2 (|:| -3043 (-634 (-1161))) (|:| -3544 (-634 (-1161)))))) (-15 -1726 ((-1249)))) 
+((-3045 (($ $) 16)) (-2197 (((-121) $) 23))) 
+(((-1198 |#1|) (-10 -8 (-15 -3045 (|#1| |#1|)) (-15 -2197 ((-121) |#1|))) (-1199)) (T -1198)) 
+NIL 
+(-10 -8 (-15 -3045 (|#1| |#1|)) (-15 -2197 ((-121) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-2689 (((-3 $ "failed") $ $) 18)) (-3045 (($ $) 49)) (-3498 (((-420 $) $) 50)) (-4490 (($) 16 T CONST)) (-2902 (((-3 $ "failed") $) 33)) (-2197 (((-121) $) 51)) (-1598 (((-121) $) 30)) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-3850 (((-420 $) $) 48)) (-2597 (((-3 $ "failed") $ $) 41)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42)) (-3425 (((-763)) 28)) (-2273 (((-121) $ $) 38)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23))) 
 (((-1199) (-1275)) (T -1199)) 
-((-3927 (*1 *2 *1) (-12 (-4 *1 (-1199)) (-5 *2 (-121)))) (-1678 (*1 *2 *1) (-12 (-5 *2 (-420 *1)) (-4 *1 (-1199)))) (-4305 (*1 *1 *1) (-4 *1 (-1199))) (-3848 (*1 *2 *1) (-12 (-5 *2 (-420 *1)) (-4 *1 (-1199))))) 
-(-13 (-453) (-10 -8 (-15 -3927 ((-121) $)) (-15 -1678 ((-420 $) $)) (-15 -4305 ($ $)) (-15 -3848 ((-420 $) $)))) 
+((-2197 (*1 *2 *1) (-12 (-4 *1 (-1199)) (-5 *2 (-121)))) (-3498 (*1 *2 *1) (-12 (-5 *2 (-420 *1)) (-4 *1 (-1199)))) (-3045 (*1 *1 *1) (-4 *1 (-1199))) (-3850 (*1 *2 *1) (-12 (-5 *2 (-420 *1)) (-4 *1 (-1199))))) 
+(-13 (-453) (-10 -8 (-15 -2197 ((-121) $)) (-15 -3498 ((-420 $) $)) (-15 -3045 ($ $)) (-15 -3850 ((-420 $) $)))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 $) . T) ((-105) . T) ((-120 $ $) . T) ((-137) . T) ((-608 (-850)) . T) ((-172) . T) ((-285) . T) ((-453) . T) ((-558) . T) ((-637 $) . T) ((-707 $) . T) ((-716) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-1775 (((-1201 |#1|) (-1201 |#1|) (-1201 |#1|)) 15))) 
-(((-1200 |#1|) (-10 -7 (-15 -1775 ((-1201 |#1|) (-1201 |#1|) (-1201 |#1|)))) (-1047)) (T -1200)) 
-((-1775 (*1 *2 *2 *2) (-12 (-5 *2 (-1201 *3)) (-4 *3 (-1047)) (-5 *1 (-1200 *3))))) 
-(-10 -7 (-15 -1775 ((-1201 |#1|) (-1201 |#1|) (-1201 |#1|)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2055 (((-634 (-1075)) $) NIL)) (-1305 (((-1161) $) NIL)) (-3196 (((-1216 (QUOTE |x|) |#1|) $ (-763)) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-2617 (($ $ (-763)) NIL) (($ $ (-763) (-763)) NIL)) (-2583 (((-1141 (-2 (|:| |k| (-763)) (|:| |c| |#1|))) $) NIL)) (-1982 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1933 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3134 (((-3 $ "failed") $ $) NIL)) (-1902 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1974 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2786 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3728 (($ (-1141 (-2 (|:| |k| (-763)) (|:| |c| |#1|)))) NIL) (($ (-1141 |#1|)) NIL)) (-1990 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1941 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2671 (($) NIL T CONST)) (-2129 (($ $) NIL)) (-2114 (($ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3490 (($ $) NIL)) (-1367 (((-953 |#1|) $ (-763)) NIL) (((-953 |#1|) $ (-763) (-763)) NIL)) (-3992 (((-121) $) NIL)) (-1897 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4477 (((-763) $) NIL) (((-763) $ (-763)) NIL)) (-2735 (((-121) $) NIL)) (-2011 (($ $) NIL)) (-4044 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2651 (($ (-568) (-568) $) NIL)) (-3536 (($ $ (-917)) NIL)) (-1716 (($ (-1 |#1| (-568)) $) NIL)) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| (-763)) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-4416 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-4487 (((-1143) $) NIL)) (-3730 (($ $) NIL)) (-2608 (($ $) NIL)) (-4053 (($ (-568) (-568) $) NIL)) (-3837 (($ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) NIL (-2198 (-12 (|has| |#1| (-15 -3837 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2055 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181))))) (($ $ (-1240 (QUOTE |x|))) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4022 (((-1108) $) NIL)) (-2224 (($ $ (-568) (-568)) NIL)) (-1807 (($ $ (-763)) NIL)) (-2595 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-1892 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2372 (($ $) NIL)) (-1339 (((-1141 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-763)))))) (-2779 ((|#1| $ (-763)) NIL) (($ $ $) NIL (|has| (-763) (-1102)))) (-4189 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $ (-1240 (QUOTE |x|))) NIL)) (-3206 (((-763) $) NIL)) (-1994 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1945 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1986 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1937 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1978 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2790 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1811 (($ $) NIL)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $) NIL (|has| |#1| (-558))) (($ |#1|) NIL (|has| |#1| (-172))) (($ (-1216 (QUOTE |x|) |#1|)) NIL) (($ (-1240 (QUOTE |x|))) NIL)) (-1302 (((-1141 |#1|) $) NIL)) (-2604 ((|#1| $ (-763)) NIL)) (-4371 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-4078 (((-763)) NIL)) (-1374 ((|#1| $) NIL)) (-2006 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1958 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1998 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1949 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2014 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1966 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3996 ((|#1| $ (-763)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-763)))) (|has| |#1| (-15 -2745 (|#1| (-1161))))))) (-4023 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1970 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2010 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1962 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2002 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1953 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) NIL T CONST)) (-3190 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ |#1|) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
-(((-1201 |#1|) (-13 (-1234 |#1|) (-10 -8 (-15 -2745 ($ (-1216 (QUOTE |x|) |#1|))) (-15 -3196 ((-1216 (QUOTE |x|) |#1|) $ (-763))) (-15 -2745 ($ (-1240 (QUOTE |x|)))) (-15 -4189 ($ $ (-1240 (QUOTE |x|)))) (-15 -2608 ($ $)) (-15 -3730 ($ $)) (-15 -2011 ($ $)) (-15 -2372 ($ $)) (-15 -2224 ($ $ (-568) (-568))) (-15 -2129 ($ $)) (-15 -2651 ($ (-568) (-568) $)) (-15 -4053 ($ (-568) (-568) $)) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -3837 ($ $ (-1240 (QUOTE |x|)))) |noBranch|))) (-1047)) (T -1201)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1216 (QUOTE |x|) *3)) (-4 *3 (-1047)) (-5 *1 (-1201 *3)))) (-3196 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1216 (QUOTE |x|) *4)) (-5 *1 (-1201 *4)) (-4 *4 (-1047)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-1240 (QUOTE |x|))) (-5 *1 (-1201 *3)) (-4 *3 (-1047)))) (-4189 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 (QUOTE |x|))) (-5 *1 (-1201 *3)) (-4 *3 (-1047)))) (-2608 (*1 *1 *1) (-12 (-5 *1 (-1201 *2)) (-4 *2 (-1047)))) (-3730 (*1 *1 *1) (-12 (-5 *1 (-1201 *2)) (-4 *2 (-1047)))) (-2011 (*1 *1 *1) (-12 (-5 *1 (-1201 *2)) (-4 *2 (-1047)))) (-2372 (*1 *1 *1) (-12 (-5 *1 (-1201 *2)) (-4 *2 (-1047)))) (-2224 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1201 *3)) (-4 *3 (-1047)))) (-2129 (*1 *1 *1) (-12 (-5 *1 (-1201 *2)) (-4 *2 (-1047)))) (-2651 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1201 *3)) (-4 *3 (-1047)))) (-4053 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1201 *3)) (-4 *3 (-1047)))) (-3837 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 (QUOTE |x|))) (-5 *1 (-1201 *3)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047))))) 
-(-13 (-1234 |#1|) (-10 -8 (-15 -2745 ($ (-1216 (QUOTE |x|) |#1|))) (-15 -3196 ((-1216 (QUOTE |x|) |#1|) $ (-763))) (-15 -2745 ($ (-1240 (QUOTE |x|)))) (-15 -4189 ($ $ (-1240 (QUOTE |x|)))) (-15 -2608 ($ $)) (-15 -3730 ($ $)) (-15 -2011 ($ $)) (-15 -2372 ($ $)) (-15 -2224 ($ $ (-568) (-568))) (-15 -2129 ($ $)) (-15 -2651 ($ (-568) (-568) $)) (-15 -4053 ($ (-568) (-568) $)) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -3837 ($ $ (-1240 (QUOTE |x|)))) |noBranch|))) 
-((-2795 (((-1207 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1207 |#1| |#3| |#5|)) 23))) 
-(((-1202 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -2795 ((-1207 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1207 |#1| |#3| |#5|)))) (-1047) (-1047) (-1161) (-1161) |#1| |#2|) (T -1202)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1207 *5 *7 *9)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-14 *7 (-1161)) (-14 *9 *5) (-14 *10 *6) (-5 *2 (-1207 *6 *8 *10)) (-5 *1 (-1202 *5 *6 *7 *8 *9 *10)) (-14 *8 (-1161))))) 
-(-10 -7 (-15 -2795 ((-1207 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1207 |#1| |#3| |#5|)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-2055 (((-634 (-1075)) $) 70)) (-1305 (((-1161) $) 98)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 50 (|has| |#1| (-558)))) (-2227 (($ $) 51 (|has| |#1| (-558)))) (-1573 (((-121) $) 53 (|has| |#1| (-558)))) (-2617 (($ $ (-568)) 93) (($ $ (-568) (-568)) 92)) (-2583 (((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) 100)) (-1982 (($ $) 127 (|has| |#1| (-43 (-409 (-568)))))) (-1933 (($ $) 110 (|has| |#1| (-43 (-409 (-568)))))) (-3134 (((-3 $ "failed") $ $) 18)) (-4305 (($ $) 154 (|has| |#1| (-365)))) (-1678 (((-420 $) $) 155 (|has| |#1| (-365)))) (-1902 (($ $) 109 (|has| |#1| (-43 (-409 (-568)))))) (-1497 (((-121) $ $) 145 (|has| |#1| (-365)))) (-1974 (($ $) 126 (|has| |#1| (-43 (-409 (-568)))))) (-2786 (($ $) 111 (|has| |#1| (-43 (-409 (-568)))))) (-3728 (($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) 166)) (-1990 (($ $) 125 (|has| |#1| (-43 (-409 (-568)))))) (-1941 (($ $) 112 (|has| |#1| (-43 (-409 (-568)))))) (-2671 (($) 16 T CONST)) (-2401 (($ $ $) 149 (|has| |#1| (-365)))) (-2114 (($ $) 59)) (-2925 (((-3 $ "failed") $) 33)) (-4446 (((-409 (-953 |#1|)) $ (-568)) 164 (|has| |#1| (-558))) (((-409 (-953 |#1|)) $ (-568) (-568)) 163 (|has| |#1| (-558)))) (-2412 (($ $ $) 148 (|has| |#1| (-365)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 143 (|has| |#1| (-365)))) (-3927 (((-121) $) 156 (|has| |#1| (-365)))) (-3992 (((-121) $) 69)) (-1897 (($) 137 (|has| |#1| (-43 (-409 (-568)))))) (-4477 (((-568) $) 95) (((-568) $ (-568)) 94)) (-2735 (((-121) $) 30)) (-4044 (($ $ (-568)) 108 (|has| |#1| (-43 (-409 (-568)))))) (-3536 (($ $ (-917)) 96)) (-1716 (($ (-1 |#1| (-568)) $) 165)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 152 (|has| |#1| (-365)))) (-3921 (((-121) $) 61)) (-2047 (($ |#1| (-568)) 60) (($ $ (-1075) (-568)) 72) (($ $ (-634 (-1075)) (-634 (-568))) 71)) (-2795 (($ (-1 |#1| |#1|) $) 62)) (-4416 (($ $) 134 (|has| |#1| (-43 (-409 (-568)))))) (-2097 (($ $) 64)) (-2102 ((|#1| $) 65)) (-2495 (($ (-634 $)) 141 (|has| |#1| (-365))) (($ $ $) 140 (|has| |#1| (-365)))) (-4487 (((-1143) $) 9)) (-2081 (($ $) 157 (|has| |#1| (-365)))) (-3837 (($ $) 162 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) 161 (-2198 (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-959)) (|has| |#1| (-1181)) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-15 -2055 ((-634 (-1161)) |#1|))) (|has| |#1| (-15 -3837 (|#1| |#1| (-1161)))) (|has| |#1| (-43 (-409 (-568)))))))) (-4022 (((-1108) $) 10)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 142 (|has| |#1| (-365)))) (-2721 (($ (-634 $)) 139 (|has| |#1| (-365))) (($ $ $) 138 (|has| |#1| (-365)))) (-3848 (((-420 $) $) 153 (|has| |#1| (-365)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 151 (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 150 (|has| |#1| (-365)))) (-1807 (($ $ (-568)) 90)) (-2595 (((-3 $ "failed") $ $) 49 (|has| |#1| (-558)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 144 (|has| |#1| (-365)))) (-1892 (($ $) 135 (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| (-568)))))) (-2709 (((-763) $) 146 (|has| |#1| (-365)))) (-2779 ((|#1| $ (-568)) 99) (($ $ $) 76 (|has| (-568) (-1102)))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 147 (|has| |#1| (-365)))) (-4189 (($ $ (-634 (-1161)) (-634 (-763))) 84 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-1161) (-763)) 83 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161))) 82 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-1161)) 81 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-763)) 79 (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $) 77 (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (-3206 (((-568) $) 63)) (-1994 (($ $) 124 (|has| |#1| (-43 (-409 (-568)))))) (-1945 (($ $) 113 (|has| |#1| (-43 (-409 (-568)))))) (-1986 (($ $) 123 (|has| |#1| (-43 (-409 (-568)))))) (-1937 (($ $) 114 (|has| |#1| (-43 (-409 (-568)))))) (-1978 (($ $) 122 (|has| |#1| (-43 (-409 (-568)))))) (-2790 (($ $) 115 (|has| |#1| (-43 (-409 (-568)))))) (-1811 (($ $) 68)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 46 (|has| |#1| (-172))) (($ (-409 (-568))) 56 (|has| |#1| (-43 (-409 (-568))))) (($ $) 48 (|has| |#1| (-558)))) (-2604 ((|#1| $ (-568)) 58)) (-4371 (((-3 $ "failed") $) 47 (|has| |#1| (-148)))) (-4078 (((-763)) 28)) (-1374 ((|#1| $) 97)) (-2006 (($ $) 133 (|has| |#1| (-43 (-409 (-568)))))) (-1958 (($ $) 121 (|has| |#1| (-43 (-409 (-568)))))) (-1826 (((-121) $ $) 52 (|has| |#1| (-558)))) (-1998 (($ $) 132 (|has| |#1| (-43 (-409 (-568)))))) (-1949 (($ $) 120 (|has| |#1| (-43 (-409 (-568)))))) (-2014 (($ $) 131 (|has| |#1| (-43 (-409 (-568)))))) (-1966 (($ $) 119 (|has| |#1| (-43 (-409 (-568)))))) (-3996 ((|#1| $ (-568)) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-568)))) (|has| |#1| (-15 -2745 (|#1| (-1161))))))) (-4023 (($ $) 130 (|has| |#1| (-43 (-409 (-568)))))) (-1970 (($ $) 118 (|has| |#1| (-43 (-409 (-568)))))) (-2010 (($ $) 129 (|has| |#1| (-43 (-409 (-568)))))) (-1962 (($ $) 117 (|has| |#1| (-43 (-409 (-568)))))) (-2002 (($ $) 128 (|has| |#1| (-43 (-409 (-568)))))) (-1953 (($ $) 116 (|has| |#1| (-43 (-409 (-568)))))) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 158 (|has| |#1| (-365)))) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $ (-634 (-1161)) (-634 (-763))) 88 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-1161) (-763)) 87 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161))) 86 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-1161)) 85 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-763)) 80 (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $) 78 (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (-1717 (((-121) $ $) 6)) (-1779 (($ $ |#1|) 57 (|has| |#1| (-365))) (($ $ $) 160 (|has| |#1| (-365)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 159 (|has| |#1| (-365))) (($ $ $) 136 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 107 (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-409 (-568)) $) 55 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 54 (|has| |#1| (-43 (-409 (-568))))))) 
+((-3992 (((-1201 |#1|) (-1201 |#1|) (-1201 |#1|)) 15))) 
+(((-1200 |#1|) (-10 -7 (-15 -3992 ((-1201 |#1|) (-1201 |#1|) (-1201 |#1|)))) (-1047)) (T -1200)) 
+((-3992 (*1 *2 *2 *2) (-12 (-5 *2 (-1201 *3)) (-4 *3 (-1047)) (-5 *1 (-1200 *3))))) 
+(-10 -7 (-15 -3992 ((-1201 |#1|) (-1201 |#1|) (-1201 |#1|)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2057 (((-634 (-1075)) $) NIL)) (-3325 (((-1161) $) NIL)) (-1802 (((-1216 (QUOTE |x|) |#1|) $ (-763)) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-4179 (($ $ (-763)) NIL) (($ $ (-763) (-763)) NIL)) (-2013 (((-1141 (-2 (|:| |k| (-763)) (|:| |c| |#1|))) $) NIL)) (-1984 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1935 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2689 (((-3 $ "failed") $ $) NIL)) (-1904 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1976 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2788 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2512 (($ (-1141 (-2 (|:| |k| (-763)) (|:| |c| |#1|)))) NIL) (($ (-1141 |#1|)) NIL)) (-1992 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1943 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4490 (($) NIL T CONST)) (-3409 (($ $) NIL)) (-2116 (($ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-3866 (($ $) NIL)) (-3808 (((-953 |#1|) $ (-763)) NIL) (((-953 |#1|) $ (-763) (-763)) NIL)) (-1302 (((-121) $) NIL)) (-1899 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1844 (((-763) $) NIL) (((-763) $ (-763)) NIL)) (-1598 (((-121) $) NIL)) (-1304 (($ $) NIL)) (-1550 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4384 (($ (-568) (-568) $) NIL)) (-4168 (($ $ (-917)) NIL)) (-3698 (($ (-1 |#1| (-568)) $) NIL)) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| (-763)) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-4418 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-1893 (((-1143) $) NIL)) (-2517 (($ $) NIL)) (-2101 (($ $) NIL)) (-1588 (($ (-568) (-568) $) NIL)) (-1845 (($ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) NIL (-2199 (-12 (|has| |#1| (-15 -1845 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2057 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181))))) (($ $ (-1240 (QUOTE |x|))) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4025 (((-1108) $) NIL)) (-3638 (($ $ (-568) (-568)) NIL)) (-2168 (($ $ (-763)) NIL)) (-2597 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-1894 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4109 (($ $) NIL)) (-1339 (((-1141 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-763)))))) (-2781 ((|#1| $ (-763)) NIL) (($ $ $) NIL (|has| (-763) (-1102)))) (-4191 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $ (-1240 (QUOTE |x|))) NIL)) (-1836 (((-763) $) NIL)) (-1996 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1947 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1988 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1939 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1980 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2792 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2188 (($ $) NIL)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $) NIL (|has| |#1| (-558))) (($ |#1|) NIL (|has| |#1| (-172))) (($ (-1216 (QUOTE |x|) |#1|)) NIL) (($ (-1240 (QUOTE |x|))) NIL)) (-3304 (((-1141 |#1|) $) NIL)) (-2079 ((|#1| $ (-763)) NIL)) (-3385 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-3425 (((-763)) NIL)) (-1374 ((|#1| $) NIL)) (-2008 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1959 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2000 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1951 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2016 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1968 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3999 ((|#1| $ (-763)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-763)))) (|has| |#1| (-15 -2747 (|#1| (-1161))))))) (-1439 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1972 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2012 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1964 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2004 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1955 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) NIL T CONST)) (-3192 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ |#1|) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
+(((-1201 |#1|) (-13 (-1234 |#1|) (-10 -8 (-15 -2747 ($ (-1216 (QUOTE |x|) |#1|))) (-15 -1802 ((-1216 (QUOTE |x|) |#1|) $ (-763))) (-15 -2747 ($ (-1240 (QUOTE |x|)))) (-15 -4191 ($ $ (-1240 (QUOTE |x|)))) (-15 -2101 ($ $)) (-15 -2517 ($ $)) (-15 -1304 ($ $)) (-15 -4109 ($ $)) (-15 -3638 ($ $ (-568) (-568))) (-15 -3409 ($ $)) (-15 -4384 ($ (-568) (-568) $)) (-15 -1588 ($ (-568) (-568) $)) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -1845 ($ $ (-1240 (QUOTE |x|)))) |noBranch|))) (-1047)) (T -1201)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1216 (QUOTE |x|) *3)) (-4 *3 (-1047)) (-5 *1 (-1201 *3)))) (-1802 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1216 (QUOTE |x|) *4)) (-5 *1 (-1201 *4)) (-4 *4 (-1047)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-1240 (QUOTE |x|))) (-5 *1 (-1201 *3)) (-4 *3 (-1047)))) (-4191 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 (QUOTE |x|))) (-5 *1 (-1201 *3)) (-4 *3 (-1047)))) (-2101 (*1 *1 *1) (-12 (-5 *1 (-1201 *2)) (-4 *2 (-1047)))) (-2517 (*1 *1 *1) (-12 (-5 *1 (-1201 *2)) (-4 *2 (-1047)))) (-1304 (*1 *1 *1) (-12 (-5 *1 (-1201 *2)) (-4 *2 (-1047)))) (-4109 (*1 *1 *1) (-12 (-5 *1 (-1201 *2)) (-4 *2 (-1047)))) (-3638 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1201 *3)) (-4 *3 (-1047)))) (-3409 (*1 *1 *1) (-12 (-5 *1 (-1201 *2)) (-4 *2 (-1047)))) (-4384 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1201 *3)) (-4 *3 (-1047)))) (-1588 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1201 *3)) (-4 *3 (-1047)))) (-1845 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 (QUOTE |x|))) (-5 *1 (-1201 *3)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047))))) 
+(-13 (-1234 |#1|) (-10 -8 (-15 -2747 ($ (-1216 (QUOTE |x|) |#1|))) (-15 -1802 ((-1216 (QUOTE |x|) |#1|) $ (-763))) (-15 -2747 ($ (-1240 (QUOTE |x|)))) (-15 -4191 ($ $ (-1240 (QUOTE |x|)))) (-15 -2101 ($ $)) (-15 -2517 ($ $)) (-15 -1304 ($ $)) (-15 -4109 ($ $)) (-15 -3638 ($ $ (-568) (-568))) (-15 -3409 ($ $)) (-15 -4384 ($ (-568) (-568) $)) (-15 -1588 ($ (-568) (-568) $)) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -1845 ($ $ (-1240 (QUOTE |x|)))) |noBranch|))) 
+((-2797 (((-1207 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1207 |#1| |#3| |#5|)) 23))) 
+(((-1202 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -2797 ((-1207 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1207 |#1| |#3| |#5|)))) (-1047) (-1047) (-1161) (-1161) |#1| |#2|) (T -1202)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1207 *5 *7 *9)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-14 *7 (-1161)) (-14 *9 *5) (-14 *10 *6) (-5 *2 (-1207 *6 *8 *10)) (-5 *1 (-1202 *5 *6 *7 *8 *9 *10)) (-14 *8 (-1161))))) 
+(-10 -7 (-15 -2797 ((-1207 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1207 |#1| |#3| |#5|)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2057 (((-634 (-1075)) $) 70)) (-3325 (((-1161) $) 98)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 50 (|has| |#1| (-558)))) (-3661 (($ $) 51 (|has| |#1| (-558)))) (-4426 (((-121) $) 53 (|has| |#1| (-558)))) (-4179 (($ $ (-568)) 93) (($ $ (-568) (-568)) 92)) (-2013 (((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) 100)) (-1984 (($ $) 127 (|has| |#1| (-43 (-409 (-568)))))) (-1935 (($ $) 110 (|has| |#1| (-43 (-409 (-568)))))) (-2689 (((-3 $ "failed") $ $) 18)) (-3045 (($ $) 154 (|has| |#1| (-365)))) (-3498 (((-420 $) $) 155 (|has| |#1| (-365)))) (-1904 (($ $) 109 (|has| |#1| (-43 (-409 (-568)))))) (-2589 (((-121) $ $) 145 (|has| |#1| (-365)))) (-1976 (($ $) 126 (|has| |#1| (-43 (-409 (-568)))))) (-2788 (($ $) 111 (|has| |#1| (-43 (-409 (-568)))))) (-2512 (($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) 166)) (-1992 (($ $) 125 (|has| |#1| (-43 (-409 (-568)))))) (-1943 (($ $) 112 (|has| |#1| (-43 (-409 (-568)))))) (-4490 (($) 16 T CONST)) (-2403 (($ $ $) 149 (|has| |#1| (-365)))) (-2116 (($ $) 59)) (-2902 (((-3 $ "failed") $) 33)) (-1685 (((-409 (-953 |#1|)) $ (-568)) 164 (|has| |#1| (-558))) (((-409 (-953 |#1|)) $ (-568) (-568)) 163 (|has| |#1| (-558)))) (-2414 (($ $ $) 148 (|has| |#1| (-365)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 143 (|has| |#1| (-365)))) (-2197 (((-121) $) 156 (|has| |#1| (-365)))) (-1302 (((-121) $) 69)) (-1899 (($) 137 (|has| |#1| (-43 (-409 (-568)))))) (-1844 (((-568) $) 95) (((-568) $ (-568)) 94)) (-1598 (((-121) $) 30)) (-1550 (($ $ (-568)) 108 (|has| |#1| (-43 (-409 (-568)))))) (-4168 (($ $ (-917)) 96)) (-3698 (($ (-1 |#1| (-568)) $) 165)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 152 (|has| |#1| (-365)))) (-2171 (((-121) $) 61)) (-2049 (($ |#1| (-568)) 60) (($ $ (-1075) (-568)) 72) (($ $ (-634 (-1075)) (-634 (-568))) 71)) (-2797 (($ (-1 |#1| |#1|) $) 62)) (-4418 (($ $) 134 (|has| |#1| (-43 (-409 (-568)))))) (-2099 (($ $) 64)) (-2104 ((|#1| $) 65)) (-2498 (($ (-634 $)) 141 (|has| |#1| (-365))) (($ $ $) 140 (|has| |#1| (-365)))) (-1893 (((-1143) $) 9)) (-2083 (($ $) 157 (|has| |#1| (-365)))) (-1845 (($ $) 162 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) 161 (-2199 (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-959)) (|has| |#1| (-1181)) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-15 -2057 ((-634 (-1161)) |#1|))) (|has| |#1| (-15 -1845 (|#1| |#1| (-1161)))) (|has| |#1| (-43 (-409 (-568)))))))) (-4025 (((-1108) $) 10)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 142 (|has| |#1| (-365)))) (-2723 (($ (-634 $)) 139 (|has| |#1| (-365))) (($ $ $) 138 (|has| |#1| (-365)))) (-3850 (((-420 $) $) 153 (|has| |#1| (-365)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 151 (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 150 (|has| |#1| (-365)))) (-2168 (($ $ (-568)) 90)) (-2597 (((-3 $ "failed") $ $) 49 (|has| |#1| (-558)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 144 (|has| |#1| (-365)))) (-1894 (($ $) 135 (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| (-568)))))) (-1466 (((-763) $) 146 (|has| |#1| (-365)))) (-2781 ((|#1| $ (-568)) 99) (($ $ $) 76 (|has| (-568) (-1102)))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 147 (|has| |#1| (-365)))) (-4191 (($ $ (-634 (-1161)) (-634 (-763))) 84 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-1161) (-763)) 83 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161))) 82 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-1161)) 81 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-763)) 79 (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $) 77 (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (-1836 (((-568) $) 63)) (-1996 (($ $) 124 (|has| |#1| (-43 (-409 (-568)))))) (-1947 (($ $) 113 (|has| |#1| (-43 (-409 (-568)))))) (-1988 (($ $) 123 (|has| |#1| (-43 (-409 (-568)))))) (-1939 (($ $) 114 (|has| |#1| (-43 (-409 (-568)))))) (-1980 (($ $) 122 (|has| |#1| (-43 (-409 (-568)))))) (-2792 (($ $) 115 (|has| |#1| (-43 (-409 (-568)))))) (-2188 (($ $) 68)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 46 (|has| |#1| (-172))) (($ (-409 (-568))) 56 (|has| |#1| (-43 (-409 (-568))))) (($ $) 48 (|has| |#1| (-558)))) (-2079 ((|#1| $ (-568)) 58)) (-3385 (((-3 $ "failed") $) 47 (|has| |#1| (-148)))) (-3425 (((-763)) 28)) (-1374 ((|#1| $) 97)) (-2008 (($ $) 133 (|has| |#1| (-43 (-409 (-568)))))) (-1959 (($ $) 121 (|has| |#1| (-43 (-409 (-568)))))) (-2273 (((-121) $ $) 52 (|has| |#1| (-558)))) (-2000 (($ $) 132 (|has| |#1| (-43 (-409 (-568)))))) (-1951 (($ $) 120 (|has| |#1| (-43 (-409 (-568)))))) (-2016 (($ $) 131 (|has| |#1| (-43 (-409 (-568)))))) (-1968 (($ $) 119 (|has| |#1| (-43 (-409 (-568)))))) (-3999 ((|#1| $ (-568)) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-568)))) (|has| |#1| (-15 -2747 (|#1| (-1161))))))) (-1439 (($ $) 130 (|has| |#1| (-43 (-409 (-568)))))) (-1972 (($ $) 118 (|has| |#1| (-43 (-409 (-568)))))) (-2012 (($ $) 129 (|has| |#1| (-43 (-409 (-568)))))) (-1964 (($ $) 117 (|has| |#1| (-43 (-409 (-568)))))) (-2004 (($ $) 128 (|has| |#1| (-43 (-409 (-568)))))) (-1955 (($ $) 116 (|has| |#1| (-43 (-409 (-568)))))) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 158 (|has| |#1| (-365)))) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $ (-634 (-1161)) (-634 (-763))) 88 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-1161) (-763)) 87 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161))) 86 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-1161)) 85 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-763)) 80 (|has| |#1| (-15 * (|#1| (-568) |#1|)))) (($ $) 78 (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (-1719 (((-121) $ $) 6)) (-1781 (($ $ |#1|) 57 (|has| |#1| (-365))) (($ $ $) 160 (|has| |#1| (-365)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 159 (|has| |#1| (-365))) (($ $ $) 136 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 107 (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-409 (-568)) $) 55 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 54 (|has| |#1| (-43 (-409 (-568))))))) 
 (((-1203 |#1|) (-1275) (-1047)) (T -1203)) 
-((-3728 (*1 *1 *2) (-12 (-5 *2 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *3)))) (-4 *3 (-1047)) (-4 *1 (-1203 *3)))) (-1716 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-568))) (-4 *1 (-1203 *3)) (-4 *3 (-1047)))) (-4446 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1203 *4)) (-4 *4 (-1047)) (-4 *4 (-558)) (-5 *2 (-409 (-953 *4))))) (-4446 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1203 *4)) (-4 *4 (-1047)) (-4 *4 (-558)) (-5 *2 (-409 (-953 *4))))) (-3837 (*1 *1 *1) (-12 (-4 *1 (-1203 *2)) (-4 *2 (-1047)) (-4 *2 (-43 (-409 (-568)))))) (-3837 (*1 *1 *1 *2) (-2198 (-12 (-5 *2 (-1161)) (-4 *1 (-1203 *3)) (-4 *3 (-1047)) (-12 (-4 *3 (-29 (-568))) (-4 *3 (-959)) (-4 *3 (-1181)) (-4 *3 (-43 (-409 (-568)))))) (-12 (-5 *2 (-1161)) (-4 *1 (-1203 *3)) (-4 *3 (-1047)) (-12 (|has| *3 (-15 -2055 ((-634 *2) *3))) (|has| *3 (-15 -3837 (*3 *3 *2))) (-4 *3 (-43 (-409 (-568))))))))) 
-(-13 (-1221 |t#1| (-568)) (-10 -8 (-15 -3728 ($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |t#1|))))) (-15 -1716 ($ (-1 |t#1| (-568)) $)) (IF (|has| |t#1| (-558)) (PROGN (-15 -4446 ((-409 (-953 |t#1|)) $ (-568))) (-15 -4446 ((-409 (-953 |t#1|)) $ (-568) (-568)))) |noBranch|) (IF (|has| |t#1| (-43 (-409 (-568)))) (PROGN (-15 -3837 ($ $)) (IF (|has| |t#1| (-15 -3837 (|t#1| |t#1| (-1161)))) (IF (|has| |t#1| (-15 -2055 ((-634 (-1161)) |t#1|))) (-15 -3837 ($ $ (-1161))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-1181)) (IF (|has| |t#1| (-959)) (IF (|has| |t#1| (-29 (-568))) (-15 -3837 ($ $ (-1161))) |noBranch|) |noBranch|) |noBranch|) (-6 (-1002)) (-6 (-1181))) |noBranch|) (IF (|has| |t#1| (-365)) (-6 (-365)) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| (-568)) . T) ((-25) . T) ((-43 (-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) -2198 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-40) |has| |#1| (-43 (-409 (-568)))) ((-98) |has| |#1| (-43 (-409 (-568)))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2198 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2198 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-225) |has| |#1| (-15 * (|#1| (-568) |#1|))) ((-238) |has| |#1| (-365)) ((-279) |has| |#1| (-43 (-409 (-568)))) ((-281 $ $) |has| (-568) (-1102)) ((-285) -2198 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-301) |has| |#1| (-365)) ((-365) |has| |#1| (-365)) ((-453) |has| |#1| (-365)) ((-502) |has| |#1| (-43 (-409 (-568)))) ((-558) -2198 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-637 (-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) -2198 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-716) . T) ((-895 (-1161)) -12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))) ((-974 |#1| (-568) (-1075)) . T) ((-916) |has| |#1| (-365)) ((-1002) |has| |#1| (-43 (-409 (-568)))) ((-1053 (-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-1053 |#1|) . T) ((-1053 $) -2198 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1181) |has| |#1| (-43 (-409 (-568)))) ((-1184) |has| |#1| (-43 (-409 (-568)))) ((-1199) |has| |#1| (-365)) ((-1221 |#1| (-568)) . T)) 
-((-2537 (((-121) $) 12)) (-3666 (((-3 |#3| "failed") $) 17) (((-3 (-1161) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 (-568) "failed") $) NIL)) (-2854 ((|#3| $) 14) (((-1161) $) NIL) (((-409 (-568)) $) NIL) (((-568) $) NIL))) 
-(((-1204 |#1| |#2| |#3|) (-10 -8 (-15 -2854 ((-568) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2854 ((-1161) |#1|)) (-15 -3666 ((-3 (-1161) "failed") |#1|)) (-15 -2854 (|#3| |#1|)) (-15 -3666 ((-3 |#3| "failed") |#1|)) (-15 -2537 ((-121) |#1|))) (-1205 |#2| |#3|) (-1047) (-1234 |#2|)) (T -1204)) 
-NIL 
-(-10 -8 (-15 -2854 ((-568) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2854 ((-1161) |#1|)) (-15 -3666 ((-3 (-1161) "failed") |#1|)) (-15 -2854 (|#3| |#1|)) (-15 -3666 ((-3 |#3| "failed") |#1|)) (-15 -2537 ((-121) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-1492 ((|#2| $) 219 (-2139 (|has| |#2| (-301)) (|has| |#1| (-365))))) (-2055 (((-634 (-1075)) $) 70)) (-1305 (((-1161) $) 98)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 50 (|has| |#1| (-558)))) (-2227 (($ $) 51 (|has| |#1| (-558)))) (-1573 (((-121) $) 53 (|has| |#1| (-558)))) (-2617 (($ $ (-568)) 93) (($ $ (-568) (-568)) 92)) (-2583 (((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) 100)) (-3613 ((|#2| $) 255)) (-4016 (((-3 |#2| "failed") $) 251)) (-2065 ((|#2| $) 252)) (-1982 (($ $) 127 (|has| |#1| (-43 (-409 (-568)))))) (-1933 (($ $) 110 (|has| |#1| (-43 (-409 (-568)))))) (-3134 (((-3 $ "failed") $ $) 18)) (-1750 (((-420 (-1157 $)) (-1157 $)) 228 (-2139 (|has| |#2| (-904)) (|has| |#1| (-365))))) (-4305 (($ $) 154 (|has| |#1| (-365)))) (-1678 (((-420 $) $) 155 (|has| |#1| (-365)))) (-1902 (($ $) 109 (|has| |#1| (-43 (-409 (-568)))))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 225 (-2139 (|has| |#2| (-904)) (|has| |#1| (-365))))) (-1497 (((-121) $ $) 145 (|has| |#1| (-365)))) (-1974 (($ $) 126 (|has| |#1| (-43 (-409 (-568)))))) (-2786 (($ $) 111 (|has| |#1| (-43 (-409 (-568)))))) (-3662 (((-568) $) 237 (-2139 (|has| |#2| (-815)) (|has| |#1| (-365))))) (-3728 (($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) 166)) (-1990 (($ $) 125 (|has| |#1| (-43 (-409 (-568)))))) (-1941 (($ $) 112 (|has| |#1| (-43 (-409 (-568)))))) (-2671 (($) 16 T CONST)) (-3666 (((-3 |#2| "failed") $) 258) (((-3 (-568) "failed") $) 247 (-2139 (|has| |#2| (-1037 (-568))) (|has| |#1| (-365)))) (((-3 (-409 (-568)) "failed") $) 245 (-2139 (|has| |#2| (-1037 (-568))) (|has| |#1| (-365)))) (((-3 (-1161) "failed") $) 230 (-2139 (|has| |#2| (-1037 (-1161))) (|has| |#1| (-365))))) (-2854 ((|#2| $) 257) (((-568) $) 248 (-2139 (|has| |#2| (-1037 (-568))) (|has| |#1| (-365)))) (((-409 (-568)) $) 246 (-2139 (|has| |#2| (-1037 (-568))) (|has| |#1| (-365)))) (((-1161) $) 231 (-2139 (|has| |#2| (-1037 (-1161))) (|has| |#1| (-365))))) (-1429 (($ $) 254) (($ (-568) $) 253)) (-2401 (($ $ $) 149 (|has| |#1| (-365)))) (-2114 (($ $) 59)) (-3164 (((-679 |#2|) (-679 $)) 209 (|has| |#1| (-365))) (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) 208 (|has| |#1| (-365))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 207 (-2139 (|has| |#2| (-630 (-568))) (|has| |#1| (-365)))) (((-679 (-568)) (-679 $)) 206 (-2139 (|has| |#2| (-630 (-568))) (|has| |#1| (-365))))) (-2925 (((-3 $ "failed") $) 33)) (-4446 (((-409 (-953 |#1|)) $ (-568)) 164 (|has| |#1| (-558))) (((-409 (-953 |#1|)) $ (-568) (-568)) 163 (|has| |#1| (-558)))) (-1731 (($) 221 (-2139 (|has| |#2| (-550)) (|has| |#1| (-365))))) (-2412 (($ $ $) 148 (|has| |#1| (-365)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 143 (|has| |#1| (-365)))) (-3927 (((-121) $) 156 (|has| |#1| (-365)))) (-2033 (((-121) $) 235 (-2139 (|has| |#2| (-815)) (|has| |#1| (-365))))) (-3992 (((-121) $) 69)) (-1897 (($) 137 (|has| |#1| (-43 (-409 (-568)))))) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 213 (-2139 (|has| |#2| (-881 (-381))) (|has| |#1| (-365)))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 212 (-2139 (|has| |#2| (-881 (-568))) (|has| |#1| (-365))))) (-4477 (((-568) $) 95) (((-568) $ (-568)) 94)) (-2735 (((-121) $) 30)) (-1332 (($ $) 217 (|has| |#1| (-365)))) (-2317 ((|#2| $) 215 (|has| |#1| (-365)))) (-4044 (($ $ (-568)) 108 (|has| |#1| (-43 (-409 (-568)))))) (-3038 (((-3 $ "failed") $) 249 (-2139 (|has| |#2| (-1136)) (|has| |#1| (-365))))) (-2245 (((-121) $) 236 (-2139 (|has| |#2| (-815)) (|has| |#1| (-365))))) (-3536 (($ $ (-917)) 96)) (-1716 (($ (-1 |#1| (-568)) $) 165)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 152 (|has| |#1| (-365)))) (-3921 (((-121) $) 61)) (-2047 (($ |#1| (-568)) 60) (($ $ (-1075) (-568)) 72) (($ $ (-634 (-1075)) (-634 (-568))) 71)) (-2521 (($ $ $) 239 (-2139 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-3268 (($ $ $) 240 (-2139 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-2795 (($ (-1 |#1| |#1|) $) 62) (($ (-1 |#2| |#2|) $) 201 (|has| |#1| (-365)))) (-4416 (($ $) 134 (|has| |#1| (-43 (-409 (-568)))))) (-2097 (($ $) 64)) (-2102 ((|#1| $) 65)) (-2495 (($ (-634 $)) 141 (|has| |#1| (-365))) (($ $ $) 140 (|has| |#1| (-365)))) (-2070 (($ (-568) |#2|) 256)) (-4487 (((-1143) $) 9)) (-2081 (($ $) 157 (|has| |#1| (-365)))) (-3837 (($ $) 162 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) 161 (-2198 (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-959)) (|has| |#1| (-1181)) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-15 -2055 ((-634 (-1161)) |#1|))) (|has| |#1| (-15 -3837 (|#1| |#1| (-1161)))) (|has| |#1| (-43 (-409 (-568)))))))) (-4434 (($) 250 (-2139 (|has| |#2| (-1136)) (|has| |#1| (-365))) CONST)) (-4022 (((-1108) $) 10)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 142 (|has| |#1| (-365)))) (-2721 (($ (-634 $)) 139 (|has| |#1| (-365))) (($ $ $) 138 (|has| |#1| (-365)))) (-3880 (($ $) 220 (-2139 (|has| |#2| (-301)) (|has| |#1| (-365))))) (-1519 ((|#2| $) 223 (-2139 (|has| |#2| (-550)) (|has| |#1| (-365))))) (-2905 (((-420 (-1157 $)) (-1157 $)) 226 (-2139 (|has| |#2| (-904)) (|has| |#1| (-365))))) (-3545 (((-420 (-1157 $)) (-1157 $)) 227 (-2139 (|has| |#2| (-904)) (|has| |#1| (-365))))) (-3848 (((-420 $) $) 153 (|has| |#1| (-365)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 151 (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 150 (|has| |#1| (-365)))) (-1807 (($ $ (-568)) 90)) (-2595 (((-3 $ "failed") $ $) 49 (|has| |#1| (-558)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 144 (|has| |#1| (-365)))) (-1892 (($ $) 135 (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| (-568))))) (($ $ (-1161) |#2|) 200 (-2139 (|has| |#2| (-523 (-1161) |#2|)) (|has| |#1| (-365)))) (($ $ (-634 (-1161)) (-634 |#2|)) 199 (-2139 (|has| |#2| (-523 (-1161) |#2|)) (|has| |#1| (-365)))) (($ $ (-634 (-288 |#2|))) 198 (-2139 (|has| |#2| (-303 |#2|)) (|has| |#1| (-365)))) (($ $ (-288 |#2|)) 197 (-2139 (|has| |#2| (-303 |#2|)) (|has| |#1| (-365)))) (($ $ |#2| |#2|) 196 (-2139 (|has| |#2| (-303 |#2|)) (|has| |#1| (-365)))) (($ $ (-634 |#2|) (-634 |#2|)) 195 (-2139 (|has| |#2| (-303 |#2|)) (|has| |#1| (-365))))) (-2709 (((-763) $) 146 (|has| |#1| (-365)))) (-2779 ((|#1| $ (-568)) 99) (($ $ $) 76 (|has| (-568) (-1102))) (($ $ |#2|) 194 (-2139 (|has| |#2| (-281 |#2| |#2|)) (|has| |#1| (-365))))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 147 (|has| |#1| (-365)))) (-4189 (($ $ (-1 |#2| |#2|)) 205 (|has| |#1| (-365))) (($ $ (-1 |#2| |#2|) (-763)) 204 (|has| |#1| (-365))) (($ $ (-763)) 79 (-2198 (-2139 (|has| |#2| (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $) 77 (-2198 (-2139 (|has| |#2| (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161)) (-634 (-763))) 84 (-2198 (-2139 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|)))))) (($ $ (-1161) (-763)) 83 (-2198 (-2139 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|)))))) (($ $ (-634 (-1161))) 82 (-2198 (-2139 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|)))))) (($ $ (-1161)) 81 (-2198 (-2139 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))))) (-3013 (($ $) 218 (|has| |#1| (-365)))) (-2324 ((|#2| $) 216 (|has| |#1| (-365)))) (-3206 (((-568) $) 63)) (-1994 (($ $) 124 (|has| |#1| (-43 (-409 (-568)))))) (-1945 (($ $) 113 (|has| |#1| (-43 (-409 (-568)))))) (-1986 (($ $) 123 (|has| |#1| (-43 (-409 (-568)))))) (-1937 (($ $) 114 (|has| |#1| (-43 (-409 (-568)))))) (-1978 (($ $) 122 (|has| |#1| (-43 (-409 (-568)))))) (-2790 (($ $) 115 (|has| |#1| (-43 (-409 (-568)))))) (-4278 (((-215) $) 234 (-2139 (|has| |#2| (-1021)) (|has| |#1| (-365)))) (((-381) $) 233 (-2139 (|has| |#2| (-1021)) (|has| |#1| (-365)))) (((-541) $) 232 (-2139 (|has| |#2| (-609 (-541))) (|has| |#1| (-365)))) (((-887 (-381)) $) 211 (-2139 (|has| |#2| (-609 (-887 (-381)))) (|has| |#1| (-365)))) (((-887 (-568)) $) 210 (-2139 (|has| |#2| (-609 (-887 (-568)))) (|has| |#1| (-365))))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) 224 (-2139 (-2139 (|has| $ (-148)) (|has| |#2| (-904))) (|has| |#1| (-365))))) (-1811 (($ $) 68)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 46 (|has| |#1| (-172))) (($ |#2|) 259) (($ (-1161)) 229 (-2139 (|has| |#2| (-1037 (-1161))) (|has| |#1| (-365)))) (($ (-409 (-568))) 56 (|has| |#1| (-43 (-409 (-568))))) (($ $) 48 (|has| |#1| (-558)))) (-2604 ((|#1| $ (-568)) 58)) (-4371 (((-3 $ "failed") $) 47 (-2198 (-2139 (-2198 (|has| |#2| (-148)) (-2139 (|has| $ (-148)) (|has| |#2| (-904)))) (|has| |#1| (-365))) (|has| |#1| (-148))))) (-4078 (((-763)) 28)) (-1374 ((|#1| $) 97)) (-2285 ((|#2| $) 222 (-2139 (|has| |#2| (-550)) (|has| |#1| (-365))))) (-2006 (($ $) 133 (|has| |#1| (-43 (-409 (-568)))))) (-1958 (($ $) 121 (|has| |#1| (-43 (-409 (-568)))))) (-1826 (((-121) $ $) 52 (|has| |#1| (-558)))) (-1998 (($ $) 132 (|has| |#1| (-43 (-409 (-568)))))) (-1949 (($ $) 120 (|has| |#1| (-43 (-409 (-568)))))) (-2014 (($ $) 131 (|has| |#1| (-43 (-409 (-568)))))) (-1966 (($ $) 119 (|has| |#1| (-43 (-409 (-568)))))) (-3996 ((|#1| $ (-568)) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-568)))) (|has| |#1| (-15 -2745 (|#1| (-1161))))))) (-4023 (($ $) 130 (|has| |#1| (-43 (-409 (-568)))))) (-1970 (($ $) 118 (|has| |#1| (-43 (-409 (-568)))))) (-2010 (($ $) 129 (|has| |#1| (-43 (-409 (-568)))))) (-1962 (($ $) 117 (|has| |#1| (-43 (-409 (-568)))))) (-2002 (($ $) 128 (|has| |#1| (-43 (-409 (-568)))))) (-1953 (($ $) 116 (|has| |#1| (-43 (-409 (-568)))))) (-2897 (($ $) 238 (-2139 (|has| |#2| (-815)) (|has| |#1| (-365))))) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 158 (|has| |#1| (-365)))) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $ (-1 |#2| |#2|)) 203 (|has| |#1| (-365))) (($ $ (-1 |#2| |#2|) (-763)) 202 (|has| |#1| (-365))) (($ $ (-763)) 80 (-2198 (-2139 (|has| |#2| (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $) 78 (-2198 (-2139 (|has| |#2| (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161)) (-634 (-763))) 88 (-2198 (-2139 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|)))))) (($ $ (-1161) (-763)) 87 (-2198 (-2139 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|)))))) (($ $ (-634 (-1161))) 86 (-2198 (-2139 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|)))))) (($ $ (-1161)) 85 (-2198 (-2139 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))))) (-1751 (((-121) $ $) 242 (-2139 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-1738 (((-121) $ $) 243 (-2139 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 241 (-2139 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-1732 (((-121) $ $) 244 (-2139 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-1779 (($ $ |#1|) 57 (|has| |#1| (-365))) (($ $ $) 160 (|has| |#1| (-365))) (($ |#2| |#2|) 214 (|has| |#1| (-365)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 159 (|has| |#1| (-365))) (($ $ $) 136 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 107 (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ $ |#2|) 193 (|has| |#1| (-365))) (($ |#2| $) 192 (|has| |#1| (-365))) (($ (-409 (-568)) $) 55 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 54 (|has| |#1| (-43 (-409 (-568))))))) 
+((-2512 (*1 *1 *2) (-12 (-5 *2 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *3)))) (-4 *3 (-1047)) (-4 *1 (-1203 *3)))) (-3698 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-568))) (-4 *1 (-1203 *3)) (-4 *3 (-1047)))) (-1685 (*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1203 *4)) (-4 *4 (-1047)) (-4 *4 (-558)) (-5 *2 (-409 (-953 *4))))) (-1685 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1203 *4)) (-4 *4 (-1047)) (-4 *4 (-558)) (-5 *2 (-409 (-953 *4))))) (-1845 (*1 *1 *1) (-12 (-4 *1 (-1203 *2)) (-4 *2 (-1047)) (-4 *2 (-43 (-409 (-568)))))) (-1845 (*1 *1 *1 *2) (-2199 (-12 (-5 *2 (-1161)) (-4 *1 (-1203 *3)) (-4 *3 (-1047)) (-12 (-4 *3 (-29 (-568))) (-4 *3 (-959)) (-4 *3 (-1181)) (-4 *3 (-43 (-409 (-568)))))) (-12 (-5 *2 (-1161)) (-4 *1 (-1203 *3)) (-4 *3 (-1047)) (-12 (|has| *3 (-15 -2057 ((-634 *2) *3))) (|has| *3 (-15 -1845 (*3 *3 *2))) (-4 *3 (-43 (-409 (-568))))))))) 
+(-13 (-1221 |t#1| (-568)) (-10 -8 (-15 -2512 ($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |t#1|))))) (-15 -3698 ($ (-1 |t#1| (-568)) $)) (IF (|has| |t#1| (-558)) (PROGN (-15 -1685 ((-409 (-953 |t#1|)) $ (-568))) (-15 -1685 ((-409 (-953 |t#1|)) $ (-568) (-568)))) |noBranch|) (IF (|has| |t#1| (-43 (-409 (-568)))) (PROGN (-15 -1845 ($ $)) (IF (|has| |t#1| (-15 -1845 (|t#1| |t#1| (-1161)))) (IF (|has| |t#1| (-15 -2057 ((-634 (-1161)) |t#1|))) (-15 -1845 ($ $ (-1161))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-1181)) (IF (|has| |t#1| (-959)) (IF (|has| |t#1| (-29 (-568))) (-15 -1845 ($ $ (-1161))) |noBranch|) |noBranch|) |noBranch|) (-6 (-1002)) (-6 (-1181))) |noBranch|) (IF (|has| |t#1| (-365)) (-6 (-365)) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| (-568)) . T) ((-25) . T) ((-43 (-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) -2199 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-40) |has| |#1| (-43 (-409 (-568)))) ((-98) |has| |#1| (-43 (-409 (-568)))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2199 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2199 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-225) |has| |#1| (-15 * (|#1| (-568) |#1|))) ((-238) |has| |#1| (-365)) ((-279) |has| |#1| (-43 (-409 (-568)))) ((-281 $ $) |has| (-568) (-1102)) ((-285) -2199 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-301) |has| |#1| (-365)) ((-365) |has| |#1| (-365)) ((-453) |has| |#1| (-365)) ((-502) |has| |#1| (-43 (-409 (-568)))) ((-558) -2199 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-637 (-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) -2199 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-716) . T) ((-895 (-1161)) -12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))) ((-974 |#1| (-568) (-1075)) . T) ((-916) |has| |#1| (-365)) ((-1002) |has| |#1| (-43 (-409 (-568)))) ((-1053 (-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-1053 |#1|) . T) ((-1053 $) -2199 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1181) |has| |#1| (-43 (-409 (-568)))) ((-1184) |has| |#1| (-43 (-409 (-568)))) ((-1199) |has| |#1| (-365)) ((-1221 |#1| (-568)) . T)) 
+((-1819 (((-121) $) 12)) (-3668 (((-3 |#3| "failed") $) 17) (((-3 (-1161) "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 (-568) "failed") $) NIL)) (-2857 ((|#3| $) 14) (((-1161) $) NIL) (((-409 (-568)) $) NIL) (((-568) $) NIL))) 
+(((-1204 |#1| |#2| |#3|) (-10 -8 (-15 -2857 ((-568) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2857 ((-1161) |#1|)) (-15 -3668 ((-3 (-1161) "failed") |#1|)) (-15 -2857 (|#3| |#1|)) (-15 -3668 ((-3 |#3| "failed") |#1|)) (-15 -1819 ((-121) |#1|))) (-1205 |#2| |#3|) (-1047) (-1234 |#2|)) (T -1204)) 
+NIL 
+(-10 -8 (-15 -2857 ((-568) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2857 ((-1161) |#1|)) (-15 -3668 ((-3 (-1161) "failed") |#1|)) (-15 -2857 (|#3| |#1|)) (-15 -3668 ((-3 |#3| "failed") |#1|)) (-15 -1819 ((-121) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2563 ((|#2| $) 219 (-2141 (|has| |#2| (-301)) (|has| |#1| (-365))))) (-2057 (((-634 (-1075)) $) 70)) (-3325 (((-1161) $) 98)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 50 (|has| |#1| (-558)))) (-3661 (($ $) 51 (|has| |#1| (-558)))) (-4426 (((-121) $) 53 (|has| |#1| (-558)))) (-4179 (($ $ (-568)) 93) (($ $ (-568) (-568)) 92)) (-2013 (((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) 100)) (-3054 ((|#2| $) 255)) (-1415 (((-3 |#2| "failed") $) 251)) (-2067 ((|#2| $) 252)) (-1984 (($ $) 127 (|has| |#1| (-43 (-409 (-568)))))) (-1935 (($ $) 110 (|has| |#1| (-43 (-409 (-568)))))) (-2689 (((-3 $ "failed") $ $) 18)) (-3863 (((-420 (-1157 $)) (-1157 $)) 228 (-2141 (|has| |#2| (-904)) (|has| |#1| (-365))))) (-3045 (($ $) 154 (|has| |#1| (-365)))) (-3498 (((-420 $) $) 155 (|has| |#1| (-365)))) (-1904 (($ $) 109 (|has| |#1| (-43 (-409 (-568)))))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 225 (-2141 (|has| |#2| (-904)) (|has| |#1| (-365))))) (-2589 (((-121) $ $) 145 (|has| |#1| (-365)))) (-1976 (($ $) 126 (|has| |#1| (-43 (-409 (-568)))))) (-2788 (($ $) 111 (|has| |#1| (-43 (-409 (-568)))))) (-3337 (((-568) $) 237 (-2141 (|has| |#2| (-815)) (|has| |#1| (-365))))) (-2512 (($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) 166)) (-1992 (($ $) 125 (|has| |#1| (-43 (-409 (-568)))))) (-1943 (($ $) 112 (|has| |#1| (-43 (-409 (-568)))))) (-4490 (($) 16 T CONST)) (-3668 (((-3 |#2| "failed") $) 258) (((-3 (-568) "failed") $) 247 (-2141 (|has| |#2| (-1037 (-568))) (|has| |#1| (-365)))) (((-3 (-409 (-568)) "failed") $) 245 (-2141 (|has| |#2| (-1037 (-568))) (|has| |#1| (-365)))) (((-3 (-1161) "failed") $) 230 (-2141 (|has| |#2| (-1037 (-1161))) (|has| |#1| (-365))))) (-2857 ((|#2| $) 257) (((-568) $) 248 (-2141 (|has| |#2| (-1037 (-568))) (|has| |#1| (-365)))) (((-409 (-568)) $) 246 (-2141 (|has| |#2| (-1037 (-568))) (|has| |#1| (-365)))) (((-1161) $) 231 (-2141 (|has| |#2| (-1037 (-1161))) (|has| |#1| (-365))))) (-2232 (($ $) 254) (($ (-568) $) 253)) (-2403 (($ $ $) 149 (|has| |#1| (-365)))) (-2116 (($ $) 59)) (-1668 (((-679 |#2|) (-679 $)) 209 (|has| |#1| (-365))) (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) 208 (|has| |#1| (-365))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 207 (-2141 (|has| |#2| (-630 (-568))) (|has| |#1| (-365)))) (((-679 (-568)) (-679 $)) 206 (-2141 (|has| |#2| (-630 (-568))) (|has| |#1| (-365))))) (-2902 (((-3 $ "failed") $) 33)) (-1685 (((-409 (-953 |#1|)) $ (-568)) 164 (|has| |#1| (-558))) (((-409 (-953 |#1|)) $ (-568) (-568)) 163 (|has| |#1| (-558)))) (-1733 (($) 221 (-2141 (|has| |#2| (-550)) (|has| |#1| (-365))))) (-2414 (($ $ $) 148 (|has| |#1| (-365)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 143 (|has| |#1| (-365)))) (-2197 (((-121) $) 156 (|has| |#1| (-365)))) (-1436 (((-121) $) 235 (-2141 (|has| |#2| (-815)) (|has| |#1| (-365))))) (-1302 (((-121) $) 69)) (-1899 (($) 137 (|has| |#1| (-43 (-409 (-568)))))) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 213 (-2141 (|has| |#2| (-881 (-381))) (|has| |#1| (-365)))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 212 (-2141 (|has| |#2| (-881 (-568))) (|has| |#1| (-365))))) (-1844 (((-568) $) 95) (((-568) $ (-568)) 94)) (-1598 (((-121) $) 30)) (-3539 (($ $) 217 (|has| |#1| (-365)))) (-2319 ((|#2| $) 215 (|has| |#1| (-365)))) (-1550 (($ $ (-568)) 108 (|has| |#1| (-43 (-409 (-568)))))) (-2214 (((-3 $ "failed") $) 249 (-2141 (|has| |#2| (-1136)) (|has| |#1| (-365))))) (-2859 (((-121) $) 236 (-2141 (|has| |#2| (-815)) (|has| |#1| (-365))))) (-4168 (($ $ (-917)) 96)) (-3698 (($ (-1 |#1| (-568)) $) 165)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 152 (|has| |#1| (-365)))) (-2171 (((-121) $) 61)) (-2049 (($ |#1| (-568)) 60) (($ $ (-1075) (-568)) 72) (($ $ (-634 (-1075)) (-634 (-568))) 71)) (-1732 (($ $ $) 239 (-2141 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-2047 (($ $ $) 240 (-2141 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-2797 (($ (-1 |#1| |#1|) $) 62) (($ (-1 |#2| |#2|) $) 201 (|has| |#1| (-365)))) (-4418 (($ $) 134 (|has| |#1| (-43 (-409 (-568)))))) (-2099 (($ $) 64)) (-2104 ((|#1| $) 65)) (-2498 (($ (-634 $)) 141 (|has| |#1| (-365))) (($ $ $) 140 (|has| |#1| (-365)))) (-2072 (($ (-568) |#2|) 256)) (-1893 (((-1143) $) 9)) (-2083 (($ $) 157 (|has| |#1| (-365)))) (-1845 (($ $) 162 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) 161 (-2199 (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-959)) (|has| |#1| (-1181)) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-15 -2057 ((-634 (-1161)) |#1|))) (|has| |#1| (-15 -1845 (|#1| |#1| (-1161)))) (|has| |#1| (-43 (-409 (-568)))))))) (-4436 (($) 250 (-2141 (|has| |#2| (-1136)) (|has| |#1| (-365))) CONST)) (-4025 (((-1108) $) 10)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 142 (|has| |#1| (-365)))) (-2723 (($ (-634 $)) 139 (|has| |#1| (-365))) (($ $ $) 138 (|has| |#1| (-365)))) (-1999 (($ $) 220 (-2141 (|has| |#2| (-301)) (|has| |#1| (-365))))) (-4115 ((|#2| $) 223 (-2141 (|has| |#2| (-550)) (|has| |#1| (-365))))) (-2841 (((-420 (-1157 $)) (-1157 $)) 226 (-2141 (|has| |#2| (-904)) (|has| |#1| (-365))))) (-2795 (((-420 (-1157 $)) (-1157 $)) 227 (-2141 (|has| |#2| (-904)) (|has| |#1| (-365))))) (-3850 (((-420 $) $) 153 (|has| |#1| (-365)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 151 (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 150 (|has| |#1| (-365)))) (-2168 (($ $ (-568)) 90)) (-2597 (((-3 $ "failed") $ $) 49 (|has| |#1| (-558)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 144 (|has| |#1| (-365)))) (-1894 (($ $) 135 (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| (-568))))) (($ $ (-1161) |#2|) 200 (-2141 (|has| |#2| (-523 (-1161) |#2|)) (|has| |#1| (-365)))) (($ $ (-634 (-1161)) (-634 |#2|)) 199 (-2141 (|has| |#2| (-523 (-1161) |#2|)) (|has| |#1| (-365)))) (($ $ (-634 (-288 |#2|))) 198 (-2141 (|has| |#2| (-303 |#2|)) (|has| |#1| (-365)))) (($ $ (-288 |#2|)) 197 (-2141 (|has| |#2| (-303 |#2|)) (|has| |#1| (-365)))) (($ $ |#2| |#2|) 196 (-2141 (|has| |#2| (-303 |#2|)) (|has| |#1| (-365)))) (($ $ (-634 |#2|) (-634 |#2|)) 195 (-2141 (|has| |#2| (-303 |#2|)) (|has| |#1| (-365))))) (-1466 (((-763) $) 146 (|has| |#1| (-365)))) (-2781 ((|#1| $ (-568)) 99) (($ $ $) 76 (|has| (-568) (-1102))) (($ $ |#2|) 194 (-2141 (|has| |#2| (-281 |#2| |#2|)) (|has| |#1| (-365))))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 147 (|has| |#1| (-365)))) (-4191 (($ $ (-1 |#2| |#2|)) 205 (|has| |#1| (-365))) (($ $ (-1 |#2| |#2|) (-763)) 204 (|has| |#1| (-365))) (($ $ (-763)) 79 (-2199 (-2141 (|has| |#2| (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $) 77 (-2199 (-2141 (|has| |#2| (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161)) (-634 (-763))) 84 (-2199 (-2141 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|)))))) (($ $ (-1161) (-763)) 83 (-2199 (-2141 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|)))))) (($ $ (-634 (-1161))) 82 (-2199 (-2141 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|)))))) (($ $ (-1161)) 81 (-2199 (-2141 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))))) (-3210 (($ $) 218 (|has| |#1| (-365)))) (-2326 ((|#2| $) 216 (|has| |#1| (-365)))) (-1836 (((-568) $) 63)) (-1996 (($ $) 124 (|has| |#1| (-43 (-409 (-568)))))) (-1947 (($ $) 113 (|has| |#1| (-43 (-409 (-568)))))) (-1988 (($ $) 123 (|has| |#1| (-43 (-409 (-568)))))) (-1939 (($ $) 114 (|has| |#1| (-43 (-409 (-568)))))) (-1980 (($ $) 122 (|has| |#1| (-43 (-409 (-568)))))) (-2792 (($ $) 115 (|has| |#1| (-43 (-409 (-568)))))) (-4280 (((-215) $) 234 (-2141 (|has| |#2| (-1021)) (|has| |#1| (-365)))) (((-381) $) 233 (-2141 (|has| |#2| (-1021)) (|has| |#1| (-365)))) (((-541) $) 232 (-2141 (|has| |#2| (-609 (-541))) (|has| |#1| (-365)))) (((-887 (-381)) $) 211 (-2141 (|has| |#2| (-609 (-887 (-381)))) (|has| |#1| (-365)))) (((-887 (-568)) $) 210 (-2141 (|has| |#2| (-609 (-887 (-568)))) (|has| |#1| (-365))))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) 224 (-2141 (-2141 (|has| $ (-148)) (|has| |#2| (-904))) (|has| |#1| (-365))))) (-2188 (($ $) 68)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 46 (|has| |#1| (-172))) (($ |#2|) 259) (($ (-1161)) 229 (-2141 (|has| |#2| (-1037 (-1161))) (|has| |#1| (-365)))) (($ (-409 (-568))) 56 (|has| |#1| (-43 (-409 (-568))))) (($ $) 48 (|has| |#1| (-558)))) (-2079 ((|#1| $ (-568)) 58)) (-3385 (((-3 $ "failed") $) 47 (-2199 (-2141 (-2199 (|has| |#2| (-148)) (-2141 (|has| $ (-148)) (|has| |#2| (-904)))) (|has| |#1| (-365))) (|has| |#1| (-148))))) (-3425 (((-763)) 28)) (-1374 ((|#1| $) 97)) (-3520 ((|#2| $) 222 (-2141 (|has| |#2| (-550)) (|has| |#1| (-365))))) (-2008 (($ $) 133 (|has| |#1| (-43 (-409 (-568)))))) (-1959 (($ $) 121 (|has| |#1| (-43 (-409 (-568)))))) (-2273 (((-121) $ $) 52 (|has| |#1| (-558)))) (-2000 (($ $) 132 (|has| |#1| (-43 (-409 (-568)))))) (-1951 (($ $) 120 (|has| |#1| (-43 (-409 (-568)))))) (-2016 (($ $) 131 (|has| |#1| (-43 (-409 (-568)))))) (-1968 (($ $) 119 (|has| |#1| (-43 (-409 (-568)))))) (-3999 ((|#1| $ (-568)) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-568)))) (|has| |#1| (-15 -2747 (|#1| (-1161))))))) (-1439 (($ $) 130 (|has| |#1| (-43 (-409 (-568)))))) (-1972 (($ $) 118 (|has| |#1| (-43 (-409 (-568)))))) (-2012 (($ $) 129 (|has| |#1| (-43 (-409 (-568)))))) (-1964 (($ $) 117 (|has| |#1| (-43 (-409 (-568)))))) (-2004 (($ $) 128 (|has| |#1| (-43 (-409 (-568)))))) (-1955 (($ $) 116 (|has| |#1| (-43 (-409 (-568)))))) (-2811 (($ $) 238 (-2141 (|has| |#2| (-815)) (|has| |#1| (-365))))) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 158 (|has| |#1| (-365)))) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $ (-1 |#2| |#2|)) 203 (|has| |#1| (-365))) (($ $ (-1 |#2| |#2|) (-763)) 202 (|has| |#1| (-365))) (($ $ (-763)) 80 (-2199 (-2141 (|has| |#2| (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $) 78 (-2199 (-2141 (|has| |#2| (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161)) (-634 (-763))) 88 (-2199 (-2141 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|)))))) (($ $ (-1161) (-763)) 87 (-2199 (-2141 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|)))))) (($ $ (-634 (-1161))) 86 (-2199 (-2141 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|)))))) (($ $ (-1161)) 85 (-2199 (-2141 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))))) (-1753 (((-121) $ $) 242 (-2141 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-1740 (((-121) $ $) 243 (-2141 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 241 (-2141 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-1734 (((-121) $ $) 244 (-2141 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-1781 (($ $ |#1|) 57 (|has| |#1| (-365))) (($ $ $) 160 (|has| |#1| (-365))) (($ |#2| |#2|) 214 (|has| |#1| (-365)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 159 (|has| |#1| (-365))) (($ $ $) 136 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 107 (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ $ |#2|) 193 (|has| |#1| (-365))) (($ |#2| $) 192 (|has| |#1| (-365))) (($ (-409 (-568)) $) 55 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 54 (|has| |#1| (-43 (-409 (-568))))))) 
 (((-1205 |#1| |#2|) (-1275) (-1047) (-1234 |t#1|)) (T -1205)) 
-((-3206 (*1 *2 *1) (-12 (-4 *1 (-1205 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1234 *3)) (-5 *2 (-568)))) (-2745 (*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *1 (-1205 *3 *2)) (-4 *2 (-1234 *3)))) (-2070 (*1 *1 *2 *3) (-12 (-5 *2 (-568)) (-4 *4 (-1047)) (-4 *1 (-1205 *4 *3)) (-4 *3 (-1234 *4)))) (-3613 (*1 *2 *1) (-12 (-4 *1 (-1205 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1234 *3)))) (-1429 (*1 *1 *1) (-12 (-4 *1 (-1205 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-1234 *2)))) (-1429 (*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-4 *1 (-1205 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1234 *3)))) (-2065 (*1 *2 *1) (-12 (-4 *1 (-1205 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1234 *3)))) (-4016 (*1 *2 *1) (|partial| -12 (-4 *1 (-1205 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1234 *3))))) 
-(-13 (-1203 |t#1|) (-1037 |t#2|) (-10 -8 (-15 -2070 ($ (-568) |t#2|)) (-15 -3206 ((-568) $)) (-15 -3613 (|t#2| $)) (-15 -1429 ($ $)) (-15 -1429 ($ (-568) $)) (-15 -2745 ($ |t#2|)) (-15 -2065 (|t#2| $)) (-15 -4016 ((-3 |t#2| "failed") $)) (IF (|has| |t#1| (-365)) (-6 (-993 |t#2|)) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| (-568)) . T) ((-25) . T) ((-43 (-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-43 |#1|) |has| |#1| (-172)) ((-43 |#2|) |has| |#1| (-365)) ((-43 $) -2198 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-40) |has| |#1| (-43 (-409 (-568)))) ((-98) |has| |#1| (-43 (-409 (-568)))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-120 |#1| |#1|) . T) ((-120 |#2| |#2|) |has| |#1| (-365)) ((-120 $ $) -2198 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-137) . T) ((-148) -2198 (-12 (|has| |#1| (-365)) (|has| |#2| (-148))) (|has| |#1| (-148))) ((-150) -2198 (-12 (|has| |#1| (-365)) (|has| |#2| (-150))) (|has| |#1| (-150))) ((-608 (-850)) . T) ((-172) -2198 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-609 (-215)) -12 (|has| |#1| (-365)) (|has| |#2| (-1021))) ((-609 (-381)) -12 (|has| |#1| (-365)) (|has| |#2| (-1021))) ((-609 (-541)) -12 (|has| |#1| (-365)) (|has| |#2| (-609 (-541)))) ((-609 (-887 (-381))) -12 (|has| |#1| (-365)) (|has| |#2| (-609 (-887 (-381))))) ((-609 (-887 (-568))) -12 (|has| |#1| (-365)) (|has| |#2| (-609 (-887 (-568))))) ((-223 |#2|) |has| |#1| (-365)) ((-225) -2198 (-12 (|has| |#1| (-365)) (|has| |#2| (-225))) (|has| |#1| (-15 * (|#1| (-568) |#1|)))) ((-238) |has| |#1| (-365)) ((-279) |has| |#1| (-43 (-409 (-568)))) ((-281 |#2| $) -12 (|has| |#1| (-365)) (|has| |#2| (-281 |#2| |#2|))) ((-281 $ $) |has| (-568) (-1102)) ((-285) -2198 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-301) |has| |#1| (-365)) ((-303 |#2|) -12 (|has| |#1| (-365)) (|has| |#2| (-303 |#2|))) ((-365) |has| |#1| (-365)) ((-336 |#2|) |has| |#1| (-365)) ((-379 |#2|) |has| |#1| (-365)) ((-402 |#2|) |has| |#1| (-365)) ((-453) |has| |#1| (-365)) ((-502) |has| |#1| (-43 (-409 (-568)))) ((-523 (-1161) |#2|) -12 (|has| |#1| (-365)) (|has| |#2| (-523 (-1161) |#2|))) ((-523 |#2| |#2|) -12 (|has| |#1| (-365)) (|has| |#2| (-303 |#2|))) ((-558) -2198 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-637 (-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-637 |#1|) . T) ((-637 |#2|) |has| |#1| (-365)) ((-637 $) . T) ((-630 (-568)) -12 (|has| |#1| (-365)) (|has| |#2| (-630 (-568)))) ((-630 |#2|) |has| |#1| (-365)) ((-707 (-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-707 |#1|) |has| |#1| (-172)) ((-707 |#2|) |has| |#1| (-365)) ((-707 $) -2198 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-716) . T) ((-786) -12 (|has| |#1| (-365)) (|has| |#2| (-815))) ((-787) -12 (|has| |#1| (-365)) (|has| |#2| (-815))) ((-789) -12 (|has| |#1| (-365)) (|has| |#2| (-815))) ((-790) -12 (|has| |#1| (-365)) (|has| |#2| (-815))) ((-815) -12 (|has| |#1| (-365)) (|has| |#2| (-815))) ((-840) -12 (|has| |#1| (-365)) (|has| |#2| (-815))) ((-842) -2198 (-12 (|has| |#1| (-365)) (|has| |#2| (-842))) (-12 (|has| |#1| (-365)) (|has| |#2| (-815)))) ((-895 (-1161)) -2198 (-12 (|has| |#1| (-365)) (|has| |#2| (-895 (-1161)))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) ((-881 (-381)) -12 (|has| |#1| (-365)) (|has| |#2| (-881 (-381)))) ((-881 (-568)) -12 (|has| |#1| (-365)) (|has| |#2| (-881 (-568)))) ((-879 |#2|) |has| |#1| (-365)) ((-904) -12 (|has| |#1| (-365)) (|has| |#2| (-904))) ((-974 |#1| (-568) (-1075)) . T) ((-916) |has| |#1| (-365)) ((-993 |#2|) |has| |#1| (-365)) ((-1002) |has| |#1| (-43 (-409 (-568)))) ((-1021) -12 (|has| |#1| (-365)) (|has| |#2| (-1021))) ((-1037 (-409 (-568))) -12 (|has| |#1| (-365)) (|has| |#2| (-1037 (-568)))) ((-1037 (-568)) -12 (|has| |#1| (-365)) (|has| |#2| (-1037 (-568)))) ((-1037 (-1161)) -12 (|has| |#1| (-365)) (|has| |#2| (-1037 (-1161)))) ((-1037 |#2|) . T) ((-1053 (-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-1053 |#1|) . T) ((-1053 |#2|) |has| |#1| (-365)) ((-1053 $) -2198 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1136) -12 (|has| |#1| (-365)) (|has| |#2| (-1136))) ((-1181) |has| |#1| (-43 (-409 (-568)))) ((-1184) |has| |#1| (-43 (-409 (-568)))) ((-1195) |has| |#1| (-365)) ((-1199) |has| |#1| (-365)) ((-1203 |#1|) . T) ((-1221 |#1| (-568)) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 70)) (-1492 ((|#2| $) NIL (-12 (|has| |#2| (-301)) (|has| |#1| (-365))))) (-2055 (((-634 (-1075)) $) NIL)) (-1305 (((-1161) $) 88)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-2617 (($ $ (-568)) 97) (($ $ (-568) (-568)) 99)) (-2583 (((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) 47)) (-3613 ((|#2| $) 11)) (-4016 (((-3 |#2| "failed") $) 30)) (-2065 ((|#2| $) 31)) (-1982 (($ $) 192 (|has| |#1| (-43 (-409 (-568)))))) (-1933 (($ $) 168 (|has| |#1| (-43 (-409 (-568)))))) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| |#2| (-904)) (|has| |#1| (-365))))) (-4305 (($ $) NIL (|has| |#1| (-365)))) (-1678 (((-420 $) $) NIL (|has| |#1| (-365)))) (-1902 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (-12 (|has| |#2| (-904)) (|has| |#1| (-365))))) (-1497 (((-121) $ $) NIL (|has| |#1| (-365)))) (-1974 (($ $) 188 (|has| |#1| (-43 (-409 (-568)))))) (-2786 (($ $) 164 (|has| |#1| (-43 (-409 (-568)))))) (-3662 (((-568) $) NIL (-12 (|has| |#2| (-815)) (|has| |#1| (-365))))) (-3728 (($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) 57)) (-1990 (($ $) 196 (|has| |#1| (-43 (-409 (-568)))))) (-1941 (($ $) 172 (|has| |#1| (-43 (-409 (-568)))))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#2| "failed") $) 144) (((-3 (-568) "failed") $) NIL (-12 (|has| |#2| (-1037 (-568))) (|has| |#1| (-365)))) (((-3 (-409 (-568)) "failed") $) NIL (-12 (|has| |#2| (-1037 (-568))) (|has| |#1| (-365)))) (((-3 (-1161) "failed") $) NIL (-12 (|has| |#2| (-1037 (-1161))) (|has| |#1| (-365))))) (-2854 ((|#2| $) 143) (((-568) $) NIL (-12 (|has| |#2| (-1037 (-568))) (|has| |#1| (-365)))) (((-409 (-568)) $) NIL (-12 (|has| |#2| (-1037 (-568))) (|has| |#1| (-365)))) (((-1161) $) NIL (-12 (|has| |#2| (-1037 (-1161))) (|has| |#1| (-365))))) (-1429 (($ $) 61) (($ (-568) $) 24)) (-2401 (($ $ $) NIL (|has| |#1| (-365)))) (-2114 (($ $) NIL)) (-3164 (((-679 |#2|) (-679 $)) NIL (|has| |#1| (-365))) (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL (|has| |#1| (-365))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (-12 (|has| |#2| (-630 (-568))) (|has| |#1| (-365)))) (((-679 (-568)) (-679 $)) NIL (-12 (|has| |#2| (-630 (-568))) (|has| |#1| (-365))))) (-2925 (((-3 $ "failed") $) 77)) (-4446 (((-409 (-953 |#1|)) $ (-568)) 112 (|has| |#1| (-558))) (((-409 (-953 |#1|)) $ (-568) (-568)) 114 (|has| |#1| (-558)))) (-1731 (($) NIL (-12 (|has| |#2| (-550)) (|has| |#1| (-365))))) (-2412 (($ $ $) NIL (|has| |#1| (-365)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-3927 (((-121) $) NIL (|has| |#1| (-365)))) (-2033 (((-121) $) NIL (-12 (|has| |#2| (-815)) (|has| |#1| (-365))))) (-3992 (((-121) $) 64)) (-1897 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| |#2| (-881 (-381))) (|has| |#1| (-365)))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| |#2| (-881 (-568))) (|has| |#1| (-365))))) (-4477 (((-568) $) 93) (((-568) $ (-568)) 95)) (-2735 (((-121) $) NIL)) (-1332 (($ $) NIL (|has| |#1| (-365)))) (-2317 ((|#2| $) 151 (|has| |#1| (-365)))) (-4044 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3038 (((-3 $ "failed") $) NIL (-12 (|has| |#2| (-1136)) (|has| |#1| (-365))))) (-2245 (((-121) $) NIL (-12 (|has| |#2| (-815)) (|has| |#1| (-365))))) (-3536 (($ $ (-917)) 136)) (-1716 (($ (-1 |#1| (-568)) $) 132)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| (-568)) 19) (($ $ (-1075) (-568)) NIL) (($ $ (-634 (-1075)) (-634 (-568))) NIL)) (-2521 (($ $ $) NIL (-12 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-3268 (($ $ $) NIL (-12 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-2795 (($ (-1 |#1| |#1|) $) 129) (($ (-1 |#2| |#2|) $) NIL (|has| |#1| (-365)))) (-4416 (($ $) 162 (|has| |#1| (-43 (-409 (-568)))))) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-2495 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-2070 (($ (-568) |#2|) 10)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) 145 (|has| |#1| (-365)))) (-3837 (($ $) 214 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) 219 (-2198 (-12 (|has| |#1| (-15 -3837 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2055 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181)))))) (-4434 (($) NIL (-12 (|has| |#2| (-1136)) (|has| |#1| (-365))) CONST)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-365)))) (-2721 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-3880 (($ $) NIL (-12 (|has| |#2| (-301)) (|has| |#1| (-365))))) (-1519 ((|#2| $) NIL (-12 (|has| |#2| (-550)) (|has| |#1| (-365))))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| |#2| (-904)) (|has| |#1| (-365))))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| |#2| (-904)) (|has| |#1| (-365))))) (-3848 (((-420 $) $) NIL (|has| |#1| (-365)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-365)))) (-1807 (($ $ (-568)) 126)) (-2595 (((-3 $ "failed") $ $) 116 (|has| |#1| (-558)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1892 (($ $) 160 (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) 85 (|has| |#1| (-15 ** (|#1| |#1| (-568))))) (($ $ (-1161) |#2|) NIL (-12 (|has| |#2| (-523 (-1161) |#2|)) (|has| |#1| (-365)))) (($ $ (-634 (-1161)) (-634 |#2|)) NIL (-12 (|has| |#2| (-523 (-1161) |#2|)) (|has| |#1| (-365)))) (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#1| (-365)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#1| (-365)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#1| (-365)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#1| (-365))))) (-2709 (((-763) $) NIL (|has| |#1| (-365)))) (-2779 ((|#1| $ (-568)) 91) (($ $ $) 79 (|has| (-568) (-1102))) (($ $ |#2|) NIL (-12 (|has| |#2| (-281 |#2| |#2|)) (|has| |#1| (-365))))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-365)))) (-4189 (($ $ (-1 |#2| |#2|)) NIL (|has| |#1| (-365))) (($ $ (-1 |#2| |#2|) (-763)) NIL (|has| |#1| (-365))) (($ $ (-763)) NIL (-2198 (-12 (|has| |#2| (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $) 137 (-2198 (-12 (|has| |#2| (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-2198 (-12 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161) (-763)) NIL (-2198 (-12 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-634 (-1161))) NIL (-2198 (-12 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161)) 140 (-2198 (-12 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))))) (-3013 (($ $) NIL (|has| |#1| (-365)))) (-2324 ((|#2| $) 152 (|has| |#1| (-365)))) (-3206 (((-568) $) 12)) (-1994 (($ $) 198 (|has| |#1| (-43 (-409 (-568)))))) (-1945 (($ $) 174 (|has| |#1| (-43 (-409 (-568)))))) (-1986 (($ $) 194 (|has| |#1| (-43 (-409 (-568)))))) (-1937 (($ $) 170 (|has| |#1| (-43 (-409 (-568)))))) (-1978 (($ $) 190 (|has| |#1| (-43 (-409 (-568)))))) (-2790 (($ $) 166 (|has| |#1| (-43 (-409 (-568)))))) (-4278 (((-215) $) NIL (-12 (|has| |#2| (-1021)) (|has| |#1| (-365)))) (((-381) $) NIL (-12 (|has| |#2| (-1021)) (|has| |#1| (-365)))) (((-541) $) NIL (-12 (|has| |#2| (-609 (-541))) (|has| |#1| (-365)))) (((-887 (-381)) $) NIL (-12 (|has| |#2| (-609 (-887 (-381)))) (|has| |#1| (-365)))) (((-887 (-568)) $) NIL (-12 (|has| |#2| (-609 (-887 (-568)))) (|has| |#1| (-365))))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#2| (-904)) (|has| |#1| (-365))))) (-1811 (($ $) 124)) (-2745 (((-850) $) 242) (($ (-568)) 23) (($ |#1|) 21 (|has| |#1| (-172))) (($ |#2|) 20) (($ (-1161)) NIL (-12 (|has| |#2| (-1037 (-1161))) (|has| |#1| (-365)))) (($ (-409 (-568))) 155 (|has| |#1| (-43 (-409 (-568))))) (($ $) NIL (|has| |#1| (-558)))) (-2604 ((|#1| $ (-568)) 74)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| |#2| (-904)) (|has| |#1| (-365))) (-12 (|has| |#2| (-148)) (|has| |#1| (-365))) (|has| |#1| (-148))))) (-4078 (((-763)) 142)) (-1374 ((|#1| $) 90)) (-2285 ((|#2| $) NIL (-12 (|has| |#2| (-550)) (|has| |#1| (-365))))) (-2006 (($ $) 204 (|has| |#1| (-43 (-409 (-568)))))) (-1958 (($ $) 180 (|has| |#1| (-43 (-409 (-568)))))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1998 (($ $) 200 (|has| |#1| (-43 (-409 (-568)))))) (-1949 (($ $) 176 (|has| |#1| (-43 (-409 (-568)))))) (-2014 (($ $) 208 (|has| |#1| (-43 (-409 (-568)))))) (-1966 (($ $) 184 (|has| |#1| (-43 (-409 (-568)))))) (-3996 ((|#1| $ (-568)) 122 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-568)))) (|has| |#1| (-15 -2745 (|#1| (-1161))))))) (-4023 (($ $) 210 (|has| |#1| (-43 (-409 (-568)))))) (-1970 (($ $) 186 (|has| |#1| (-43 (-409 (-568)))))) (-2010 (($ $) 206 (|has| |#1| (-43 (-409 (-568)))))) (-1962 (($ $) 182 (|has| |#1| (-43 (-409 (-568)))))) (-2002 (($ $) 202 (|has| |#1| (-43 (-409 (-568)))))) (-1953 (($ $) 178 (|has| |#1| (-43 (-409 (-568)))))) (-2897 (($ $) NIL (-12 (|has| |#2| (-815)) (|has| |#1| (-365))))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (-3056 (($) 13 T CONST)) (-1556 (($) 17 T CONST)) (-3190 (($ $ (-1 |#2| |#2|)) NIL (|has| |#1| (-365))) (($ $ (-1 |#2| |#2|) (-763)) NIL (|has| |#1| (-365))) (($ $ (-763)) NIL (-2198 (-12 (|has| |#2| (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $) NIL (-2198 (-12 (|has| |#2| (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-2198 (-12 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161) (-763)) NIL (-2198 (-12 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-634 (-1161))) NIL (-2198 (-12 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161)) NIL (-2198 (-12 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))))) (-1751 (((-121) $ $) NIL (-12 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-1738 (((-121) $ $) NIL (-12 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-1717 (((-121) $ $) 63)) (-1745 (((-121) $ $) NIL (-12 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-1732 (((-121) $ $) NIL (-12 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365))) (($ $ $) 149 (|has| |#1| (-365))) (($ |#2| |#2|) 150 (|has| |#1| (-365)))) (-1773 (($ $) 213) (($ $ $) 68)) (-1767 (($ $ $) 66)) (** (($ $ (-917)) NIL) (($ $ (-763)) 73) (($ $ (-568)) 146 (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 158 (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 69) (($ $ |#1|) NIL) (($ |#1| $) 139) (($ $ |#2|) 148 (|has| |#1| (-365))) (($ |#2| $) 147 (|has| |#1| (-365))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
+((-1836 (*1 *2 *1) (-12 (-4 *1 (-1205 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1234 *3)) (-5 *2 (-568)))) (-2747 (*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *1 (-1205 *3 *2)) (-4 *2 (-1234 *3)))) (-2072 (*1 *1 *2 *3) (-12 (-5 *2 (-568)) (-4 *4 (-1047)) (-4 *1 (-1205 *4 *3)) (-4 *3 (-1234 *4)))) (-3054 (*1 *2 *1) (-12 (-4 *1 (-1205 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1234 *3)))) (-2232 (*1 *1 *1) (-12 (-4 *1 (-1205 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-1234 *2)))) (-2232 (*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-4 *1 (-1205 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1234 *3)))) (-2067 (*1 *2 *1) (-12 (-4 *1 (-1205 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1234 *3)))) (-1415 (*1 *2 *1) (|partial| -12 (-4 *1 (-1205 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1234 *3))))) 
+(-13 (-1203 |t#1|) (-1037 |t#2|) (-10 -8 (-15 -2072 ($ (-568) |t#2|)) (-15 -1836 ((-568) $)) (-15 -3054 (|t#2| $)) (-15 -2232 ($ $)) (-15 -2232 ($ (-568) $)) (-15 -2747 ($ |t#2|)) (-15 -2067 (|t#2| $)) (-15 -1415 ((-3 |t#2| "failed") $)) (IF (|has| |t#1| (-365)) (-6 (-993 |t#2|)) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| (-568)) . T) ((-25) . T) ((-43 (-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-43 |#1|) |has| |#1| (-172)) ((-43 |#2|) |has| |#1| (-365)) ((-43 $) -2199 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-40) |has| |#1| (-43 (-409 (-568)))) ((-98) |has| |#1| (-43 (-409 (-568)))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-120 |#1| |#1|) . T) ((-120 |#2| |#2|) |has| |#1| (-365)) ((-120 $ $) -2199 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-137) . T) ((-148) -2199 (-12 (|has| |#1| (-365)) (|has| |#2| (-148))) (|has| |#1| (-148))) ((-150) -2199 (-12 (|has| |#1| (-365)) (|has| |#2| (-150))) (|has| |#1| (-150))) ((-608 (-850)) . T) ((-172) -2199 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-609 (-215)) -12 (|has| |#1| (-365)) (|has| |#2| (-1021))) ((-609 (-381)) -12 (|has| |#1| (-365)) (|has| |#2| (-1021))) ((-609 (-541)) -12 (|has| |#1| (-365)) (|has| |#2| (-609 (-541)))) ((-609 (-887 (-381))) -12 (|has| |#1| (-365)) (|has| |#2| (-609 (-887 (-381))))) ((-609 (-887 (-568))) -12 (|has| |#1| (-365)) (|has| |#2| (-609 (-887 (-568))))) ((-223 |#2|) |has| |#1| (-365)) ((-225) -2199 (-12 (|has| |#1| (-365)) (|has| |#2| (-225))) (|has| |#1| (-15 * (|#1| (-568) |#1|)))) ((-238) |has| |#1| (-365)) ((-279) |has| |#1| (-43 (-409 (-568)))) ((-281 |#2| $) -12 (|has| |#1| (-365)) (|has| |#2| (-281 |#2| |#2|))) ((-281 $ $) |has| (-568) (-1102)) ((-285) -2199 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-301) |has| |#1| (-365)) ((-303 |#2|) -12 (|has| |#1| (-365)) (|has| |#2| (-303 |#2|))) ((-365) |has| |#1| (-365)) ((-336 |#2|) |has| |#1| (-365)) ((-379 |#2|) |has| |#1| (-365)) ((-402 |#2|) |has| |#1| (-365)) ((-453) |has| |#1| (-365)) ((-502) |has| |#1| (-43 (-409 (-568)))) ((-523 (-1161) |#2|) -12 (|has| |#1| (-365)) (|has| |#2| (-523 (-1161) |#2|))) ((-523 |#2| |#2|) -12 (|has| |#1| (-365)) (|has| |#2| (-303 |#2|))) ((-558) -2199 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-637 (-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-637 |#1|) . T) ((-637 |#2|) |has| |#1| (-365)) ((-637 $) . T) ((-630 (-568)) -12 (|has| |#1| (-365)) (|has| |#2| (-630 (-568)))) ((-630 |#2|) |has| |#1| (-365)) ((-707 (-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-707 |#1|) |has| |#1| (-172)) ((-707 |#2|) |has| |#1| (-365)) ((-707 $) -2199 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-716) . T) ((-786) -12 (|has| |#1| (-365)) (|has| |#2| (-815))) ((-787) -12 (|has| |#1| (-365)) (|has| |#2| (-815))) ((-789) -12 (|has| |#1| (-365)) (|has| |#2| (-815))) ((-790) -12 (|has| |#1| (-365)) (|has| |#2| (-815))) ((-815) -12 (|has| |#1| (-365)) (|has| |#2| (-815))) ((-840) -12 (|has| |#1| (-365)) (|has| |#2| (-815))) ((-842) -2199 (-12 (|has| |#1| (-365)) (|has| |#2| (-842))) (-12 (|has| |#1| (-365)) (|has| |#2| (-815)))) ((-895 (-1161)) -2199 (-12 (|has| |#1| (-365)) (|has| |#2| (-895 (-1161)))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))) ((-881 (-381)) -12 (|has| |#1| (-365)) (|has| |#2| (-881 (-381)))) ((-881 (-568)) -12 (|has| |#1| (-365)) (|has| |#2| (-881 (-568)))) ((-879 |#2|) |has| |#1| (-365)) ((-904) -12 (|has| |#1| (-365)) (|has| |#2| (-904))) ((-974 |#1| (-568) (-1075)) . T) ((-916) |has| |#1| (-365)) ((-993 |#2|) |has| |#1| (-365)) ((-1002) |has| |#1| (-43 (-409 (-568)))) ((-1021) -12 (|has| |#1| (-365)) (|has| |#2| (-1021))) ((-1037 (-409 (-568))) -12 (|has| |#1| (-365)) (|has| |#2| (-1037 (-568)))) ((-1037 (-568)) -12 (|has| |#1| (-365)) (|has| |#2| (-1037 (-568)))) ((-1037 (-1161)) -12 (|has| |#1| (-365)) (|has| |#2| (-1037 (-1161)))) ((-1037 |#2|) . T) ((-1053 (-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-1053 |#1|) . T) ((-1053 |#2|) |has| |#1| (-365)) ((-1053 $) -2199 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1136) -12 (|has| |#1| (-365)) (|has| |#2| (-1136))) ((-1181) |has| |#1| (-43 (-409 (-568)))) ((-1184) |has| |#1| (-43 (-409 (-568)))) ((-1195) |has| |#1| (-365)) ((-1199) |has| |#1| (-365)) ((-1203 |#1|) . T) ((-1221 |#1| (-568)) . T)) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 70)) (-2563 ((|#2| $) NIL (-12 (|has| |#2| (-301)) (|has| |#1| (-365))))) (-2057 (((-634 (-1075)) $) NIL)) (-3325 (((-1161) $) 88)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-4179 (($ $ (-568)) 97) (($ $ (-568) (-568)) 99)) (-2013 (((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) 47)) (-3054 ((|#2| $) 11)) (-1415 (((-3 |#2| "failed") $) 30)) (-2067 ((|#2| $) 31)) (-1984 (($ $) 192 (|has| |#1| (-43 (-409 (-568)))))) (-1935 (($ $) 168 (|has| |#1| (-43 (-409 (-568)))))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| |#2| (-904)) (|has| |#1| (-365))))) (-3045 (($ $) NIL (|has| |#1| (-365)))) (-3498 (((-420 $) $) NIL (|has| |#1| (-365)))) (-1904 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (-12 (|has| |#2| (-904)) (|has| |#1| (-365))))) (-2589 (((-121) $ $) NIL (|has| |#1| (-365)))) (-1976 (($ $) 188 (|has| |#1| (-43 (-409 (-568)))))) (-2788 (($ $) 164 (|has| |#1| (-43 (-409 (-568)))))) (-3337 (((-568) $) NIL (-12 (|has| |#2| (-815)) (|has| |#1| (-365))))) (-2512 (($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) 57)) (-1992 (($ $) 196 (|has| |#1| (-43 (-409 (-568)))))) (-1943 (($ $) 172 (|has| |#1| (-43 (-409 (-568)))))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#2| "failed") $) 144) (((-3 (-568) "failed") $) NIL (-12 (|has| |#2| (-1037 (-568))) (|has| |#1| (-365)))) (((-3 (-409 (-568)) "failed") $) NIL (-12 (|has| |#2| (-1037 (-568))) (|has| |#1| (-365)))) (((-3 (-1161) "failed") $) NIL (-12 (|has| |#2| (-1037 (-1161))) (|has| |#1| (-365))))) (-2857 ((|#2| $) 143) (((-568) $) NIL (-12 (|has| |#2| (-1037 (-568))) (|has| |#1| (-365)))) (((-409 (-568)) $) NIL (-12 (|has| |#2| (-1037 (-568))) (|has| |#1| (-365)))) (((-1161) $) NIL (-12 (|has| |#2| (-1037 (-1161))) (|has| |#1| (-365))))) (-2232 (($ $) 61) (($ (-568) $) 24)) (-2403 (($ $ $) NIL (|has| |#1| (-365)))) (-2116 (($ $) NIL)) (-1668 (((-679 |#2|) (-679 $)) NIL (|has| |#1| (-365))) (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL (|has| |#1| (-365))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (-12 (|has| |#2| (-630 (-568))) (|has| |#1| (-365)))) (((-679 (-568)) (-679 $)) NIL (-12 (|has| |#2| (-630 (-568))) (|has| |#1| (-365))))) (-2902 (((-3 $ "failed") $) 77)) (-1685 (((-409 (-953 |#1|)) $ (-568)) 112 (|has| |#1| (-558))) (((-409 (-953 |#1|)) $ (-568) (-568)) 114 (|has| |#1| (-558)))) (-1733 (($) NIL (-12 (|has| |#2| (-550)) (|has| |#1| (-365))))) (-2414 (($ $ $) NIL (|has| |#1| (-365)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-2197 (((-121) $) NIL (|has| |#1| (-365)))) (-1436 (((-121) $) NIL (-12 (|has| |#2| (-815)) (|has| |#1| (-365))))) (-1302 (((-121) $) 64)) (-1899 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| |#2| (-881 (-381))) (|has| |#1| (-365)))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| |#2| (-881 (-568))) (|has| |#1| (-365))))) (-1844 (((-568) $) 93) (((-568) $ (-568)) 95)) (-1598 (((-121) $) NIL)) (-3539 (($ $) NIL (|has| |#1| (-365)))) (-2319 ((|#2| $) 151 (|has| |#1| (-365)))) (-1550 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2214 (((-3 $ "failed") $) NIL (-12 (|has| |#2| (-1136)) (|has| |#1| (-365))))) (-2859 (((-121) $) NIL (-12 (|has| |#2| (-815)) (|has| |#1| (-365))))) (-4168 (($ $ (-917)) 136)) (-3698 (($ (-1 |#1| (-568)) $) 132)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| (-568)) 19) (($ $ (-1075) (-568)) NIL) (($ $ (-634 (-1075)) (-634 (-568))) NIL)) (-1732 (($ $ $) NIL (-12 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-2047 (($ $ $) NIL (-12 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-2797 (($ (-1 |#1| |#1|) $) 129) (($ (-1 |#2| |#2|) $) NIL (|has| |#1| (-365)))) (-4418 (($ $) 162 (|has| |#1| (-43 (-409 (-568)))))) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-2498 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-2072 (($ (-568) |#2|) 10)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) 145 (|has| |#1| (-365)))) (-1845 (($ $) 214 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) 219 (-2199 (-12 (|has| |#1| (-15 -1845 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2057 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181)))))) (-4436 (($) NIL (-12 (|has| |#2| (-1136)) (|has| |#1| (-365))) CONST)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-365)))) (-2723 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-1999 (($ $) NIL (-12 (|has| |#2| (-301)) (|has| |#1| (-365))))) (-4115 ((|#2| $) NIL (-12 (|has| |#2| (-550)) (|has| |#1| (-365))))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| |#2| (-904)) (|has| |#1| (-365))))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| |#2| (-904)) (|has| |#1| (-365))))) (-3850 (((-420 $) $) NIL (|has| |#1| (-365)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-365)))) (-2168 (($ $ (-568)) 126)) (-2597 (((-3 $ "failed") $ $) 116 (|has| |#1| (-558)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1894 (($ $) 160 (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) 85 (|has| |#1| (-15 ** (|#1| |#1| (-568))))) (($ $ (-1161) |#2|) NIL (-12 (|has| |#2| (-523 (-1161) |#2|)) (|has| |#1| (-365)))) (($ $ (-634 (-1161)) (-634 |#2|)) NIL (-12 (|has| |#2| (-523 (-1161) |#2|)) (|has| |#1| (-365)))) (($ $ (-634 (-288 |#2|))) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#1| (-365)))) (($ $ (-288 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#1| (-365)))) (($ $ |#2| |#2|) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#1| (-365)))) (($ $ (-634 |#2|) (-634 |#2|)) NIL (-12 (|has| |#2| (-303 |#2|)) (|has| |#1| (-365))))) (-1466 (((-763) $) NIL (|has| |#1| (-365)))) (-2781 ((|#1| $ (-568)) 91) (($ $ $) 79 (|has| (-568) (-1102))) (($ $ |#2|) NIL (-12 (|has| |#2| (-281 |#2| |#2|)) (|has| |#1| (-365))))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-365)))) (-4191 (($ $ (-1 |#2| |#2|)) NIL (|has| |#1| (-365))) (($ $ (-1 |#2| |#2|) (-763)) NIL (|has| |#1| (-365))) (($ $ (-763)) NIL (-2199 (-12 (|has| |#2| (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $) 137 (-2199 (-12 (|has| |#2| (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-2199 (-12 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161) (-763)) NIL (-2199 (-12 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-634 (-1161))) NIL (-2199 (-12 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161)) 140 (-2199 (-12 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))))) (-3210 (($ $) NIL (|has| |#1| (-365)))) (-2326 ((|#2| $) 152 (|has| |#1| (-365)))) (-1836 (((-568) $) 12)) (-1996 (($ $) 198 (|has| |#1| (-43 (-409 (-568)))))) (-1947 (($ $) 174 (|has| |#1| (-43 (-409 (-568)))))) (-1988 (($ $) 194 (|has| |#1| (-43 (-409 (-568)))))) (-1939 (($ $) 170 (|has| |#1| (-43 (-409 (-568)))))) (-1980 (($ $) 190 (|has| |#1| (-43 (-409 (-568)))))) (-2792 (($ $) 166 (|has| |#1| (-43 (-409 (-568)))))) (-4280 (((-215) $) NIL (-12 (|has| |#2| (-1021)) (|has| |#1| (-365)))) (((-381) $) NIL (-12 (|has| |#2| (-1021)) (|has| |#1| (-365)))) (((-541) $) NIL (-12 (|has| |#2| (-609 (-541))) (|has| |#1| (-365)))) (((-887 (-381)) $) NIL (-12 (|has| |#2| (-609 (-887 (-381)))) (|has| |#1| (-365)))) (((-887 (-568)) $) NIL (-12 (|has| |#2| (-609 (-887 (-568)))) (|has| |#1| (-365))))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#2| (-904)) (|has| |#1| (-365))))) (-2188 (($ $) 124)) (-2747 (((-850) $) 242) (($ (-568)) 23) (($ |#1|) 21 (|has| |#1| (-172))) (($ |#2|) 20) (($ (-1161)) NIL (-12 (|has| |#2| (-1037 (-1161))) (|has| |#1| (-365)))) (($ (-409 (-568))) 155 (|has| |#1| (-43 (-409 (-568))))) (($ $) NIL (|has| |#1| (-558)))) (-2079 ((|#1| $ (-568)) 74)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| |#2| (-904)) (|has| |#1| (-365))) (-12 (|has| |#2| (-148)) (|has| |#1| (-365))) (|has| |#1| (-148))))) (-3425 (((-763)) 142)) (-1374 ((|#1| $) 90)) (-3520 ((|#2| $) NIL (-12 (|has| |#2| (-550)) (|has| |#1| (-365))))) (-2008 (($ $) 204 (|has| |#1| (-43 (-409 (-568)))))) (-1959 (($ $) 180 (|has| |#1| (-43 (-409 (-568)))))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2000 (($ $) 200 (|has| |#1| (-43 (-409 (-568)))))) (-1951 (($ $) 176 (|has| |#1| (-43 (-409 (-568)))))) (-2016 (($ $) 208 (|has| |#1| (-43 (-409 (-568)))))) (-1968 (($ $) 184 (|has| |#1| (-43 (-409 (-568)))))) (-3999 ((|#1| $ (-568)) 122 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-568)))) (|has| |#1| (-15 -2747 (|#1| (-1161))))))) (-1439 (($ $) 210 (|has| |#1| (-43 (-409 (-568)))))) (-1972 (($ $) 186 (|has| |#1| (-43 (-409 (-568)))))) (-2012 (($ $) 206 (|has| |#1| (-43 (-409 (-568)))))) (-1964 (($ $) 182 (|has| |#1| (-43 (-409 (-568)))))) (-2004 (($ $) 202 (|has| |#1| (-43 (-409 (-568)))))) (-1955 (($ $) 178 (|has| |#1| (-43 (-409 (-568)))))) (-2811 (($ $) NIL (-12 (|has| |#2| (-815)) (|has| |#1| (-365))))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (-3058 (($) 13 T CONST)) (-1557 (($) 17 T CONST)) (-3192 (($ $ (-1 |#2| |#2|)) NIL (|has| |#1| (-365))) (($ $ (-1 |#2| |#2|) (-763)) NIL (|has| |#1| (-365))) (($ $ (-763)) NIL (-2199 (-12 (|has| |#2| (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $) NIL (-2199 (-12 (|has| |#2| (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-2199 (-12 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161) (-763)) NIL (-2199 (-12 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-634 (-1161))) NIL (-2199 (-12 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161)) NIL (-2199 (-12 (|has| |#2| (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))))) (-1753 (((-121) $ $) NIL (-12 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-1740 (((-121) $ $) NIL (-12 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-1719 (((-121) $ $) 63)) (-1747 (((-121) $ $) NIL (-12 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-1734 (((-121) $ $) NIL (-12 (|has| |#2| (-842)) (|has| |#1| (-365))))) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365))) (($ $ $) 149 (|has| |#1| (-365))) (($ |#2| |#2|) 150 (|has| |#1| (-365)))) (-1775 (($ $) 213) (($ $ $) 68)) (-1769 (($ $ $) 66)) (** (($ $ (-917)) NIL) (($ $ (-763)) 73) (($ $ (-568)) 146 (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 158 (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 69) (($ $ |#1|) NIL) (($ |#1| $) 139) (($ $ |#2|) 148 (|has| |#1| (-365))) (($ |#2| $) 147 (|has| |#1| (-365))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
 (((-1206 |#1| |#2|) (-1205 |#1| |#2|) (-1047) (-1234 |#1|)) (T -1206)) 
 NIL 
 (-1205 |#1| |#2|) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-1492 (((-1235 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-301)) (|has| |#1| (-365))))) (-2055 (((-634 (-1075)) $) NIL)) (-1305 (((-1161) $) 10)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558))))) (-2227 (($ $) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558))))) (-1573 (((-121) $) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558))))) (-2617 (($ $ (-568)) NIL) (($ $ (-568) (-568)) NIL)) (-2583 (((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL)) (-3613 (((-1235 |#1| |#2| |#3|) $) NIL)) (-4016 (((-3 (-1235 |#1| |#2| |#3|) "failed") $) NIL)) (-2065 (((-1235 |#1| |#2| |#3|) $) NIL)) (-1982 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1933 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3134 (((-3 $ "failed") $ $) NIL)) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))))) (-4305 (($ $) NIL (|has| |#1| (-365)))) (-1678 (((-420 $) $) NIL (|has| |#1| (-365)))) (-1902 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))))) (-1497 (((-121) $ $) NIL (|has| |#1| (-365)))) (-1974 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2786 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3662 (((-568) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))))) (-3728 (($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) NIL)) (-1990 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1941 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-1235 |#1| |#2| |#3|) "failed") $) NIL) (((-3 (-1161) "failed") $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-1037 (-1161))) (|has| |#1| (-365)))) (((-3 (-409 (-568)) "failed") $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-1037 (-568))) (|has| |#1| (-365)))) (((-3 (-568) "failed") $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-1037 (-568))) (|has| |#1| (-365))))) (-2854 (((-1235 |#1| |#2| |#3|) $) NIL) (((-1161) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-1037 (-1161))) (|has| |#1| (-365)))) (((-409 (-568)) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-1037 (-568))) (|has| |#1| (-365)))) (((-568) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-1037 (-568))) (|has| |#1| (-365))))) (-1429 (($ $) NIL) (($ (-568) $) NIL)) (-2401 (($ $ $) NIL (|has| |#1| (-365)))) (-2114 (($ $) NIL)) (-3164 (((-679 (-1235 |#1| |#2| |#3|)) (-679 $)) NIL (|has| |#1| (-365))) (((-2 (|:| -2928 (-679 (-1235 |#1| |#2| |#3|))) (|:| |vec| (-1244 (-1235 |#1| |#2| |#3|)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-365))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-630 (-568))) (|has| |#1| (-365)))) (((-679 (-568)) (-679 $)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-630 (-568))) (|has| |#1| (-365))))) (-2925 (((-3 $ "failed") $) NIL)) (-4446 (((-409 (-953 |#1|)) $ (-568)) NIL (|has| |#1| (-558))) (((-409 (-953 |#1|)) $ (-568) (-568)) NIL (|has| |#1| (-558)))) (-1731 (($) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-550)) (|has| |#1| (-365))))) (-2412 (($ $ $) NIL (|has| |#1| (-365)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-3927 (((-121) $) NIL (|has| |#1| (-365)))) (-2033 (((-121) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))))) (-3992 (((-121) $) NIL)) (-1897 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4410 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-881 (-568))) (|has| |#1| (-365)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-881 (-381))) (|has| |#1| (-365))))) (-4477 (((-568) $) NIL) (((-568) $ (-568)) NIL)) (-2735 (((-121) $) NIL)) (-1332 (($ $) NIL (|has| |#1| (-365)))) (-2317 (((-1235 |#1| |#2| |#3|) $) NIL (|has| |#1| (-365)))) (-4044 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3038 (((-3 $ "failed") $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-1136)) (|has| |#1| (-365))))) (-2245 (((-121) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))))) (-3536 (($ $ (-917)) NIL)) (-1716 (($ (-1 |#1| (-568)) $) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| (-568)) 17) (($ $ (-1075) (-568)) NIL) (($ $ (-634 (-1075)) (-634 (-568))) NIL)) (-2521 (($ $ $) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-3268 (($ $ $) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-2795 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 (-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|)) $) NIL (|has| |#1| (-365)))) (-4416 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-2495 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-2070 (($ (-568) (-1235 |#1| |#2| |#3|)) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL (|has| |#1| (-365)))) (-3837 (($ $) 25 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) NIL (-2198 (-12 (|has| |#1| (-15 -3837 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2055 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181))))) (($ $ (-1240 |#2|)) 26 (|has| |#1| (-43 (-409 (-568)))))) (-4434 (($) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-1136)) (|has| |#1| (-365))) CONST)) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-365)))) (-2721 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-3880 (($ $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-301)) (|has| |#1| (-365))))) (-1519 (((-1235 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-550)) (|has| |#1| (-365))))) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))))) (-3848 (((-420 $) $) NIL (|has| |#1| (-365)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-365)))) (-1807 (($ $ (-568)) NIL)) (-2595 (((-3 $ "failed") $ $) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558))))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1892 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-568))))) (($ $ (-1161) (-1235 |#1| |#2| |#3|)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-523 (-1161) (-1235 |#1| |#2| |#3|))) (|has| |#1| (-365)))) (($ $ (-634 (-1161)) (-634 (-1235 |#1| |#2| |#3|))) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-523 (-1161) (-1235 |#1| |#2| |#3|))) (|has| |#1| (-365)))) (($ $ (-634 (-288 (-1235 |#1| |#2| |#3|)))) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-303 (-1235 |#1| |#2| |#3|))) (|has| |#1| (-365)))) (($ $ (-288 (-1235 |#1| |#2| |#3|))) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-303 (-1235 |#1| |#2| |#3|))) (|has| |#1| (-365)))) (($ $ (-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-303 (-1235 |#1| |#2| |#3|))) (|has| |#1| (-365)))) (($ $ (-634 (-1235 |#1| |#2| |#3|)) (-634 (-1235 |#1| |#2| |#3|))) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-303 (-1235 |#1| |#2| |#3|))) (|has| |#1| (-365))))) (-2709 (((-763) $) NIL (|has| |#1| (-365)))) (-2779 ((|#1| $ (-568)) NIL) (($ $ $) NIL (|has| (-568) (-1102))) (($ $ (-1235 |#1| |#2| |#3|)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-281 (-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|))) (|has| |#1| (-365))))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-365)))) (-4189 (($ $ (-1 (-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|))) NIL (|has| |#1| (-365))) (($ $ (-1 (-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|)) (-763)) NIL (|has| |#1| (-365))) (($ $ (-1240 |#2|)) 24) (($ $ (-763)) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $) 23 (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161) (-763)) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-634 (-1161))) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161)) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))))) (-3013 (($ $) NIL (|has| |#1| (-365)))) (-2324 (((-1235 |#1| |#2| |#3|) $) NIL (|has| |#1| (-365)))) (-3206 (((-568) $) NIL)) (-1994 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1945 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1986 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1937 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1978 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2790 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4278 (((-541) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-609 (-541))) (|has| |#1| (-365)))) (((-381) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-1021)) (|has| |#1| (-365)))) (((-215) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-1021)) (|has| |#1| (-365)))) (((-887 (-381)) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-609 (-887 (-381)))) (|has| |#1| (-365)))) (((-887 (-568)) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-609 (-887 (-568)))) (|has| |#1| (-365))))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))))) (-1811 (($ $) NIL)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL (|has| |#1| (-172))) (($ (-1235 |#1| |#2| |#3|)) NIL) (($ (-1240 |#2|)) 22) (($ (-1161)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-1037 (-1161))) (|has| |#1| (-365)))) (($ $) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558)))) (($ (-409 (-568))) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-1037 (-568))) (|has| |#1| (-365))) (|has| |#1| (-43 (-409 (-568))))))) (-2604 ((|#1| $ (-568)) NIL)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-148)) (|has| |#1| (-365))) (|has| |#1| (-148))))) (-4078 (((-763)) NIL)) (-1374 ((|#1| $) 11)) (-2285 (((-1235 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-550)) (|has| |#1| (-365))))) (-2006 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1958 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1826 (((-121) $ $) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558))))) (-1998 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1949 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2014 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1966 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3996 ((|#1| $ (-568)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-568)))) (|has| |#1| (-15 -2745 (|#1| (-1161))))))) (-4023 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1970 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2010 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1962 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2002 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1953 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2897 (($ $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (-3056 (($) 19 T CONST)) (-1556 (($) 15 T CONST)) (-3190 (($ $ (-1 (-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|))) NIL (|has| |#1| (-365))) (($ $ (-1 (-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|)) (-763)) NIL (|has| |#1| (-365))) (($ $ (-763)) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161) (-763)) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-634 (-1161))) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161)) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))))) (-1751 (((-121) $ $) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-1738 (((-121) $ $) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-1732 (((-121) $ $) NIL (-2198 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365))) (($ (-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|)) NIL (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) 20)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ (-1235 |#1| |#2| |#3|)) NIL (|has| |#1| (-365))) (($ (-1235 |#1| |#2| |#3|) $) NIL (|has| |#1| (-365))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
-(((-1207 |#1| |#2| |#3|) (-13 (-1205 |#1| (-1235 |#1| |#2| |#3|)) (-10 -8 (-15 -2745 ($ (-1240 |#2|))) (-15 -4189 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -3837 ($ $ (-1240 |#2|))) |noBranch|))) (-1047) (-1161) |#1|) (T -1207)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1207 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-4189 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1207 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-3837 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1207 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3)))) 
-(-13 (-1205 |#1| (-1235 |#1| |#2| |#3|)) (-10 -8 (-15 -2745 ($ (-1240 |#2|))) (-15 -4189 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -3837 ($ $ (-1240 |#2|))) |noBranch|))) 
-((-2954 (((-2 (|:| |contp| (-568)) (|:| -3276 (-634 (-2 (|:| |irr| |#1|) (|:| -3959 (-568)))))) |#1| (-121)) 10)) (-2630 (((-420 |#1|) |#1|) 21)) (-3848 (((-420 |#1|) |#1|) 20))) 
-(((-1208 |#1|) (-10 -7 (-15 -3848 ((-420 |#1|) |#1|)) (-15 -2630 ((-420 |#1|) |#1|)) (-15 -2954 ((-2 (|:| |contp| (-568)) (|:| -3276 (-634 (-2 (|:| |irr| |#1|) (|:| -3959 (-568)))))) |#1| (-121)))) (-1219 (-568))) (T -1208)) 
-((-2954 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-5 *2 (-2 (|:| |contp| (-568)) (|:| -3276 (-634 (-2 (|:| |irr| *3) (|:| -3959 (-568))))))) (-5 *1 (-1208 *3)) (-4 *3 (-1219 (-568))))) (-2630 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-1208 *3)) (-4 *3 (-1219 (-568))))) (-3848 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-1208 *3)) (-4 *3 (-1219 (-568)))))) 
-(-10 -7 (-15 -3848 ((-420 |#1|) |#1|)) (-15 -2630 ((-420 |#1|) |#1|)) (-15 -2954 ((-2 (|:| |contp| (-568)) (|:| -3276 (-634 (-2 (|:| |irr| |#1|) (|:| -3959 (-568)))))) |#1| (-121)))) 
-((-2795 (((-1141 |#2|) (-1 |#2| |#1|) (-1210 |#1|)) 23 (|has| |#1| (-840))) (((-1210 |#2|) (-1 |#2| |#1|) (-1210 |#1|)) 17))) 
-(((-1209 |#1| |#2|) (-10 -7 (-15 -2795 ((-1210 |#2|) (-1 |#2| |#1|) (-1210 |#1|))) (IF (|has| |#1| (-840)) (-15 -2795 ((-1141 |#2|) (-1 |#2| |#1|) (-1210 |#1|))) |noBranch|)) (-1195) (-1195)) (T -1209)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1210 *5)) (-4 *5 (-840)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1141 *6)) (-5 *1 (-1209 *5 *6)))) (-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1210 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1210 *6)) (-5 *1 (-1209 *5 *6))))) 
-(-10 -7 (-15 -2795 ((-1210 |#2|) (-1 |#2| |#1|) (-1210 |#1|))) (IF (|has| |#1| (-840)) (-15 -2795 ((-1141 |#2|) (-1 |#2| |#1|) (-1210 |#1|))) |noBranch|)) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2463 (($ |#1| |#1|) 9) (($ |#1|) 8)) (-2795 (((-1141 |#1|) (-1 |#1| |#1|) $) 41 (|has| |#1| (-840)))) (-4100 ((|#1| $) 14)) (-2746 ((|#1| $) 10)) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-2751 (((-568) $) 18)) (-2971 ((|#1| $) 17)) (-2754 ((|#1| $) 11)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-4000 (((-121) $) 16)) (-2789 (((-1141 |#1|) $) 38 (|has| |#1| (-840))) (((-1141 |#1|) (-634 $)) 37 (|has| |#1| (-840)))) (-4278 (($ |#1|) 25)) (-2745 (($ (-1084 |#1|)) 24) (((-850) $) 34 (|has| |#1| (-1090)))) (-4253 (($ |#1| |#1|) 20) (($ |#1|) 19)) (-4143 (($ $ (-568)) 13)) (-1717 (((-121) $ $) 27 (|has| |#1| (-1090))))) 
-(((-1210 |#1|) (-13 (-1083 |#1|) (-10 -8 (-15 -4253 ($ |#1|)) (-15 -2463 ($ |#1|)) (-15 -2745 ($ (-1084 |#1|))) (-15 -4000 ((-121) $)) (IF (|has| |#1| (-1090)) (-6 (-1090)) |noBranch|) (IF (|has| |#1| (-840)) (-6 (-1085 |#1| (-1141 |#1|))) |noBranch|))) (-1195)) (T -1210)) 
-((-4253 (*1 *1 *2) (-12 (-5 *1 (-1210 *2)) (-4 *2 (-1195)))) (-2463 (*1 *1 *2) (-12 (-5 *1 (-1210 *2)) (-4 *2 (-1195)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-1084 *3)) (-4 *3 (-1195)) (-5 *1 (-1210 *3)))) (-4000 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1210 *3)) (-4 *3 (-1195))))) 
-(-13 (-1083 |#1|) (-10 -8 (-15 -4253 ($ |#1|)) (-15 -2463 ($ |#1|)) (-15 -2745 ($ (-1084 |#1|))) (-15 -4000 ((-121) $)) (IF (|has| |#1| (-1090)) (-6 (-1090)) |noBranch|) (IF (|has| |#1| (-840)) (-6 (-1085 |#1| (-1141 |#1|))) |noBranch|))) 
-((-2795 (((-1216 |#3| |#4|) (-1 |#4| |#2|) (-1216 |#1| |#2|)) 15))) 
-(((-1211 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2795 ((-1216 |#3| |#4|) (-1 |#4| |#2|) (-1216 |#1| |#2|)))) (-1161) (-1047) (-1161) (-1047)) (T -1211)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *6)) (-5 *4 (-1216 *5 *6)) (-14 *5 (-1161)) (-4 *6 (-1047)) (-4 *8 (-1047)) (-5 *2 (-1216 *7 *8)) (-5 *1 (-1211 *5 *6 *7 *8)) (-14 *7 (-1161))))) 
-(-10 -7 (-15 -2795 ((-1216 |#3| |#4|) (-1 |#4| |#2|) (-1216 |#1| |#2|)))) 
-((-4114 (((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|) 21)) (-3093 ((|#1| |#3|) 13)) (-2469 ((|#3| |#3|) 19))) 
-(((-1212 |#1| |#2| |#3|) (-10 -7 (-15 -3093 (|#1| |#3|)) (-15 -2469 (|#3| |#3|)) (-15 -4114 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|))) (-558) (-993 |#1|) (-1219 |#2|)) (T -1212)) 
-((-4114 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-993 *4)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4))) (-5 *1 (-1212 *4 *5 *3)) (-4 *3 (-1219 *5)))) (-2469 (*1 *2 *2) (-12 (-4 *3 (-558)) (-4 *4 (-993 *3)) (-5 *1 (-1212 *3 *4 *2)) (-4 *2 (-1219 *4)))) (-3093 (*1 *2 *3) (-12 (-4 *4 (-993 *2)) (-4 *2 (-558)) (-5 *1 (-1212 *2 *4 *3)) (-4 *3 (-1219 *4))))) 
-(-10 -7 (-15 -3093 (|#1| |#3|)) (-15 -2469 (|#3| |#3|)) (-15 -4114 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|))) 
-((-3076 (((-3 |#2| "failed") |#2| (-763) |#1|) 29)) (-2162 (((-3 |#2| "failed") |#2| (-763)) 30)) (-2518 (((-3 (-2 (|:| -3028 |#2|) (|:| -3284 |#2|)) "failed") |#2|) 42)) (-2101 (((-634 |#2|) |#2|) 44)) (-1603 (((-3 |#2| "failed") |#2| |#2|) 39))) 
-(((-1213 |#1| |#2|) (-10 -7 (-15 -2162 ((-3 |#2| "failed") |#2| (-763))) (-15 -3076 ((-3 |#2| "failed") |#2| (-763) |#1|)) (-15 -1603 ((-3 |#2| "failed") |#2| |#2|)) (-15 -2518 ((-3 (-2 (|:| -3028 |#2|) (|:| -3284 |#2|)) "failed") |#2|)) (-15 -2101 ((-634 |#2|) |#2|))) (-13 (-558) (-150)) (-1219 |#1|)) (T -1213)) 
-((-2101 (*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-150))) (-5 *2 (-634 *3)) (-5 *1 (-1213 *4 *3)) (-4 *3 (-1219 *4)))) (-2518 (*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-558) (-150))) (-5 *2 (-2 (|:| -3028 *3) (|:| -3284 *3))) (-5 *1 (-1213 *4 *3)) (-4 *3 (-1219 *4)))) (-1603 (*1 *2 *2 *2) (|partial| -12 (-4 *3 (-13 (-558) (-150))) (-5 *1 (-1213 *3 *2)) (-4 *2 (-1219 *3)))) (-3076 (*1 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-763)) (-4 *4 (-13 (-558) (-150))) (-5 *1 (-1213 *4 *2)) (-4 *2 (-1219 *4)))) (-2162 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-763)) (-4 *4 (-13 (-558) (-150))) (-5 *1 (-1213 *4 *2)) (-4 *2 (-1219 *4))))) 
-(-10 -7 (-15 -2162 ((-3 |#2| "failed") |#2| (-763))) (-15 -3076 ((-3 |#2| "failed") |#2| (-763) |#1|)) (-15 -1603 ((-3 |#2| "failed") |#2| |#2|)) (-15 -2518 ((-3 (-2 (|:| -3028 |#2|) (|:| -3284 |#2|)) "failed") |#2|)) (-15 -2101 ((-634 |#2|) |#2|))) 
-((-1827 (((-3 (-2 (|:| -3961 |#2|) (|:| -1500 |#2|)) "failed") |#2| |#2|) 31))) 
-(((-1214 |#1| |#2|) (-10 -7 (-15 -1827 ((-3 (-2 (|:| -3961 |#2|) (|:| -1500 |#2|)) "failed") |#2| |#2|))) (-558) (-1219 |#1|)) (T -1214)) 
-((-1827 (*1 *2 *3 *3) (|partial| -12 (-4 *4 (-558)) (-5 *2 (-2 (|:| -3961 *3) (|:| -1500 *3))) (-5 *1 (-1214 *4 *3)) (-4 *3 (-1219 *4))))) 
-(-10 -7 (-15 -1827 ((-3 (-2 (|:| -3961 |#2|) (|:| -1500 |#2|)) "failed") |#2| |#2|))) 
-((-2154 ((|#2| |#2| |#2|) 19)) (-4404 ((|#2| |#2| |#2|) 30)) (-1456 ((|#2| |#2| |#2| (-763) (-763)) 36))) 
-(((-1215 |#1| |#2|) (-10 -7 (-15 -2154 (|#2| |#2| |#2|)) (-15 -4404 (|#2| |#2| |#2|)) (-15 -1456 (|#2| |#2| |#2| (-763) (-763)))) (-1047) (-1219 |#1|)) (T -1215)) 
-((-1456 (*1 *2 *2 *2 *3 *3) (-12 (-5 *3 (-763)) (-4 *4 (-1047)) (-5 *1 (-1215 *4 *2)) (-4 *2 (-1219 *4)))) (-4404 (*1 *2 *2 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-1215 *3 *2)) (-4 *2 (-1219 *3)))) (-2154 (*1 *2 *2 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-1215 *3 *2)) (-4 *2 (-1219 *3))))) 
-(-10 -7 (-15 -2154 (|#2| |#2| |#2|)) (-15 -4404 (|#2| |#2| |#2|)) (-15 -1456 (|#2| |#2| |#2| (-763) (-763)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2572 (((-1244 |#2|) $ (-763)) NIL)) (-2055 (((-634 (-1075)) $) NIL)) (-3197 (($ (-1157 |#2|)) NIL)) (-3839 (((-1157 $) $ (-1075)) NIL) (((-1157 |#2|) $) NIL)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#2| (-558)))) (-2227 (($ $) NIL (|has| |#2| (-558)))) (-1573 (((-121) $) NIL (|has| |#2| (-558)))) (-2773 (((-763) $) NIL) (((-763) $ (-634 (-1075))) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-3809 (($ $ $) NIL (|has| |#2| (-558)))) (-1750 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-4305 (($ $) NIL (|has| |#2| (-453)))) (-1678 (((-420 $) $) NIL (|has| |#2| (-453)))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-1497 (((-121) $ $) NIL (|has| |#2| (-365)))) (-3151 (($ $ (-763)) NIL)) (-3772 (($ $ (-763)) NIL)) (-1619 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#2| (-453)))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#2| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#2| (-1037 (-568)))) (((-3 (-1075) "failed") $) NIL)) (-2854 ((|#2| $) NIL) (((-409 (-568)) $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#2| (-1037 (-568)))) (((-1075) $) NIL)) (-4265 (($ $ $ (-1075)) NIL (|has| |#2| (-172))) ((|#2| $ $) NIL (|has| |#2| (-172)))) (-2401 (($ $ $) NIL (|has| |#2| (-365)))) (-2114 (($ $) NIL)) (-3164 (((-679 (-568)) (-679 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL) (((-679 |#2|) (-679 $)) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-2412 (($ $ $) NIL (|has| |#2| (-365)))) (-3002 (($ $ $) NIL)) (-3581 (($ $ $) NIL (|has| |#2| (-558)))) (-4144 (((-2 (|:| -2348 |#2|) (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#2| (-558)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| |#2| (-365)))) (-3250 (($ $) NIL (|has| |#2| (-453))) (($ $ (-1075)) NIL (|has| |#2| (-453)))) (-2108 (((-634 $) $) NIL)) (-3927 (((-121) $) NIL (|has| |#2| (-904)))) (-3088 (($ $ |#2| (-763) $) NIL)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-1075) (-881 (-381))) (|has| |#2| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-1075) (-881 (-568))) (|has| |#2| (-881 (-568)))))) (-4477 (((-763) $ $) NIL (|has| |#2| (-558)))) (-2735 (((-121) $) NIL)) (-4178 (((-763) $) NIL)) (-3038 (((-3 $ "failed") $) NIL (|has| |#2| (-1136)))) (-2051 (($ (-1157 |#2|) (-1075)) NIL) (($ (-1157 $) (-1075)) NIL)) (-3536 (($ $ (-763)) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#2| (-365)))) (-2976 (((-634 $) $) NIL)) (-3921 (((-121) $) NIL)) (-2047 (($ |#2| (-763)) 17) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-3379 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $ (-1075)) NIL) (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL)) (-2144 (((-763) $) NIL) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-2521 (($ $ $) NIL (|has| |#2| (-842)))) (-3268 (($ $ $) NIL (|has| |#2| (-842)))) (-3842 (($ (-1 (-763) (-763)) $) NIL)) (-2795 (($ (-1 |#2| |#2|) $) NIL)) (-3764 (((-1157 |#2|) $) NIL)) (-2244 (((-3 (-1075) "failed") $) NIL)) (-2097 (($ $) NIL)) (-2102 ((|#2| $) NIL)) (-2495 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) NIL (|has| |#2| (-453)))) (-4487 (((-1143) $) NIL)) (-1643 (((-2 (|:| -3961 $) (|:| -1500 $)) $ (-763)) NIL)) (-3324 (((-3 (-634 $) "failed") $) NIL)) (-1794 (((-3 (-634 $) "failed") $) NIL)) (-3751 (((-3 (-2 (|:| |var| (-1075)) (|:| -3438 (-763))) "failed") $) NIL)) (-3837 (($ $) NIL (|has| |#2| (-43 (-409 (-568)))))) (-4434 (($) NIL (|has| |#2| (-1136)) CONST)) (-4022 (((-1108) $) NIL)) (-2086 (((-121) $) NIL)) (-2091 ((|#2| $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#2| (-453)))) (-2721 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) NIL (|has| |#2| (-453)))) (-4285 (($ $ (-763) |#2| $) NIL)) (-2905 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3848 (((-420 $) $) NIL (|has| |#2| (-904)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#2| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#2| (-365)))) (-2595 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-558)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#2| (-365)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-1075) |#2|) NIL) (($ $ (-634 (-1075)) (-634 |#2|)) NIL) (($ $ (-1075) $) NIL) (($ $ (-634 (-1075)) (-634 $)) NIL)) (-2709 (((-763) $) NIL (|has| |#2| (-365)))) (-2779 ((|#2| $ |#2|) NIL) (($ $ $) NIL) (((-409 $) (-409 $) (-409 $)) NIL (|has| |#2| (-558))) ((|#2| (-409 $) |#2|) NIL (|has| |#2| (-365))) (((-409 $) $ (-409 $)) NIL (|has| |#2| (-558)))) (-2167 (((-3 $ "failed") $ (-763)) NIL)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#2| (-365)))) (-2217 (($ $ (-1075)) NIL (|has| |#2| (-172))) ((|#2| $) NIL (|has| |#2| (-172)))) (-4189 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) $) NIL)) (-3206 (((-763) $) NIL) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-4278 (((-887 (-381)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-381)))) (|has| |#2| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-568)))) (|has| |#2| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-1075) (-609 (-541))) (|has| |#2| (-609 (-541)))))) (-3367 ((|#2| $) NIL (|has| |#2| (-453))) (($ $ (-1075)) NIL (|has| |#2| (-453)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#2| (-904))))) (-3950 (((-3 $ "failed") $ $) NIL (|has| |#2| (-558))) (((-3 (-409 $) "failed") (-409 $) $) NIL (|has| |#2| (-558)))) (-2745 (((-850) $) 13) (($ (-568)) NIL) (($ |#2|) NIL) (($ (-1075)) NIL) (($ (-1240 |#1|)) 19) (($ (-409 (-568))) NIL (-2198 (|has| |#2| (-43 (-409 (-568)))) (|has| |#2| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#2| (-558)))) (-1302 (((-634 |#2|) $) NIL)) (-2604 ((|#2| $ (-763)) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-4371 (((-3 $ "failed") $) NIL (-2198 (-12 (|has| $ (-148)) (|has| |#2| (-904))) (|has| |#2| (-148))))) (-4078 (((-763)) NIL)) (-4171 (($ $ $ (-763)) NIL (|has| |#2| (-172)))) (-1826 (((-121) $ $) NIL (|has| |#2| (-558)))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-1556 (($) 14 T CONST)) (-3190 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) NIL)) (-1751 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1717 (((-121) $ $) NIL)) (-1745 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1779 (($ $ |#2|) NIL (|has| |#2| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#2| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#2| (-43 (-409 (-568))))) (($ |#2| $) NIL) (($ $ |#2|) NIL))) 
-(((-1216 |#1| |#2|) (-13 (-1219 |#2|) (-10 -8 (-15 -2745 ($ (-1240 |#1|))) (-15 -4285 ($ $ (-763) |#2| $)))) (-1161) (-1047)) (T -1216)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1240 *3)) (-14 *3 (-1161)) (-5 *1 (-1216 *3 *4)) (-4 *4 (-1047)))) (-4285 (*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1216 *4 *3)) (-14 *4 (-1161)) (-4 *3 (-1047))))) 
-(-13 (-1219 |#2|) (-10 -8 (-15 -2745 ($ (-1240 |#1|))) (-15 -4285 ($ $ (-763) |#2| $)))) 
-((-2795 ((|#4| (-1 |#3| |#1|) |#2|) 22))) 
-(((-1217 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2795 (|#4| (-1 |#3| |#1|) |#2|))) (-1047) (-1219 |#1|) (-1047) (-1219 |#3|)) (T -1217)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-4 *2 (-1219 *6)) (-5 *1 (-1217 *5 *4 *6 *2)) (-4 *4 (-1219 *5))))) 
-(-10 -7 (-15 -2795 (|#4| (-1 |#3| |#1|) |#2|))) 
-((-2572 (((-1244 |#2|) $ (-763)) 113)) (-2055 (((-634 (-1075)) $) 15)) (-3197 (($ (-1157 |#2|)) 66)) (-2773 (((-763) $) NIL) (((-763) $ (-634 (-1075))) 18)) (-1750 (((-420 (-1157 $)) (-1157 $)) 183)) (-4305 (($ $) 173)) (-1678 (((-420 $) $) 171)) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 81)) (-3151 (($ $ (-763)) 70)) (-3772 (($ $ (-763)) 72)) (-1619 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) 129)) (-3666 (((-3 |#2| "failed") $) 116) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 (-568) "failed") $) NIL) (((-3 (-1075) "failed") $) NIL)) (-2854 ((|#2| $) 114) (((-409 (-568)) $) NIL) (((-568) $) NIL) (((-1075) $) NIL)) (-3581 (($ $ $) 150)) (-4144 (((-2 (|:| -2348 |#2|) (|:| -3961 $) (|:| -1500 $)) $ $) 152)) (-4477 (((-763) $ $) 168)) (-3038 (((-3 $ "failed") $) 122)) (-2047 (($ |#2| (-763)) NIL) (($ $ (-1075) (-763)) 46) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-2144 (((-763) $) NIL) (((-763) $ (-1075)) 41) (((-634 (-763)) $ (-634 (-1075))) 42)) (-3764 (((-1157 |#2|) $) 58)) (-2244 (((-3 (-1075) "failed") $) 39)) (-1643 (((-2 (|:| -3961 $) (|:| -1500 $)) $ (-763)) 69)) (-3837 (($ $) 194)) (-4434 (($) 118)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 180)) (-2905 (((-420 (-1157 $)) (-1157 $)) 87)) (-3545 (((-420 (-1157 $)) (-1157 $)) 85)) (-3848 (((-420 $) $) 105)) (-1339 (($ $ (-634 (-288 $))) 38) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-1075) |#2|) 31) (($ $ (-634 (-1075)) (-634 |#2|)) 28) (($ $ (-1075) $) 25) (($ $ (-634 (-1075)) (-634 $)) 23)) (-2709 (((-763) $) 186)) (-2779 ((|#2| $ |#2|) NIL) (($ $ $) NIL) (((-409 $) (-409 $) (-409 $)) 146) ((|#2| (-409 $) |#2|) 185) (((-409 $) $ (-409 $)) 167)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 189)) (-4189 (($ $ (-1075)) 139) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) 137) (($ $ (-1161)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) 136) (($ $ (-1 |#2| |#2|) $) 133)) (-3206 (((-763) $) NIL) (((-763) $ (-1075)) 16) (((-634 (-763)) $ (-634 (-1075))) 20)) (-3367 ((|#2| $) NIL) (($ $ (-1075)) 124)) (-3950 (((-3 $ "failed") $ $) 160) (((-3 (-409 $) "failed") (-409 $) $) 156)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#2|) NIL) (($ (-1075)) 50) (($ (-409 (-568))) NIL) (($ $) NIL))) 
-(((-1218 |#1| |#2|) (-10 -8 (-15 -2745 (|#1| |#1|)) (-15 -2155 ((-1157 |#1|) (-1157 |#1|) (-1157 |#1|))) (-15 -1678 ((-420 |#1|) |#1|)) (-15 -4305 (|#1| |#1|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -4434 (|#1|)) (-15 -3038 ((-3 |#1| "failed") |#1|)) (-15 -2779 ((-409 |#1|) |#1| (-409 |#1|))) (-15 -2709 ((-763) |#1|)) (-15 -3210 ((-2 (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1|)) (-15 -3837 (|#1| |#1|)) (-15 -2779 (|#2| (-409 |#1|) |#2|)) (-15 -1619 ((-2 (|:| |primePart| |#1|) (|:| |commonPart| |#1|)) |#1| |#1|)) (-15 -4144 ((-2 (|:| -2348 |#2|) (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1|)) (-15 -3581 (|#1| |#1| |#1|)) (-15 -3950 ((-3 (-409 |#1|) "failed") (-409 |#1|) |#1|)) (-15 -3950 ((-3 |#1| "failed") |#1| |#1|)) (-15 -4477 ((-763) |#1| |#1|)) (-15 -2779 ((-409 |#1|) (-409 |#1|) (-409 |#1|))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|) |#1|)) (-15 -3772 (|#1| |#1| (-763))) (-15 -3151 (|#1| |#1| (-763))) (-15 -1643 ((-2 (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| (-763))) (-15 -3197 (|#1| (-1157 |#2|))) (-15 -3764 ((-1157 |#2|) |#1|)) (-15 -2572 ((-1244 |#2|) |#1| (-763))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -4189 (|#1| |#1| (-1161) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)))) (-15 -4189 (|#1| |#1| (-1161))) (-15 -4189 (|#1| |#1|)) (-15 -4189 (|#1| |#1| (-763))) (-15 -2779 (|#1| |#1| |#1|)) (-15 -2779 (|#2| |#1| |#2|)) (-15 -3848 ((-420 |#1|) |#1|)) (-15 -1750 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -3545 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -2905 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -1858 ((-3 (-634 (-1157 |#1|)) "failed") (-634 (-1157 |#1|)) (-1157 |#1|))) (-15 -3367 (|#1| |#1| (-1075))) (-15 -2055 ((-634 (-1075)) |#1|)) (-15 -2773 ((-763) |#1| (-634 (-1075)))) (-15 -2773 ((-763) |#1|)) (-15 -2047 (|#1| |#1| (-634 (-1075)) (-634 (-763)))) (-15 -2047 (|#1| |#1| (-1075) (-763))) (-15 -2144 ((-634 (-763)) |#1| (-634 (-1075)))) (-15 -2144 ((-763) |#1| (-1075))) (-15 -2244 ((-3 (-1075) "failed") |#1|)) (-15 -3206 ((-634 (-763)) |#1| (-634 (-1075)))) (-15 -3206 ((-763) |#1| (-1075))) (-15 -2854 ((-1075) |#1|)) (-15 -3666 ((-3 (-1075) "failed") |#1|)) (-15 -2745 (|#1| (-1075))) (-15 -1339 (|#1| |#1| (-634 (-1075)) (-634 |#1|))) (-15 -1339 (|#1| |#1| (-1075) |#1|)) (-15 -1339 (|#1| |#1| (-634 (-1075)) (-634 |#2|))) (-15 -1339 (|#1| |#1| (-1075) |#2|)) (-15 -1339 (|#1| |#1| (-634 |#1|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#1| |#1|)) (-15 -1339 (|#1| |#1| (-288 |#1|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -3206 ((-763) |#1|)) (-15 -2047 (|#1| |#2| (-763))) (-15 -2854 ((-568) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2745 (|#1| |#2|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -2854 (|#2| |#1|)) (-15 -2144 ((-763) |#1|)) (-15 -3367 (|#2| |#1|)) (-15 -4189 (|#1| |#1| (-634 (-1075)) (-634 (-763)))) (-15 -4189 (|#1| |#1| (-1075) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1075)))) (-15 -4189 (|#1| |#1| (-1075))) (-15 -2745 (|#1| (-568))) (-15 -2745 ((-850) |#1|))) (-1219 |#2|) (-1047)) (T -1218)) 
-NIL 
-(-10 -8 (-15 -2745 (|#1| |#1|)) (-15 -2155 ((-1157 |#1|) (-1157 |#1|) (-1157 |#1|))) (-15 -1678 ((-420 |#1|) |#1|)) (-15 -4305 (|#1| |#1|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -4434 (|#1|)) (-15 -3038 ((-3 |#1| "failed") |#1|)) (-15 -2779 ((-409 |#1|) |#1| (-409 |#1|))) (-15 -2709 ((-763) |#1|)) (-15 -3210 ((-2 (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1|)) (-15 -3837 (|#1| |#1|)) (-15 -2779 (|#2| (-409 |#1|) |#2|)) (-15 -1619 ((-2 (|:| |primePart| |#1|) (|:| |commonPart| |#1|)) |#1| |#1|)) (-15 -4144 ((-2 (|:| -2348 |#2|) (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| |#1|)) (-15 -3581 (|#1| |#1| |#1|)) (-15 -3950 ((-3 (-409 |#1|) "failed") (-409 |#1|) |#1|)) (-15 -3950 ((-3 |#1| "failed") |#1| |#1|)) (-15 -4477 ((-763) |#1| |#1|)) (-15 -2779 ((-409 |#1|) (-409 |#1|) (-409 |#1|))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|) |#1|)) (-15 -3772 (|#1| |#1| (-763))) (-15 -3151 (|#1| |#1| (-763))) (-15 -1643 ((-2 (|:| -3961 |#1|) (|:| -1500 |#1|)) |#1| (-763))) (-15 -3197 (|#1| (-1157 |#2|))) (-15 -3764 ((-1157 |#2|) |#1|)) (-15 -2572 ((-1244 |#2|) |#1| (-763))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4189 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -4189 (|#1| |#1| (-1161) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1161)))) (-15 -4189 (|#1| |#1| (-1161))) (-15 -4189 (|#1| |#1|)) (-15 -4189 (|#1| |#1| (-763))) (-15 -2779 (|#1| |#1| |#1|)) (-15 -2779 (|#2| |#1| |#2|)) (-15 -3848 ((-420 |#1|) |#1|)) (-15 -1750 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -3545 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -2905 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -1858 ((-3 (-634 (-1157 |#1|)) "failed") (-634 (-1157 |#1|)) (-1157 |#1|))) (-15 -3367 (|#1| |#1| (-1075))) (-15 -2055 ((-634 (-1075)) |#1|)) (-15 -2773 ((-763) |#1| (-634 (-1075)))) (-15 -2773 ((-763) |#1|)) (-15 -2047 (|#1| |#1| (-634 (-1075)) (-634 (-763)))) (-15 -2047 (|#1| |#1| (-1075) (-763))) (-15 -2144 ((-634 (-763)) |#1| (-634 (-1075)))) (-15 -2144 ((-763) |#1| (-1075))) (-15 -2244 ((-3 (-1075) "failed") |#1|)) (-15 -3206 ((-634 (-763)) |#1| (-634 (-1075)))) (-15 -3206 ((-763) |#1| (-1075))) (-15 -2854 ((-1075) |#1|)) (-15 -3666 ((-3 (-1075) "failed") |#1|)) (-15 -2745 (|#1| (-1075))) (-15 -1339 (|#1| |#1| (-634 (-1075)) (-634 |#1|))) (-15 -1339 (|#1| |#1| (-1075) |#1|)) (-15 -1339 (|#1| |#1| (-634 (-1075)) (-634 |#2|))) (-15 -1339 (|#1| |#1| (-1075) |#2|)) (-15 -1339 (|#1| |#1| (-634 |#1|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#1| |#1|)) (-15 -1339 (|#1| |#1| (-288 |#1|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -3206 ((-763) |#1|)) (-15 -2047 (|#1| |#2| (-763))) (-15 -2854 ((-568) |#1|)) (-15 -3666 ((-3 (-568) "failed") |#1|)) (-15 -2854 ((-409 (-568)) |#1|)) (-15 -3666 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2745 (|#1| |#2|)) (-15 -3666 ((-3 |#2| "failed") |#1|)) (-15 -2854 (|#2| |#1|)) (-15 -2144 ((-763) |#1|)) (-15 -3367 (|#2| |#1|)) (-15 -4189 (|#1| |#1| (-634 (-1075)) (-634 (-763)))) (-15 -4189 (|#1| |#1| (-1075) (-763))) (-15 -4189 (|#1| |#1| (-634 (-1075)))) (-15 -4189 (|#1| |#1| (-1075))) (-15 -2745 (|#1| (-568))) (-15 -2745 ((-850) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-2572 (((-1244 |#1|) $ (-763)) 217)) (-2055 (((-634 (-1075)) $) 108)) (-3197 (($ (-1157 |#1|)) 215)) (-3839 (((-1157 $) $ (-1075)) 123) (((-1157 |#1|) $) 122)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 85 (|has| |#1| (-558)))) (-2227 (($ $) 86 (|has| |#1| (-558)))) (-1573 (((-121) $) 88 (|has| |#1| (-558)))) (-2773 (((-763) $) 110) (((-763) $ (-634 (-1075))) 109)) (-3134 (((-3 $ "failed") $ $) 18)) (-3809 (($ $ $) 202 (|has| |#1| (-558)))) (-1750 (((-420 (-1157 $)) (-1157 $)) 98 (|has| |#1| (-904)))) (-4305 (($ $) 96 (|has| |#1| (-453)))) (-1678 (((-420 $) $) 95 (|has| |#1| (-453)))) (-1858 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 101 (|has| |#1| (-904)))) (-1497 (((-121) $ $) 187 (|has| |#1| (-365)))) (-3151 (($ $ (-763)) 210)) (-3772 (($ $ (-763)) 209)) (-1619 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) 197 (|has| |#1| (-453)))) (-2671 (($) 16 T CONST)) (-3666 (((-3 |#1| "failed") $) 162) (((-3 (-409 (-568)) "failed") $) 160 (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) 158 (|has| |#1| (-1037 (-568)))) (((-3 (-1075) "failed") $) 134)) (-2854 ((|#1| $) 163) (((-409 (-568)) $) 159 (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) 157 (|has| |#1| (-1037 (-568)))) (((-1075) $) 133)) (-4265 (($ $ $ (-1075)) 106 (|has| |#1| (-172))) ((|#1| $ $) 205 (|has| |#1| (-172)))) (-2401 (($ $ $) 191 (|has| |#1| (-365)))) (-2114 (($ $) 152)) (-3164 (((-679 (-568)) (-679 $)) 132 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 131 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2928 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 130) (((-679 |#1|) (-679 $)) 129)) (-2925 (((-3 $ "failed") $) 33)) (-2412 (($ $ $) 190 (|has| |#1| (-365)))) (-3002 (($ $ $) 208)) (-3581 (($ $ $) 199 (|has| |#1| (-558)))) (-4144 (((-2 (|:| -2348 |#1|) (|:| -3961 $) (|:| -1500 $)) $ $) 198 (|has| |#1| (-558)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 185 (|has| |#1| (-365)))) (-3250 (($ $) 174 (|has| |#1| (-453))) (($ $ (-1075)) 103 (|has| |#1| (-453)))) (-2108 (((-634 $) $) 107)) (-3927 (((-121) $) 94 (|has| |#1| (-904)))) (-3088 (($ $ |#1| (-763) $) 170)) (-4410 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 82 (-12 (|has| (-1075) (-881 (-381))) (|has| |#1| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 81 (-12 (|has| (-1075) (-881 (-568))) (|has| |#1| (-881 (-568)))))) (-4477 (((-763) $ $) 203 (|has| |#1| (-558)))) (-2735 (((-121) $) 30)) (-4178 (((-763) $) 167)) (-3038 (((-3 $ "failed") $) 183 (|has| |#1| (-1136)))) (-2051 (($ (-1157 |#1|) (-1075)) 115) (($ (-1157 $) (-1075)) 114)) (-3536 (($ $ (-763)) 214)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 194 (|has| |#1| (-365)))) (-2976 (((-634 $) $) 124)) (-3921 (((-121) $) 150)) (-2047 (($ |#1| (-763)) 151) (($ $ (-1075) (-763)) 117) (($ $ (-634 (-1075)) (-634 (-763))) 116)) (-3379 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $ (-1075)) 118) (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 212)) (-2144 (((-763) $) 168) (((-763) $ (-1075)) 120) (((-634 (-763)) $ (-634 (-1075))) 119)) (-2521 (($ $ $) 77 (|has| |#1| (-842)))) (-3268 (($ $ $) 76 (|has| |#1| (-842)))) (-3842 (($ (-1 (-763) (-763)) $) 169)) (-2795 (($ (-1 |#1| |#1|) $) 149)) (-3764 (((-1157 |#1|) $) 216)) (-2244 (((-3 (-1075) "failed") $) 121)) (-2097 (($ $) 147)) (-2102 ((|#1| $) 146)) (-2495 (($ (-634 $)) 92 (|has| |#1| (-453))) (($ $ $) 91 (|has| |#1| (-453)))) (-4487 (((-1143) $) 9)) (-1643 (((-2 (|:| -3961 $) (|:| -1500 $)) $ (-763)) 211)) (-3324 (((-3 (-634 $) "failed") $) 112)) (-1794 (((-3 (-634 $) "failed") $) 113)) (-3751 (((-3 (-2 (|:| |var| (-1075)) (|:| -3438 (-763))) "failed") $) 111)) (-3837 (($ $) 195 (|has| |#1| (-43 (-409 (-568)))))) (-4434 (($) 182 (|has| |#1| (-1136)) CONST)) (-4022 (((-1108) $) 10)) (-2086 (((-121) $) 164)) (-2091 ((|#1| $) 165)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 93 (|has| |#1| (-453)))) (-2721 (($ (-634 $)) 90 (|has| |#1| (-453))) (($ $ $) 89 (|has| |#1| (-453)))) (-2905 (((-420 (-1157 $)) (-1157 $)) 100 (|has| |#1| (-904)))) (-3545 (((-420 (-1157 $)) (-1157 $)) 99 (|has| |#1| (-904)))) (-3848 (((-420 $) $) 97 (|has| |#1| (-904)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 193 (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 192 (|has| |#1| (-365)))) (-2595 (((-3 $ "failed") $ |#1|) 172 (|has| |#1| (-558))) (((-3 $ "failed") $ $) 84 (|has| |#1| (-558)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 186 (|has| |#1| (-365)))) (-1339 (($ $ (-634 (-288 $))) 143) (($ $ (-288 $)) 142) (($ $ $ $) 141) (($ $ (-634 $) (-634 $)) 140) (($ $ (-1075) |#1|) 139) (($ $ (-634 (-1075)) (-634 |#1|)) 138) (($ $ (-1075) $) 137) (($ $ (-634 (-1075)) (-634 $)) 136)) (-2709 (((-763) $) 188 (|has| |#1| (-365)))) (-2779 ((|#1| $ |#1|) 235) (($ $ $) 234) (((-409 $) (-409 $) (-409 $)) 204 (|has| |#1| (-558))) ((|#1| (-409 $) |#1|) 196 (|has| |#1| (-365))) (((-409 $) $ (-409 $)) 184 (|has| |#1| (-558)))) (-2167 (((-3 $ "failed") $ (-763)) 213)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 189 (|has| |#1| (-365)))) (-2217 (($ $ (-1075)) 105 (|has| |#1| (-172))) ((|#1| $) 206 (|has| |#1| (-172)))) (-4189 (($ $ (-1075)) 41) (($ $ (-634 (-1075))) 40) (($ $ (-1075) (-763)) 39) (($ $ (-634 (-1075)) (-634 (-763))) 38) (($ $ (-763)) 232) (($ $) 230) (($ $ (-1161)) 229 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 228 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 227 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) 226 (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) 219) (($ $ (-1 |#1| |#1|)) 218) (($ $ (-1 |#1| |#1|) $) 207)) (-3206 (((-763) $) 148) (((-763) $ (-1075)) 128) (((-634 (-763)) $ (-634 (-1075))) 127)) (-4278 (((-887 (-381)) $) 80 (-12 (|has| (-1075) (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381)))))) (((-887 (-568)) $) 79 (-12 (|has| (-1075) (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568)))))) (((-541) $) 78 (-12 (|has| (-1075) (-609 (-541))) (|has| |#1| (-609 (-541)))))) (-3367 ((|#1| $) 173 (|has| |#1| (-453))) (($ $ (-1075)) 104 (|has| |#1| (-453)))) (-2979 (((-3 (-1244 $) "failed") (-679 $)) 102 (-2139 (|has| $ (-148)) (|has| |#1| (-904))))) (-3950 (((-3 $ "failed") $ $) 201 (|has| |#1| (-558))) (((-3 (-409 $) "failed") (-409 $) $) 200 (|has| |#1| (-558)))) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 161) (($ (-1075)) 135) (($ (-409 (-568))) 70 (-2198 (|has| |#1| (-1037 (-409 (-568)))) (|has| |#1| (-43 (-409 (-568)))))) (($ $) 83 (|has| |#1| (-558)))) (-1302 (((-634 |#1|) $) 166)) (-2604 ((|#1| $ (-763)) 153) (($ $ (-1075) (-763)) 126) (($ $ (-634 (-1075)) (-634 (-763))) 125)) (-4371 (((-3 $ "failed") $) 71 (-2198 (-2139 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-4078 (((-763)) 28)) (-4171 (($ $ $ (-763)) 171 (|has| |#1| (-172)))) (-1826 (((-121) $ $) 87 (|has| |#1| (-558)))) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $ (-1075)) 37) (($ $ (-634 (-1075))) 36) (($ $ (-1075) (-763)) 35) (($ $ (-634 (-1075)) (-634 (-763))) 34) (($ $ (-763)) 233) (($ $) 231) (($ $ (-1161)) 225 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 224 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 223 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) 222 (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) 221) (($ $ (-1 |#1| |#1|)) 220)) (-1751 (((-121) $ $) 74 (|has| |#1| (-842)))) (-1738 (((-121) $ $) 73 (|has| |#1| (-842)))) (-1717 (((-121) $ $) 6)) (-1745 (((-121) $ $) 75 (|has| |#1| (-842)))) (-1732 (((-121) $ $) 72 (|has| |#1| (-842)))) (-1779 (($ $ |#1|) 154 (|has| |#1| (-365)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 156 (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) 155 (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) 145) (($ $ |#1|) 144))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2563 (((-1235 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-301)) (|has| |#1| (-365))))) (-2057 (((-634 (-1075)) $) NIL)) (-3325 (((-1161) $) 10)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558))))) (-3661 (($ $) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558))))) (-4426 (((-121) $) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558))))) (-4179 (($ $ (-568)) NIL) (($ $ (-568) (-568)) NIL)) (-2013 (((-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|))) $) NIL)) (-3054 (((-1235 |#1| |#2| |#3|) $) NIL)) (-1415 (((-3 (-1235 |#1| |#2| |#3|) "failed") $) NIL)) (-2067 (((-1235 |#1| |#2| |#3|) $) NIL)) (-1984 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1935 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))))) (-3045 (($ $) NIL (|has| |#1| (-365)))) (-3498 (((-420 $) $) NIL (|has| |#1| (-365)))) (-1904 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))))) (-2589 (((-121) $ $) NIL (|has| |#1| (-365)))) (-1976 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2788 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3337 (((-568) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))))) (-2512 (($ (-1141 (-2 (|:| |k| (-568)) (|:| |c| |#1|)))) NIL)) (-1992 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1943 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-1235 |#1| |#2| |#3|) "failed") $) NIL) (((-3 (-1161) "failed") $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-1037 (-1161))) (|has| |#1| (-365)))) (((-3 (-409 (-568)) "failed") $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-1037 (-568))) (|has| |#1| (-365)))) (((-3 (-568) "failed") $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-1037 (-568))) (|has| |#1| (-365))))) (-2857 (((-1235 |#1| |#2| |#3|) $) NIL) (((-1161) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-1037 (-1161))) (|has| |#1| (-365)))) (((-409 (-568)) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-1037 (-568))) (|has| |#1| (-365)))) (((-568) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-1037 (-568))) (|has| |#1| (-365))))) (-2232 (($ $) NIL) (($ (-568) $) NIL)) (-2403 (($ $ $) NIL (|has| |#1| (-365)))) (-2116 (($ $) NIL)) (-1668 (((-679 (-1235 |#1| |#2| |#3|)) (-679 $)) NIL (|has| |#1| (-365))) (((-2 (|:| -2908 (-679 (-1235 |#1| |#2| |#3|))) (|:| |vec| (-1244 (-1235 |#1| |#2| |#3|)))) (-679 $) (-1244 $)) NIL (|has| |#1| (-365))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-630 (-568))) (|has| |#1| (-365)))) (((-679 (-568)) (-679 $)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-630 (-568))) (|has| |#1| (-365))))) (-2902 (((-3 $ "failed") $) NIL)) (-1685 (((-409 (-953 |#1|)) $ (-568)) NIL (|has| |#1| (-558))) (((-409 (-953 |#1|)) $ (-568) (-568)) NIL (|has| |#1| (-558)))) (-1733 (($) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-550)) (|has| |#1| (-365))))) (-2414 (($ $ $) NIL (|has| |#1| (-365)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-2197 (((-121) $) NIL (|has| |#1| (-365)))) (-1436 (((-121) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))))) (-1302 (((-121) $) NIL)) (-1899 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1519 (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-881 (-568))) (|has| |#1| (-365)))) (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-881 (-381))) (|has| |#1| (-365))))) (-1844 (((-568) $) NIL) (((-568) $ (-568)) NIL)) (-1598 (((-121) $) NIL)) (-3539 (($ $) NIL (|has| |#1| (-365)))) (-2319 (((-1235 |#1| |#2| |#3|) $) NIL (|has| |#1| (-365)))) (-1550 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2214 (((-3 $ "failed") $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-1136)) (|has| |#1| (-365))))) (-2859 (((-121) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))))) (-4168 (($ $ (-917)) NIL)) (-3698 (($ (-1 |#1| (-568)) $) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| (-568)) 17) (($ $ (-1075) (-568)) NIL) (($ $ (-634 (-1075)) (-634 (-568))) NIL)) (-1732 (($ $ $) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-2047 (($ $ $) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-2797 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 (-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|)) $) NIL (|has| |#1| (-365)))) (-4418 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-2498 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-2072 (($ (-568) (-1235 |#1| |#2| |#3|)) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL (|has| |#1| (-365)))) (-1845 (($ $) 25 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) NIL (-2199 (-12 (|has| |#1| (-15 -1845 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2057 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181))))) (($ $ (-1240 |#2|)) 26 (|has| |#1| (-43 (-409 (-568)))))) (-4436 (($) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-1136)) (|has| |#1| (-365))) CONST)) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-365)))) (-2723 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-1999 (($ $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-301)) (|has| |#1| (-365))))) (-4115 (((-1235 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-550)) (|has| |#1| (-365))))) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))))) (-3850 (((-420 $) $) NIL (|has| |#1| (-365)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-365)))) (-2168 (($ $ (-568)) NIL)) (-2597 (((-3 $ "failed") $ $) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558))))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1894 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-568))))) (($ $ (-1161) (-1235 |#1| |#2| |#3|)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-523 (-1161) (-1235 |#1| |#2| |#3|))) (|has| |#1| (-365)))) (($ $ (-634 (-1161)) (-634 (-1235 |#1| |#2| |#3|))) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-523 (-1161) (-1235 |#1| |#2| |#3|))) (|has| |#1| (-365)))) (($ $ (-634 (-288 (-1235 |#1| |#2| |#3|)))) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-303 (-1235 |#1| |#2| |#3|))) (|has| |#1| (-365)))) (($ $ (-288 (-1235 |#1| |#2| |#3|))) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-303 (-1235 |#1| |#2| |#3|))) (|has| |#1| (-365)))) (($ $ (-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-303 (-1235 |#1| |#2| |#3|))) (|has| |#1| (-365)))) (($ $ (-634 (-1235 |#1| |#2| |#3|)) (-634 (-1235 |#1| |#2| |#3|))) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-303 (-1235 |#1| |#2| |#3|))) (|has| |#1| (-365))))) (-1466 (((-763) $) NIL (|has| |#1| (-365)))) (-2781 ((|#1| $ (-568)) NIL) (($ $ $) NIL (|has| (-568) (-1102))) (($ $ (-1235 |#1| |#2| |#3|)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-281 (-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|))) (|has| |#1| (-365))))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-365)))) (-4191 (($ $ (-1 (-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|))) NIL (|has| |#1| (-365))) (($ $ (-1 (-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|)) (-763)) NIL (|has| |#1| (-365))) (($ $ (-1240 |#2|)) 24) (($ $ (-763)) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $) 23 (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161) (-763)) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-634 (-1161))) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161)) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))))) (-3210 (($ $) NIL (|has| |#1| (-365)))) (-2326 (((-1235 |#1| |#2| |#3|) $) NIL (|has| |#1| (-365)))) (-1836 (((-568) $) NIL)) (-1996 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1947 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1988 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1939 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1980 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2792 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4280 (((-541) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-609 (-541))) (|has| |#1| (-365)))) (((-381) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-1021)) (|has| |#1| (-365)))) (((-215) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-1021)) (|has| |#1| (-365)))) (((-887 (-381)) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-609 (-887 (-381)))) (|has| |#1| (-365)))) (((-887 (-568)) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-609 (-887 (-568)))) (|has| |#1| (-365))))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))))) (-2188 (($ $) NIL)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL (|has| |#1| (-172))) (($ (-1235 |#1| |#2| |#3|)) NIL) (($ (-1240 |#2|)) 22) (($ (-1161)) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-1037 (-1161))) (|has| |#1| (-365)))) (($ $) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558)))) (($ (-409 (-568))) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-1037 (-568))) (|has| |#1| (-365))) (|has| |#1| (-43 (-409 (-568))))))) (-2079 ((|#1| $ (-568)) NIL)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-148)) (|has| |#1| (-365))) (|has| |#1| (-148))))) (-3425 (((-763)) NIL)) (-1374 ((|#1| $) 11)) (-3520 (((-1235 |#1| |#2| |#3|) $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-550)) (|has| |#1| (-365))))) (-2008 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1959 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2273 (((-121) $ $) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-904)) (|has| |#1| (-365))) (|has| |#1| (-558))))) (-2000 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1951 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2016 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1968 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3999 ((|#1| $ (-568)) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-568)))) (|has| |#1| (-15 -2747 (|#1| (-1161))))))) (-1439 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1972 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2012 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1964 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2004 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1955 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2811 (($ $) NIL (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (-3058 (($) 19 T CONST)) (-1557 (($) 15 T CONST)) (-3192 (($ $ (-1 (-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|))) NIL (|has| |#1| (-365))) (($ $ (-1 (-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|)) (-763)) NIL (|has| |#1| (-365))) (($ $ (-763)) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-225)) (|has| |#1| (-365))) (|has| |#1| (-15 * (|#1| (-568) |#1|))))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161) (-763)) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-634 (-1161))) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161)))))) (($ $ (-1161)) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-895 (-1161))) (|has| |#1| (-365))) (-12 (|has| |#1| (-15 * (|#1| (-568) |#1|))) (|has| |#1| (-895 (-1161))))))) (-1753 (((-121) $ $) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-1740 (((-121) $ $) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-1734 (((-121) $ $) NIL (-2199 (-12 (|has| (-1235 |#1| |#2| |#3|) (-815)) (|has| |#1| (-365))) (-12 (|has| (-1235 |#1| |#2| |#3|) (-842)) (|has| |#1| (-365)))))) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365))) (($ (-1235 |#1| |#2| |#3|) (-1235 |#1| |#2| |#3|)) NIL (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) 20)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ (-1235 |#1| |#2| |#3|)) NIL (|has| |#1| (-365))) (($ (-1235 |#1| |#2| |#3|) $) NIL (|has| |#1| (-365))) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
+(((-1207 |#1| |#2| |#3|) (-13 (-1205 |#1| (-1235 |#1| |#2| |#3|)) (-10 -8 (-15 -2747 ($ (-1240 |#2|))) (-15 -4191 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -1845 ($ $ (-1240 |#2|))) |noBranch|))) (-1047) (-1161) |#1|) (T -1207)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1207 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-4191 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1207 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-1845 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1207 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3)))) 
+(-13 (-1205 |#1| (-1235 |#1| |#2| |#3|)) (-10 -8 (-15 -2747 ($ (-1240 |#2|))) (-15 -4191 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -1845 ($ $ (-1240 |#2|))) |noBranch|))) 
+((-2996 (((-2 (|:| |contp| (-568)) (|:| -2075 (-634 (-2 (|:| |irr| |#1|) (|:| -4402 (-568)))))) |#1| (-121)) 10)) (-4254 (((-420 |#1|) |#1|) 21)) (-3850 (((-420 |#1|) |#1|) 20))) 
+(((-1208 |#1|) (-10 -7 (-15 -3850 ((-420 |#1|) |#1|)) (-15 -4254 ((-420 |#1|) |#1|)) (-15 -2996 ((-2 (|:| |contp| (-568)) (|:| -2075 (-634 (-2 (|:| |irr| |#1|) (|:| -4402 (-568)))))) |#1| (-121)))) (-1219 (-568))) (T -1208)) 
+((-2996 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-5 *2 (-2 (|:| |contp| (-568)) (|:| -2075 (-634 (-2 (|:| |irr| *3) (|:| -4402 (-568))))))) (-5 *1 (-1208 *3)) (-4 *3 (-1219 (-568))))) (-4254 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-1208 *3)) (-4 *3 (-1219 (-568))))) (-3850 (*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-1208 *3)) (-4 *3 (-1219 (-568)))))) 
+(-10 -7 (-15 -3850 ((-420 |#1|) |#1|)) (-15 -4254 ((-420 |#1|) |#1|)) (-15 -2996 ((-2 (|:| |contp| (-568)) (|:| -2075 (-634 (-2 (|:| |irr| |#1|) (|:| -4402 (-568)))))) |#1| (-121)))) 
+((-2797 (((-1141 |#2|) (-1 |#2| |#1|) (-1210 |#1|)) 23 (|has| |#1| (-840))) (((-1210 |#2|) (-1 |#2| |#1|) (-1210 |#1|)) 17))) 
+(((-1209 |#1| |#2|) (-10 -7 (-15 -2797 ((-1210 |#2|) (-1 |#2| |#1|) (-1210 |#1|))) (IF (|has| |#1| (-840)) (-15 -2797 ((-1141 |#2|) (-1 |#2| |#1|) (-1210 |#1|))) |noBranch|)) (-1195) (-1195)) (T -1209)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1210 *5)) (-4 *5 (-840)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1141 *6)) (-5 *1 (-1209 *5 *6)))) (-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1210 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1210 *6)) (-5 *1 (-1209 *5 *6))))) 
+(-10 -7 (-15 -2797 ((-1210 |#2|) (-1 |#2| |#1|) (-1210 |#1|))) (IF (|has| |#1| (-840)) (-15 -2797 ((-1141 |#2|) (-1 |#2| |#1|) (-1210 |#1|))) |noBranch|)) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-2465 (($ |#1| |#1|) 9) (($ |#1|) 8)) (-2797 (((-1141 |#1|) (-1 |#1| |#1|) $) 41 (|has| |#1| (-840)))) (-3544 ((|#1| $) 14)) (-2748 ((|#1| $) 10)) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-2753 (((-568) $) 18)) (-3043 ((|#1| $) 17)) (-2756 ((|#1| $) 11)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-1336 (((-121) $) 16)) (-2791 (((-1141 |#1|) $) 38 (|has| |#1| (-840))) (((-1141 |#1|) (-634 $)) 37 (|has| |#1| (-840)))) (-4280 (($ |#1|) 25)) (-2747 (($ (-1084 |#1|)) 24) (((-850) $) 34 (|has| |#1| (-1090)))) (-4255 (($ |#1| |#1|) 20) (($ |#1|) 19)) (-4145 (($ $ (-568)) 13)) (-1719 (((-121) $ $) 27 (|has| |#1| (-1090))))) 
+(((-1210 |#1|) (-13 (-1083 |#1|) (-10 -8 (-15 -4255 ($ |#1|)) (-15 -2465 ($ |#1|)) (-15 -2747 ($ (-1084 |#1|))) (-15 -1336 ((-121) $)) (IF (|has| |#1| (-1090)) (-6 (-1090)) |noBranch|) (IF (|has| |#1| (-840)) (-6 (-1085 |#1| (-1141 |#1|))) |noBranch|))) (-1195)) (T -1210)) 
+((-4255 (*1 *1 *2) (-12 (-5 *1 (-1210 *2)) (-4 *2 (-1195)))) (-2465 (*1 *1 *2) (-12 (-5 *1 (-1210 *2)) (-4 *2 (-1195)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-1084 *3)) (-4 *3 (-1195)) (-5 *1 (-1210 *3)))) (-1336 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1210 *3)) (-4 *3 (-1195))))) 
+(-13 (-1083 |#1|) (-10 -8 (-15 -4255 ($ |#1|)) (-15 -2465 ($ |#1|)) (-15 -2747 ($ (-1084 |#1|))) (-15 -1336 ((-121) $)) (IF (|has| |#1| (-1090)) (-6 (-1090)) |noBranch|) (IF (|has| |#1| (-840)) (-6 (-1085 |#1| (-1141 |#1|))) |noBranch|))) 
+((-2797 (((-1216 |#3| |#4|) (-1 |#4| |#2|) (-1216 |#1| |#2|)) 15))) 
+(((-1211 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2797 ((-1216 |#3| |#4|) (-1 |#4| |#2|) (-1216 |#1| |#2|)))) (-1161) (-1047) (-1161) (-1047)) (T -1211)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *6)) (-5 *4 (-1216 *5 *6)) (-14 *5 (-1161)) (-4 *6 (-1047)) (-4 *8 (-1047)) (-5 *2 (-1216 *7 *8)) (-5 *1 (-1211 *5 *6 *7 *8)) (-14 *7 (-1161))))) 
+(-10 -7 (-15 -2797 ((-1216 |#3| |#4|) (-1 |#4| |#2|) (-1216 |#1| |#2|)))) 
+((-3618 (((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|) 21)) (-2471 ((|#1| |#3|) 13)) (-2609 ((|#3| |#3|) 19))) 
+(((-1212 |#1| |#2| |#3|) (-10 -7 (-15 -2471 (|#1| |#3|)) (-15 -2609 (|#3| |#3|)) (-15 -3618 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|))) (-558) (-993 |#1|) (-1219 |#2|)) (T -1212)) 
+((-3618 (*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-993 *4)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4))) (-5 *1 (-1212 *4 *5 *3)) (-4 *3 (-1219 *5)))) (-2609 (*1 *2 *2) (-12 (-4 *3 (-558)) (-4 *4 (-993 *3)) (-5 *1 (-1212 *3 *4 *2)) (-4 *2 (-1219 *4)))) (-2471 (*1 *2 *3) (-12 (-4 *4 (-993 *2)) (-4 *2 (-558)) (-5 *1 (-1212 *2 *4 *3)) (-4 *3 (-1219 *4))))) 
+(-10 -7 (-15 -2471 (|#1| |#3|)) (-15 -2609 (|#3| |#3|)) (-15 -3618 ((-2 (|:| |num| |#3|) (|:| |den| |#1|)) |#3|))) 
+((-2390 (((-3 |#2| "failed") |#2| (-763) |#1|) 29)) (-3745 (((-3 |#2| "failed") |#2| (-763)) 30)) (-1712 (((-3 (-2 (|:| -3030 |#2|) (|:| -3286 |#2|)) "failed") |#2|) 42)) (-3212 (((-634 |#2|) |#2|) 44)) (-1354 (((-3 |#2| "failed") |#2| |#2|) 39))) 
+(((-1213 |#1| |#2|) (-10 -7 (-15 -3745 ((-3 |#2| "failed") |#2| (-763))) (-15 -2390 ((-3 |#2| "failed") |#2| (-763) |#1|)) (-15 -1354 ((-3 |#2| "failed") |#2| |#2|)) (-15 -1712 ((-3 (-2 (|:| -3030 |#2|) (|:| -3286 |#2|)) "failed") |#2|)) (-15 -3212 ((-634 |#2|) |#2|))) (-13 (-558) (-150)) (-1219 |#1|)) (T -1213)) 
+((-3212 (*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-150))) (-5 *2 (-634 *3)) (-5 *1 (-1213 *4 *3)) (-4 *3 (-1219 *4)))) (-1712 (*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-558) (-150))) (-5 *2 (-2 (|:| -3030 *3) (|:| -3286 *3))) (-5 *1 (-1213 *4 *3)) (-4 *3 (-1219 *4)))) (-1354 (*1 *2 *2 *2) (|partial| -12 (-4 *3 (-13 (-558) (-150))) (-5 *1 (-1213 *3 *2)) (-4 *2 (-1219 *3)))) (-2390 (*1 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-763)) (-4 *4 (-13 (-558) (-150))) (-5 *1 (-1213 *4 *2)) (-4 *2 (-1219 *4)))) (-3745 (*1 *2 *2 *3) (|partial| -12 (-5 *3 (-763)) (-4 *4 (-13 (-558) (-150))) (-5 *1 (-1213 *4 *2)) (-4 *2 (-1219 *4))))) 
+(-10 -7 (-15 -3745 ((-3 |#2| "failed") |#2| (-763))) (-15 -2390 ((-3 |#2| "failed") |#2| (-763) |#1|)) (-15 -1354 ((-3 |#2| "failed") |#2| |#2|)) (-15 -1712 ((-3 (-2 (|:| -3030 |#2|) (|:| -3286 |#2|)) "failed") |#2|)) (-15 -3212 ((-634 |#2|) |#2|))) 
+((-2278 (((-3 (-2 (|:| -4409 |#2|) (|:| -2607 |#2|)) "failed") |#2| |#2|) 31))) 
+(((-1214 |#1| |#2|) (-10 -7 (-15 -2278 ((-3 (-2 (|:| -4409 |#2|) (|:| -2607 |#2|)) "failed") |#2| |#2|))) (-558) (-1219 |#1|)) (T -1214)) 
+((-2278 (*1 *2 *3 *3) (|partial| -12 (-4 *4 (-558)) (-5 *2 (-2 (|:| -4409 *3) (|:| -2607 *3))) (-5 *1 (-1214 *4 *3)) (-4 *3 (-1219 *4))))) 
+(-10 -7 (-15 -2278 ((-3 (-2 (|:| -4409 |#2|) (|:| -2607 |#2|)) "failed") |#2| |#2|))) 
+((-3595 ((|#2| |#2| |#2|) 19)) (-1481 ((|#2| |#2| |#2|) 30)) (-2377 ((|#2| |#2| |#2| (-763) (-763)) 36))) 
+(((-1215 |#1| |#2|) (-10 -7 (-15 -3595 (|#2| |#2| |#2|)) (-15 -1481 (|#2| |#2| |#2|)) (-15 -2377 (|#2| |#2| |#2| (-763) (-763)))) (-1047) (-1219 |#1|)) (T -1215)) 
+((-2377 (*1 *2 *2 *2 *3 *3) (-12 (-5 *3 (-763)) (-4 *4 (-1047)) (-5 *1 (-1215 *4 *2)) (-4 *2 (-1219 *4)))) (-1481 (*1 *2 *2 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-1215 *3 *2)) (-4 *2 (-1219 *3)))) (-3595 (*1 *2 *2 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-1215 *3 *2)) (-4 *2 (-1219 *3))))) 
+(-10 -7 (-15 -3595 (|#2| |#2| |#2|)) (-15 -1481 (|#2| |#2| |#2|)) (-15 -2377 (|#2| |#2| |#2| (-763) (-763)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-1969 (((-1244 |#2|) $ (-763)) NIL)) (-2057 (((-634 (-1075)) $) NIL)) (-1807 (($ (-1157 |#2|)) NIL)) (-3840 (((-1157 $) $ (-1075)) NIL) (((-1157 |#2|) $) NIL)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#2| (-558)))) (-3661 (($ $) NIL (|has| |#2| (-558)))) (-4426 (((-121) $) NIL (|has| |#2| (-558)))) (-3528 (((-763) $) NIL) (((-763) $ (-634 (-1075))) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-1736 (($ $ $) NIL (|has| |#2| (-558)))) (-3863 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3045 (($ $) NIL (|has| |#2| (-453)))) (-3498 (((-420 $) $) NIL (|has| |#2| (-453)))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-2589 (((-121) $ $) NIL (|has| |#2| (-365)))) (-2752 (($ $ (-763)) NIL)) (-2699 (($ $ (-763)) NIL)) (-1448 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) NIL (|has| |#2| (-453)))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#2| "failed") $) NIL) (((-3 (-409 (-568)) "failed") $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) NIL (|has| |#2| (-1037 (-568)))) (((-3 (-1075) "failed") $) NIL)) (-2857 ((|#2| $) NIL) (((-409 (-568)) $) NIL (|has| |#2| (-1037 (-409 (-568))))) (((-568) $) NIL (|has| |#2| (-1037 (-568)))) (((-1075) $) NIL)) (-2910 (($ $ $ (-1075)) NIL (|has| |#2| (-172))) ((|#2| $ $) NIL (|has| |#2| (-172)))) (-2403 (($ $ $) NIL (|has| |#2| (-365)))) (-2116 (($ $) NIL)) (-1668 (((-679 (-568)) (-679 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) NIL (|has| |#2| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#2|)) (|:| |vec| (-1244 |#2|))) (-679 $) (-1244 $)) NIL) (((-679 |#2|) (-679 $)) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-2414 (($ $ $) NIL (|has| |#2| (-365)))) (-3152 (($ $ $) NIL)) (-2929 (($ $ $) NIL (|has| |#2| (-558)))) (-3777 (((-2 (|:| -2350 |#2|) (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#2| (-558)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| |#2| (-365)))) (-1998 (($ $) NIL (|has| |#2| (-453))) (($ $ (-1075)) NIL (|has| |#2| (-453)))) (-2110 (((-634 $) $) NIL)) (-2197 (((-121) $) NIL (|has| |#2| (-904)))) (-2453 (($ $ |#2| (-763) $) NIL)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) NIL (-12 (|has| (-1075) (-881 (-381))) (|has| |#2| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) NIL (-12 (|has| (-1075) (-881 (-568))) (|has| |#2| (-881 (-568)))))) (-1844 (((-763) $ $) NIL (|has| |#2| (-558)))) (-1598 (((-121) $) NIL)) (-3971 (((-763) $) NIL)) (-2214 (((-3 $ "failed") $) NIL (|has| |#2| (-1136)))) (-2053 (($ (-1157 |#2|) (-1075)) NIL) (($ (-1157 $) (-1075)) NIL)) (-4168 (($ $ (-763)) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#2| (-365)))) (-3062 (((-634 $) $) NIL)) (-2171 (((-121) $) NIL)) (-2049 (($ |#2| (-763)) 17) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-1438 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $ (-1075)) NIL) (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL)) (-3524 (((-763) $) NIL) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-1732 (($ $ $) NIL (|has| |#2| (-842)))) (-2047 (($ $ $) NIL (|has| |#2| (-842)))) (-1865 (($ (-1 (-763) (-763)) $) NIL)) (-2797 (($ (-1 |#2| |#2|) $) NIL)) (-2671 (((-1157 |#2|) $) NIL)) (-2817 (((-3 (-1075) "failed") $) NIL)) (-2099 (($ $) NIL)) (-2104 ((|#2| $) NIL)) (-2498 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) NIL (|has| |#2| (-453)))) (-1893 (((-1143) $) NIL)) (-3262 (((-2 (|:| -4409 $) (|:| -2607 $)) $ (-763)) NIL)) (-4362 (((-3 (-634 $) "failed") $) NIL)) (-2112 (((-3 (-634 $) "failed") $) NIL)) (-2617 (((-3 (-2 (|:| |var| (-1075)) (|:| -3483 (-763))) "failed") $) NIL)) (-1845 (($ $) NIL (|has| |#2| (-43 (-409 (-568)))))) (-4436 (($) NIL (|has| |#2| (-1136)) CONST)) (-4025 (((-1108) $) NIL)) (-2088 (((-121) $) NIL)) (-2093 ((|#2| $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#2| (-453)))) (-2723 (($ (-634 $)) NIL (|has| |#2| (-453))) (($ $ $) NIL (|has| |#2| (-453)))) (-2973 (($ $ (-763) |#2| $) NIL)) (-2841 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) NIL (|has| |#2| (-904)))) (-3850 (((-420 $) $) NIL (|has| |#2| (-904)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#2| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#2| (-365)))) (-2597 (((-3 $ "failed") $ |#2|) NIL (|has| |#2| (-558))) (((-3 $ "failed") $ $) NIL (|has| |#2| (-558)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#2| (-365)))) (-1339 (($ $ (-634 (-288 $))) NIL) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-1075) |#2|) NIL) (($ $ (-634 (-1075)) (-634 |#2|)) NIL) (($ $ (-1075) $) NIL) (($ $ (-634 (-1075)) (-634 $)) NIL)) (-1466 (((-763) $) NIL (|has| |#2| (-365)))) (-2781 ((|#2| $ |#2|) NIL) (($ $ $) NIL) (((-409 $) (-409 $) (-409 $)) NIL (|has| |#2| (-558))) ((|#2| (-409 $) |#2|) NIL (|has| |#2| (-365))) (((-409 $) $ (-409 $)) NIL (|has| |#2| (-558)))) (-3805 (((-3 $ "failed") $ (-763)) NIL)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#2| (-365)))) (-3440 (($ $ (-1075)) NIL (|has| |#2| (-172))) ((|#2| $) NIL (|has| |#2| (-172)))) (-4191 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) NIL) (($ $ (-1 |#2| |#2|) $) NIL)) (-1836 (((-763) $) NIL) (((-763) $ (-1075)) NIL) (((-634 (-763)) $ (-634 (-1075))) NIL)) (-4280 (((-887 (-381)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-381)))) (|has| |#2| (-609 (-887 (-381)))))) (((-887 (-568)) $) NIL (-12 (|has| (-1075) (-609 (-887 (-568)))) (|has| |#2| (-609 (-887 (-568)))))) (((-541) $) NIL (-12 (|has| (-1075) (-609 (-541))) (|has| |#2| (-609 (-541)))))) (-1364 ((|#2| $) NIL (|has| |#2| (-453))) (($ $ (-1075)) NIL (|has| |#2| (-453)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) NIL (-12 (|has| $ (-148)) (|has| |#2| (-904))))) (-4363 (((-3 $ "failed") $ $) NIL (|has| |#2| (-558))) (((-3 (-409 $) "failed") (-409 $) $) NIL (|has| |#2| (-558)))) (-2747 (((-850) $) 13) (($ (-568)) NIL) (($ |#2|) NIL) (($ (-1075)) NIL) (($ (-1240 |#1|)) 19) (($ (-409 (-568))) NIL (-2199 (|has| |#2| (-43 (-409 (-568)))) (|has| |#2| (-1037 (-409 (-568)))))) (($ $) NIL (|has| |#2| (-558)))) (-3304 (((-634 |#2|) $) NIL)) (-2079 ((|#2| $ (-763)) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-3385 (((-3 $ "failed") $) NIL (-2199 (-12 (|has| $ (-148)) (|has| |#2| (-904))) (|has| |#2| (-148))))) (-3425 (((-763)) NIL)) (-3925 (($ $ $ (-763)) NIL (|has| |#2| (-172)))) (-2273 (((-121) $ $) NIL (|has| |#2| (-558)))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-1557 (($) 14 T CONST)) (-3192 (($ $ (-1075)) NIL) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) NIL) (($ $ (-1161)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1161) (-763)) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) NIL (|has| |#2| (-895 (-1161)))) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) NIL)) (-1753 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1719 (((-121) $ $) NIL)) (-1747 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#2| (-842)))) (-1781 (($ $ |#2|) NIL (|has| |#2| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-409 (-568))) NIL (|has| |#2| (-43 (-409 (-568))))) (($ (-409 (-568)) $) NIL (|has| |#2| (-43 (-409 (-568))))) (($ |#2| $) NIL) (($ $ |#2|) NIL))) 
+(((-1216 |#1| |#2|) (-13 (-1219 |#2|) (-10 -8 (-15 -2747 ($ (-1240 |#1|))) (-15 -2973 ($ $ (-763) |#2| $)))) (-1161) (-1047)) (T -1216)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1240 *3)) (-14 *3 (-1161)) (-5 *1 (-1216 *3 *4)) (-4 *4 (-1047)))) (-2973 (*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1216 *4 *3)) (-14 *4 (-1161)) (-4 *3 (-1047))))) 
+(-13 (-1219 |#2|) (-10 -8 (-15 -2747 ($ (-1240 |#1|))) (-15 -2973 ($ $ (-763) |#2| $)))) 
+((-2797 ((|#4| (-1 |#3| |#1|) |#2|) 22))) 
+(((-1217 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2797 (|#4| (-1 |#3| |#1|) |#2|))) (-1047) (-1219 |#1|) (-1047) (-1219 |#3|)) (T -1217)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-4 *2 (-1219 *6)) (-5 *1 (-1217 *5 *4 *6 *2)) (-4 *4 (-1219 *5))))) 
+(-10 -7 (-15 -2797 (|#4| (-1 |#3| |#1|) |#2|))) 
+((-1969 (((-1244 |#2|) $ (-763)) 113)) (-2057 (((-634 (-1075)) $) 15)) (-1807 (($ (-1157 |#2|)) 66)) (-3528 (((-763) $) NIL) (((-763) $ (-634 (-1075))) 18)) (-3863 (((-420 (-1157 $)) (-1157 $)) 183)) (-3045 (($ $) 173)) (-3498 (((-420 $) $) 171)) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 81)) (-2752 (($ $ (-763)) 70)) (-2699 (($ $ (-763)) 72)) (-1448 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) 129)) (-3668 (((-3 |#2| "failed") $) 116) (((-3 (-409 (-568)) "failed") $) NIL) (((-3 (-568) "failed") $) NIL) (((-3 (-1075) "failed") $) NIL)) (-2857 ((|#2| $) 114) (((-409 (-568)) $) NIL) (((-568) $) NIL) (((-1075) $) NIL)) (-2929 (($ $ $) 150)) (-3777 (((-2 (|:| -2350 |#2|) (|:| -4409 $) (|:| -2607 $)) $ $) 152)) (-1844 (((-763) $ $) 168)) (-2214 (((-3 $ "failed") $) 122)) (-2049 (($ |#2| (-763)) NIL) (($ $ (-1075) (-763)) 46) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-3524 (((-763) $) NIL) (((-763) $ (-1075)) 41) (((-634 (-763)) $ (-634 (-1075))) 42)) (-2671 (((-1157 |#2|) $) 58)) (-2817 (((-3 (-1075) "failed") $) 39)) (-3262 (((-2 (|:| -4409 $) (|:| -2607 $)) $ (-763)) 69)) (-1845 (($ $) 194)) (-4436 (($) 118)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 180)) (-2841 (((-420 (-1157 $)) (-1157 $)) 87)) (-2795 (((-420 (-1157 $)) (-1157 $)) 85)) (-3850 (((-420 $) $) 105)) (-1339 (($ $ (-634 (-288 $))) 38) (($ $ (-288 $)) NIL) (($ $ $ $) NIL) (($ $ (-634 $) (-634 $)) NIL) (($ $ (-1075) |#2|) 31) (($ $ (-634 (-1075)) (-634 |#2|)) 28) (($ $ (-1075) $) 25) (($ $ (-634 (-1075)) (-634 $)) 23)) (-1466 (((-763) $) 186)) (-2781 ((|#2| $ |#2|) NIL) (($ $ $) NIL) (((-409 $) (-409 $) (-409 $)) 146) ((|#2| (-409 $) |#2|) 185) (((-409 $) $ (-409 $)) 167)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 189)) (-4191 (($ $ (-1075)) 139) (($ $ (-634 (-1075))) NIL) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL) (($ $ (-763)) NIL) (($ $) 137) (($ $ (-1161)) NIL) (($ $ (-634 (-1161))) NIL) (($ $ (-1161) (-763)) NIL) (($ $ (-634 (-1161)) (-634 (-763))) NIL) (($ $ (-1 |#2| |#2|) (-763)) NIL) (($ $ (-1 |#2| |#2|)) 136) (($ $ (-1 |#2| |#2|) $) 133)) (-1836 (((-763) $) NIL) (((-763) $ (-1075)) 16) (((-634 (-763)) $ (-634 (-1075))) 20)) (-1364 ((|#2| $) NIL) (($ $ (-1075)) 124)) (-4363 (((-3 $ "failed") $ $) 160) (((-3 (-409 $) "failed") (-409 $) $) 156)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#2|) NIL) (($ (-1075)) 50) (($ (-409 (-568))) NIL) (($ $) NIL))) 
+(((-1218 |#1| |#2|) (-10 -8 (-15 -2747 (|#1| |#1|)) (-15 -3603 ((-1157 |#1|) (-1157 |#1|) (-1157 |#1|))) (-15 -3498 ((-420 |#1|) |#1|)) (-15 -3045 (|#1| |#1|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -4436 (|#1|)) (-15 -2214 ((-3 |#1| "failed") |#1|)) (-15 -2781 ((-409 |#1|) |#1| (-409 |#1|))) (-15 -1466 ((-763) |#1|)) (-15 -1854 ((-2 (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1|)) (-15 -1845 (|#1| |#1|)) (-15 -2781 (|#2| (-409 |#1|) |#2|)) (-15 -1448 ((-2 (|:| |primePart| |#1|) (|:| |commonPart| |#1|)) |#1| |#1|)) (-15 -3777 ((-2 (|:| -2350 |#2|) (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1|)) (-15 -2929 (|#1| |#1| |#1|)) (-15 -4363 ((-3 (-409 |#1|) "failed") (-409 |#1|) |#1|)) (-15 -4363 ((-3 |#1| "failed") |#1| |#1|)) (-15 -1844 ((-763) |#1| |#1|)) (-15 -2781 ((-409 |#1|) (-409 |#1|) (-409 |#1|))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|) |#1|)) (-15 -2699 (|#1| |#1| (-763))) (-15 -2752 (|#1| |#1| (-763))) (-15 -3262 ((-2 (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| (-763))) (-15 -1807 (|#1| (-1157 |#2|))) (-15 -2671 ((-1157 |#2|) |#1|)) (-15 -1969 ((-1244 |#2|) |#1| (-763))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -4191 (|#1| |#1| (-1161) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)))) (-15 -4191 (|#1| |#1| (-1161))) (-15 -4191 (|#1| |#1|)) (-15 -4191 (|#1| |#1| (-763))) (-15 -2781 (|#1| |#1| |#1|)) (-15 -2781 (|#2| |#1| |#2|)) (-15 -3850 ((-420 |#1|) |#1|)) (-15 -3863 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -2795 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -2841 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -2434 ((-3 (-634 (-1157 |#1|)) "failed") (-634 (-1157 |#1|)) (-1157 |#1|))) (-15 -1364 (|#1| |#1| (-1075))) (-15 -2057 ((-634 (-1075)) |#1|)) (-15 -3528 ((-763) |#1| (-634 (-1075)))) (-15 -3528 ((-763) |#1|)) (-15 -2049 (|#1| |#1| (-634 (-1075)) (-634 (-763)))) (-15 -2049 (|#1| |#1| (-1075) (-763))) (-15 -3524 ((-634 (-763)) |#1| (-634 (-1075)))) (-15 -3524 ((-763) |#1| (-1075))) (-15 -2817 ((-3 (-1075) "failed") |#1|)) (-15 -1836 ((-634 (-763)) |#1| (-634 (-1075)))) (-15 -1836 ((-763) |#1| (-1075))) (-15 -2857 ((-1075) |#1|)) (-15 -3668 ((-3 (-1075) "failed") |#1|)) (-15 -2747 (|#1| (-1075))) (-15 -1339 (|#1| |#1| (-634 (-1075)) (-634 |#1|))) (-15 -1339 (|#1| |#1| (-1075) |#1|)) (-15 -1339 (|#1| |#1| (-634 (-1075)) (-634 |#2|))) (-15 -1339 (|#1| |#1| (-1075) |#2|)) (-15 -1339 (|#1| |#1| (-634 |#1|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#1| |#1|)) (-15 -1339 (|#1| |#1| (-288 |#1|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -1836 ((-763) |#1|)) (-15 -2049 (|#1| |#2| (-763))) (-15 -2857 ((-568) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2747 (|#1| |#2|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -2857 (|#2| |#1|)) (-15 -3524 ((-763) |#1|)) (-15 -1364 (|#2| |#1|)) (-15 -4191 (|#1| |#1| (-634 (-1075)) (-634 (-763)))) (-15 -4191 (|#1| |#1| (-1075) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1075)))) (-15 -4191 (|#1| |#1| (-1075))) (-15 -2747 (|#1| (-568))) (-15 -2747 ((-850) |#1|))) (-1219 |#2|) (-1047)) (T -1218)) 
+NIL 
+(-10 -8 (-15 -2747 (|#1| |#1|)) (-15 -3603 ((-1157 |#1|) (-1157 |#1|) (-1157 |#1|))) (-15 -3498 ((-420 |#1|) |#1|)) (-15 -3045 (|#1| |#1|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -4436 (|#1|)) (-15 -2214 ((-3 |#1| "failed") |#1|)) (-15 -2781 ((-409 |#1|) |#1| (-409 |#1|))) (-15 -1466 ((-763) |#1|)) (-15 -1854 ((-2 (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1|)) (-15 -1845 (|#1| |#1|)) (-15 -2781 (|#2| (-409 |#1|) |#2|)) (-15 -1448 ((-2 (|:| |primePart| |#1|) (|:| |commonPart| |#1|)) |#1| |#1|)) (-15 -3777 ((-2 (|:| -2350 |#2|) (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| |#1|)) (-15 -2929 (|#1| |#1| |#1|)) (-15 -4363 ((-3 (-409 |#1|) "failed") (-409 |#1|) |#1|)) (-15 -4363 ((-3 |#1| "failed") |#1| |#1|)) (-15 -1844 ((-763) |#1| |#1|)) (-15 -2781 ((-409 |#1|) (-409 |#1|) (-409 |#1|))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|) |#1|)) (-15 -2699 (|#1| |#1| (-763))) (-15 -2752 (|#1| |#1| (-763))) (-15 -3262 ((-2 (|:| -4409 |#1|) (|:| -2607 |#1|)) |#1| (-763))) (-15 -1807 (|#1| (-1157 |#2|))) (-15 -2671 ((-1157 |#2|) |#1|)) (-15 -1969 ((-1244 |#2|) |#1| (-763))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|))) (-15 -4191 (|#1| |#1| (-1 |#2| |#2|) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)) (-634 (-763)))) (-15 -4191 (|#1| |#1| (-1161) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1161)))) (-15 -4191 (|#1| |#1| (-1161))) (-15 -4191 (|#1| |#1|)) (-15 -4191 (|#1| |#1| (-763))) (-15 -2781 (|#1| |#1| |#1|)) (-15 -2781 (|#2| |#1| |#2|)) (-15 -3850 ((-420 |#1|) |#1|)) (-15 -3863 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -2795 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -2841 ((-420 (-1157 |#1|)) (-1157 |#1|))) (-15 -2434 ((-3 (-634 (-1157 |#1|)) "failed") (-634 (-1157 |#1|)) (-1157 |#1|))) (-15 -1364 (|#1| |#1| (-1075))) (-15 -2057 ((-634 (-1075)) |#1|)) (-15 -3528 ((-763) |#1| (-634 (-1075)))) (-15 -3528 ((-763) |#1|)) (-15 -2049 (|#1| |#1| (-634 (-1075)) (-634 (-763)))) (-15 -2049 (|#1| |#1| (-1075) (-763))) (-15 -3524 ((-634 (-763)) |#1| (-634 (-1075)))) (-15 -3524 ((-763) |#1| (-1075))) (-15 -2817 ((-3 (-1075) "failed") |#1|)) (-15 -1836 ((-634 (-763)) |#1| (-634 (-1075)))) (-15 -1836 ((-763) |#1| (-1075))) (-15 -2857 ((-1075) |#1|)) (-15 -3668 ((-3 (-1075) "failed") |#1|)) (-15 -2747 (|#1| (-1075))) (-15 -1339 (|#1| |#1| (-634 (-1075)) (-634 |#1|))) (-15 -1339 (|#1| |#1| (-1075) |#1|)) (-15 -1339 (|#1| |#1| (-634 (-1075)) (-634 |#2|))) (-15 -1339 (|#1| |#1| (-1075) |#2|)) (-15 -1339 (|#1| |#1| (-634 |#1|) (-634 |#1|))) (-15 -1339 (|#1| |#1| |#1| |#1|)) (-15 -1339 (|#1| |#1| (-288 |#1|))) (-15 -1339 (|#1| |#1| (-634 (-288 |#1|)))) (-15 -1836 ((-763) |#1|)) (-15 -2049 (|#1| |#2| (-763))) (-15 -2857 ((-568) |#1|)) (-15 -3668 ((-3 (-568) "failed") |#1|)) (-15 -2857 ((-409 (-568)) |#1|)) (-15 -3668 ((-3 (-409 (-568)) "failed") |#1|)) (-15 -2747 (|#1| |#2|)) (-15 -3668 ((-3 |#2| "failed") |#1|)) (-15 -2857 (|#2| |#1|)) (-15 -3524 ((-763) |#1|)) (-15 -1364 (|#2| |#1|)) (-15 -4191 (|#1| |#1| (-634 (-1075)) (-634 (-763)))) (-15 -4191 (|#1| |#1| (-1075) (-763))) (-15 -4191 (|#1| |#1| (-634 (-1075)))) (-15 -4191 (|#1| |#1| (-1075))) (-15 -2747 (|#1| (-568))) (-15 -2747 ((-850) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-1969 (((-1244 |#1|) $ (-763)) 217)) (-2057 (((-634 (-1075)) $) 108)) (-1807 (($ (-1157 |#1|)) 215)) (-3840 (((-1157 $) $ (-1075)) 123) (((-1157 |#1|) $) 122)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 85 (|has| |#1| (-558)))) (-3661 (($ $) 86 (|has| |#1| (-558)))) (-4426 (((-121) $) 88 (|has| |#1| (-558)))) (-3528 (((-763) $) 110) (((-763) $ (-634 (-1075))) 109)) (-2689 (((-3 $ "failed") $ $) 18)) (-1736 (($ $ $) 202 (|has| |#1| (-558)))) (-3863 (((-420 (-1157 $)) (-1157 $)) 98 (|has| |#1| (-904)))) (-3045 (($ $) 96 (|has| |#1| (-453)))) (-3498 (((-420 $) $) 95 (|has| |#1| (-453)))) (-2434 (((-3 (-634 (-1157 $)) "failed") (-634 (-1157 $)) (-1157 $)) 101 (|has| |#1| (-904)))) (-2589 (((-121) $ $) 187 (|has| |#1| (-365)))) (-2752 (($ $ (-763)) 210)) (-2699 (($ $ (-763)) 209)) (-1448 (((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $) 197 (|has| |#1| (-453)))) (-4490 (($) 16 T CONST)) (-3668 (((-3 |#1| "failed") $) 162) (((-3 (-409 (-568)) "failed") $) 160 (|has| |#1| (-1037 (-409 (-568))))) (((-3 (-568) "failed") $) 158 (|has| |#1| (-1037 (-568)))) (((-3 (-1075) "failed") $) 134)) (-2857 ((|#1| $) 163) (((-409 (-568)) $) 159 (|has| |#1| (-1037 (-409 (-568))))) (((-568) $) 157 (|has| |#1| (-1037 (-568)))) (((-1075) $) 133)) (-2910 (($ $ $ (-1075)) 106 (|has| |#1| (-172))) ((|#1| $ $) 205 (|has| |#1| (-172)))) (-2403 (($ $ $) 191 (|has| |#1| (-365)))) (-2116 (($ $) 152)) (-1668 (((-679 (-568)) (-679 $)) 132 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 (-568))) (|:| |vec| (-1244 (-568)))) (-679 $) (-1244 $)) 131 (|has| |#1| (-630 (-568)))) (((-2 (|:| -2908 (-679 |#1|)) (|:| |vec| (-1244 |#1|))) (-679 $) (-1244 $)) 130) (((-679 |#1|) (-679 $)) 129)) (-2902 (((-3 $ "failed") $) 33)) (-2414 (($ $ $) 190 (|has| |#1| (-365)))) (-3152 (($ $ $) 208)) (-2929 (($ $ $) 199 (|has| |#1| (-558)))) (-3777 (((-2 (|:| -2350 |#1|) (|:| -4409 $) (|:| -2607 $)) $ $) 198 (|has| |#1| (-558)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 185 (|has| |#1| (-365)))) (-1998 (($ $) 174 (|has| |#1| (-453))) (($ $ (-1075)) 103 (|has| |#1| (-453)))) (-2110 (((-634 $) $) 107)) (-2197 (((-121) $) 94 (|has| |#1| (-904)))) (-2453 (($ $ |#1| (-763) $) 170)) (-1519 (((-884 (-381) $) $ (-887 (-381)) (-884 (-381) $)) 82 (-12 (|has| (-1075) (-881 (-381))) (|has| |#1| (-881 (-381))))) (((-884 (-568) $) $ (-887 (-568)) (-884 (-568) $)) 81 (-12 (|has| (-1075) (-881 (-568))) (|has| |#1| (-881 (-568)))))) (-1844 (((-763) $ $) 203 (|has| |#1| (-558)))) (-1598 (((-121) $) 30)) (-3971 (((-763) $) 167)) (-2214 (((-3 $ "failed") $) 183 (|has| |#1| (-1136)))) (-2053 (($ (-1157 |#1|) (-1075)) 115) (($ (-1157 $) (-1075)) 114)) (-4168 (($ $ (-763)) 214)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 194 (|has| |#1| (-365)))) (-3062 (((-634 $) $) 124)) (-2171 (((-121) $) 150)) (-2049 (($ |#1| (-763)) 151) (($ $ (-1075) (-763)) 117) (($ $ (-634 (-1075)) (-634 (-763))) 116)) (-1438 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $ (-1075)) 118) (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 212)) (-3524 (((-763) $) 168) (((-763) $ (-1075)) 120) (((-634 (-763)) $ (-634 (-1075))) 119)) (-1732 (($ $ $) 77 (|has| |#1| (-842)))) (-2047 (($ $ $) 76 (|has| |#1| (-842)))) (-1865 (($ (-1 (-763) (-763)) $) 169)) (-2797 (($ (-1 |#1| |#1|) $) 149)) (-2671 (((-1157 |#1|) $) 216)) (-2817 (((-3 (-1075) "failed") $) 121)) (-2099 (($ $) 147)) (-2104 ((|#1| $) 146)) (-2498 (($ (-634 $)) 92 (|has| |#1| (-453))) (($ $ $) 91 (|has| |#1| (-453)))) (-1893 (((-1143) $) 9)) (-3262 (((-2 (|:| -4409 $) (|:| -2607 $)) $ (-763)) 211)) (-4362 (((-3 (-634 $) "failed") $) 112)) (-2112 (((-3 (-634 $) "failed") $) 113)) (-2617 (((-3 (-2 (|:| |var| (-1075)) (|:| -3483 (-763))) "failed") $) 111)) (-1845 (($ $) 195 (|has| |#1| (-43 (-409 (-568)))))) (-4436 (($) 182 (|has| |#1| (-1136)) CONST)) (-4025 (((-1108) $) 10)) (-2088 (((-121) $) 164)) (-2093 ((|#1| $) 165)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 93 (|has| |#1| (-453)))) (-2723 (($ (-634 $)) 90 (|has| |#1| (-453))) (($ $ $) 89 (|has| |#1| (-453)))) (-2841 (((-420 (-1157 $)) (-1157 $)) 100 (|has| |#1| (-904)))) (-2795 (((-420 (-1157 $)) (-1157 $)) 99 (|has| |#1| (-904)))) (-3850 (((-420 $) $) 97 (|has| |#1| (-904)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 193 (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 192 (|has| |#1| (-365)))) (-2597 (((-3 $ "failed") $ |#1|) 172 (|has| |#1| (-558))) (((-3 $ "failed") $ $) 84 (|has| |#1| (-558)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 186 (|has| |#1| (-365)))) (-1339 (($ $ (-634 (-288 $))) 143) (($ $ (-288 $)) 142) (($ $ $ $) 141) (($ $ (-634 $) (-634 $)) 140) (($ $ (-1075) |#1|) 139) (($ $ (-634 (-1075)) (-634 |#1|)) 138) (($ $ (-1075) $) 137) (($ $ (-634 (-1075)) (-634 $)) 136)) (-1466 (((-763) $) 188 (|has| |#1| (-365)))) (-2781 ((|#1| $ |#1|) 235) (($ $ $) 234) (((-409 $) (-409 $) (-409 $)) 204 (|has| |#1| (-558))) ((|#1| (-409 $) |#1|) 196 (|has| |#1| (-365))) (((-409 $) $ (-409 $)) 184 (|has| |#1| (-558)))) (-3805 (((-3 $ "failed") $ (-763)) 213)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 189 (|has| |#1| (-365)))) (-3440 (($ $ (-1075)) 105 (|has| |#1| (-172))) ((|#1| $) 206 (|has| |#1| (-172)))) (-4191 (($ $ (-1075)) 41) (($ $ (-634 (-1075))) 40) (($ $ (-1075) (-763)) 39) (($ $ (-634 (-1075)) (-634 (-763))) 38) (($ $ (-763)) 232) (($ $) 230) (($ $ (-1161)) 229 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 228 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 227 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) 226 (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) 219) (($ $ (-1 |#1| |#1|)) 218) (($ $ (-1 |#1| |#1|) $) 207)) (-1836 (((-763) $) 148) (((-763) $ (-1075)) 128) (((-634 (-763)) $ (-634 (-1075))) 127)) (-4280 (((-887 (-381)) $) 80 (-12 (|has| (-1075) (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381)))))) (((-887 (-568)) $) 79 (-12 (|has| (-1075) (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568)))))) (((-541) $) 78 (-12 (|has| (-1075) (-609 (-541))) (|has| |#1| (-609 (-541)))))) (-1364 ((|#1| $) 173 (|has| |#1| (-453))) (($ $ (-1075)) 104 (|has| |#1| (-453)))) (-3070 (((-3 (-1244 $) "failed") (-679 $)) 102 (-2141 (|has| $ (-148)) (|has| |#1| (-904))))) (-4363 (((-3 $ "failed") $ $) 201 (|has| |#1| (-558))) (((-3 (-409 $) "failed") (-409 $) $) 200 (|has| |#1| (-558)))) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 161) (($ (-1075)) 135) (($ (-409 (-568))) 70 (-2199 (|has| |#1| (-1037 (-409 (-568)))) (|has| |#1| (-43 (-409 (-568)))))) (($ $) 83 (|has| |#1| (-558)))) (-3304 (((-634 |#1|) $) 166)) (-2079 ((|#1| $ (-763)) 153) (($ $ (-1075) (-763)) 126) (($ $ (-634 (-1075)) (-634 (-763))) 125)) (-3385 (((-3 $ "failed") $) 71 (-2199 (-2141 (|has| $ (-148)) (|has| |#1| (-904))) (|has| |#1| (-148))))) (-3425 (((-763)) 28)) (-3925 (($ $ $ (-763)) 171 (|has| |#1| (-172)))) (-2273 (((-121) $ $) 87 (|has| |#1| (-558)))) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $ (-1075)) 37) (($ $ (-634 (-1075))) 36) (($ $ (-1075) (-763)) 35) (($ $ (-634 (-1075)) (-634 (-763))) 34) (($ $ (-763)) 233) (($ $) 231) (($ $ (-1161)) 225 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161))) 224 (|has| |#1| (-895 (-1161)))) (($ $ (-1161) (-763)) 223 (|has| |#1| (-895 (-1161)))) (($ $ (-634 (-1161)) (-634 (-763))) 222 (|has| |#1| (-895 (-1161)))) (($ $ (-1 |#1| |#1|) (-763)) 221) (($ $ (-1 |#1| |#1|)) 220)) (-1753 (((-121) $ $) 74 (|has| |#1| (-842)))) (-1740 (((-121) $ $) 73 (|has| |#1| (-842)))) (-1719 (((-121) $ $) 6)) (-1747 (((-121) $ $) 75 (|has| |#1| (-842)))) (-1734 (((-121) $ $) 72 (|has| |#1| (-842)))) (-1781 (($ $ |#1|) 154 (|has| |#1| (-365)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 156 (|has| |#1| (-43 (-409 (-568))))) (($ (-409 (-568)) $) 155 (|has| |#1| (-43 (-409 (-568))))) (($ |#1| $) 145) (($ $ |#1|) 144))) 
 (((-1219 |#1|) (-1275) (-1047)) (T -1219)) 
-((-2572 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-1219 *4)) (-4 *4 (-1047)) (-5 *2 (-1244 *4)))) (-3764 (*1 *2 *1) (-12 (-4 *1 (-1219 *3)) (-4 *3 (-1047)) (-5 *2 (-1157 *3)))) (-3197 (*1 *1 *2) (-12 (-5 *2 (-1157 *3)) (-4 *3 (-1047)) (-4 *1 (-1219 *3)))) (-3536 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1219 *3)) (-4 *3 (-1047)))) (-2167 (*1 *1 *1 *2) (|partial| -12 (-5 *2 (-763)) (-4 *1 (-1219 *3)) (-4 *3 (-1047)))) (-3379 (*1 *2 *1 *1) (-12 (-4 *3 (-1047)) (-5 *2 (-2 (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-1219 *3)))) (-1643 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *4 (-1047)) (-5 *2 (-2 (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-1219 *4)))) (-3151 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1219 *3)) (-4 *3 (-1047)))) (-3772 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1219 *3)) (-4 *3 (-1047)))) (-3002 (*1 *1 *1 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)))) (-4189 (*1 *1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-1219 *3)) (-4 *3 (-1047)))) (-2217 (*1 *2 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-172)))) (-4265 (*1 *2 *1 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-172)))) (-2779 (*1 *2 *2 *2) (-12 (-5 *2 (-409 *1)) (-4 *1 (-1219 *3)) (-4 *3 (-1047)) (-4 *3 (-558)))) (-4477 (*1 *2 *1 *1) (-12 (-4 *1 (-1219 *3)) (-4 *3 (-1047)) (-4 *3 (-558)) (-5 *2 (-763)))) (-3809 (*1 *1 *1 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-558)))) (-3950 (*1 *1 *1 *1) (|partial| -12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-558)))) (-3950 (*1 *2 *2 *1) (|partial| -12 (-5 *2 (-409 *1)) (-4 *1 (-1219 *3)) (-4 *3 (-1047)) (-4 *3 (-558)))) (-3581 (*1 *1 *1 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-558)))) (-4144 (*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -2348 *3) (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-1219 *3)))) (-1619 (*1 *2 *1 *1) (-12 (-4 *3 (-453)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| |primePart| *1) (|:| |commonPart| *1))) (-4 *1 (-1219 *3)))) (-2779 (*1 *2 *3 *2) (-12 (-5 *3 (-409 *1)) (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-3837 (*1 *1 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-43 (-409 (-568))))))) 
-(-13 (-950 |t#1| (-763) (-1075)) (-281 |t#1| |t#1|) (-281 $ $) (-225) (-223 |t#1|) (-10 -8 (-15 -2572 ((-1244 |t#1|) $ (-763))) (-15 -3764 ((-1157 |t#1|) $)) (-15 -3197 ($ (-1157 |t#1|))) (-15 -3536 ($ $ (-763))) (-15 -2167 ((-3 $ "failed") $ (-763))) (-15 -3379 ((-2 (|:| -3961 $) (|:| -1500 $)) $ $)) (-15 -1643 ((-2 (|:| -3961 $) (|:| -1500 $)) $ (-763))) (-15 -3151 ($ $ (-763))) (-15 -3772 ($ $ (-763))) (-15 -3002 ($ $ $)) (-15 -4189 ($ $ (-1 |t#1| |t#1|) $)) (IF (|has| |t#1| (-1136)) (-6 (-1136)) |noBranch|) (IF (|has| |t#1| (-172)) (PROGN (-15 -2217 (|t#1| $)) (-15 -4265 (|t#1| $ $))) |noBranch|) (IF (|has| |t#1| (-558)) (PROGN (-6 (-281 (-409 $) (-409 $))) (-15 -2779 ((-409 $) (-409 $) (-409 $))) (-15 -4477 ((-763) $ $)) (-15 -3809 ($ $ $)) (-15 -3950 ((-3 $ "failed") $ $)) (-15 -3950 ((-3 (-409 $) "failed") (-409 $) $)) (-15 -3581 ($ $ $)) (-15 -4144 ((-2 (|:| -2348 |t#1|) (|:| -3961 $) (|:| -1500 $)) $ $))) |noBranch|) (IF (|has| |t#1| (-453)) (-15 -1619 ((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $)) |noBranch|) (IF (|has| |t#1| (-365)) (PROGN (-6 (-301)) (-6 -4515) (-15 -2779 (|t#1| (-409 $) |t#1|))) |noBranch|) (IF (|has| |t#1| (-43 (-409 (-568)))) (-15 -3837 ($ $)) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| (-763)) . T) ((-25) . T) ((-43 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-365))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-609 (-541)) -12 (|has| (-1075) (-609 (-541))) (|has| |#1| (-609 (-541)))) ((-609 (-887 (-381))) -12 (|has| (-1075) (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381))))) ((-609 (-887 (-568))) -12 (|has| (-1075) (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568))))) ((-223 |#1|) . T) ((-225) . T) ((-281 (-409 $) (-409 $)) |has| |#1| (-558)) ((-281 |#1| |#1|) . T) ((-281 $ $) . T) ((-285) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-365))) ((-301) |has| |#1| (-365)) ((-303 $) . T) ((-324 |#1| (-763)) . T) ((-379 |#1|) . T) ((-413 |#1|) . T) ((-453) -2198 (|has| |#1| (-904)) (|has| |#1| (-453)) (|has| |#1| (-365))) ((-523 (-1075) |#1|) . T) ((-523 (-1075) $) . T) ((-523 $ $) . T) ((-558) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-365))) ((-637 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-637 |#1|) . T) ((-637 $) . T) ((-630 (-568)) |has| |#1| (-630 (-568))) ((-630 |#1|) . T) ((-707 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-365))) ((-716) . T) ((-842) |has| |#1| (-842)) ((-895 (-1075)) . T) ((-895 (-1161)) |has| |#1| (-895 (-1161))) ((-881 (-381)) -12 (|has| (-1075) (-881 (-381))) (|has| |#1| (-881 (-381)))) ((-881 (-568)) -12 (|has| (-1075) (-881 (-568))) (|has| |#1| (-881 (-568)))) ((-950 |#1| (-763) (-1075)) . T) ((-904) |has| |#1| (-904)) ((-916) |has| |#1| (-365)) ((-1037 (-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 (-1075)) . T) ((-1037 |#1|) . T) ((-1053 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-1053 |#1|) . T) ((-1053 $) -2198 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1136) |has| |#1| (-1136)) ((-1199) |has| |#1| (-904))) 
-((-2055 (((-634 (-1075)) $) 28)) (-2114 (($ $) 25)) (-2047 (($ |#2| |#3|) NIL) (($ $ (-1075) |#3|) 22) (($ $ (-634 (-1075)) (-634 |#3|)) 20)) (-2097 (($ $) 14)) (-2102 ((|#2| $) 12)) (-3206 ((|#3| $) 10))) 
-(((-1220 |#1| |#2| |#3|) (-10 -8 (-15 -2055 ((-634 (-1075)) |#1|)) (-15 -2047 (|#1| |#1| (-634 (-1075)) (-634 |#3|))) (-15 -2047 (|#1| |#1| (-1075) |#3|)) (-15 -2114 (|#1| |#1|)) (-15 -2047 (|#1| |#2| |#3|)) (-15 -3206 (|#3| |#1|)) (-15 -2097 (|#1| |#1|)) (-15 -2102 (|#2| |#1|))) (-1221 |#2| |#3|) (-1047) (-787)) (T -1220)) 
-NIL 
-(-10 -8 (-15 -2055 ((-634 (-1075)) |#1|)) (-15 -2047 (|#1| |#1| (-634 (-1075)) (-634 |#3|))) (-15 -2047 (|#1| |#1| (-1075) |#3|)) (-15 -2114 (|#1| |#1|)) (-15 -2047 (|#1| |#2| |#3|)) (-15 -3206 (|#3| |#1|)) (-15 -2097 (|#1| |#1|)) (-15 -2102 (|#2| |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-2055 (((-634 (-1075)) $) 70)) (-1305 (((-1161) $) 98)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 50 (|has| |#1| (-558)))) (-2227 (($ $) 51 (|has| |#1| (-558)))) (-1573 (((-121) $) 53 (|has| |#1| (-558)))) (-2617 (($ $ |#2|) 93) (($ $ |#2| |#2|) 92)) (-2583 (((-1141 (-2 (|:| |k| |#2|) (|:| |c| |#1|))) $) 100)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-2114 (($ $) 59)) (-2925 (((-3 $ "failed") $) 33)) (-3992 (((-121) $) 69)) (-4477 ((|#2| $) 95) ((|#2| $ |#2|) 94)) (-2735 (((-121) $) 30)) (-3536 (($ $ (-917)) 96)) (-3921 (((-121) $) 61)) (-2047 (($ |#1| |#2|) 60) (($ $ (-1075) |#2|) 72) (($ $ (-634 (-1075)) (-634 |#2|)) 71)) (-2795 (($ (-1 |#1| |#1|) $) 62)) (-2097 (($ $) 64)) (-2102 ((|#1| $) 65)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-1807 (($ $ |#2|) 90)) (-2595 (((-3 $ "failed") $ $) 49 (|has| |#1| (-558)))) (-1339 (((-1141 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| |#2|))))) (-2779 ((|#1| $ |#2|) 99) (($ $ $) 76 (|has| |#2| (-1102)))) (-4189 (($ $ (-634 (-1161)) (-634 (-763))) 84 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-1161) (-763)) 83 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-634 (-1161))) 82 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-1161)) 81 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-763)) 79 (|has| |#1| (-15 * (|#1| |#2| |#1|)))) (($ $) 77 (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (-3206 ((|#2| $) 63)) (-1811 (($ $) 68)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ (-409 (-568))) 56 (|has| |#1| (-43 (-409 (-568))))) (($ $) 48 (|has| |#1| (-558))) (($ |#1|) 46 (|has| |#1| (-172)))) (-2604 ((|#1| $ |#2|) 58)) (-4371 (((-3 $ "failed") $) 47 (|has| |#1| (-148)))) (-4078 (((-763)) 28)) (-1374 ((|#1| $) 97)) (-1826 (((-121) $ $) 52 (|has| |#1| (-558)))) (-3996 ((|#1| $ |#2|) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| |#2|))) (|has| |#1| (-15 -2745 (|#1| (-1161))))))) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $ (-634 (-1161)) (-634 (-763))) 88 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-1161) (-763)) 87 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-634 (-1161))) 86 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-1161)) 85 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-763)) 80 (|has| |#1| (-15 * (|#1| |#2| |#1|)))) (($ $) 78 (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (-1717 (((-121) $ $) 6)) (-1779 (($ $ |#1|) 57 (|has| |#1| (-365)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-409 (-568)) $) 55 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 54 (|has| |#1| (-43 (-409 (-568))))))) 
+((-1969 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-1219 *4)) (-4 *4 (-1047)) (-5 *2 (-1244 *4)))) (-2671 (*1 *2 *1) (-12 (-4 *1 (-1219 *3)) (-4 *3 (-1047)) (-5 *2 (-1157 *3)))) (-1807 (*1 *1 *2) (-12 (-5 *2 (-1157 *3)) (-4 *3 (-1047)) (-4 *1 (-1219 *3)))) (-4168 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1219 *3)) (-4 *3 (-1047)))) (-3805 (*1 *1 *1 *2) (|partial| -12 (-5 *2 (-763)) (-4 *1 (-1219 *3)) (-4 *3 (-1047)))) (-1438 (*1 *2 *1 *1) (-12 (-4 *3 (-1047)) (-5 *2 (-2 (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-1219 *3)))) (-3262 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *4 (-1047)) (-5 *2 (-2 (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-1219 *4)))) (-2752 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1219 *3)) (-4 *3 (-1047)))) (-2699 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1219 *3)) (-4 *3 (-1047)))) (-3152 (*1 *1 *1 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)))) (-4191 (*1 *1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-1219 *3)) (-4 *3 (-1047)))) (-3440 (*1 *2 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-172)))) (-2910 (*1 *2 *1 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-172)))) (-2781 (*1 *2 *2 *2) (-12 (-5 *2 (-409 *1)) (-4 *1 (-1219 *3)) (-4 *3 (-1047)) (-4 *3 (-558)))) (-1844 (*1 *2 *1 *1) (-12 (-4 *1 (-1219 *3)) (-4 *3 (-1047)) (-4 *3 (-558)) (-5 *2 (-763)))) (-1736 (*1 *1 *1 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-558)))) (-4363 (*1 *1 *1 *1) (|partial| -12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-558)))) (-4363 (*1 *2 *2 *1) (|partial| -12 (-5 *2 (-409 *1)) (-4 *1 (-1219 *3)) (-4 *3 (-1047)) (-4 *3 (-558)))) (-2929 (*1 *1 *1 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-558)))) (-3777 (*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -2350 *3) (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-1219 *3)))) (-1448 (*1 *2 *1 *1) (-12 (-4 *3 (-453)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| |primePart| *1) (|:| |commonPart| *1))) (-4 *1 (-1219 *3)))) (-2781 (*1 *2 *3 *2) (-12 (-5 *3 (-409 *1)) (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-1845 (*1 *1 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-43 (-409 (-568))))))) 
+(-13 (-950 |t#1| (-763) (-1075)) (-281 |t#1| |t#1|) (-281 $ $) (-225) (-223 |t#1|) (-10 -8 (-15 -1969 ((-1244 |t#1|) $ (-763))) (-15 -2671 ((-1157 |t#1|) $)) (-15 -1807 ($ (-1157 |t#1|))) (-15 -4168 ($ $ (-763))) (-15 -3805 ((-3 $ "failed") $ (-763))) (-15 -1438 ((-2 (|:| -4409 $) (|:| -2607 $)) $ $)) (-15 -3262 ((-2 (|:| -4409 $) (|:| -2607 $)) $ (-763))) (-15 -2752 ($ $ (-763))) (-15 -2699 ($ $ (-763))) (-15 -3152 ($ $ $)) (-15 -4191 ($ $ (-1 |t#1| |t#1|) $)) (IF (|has| |t#1| (-1136)) (-6 (-1136)) |noBranch|) (IF (|has| |t#1| (-172)) (PROGN (-15 -3440 (|t#1| $)) (-15 -2910 (|t#1| $ $))) |noBranch|) (IF (|has| |t#1| (-558)) (PROGN (-6 (-281 (-409 $) (-409 $))) (-15 -2781 ((-409 $) (-409 $) (-409 $))) (-15 -1844 ((-763) $ $)) (-15 -1736 ($ $ $)) (-15 -4363 ((-3 $ "failed") $ $)) (-15 -4363 ((-3 (-409 $) "failed") (-409 $) $)) (-15 -2929 ($ $ $)) (-15 -3777 ((-2 (|:| -2350 |t#1|) (|:| -4409 $) (|:| -2607 $)) $ $))) |noBranch|) (IF (|has| |t#1| (-453)) (-15 -1448 ((-2 (|:| |primePart| $) (|:| |commonPart| $)) $ $)) |noBranch|) (IF (|has| |t#1| (-365)) (PROGN (-6 (-301)) (-6 -4517) (-15 -2781 (|t#1| (-409 $) |t#1|))) |noBranch|) (IF (|has| |t#1| (-43 (-409 (-568)))) (-15 -1845 ($ $)) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| (-763)) . T) ((-25) . T) ((-43 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-365))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-609 (-541)) -12 (|has| (-1075) (-609 (-541))) (|has| |#1| (-609 (-541)))) ((-609 (-887 (-381))) -12 (|has| (-1075) (-609 (-887 (-381)))) (|has| |#1| (-609 (-887 (-381))))) ((-609 (-887 (-568))) -12 (|has| (-1075) (-609 (-887 (-568)))) (|has| |#1| (-609 (-887 (-568))))) ((-223 |#1|) . T) ((-225) . T) ((-281 (-409 $) (-409 $)) |has| |#1| (-558)) ((-281 |#1| |#1|) . T) ((-281 $ $) . T) ((-285) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-365))) ((-301) |has| |#1| (-365)) ((-303 $) . T) ((-324 |#1| (-763)) . T) ((-379 |#1|) . T) ((-413 |#1|) . T) ((-453) -2199 (|has| |#1| (-904)) (|has| |#1| (-453)) (|has| |#1| (-365))) ((-523 (-1075) |#1|) . T) ((-523 (-1075) $) . T) ((-523 $ $) . T) ((-558) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-365))) ((-637 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-637 |#1|) . T) ((-637 $) . T) ((-630 (-568)) |has| |#1| (-630 (-568))) ((-630 |#1|) . T) ((-707 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-365))) ((-716) . T) ((-842) |has| |#1| (-842)) ((-895 (-1075)) . T) ((-895 (-1161)) |has| |#1| (-895 (-1161))) ((-881 (-381)) -12 (|has| (-1075) (-881 (-381))) (|has| |#1| (-881 (-381)))) ((-881 (-568)) -12 (|has| (-1075) (-881 (-568))) (|has| |#1| (-881 (-568)))) ((-950 |#1| (-763) (-1075)) . T) ((-904) |has| |#1| (-904)) ((-916) |has| |#1| (-365)) ((-1037 (-409 (-568))) |has| |#1| (-1037 (-409 (-568)))) ((-1037 (-568)) |has| |#1| (-1037 (-568))) ((-1037 (-1075)) . T) ((-1037 |#1|) . T) ((-1053 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-1053 |#1|) . T) ((-1053 $) -2199 (|has| |#1| (-904)) (|has| |#1| (-558)) (|has| |#1| (-453)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1136) |has| |#1| (-1136)) ((-1199) |has| |#1| (-904))) 
+((-2057 (((-634 (-1075)) $) 28)) (-2116 (($ $) 25)) (-2049 (($ |#2| |#3|) NIL) (($ $ (-1075) |#3|) 22) (($ $ (-634 (-1075)) (-634 |#3|)) 20)) (-2099 (($ $) 14)) (-2104 ((|#2| $) 12)) (-1836 ((|#3| $) 10))) 
+(((-1220 |#1| |#2| |#3|) (-10 -8 (-15 -2057 ((-634 (-1075)) |#1|)) (-15 -2049 (|#1| |#1| (-634 (-1075)) (-634 |#3|))) (-15 -2049 (|#1| |#1| (-1075) |#3|)) (-15 -2116 (|#1| |#1|)) (-15 -2049 (|#1| |#2| |#3|)) (-15 -1836 (|#3| |#1|)) (-15 -2099 (|#1| |#1|)) (-15 -2104 (|#2| |#1|))) (-1221 |#2| |#3|) (-1047) (-787)) (T -1220)) 
+NIL 
+(-10 -8 (-15 -2057 ((-634 (-1075)) |#1|)) (-15 -2049 (|#1| |#1| (-634 (-1075)) (-634 |#3|))) (-15 -2049 (|#1| |#1| (-1075) |#3|)) (-15 -2116 (|#1| |#1|)) (-15 -2049 (|#1| |#2| |#3|)) (-15 -1836 (|#3| |#1|)) (-15 -2099 (|#1| |#1|)) (-15 -2104 (|#2| |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2057 (((-634 (-1075)) $) 70)) (-3325 (((-1161) $) 98)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 50 (|has| |#1| (-558)))) (-3661 (($ $) 51 (|has| |#1| (-558)))) (-4426 (((-121) $) 53 (|has| |#1| (-558)))) (-4179 (($ $ |#2|) 93) (($ $ |#2| |#2|) 92)) (-2013 (((-1141 (-2 (|:| |k| |#2|) (|:| |c| |#1|))) $) 100)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-2116 (($ $) 59)) (-2902 (((-3 $ "failed") $) 33)) (-1302 (((-121) $) 69)) (-1844 ((|#2| $) 95) ((|#2| $ |#2|) 94)) (-1598 (((-121) $) 30)) (-4168 (($ $ (-917)) 96)) (-2171 (((-121) $) 61)) (-2049 (($ |#1| |#2|) 60) (($ $ (-1075) |#2|) 72) (($ $ (-634 (-1075)) (-634 |#2|)) 71)) (-2797 (($ (-1 |#1| |#1|) $) 62)) (-2099 (($ $) 64)) (-2104 ((|#1| $) 65)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2168 (($ $ |#2|) 90)) (-2597 (((-3 $ "failed") $ $) 49 (|has| |#1| (-558)))) (-1339 (((-1141 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| |#2|))))) (-2781 ((|#1| $ |#2|) 99) (($ $ $) 76 (|has| |#2| (-1102)))) (-4191 (($ $ (-634 (-1161)) (-634 (-763))) 84 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-1161) (-763)) 83 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-634 (-1161))) 82 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-1161)) 81 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-763)) 79 (|has| |#1| (-15 * (|#1| |#2| |#1|)))) (($ $) 77 (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (-1836 ((|#2| $) 63)) (-2188 (($ $) 68)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ (-409 (-568))) 56 (|has| |#1| (-43 (-409 (-568))))) (($ $) 48 (|has| |#1| (-558))) (($ |#1|) 46 (|has| |#1| (-172)))) (-2079 ((|#1| $ |#2|) 58)) (-3385 (((-3 $ "failed") $) 47 (|has| |#1| (-148)))) (-3425 (((-763)) 28)) (-1374 ((|#1| $) 97)) (-2273 (((-121) $ $) 52 (|has| |#1| (-558)))) (-3999 ((|#1| $ |#2|) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| |#2|))) (|has| |#1| (-15 -2747 (|#1| (-1161))))))) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $ (-634 (-1161)) (-634 (-763))) 88 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-1161) (-763)) 87 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-634 (-1161))) 86 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-1161)) 85 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (($ $ (-763)) 80 (|has| |#1| (-15 * (|#1| |#2| |#1|)))) (($ $) 78 (|has| |#1| (-15 * (|#1| |#2| |#1|))))) (-1719 (((-121) $ $) 6)) (-1781 (($ $ |#1|) 57 (|has| |#1| (-365)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-409 (-568)) $) 55 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 54 (|has| |#1| (-43 (-409 (-568))))))) 
 (((-1221 |#1| |#2|) (-1275) (-1047) (-787)) (T -1221)) 
-((-2583 (*1 *2 *1) (-12 (-4 *1 (-1221 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-1141 (-2 (|:| |k| *4) (|:| |c| *3)))))) (-2779 (*1 *2 *1 *3) (-12 (-4 *1 (-1221 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047)))) (-1305 (*1 *2 *1) (-12 (-4 *1 (-1221 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-1161)))) (-1374 (*1 *2 *1) (-12 (-4 *1 (-1221 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047)))) (-3536 (*1 *1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-1221 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)))) (-4477 (*1 *2 *1) (-12 (-4 *1 (-1221 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787)))) (-4477 (*1 *2 *1 *2) (-12 (-4 *1 (-1221 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787)))) (-2617 (*1 *1 *1 *2) (-12 (-4 *1 (-1221 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787)))) (-2617 (*1 *1 *1 *2 *2) (-12 (-4 *1 (-1221 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787)))) (-3996 (*1 *2 *1 *3) (-12 (-4 *1 (-1221 *2 *3)) (-4 *3 (-787)) (|has| *2 (-15 ** (*2 *2 *3))) (|has| *2 (-15 -2745 (*2 (-1161)))) (-4 *2 (-1047)))) (-1807 (*1 *1 *1 *2) (-12 (-4 *1 (-1221 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787)))) (-1339 (*1 *2 *1 *3) (-12 (-4 *1 (-1221 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (|has| *3 (-15 ** (*3 *3 *4))) (-5 *2 (-1141 *3))))) 
-(-13 (-974 |t#1| |t#2| (-1075)) (-10 -8 (-15 -2583 ((-1141 (-2 (|:| |k| |t#2|) (|:| |c| |t#1|))) $)) (-15 -2779 (|t#1| $ |t#2|)) (-15 -1305 ((-1161) $)) (-15 -1374 (|t#1| $)) (-15 -3536 ($ $ (-917))) (-15 -4477 (|t#2| $)) (-15 -4477 (|t#2| $ |t#2|)) (-15 -2617 ($ $ |t#2|)) (-15 -2617 ($ $ |t#2| |t#2|)) (IF (|has| |t#1| (-15 -2745 (|t#1| (-1161)))) (IF (|has| |t#1| (-15 ** (|t#1| |t#1| |t#2|))) (-15 -3996 (|t#1| $ |t#2|)) |noBranch|) |noBranch|) (-15 -1807 ($ $ |t#2|)) (IF (|has| |t#2| (-1102)) (-6 (-281 $ $)) |noBranch|) (IF (|has| |t#1| (-15 * (|t#1| |t#2| |t#1|))) (PROGN (-6 (-225)) (IF (|has| |t#1| (-895 (-1161))) (-6 (-895 (-1161))) |noBranch|)) |noBranch|) (IF (|has| |t#1| (-15 ** (|t#1| |t#1| |t#2|))) (-15 -1339 ((-1141 |t#1|) $ |t#1|)) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| |#2|) . T) ((-25) . T) ((-43 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) |has| |#1| (-558)) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2198 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2198 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-225) |has| |#1| (-15 * (|#1| |#2| |#1|))) ((-281 $ $) |has| |#2| (-1102)) ((-285) |has| |#1| (-558)) ((-558) |has| |#1| (-558)) ((-637 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) |has| |#1| (-558)) ((-716) . T) ((-895 (-1161)) -12 (|has| |#1| (-15 * (|#1| |#2| |#1|))) (|has| |#1| (-895 (-1161)))) ((-974 |#1| |#2| (-1075)) . T) ((-1053 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-1053 |#1|) . T) ((-1053 $) -2198 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-4305 ((|#2| |#2|) 12)) (-1678 (((-420 |#2|) |#2|) 14)) (-1699 (((-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-568))) (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-568)))) 30))) 
-(((-1222 |#1| |#2|) (-10 -7 (-15 -1678 ((-420 |#2|) |#2|)) (-15 -4305 (|#2| |#2|)) (-15 -1699 ((-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-568))) (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-568)))))) (-558) (-13 (-1219 |#1|) (-558) (-10 -8 (-15 -2721 ($ $ $))))) (T -1222)) 
-((-1699 (*1 *2 *2) (-12 (-5 *2 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *4) (|:| |xpnt| (-568)))) (-4 *4 (-13 (-1219 *3) (-558) (-10 -8 (-15 -2721 ($ $ $))))) (-4 *3 (-558)) (-5 *1 (-1222 *3 *4)))) (-4305 (*1 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-1222 *3 *2)) (-4 *2 (-13 (-1219 *3) (-558) (-10 -8 (-15 -2721 ($ $ $))))))) (-1678 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-420 *3)) (-5 *1 (-1222 *4 *3)) (-4 *3 (-13 (-1219 *4) (-558) (-10 -8 (-15 -2721 ($ $ $)))))))) 
-(-10 -7 (-15 -1678 ((-420 |#2|) |#2|)) (-15 -4305 (|#2| |#2|)) (-15 -1699 ((-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-568))) (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-568)))))) 
-((-2795 (((-1228 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1228 |#1| |#3| |#5|)) 23))) 
-(((-1223 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -2795 ((-1228 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1228 |#1| |#3| |#5|)))) (-1047) (-1047) (-1161) (-1161) |#1| |#2|) (T -1223)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1228 *5 *7 *9)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-14 *7 (-1161)) (-14 *9 *5) (-14 *10 *6) (-5 *2 (-1228 *6 *8 *10)) (-5 *1 (-1223 *5 *6 *7 *8 *9 *10)) (-14 *8 (-1161))))) 
-(-10 -7 (-15 -2795 ((-1228 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1228 |#1| |#3| |#5|)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-2055 (((-634 (-1075)) $) 70)) (-1305 (((-1161) $) 98)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 50 (|has| |#1| (-558)))) (-2227 (($ $) 51 (|has| |#1| (-558)))) (-1573 (((-121) $) 53 (|has| |#1| (-558)))) (-2617 (($ $ (-409 (-568))) 93) (($ $ (-409 (-568)) (-409 (-568))) 92)) (-2583 (((-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|))) $) 100)) (-1982 (($ $) 127 (|has| |#1| (-43 (-409 (-568)))))) (-1933 (($ $) 110 (|has| |#1| (-43 (-409 (-568)))))) (-3134 (((-3 $ "failed") $ $) 18)) (-4305 (($ $) 154 (|has| |#1| (-365)))) (-1678 (((-420 $) $) 155 (|has| |#1| (-365)))) (-1902 (($ $) 109 (|has| |#1| (-43 (-409 (-568)))))) (-1497 (((-121) $ $) 145 (|has| |#1| (-365)))) (-1974 (($ $) 126 (|has| |#1| (-43 (-409 (-568)))))) (-2786 (($ $) 111 (|has| |#1| (-43 (-409 (-568)))))) (-3728 (($ (-763) (-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|)))) 164)) (-1990 (($ $) 125 (|has| |#1| (-43 (-409 (-568)))))) (-1941 (($ $) 112 (|has| |#1| (-43 (-409 (-568)))))) (-2671 (($) 16 T CONST)) (-2401 (($ $ $) 149 (|has| |#1| (-365)))) (-2114 (($ $) 59)) (-2925 (((-3 $ "failed") $) 33)) (-2412 (($ $ $) 148 (|has| |#1| (-365)))) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 143 (|has| |#1| (-365)))) (-3927 (((-121) $) 156 (|has| |#1| (-365)))) (-3992 (((-121) $) 69)) (-1897 (($) 137 (|has| |#1| (-43 (-409 (-568)))))) (-4477 (((-409 (-568)) $) 95) (((-409 (-568)) $ (-409 (-568))) 94)) (-2735 (((-121) $) 30)) (-4044 (($ $ (-568)) 108 (|has| |#1| (-43 (-409 (-568)))))) (-3536 (($ $ (-917)) 96) (($ $ (-409 (-568))) 163)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 152 (|has| |#1| (-365)))) (-3921 (((-121) $) 61)) (-2047 (($ |#1| (-409 (-568))) 60) (($ $ (-1075) (-409 (-568))) 72) (($ $ (-634 (-1075)) (-634 (-409 (-568)))) 71)) (-2795 (($ (-1 |#1| |#1|) $) 62)) (-4416 (($ $) 134 (|has| |#1| (-43 (-409 (-568)))))) (-2097 (($ $) 64)) (-2102 ((|#1| $) 65)) (-2495 (($ (-634 $)) 141 (|has| |#1| (-365))) (($ $ $) 140 (|has| |#1| (-365)))) (-4487 (((-1143) $) 9)) (-2081 (($ $) 157 (|has| |#1| (-365)))) (-3837 (($ $) 162 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) 161 (-2198 (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-959)) (|has| |#1| (-1181)) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-15 -2055 ((-634 (-1161)) |#1|))) (|has| |#1| (-15 -3837 (|#1| |#1| (-1161)))) (|has| |#1| (-43 (-409 (-568)))))))) (-4022 (((-1108) $) 10)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 142 (|has| |#1| (-365)))) (-2721 (($ (-634 $)) 139 (|has| |#1| (-365))) (($ $ $) 138 (|has| |#1| (-365)))) (-3848 (((-420 $) $) 153 (|has| |#1| (-365)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 151 (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 150 (|has| |#1| (-365)))) (-1807 (($ $ (-409 (-568))) 90)) (-2595 (((-3 $ "failed") $ $) 49 (|has| |#1| (-558)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 144 (|has| |#1| (-365)))) (-1892 (($ $) 135 (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))))) (-2709 (((-763) $) 146 (|has| |#1| (-365)))) (-2779 ((|#1| $ (-409 (-568))) 99) (($ $ $) 76 (|has| (-409 (-568)) (-1102)))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 147 (|has| |#1| (-365)))) (-4189 (($ $ (-634 (-1161)) (-634 (-763))) 84 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-1161) (-763)) 83 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-634 (-1161))) 82 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-1161)) 81 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-763)) 79 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) 77 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (-3206 (((-409 (-568)) $) 63)) (-1994 (($ $) 124 (|has| |#1| (-43 (-409 (-568)))))) (-1945 (($ $) 113 (|has| |#1| (-43 (-409 (-568)))))) (-1986 (($ $) 123 (|has| |#1| (-43 (-409 (-568)))))) (-1937 (($ $) 114 (|has| |#1| (-43 (-409 (-568)))))) (-1978 (($ $) 122 (|has| |#1| (-43 (-409 (-568)))))) (-2790 (($ $) 115 (|has| |#1| (-43 (-409 (-568)))))) (-1811 (($ $) 68)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 46 (|has| |#1| (-172))) (($ (-409 (-568))) 56 (|has| |#1| (-43 (-409 (-568))))) (($ $) 48 (|has| |#1| (-558)))) (-2604 ((|#1| $ (-409 (-568))) 58)) (-4371 (((-3 $ "failed") $) 47 (|has| |#1| (-148)))) (-4078 (((-763)) 28)) (-1374 ((|#1| $) 97)) (-2006 (($ $) 133 (|has| |#1| (-43 (-409 (-568)))))) (-1958 (($ $) 121 (|has| |#1| (-43 (-409 (-568)))))) (-1826 (((-121) $ $) 52 (|has| |#1| (-558)))) (-1998 (($ $) 132 (|has| |#1| (-43 (-409 (-568)))))) (-1949 (($ $) 120 (|has| |#1| (-43 (-409 (-568)))))) (-2014 (($ $) 131 (|has| |#1| (-43 (-409 (-568)))))) (-1966 (($ $) 119 (|has| |#1| (-43 (-409 (-568)))))) (-3996 ((|#1| $ (-409 (-568))) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))) (|has| |#1| (-15 -2745 (|#1| (-1161))))))) (-4023 (($ $) 130 (|has| |#1| (-43 (-409 (-568)))))) (-1970 (($ $) 118 (|has| |#1| (-43 (-409 (-568)))))) (-2010 (($ $) 129 (|has| |#1| (-43 (-409 (-568)))))) (-1962 (($ $) 117 (|has| |#1| (-43 (-409 (-568)))))) (-2002 (($ $) 128 (|has| |#1| (-43 (-409 (-568)))))) (-1953 (($ $) 116 (|has| |#1| (-43 (-409 (-568)))))) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 158 (|has| |#1| (-365)))) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $ (-634 (-1161)) (-634 (-763))) 88 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-1161) (-763)) 87 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-634 (-1161))) 86 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-1161)) 85 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-763)) 80 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) 78 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (-1717 (((-121) $ $) 6)) (-1779 (($ $ |#1|) 57 (|has| |#1| (-365))) (($ $ $) 160 (|has| |#1| (-365)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 159 (|has| |#1| (-365))) (($ $ $) 136 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 107 (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-409 (-568)) $) 55 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 54 (|has| |#1| (-43 (-409 (-568))))))) 
+((-2013 (*1 *2 *1) (-12 (-4 *1 (-1221 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-1141 (-2 (|:| |k| *4) (|:| |c| *3)))))) (-2781 (*1 *2 *1 *3) (-12 (-4 *1 (-1221 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047)))) (-3325 (*1 *2 *1) (-12 (-4 *1 (-1221 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-1161)))) (-1374 (*1 *2 *1) (-12 (-4 *1 (-1221 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047)))) (-4168 (*1 *1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-1221 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)))) (-1844 (*1 *2 *1) (-12 (-4 *1 (-1221 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787)))) (-1844 (*1 *2 *1 *2) (-12 (-4 *1 (-1221 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787)))) (-4179 (*1 *1 *1 *2) (-12 (-4 *1 (-1221 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787)))) (-4179 (*1 *1 *1 *2 *2) (-12 (-4 *1 (-1221 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787)))) (-3999 (*1 *2 *1 *3) (-12 (-4 *1 (-1221 *2 *3)) (-4 *3 (-787)) (|has| *2 (-15 ** (*2 *2 *3))) (|has| *2 (-15 -2747 (*2 (-1161)))) (-4 *2 (-1047)))) (-2168 (*1 *1 *1 *2) (-12 (-4 *1 (-1221 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787)))) (-1339 (*1 *2 *1 *3) (-12 (-4 *1 (-1221 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (|has| *3 (-15 ** (*3 *3 *4))) (-5 *2 (-1141 *3))))) 
+(-13 (-974 |t#1| |t#2| (-1075)) (-10 -8 (-15 -2013 ((-1141 (-2 (|:| |k| |t#2|) (|:| |c| |t#1|))) $)) (-15 -2781 (|t#1| $ |t#2|)) (-15 -3325 ((-1161) $)) (-15 -1374 (|t#1| $)) (-15 -4168 ($ $ (-917))) (-15 -1844 (|t#2| $)) (-15 -1844 (|t#2| $ |t#2|)) (-15 -4179 ($ $ |t#2|)) (-15 -4179 ($ $ |t#2| |t#2|)) (IF (|has| |t#1| (-15 -2747 (|t#1| (-1161)))) (IF (|has| |t#1| (-15 ** (|t#1| |t#1| |t#2|))) (-15 -3999 (|t#1| $ |t#2|)) |noBranch|) |noBranch|) (-15 -2168 ($ $ |t#2|)) (IF (|has| |t#2| (-1102)) (-6 (-281 $ $)) |noBranch|) (IF (|has| |t#1| (-15 * (|t#1| |t#2| |t#1|))) (PROGN (-6 (-225)) (IF (|has| |t#1| (-895 (-1161))) (-6 (-895 (-1161))) |noBranch|)) |noBranch|) (IF (|has| |t#1| (-15 ** (|t#1| |t#1| |t#2|))) (-15 -1339 ((-1141 |t#1|) $ |t#1|)) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| |#2|) . T) ((-25) . T) ((-43 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) |has| |#1| (-558)) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2199 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2199 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-225) |has| |#1| (-15 * (|#1| |#2| |#1|))) ((-281 $ $) |has| |#2| (-1102)) ((-285) |has| |#1| (-558)) ((-558) |has| |#1| (-558)) ((-637 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) |has| |#1| (-558)) ((-716) . T) ((-895 (-1161)) -12 (|has| |#1| (-15 * (|#1| |#2| |#1|))) (|has| |#1| (-895 (-1161)))) ((-974 |#1| |#2| (-1075)) . T) ((-1053 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-1053 |#1|) . T) ((-1053 $) -2199 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
+((-3045 ((|#2| |#2|) 12)) (-3498 (((-420 |#2|) |#2|) 14)) (-3598 (((-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-568))) (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-568)))) 30))) 
+(((-1222 |#1| |#2|) (-10 -7 (-15 -3498 ((-420 |#2|) |#2|)) (-15 -3045 (|#2| |#2|)) (-15 -3598 ((-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-568))) (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-568)))))) (-558) (-13 (-1219 |#1|) (-558) (-10 -8 (-15 -2723 ($ $ $))))) (T -1222)) 
+((-3598 (*1 *2 *2) (-12 (-5 *2 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *4) (|:| |xpnt| (-568)))) (-4 *4 (-13 (-1219 *3) (-558) (-10 -8 (-15 -2723 ($ $ $))))) (-4 *3 (-558)) (-5 *1 (-1222 *3 *4)))) (-3045 (*1 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-1222 *3 *2)) (-4 *2 (-13 (-1219 *3) (-558) (-10 -8 (-15 -2723 ($ $ $))))))) (-3498 (*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-420 *3)) (-5 *1 (-1222 *4 *3)) (-4 *3 (-13 (-1219 *4) (-558) (-10 -8 (-15 -2723 ($ $ $)))))))) 
+(-10 -7 (-15 -3498 ((-420 |#2|) |#2|)) (-15 -3045 (|#2| |#2|)) (-15 -3598 ((-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-568))) (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| |#2|) (|:| |xpnt| (-568)))))) 
+((-2797 (((-1228 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1228 |#1| |#3| |#5|)) 23))) 
+(((-1223 |#1| |#2| |#3| |#4| |#5| |#6|) (-10 -7 (-15 -2797 ((-1228 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1228 |#1| |#3| |#5|)))) (-1047) (-1047) (-1161) (-1161) |#1| |#2|) (T -1223)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1228 *5 *7 *9)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-14 *7 (-1161)) (-14 *9 *5) (-14 *10 *6) (-5 *2 (-1228 *6 *8 *10)) (-5 *1 (-1223 *5 *6 *7 *8 *9 *10)) (-14 *8 (-1161))))) 
+(-10 -7 (-15 -2797 ((-1228 |#2| |#4| |#6|) (-1 |#2| |#1|) (-1228 |#1| |#3| |#5|)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2057 (((-634 (-1075)) $) 70)) (-3325 (((-1161) $) 98)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 50 (|has| |#1| (-558)))) (-3661 (($ $) 51 (|has| |#1| (-558)))) (-4426 (((-121) $) 53 (|has| |#1| (-558)))) (-4179 (($ $ (-409 (-568))) 93) (($ $ (-409 (-568)) (-409 (-568))) 92)) (-2013 (((-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|))) $) 100)) (-1984 (($ $) 127 (|has| |#1| (-43 (-409 (-568)))))) (-1935 (($ $) 110 (|has| |#1| (-43 (-409 (-568)))))) (-2689 (((-3 $ "failed") $ $) 18)) (-3045 (($ $) 154 (|has| |#1| (-365)))) (-3498 (((-420 $) $) 155 (|has| |#1| (-365)))) (-1904 (($ $) 109 (|has| |#1| (-43 (-409 (-568)))))) (-2589 (((-121) $ $) 145 (|has| |#1| (-365)))) (-1976 (($ $) 126 (|has| |#1| (-43 (-409 (-568)))))) (-2788 (($ $) 111 (|has| |#1| (-43 (-409 (-568)))))) (-2512 (($ (-763) (-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|)))) 164)) (-1992 (($ $) 125 (|has| |#1| (-43 (-409 (-568)))))) (-1943 (($ $) 112 (|has| |#1| (-43 (-409 (-568)))))) (-4490 (($) 16 T CONST)) (-2403 (($ $ $) 149 (|has| |#1| (-365)))) (-2116 (($ $) 59)) (-2902 (((-3 $ "failed") $) 33)) (-2414 (($ $ $) 148 (|has| |#1| (-365)))) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 143 (|has| |#1| (-365)))) (-2197 (((-121) $) 156 (|has| |#1| (-365)))) (-1302 (((-121) $) 69)) (-1899 (($) 137 (|has| |#1| (-43 (-409 (-568)))))) (-1844 (((-409 (-568)) $) 95) (((-409 (-568)) $ (-409 (-568))) 94)) (-1598 (((-121) $) 30)) (-1550 (($ $ (-568)) 108 (|has| |#1| (-43 (-409 (-568)))))) (-4168 (($ $ (-917)) 96) (($ $ (-409 (-568))) 163)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 152 (|has| |#1| (-365)))) (-2171 (((-121) $) 61)) (-2049 (($ |#1| (-409 (-568))) 60) (($ $ (-1075) (-409 (-568))) 72) (($ $ (-634 (-1075)) (-634 (-409 (-568)))) 71)) (-2797 (($ (-1 |#1| |#1|) $) 62)) (-4418 (($ $) 134 (|has| |#1| (-43 (-409 (-568)))))) (-2099 (($ $) 64)) (-2104 ((|#1| $) 65)) (-2498 (($ (-634 $)) 141 (|has| |#1| (-365))) (($ $ $) 140 (|has| |#1| (-365)))) (-1893 (((-1143) $) 9)) (-2083 (($ $) 157 (|has| |#1| (-365)))) (-1845 (($ $) 162 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) 161 (-2199 (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-959)) (|has| |#1| (-1181)) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-15 -2057 ((-634 (-1161)) |#1|))) (|has| |#1| (-15 -1845 (|#1| |#1| (-1161)))) (|has| |#1| (-43 (-409 (-568)))))))) (-4025 (((-1108) $) 10)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 142 (|has| |#1| (-365)))) (-2723 (($ (-634 $)) 139 (|has| |#1| (-365))) (($ $ $) 138 (|has| |#1| (-365)))) (-3850 (((-420 $) $) 153 (|has| |#1| (-365)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 151 (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 150 (|has| |#1| (-365)))) (-2168 (($ $ (-409 (-568))) 90)) (-2597 (((-3 $ "failed") $ $) 49 (|has| |#1| (-558)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 144 (|has| |#1| (-365)))) (-1894 (($ $) 135 (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))))) (-1466 (((-763) $) 146 (|has| |#1| (-365)))) (-2781 ((|#1| $ (-409 (-568))) 99) (($ $ $) 76 (|has| (-409 (-568)) (-1102)))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 147 (|has| |#1| (-365)))) (-4191 (($ $ (-634 (-1161)) (-634 (-763))) 84 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-1161) (-763)) 83 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-634 (-1161))) 82 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-1161)) 81 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-763)) 79 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) 77 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (-1836 (((-409 (-568)) $) 63)) (-1996 (($ $) 124 (|has| |#1| (-43 (-409 (-568)))))) (-1947 (($ $) 113 (|has| |#1| (-43 (-409 (-568)))))) (-1988 (($ $) 123 (|has| |#1| (-43 (-409 (-568)))))) (-1939 (($ $) 114 (|has| |#1| (-43 (-409 (-568)))))) (-1980 (($ $) 122 (|has| |#1| (-43 (-409 (-568)))))) (-2792 (($ $) 115 (|has| |#1| (-43 (-409 (-568)))))) (-2188 (($ $) 68)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 46 (|has| |#1| (-172))) (($ (-409 (-568))) 56 (|has| |#1| (-43 (-409 (-568))))) (($ $) 48 (|has| |#1| (-558)))) (-2079 ((|#1| $ (-409 (-568))) 58)) (-3385 (((-3 $ "failed") $) 47 (|has| |#1| (-148)))) (-3425 (((-763)) 28)) (-1374 ((|#1| $) 97)) (-2008 (($ $) 133 (|has| |#1| (-43 (-409 (-568)))))) (-1959 (($ $) 121 (|has| |#1| (-43 (-409 (-568)))))) (-2273 (((-121) $ $) 52 (|has| |#1| (-558)))) (-2000 (($ $) 132 (|has| |#1| (-43 (-409 (-568)))))) (-1951 (($ $) 120 (|has| |#1| (-43 (-409 (-568)))))) (-2016 (($ $) 131 (|has| |#1| (-43 (-409 (-568)))))) (-1968 (($ $) 119 (|has| |#1| (-43 (-409 (-568)))))) (-3999 ((|#1| $ (-409 (-568))) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))) (|has| |#1| (-15 -2747 (|#1| (-1161))))))) (-1439 (($ $) 130 (|has| |#1| (-43 (-409 (-568)))))) (-1972 (($ $) 118 (|has| |#1| (-43 (-409 (-568)))))) (-2012 (($ $) 129 (|has| |#1| (-43 (-409 (-568)))))) (-1964 (($ $) 117 (|has| |#1| (-43 (-409 (-568)))))) (-2004 (($ $) 128 (|has| |#1| (-43 (-409 (-568)))))) (-1955 (($ $) 116 (|has| |#1| (-43 (-409 (-568)))))) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 158 (|has| |#1| (-365)))) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $ (-634 (-1161)) (-634 (-763))) 88 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-1161) (-763)) 87 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-634 (-1161))) 86 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-1161)) 85 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-763)) 80 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) 78 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (-1719 (((-121) $ $) 6)) (-1781 (($ $ |#1|) 57 (|has| |#1| (-365))) (($ $ $) 160 (|has| |#1| (-365)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 159 (|has| |#1| (-365))) (($ $ $) 136 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 107 (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-409 (-568)) $) 55 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 54 (|has| |#1| (-43 (-409 (-568))))))) 
 (((-1224 |#1|) (-1275) (-1047)) (T -1224)) 
-((-3728 (*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *3 (-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| *4)))) (-4 *4 (-1047)) (-4 *1 (-1224 *4)))) (-3536 (*1 *1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-4 *1 (-1224 *3)) (-4 *3 (-1047)))) (-3837 (*1 *1 *1) (-12 (-4 *1 (-1224 *2)) (-4 *2 (-1047)) (-4 *2 (-43 (-409 (-568)))))) (-3837 (*1 *1 *1 *2) (-2198 (-12 (-5 *2 (-1161)) (-4 *1 (-1224 *3)) (-4 *3 (-1047)) (-12 (-4 *3 (-29 (-568))) (-4 *3 (-959)) (-4 *3 (-1181)) (-4 *3 (-43 (-409 (-568)))))) (-12 (-5 *2 (-1161)) (-4 *1 (-1224 *3)) (-4 *3 (-1047)) (-12 (|has| *3 (-15 -2055 ((-634 *2) *3))) (|has| *3 (-15 -3837 (*3 *3 *2))) (-4 *3 (-43 (-409 (-568))))))))) 
-(-13 (-1221 |t#1| (-409 (-568))) (-10 -8 (-15 -3728 ($ (-763) (-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |t#1|))))) (-15 -3536 ($ $ (-409 (-568)))) (IF (|has| |t#1| (-43 (-409 (-568)))) (PROGN (-15 -3837 ($ $)) (IF (|has| |t#1| (-15 -3837 (|t#1| |t#1| (-1161)))) (IF (|has| |t#1| (-15 -2055 ((-634 (-1161)) |t#1|))) (-15 -3837 ($ $ (-1161))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-1181)) (IF (|has| |t#1| (-959)) (IF (|has| |t#1| (-29 (-568))) (-15 -3837 ($ $ (-1161))) |noBranch|) |noBranch|) |noBranch|) (-6 (-1002)) (-6 (-1181))) |noBranch|) (IF (|has| |t#1| (-365)) (-6 (-365)) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| (-409 (-568))) . T) ((-25) . T) ((-43 (-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) -2198 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-40) |has| |#1| (-43 (-409 (-568)))) ((-98) |has| |#1| (-43 (-409 (-568)))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2198 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2198 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-225) |has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) ((-238) |has| |#1| (-365)) ((-279) |has| |#1| (-43 (-409 (-568)))) ((-281 $ $) |has| (-409 (-568)) (-1102)) ((-285) -2198 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-301) |has| |#1| (-365)) ((-365) |has| |#1| (-365)) ((-453) |has| |#1| (-365)) ((-502) |has| |#1| (-43 (-409 (-568)))) ((-558) -2198 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-637 (-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) -2198 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-716) . T) ((-895 (-1161)) -12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161)))) ((-974 |#1| (-409 (-568)) (-1075)) . T) ((-916) |has| |#1| (-365)) ((-1002) |has| |#1| (-43 (-409 (-568)))) ((-1053 (-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-1053 |#1|) . T) ((-1053 $) -2198 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1181) |has| |#1| (-43 (-409 (-568)))) ((-1184) |has| |#1| (-43 (-409 (-568)))) ((-1199) |has| |#1| (-365)) ((-1221 |#1| (-409 (-568))) . T)) 
-((-2537 (((-121) $) 12)) (-3666 (((-3 |#3| "failed") $) 17)) (-2854 ((|#3| $) 14))) 
-(((-1225 |#1| |#2| |#3|) (-10 -8 (-15 -2854 (|#3| |#1|)) (-15 -3666 ((-3 |#3| "failed") |#1|)) (-15 -2537 ((-121) |#1|))) (-1226 |#2| |#3|) (-1047) (-1203 |#2|)) (T -1225)) 
-NIL 
-(-10 -8 (-15 -2854 (|#3| |#1|)) (-15 -3666 ((-3 |#3| "failed") |#1|)) (-15 -2537 ((-121) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-2055 (((-634 (-1075)) $) 70)) (-1305 (((-1161) $) 98)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 50 (|has| |#1| (-558)))) (-2227 (($ $) 51 (|has| |#1| (-558)))) (-1573 (((-121) $) 53 (|has| |#1| (-558)))) (-2617 (($ $ (-409 (-568))) 93) (($ $ (-409 (-568)) (-409 (-568))) 92)) (-2583 (((-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|))) $) 100)) (-1982 (($ $) 127 (|has| |#1| (-43 (-409 (-568)))))) (-1933 (($ $) 110 (|has| |#1| (-43 (-409 (-568)))))) (-3134 (((-3 $ "failed") $ $) 18)) (-4305 (($ $) 154 (|has| |#1| (-365)))) (-1678 (((-420 $) $) 155 (|has| |#1| (-365)))) (-1902 (($ $) 109 (|has| |#1| (-43 (-409 (-568)))))) (-1497 (((-121) $ $) 145 (|has| |#1| (-365)))) (-1974 (($ $) 126 (|has| |#1| (-43 (-409 (-568)))))) (-2786 (($ $) 111 (|has| |#1| (-43 (-409 (-568)))))) (-3728 (($ (-763) (-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|)))) 164)) (-1990 (($ $) 125 (|has| |#1| (-43 (-409 (-568)))))) (-1941 (($ $) 112 (|has| |#1| (-43 (-409 (-568)))))) (-2671 (($) 16 T CONST)) (-3666 (((-3 |#2| "failed") $) 172)) (-2854 ((|#2| $) 171)) (-2401 (($ $ $) 149 (|has| |#1| (-365)))) (-2114 (($ $) 59)) (-2925 (((-3 $ "failed") $) 33)) (-3533 (((-409 (-568)) $) 169)) (-2412 (($ $ $) 148 (|has| |#1| (-365)))) (-2075 (($ (-409 (-568)) |#2|) 170)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 143 (|has| |#1| (-365)))) (-3927 (((-121) $) 156 (|has| |#1| (-365)))) (-3992 (((-121) $) 69)) (-1897 (($) 137 (|has| |#1| (-43 (-409 (-568)))))) (-4477 (((-409 (-568)) $) 95) (((-409 (-568)) $ (-409 (-568))) 94)) (-2735 (((-121) $) 30)) (-4044 (($ $ (-568)) 108 (|has| |#1| (-43 (-409 (-568)))))) (-3536 (($ $ (-917)) 96) (($ $ (-409 (-568))) 163)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 152 (|has| |#1| (-365)))) (-3921 (((-121) $) 61)) (-2047 (($ |#1| (-409 (-568))) 60) (($ $ (-1075) (-409 (-568))) 72) (($ $ (-634 (-1075)) (-634 (-409 (-568)))) 71)) (-2795 (($ (-1 |#1| |#1|) $) 62)) (-4416 (($ $) 134 (|has| |#1| (-43 (-409 (-568)))))) (-2097 (($ $) 64)) (-2102 ((|#1| $) 65)) (-2495 (($ (-634 $)) 141 (|has| |#1| (-365))) (($ $ $) 140 (|has| |#1| (-365)))) (-3429 ((|#2| $) 168)) (-3074 (((-3 |#2| "failed") $) 166)) (-2070 ((|#2| $) 167)) (-4487 (((-1143) $) 9)) (-2081 (($ $) 157 (|has| |#1| (-365)))) (-3837 (($ $) 162 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) 161 (-2198 (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-959)) (|has| |#1| (-1181)) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-15 -2055 ((-634 (-1161)) |#1|))) (|has| |#1| (-15 -3837 (|#1| |#1| (-1161)))) (|has| |#1| (-43 (-409 (-568)))))))) (-4022 (((-1108) $) 10)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 142 (|has| |#1| (-365)))) (-2721 (($ (-634 $)) 139 (|has| |#1| (-365))) (($ $ $) 138 (|has| |#1| (-365)))) (-3848 (((-420 $) $) 153 (|has| |#1| (-365)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 151 (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 150 (|has| |#1| (-365)))) (-1807 (($ $ (-409 (-568))) 90)) (-2595 (((-3 $ "failed") $ $) 49 (|has| |#1| (-558)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 144 (|has| |#1| (-365)))) (-1892 (($ $) 135 (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))))) (-2709 (((-763) $) 146 (|has| |#1| (-365)))) (-2779 ((|#1| $ (-409 (-568))) 99) (($ $ $) 76 (|has| (-409 (-568)) (-1102)))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 147 (|has| |#1| (-365)))) (-4189 (($ $ (-634 (-1161)) (-634 (-763))) 84 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-1161) (-763)) 83 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-634 (-1161))) 82 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-1161)) 81 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-763)) 79 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) 77 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (-3206 (((-409 (-568)) $) 63)) (-1994 (($ $) 124 (|has| |#1| (-43 (-409 (-568)))))) (-1945 (($ $) 113 (|has| |#1| (-43 (-409 (-568)))))) (-1986 (($ $) 123 (|has| |#1| (-43 (-409 (-568)))))) (-1937 (($ $) 114 (|has| |#1| (-43 (-409 (-568)))))) (-1978 (($ $) 122 (|has| |#1| (-43 (-409 (-568)))))) (-2790 (($ $) 115 (|has| |#1| (-43 (-409 (-568)))))) (-1811 (($ $) 68)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 46 (|has| |#1| (-172))) (($ |#2|) 173) (($ (-409 (-568))) 56 (|has| |#1| (-43 (-409 (-568))))) (($ $) 48 (|has| |#1| (-558)))) (-2604 ((|#1| $ (-409 (-568))) 58)) (-4371 (((-3 $ "failed") $) 47 (|has| |#1| (-148)))) (-4078 (((-763)) 28)) (-1374 ((|#1| $) 97)) (-2006 (($ $) 133 (|has| |#1| (-43 (-409 (-568)))))) (-1958 (($ $) 121 (|has| |#1| (-43 (-409 (-568)))))) (-1826 (((-121) $ $) 52 (|has| |#1| (-558)))) (-1998 (($ $) 132 (|has| |#1| (-43 (-409 (-568)))))) (-1949 (($ $) 120 (|has| |#1| (-43 (-409 (-568)))))) (-2014 (($ $) 131 (|has| |#1| (-43 (-409 (-568)))))) (-1966 (($ $) 119 (|has| |#1| (-43 (-409 (-568)))))) (-3996 ((|#1| $ (-409 (-568))) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))) (|has| |#1| (-15 -2745 (|#1| (-1161))))))) (-4023 (($ $) 130 (|has| |#1| (-43 (-409 (-568)))))) (-1970 (($ $) 118 (|has| |#1| (-43 (-409 (-568)))))) (-2010 (($ $) 129 (|has| |#1| (-43 (-409 (-568)))))) (-1962 (($ $) 117 (|has| |#1| (-43 (-409 (-568)))))) (-2002 (($ $) 128 (|has| |#1| (-43 (-409 (-568)))))) (-1953 (($ $) 116 (|has| |#1| (-43 (-409 (-568)))))) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 158 (|has| |#1| (-365)))) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $ (-634 (-1161)) (-634 (-763))) 88 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-1161) (-763)) 87 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-634 (-1161))) 86 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-1161)) 85 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-763)) 80 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) 78 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (-1717 (((-121) $ $) 6)) (-1779 (($ $ |#1|) 57 (|has| |#1| (-365))) (($ $ $) 160 (|has| |#1| (-365)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 159 (|has| |#1| (-365))) (($ $ $) 136 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 107 (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-409 (-568)) $) 55 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 54 (|has| |#1| (-43 (-409 (-568))))))) 
+((-2512 (*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *3 (-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| *4)))) (-4 *4 (-1047)) (-4 *1 (-1224 *4)))) (-4168 (*1 *1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-4 *1 (-1224 *3)) (-4 *3 (-1047)))) (-1845 (*1 *1 *1) (-12 (-4 *1 (-1224 *2)) (-4 *2 (-1047)) (-4 *2 (-43 (-409 (-568)))))) (-1845 (*1 *1 *1 *2) (-2199 (-12 (-5 *2 (-1161)) (-4 *1 (-1224 *3)) (-4 *3 (-1047)) (-12 (-4 *3 (-29 (-568))) (-4 *3 (-959)) (-4 *3 (-1181)) (-4 *3 (-43 (-409 (-568)))))) (-12 (-5 *2 (-1161)) (-4 *1 (-1224 *3)) (-4 *3 (-1047)) (-12 (|has| *3 (-15 -2057 ((-634 *2) *3))) (|has| *3 (-15 -1845 (*3 *3 *2))) (-4 *3 (-43 (-409 (-568))))))))) 
+(-13 (-1221 |t#1| (-409 (-568))) (-10 -8 (-15 -2512 ($ (-763) (-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |t#1|))))) (-15 -4168 ($ $ (-409 (-568)))) (IF (|has| |t#1| (-43 (-409 (-568)))) (PROGN (-15 -1845 ($ $)) (IF (|has| |t#1| (-15 -1845 (|t#1| |t#1| (-1161)))) (IF (|has| |t#1| (-15 -2057 ((-634 (-1161)) |t#1|))) (-15 -1845 ($ $ (-1161))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-1181)) (IF (|has| |t#1| (-959)) (IF (|has| |t#1| (-29 (-568))) (-15 -1845 ($ $ (-1161))) |noBranch|) |noBranch|) |noBranch|) (-6 (-1002)) (-6 (-1181))) |noBranch|) (IF (|has| |t#1| (-365)) (-6 (-365)) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| (-409 (-568))) . T) ((-25) . T) ((-43 (-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) -2199 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-40) |has| |#1| (-43 (-409 (-568)))) ((-98) |has| |#1| (-43 (-409 (-568)))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2199 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2199 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-225) |has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) ((-238) |has| |#1| (-365)) ((-279) |has| |#1| (-43 (-409 (-568)))) ((-281 $ $) |has| (-409 (-568)) (-1102)) ((-285) -2199 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-301) |has| |#1| (-365)) ((-365) |has| |#1| (-365)) ((-453) |has| |#1| (-365)) ((-502) |has| |#1| (-43 (-409 (-568)))) ((-558) -2199 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-637 (-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) -2199 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-716) . T) ((-895 (-1161)) -12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161)))) ((-974 |#1| (-409 (-568)) (-1075)) . T) ((-916) |has| |#1| (-365)) ((-1002) |has| |#1| (-43 (-409 (-568)))) ((-1053 (-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-1053 |#1|) . T) ((-1053 $) -2199 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1181) |has| |#1| (-43 (-409 (-568)))) ((-1184) |has| |#1| (-43 (-409 (-568)))) ((-1199) |has| |#1| (-365)) ((-1221 |#1| (-409 (-568))) . T)) 
+((-1819 (((-121) $) 12)) (-3668 (((-3 |#3| "failed") $) 17)) (-2857 ((|#3| $) 14))) 
+(((-1225 |#1| |#2| |#3|) (-10 -8 (-15 -2857 (|#3| |#1|)) (-15 -3668 ((-3 |#3| "failed") |#1|)) (-15 -1819 ((-121) |#1|))) (-1226 |#2| |#3|) (-1047) (-1203 |#2|)) (T -1225)) 
+NIL 
+(-10 -8 (-15 -2857 (|#3| |#1|)) (-15 -3668 ((-3 |#3| "failed") |#1|)) (-15 -1819 ((-121) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2057 (((-634 (-1075)) $) 70)) (-3325 (((-1161) $) 98)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 50 (|has| |#1| (-558)))) (-3661 (($ $) 51 (|has| |#1| (-558)))) (-4426 (((-121) $) 53 (|has| |#1| (-558)))) (-4179 (($ $ (-409 (-568))) 93) (($ $ (-409 (-568)) (-409 (-568))) 92)) (-2013 (((-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|))) $) 100)) (-1984 (($ $) 127 (|has| |#1| (-43 (-409 (-568)))))) (-1935 (($ $) 110 (|has| |#1| (-43 (-409 (-568)))))) (-2689 (((-3 $ "failed") $ $) 18)) (-3045 (($ $) 154 (|has| |#1| (-365)))) (-3498 (((-420 $) $) 155 (|has| |#1| (-365)))) (-1904 (($ $) 109 (|has| |#1| (-43 (-409 (-568)))))) (-2589 (((-121) $ $) 145 (|has| |#1| (-365)))) (-1976 (($ $) 126 (|has| |#1| (-43 (-409 (-568)))))) (-2788 (($ $) 111 (|has| |#1| (-43 (-409 (-568)))))) (-2512 (($ (-763) (-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|)))) 164)) (-1992 (($ $) 125 (|has| |#1| (-43 (-409 (-568)))))) (-1943 (($ $) 112 (|has| |#1| (-43 (-409 (-568)))))) (-4490 (($) 16 T CONST)) (-3668 (((-3 |#2| "failed") $) 172)) (-2857 ((|#2| $) 171)) (-2403 (($ $ $) 149 (|has| |#1| (-365)))) (-2116 (($ $) 59)) (-2902 (((-3 $ "failed") $) 33)) (-4147 (((-409 (-568)) $) 169)) (-2414 (($ $ $) 148 (|has| |#1| (-365)))) (-2077 (($ (-409 (-568)) |#2|) 170)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 143 (|has| |#1| (-365)))) (-2197 (((-121) $) 156 (|has| |#1| (-365)))) (-1302 (((-121) $) 69)) (-1899 (($) 137 (|has| |#1| (-43 (-409 (-568)))))) (-1844 (((-409 (-568)) $) 95) (((-409 (-568)) $ (-409 (-568))) 94)) (-1598 (((-121) $) 30)) (-1550 (($ $ (-568)) 108 (|has| |#1| (-43 (-409 (-568)))))) (-4168 (($ $ (-917)) 96) (($ $ (-409 (-568))) 163)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 152 (|has| |#1| (-365)))) (-2171 (((-121) $) 61)) (-2049 (($ |#1| (-409 (-568))) 60) (($ $ (-1075) (-409 (-568))) 72) (($ $ (-634 (-1075)) (-634 (-409 (-568)))) 71)) (-2797 (($ (-1 |#1| |#1|) $) 62)) (-4418 (($ $) 134 (|has| |#1| (-43 (-409 (-568)))))) (-2099 (($ $) 64)) (-2104 ((|#1| $) 65)) (-2498 (($ (-634 $)) 141 (|has| |#1| (-365))) (($ $ $) 140 (|has| |#1| (-365)))) (-3408 ((|#2| $) 168)) (-2380 (((-3 |#2| "failed") $) 166)) (-2072 ((|#2| $) 167)) (-1893 (((-1143) $) 9)) (-2083 (($ $) 157 (|has| |#1| (-365)))) (-1845 (($ $) 162 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) 161 (-2199 (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-959)) (|has| |#1| (-1181)) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-15 -2057 ((-634 (-1161)) |#1|))) (|has| |#1| (-15 -1845 (|#1| |#1| (-1161)))) (|has| |#1| (-43 (-409 (-568)))))))) (-4025 (((-1108) $) 10)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 142 (|has| |#1| (-365)))) (-2723 (($ (-634 $)) 139 (|has| |#1| (-365))) (($ $ $) 138 (|has| |#1| (-365)))) (-3850 (((-420 $) $) 153 (|has| |#1| (-365)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 151 (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 150 (|has| |#1| (-365)))) (-2168 (($ $ (-409 (-568))) 90)) (-2597 (((-3 $ "failed") $ $) 49 (|has| |#1| (-558)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 144 (|has| |#1| (-365)))) (-1894 (($ $) 135 (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))))) (-1466 (((-763) $) 146 (|has| |#1| (-365)))) (-2781 ((|#1| $ (-409 (-568))) 99) (($ $ $) 76 (|has| (-409 (-568)) (-1102)))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 147 (|has| |#1| (-365)))) (-4191 (($ $ (-634 (-1161)) (-634 (-763))) 84 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-1161) (-763)) 83 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-634 (-1161))) 82 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-1161)) 81 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-763)) 79 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) 77 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (-1836 (((-409 (-568)) $) 63)) (-1996 (($ $) 124 (|has| |#1| (-43 (-409 (-568)))))) (-1947 (($ $) 113 (|has| |#1| (-43 (-409 (-568)))))) (-1988 (($ $) 123 (|has| |#1| (-43 (-409 (-568)))))) (-1939 (($ $) 114 (|has| |#1| (-43 (-409 (-568)))))) (-1980 (($ $) 122 (|has| |#1| (-43 (-409 (-568)))))) (-2792 (($ $) 115 (|has| |#1| (-43 (-409 (-568)))))) (-2188 (($ $) 68)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 46 (|has| |#1| (-172))) (($ |#2|) 173) (($ (-409 (-568))) 56 (|has| |#1| (-43 (-409 (-568))))) (($ $) 48 (|has| |#1| (-558)))) (-2079 ((|#1| $ (-409 (-568))) 58)) (-3385 (((-3 $ "failed") $) 47 (|has| |#1| (-148)))) (-3425 (((-763)) 28)) (-1374 ((|#1| $) 97)) (-2008 (($ $) 133 (|has| |#1| (-43 (-409 (-568)))))) (-1959 (($ $) 121 (|has| |#1| (-43 (-409 (-568)))))) (-2273 (((-121) $ $) 52 (|has| |#1| (-558)))) (-2000 (($ $) 132 (|has| |#1| (-43 (-409 (-568)))))) (-1951 (($ $) 120 (|has| |#1| (-43 (-409 (-568)))))) (-2016 (($ $) 131 (|has| |#1| (-43 (-409 (-568)))))) (-1968 (($ $) 119 (|has| |#1| (-43 (-409 (-568)))))) (-3999 ((|#1| $ (-409 (-568))) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))) (|has| |#1| (-15 -2747 (|#1| (-1161))))))) (-1439 (($ $) 130 (|has| |#1| (-43 (-409 (-568)))))) (-1972 (($ $) 118 (|has| |#1| (-43 (-409 (-568)))))) (-2012 (($ $) 129 (|has| |#1| (-43 (-409 (-568)))))) (-1964 (($ $) 117 (|has| |#1| (-43 (-409 (-568)))))) (-2004 (($ $) 128 (|has| |#1| (-43 (-409 (-568)))))) (-1955 (($ $) 116 (|has| |#1| (-43 (-409 (-568)))))) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 158 (|has| |#1| (-365)))) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $ (-634 (-1161)) (-634 (-763))) 88 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-1161) (-763)) 87 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-634 (-1161))) 86 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-1161)) 85 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (($ $ (-763)) 80 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) 78 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (-1719 (((-121) $ $) 6)) (-1781 (($ $ |#1|) 57 (|has| |#1| (-365))) (($ $ $) 160 (|has| |#1| (-365)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 159 (|has| |#1| (-365))) (($ $ $) 136 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 107 (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-409 (-568)) $) 55 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 54 (|has| |#1| (-43 (-409 (-568))))))) 
 (((-1226 |#1| |#2|) (-1275) (-1047) (-1203 |t#1|)) (T -1226)) 
-((-3206 (*1 *2 *1) (-12 (-4 *1 (-1226 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1203 *3)) (-5 *2 (-409 (-568))))) (-2745 (*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *1 (-1226 *3 *2)) (-4 *2 (-1203 *3)))) (-2075 (*1 *1 *2 *3) (-12 (-5 *2 (-409 (-568))) (-4 *4 (-1047)) (-4 *1 (-1226 *4 *3)) (-4 *3 (-1203 *4)))) (-3533 (*1 *2 *1) (-12 (-4 *1 (-1226 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1203 *3)) (-5 *2 (-409 (-568))))) (-3429 (*1 *2 *1) (-12 (-4 *1 (-1226 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1203 *3)))) (-2070 (*1 *2 *1) (-12 (-4 *1 (-1226 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1203 *3)))) (-3074 (*1 *2 *1) (|partial| -12 (-4 *1 (-1226 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1203 *3))))) 
-(-13 (-1224 |t#1|) (-1037 |t#2|) (-10 -8 (-15 -2075 ($ (-409 (-568)) |t#2|)) (-15 -3533 ((-409 (-568)) $)) (-15 -3429 (|t#2| $)) (-15 -3206 ((-409 (-568)) $)) (-15 -2745 ($ |t#2|)) (-15 -2070 (|t#2| $)) (-15 -3074 ((-3 |t#2| "failed") $)))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| (-409 (-568))) . T) ((-25) . T) ((-43 (-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) -2198 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-40) |has| |#1| (-43 (-409 (-568)))) ((-98) |has| |#1| (-43 (-409 (-568)))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2198 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2198 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-225) |has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) ((-238) |has| |#1| (-365)) ((-279) |has| |#1| (-43 (-409 (-568)))) ((-281 $ $) |has| (-409 (-568)) (-1102)) ((-285) -2198 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-301) |has| |#1| (-365)) ((-365) |has| |#1| (-365)) ((-453) |has| |#1| (-365)) ((-502) |has| |#1| (-43 (-409 (-568)))) ((-558) -2198 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-637 (-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) -2198 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-716) . T) ((-895 (-1161)) -12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161)))) ((-974 |#1| (-409 (-568)) (-1075)) . T) ((-916) |has| |#1| (-365)) ((-1002) |has| |#1| (-43 (-409 (-568)))) ((-1037 |#2|) . T) ((-1053 (-409 (-568))) -2198 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-1053 |#1|) . T) ((-1053 $) -2198 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1181) |has| |#1| (-43 (-409 (-568)))) ((-1184) |has| |#1| (-43 (-409 (-568)))) ((-1199) |has| |#1| (-365)) ((-1221 |#1| (-409 (-568))) . T) ((-1224 |#1|) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2055 (((-634 (-1075)) $) NIL)) (-1305 (((-1161) $) 96)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-2617 (($ $ (-409 (-568))) 106) (($ $ (-409 (-568)) (-409 (-568))) 108)) (-2583 (((-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|))) $) 51)) (-1982 (($ $) 179 (|has| |#1| (-43 (-409 (-568)))))) (-1933 (($ $) 155 (|has| |#1| (-43 (-409 (-568)))))) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL (|has| |#1| (-365)))) (-1678 (((-420 $) $) NIL (|has| |#1| (-365)))) (-1902 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1497 (((-121) $ $) NIL (|has| |#1| (-365)))) (-1974 (($ $) 175 (|has| |#1| (-43 (-409 (-568)))))) (-2786 (($ $) 151 (|has| |#1| (-43 (-409 (-568)))))) (-3728 (($ (-763) (-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|)))) 61)) (-1990 (($ $) 183 (|has| |#1| (-43 (-409 (-568)))))) (-1941 (($ $) 159 (|has| |#1| (-43 (-409 (-568)))))) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#2| "failed") $) NIL)) (-2854 ((|#2| $) NIL)) (-2401 (($ $ $) NIL (|has| |#1| (-365)))) (-2114 (($ $) NIL)) (-2925 (((-3 $ "failed") $) 79)) (-3533 (((-409 (-568)) $) 12)) (-2412 (($ $ $) NIL (|has| |#1| (-365)))) (-2075 (($ (-409 (-568)) |#2|) 10)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-3927 (((-121) $) NIL (|has| |#1| (-365)))) (-3992 (((-121) $) 68)) (-1897 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4477 (((-409 (-568)) $) 103) (((-409 (-568)) $ (-409 (-568))) 104)) (-2735 (((-121) $) NIL)) (-4044 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3536 (($ $ (-917)) 120) (($ $ (-409 (-568))) 118)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| (-409 (-568))) 31) (($ $ (-1075) (-409 (-568))) NIL) (($ $ (-634 (-1075)) (-634 (-409 (-568)))) NIL)) (-2795 (($ (-1 |#1| |#1|) $) 115)) (-4416 (($ $) 149 (|has| |#1| (-43 (-409 (-568)))))) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-2495 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-3429 ((|#2| $) 11)) (-3074 (((-3 |#2| "failed") $) 41)) (-2070 ((|#2| $) 42)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) 93 (|has| |#1| (-365)))) (-3837 (($ $) 135 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) 140 (-2198 (-12 (|has| |#1| (-15 -3837 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2055 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181)))))) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-365)))) (-2721 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-3848 (((-420 $) $) NIL (|has| |#1| (-365)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-365)))) (-1807 (($ $ (-409 (-568))) 112)) (-2595 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1892 (($ $) 147 (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) 90 (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))))) (-2709 (((-763) $) NIL (|has| |#1| (-365)))) (-2779 ((|#1| $ (-409 (-568))) 100) (($ $ $) 86 (|has| (-409 (-568)) (-1102)))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-365)))) (-4189 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) 127 (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) 124 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (-3206 (((-409 (-568)) $) 16)) (-1994 (($ $) 185 (|has| |#1| (-43 (-409 (-568)))))) (-1945 (($ $) 161 (|has| |#1| (-43 (-409 (-568)))))) (-1986 (($ $) 181 (|has| |#1| (-43 (-409 (-568)))))) (-1937 (($ $) 157 (|has| |#1| (-43 (-409 (-568)))))) (-1978 (($ $) 177 (|has| |#1| (-43 (-409 (-568)))))) (-2790 (($ $) 153 (|has| |#1| (-43 (-409 (-568)))))) (-1811 (($ $) 110)) (-2745 (((-850) $) NIL) (($ (-568)) 35) (($ |#1|) 27 (|has| |#1| (-172))) (($ |#2|) 32) (($ (-409 (-568))) 128 (|has| |#1| (-43 (-409 (-568))))) (($ $) NIL (|has| |#1| (-558)))) (-2604 ((|#1| $ (-409 (-568))) 99)) (-4371 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-4078 (((-763)) 117)) (-1374 ((|#1| $) 98)) (-2006 (($ $) 191 (|has| |#1| (-43 (-409 (-568)))))) (-1958 (($ $) 167 (|has| |#1| (-43 (-409 (-568)))))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1998 (($ $) 187 (|has| |#1| (-43 (-409 (-568)))))) (-1949 (($ $) 163 (|has| |#1| (-43 (-409 (-568)))))) (-2014 (($ $) 195 (|has| |#1| (-43 (-409 (-568)))))) (-1966 (($ $) 171 (|has| |#1| (-43 (-409 (-568)))))) (-3996 ((|#1| $ (-409 (-568))) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))) (|has| |#1| (-15 -2745 (|#1| (-1161))))))) (-4023 (($ $) 197 (|has| |#1| (-43 (-409 (-568)))))) (-1970 (($ $) 173 (|has| |#1| (-43 (-409 (-568)))))) (-2010 (($ $) 193 (|has| |#1| (-43 (-409 (-568)))))) (-1962 (($ $) 169 (|has| |#1| (-43 (-409 (-568)))))) (-2002 (($ $) 189 (|has| |#1| (-43 (-409 (-568)))))) (-1953 (($ $) 165 (|has| |#1| (-43 (-409 (-568)))))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (-3056 (($) 21 T CONST)) (-1556 (($) 17 T CONST)) (-3190 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (-1717 (((-121) $ $) 66)) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365))) (($ $ $) 92 (|has| |#1| (-365)))) (-1773 (($ $) 131) (($ $ $) 72)) (-1767 (($ $ $) 70)) (** (($ $ (-917)) NIL) (($ $ (-763)) 76) (($ $ (-568)) 144 (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 145 (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 74) (($ $ |#1|) NIL) (($ |#1| $) 126) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
+((-1836 (*1 *2 *1) (-12 (-4 *1 (-1226 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1203 *3)) (-5 *2 (-409 (-568))))) (-2747 (*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *1 (-1226 *3 *2)) (-4 *2 (-1203 *3)))) (-2077 (*1 *1 *2 *3) (-12 (-5 *2 (-409 (-568))) (-4 *4 (-1047)) (-4 *1 (-1226 *4 *3)) (-4 *3 (-1203 *4)))) (-4147 (*1 *2 *1) (-12 (-4 *1 (-1226 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1203 *3)) (-5 *2 (-409 (-568))))) (-3408 (*1 *2 *1) (-12 (-4 *1 (-1226 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1203 *3)))) (-2072 (*1 *2 *1) (-12 (-4 *1 (-1226 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1203 *3)))) (-2380 (*1 *2 *1) (|partial| -12 (-4 *1 (-1226 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1203 *3))))) 
+(-13 (-1224 |t#1|) (-1037 |t#2|) (-10 -8 (-15 -2077 ($ (-409 (-568)) |t#2|)) (-15 -4147 ((-409 (-568)) $)) (-15 -3408 (|t#2| $)) (-15 -1836 ((-409 (-568)) $)) (-15 -2747 ($ |t#2|)) (-15 -2072 (|t#2| $)) (-15 -2380 ((-3 |t#2| "failed") $)))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| (-409 (-568))) . T) ((-25) . T) ((-43 (-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) -2199 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-40) |has| |#1| (-43 (-409 (-568)))) ((-98) |has| |#1| (-43 (-409 (-568)))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2199 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2199 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-225) |has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) ((-238) |has| |#1| (-365)) ((-279) |has| |#1| (-43 (-409 (-568)))) ((-281 $ $) |has| (-409 (-568)) (-1102)) ((-285) -2199 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-301) |has| |#1| (-365)) ((-365) |has| |#1| (-365)) ((-453) |has| |#1| (-365)) ((-502) |has| |#1| (-43 (-409 (-568)))) ((-558) -2199 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-637 (-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) -2199 (|has| |#1| (-558)) (|has| |#1| (-365))) ((-716) . T) ((-895 (-1161)) -12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161)))) ((-974 |#1| (-409 (-568)) (-1075)) . T) ((-916) |has| |#1| (-365)) ((-1002) |has| |#1| (-43 (-409 (-568)))) ((-1037 |#2|) . T) ((-1053 (-409 (-568))) -2199 (|has| |#1| (-365)) (|has| |#1| (-43 (-409 (-568))))) ((-1053 |#1|) . T) ((-1053 $) -2199 (|has| |#1| (-558)) (|has| |#1| (-365)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1181) |has| |#1| (-43 (-409 (-568)))) ((-1184) |has| |#1| (-43 (-409 (-568)))) ((-1199) |has| |#1| (-365)) ((-1221 |#1| (-409 (-568))) . T) ((-1224 |#1|) . T)) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2057 (((-634 (-1075)) $) NIL)) (-3325 (((-1161) $) 96)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-4179 (($ $ (-409 (-568))) 106) (($ $ (-409 (-568)) (-409 (-568))) 108)) (-2013 (((-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|))) $) 51)) (-1984 (($ $) 179 (|has| |#1| (-43 (-409 (-568)))))) (-1935 (($ $) 155 (|has| |#1| (-43 (-409 (-568)))))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL (|has| |#1| (-365)))) (-3498 (((-420 $) $) NIL (|has| |#1| (-365)))) (-1904 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2589 (((-121) $ $) NIL (|has| |#1| (-365)))) (-1976 (($ $) 175 (|has| |#1| (-43 (-409 (-568)))))) (-2788 (($ $) 151 (|has| |#1| (-43 (-409 (-568)))))) (-2512 (($ (-763) (-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|)))) 61)) (-1992 (($ $) 183 (|has| |#1| (-43 (-409 (-568)))))) (-1943 (($ $) 159 (|has| |#1| (-43 (-409 (-568)))))) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#2| "failed") $) NIL)) (-2857 ((|#2| $) NIL)) (-2403 (($ $ $) NIL (|has| |#1| (-365)))) (-2116 (($ $) NIL)) (-2902 (((-3 $ "failed") $) 79)) (-4147 (((-409 (-568)) $) 12)) (-2414 (($ $ $) NIL (|has| |#1| (-365)))) (-2077 (($ (-409 (-568)) |#2|) 10)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-2197 (((-121) $) NIL (|has| |#1| (-365)))) (-1302 (((-121) $) 68)) (-1899 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1844 (((-409 (-568)) $) 103) (((-409 (-568)) $ (-409 (-568))) 104)) (-1598 (((-121) $) NIL)) (-1550 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4168 (($ $ (-917)) 120) (($ $ (-409 (-568))) 118)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| (-409 (-568))) 31) (($ $ (-1075) (-409 (-568))) NIL) (($ $ (-634 (-1075)) (-634 (-409 (-568)))) NIL)) (-2797 (($ (-1 |#1| |#1|) $) 115)) (-4418 (($ $) 149 (|has| |#1| (-43 (-409 (-568)))))) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-2498 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-3408 ((|#2| $) 11)) (-2380 (((-3 |#2| "failed") $) 41)) (-2072 ((|#2| $) 42)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) 93 (|has| |#1| (-365)))) (-1845 (($ $) 135 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) 140 (-2199 (-12 (|has| |#1| (-15 -1845 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2057 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181)))))) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-365)))) (-2723 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-3850 (((-420 $) $) NIL (|has| |#1| (-365)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-365)))) (-2168 (($ $ (-409 (-568))) 112)) (-2597 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1894 (($ $) 147 (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) 90 (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))))) (-1466 (((-763) $) NIL (|has| |#1| (-365)))) (-2781 ((|#1| $ (-409 (-568))) 100) (($ $ $) 86 (|has| (-409 (-568)) (-1102)))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-365)))) (-4191 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) 127 (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) 124 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (-1836 (((-409 (-568)) $) 16)) (-1996 (($ $) 185 (|has| |#1| (-43 (-409 (-568)))))) (-1947 (($ $) 161 (|has| |#1| (-43 (-409 (-568)))))) (-1988 (($ $) 181 (|has| |#1| (-43 (-409 (-568)))))) (-1939 (($ $) 157 (|has| |#1| (-43 (-409 (-568)))))) (-1980 (($ $) 177 (|has| |#1| (-43 (-409 (-568)))))) (-2792 (($ $) 153 (|has| |#1| (-43 (-409 (-568)))))) (-2188 (($ $) 110)) (-2747 (((-850) $) NIL) (($ (-568)) 35) (($ |#1|) 27 (|has| |#1| (-172))) (($ |#2|) 32) (($ (-409 (-568))) 128 (|has| |#1| (-43 (-409 (-568))))) (($ $) NIL (|has| |#1| (-558)))) (-2079 ((|#1| $ (-409 (-568))) 99)) (-3385 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-3425 (((-763)) 117)) (-1374 ((|#1| $) 98)) (-2008 (($ $) 191 (|has| |#1| (-43 (-409 (-568)))))) (-1959 (($ $) 167 (|has| |#1| (-43 (-409 (-568)))))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2000 (($ $) 187 (|has| |#1| (-43 (-409 (-568)))))) (-1951 (($ $) 163 (|has| |#1| (-43 (-409 (-568)))))) (-2016 (($ $) 195 (|has| |#1| (-43 (-409 (-568)))))) (-1968 (($ $) 171 (|has| |#1| (-43 (-409 (-568)))))) (-3999 ((|#1| $ (-409 (-568))) NIL (-12 (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))) (|has| |#1| (-15 -2747 (|#1| (-1161))))))) (-1439 (($ $) 197 (|has| |#1| (-43 (-409 (-568)))))) (-1972 (($ $) 173 (|has| |#1| (-43 (-409 (-568)))))) (-2012 (($ $) 193 (|has| |#1| (-43 (-409 (-568)))))) (-1964 (($ $) 169 (|has| |#1| (-43 (-409 (-568)))))) (-2004 (($ $) 189 (|has| |#1| (-43 (-409 (-568)))))) (-1955 (($ $) 165 (|has| |#1| (-43 (-409 (-568)))))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (-3058 (($) 21 T CONST)) (-1557 (($) 17 T CONST)) (-3192 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (-1719 (((-121) $ $) 66)) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365))) (($ $ $) 92 (|has| |#1| (-365)))) (-1775 (($ $) 131) (($ $ $) 72)) (-1769 (($ $ $) 70)) (** (($ $ (-917)) NIL) (($ $ (-763)) 76) (($ $ (-568)) 144 (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 145 (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 74) (($ $ |#1|) NIL) (($ |#1| $) 126) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
 (((-1227 |#1| |#2|) (-1226 |#1| |#2|) (-1047) (-1203 |#1|)) (T -1227)) 
 NIL 
 (-1226 |#1| |#2|) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2055 (((-634 (-1075)) $) NIL)) (-1305 (((-1161) $) 11)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) NIL (|has| |#1| (-558)))) (-2617 (($ $ (-409 (-568))) NIL) (($ $ (-409 (-568)) (-409 (-568))) NIL)) (-2583 (((-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|))) $) NIL)) (-1982 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1933 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3134 (((-3 $ "failed") $ $) NIL)) (-4305 (($ $) NIL (|has| |#1| (-365)))) (-1678 (((-420 $) $) NIL (|has| |#1| (-365)))) (-1902 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1497 (((-121) $ $) NIL (|has| |#1| (-365)))) (-1974 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2786 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3728 (($ (-763) (-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|)))) NIL)) (-1990 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1941 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-1207 |#1| |#2| |#3|) "failed") $) 19) (((-3 (-1235 |#1| |#2| |#3|) "failed") $) 22)) (-2854 (((-1207 |#1| |#2| |#3|) $) NIL) (((-1235 |#1| |#2| |#3|) $) NIL)) (-2401 (($ $ $) NIL (|has| |#1| (-365)))) (-2114 (($ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3533 (((-409 (-568)) $) 57)) (-2412 (($ $ $) NIL (|has| |#1| (-365)))) (-2075 (($ (-409 (-568)) (-1207 |#1| |#2| |#3|)) NIL)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-3927 (((-121) $) NIL (|has| |#1| (-365)))) (-3992 (((-121) $) NIL)) (-1897 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4477 (((-409 (-568)) $) NIL) (((-409 (-568)) $ (-409 (-568))) NIL)) (-2735 (((-121) $) NIL)) (-4044 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3536 (($ $ (-917)) NIL) (($ $ (-409 (-568))) NIL)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| (-409 (-568))) 29) (($ $ (-1075) (-409 (-568))) NIL) (($ $ (-634 (-1075)) (-634 (-409 (-568)))) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-4416 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-2495 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-3429 (((-1207 |#1| |#2| |#3|) $) 60)) (-3074 (((-3 (-1207 |#1| |#2| |#3|) "failed") $) NIL)) (-2070 (((-1207 |#1| |#2| |#3|) $) NIL)) (-4487 (((-1143) $) NIL)) (-2081 (($ $) NIL (|has| |#1| (-365)))) (-3837 (($ $) 38 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) NIL (-2198 (-12 (|has| |#1| (-15 -3837 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2055 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181))))) (($ $ (-1240 |#2|)) 39 (|has| |#1| (-43 (-409 (-568)))))) (-4022 (((-1108) $) NIL)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-365)))) (-2721 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-3848 (((-420 $) $) NIL (|has| |#1| (-365)))) (-4497 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) NIL (|has| |#1| (-365)))) (-1807 (($ $ (-409 (-568))) NIL)) (-2595 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-2344 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1892 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))))) (-2709 (((-763) $) NIL (|has| |#1| (-365)))) (-2779 ((|#1| $ (-409 (-568))) NIL) (($ $ $) NIL (|has| (-409 (-568)) (-1102)))) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) NIL (|has| |#1| (-365)))) (-4189 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) 36 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $ (-1240 |#2|)) 37)) (-3206 (((-409 (-568)) $) NIL)) (-1994 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1945 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1986 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1937 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1978 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2790 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1811 (($ $) NIL)) (-2745 (((-850) $) 87) (($ (-568)) NIL) (($ |#1|) NIL (|has| |#1| (-172))) (($ (-1207 |#1| |#2| |#3|)) 16) (($ (-1235 |#1| |#2| |#3|)) 17) (($ (-1240 |#2|)) 35) (($ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $) NIL (|has| |#1| (-558)))) (-2604 ((|#1| $ (-409 (-568))) NIL)) (-4371 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-4078 (((-763)) NIL)) (-1374 ((|#1| $) 12)) (-2006 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1958 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1998 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1949 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2014 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1966 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3996 ((|#1| $ (-409 (-568))) 62 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))) (|has| |#1| (-15 -2745 (|#1| (-1161))))))) (-4023 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1970 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2010 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1962 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2002 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1953 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (-3056 (($) 31 T CONST)) (-1556 (($) 26 T CONST)) (-3190 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) 33)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
-(((-1228 |#1| |#2| |#3|) (-13 (-1226 |#1| (-1207 |#1| |#2| |#3|)) (-1037 (-1235 |#1| |#2| |#3|)) (-10 -8 (-15 -2745 ($ (-1240 |#2|))) (-15 -4189 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -3837 ($ $ (-1240 |#2|))) |noBranch|))) (-1047) (-1161) |#1|) (T -1228)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1228 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-4189 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1228 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-3837 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1228 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3)))) 
-(-13 (-1226 |#1| (-1207 |#1| |#2| |#3|)) (-1037 (-1235 |#1| |#2| |#3|)) (-10 -8 (-15 -2745 ($ (-1240 |#2|))) (-15 -4189 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -3837 ($ $ (-1240 |#2|))) |noBranch|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 32)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL)) (-2227 (($ $) NIL)) (-1573 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 (-568) "failed") $) NIL (|has| (-1228 |#2| |#3| |#4|) (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| (-1228 |#2| |#3| |#4|) (-1037 (-409 (-568))))) (((-3 (-1228 |#2| |#3| |#4|) "failed") $) 20)) (-2854 (((-568) $) NIL (|has| (-1228 |#2| |#3| |#4|) (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| (-1228 |#2| |#3| |#4|) (-1037 (-409 (-568))))) (((-1228 |#2| |#3| |#4|) $) NIL)) (-2114 (($ $) 33)) (-2925 (((-3 $ "failed") $) 25)) (-3250 (($ $) NIL (|has| (-1228 |#2| |#3| |#4|) (-453)))) (-3088 (($ $ (-1228 |#2| |#3| |#4|) (-314 |#2| |#3| |#4|) $) NIL)) (-2735 (((-121) $) NIL)) (-4178 (((-763) $) 11)) (-3921 (((-121) $) NIL)) (-2047 (($ (-1228 |#2| |#3| |#4|) (-314 |#2| |#3| |#4|)) 23)) (-2144 (((-314 |#2| |#3| |#4|) $) NIL)) (-3842 (($ (-1 (-314 |#2| |#3| |#4|) (-314 |#2| |#3| |#4|)) $) NIL)) (-2795 (($ (-1 (-1228 |#2| |#3| |#4|) (-1228 |#2| |#3| |#4|)) $) NIL)) (-2620 (((-3 (-835 |#2|) "failed") $) 72)) (-2097 (($ $) NIL)) (-2102 (((-1228 |#2| |#3| |#4|) $) 18)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2086 (((-121) $) NIL)) (-2091 (((-1228 |#2| |#3| |#4|) $) NIL)) (-2595 (((-3 $ "failed") $ (-1228 |#2| |#3| |#4|)) NIL (|has| (-1228 |#2| |#3| |#4|) (-558))) (((-3 $ "failed") $ $) NIL)) (-3660 (((-3 (-2 (|:| |%term| (-2 (|:| |%coef| (-1228 |#2| |#3| |#4|)) (|:| |%expon| (-314 |#2| |#3| |#4|)) (|:| |%expTerms| (-634 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#2|)))))) (|:| |%type| (-1143))) "failed") $) 55)) (-3206 (((-314 |#2| |#3| |#4|) $) 14)) (-3367 (((-1228 |#2| |#3| |#4|) $) NIL (|has| (-1228 |#2| |#3| |#4|) (-453)))) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ (-1228 |#2| |#3| |#4|)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL (-2198 (|has| (-1228 |#2| |#3| |#4|) (-43 (-409 (-568)))) (|has| (-1228 |#2| |#3| |#4|) (-1037 (-409 (-568))))))) (-1302 (((-634 (-1228 |#2| |#3| |#4|)) $) NIL)) (-2604 (((-1228 |#2| |#3| |#4|) $ (-314 |#2| |#3| |#4|)) NIL)) (-4371 (((-3 $ "failed") $) NIL (|has| (-1228 |#2| |#3| |#4|) (-148)))) (-4078 (((-763)) NIL)) (-4171 (($ $ $ (-763)) NIL (|has| (-1228 |#2| |#3| |#4|) (-172)))) (-1826 (((-121) $ $) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 60 T CONST)) (-1556 (($) NIL T CONST)) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ (-1228 |#2| |#3| |#4|)) NIL (|has| (-1228 |#2| |#3| |#4|) (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-1228 |#2| |#3| |#4|)) NIL) (($ (-1228 |#2| |#3| |#4|) $) NIL) (($ (-409 (-568)) $) NIL (|has| (-1228 |#2| |#3| |#4|) (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| (-1228 |#2| |#3| |#4|) (-43 (-409 (-568))))))) 
-(((-1229 |#1| |#2| |#3| |#4|) (-13 (-324 (-1228 |#2| |#3| |#4|) (-314 |#2| |#3| |#4|)) (-558) (-10 -8 (-15 -2620 ((-3 (-835 |#2|) "failed") $)) (-15 -3660 ((-3 (-2 (|:| |%term| (-2 (|:| |%coef| (-1228 |#2| |#3| |#4|)) (|:| |%expon| (-314 |#2| |#3| |#4|)) (|:| |%expTerms| (-634 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#2|)))))) (|:| |%type| (-1143))) "failed") $)))) (-13 (-842) (-1037 (-568)) (-630 (-568)) (-453)) (-13 (-27) (-1181) (-432 |#1|)) (-1161) |#2|) (T -1229)) 
-((-2620 (*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-842) (-1037 (-568)) (-630 (-568)) (-453))) (-5 *2 (-835 *4)) (-5 *1 (-1229 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1181) (-432 *3))) (-14 *5 (-1161)) (-14 *6 *4))) (-3660 (*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-842) (-1037 (-568)) (-630 (-568)) (-453))) (-5 *2 (-2 (|:| |%term| (-2 (|:| |%coef| (-1228 *4 *5 *6)) (|:| |%expon| (-314 *4 *5 *6)) (|:| |%expTerms| (-634 (-2 (|:| |k| (-409 (-568))) (|:| |c| *4)))))) (|:| |%type| (-1143)))) (-5 *1 (-1229 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1181) (-432 *3))) (-14 *5 (-1161)) (-14 *6 *4)))) 
-(-13 (-324 (-1228 |#2| |#3| |#4|) (-314 |#2| |#3| |#4|)) (-558) (-10 -8 (-15 -2620 ((-3 (-835 |#2|) "failed") $)) (-15 -3660 ((-3 (-2 (|:| |%term| (-2 (|:| |%coef| (-1228 |#2| |#3| |#4|)) (|:| |%expon| (-314 |#2| |#3| |#4|)) (|:| |%expTerms| (-634 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#2|)))))) (|:| |%type| (-1143))) "failed") $)))) 
-((-2850 ((|#2| $) 28)) (-2235 ((|#2| $) 18)) (-2796 (($ $) 35)) (-3910 (($ $ (-568)) 63)) (-2510 (((-121) $ (-763)) 32)) (-1659 ((|#2| $ |#2|) 60)) (-2395 ((|#2| $ |#2|) 58)) (-2436 ((|#2| $ "value" |#2|) NIL) ((|#2| $ "first" |#2|) 51) (($ $ "rest" $) 55) ((|#2| $ "last" |#2|) 53)) (-3827 (($ $ (-634 $)) 59)) (-1679 ((|#2| $) 17)) (-3935 (($ $) NIL) (($ $ (-763)) 41)) (-2287 (((-634 $) $) 25)) (-1700 (((-121) $ $) 49)) (-1737 (((-121) $ (-763)) 31)) (-2166 (((-121) $ (-763)) 30)) (-1651 (((-121) $) 27)) (-4162 ((|#2| $) 23) (($ $ (-763)) 45)) (-2779 ((|#2| $ "value") NIL) ((|#2| $ "first") 10) (($ $ "rest") 16) ((|#2| $ "last") 13)) (-3790 (((-121) $) 21)) (-2340 (($ $) 38)) (-2714 (($ $) 64)) (-2775 (((-763) $) 40)) (-3335 (($ $) 39)) (-2768 (($ $ $) 57) (($ |#2| $) NIL)) (-4339 (((-634 $) $) 26)) (-1717 (((-121) $ $) 47)) (-1697 (((-763) $) 34))) 
-(((-1230 |#1| |#2|) (-10 -8 (-15 -3910 (|#1| |#1| (-568))) (-15 -2436 (|#2| |#1| "last" |#2|)) (-15 -2395 (|#2| |#1| |#2|)) (-15 -2436 (|#1| |#1| "rest" |#1|)) (-15 -2436 (|#2| |#1| "first" |#2|)) (-15 -2714 (|#1| |#1|)) (-15 -2340 (|#1| |#1|)) (-15 -2775 ((-763) |#1|)) (-15 -3335 (|#1| |#1|)) (-15 -2235 (|#2| |#1|)) (-15 -1679 (|#2| |#1|)) (-15 -2796 (|#1| |#1|)) (-15 -4162 (|#1| |#1| (-763))) (-15 -2779 (|#2| |#1| "last")) (-15 -4162 (|#2| |#1|)) (-15 -3935 (|#1| |#1| (-763))) (-15 -2779 (|#1| |#1| "rest")) (-15 -3935 (|#1| |#1|)) (-15 -2779 (|#2| |#1| "first")) (-15 -2768 (|#1| |#2| |#1|)) (-15 -2768 (|#1| |#1| |#1|)) (-15 -1659 (|#2| |#1| |#2|)) (-15 -2436 (|#2| |#1| "value" |#2|)) (-15 -3827 (|#1| |#1| (-634 |#1|))) (-15 -1700 ((-121) |#1| |#1|)) (-15 -3790 ((-121) |#1|)) (-15 -2779 (|#2| |#1| "value")) (-15 -2850 (|#2| |#1|)) (-15 -1651 ((-121) |#1|)) (-15 -2287 ((-634 |#1|) |#1|)) (-15 -4339 ((-634 |#1|) |#1|)) (-15 -1717 ((-121) |#1| |#1|)) (-15 -1697 ((-763) |#1|)) (-15 -2510 ((-121) |#1| (-763))) (-15 -1737 ((-121) |#1| (-763))) (-15 -2166 ((-121) |#1| (-763)))) (-1231 |#2|) (-1195)) (T -1230)) 
-NIL 
-(-10 -8 (-15 -3910 (|#1| |#1| (-568))) (-15 -2436 (|#2| |#1| "last" |#2|)) (-15 -2395 (|#2| |#1| |#2|)) (-15 -2436 (|#1| |#1| "rest" |#1|)) (-15 -2436 (|#2| |#1| "first" |#2|)) (-15 -2714 (|#1| |#1|)) (-15 -2340 (|#1| |#1|)) (-15 -2775 ((-763) |#1|)) (-15 -3335 (|#1| |#1|)) (-15 -2235 (|#2| |#1|)) (-15 -1679 (|#2| |#1|)) (-15 -2796 (|#1| |#1|)) (-15 -4162 (|#1| |#1| (-763))) (-15 -2779 (|#2| |#1| "last")) (-15 -4162 (|#2| |#1|)) (-15 -3935 (|#1| |#1| (-763))) (-15 -2779 (|#1| |#1| "rest")) (-15 -3935 (|#1| |#1|)) (-15 -2779 (|#2| |#1| "first")) (-15 -2768 (|#1| |#2| |#1|)) (-15 -2768 (|#1| |#1| |#1|)) (-15 -1659 (|#2| |#1| |#2|)) (-15 -2436 (|#2| |#1| "value" |#2|)) (-15 -3827 (|#1| |#1| (-634 |#1|))) (-15 -1700 ((-121) |#1| |#1|)) (-15 -3790 ((-121) |#1|)) (-15 -2779 (|#2| |#1| "value")) (-15 -2850 (|#2| |#1|)) (-15 -1651 ((-121) |#1|)) (-15 -2287 ((-634 |#1|) |#1|)) (-15 -4339 ((-634 |#1|) |#1|)) (-15 -1717 ((-121) |#1| |#1|)) (-15 -1697 ((-763) |#1|)) (-15 -2510 ((-121) |#1| (-763))) (-15 -1737 ((-121) |#1| (-763))) (-15 -2166 ((-121) |#1| (-763)))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2850 ((|#1| $) 45)) (-2235 ((|#1| $) 62)) (-2796 (($ $) 64)) (-3910 (($ $ (-568)) 49 (|has| $ (-6 -4520)))) (-2510 (((-121) $ (-763)) 8)) (-1659 ((|#1| $ |#1|) 36 (|has| $ (-6 -4520)))) (-3869 (($ $ $) 53 (|has| $ (-6 -4520)))) (-2395 ((|#1| $ |#1|) 51 (|has| $ (-6 -4520)))) (-2517 ((|#1| $ |#1|) 55 (|has| $ (-6 -4520)))) (-2436 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4520))) ((|#1| $ "first" |#1|) 54 (|has| $ (-6 -4520))) (($ $ "rest" $) 52 (|has| $ (-6 -4520))) ((|#1| $ "last" |#1|) 50 (|has| $ (-6 -4520)))) (-3827 (($ $ (-634 $)) 38 (|has| $ (-6 -4520)))) (-1679 ((|#1| $) 63)) (-2671 (($) 7 T CONST)) (-3935 (($ $) 70) (($ $ (-763)) 68)) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-2287 (((-634 $) $) 47)) (-1700 (((-121) $ $) 39 (|has| |#1| (-1090)))) (-1737 (((-121) $ (-763)) 9)) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35)) (-2166 (((-121) $ (-763)) 10)) (-2869 (((-634 |#1|) $) 42)) (-1651 (((-121) $) 46)) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4162 ((|#1| $) 67) (($ $ (-763)) 65)) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3876 ((|#1| $) 73) (($ $ (-763)) 71)) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 ((|#1| $ "value") 44) ((|#1| $ "first") 72) (($ $ "rest") 69) ((|#1| $ "last") 66)) (-4075 (((-568) $ $) 41)) (-3790 (((-121) $) 43)) (-2340 (($ $) 59)) (-2714 (($ $) 56 (|has| $ (-6 -4520)))) (-2775 (((-763) $) 60)) (-3335 (($ $) 61)) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-3863 (($ $) 13)) (-3845 (($ $ $) 58 (|has| $ (-6 -4520))) (($ $ |#1|) 57 (|has| $ (-6 -4520)))) (-2768 (($ $ $) 75) (($ |#1| $) 74)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-4339 (((-634 $) $) 48)) (-3491 (((-121) $ $) 40 (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2057 (((-634 (-1075)) $) NIL)) (-3325 (((-1161) $) 11)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) NIL (|has| |#1| (-558)))) (-4179 (($ $ (-409 (-568))) NIL) (($ $ (-409 (-568)) (-409 (-568))) NIL)) (-2013 (((-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|))) $) NIL)) (-1984 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1935 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2689 (((-3 $ "failed") $ $) NIL)) (-3045 (($ $) NIL (|has| |#1| (-365)))) (-3498 (((-420 $) $) NIL (|has| |#1| (-365)))) (-1904 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2589 (((-121) $ $) NIL (|has| |#1| (-365)))) (-1976 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2788 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2512 (($ (-763) (-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#1|)))) NIL)) (-1992 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1943 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-1207 |#1| |#2| |#3|) "failed") $) 19) (((-3 (-1235 |#1| |#2| |#3|) "failed") $) 22)) (-2857 (((-1207 |#1| |#2| |#3|) $) NIL) (((-1235 |#1| |#2| |#3|) $) NIL)) (-2403 (($ $ $) NIL (|has| |#1| (-365)))) (-2116 (($ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-4147 (((-409 (-568)) $) 57)) (-2414 (($ $ $) NIL (|has| |#1| (-365)))) (-2077 (($ (-409 (-568)) (-1207 |#1| |#2| |#3|)) NIL)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) NIL (|has| |#1| (-365)))) (-2197 (((-121) $) NIL (|has| |#1| (-365)))) (-1302 (((-121) $) NIL)) (-1899 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1844 (((-409 (-568)) $) NIL) (((-409 (-568)) $ (-409 (-568))) NIL)) (-1598 (((-121) $) NIL)) (-1550 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4168 (($ $ (-917)) NIL) (($ $ (-409 (-568))) NIL)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| (-409 (-568))) 29) (($ $ (-1075) (-409 (-568))) NIL) (($ $ (-634 (-1075)) (-634 (-409 (-568)))) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-4418 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-2498 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-3408 (((-1207 |#1| |#2| |#3|) $) 60)) (-2380 (((-3 (-1207 |#1| |#2| |#3|) "failed") $) NIL)) (-2072 (((-1207 |#1| |#2| |#3|) $) NIL)) (-1893 (((-1143) $) NIL)) (-2083 (($ $) NIL (|has| |#1| (-365)))) (-1845 (($ $) 38 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) NIL (-2199 (-12 (|has| |#1| (-15 -1845 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2057 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181))))) (($ $ (-1240 |#2|)) 39 (|has| |#1| (-43 (-409 (-568)))))) (-4025 (((-1108) $) NIL)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) NIL (|has| |#1| (-365)))) (-2723 (($ (-634 $)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-3850 (((-420 $) $) NIL (|has| |#1| (-365)))) (-3833 (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) NIL (|has| |#1| (-365))) (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) NIL (|has| |#1| (-365)))) (-2168 (($ $ (-409 (-568))) NIL)) (-2597 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-3922 (((-3 (-634 $) "failed") (-634 $) $) NIL (|has| |#1| (-365)))) (-1894 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) NIL (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))))) (-1466 (((-763) $) NIL (|has| |#1| (-365)))) (-2781 ((|#1| $ (-409 (-568))) NIL) (($ $ $) NIL (|has| (-409 (-568)) (-1102)))) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) NIL (|has| |#1| (-365)))) (-4191 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) 36 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $ (-1240 |#2|)) 37)) (-1836 (((-409 (-568)) $) NIL)) (-1996 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1947 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1988 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1939 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1980 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2792 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2188 (($ $) NIL)) (-2747 (((-850) $) 87) (($ (-568)) NIL) (($ |#1|) NIL (|has| |#1| (-172))) (($ (-1207 |#1| |#2| |#3|)) 16) (($ (-1235 |#1| |#2| |#3|)) 17) (($ (-1240 |#2|)) 35) (($ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $) NIL (|has| |#1| (-558)))) (-2079 ((|#1| $ (-409 (-568))) NIL)) (-3385 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-3425 (((-763)) NIL)) (-1374 ((|#1| $) 12)) (-2008 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1959 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2000 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1951 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2016 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1968 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3999 ((|#1| $ (-409 (-568))) 62 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-409 (-568))))) (|has| |#1| (-15 -2747 (|#1| (-1161))))))) (-1439 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1972 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2012 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1964 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2004 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1955 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365)))) (-3058 (($) 31 T CONST)) (-1557 (($) 26 T CONST)) (-3192 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-409 (-568)) |#1|))))) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) 33)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ (-568)) NIL (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
+(((-1228 |#1| |#2| |#3|) (-13 (-1226 |#1| (-1207 |#1| |#2| |#3|)) (-1037 (-1235 |#1| |#2| |#3|)) (-10 -8 (-15 -2747 ($ (-1240 |#2|))) (-15 -4191 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -1845 ($ $ (-1240 |#2|))) |noBranch|))) (-1047) (-1161) |#1|) (T -1228)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1228 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-4191 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1228 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-1845 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1228 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3)))) 
+(-13 (-1226 |#1| (-1207 |#1| |#2| |#3|)) (-1037 (-1235 |#1| |#2| |#3|)) (-10 -8 (-15 -2747 ($ (-1240 |#2|))) (-15 -4191 ($ $ (-1240 |#2|))) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -1845 ($ $ (-1240 |#2|))) |noBranch|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 32)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL)) (-3661 (($ $) NIL)) (-4426 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 (-568) "failed") $) NIL (|has| (-1228 |#2| |#3| |#4|) (-1037 (-568)))) (((-3 (-409 (-568)) "failed") $) NIL (|has| (-1228 |#2| |#3| |#4|) (-1037 (-409 (-568))))) (((-3 (-1228 |#2| |#3| |#4|) "failed") $) 20)) (-2857 (((-568) $) NIL (|has| (-1228 |#2| |#3| |#4|) (-1037 (-568)))) (((-409 (-568)) $) NIL (|has| (-1228 |#2| |#3| |#4|) (-1037 (-409 (-568))))) (((-1228 |#2| |#3| |#4|) $) NIL)) (-2116 (($ $) 33)) (-2902 (((-3 $ "failed") $) 25)) (-1998 (($ $) NIL (|has| (-1228 |#2| |#3| |#4|) (-453)))) (-2453 (($ $ (-1228 |#2| |#3| |#4|) (-314 |#2| |#3| |#4|) $) NIL)) (-1598 (((-121) $) NIL)) (-3971 (((-763) $) 11)) (-2171 (((-121) $) NIL)) (-2049 (($ (-1228 |#2| |#3| |#4|) (-314 |#2| |#3| |#4|)) 23)) (-3524 (((-314 |#2| |#3| |#4|) $) NIL)) (-1865 (($ (-1 (-314 |#2| |#3| |#4|) (-314 |#2| |#3| |#4|)) $) NIL)) (-2797 (($ (-1 (-1228 |#2| |#3| |#4|) (-1228 |#2| |#3| |#4|)) $) NIL)) (-4200 (((-3 (-835 |#2|) "failed") $) 72)) (-2099 (($ $) NIL)) (-2104 (((-1228 |#2| |#3| |#4|) $) 18)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2088 (((-121) $) NIL)) (-2093 (((-1228 |#2| |#3| |#4|) $) NIL)) (-2597 (((-3 $ "failed") $ (-1228 |#2| |#3| |#4|)) NIL (|has| (-1228 |#2| |#3| |#4|) (-558))) (((-3 $ "failed") $ $) NIL)) (-3323 (((-3 (-2 (|:| |%term| (-2 (|:| |%coef| (-1228 |#2| |#3| |#4|)) (|:| |%expon| (-314 |#2| |#3| |#4|)) (|:| |%expTerms| (-634 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#2|)))))) (|:| |%type| (-1143))) "failed") $) 55)) (-1836 (((-314 |#2| |#3| |#4|) $) 14)) (-1364 (((-1228 |#2| |#3| |#4|) $) NIL (|has| (-1228 |#2| |#3| |#4|) (-453)))) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ (-1228 |#2| |#3| |#4|)) NIL) (($ $) NIL) (($ (-409 (-568))) NIL (-2199 (|has| (-1228 |#2| |#3| |#4|) (-43 (-409 (-568)))) (|has| (-1228 |#2| |#3| |#4|) (-1037 (-409 (-568))))))) (-3304 (((-634 (-1228 |#2| |#3| |#4|)) $) NIL)) (-2079 (((-1228 |#2| |#3| |#4|) $ (-314 |#2| |#3| |#4|)) NIL)) (-3385 (((-3 $ "failed") $) NIL (|has| (-1228 |#2| |#3| |#4|) (-148)))) (-3425 (((-763)) NIL)) (-3925 (($ $ $ (-763)) NIL (|has| (-1228 |#2| |#3| |#4|) (-172)))) (-2273 (((-121) $ $) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 60 T CONST)) (-1557 (($) NIL T CONST)) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ (-1228 |#2| |#3| |#4|)) NIL (|has| (-1228 |#2| |#3| |#4|) (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ (-1228 |#2| |#3| |#4|)) NIL) (($ (-1228 |#2| |#3| |#4|) $) NIL) (($ (-409 (-568)) $) NIL (|has| (-1228 |#2| |#3| |#4|) (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| (-1228 |#2| |#3| |#4|) (-43 (-409 (-568))))))) 
+(((-1229 |#1| |#2| |#3| |#4|) (-13 (-324 (-1228 |#2| |#3| |#4|) (-314 |#2| |#3| |#4|)) (-558) (-10 -8 (-15 -4200 ((-3 (-835 |#2|) "failed") $)) (-15 -3323 ((-3 (-2 (|:| |%term| (-2 (|:| |%coef| (-1228 |#2| |#3| |#4|)) (|:| |%expon| (-314 |#2| |#3| |#4|)) (|:| |%expTerms| (-634 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#2|)))))) (|:| |%type| (-1143))) "failed") $)))) (-13 (-842) (-1037 (-568)) (-630 (-568)) (-453)) (-13 (-27) (-1181) (-432 |#1|)) (-1161) |#2|) (T -1229)) 
+((-4200 (*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-842) (-1037 (-568)) (-630 (-568)) (-453))) (-5 *2 (-835 *4)) (-5 *1 (-1229 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1181) (-432 *3))) (-14 *5 (-1161)) (-14 *6 *4))) (-3323 (*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-842) (-1037 (-568)) (-630 (-568)) (-453))) (-5 *2 (-2 (|:| |%term| (-2 (|:| |%coef| (-1228 *4 *5 *6)) (|:| |%expon| (-314 *4 *5 *6)) (|:| |%expTerms| (-634 (-2 (|:| |k| (-409 (-568))) (|:| |c| *4)))))) (|:| |%type| (-1143)))) (-5 *1 (-1229 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1181) (-432 *3))) (-14 *5 (-1161)) (-14 *6 *4)))) 
+(-13 (-324 (-1228 |#2| |#3| |#4|) (-314 |#2| |#3| |#4|)) (-558) (-10 -8 (-15 -4200 ((-3 (-835 |#2|) "failed") $)) (-15 -3323 ((-3 (-2 (|:| |%term| (-2 (|:| |%coef| (-1228 |#2| |#3| |#4|)) (|:| |%expon| (-314 |#2| |#3| |#4|)) (|:| |%expTerms| (-634 (-2 (|:| |k| (-409 (-568))) (|:| |c| |#2|)))))) (|:| |%type| (-1143))) "failed") $)))) 
+((-2852 ((|#2| $) 28)) (-2237 ((|#2| $) 18)) (-3623 (($ $) 35)) (-2121 (($ $ (-568)) 63)) (-1667 (((-121) $ (-763)) 32)) (-3370 ((|#2| $ |#2|) 60)) (-2257 ((|#2| $ |#2|) 58)) (-2438 ((|#2| $ "value" |#2|) NIL) ((|#2| $ "first" |#2|) 51) (($ $ "rest" $) 55) ((|#2| $ "last" |#2|) 53)) (-1809 (($ $ (-634 $)) 59)) (-1681 ((|#2| $) 17)) (-3936 (($ $) NIL) (($ $ (-763)) 41)) (-3534 (((-634 $) $) 25)) (-3606 (((-121) $ $) 49)) (-3791 (((-121) $ (-763)) 31)) (-3796 (((-121) $ (-763)) 30)) (-3319 (((-121) $) 27)) (-4164 ((|#2| $) 23) (($ $ (-763)) 45)) (-2781 ((|#2| $ "value") NIL) ((|#2| $ "first") 10) (($ $ "rest") 16) ((|#2| $ "last") 13)) (-2763 (((-121) $) 21)) (-3903 (($ $) 38)) (-1499 (($ $) 64)) (-3535 (((-763) $) 40)) (-4424 (($ $) 39)) (-2770 (($ $ $) 57) (($ |#2| $) NIL)) (-3180 (((-634 $) $) 26)) (-1719 (((-121) $ $) 47)) (-1699 (((-763) $) 34))) 
+(((-1230 |#1| |#2|) (-10 -8 (-15 -2121 (|#1| |#1| (-568))) (-15 -2438 (|#2| |#1| "last" |#2|)) (-15 -2257 (|#2| |#1| |#2|)) (-15 -2438 (|#1| |#1| "rest" |#1|)) (-15 -2438 (|#2| |#1| "first" |#2|)) (-15 -1499 (|#1| |#1|)) (-15 -3903 (|#1| |#1|)) (-15 -3535 ((-763) |#1|)) (-15 -4424 (|#1| |#1|)) (-15 -2237 (|#2| |#1|)) (-15 -1681 (|#2| |#1|)) (-15 -3623 (|#1| |#1|)) (-15 -4164 (|#1| |#1| (-763))) (-15 -2781 (|#2| |#1| "last")) (-15 -4164 (|#2| |#1|)) (-15 -3936 (|#1| |#1| (-763))) (-15 -2781 (|#1| |#1| "rest")) (-15 -3936 (|#1| |#1|)) (-15 -2781 (|#2| |#1| "first")) (-15 -2770 (|#1| |#2| |#1|)) (-15 -2770 (|#1| |#1| |#1|)) (-15 -3370 (|#2| |#1| |#2|)) (-15 -2438 (|#2| |#1| "value" |#2|)) (-15 -1809 (|#1| |#1| (-634 |#1|))) (-15 -3606 ((-121) |#1| |#1|)) (-15 -2763 ((-121) |#1|)) (-15 -2781 (|#2| |#1| "value")) (-15 -2852 (|#2| |#1|)) (-15 -3319 ((-121) |#1|)) (-15 -3534 ((-634 |#1|) |#1|)) (-15 -3180 ((-634 |#1|) |#1|)) (-15 -1719 ((-121) |#1| |#1|)) (-15 -1699 ((-763) |#1|)) (-15 -1667 ((-121) |#1| (-763))) (-15 -3791 ((-121) |#1| (-763))) (-15 -3796 ((-121) |#1| (-763)))) (-1231 |#2|) (-1195)) (T -1230)) 
+NIL 
+(-10 -8 (-15 -2121 (|#1| |#1| (-568))) (-15 -2438 (|#2| |#1| "last" |#2|)) (-15 -2257 (|#2| |#1| |#2|)) (-15 -2438 (|#1| |#1| "rest" |#1|)) (-15 -2438 (|#2| |#1| "first" |#2|)) (-15 -1499 (|#1| |#1|)) (-15 -3903 (|#1| |#1|)) (-15 -3535 ((-763) |#1|)) (-15 -4424 (|#1| |#1|)) (-15 -2237 (|#2| |#1|)) (-15 -1681 (|#2| |#1|)) (-15 -3623 (|#1| |#1|)) (-15 -4164 (|#1| |#1| (-763))) (-15 -2781 (|#2| |#1| "last")) (-15 -4164 (|#2| |#1|)) (-15 -3936 (|#1| |#1| (-763))) (-15 -2781 (|#1| |#1| "rest")) (-15 -3936 (|#1| |#1|)) (-15 -2781 (|#2| |#1| "first")) (-15 -2770 (|#1| |#2| |#1|)) (-15 -2770 (|#1| |#1| |#1|)) (-15 -3370 (|#2| |#1| |#2|)) (-15 -2438 (|#2| |#1| "value" |#2|)) (-15 -1809 (|#1| |#1| (-634 |#1|))) (-15 -3606 ((-121) |#1| |#1|)) (-15 -2763 ((-121) |#1|)) (-15 -2781 (|#2| |#1| "value")) (-15 -2852 (|#2| |#1|)) (-15 -3319 ((-121) |#1|)) (-15 -3534 ((-634 |#1|) |#1|)) (-15 -3180 ((-634 |#1|) |#1|)) (-15 -1719 ((-121) |#1| |#1|)) (-15 -1699 ((-763) |#1|)) (-15 -1667 ((-121) |#1| (-763))) (-15 -3791 ((-121) |#1| (-763))) (-15 -3796 ((-121) |#1| (-763)))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-2852 ((|#1| $) 45)) (-2237 ((|#1| $) 62)) (-3623 (($ $) 64)) (-2121 (($ $ (-568)) 49 (|has| $ (-6 -4522)))) (-1667 (((-121) $ (-763)) 8)) (-3370 ((|#1| $ |#1|) 36 (|has| $ (-6 -4522)))) (-1958 (($ $ $) 53 (|has| $ (-6 -4522)))) (-2257 ((|#1| $ |#1|) 51 (|has| $ (-6 -4522)))) (-1706 ((|#1| $ |#1|) 55 (|has| $ (-6 -4522)))) (-2438 ((|#1| $ "value" |#1|) 37 (|has| $ (-6 -4522))) ((|#1| $ "first" |#1|) 54 (|has| $ (-6 -4522))) (($ $ "rest" $) 52 (|has| $ (-6 -4522))) ((|#1| $ "last" |#1|) 50 (|has| $ (-6 -4522)))) (-1809 (($ $ (-634 $)) 38 (|has| $ (-6 -4522)))) (-1681 ((|#1| $) 63)) (-4490 (($) 7 T CONST)) (-3936 (($ $) 70) (($ $ (-763)) 68)) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-3534 (((-634 $) $) 47)) (-3606 (((-121) $ $) 39 (|has| |#1| (-1090)))) (-3791 (((-121) $ (-763)) 9)) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35)) (-3796 (((-121) $ (-763)) 10)) (-4081 (((-634 |#1|) $) 42)) (-3319 (((-121) $) 46)) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4164 ((|#1| $) 67) (($ $ (-763)) 65)) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3877 ((|#1| $) 73) (($ $ (-763)) 71)) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 ((|#1| $ "value") 44) ((|#1| $ "first") 72) (($ $ "rest") 69) ((|#1| $ "last") 66)) (-1665 (((-568) $ $) 41)) (-2763 (((-121) $) 43)) (-3903 (($ $) 59)) (-1499 (($ $) 56 (|has| $ (-6 -4522)))) (-3535 (((-763) $) 60)) (-4424 (($ $) 61)) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3865 (($ $) 13)) (-1876 (($ $ $) 58 (|has| $ (-6 -4522))) (($ $ |#1|) 57 (|has| $ (-6 -4522)))) (-2770 (($ $ $) 75) (($ |#1| $) 74)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-3180 (((-634 $) $) 48)) (-3873 (((-121) $ $) 40 (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-1231 |#1|) (-1275) (-1195)) (T -1231)) 
-((-2768 (*1 *1 *1 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-2768 (*1 *1 *2 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-3876 (*1 *2 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-2779 (*1 *2 *1 *3) (-12 (-5 *3 "first") (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-3876 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1231 *3)) (-4 *3 (-1195)))) (-3935 (*1 *1 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-2779 (*1 *1 *1 *2) (-12 (-5 *2 "rest") (-4 *1 (-1231 *3)) (-4 *3 (-1195)))) (-3935 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1231 *3)) (-4 *3 (-1195)))) (-4162 (*1 *2 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-2779 (*1 *2 *1 *3) (-12 (-5 *3 "last") (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-4162 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1231 *3)) (-4 *3 (-1195)))) (-2796 (*1 *1 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-1679 (*1 *2 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-2235 (*1 *2 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-3335 (*1 *1 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-2775 (*1 *2 *1) (-12 (-4 *1 (-1231 *3)) (-4 *3 (-1195)) (-5 *2 (-763)))) (-2340 (*1 *1 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-3845 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-3845 (*1 *1 *1 *2) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-2714 (*1 *1 *1) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-2517 (*1 *2 *1 *2) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-2436 (*1 *2 *1 *3 *2) (-12 (-5 *3 "first") (|has| *1 (-6 -4520)) (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-3869 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-2436 (*1 *1 *1 *2 *1) (-12 (-5 *2 "rest") (|has| *1 (-6 -4520)) (-4 *1 (-1231 *3)) (-4 *3 (-1195)))) (-2395 (*1 *2 *1 *2) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-2436 (*1 *2 *1 *3 *2) (-12 (-5 *3 "last") (|has| *1 (-6 -4520)) (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-3910 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (|has| *1 (-6 -4520)) (-4 *1 (-1231 *3)) (-4 *3 (-1195))))) 
-(-13 (-1010 |t#1|) (-10 -8 (-15 -2768 ($ $ $)) (-15 -2768 ($ |t#1| $)) (-15 -3876 (|t#1| $)) (-15 -2779 (|t#1| $ "first")) (-15 -3876 ($ $ (-763))) (-15 -3935 ($ $)) (-15 -2779 ($ $ "rest")) (-15 -3935 ($ $ (-763))) (-15 -4162 (|t#1| $)) (-15 -2779 (|t#1| $ "last")) (-15 -4162 ($ $ (-763))) (-15 -2796 ($ $)) (-15 -1679 (|t#1| $)) (-15 -2235 (|t#1| $)) (-15 -3335 ($ $)) (-15 -2775 ((-763) $)) (-15 -2340 ($ $)) (IF (|has| $ (-6 -4520)) (PROGN (-15 -3845 ($ $ $)) (-15 -3845 ($ $ |t#1|)) (-15 -2714 ($ $)) (-15 -2517 (|t#1| $ |t#1|)) (-15 -2436 (|t#1| $ "first" |t#1|)) (-15 -3869 ($ $ $)) (-15 -2436 ($ $ "rest" $)) (-15 -2395 (|t#1| $ |t#1|)) (-15 -2436 (|t#1| $ "last" |t#1|)) (-15 -3910 ($ $ (-568)))) |noBranch|))) 
+((-2770 (*1 *1 *1 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-2770 (*1 *1 *2 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-3877 (*1 *2 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-2781 (*1 *2 *1 *3) (-12 (-5 *3 "first") (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-3877 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1231 *3)) (-4 *3 (-1195)))) (-3936 (*1 *1 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-2781 (*1 *1 *1 *2) (-12 (-5 *2 "rest") (-4 *1 (-1231 *3)) (-4 *3 (-1195)))) (-3936 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1231 *3)) (-4 *3 (-1195)))) (-4164 (*1 *2 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-2781 (*1 *2 *1 *3) (-12 (-5 *3 "last") (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-4164 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1231 *3)) (-4 *3 (-1195)))) (-3623 (*1 *1 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-1681 (*1 *2 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-2237 (*1 *2 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-4424 (*1 *1 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-3535 (*1 *2 *1) (-12 (-4 *1 (-1231 *3)) (-4 *3 (-1195)) (-5 *2 (-763)))) (-3903 (*1 *1 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-1876 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-1876 (*1 *1 *1 *2) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-1499 (*1 *1 *1) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-1706 (*1 *2 *1 *2) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-2438 (*1 *2 *1 *3 *2) (-12 (-5 *3 "first") (|has| *1 (-6 -4522)) (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-1958 (*1 *1 *1 *1) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-2438 (*1 *1 *1 *2 *1) (-12 (-5 *2 "rest") (|has| *1 (-6 -4522)) (-4 *1 (-1231 *3)) (-4 *3 (-1195)))) (-2257 (*1 *2 *1 *2) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-2438 (*1 *2 *1 *3 *2) (-12 (-5 *3 "last") (|has| *1 (-6 -4522)) (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) (-2121 (*1 *1 *1 *2) (-12 (-5 *2 (-568)) (|has| *1 (-6 -4522)) (-4 *1 (-1231 *3)) (-4 *3 (-1195))))) 
+(-13 (-1010 |t#1|) (-10 -8 (-15 -2770 ($ $ $)) (-15 -2770 ($ |t#1| $)) (-15 -3877 (|t#1| $)) (-15 -2781 (|t#1| $ "first")) (-15 -3877 ($ $ (-763))) (-15 -3936 ($ $)) (-15 -2781 ($ $ "rest")) (-15 -3936 ($ $ (-763))) (-15 -4164 (|t#1| $)) (-15 -2781 (|t#1| $ "last")) (-15 -4164 ($ $ (-763))) (-15 -3623 ($ $)) (-15 -1681 (|t#1| $)) (-15 -2237 (|t#1| $)) (-15 -4424 ($ $)) (-15 -3535 ((-763) $)) (-15 -3903 ($ $)) (IF (|has| $ (-6 -4522)) (PROGN (-15 -1876 ($ $ $)) (-15 -1876 ($ $ |t#1|)) (-15 -1499 ($ $)) (-15 -1706 (|t#1| $ |t#1|)) (-15 -2438 (|t#1| $ "first" |t#1|)) (-15 -1958 ($ $ $)) (-15 -2438 ($ $ "rest" $)) (-15 -2257 (|t#1| $ |t#1|)) (-15 -2438 (|t#1| $ "last" |t#1|)) (-15 -2121 ($ $ (-568)))) |noBranch|))) 
 (((-39) . T) ((-105) |has| |#1| (-1090)) ((-608 (-850)) |has| |#1| (-1090)) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-499 |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-1010 |#1|) . T) ((-1090) |has| |#1| (-1090)) ((-1195) . T)) 
-((-2795 ((|#4| (-1 |#2| |#1|) |#3|) 17))) 
-(((-1232 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2795 (|#4| (-1 |#2| |#1|) |#3|))) (-1047) (-1047) (-1234 |#1|) (-1234 |#2|)) (T -1232)) 
-((-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-4 *2 (-1234 *6)) (-5 *1 (-1232 *5 *6 *4 *2)) (-4 *4 (-1234 *5))))) 
-(-10 -7 (-15 -2795 (|#4| (-1 |#2| |#1|) |#3|))) 
-((-2537 (((-121) $) 15)) (-1982 (($ $) 90)) (-1933 (($ $) 66)) (-1974 (($ $) 86)) (-2786 (($ $) 62)) (-1990 (($ $) 94)) (-1941 (($ $) 70)) (-4416 (($ $) 60)) (-1892 (($ $) 58)) (-1994 (($ $) 96)) (-1945 (($ $) 72)) (-1986 (($ $) 92)) (-1937 (($ $) 68)) (-1978 (($ $) 88)) (-2790 (($ $) 64)) (-2745 (((-850) $) 46) (($ (-568)) NIL) (($ (-409 (-568))) NIL) (($ $) NIL) (($ |#2|) NIL)) (-2006 (($ $) 102)) (-1958 (($ $) 78)) (-1998 (($ $) 98)) (-1949 (($ $) 74)) (-2014 (($ $) 106)) (-1966 (($ $) 82)) (-4023 (($ $) 108)) (-1970 (($ $) 84)) (-2010 (($ $) 104)) (-1962 (($ $) 80)) (-2002 (($ $) 100)) (-1953 (($ $) 76)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ |#2|) 50) (($ $ $) 53) (($ $ (-409 (-568))) 56))) 
-(((-1233 |#1| |#2|) (-10 -8 (-15 ** (|#1| |#1| (-409 (-568)))) (-15 -1933 (|#1| |#1|)) (-15 -2786 (|#1| |#1|)) (-15 -1941 (|#1| |#1|)) (-15 -1945 (|#1| |#1|)) (-15 -1937 (|#1| |#1|)) (-15 -2790 (|#1| |#1|)) (-15 -1953 (|#1| |#1|)) (-15 -1962 (|#1| |#1|)) (-15 -1970 (|#1| |#1|)) (-15 -1966 (|#1| |#1|)) (-15 -1949 (|#1| |#1|)) (-15 -1958 (|#1| |#1|)) (-15 -1978 (|#1| |#1|)) (-15 -1986 (|#1| |#1|)) (-15 -1994 (|#1| |#1|)) (-15 -1990 (|#1| |#1|)) (-15 -1974 (|#1| |#1|)) (-15 -1982 (|#1| |#1|)) (-15 -2002 (|#1| |#1|)) (-15 -2010 (|#1| |#1|)) (-15 -4023 (|#1| |#1|)) (-15 -2014 (|#1| |#1|)) (-15 -1998 (|#1| |#1|)) (-15 -2006 (|#1| |#1|)) (-15 -4416 (|#1| |#1|)) (-15 -1892 (|#1| |#1|)) (-15 ** (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| |#2|)) (-15 -2745 (|#1| |#2|)) (-15 -2745 (|#1| |#1|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -2745 (|#1| (-568))) (-15 ** (|#1| |#1| (-763))) (-15 ** (|#1| |#1| (-917))) (-15 -2537 ((-121) |#1|)) (-15 -2745 ((-850) |#1|))) (-1234 |#2|) (-1047)) (T -1233)) 
-NIL 
-(-10 -8 (-15 ** (|#1| |#1| (-409 (-568)))) (-15 -1933 (|#1| |#1|)) (-15 -2786 (|#1| |#1|)) (-15 -1941 (|#1| |#1|)) (-15 -1945 (|#1| |#1|)) (-15 -1937 (|#1| |#1|)) (-15 -2790 (|#1| |#1|)) (-15 -1953 (|#1| |#1|)) (-15 -1962 (|#1| |#1|)) (-15 -1970 (|#1| |#1|)) (-15 -1966 (|#1| |#1|)) (-15 -1949 (|#1| |#1|)) (-15 -1958 (|#1| |#1|)) (-15 -1978 (|#1| |#1|)) (-15 -1986 (|#1| |#1|)) (-15 -1994 (|#1| |#1|)) (-15 -1990 (|#1| |#1|)) (-15 -1974 (|#1| |#1|)) (-15 -1982 (|#1| |#1|)) (-15 -2002 (|#1| |#1|)) (-15 -2010 (|#1| |#1|)) (-15 -4023 (|#1| |#1|)) (-15 -2014 (|#1| |#1|)) (-15 -1998 (|#1| |#1|)) (-15 -2006 (|#1| |#1|)) (-15 -4416 (|#1| |#1|)) (-15 -1892 (|#1| |#1|)) (-15 ** (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| |#2|)) (-15 -2745 (|#1| |#2|)) (-15 -2745 (|#1| |#1|)) (-15 -2745 (|#1| (-409 (-568)))) (-15 -2745 (|#1| (-568))) (-15 ** (|#1| |#1| (-763))) (-15 ** (|#1| |#1| (-917))) (-15 -2537 ((-121) |#1|)) (-15 -2745 ((-850) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-2055 (((-634 (-1075)) $) 70)) (-1305 (((-1161) $) 98)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 50 (|has| |#1| (-558)))) (-2227 (($ $) 51 (|has| |#1| (-558)))) (-1573 (((-121) $) 53 (|has| |#1| (-558)))) (-2617 (($ $ (-763)) 93) (($ $ (-763) (-763)) 92)) (-2583 (((-1141 (-2 (|:| |k| (-763)) (|:| |c| |#1|))) $) 100)) (-1982 (($ $) 127 (|has| |#1| (-43 (-409 (-568)))))) (-1933 (($ $) 110 (|has| |#1| (-43 (-409 (-568)))))) (-3134 (((-3 $ "failed") $ $) 18)) (-1902 (($ $) 109 (|has| |#1| (-43 (-409 (-568)))))) (-1974 (($ $) 126 (|has| |#1| (-43 (-409 (-568)))))) (-2786 (($ $) 111 (|has| |#1| (-43 (-409 (-568)))))) (-3728 (($ (-1141 (-2 (|:| |k| (-763)) (|:| |c| |#1|)))) 147) (($ (-1141 |#1|)) 145)) (-1990 (($ $) 125 (|has| |#1| (-43 (-409 (-568)))))) (-1941 (($ $) 112 (|has| |#1| (-43 (-409 (-568)))))) (-2671 (($) 16 T CONST)) (-2114 (($ $) 59)) (-2925 (((-3 $ "failed") $) 33)) (-3490 (($ $) 144)) (-1367 (((-953 |#1|) $ (-763)) 142) (((-953 |#1|) $ (-763) (-763)) 141)) (-3992 (((-121) $) 69)) (-1897 (($) 137 (|has| |#1| (-43 (-409 (-568)))))) (-4477 (((-763) $) 95) (((-763) $ (-763)) 94)) (-2735 (((-121) $) 30)) (-4044 (($ $ (-568)) 108 (|has| |#1| (-43 (-409 (-568)))))) (-3536 (($ $ (-917)) 96)) (-1716 (($ (-1 |#1| (-568)) $) 143)) (-3921 (((-121) $) 61)) (-2047 (($ |#1| (-763)) 60) (($ $ (-1075) (-763)) 72) (($ $ (-634 (-1075)) (-634 (-763))) 71)) (-2795 (($ (-1 |#1| |#1|) $) 62)) (-4416 (($ $) 134 (|has| |#1| (-43 (-409 (-568)))))) (-2097 (($ $) 64)) (-2102 ((|#1| $) 65)) (-4487 (((-1143) $) 9)) (-3837 (($ $) 139 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) 138 (-2198 (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-959)) (|has| |#1| (-1181)) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-15 -2055 ((-634 (-1161)) |#1|))) (|has| |#1| (-15 -3837 (|#1| |#1| (-1161)))) (|has| |#1| (-43 (-409 (-568)))))))) (-4022 (((-1108) $) 10)) (-1807 (($ $ (-763)) 90)) (-2595 (((-3 $ "failed") $ $) 49 (|has| |#1| (-558)))) (-1892 (($ $) 135 (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| (-763)))))) (-2779 ((|#1| $ (-763)) 99) (($ $ $) 76 (|has| (-763) (-1102)))) (-4189 (($ $ (-634 (-1161)) (-634 (-763))) 84 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (($ $ (-1161) (-763)) 83 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (($ $ (-634 (-1161))) 82 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (($ $ (-1161)) 81 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (($ $ (-763)) 79 (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $) 77 (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (-3206 (((-763) $) 63)) (-1994 (($ $) 124 (|has| |#1| (-43 (-409 (-568)))))) (-1945 (($ $) 113 (|has| |#1| (-43 (-409 (-568)))))) (-1986 (($ $) 123 (|has| |#1| (-43 (-409 (-568)))))) (-1937 (($ $) 114 (|has| |#1| (-43 (-409 (-568)))))) (-1978 (($ $) 122 (|has| |#1| (-43 (-409 (-568)))))) (-2790 (($ $) 115 (|has| |#1| (-43 (-409 (-568)))))) (-1811 (($ $) 68)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ (-409 (-568))) 56 (|has| |#1| (-43 (-409 (-568))))) (($ $) 48 (|has| |#1| (-558))) (($ |#1|) 46 (|has| |#1| (-172)))) (-1302 (((-1141 |#1|) $) 146)) (-2604 ((|#1| $ (-763)) 58)) (-4371 (((-3 $ "failed") $) 47 (|has| |#1| (-148)))) (-4078 (((-763)) 28)) (-1374 ((|#1| $) 97)) (-2006 (($ $) 133 (|has| |#1| (-43 (-409 (-568)))))) (-1958 (($ $) 121 (|has| |#1| (-43 (-409 (-568)))))) (-1826 (((-121) $ $) 52 (|has| |#1| (-558)))) (-1998 (($ $) 132 (|has| |#1| (-43 (-409 (-568)))))) (-1949 (($ $) 120 (|has| |#1| (-43 (-409 (-568)))))) (-2014 (($ $) 131 (|has| |#1| (-43 (-409 (-568)))))) (-1966 (($ $) 119 (|has| |#1| (-43 (-409 (-568)))))) (-3996 ((|#1| $ (-763)) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-763)))) (|has| |#1| (-15 -2745 (|#1| (-1161))))))) (-4023 (($ $) 130 (|has| |#1| (-43 (-409 (-568)))))) (-1970 (($ $) 118 (|has| |#1| (-43 (-409 (-568)))))) (-2010 (($ $) 129 (|has| |#1| (-43 (-409 (-568)))))) (-1962 (($ $) 117 (|has| |#1| (-43 (-409 (-568)))))) (-2002 (($ $) 128 (|has| |#1| (-43 (-409 (-568)))))) (-1953 (($ $) 116 (|has| |#1| (-43 (-409 (-568)))))) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-3190 (($ $ (-634 (-1161)) (-634 (-763))) 88 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (($ $ (-1161) (-763)) 87 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (($ $ (-634 (-1161))) 86 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (($ $ (-1161)) 85 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (($ $ (-763)) 80 (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $) 78 (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (-1717 (((-121) $ $) 6)) (-1779 (($ $ |#1|) 57 (|has| |#1| (-365)))) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ |#1|) 140 (|has| |#1| (-365))) (($ $ $) 136 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 107 (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-409 (-568)) $) 55 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 54 (|has| |#1| (-43 (-409 (-568))))))) 
+((-2797 ((|#4| (-1 |#2| |#1|) |#3|) 17))) 
+(((-1232 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2797 (|#4| (-1 |#2| |#1|) |#3|))) (-1047) (-1047) (-1234 |#1|) (-1234 |#2|)) (T -1232)) 
+((-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-4 *2 (-1234 *6)) (-5 *1 (-1232 *5 *6 *4 *2)) (-4 *4 (-1234 *5))))) 
+(-10 -7 (-15 -2797 (|#4| (-1 |#2| |#1|) |#3|))) 
+((-1819 (((-121) $) 15)) (-1984 (($ $) 90)) (-1935 (($ $) 66)) (-1976 (($ $) 86)) (-2788 (($ $) 62)) (-1992 (($ $) 94)) (-1943 (($ $) 70)) (-4418 (($ $) 60)) (-1894 (($ $) 58)) (-1996 (($ $) 96)) (-1947 (($ $) 72)) (-1988 (($ $) 92)) (-1939 (($ $) 68)) (-1980 (($ $) 88)) (-2792 (($ $) 64)) (-2747 (((-850) $) 46) (($ (-568)) NIL) (($ (-409 (-568))) NIL) (($ $) NIL) (($ |#2|) NIL)) (-2008 (($ $) 102)) (-1959 (($ $) 78)) (-2000 (($ $) 98)) (-1951 (($ $) 74)) (-2016 (($ $) 106)) (-1968 (($ $) 82)) (-1439 (($ $) 108)) (-1972 (($ $) 84)) (-2012 (($ $) 104)) (-1964 (($ $) 80)) (-2004 (($ $) 100)) (-1955 (($ $) 76)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ |#2|) 50) (($ $ $) 53) (($ $ (-409 (-568))) 56))) 
+(((-1233 |#1| |#2|) (-10 -8 (-15 ** (|#1| |#1| (-409 (-568)))) (-15 -1935 (|#1| |#1|)) (-15 -2788 (|#1| |#1|)) (-15 -1943 (|#1| |#1|)) (-15 -1947 (|#1| |#1|)) (-15 -1939 (|#1| |#1|)) (-15 -2792 (|#1| |#1|)) (-15 -1955 (|#1| |#1|)) (-15 -1964 (|#1| |#1|)) (-15 -1972 (|#1| |#1|)) (-15 -1968 (|#1| |#1|)) (-15 -1951 (|#1| |#1|)) (-15 -1959 (|#1| |#1|)) (-15 -1980 (|#1| |#1|)) (-15 -1988 (|#1| |#1|)) (-15 -1996 (|#1| |#1|)) (-15 -1992 (|#1| |#1|)) (-15 -1976 (|#1| |#1|)) (-15 -1984 (|#1| |#1|)) (-15 -2004 (|#1| |#1|)) (-15 -2012 (|#1| |#1|)) (-15 -1439 (|#1| |#1|)) (-15 -2016 (|#1| |#1|)) (-15 -2000 (|#1| |#1|)) (-15 -2008 (|#1| |#1|)) (-15 -4418 (|#1| |#1|)) (-15 -1894 (|#1| |#1|)) (-15 ** (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| |#2|)) (-15 -2747 (|#1| |#2|)) (-15 -2747 (|#1| |#1|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -2747 (|#1| (-568))) (-15 ** (|#1| |#1| (-763))) (-15 ** (|#1| |#1| (-917))) (-15 -1819 ((-121) |#1|)) (-15 -2747 ((-850) |#1|))) (-1234 |#2|) (-1047)) (T -1233)) 
+NIL 
+(-10 -8 (-15 ** (|#1| |#1| (-409 (-568)))) (-15 -1935 (|#1| |#1|)) (-15 -2788 (|#1| |#1|)) (-15 -1943 (|#1| |#1|)) (-15 -1947 (|#1| |#1|)) (-15 -1939 (|#1| |#1|)) (-15 -2792 (|#1| |#1|)) (-15 -1955 (|#1| |#1|)) (-15 -1964 (|#1| |#1|)) (-15 -1972 (|#1| |#1|)) (-15 -1968 (|#1| |#1|)) (-15 -1951 (|#1| |#1|)) (-15 -1959 (|#1| |#1|)) (-15 -1980 (|#1| |#1|)) (-15 -1988 (|#1| |#1|)) (-15 -1996 (|#1| |#1|)) (-15 -1992 (|#1| |#1|)) (-15 -1976 (|#1| |#1|)) (-15 -1984 (|#1| |#1|)) (-15 -2004 (|#1| |#1|)) (-15 -2012 (|#1| |#1|)) (-15 -1439 (|#1| |#1|)) (-15 -2016 (|#1| |#1|)) (-15 -2000 (|#1| |#1|)) (-15 -2008 (|#1| |#1|)) (-15 -4418 (|#1| |#1|)) (-15 -1894 (|#1| |#1|)) (-15 ** (|#1| |#1| |#1|)) (-15 ** (|#1| |#1| |#2|)) (-15 -2747 (|#1| |#2|)) (-15 -2747 (|#1| |#1|)) (-15 -2747 (|#1| (-409 (-568)))) (-15 -2747 (|#1| (-568))) (-15 ** (|#1| |#1| (-763))) (-15 ** (|#1| |#1| (-917))) (-15 -1819 ((-121) |#1|)) (-15 -2747 ((-850) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2057 (((-634 (-1075)) $) 70)) (-3325 (((-1161) $) 98)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 50 (|has| |#1| (-558)))) (-3661 (($ $) 51 (|has| |#1| (-558)))) (-4426 (((-121) $) 53 (|has| |#1| (-558)))) (-4179 (($ $ (-763)) 93) (($ $ (-763) (-763)) 92)) (-2013 (((-1141 (-2 (|:| |k| (-763)) (|:| |c| |#1|))) $) 100)) (-1984 (($ $) 127 (|has| |#1| (-43 (-409 (-568)))))) (-1935 (($ $) 110 (|has| |#1| (-43 (-409 (-568)))))) (-2689 (((-3 $ "failed") $ $) 18)) (-1904 (($ $) 109 (|has| |#1| (-43 (-409 (-568)))))) (-1976 (($ $) 126 (|has| |#1| (-43 (-409 (-568)))))) (-2788 (($ $) 111 (|has| |#1| (-43 (-409 (-568)))))) (-2512 (($ (-1141 (-2 (|:| |k| (-763)) (|:| |c| |#1|)))) 147) (($ (-1141 |#1|)) 145)) (-1992 (($ $) 125 (|has| |#1| (-43 (-409 (-568)))))) (-1943 (($ $) 112 (|has| |#1| (-43 (-409 (-568)))))) (-4490 (($) 16 T CONST)) (-2116 (($ $) 59)) (-2902 (((-3 $ "failed") $) 33)) (-3866 (($ $) 144)) (-3808 (((-953 |#1|) $ (-763)) 142) (((-953 |#1|) $ (-763) (-763)) 141)) (-1302 (((-121) $) 69)) (-1899 (($) 137 (|has| |#1| (-43 (-409 (-568)))))) (-1844 (((-763) $) 95) (((-763) $ (-763)) 94)) (-1598 (((-121) $) 30)) (-1550 (($ $ (-568)) 108 (|has| |#1| (-43 (-409 (-568)))))) (-4168 (($ $ (-917)) 96)) (-3698 (($ (-1 |#1| (-568)) $) 143)) (-2171 (((-121) $) 61)) (-2049 (($ |#1| (-763)) 60) (($ $ (-1075) (-763)) 72) (($ $ (-634 (-1075)) (-634 (-763))) 71)) (-2797 (($ (-1 |#1| |#1|) $) 62)) (-4418 (($ $) 134 (|has| |#1| (-43 (-409 (-568)))))) (-2099 (($ $) 64)) (-2104 ((|#1| $) 65)) (-1893 (((-1143) $) 9)) (-1845 (($ $) 139 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) 138 (-2199 (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-959)) (|has| |#1| (-1181)) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-15 -2057 ((-634 (-1161)) |#1|))) (|has| |#1| (-15 -1845 (|#1| |#1| (-1161)))) (|has| |#1| (-43 (-409 (-568)))))))) (-4025 (((-1108) $) 10)) (-2168 (($ $ (-763)) 90)) (-2597 (((-3 $ "failed") $ $) 49 (|has| |#1| (-558)))) (-1894 (($ $) 135 (|has| |#1| (-43 (-409 (-568)))))) (-1339 (((-1141 |#1|) $ |#1|) 89 (|has| |#1| (-15 ** (|#1| |#1| (-763)))))) (-2781 ((|#1| $ (-763)) 99) (($ $ $) 76 (|has| (-763) (-1102)))) (-4191 (($ $ (-634 (-1161)) (-634 (-763))) 84 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (($ $ (-1161) (-763)) 83 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (($ $ (-634 (-1161))) 82 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (($ $ (-1161)) 81 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (($ $ (-763)) 79 (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $) 77 (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (-1836 (((-763) $) 63)) (-1996 (($ $) 124 (|has| |#1| (-43 (-409 (-568)))))) (-1947 (($ $) 113 (|has| |#1| (-43 (-409 (-568)))))) (-1988 (($ $) 123 (|has| |#1| (-43 (-409 (-568)))))) (-1939 (($ $) 114 (|has| |#1| (-43 (-409 (-568)))))) (-1980 (($ $) 122 (|has| |#1| (-43 (-409 (-568)))))) (-2792 (($ $) 115 (|has| |#1| (-43 (-409 (-568)))))) (-2188 (($ $) 68)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ (-409 (-568))) 56 (|has| |#1| (-43 (-409 (-568))))) (($ $) 48 (|has| |#1| (-558))) (($ |#1|) 46 (|has| |#1| (-172)))) (-3304 (((-1141 |#1|) $) 146)) (-2079 ((|#1| $ (-763)) 58)) (-3385 (((-3 $ "failed") $) 47 (|has| |#1| (-148)))) (-3425 (((-763)) 28)) (-1374 ((|#1| $) 97)) (-2008 (($ $) 133 (|has| |#1| (-43 (-409 (-568)))))) (-1959 (($ $) 121 (|has| |#1| (-43 (-409 (-568)))))) (-2273 (((-121) $ $) 52 (|has| |#1| (-558)))) (-2000 (($ $) 132 (|has| |#1| (-43 (-409 (-568)))))) (-1951 (($ $) 120 (|has| |#1| (-43 (-409 (-568)))))) (-2016 (($ $) 131 (|has| |#1| (-43 (-409 (-568)))))) (-1968 (($ $) 119 (|has| |#1| (-43 (-409 (-568)))))) (-3999 ((|#1| $ (-763)) 91 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-763)))) (|has| |#1| (-15 -2747 (|#1| (-1161))))))) (-1439 (($ $) 130 (|has| |#1| (-43 (-409 (-568)))))) (-1972 (($ $) 118 (|has| |#1| (-43 (-409 (-568)))))) (-2012 (($ $) 129 (|has| |#1| (-43 (-409 (-568)))))) (-1964 (($ $) 117 (|has| |#1| (-43 (-409 (-568)))))) (-2004 (($ $) 128 (|has| |#1| (-43 (-409 (-568)))))) (-1955 (($ $) 116 (|has| |#1| (-43 (-409 (-568)))))) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3192 (($ $ (-634 (-1161)) (-634 (-763))) 88 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (($ $ (-1161) (-763)) 87 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (($ $ (-634 (-1161))) 86 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (($ $ (-1161)) 85 (-12 (|has| |#1| (-895 (-1161))) (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (($ $ (-763)) 80 (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $) 78 (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (-1719 (((-121) $ $) 6)) (-1781 (($ $ |#1|) 57 (|has| |#1| (-365)))) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ |#1|) 140 (|has| |#1| (-365))) (($ $ $) 136 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 107 (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 67) (($ |#1| $) 66) (($ (-409 (-568)) $) 55 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) 54 (|has| |#1| (-43 (-409 (-568))))))) 
 (((-1234 |#1|) (-1275) (-1047)) (T -1234)) 
-((-3728 (*1 *1 *2) (-12 (-5 *2 (-1141 (-2 (|:| |k| (-763)) (|:| |c| *3)))) (-4 *3 (-1047)) (-4 *1 (-1234 *3)))) (-1302 (*1 *2 *1) (-12 (-4 *1 (-1234 *3)) (-4 *3 (-1047)) (-5 *2 (-1141 *3)))) (-3728 (*1 *1 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-4 *1 (-1234 *3)))) (-3490 (*1 *1 *1) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1047)))) (-1716 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-568))) (-4 *1 (-1234 *3)) (-4 *3 (-1047)))) (-1367 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-1234 *4)) (-4 *4 (-1047)) (-5 *2 (-953 *4)))) (-1367 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-4 *1 (-1234 *4)) (-4 *4 (-1047)) (-5 *2 (-953 *4)))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-3837 (*1 *1 *1) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1047)) (-4 *2 (-43 (-409 (-568)))))) (-3837 (*1 *1 *1 *2) (-2198 (-12 (-5 *2 (-1161)) (-4 *1 (-1234 *3)) (-4 *3 (-1047)) (-12 (-4 *3 (-29 (-568))) (-4 *3 (-959)) (-4 *3 (-1181)) (-4 *3 (-43 (-409 (-568)))))) (-12 (-5 *2 (-1161)) (-4 *1 (-1234 *3)) (-4 *3 (-1047)) (-12 (|has| *3 (-15 -2055 ((-634 *2) *3))) (|has| *3 (-15 -3837 (*3 *3 *2))) (-4 *3 (-43 (-409 (-568))))))))) 
-(-13 (-1221 |t#1| (-763)) (-10 -8 (-15 -3728 ($ (-1141 (-2 (|:| |k| (-763)) (|:| |c| |t#1|))))) (-15 -1302 ((-1141 |t#1|) $)) (-15 -3728 ($ (-1141 |t#1|))) (-15 -3490 ($ $)) (-15 -1716 ($ (-1 |t#1| (-568)) $)) (-15 -1367 ((-953 |t#1|) $ (-763))) (-15 -1367 ((-953 |t#1|) $ (-763) (-763))) (IF (|has| |t#1| (-365)) (-15 ** ($ $ |t#1|)) |noBranch|) (IF (|has| |t#1| (-43 (-409 (-568)))) (PROGN (-15 -3837 ($ $)) (IF (|has| |t#1| (-15 -3837 (|t#1| |t#1| (-1161)))) (IF (|has| |t#1| (-15 -2055 ((-634 (-1161)) |t#1|))) (-15 -3837 ($ $ (-1161))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-1181)) (IF (|has| |t#1| (-959)) (IF (|has| |t#1| (-29 (-568))) (-15 -3837 ($ $ (-1161))) |noBranch|) |noBranch|) |noBranch|) (-6 (-1002)) (-6 (-1181))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-52 |#1| (-763)) . T) ((-25) . T) ((-43 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) |has| |#1| (-558)) ((-40) |has| |#1| (-43 (-409 (-568)))) ((-98) |has| |#1| (-43 (-409 (-568)))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2198 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2198 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-225) |has| |#1| (-15 * (|#1| (-763) |#1|))) ((-279) |has| |#1| (-43 (-409 (-568)))) ((-281 $ $) |has| (-763) (-1102)) ((-285) |has| |#1| (-558)) ((-502) |has| |#1| (-43 (-409 (-568)))) ((-558) |has| |#1| (-558)) ((-637 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) |has| |#1| (-558)) ((-716) . T) ((-895 (-1161)) -12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161)))) ((-974 |#1| (-763) (-1075)) . T) ((-1002) |has| |#1| (-43 (-409 (-568)))) ((-1053 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-1053 |#1|) . T) ((-1053 $) -2198 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1181) |has| |#1| (-43 (-409 (-568)))) ((-1184) |has| |#1| (-43 (-409 (-568)))) ((-1221 |#1| (-763)) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2055 (((-634 (-1075)) $) NIL)) (-1305 (((-1161) $) 86)) (-3196 (((-1216 |#2| |#1|) $ (-763)) 73)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) 135 (|has| |#1| (-558)))) (-2617 (($ $ (-763)) 120) (($ $ (-763) (-763)) 122)) (-2583 (((-1141 (-2 (|:| |k| (-763)) (|:| |c| |#1|))) $) 42)) (-1982 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1933 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3134 (((-3 $ "failed") $ $) NIL)) (-1902 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1974 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2786 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3728 (($ (-1141 (-2 (|:| |k| (-763)) (|:| |c| |#1|)))) 53) (($ (-1141 |#1|)) NIL)) (-1990 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1941 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2671 (($) NIL T CONST)) (-2129 (($ $) 126)) (-2114 (($ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3490 (($ $) 133)) (-1367 (((-953 |#1|) $ (-763)) 63) (((-953 |#1|) $ (-763) (-763)) 65)) (-3992 (((-121) $) NIL)) (-1897 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4477 (((-763) $) NIL) (((-763) $ (-763)) NIL)) (-2735 (((-121) $) NIL)) (-2011 (($ $) 110)) (-4044 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2651 (($ (-568) (-568) $) 128)) (-3536 (($ $ (-917)) 132)) (-1716 (($ (-1 |#1| (-568)) $) 104)) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| (-763)) 15) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-2795 (($ (-1 |#1| |#1|) $) 92)) (-4416 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-4487 (((-1143) $) NIL)) (-3730 (($ $) 108)) (-2608 (($ $) 106)) (-4053 (($ (-568) (-568) $) 130)) (-3837 (($ $) 143 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) 149 (-2198 (-12 (|has| |#1| (-15 -3837 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2055 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181))))) (($ $ (-1240 |#2|)) 144 (|has| |#1| (-43 (-409 (-568)))))) (-4022 (((-1108) $) NIL)) (-2224 (($ $ (-568) (-568)) 114)) (-1807 (($ $ (-763)) 116)) (-2595 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-1892 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2372 (($ $) 112)) (-1339 (((-1141 |#1|) $ |#1|) 94 (|has| |#1| (-15 ** (|#1| |#1| (-763)))))) (-2779 ((|#1| $ (-763)) 89) (($ $ $) 124 (|has| (-763) (-1102)))) (-4189 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) 101 (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $) 96 (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $ (-1240 |#2|)) 97)) (-3206 (((-763) $) NIL)) (-1994 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1945 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1986 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1937 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1978 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2790 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1811 (($ $) 118)) (-2745 (((-850) $) NIL) (($ (-568)) 24) (($ (-409 (-568))) 141 (|has| |#1| (-43 (-409 (-568))))) (($ $) NIL (|has| |#1| (-558))) (($ |#1|) 23 (|has| |#1| (-172))) (($ (-1216 |#2| |#1|)) 79) (($ (-1240 |#2|)) 20)) (-1302 (((-1141 |#1|) $) NIL)) (-2604 ((|#1| $ (-763)) 88)) (-4371 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-4078 (((-763)) NIL)) (-1374 ((|#1| $) 87)) (-2006 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1958 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1998 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1949 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2014 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1966 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3996 ((|#1| $ (-763)) 85 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-763)))) (|has| |#1| (-15 -2745 (|#1| (-1161))))))) (-4023 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1970 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2010 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1962 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2002 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1953 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 17 T CONST)) (-1556 (($) 13 T CONST)) (-3190 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) 100)) (-1767 (($ $ $) 18)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ |#1|) 138 (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) 99) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
-(((-1235 |#1| |#2| |#3|) (-13 (-1234 |#1|) (-10 -8 (-15 -2745 ($ (-1216 |#2| |#1|))) (-15 -3196 ((-1216 |#2| |#1|) $ (-763))) (-15 -2745 ($ (-1240 |#2|))) (-15 -4189 ($ $ (-1240 |#2|))) (-15 -2608 ($ $)) (-15 -3730 ($ $)) (-15 -2011 ($ $)) (-15 -2372 ($ $)) (-15 -2224 ($ $ (-568) (-568))) (-15 -2129 ($ $)) (-15 -2651 ($ (-568) (-568) $)) (-15 -4053 ($ (-568) (-568) $)) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -3837 ($ $ (-1240 |#2|))) |noBranch|))) (-1047) (-1161) |#1|) (T -1235)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1216 *4 *3)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3) (-5 *1 (-1235 *3 *4 *5)))) (-3196 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1216 *5 *4)) (-5 *1 (-1235 *4 *5 *6)) (-4 *4 (-1047)) (-14 *5 (-1161)) (-14 *6 *4))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-4189 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-2608 (*1 *1 *1) (-12 (-5 *1 (-1235 *2 *3 *4)) (-4 *2 (-1047)) (-14 *3 (-1161)) (-14 *4 *2))) (-3730 (*1 *1 *1) (-12 (-5 *1 (-1235 *2 *3 *4)) (-4 *2 (-1047)) (-14 *3 (-1161)) (-14 *4 *2))) (-2011 (*1 *1 *1) (-12 (-5 *1 (-1235 *2 *3 *4)) (-4 *2 (-1047)) (-14 *3 (-1161)) (-14 *4 *2))) (-2372 (*1 *1 *1) (-12 (-5 *1 (-1235 *2 *3 *4)) (-4 *2 (-1047)) (-14 *3 (-1161)) (-14 *4 *2))) (-2224 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3))) (-2129 (*1 *1 *1) (-12 (-5 *1 (-1235 *2 *3 *4)) (-4 *2 (-1047)) (-14 *3 (-1161)) (-14 *4 *2))) (-2651 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3))) (-4053 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3))) (-3837 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3)))) 
-(-13 (-1234 |#1|) (-10 -8 (-15 -2745 ($ (-1216 |#2| |#1|))) (-15 -3196 ((-1216 |#2| |#1|) $ (-763))) (-15 -2745 ($ (-1240 |#2|))) (-15 -4189 ($ $ (-1240 |#2|))) (-15 -2608 ($ $)) (-15 -3730 ($ $)) (-15 -2011 ($ $)) (-15 -2372 ($ $)) (-15 -2224 ($ $ (-568) (-568))) (-15 -2129 ($ $)) (-15 -2651 ($ (-568) (-568) $)) (-15 -4053 ($ (-568) (-568) $)) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -3837 ($ $ (-1240 |#2|))) |noBranch|))) 
-((-3118 (((-1 (-1141 |#1|) (-634 (-1141 |#1|))) (-1 |#2| (-634 |#2|))) 24)) (-1531 (((-1 (-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) (-1 |#2| |#2| |#2|)) 16)) (-1817 (((-1 (-1141 |#1|) (-1141 |#1|)) (-1 |#2| |#2|)) 13)) (-2565 ((|#2| (-1 |#2| |#2| |#2|) |#1| |#1|) 48)) (-1886 ((|#2| (-1 |#2| |#2|) |#1|) 46)) (-2765 ((|#2| (-1 |#2| (-634 |#2|)) (-634 |#1|)) 54)) (-1797 (((-634 |#2|) (-634 |#1|) (-634 (-1 |#2| (-634 |#2|)))) 61)) (-4398 ((|#2| |#2| |#2|) 43))) 
-(((-1236 |#1| |#2|) (-10 -7 (-15 -1817 ((-1 (-1141 |#1|) (-1141 |#1|)) (-1 |#2| |#2|))) (-15 -1531 ((-1 (-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) (-1 |#2| |#2| |#2|))) (-15 -3118 ((-1 (-1141 |#1|) (-634 (-1141 |#1|))) (-1 |#2| (-634 |#2|)))) (-15 -4398 (|#2| |#2| |#2|)) (-15 -1886 (|#2| (-1 |#2| |#2|) |#1|)) (-15 -2565 (|#2| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -2765 (|#2| (-1 |#2| (-634 |#2|)) (-634 |#1|))) (-15 -1797 ((-634 |#2|) (-634 |#1|) (-634 (-1 |#2| (-634 |#2|)))))) (-43 (-409 (-568))) (-1234 |#1|)) (T -1236)) 
-((-1797 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-1 *6 (-634 *6)))) (-4 *5 (-43 (-409 (-568)))) (-4 *6 (-1234 *5)) (-5 *2 (-634 *6)) (-5 *1 (-1236 *5 *6)))) (-2765 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 (-634 *2))) (-5 *4 (-634 *5)) (-4 *5 (-43 (-409 (-568)))) (-4 *2 (-1234 *5)) (-5 *1 (-1236 *5 *2)))) (-2565 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1234 *4)) (-5 *1 (-1236 *4 *2)) (-4 *4 (-43 (-409 (-568)))))) (-1886 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 *2)) (-4 *2 (-1234 *4)) (-5 *1 (-1236 *4 *2)) (-4 *4 (-43 (-409 (-568)))))) (-4398 (*1 *2 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1236 *3 *2)) (-4 *2 (-1234 *3)))) (-3118 (*1 *2 *3) (-12 (-5 *3 (-1 *5 (-634 *5))) (-4 *5 (-1234 *4)) (-4 *4 (-43 (-409 (-568)))) (-5 *2 (-1 (-1141 *4) (-634 (-1141 *4)))) (-5 *1 (-1236 *4 *5)))) (-1531 (*1 *2 *3) (-12 (-5 *3 (-1 *5 *5 *5)) (-4 *5 (-1234 *4)) (-4 *4 (-43 (-409 (-568)))) (-5 *2 (-1 (-1141 *4) (-1141 *4) (-1141 *4))) (-5 *1 (-1236 *4 *5)))) (-1817 (*1 *2 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-1234 *4)) (-4 *4 (-43 (-409 (-568)))) (-5 *2 (-1 (-1141 *4) (-1141 *4))) (-5 *1 (-1236 *4 *5))))) 
-(-10 -7 (-15 -1817 ((-1 (-1141 |#1|) (-1141 |#1|)) (-1 |#2| |#2|))) (-15 -1531 ((-1 (-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) (-1 |#2| |#2| |#2|))) (-15 -3118 ((-1 (-1141 |#1|) (-634 (-1141 |#1|))) (-1 |#2| (-634 |#2|)))) (-15 -4398 (|#2| |#2| |#2|)) (-15 -1886 (|#2| (-1 |#2| |#2|) |#1|)) (-15 -2565 (|#2| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -2765 (|#2| (-1 |#2| (-634 |#2|)) (-634 |#1|))) (-15 -1797 ((-634 |#2|) (-634 |#1|) (-634 (-1 |#2| (-634 |#2|)))))) 
-((-3462 ((|#2| |#4| (-763)) 30)) (-1905 ((|#4| |#2|) 25)) (-1512 ((|#4| (-409 |#2|)) 51 (|has| |#1| (-558)))) (-3068 (((-1 |#4| (-634 |#4|)) |#3|) 45))) 
-(((-1237 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -1905 (|#4| |#2|)) (-15 -3462 (|#2| |#4| (-763))) (-15 -3068 ((-1 |#4| (-634 |#4|)) |#3|)) (IF (|has| |#1| (-558)) (-15 -1512 (|#4| (-409 |#2|))) |noBranch|)) (-1047) (-1219 |#1|) (-646 |#2|) (-1234 |#1|)) (T -1237)) 
-((-1512 (*1 *2 *3) (-12 (-5 *3 (-409 *5)) (-4 *5 (-1219 *4)) (-4 *4 (-558)) (-4 *4 (-1047)) (-4 *2 (-1234 *4)) (-5 *1 (-1237 *4 *5 *6 *2)) (-4 *6 (-646 *5)))) (-3068 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-1219 *4)) (-5 *2 (-1 *6 (-634 *6))) (-5 *1 (-1237 *4 *5 *3 *6)) (-4 *3 (-646 *5)) (-4 *6 (-1234 *4)))) (-3462 (*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-1047)) (-4 *2 (-1219 *5)) (-5 *1 (-1237 *5 *2 *6 *3)) (-4 *6 (-646 *2)) (-4 *3 (-1234 *5)))) (-1905 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *3 (-1219 *4)) (-4 *2 (-1234 *4)) (-5 *1 (-1237 *4 *3 *5 *2)) (-4 *5 (-646 *3))))) 
-(-10 -7 (-15 -1905 (|#4| |#2|)) (-15 -3462 (|#2| |#4| (-763))) (-15 -3068 ((-1 |#4| (-634 |#4|)) |#3|)) (IF (|has| |#1| (-558)) (-15 -1512 (|#4| (-409 |#2|))) |noBranch|)) 
-((-4251 ((|#2| (-1 |#3| |#3|) (-634 |#1|)) 67))) 
-(((-1238 |#1| |#2| |#3|) (-10 -7 (-15 -4251 (|#2| (-1 |#3| |#3|) (-634 |#1|)))) (-365) (-1234 |#1|) (-1234 (-1155 |#1|))) (T -1238)) 
-((-4251 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *6)) (-5 *4 (-634 *5)) (-4 *5 (-365)) (-4 *6 (-1234 (-1155 *5))) (-4 *2 (-1234 *5)) (-5 *1 (-1238 *5 *2 *6))))) 
-(-10 -7 (-15 -4251 (|#2| (-1 |#3| |#3|) (-634 |#1|)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-2055 (((-634 (-1075)) $) NIL)) (-1305 (((-1161) $) 79)) (-3196 (((-1216 |#2| |#1|) $ (-763)) 68)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-2227 (($ $) NIL (|has| |#1| (-558)))) (-1573 (((-121) $) 128 (|has| |#1| (-558)))) (-2617 (($ $ (-763)) 113) (($ $ (-763) (-763)) 115)) (-2583 (((-1141 (-2 (|:| |k| (-763)) (|:| |c| |#1|))) $) 38)) (-1982 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1933 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3134 (((-3 $ "failed") $ $) NIL)) (-1902 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1974 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2786 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3728 (($ (-1141 (-2 (|:| |k| (-763)) (|:| |c| |#1|)))) 51) (($ (-1141 |#1|)) NIL)) (-1990 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1941 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2671 (($) NIL T CONST)) (-2129 (($ $) 119)) (-2114 (($ $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3490 (($ $) 126)) (-1367 (((-953 |#1|) $ (-763)) 59) (((-953 |#1|) $ (-763) (-763)) 61)) (-3992 (((-121) $) NIL)) (-1897 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4477 (((-763) $) NIL) (((-763) $ (-763)) NIL)) (-2735 (((-121) $) NIL)) (-2011 (($ $) 103)) (-4044 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2651 (($ (-568) (-568) $) 121)) (-3536 (($ $ (-917)) 125)) (-1716 (($ (-1 |#1| (-568)) $) 97)) (-3921 (((-121) $) NIL)) (-2047 (($ |#1| (-763)) 12) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-2795 (($ (-1 |#1| |#1|) $) 85)) (-4416 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2097 (($ $) NIL)) (-2102 ((|#1| $) NIL)) (-4487 (((-1143) $) NIL)) (-3730 (($ $) 101)) (-2608 (($ $) 99)) (-4053 (($ (-568) (-568) $) 123)) (-3837 (($ $) 136 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) 139 (-2198 (-12 (|has| |#1| (-15 -3837 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2055 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181))))) (($ $ (-1240 |#2|)) 137 (|has| |#1| (-43 (-409 (-568)))))) (-4022 (((-1108) $) NIL)) (-2224 (($ $ (-568) (-568)) 107)) (-1807 (($ $ (-763)) 109)) (-2595 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-1892 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2372 (($ $) 105)) (-1339 (((-1141 |#1|) $ |#1|) 87 (|has| |#1| (-15 ** (|#1| |#1| (-763)))))) (-2779 ((|#1| $ (-763)) 82) (($ $ $) 117 (|has| (-763) (-1102)))) (-4189 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) 92 (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $) 89 (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $ (-1240 |#2|)) 90)) (-3206 (((-763) $) NIL)) (-1994 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1945 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1986 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1937 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1978 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2790 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1811 (($ $) 111)) (-2745 (((-850) $) NIL) (($ (-568)) 18) (($ (-409 (-568))) 134 (|has| |#1| (-43 (-409 (-568))))) (($ $) NIL (|has| |#1| (-558))) (($ |#1|) 17 (|has| |#1| (-172))) (($ (-1216 |#2| |#1|)) 73) (($ (-1240 |#2|)) 14)) (-1302 (((-1141 |#1|) $) NIL)) (-2604 ((|#1| $ (-763)) 81)) (-4371 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-4078 (((-763)) NIL)) (-1374 ((|#1| $) 80)) (-2006 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1958 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1826 (((-121) $ $) NIL (|has| |#1| (-558)))) (-1998 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1949 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2014 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1966 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3996 ((|#1| $ (-763)) 78 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-763)))) (|has| |#1| (-15 -2745 (|#1| (-1161))))))) (-4023 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1970 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2010 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1962 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2002 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1953 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 44 T CONST)) (-1556 (($) 9 T CONST)) (-3190 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (-1717 (((-121) $ $) NIL)) (-1779 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) 94)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ |#1|) 131 (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 93) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
-(((-1239 |#1| |#2|) (-13 (-1234 |#1|) (-10 -8 (-15 -2745 ($ (-1216 |#2| |#1|))) (-15 -3196 ((-1216 |#2| |#1|) $ (-763))) (-15 -2745 ($ (-1240 |#2|))) (-15 -4189 ($ $ (-1240 |#2|))) (-15 -2608 ($ $)) (-15 -3730 ($ $)) (-15 -2011 ($ $)) (-15 -2372 ($ $)) (-15 -2224 ($ $ (-568) (-568))) (-15 -2129 ($ $)) (-15 -2651 ($ (-568) (-568) $)) (-15 -4053 ($ (-568) (-568) $)) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -3837 ($ $ (-1240 |#2|))) |noBranch|))) (-1047) (-1161)) (T -1239)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-1216 *4 *3)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-5 *1 (-1239 *3 *4)))) (-3196 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1216 *5 *4)) (-5 *1 (-1239 *4 *5)) (-4 *4 (-1047)) (-14 *5 (-1161)))) (-2745 (*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-1047)))) (-4189 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-1047)))) (-2608 (*1 *1 *1) (-12 (-5 *1 (-1239 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-1161)))) (-3730 (*1 *1 *1) (-12 (-5 *1 (-1239 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-1161)))) (-2011 (*1 *1 *1) (-12 (-5 *1 (-1239 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-1161)))) (-2372 (*1 *1 *1) (-12 (-5 *1 (-1239 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-1161)))) (-2224 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-1161)))) (-2129 (*1 *1 *1) (-12 (-5 *1 (-1239 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-1161)))) (-2651 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-1161)))) (-4053 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-1161)))) (-3837 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047))))) 
-(-13 (-1234 |#1|) (-10 -8 (-15 -2745 ($ (-1216 |#2| |#1|))) (-15 -3196 ((-1216 |#2| |#1|) $ (-763))) (-15 -2745 ($ (-1240 |#2|))) (-15 -4189 ($ $ (-1240 |#2|))) (-15 -2608 ($ $)) (-15 -3730 ($ $)) (-15 -2011 ($ $)) (-15 -2372 ($ $)) (-15 -2224 ($ $ (-568) (-568))) (-15 -2129 ($ $)) (-15 -2651 ($ (-568) (-568) $)) (-15 -4053 ($ (-568) (-568) $)) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -3837 ($ $ (-1240 |#2|))) |noBranch|))) 
-((-2447 (((-121) $ $) NIL)) (-1305 (((-1161)) 12)) (-4487 (((-1143) $) 17)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 11) (((-1161) $) 8)) (-1717 (((-121) $ $) 14))) 
-(((-1240 |#1|) (-13 (-1090) (-608 (-1161)) (-10 -8 (-15 -2745 ((-1161) $)) (-15 -1305 ((-1161))))) (-1161)) (T -1240)) 
-((-2745 (*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-1240 *3)) (-14 *3 *2))) (-1305 (*1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1240 *3)) (-14 *3 *2)))) 
-(-13 (-1090) (-608 (-1161)) (-10 -8 (-15 -2745 ((-1161) $)) (-15 -1305 ((-1161))))) 
-((-3205 (($ (-763)) 16)) (-1802 (((-679 |#2|) $ $) 37)) (-1550 ((|#2| $) 46)) (-3678 ((|#2| $) 45)) (-3682 ((|#2| $ $) 33)) (-2748 (($ $ $) 42)) (-1773 (($ $) 20) (($ $ $) 26)) (-1767 (($ $ $) 13)) (* (($ (-568) $) 23) (($ |#2| $) 29) (($ $ |#2|) 28))) 
-(((-1241 |#1| |#2|) (-10 -8 (-15 -1550 (|#2| |#1|)) (-15 -3678 (|#2| |#1|)) (-15 -2748 (|#1| |#1| |#1|)) (-15 -1802 ((-679 |#2|) |#1| |#1|)) (-15 -3682 (|#2| |#1| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 -1773 (|#1| |#1| |#1|)) (-15 -1773 (|#1| |#1|)) (-15 -3205 (|#1| (-763))) (-15 -1767 (|#1| |#1| |#1|))) (-1242 |#2|) (-1195)) (T -1241)) 
-NIL 
-(-10 -8 (-15 -1550 (|#2| |#1|)) (-15 -3678 (|#2| |#1|)) (-15 -2748 (|#1| |#1| |#1|)) (-15 -1802 ((-679 |#2|) |#1| |#1|)) (-15 -3682 (|#2| |#1| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 -1773 (|#1| |#1| |#1|)) (-15 -1773 (|#1| |#1|)) (-15 -3205 (|#1| (-763))) (-15 -1767 (|#1| |#1| |#1|))) 
-((-2447 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-3205 (($ (-763)) 105 (|has| |#1| (-23)))) (-1868 (((-1249) $ (-568) (-568)) 37 (|has| $ (-6 -4520)))) (-2016 (((-121) (-1 (-121) |#1| |#1|) $) 91) (((-121) $) 85 (|has| |#1| (-842)))) (-3908 (($ (-1 (-121) |#1| |#1|) $) 82 (|has| $ (-6 -4520))) (($ $) 81 (-12 (|has| |#1| (-842)) (|has| $ (-6 -4520))))) (-3644 (($ (-1 (-121) |#1| |#1|) $) 92) (($ $) 86 (|has| |#1| (-842)))) (-2510 (((-121) $ (-763)) 8)) (-2436 ((|#1| $ (-568) |#1|) 49 (|has| $ (-6 -4520))) ((|#1| $ (-1210 (-568)) |#1|) 53 (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) |#1|) $) 70 (|has| $ (-6 -4519)))) (-2671 (($) 7 T CONST)) (-1578 (($ $) 83 (|has| $ (-6 -4520)))) (-3943 (($ $) 93)) (-3924 (($ $) 73 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-4328 (($ |#1| $) 72 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) (($ (-1 (-121) |#1|) $) 69 (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4519)))) (-3989 ((|#1| $ (-568) |#1|) 50 (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-568)) 48)) (-2764 (((-568) (-1 (-121) |#1|) $) 90) (((-568) |#1| $) 89 (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) 88 (|has| |#1| (-1090)))) (-4360 (((-634 |#1|) $) 30 (|has| $ (-6 -4519)))) (-1802 (((-679 |#1|) $ $) 98 (|has| |#1| (-1047)))) (-1849 (($ (-763) |#1|) 64)) (-1737 (((-121) $ (-763)) 9)) (-1881 (((-568) $) 40 (|has| (-568) (-842)))) (-2521 (($ $ $) 80 (|has| |#1| (-842)))) (-1347 (($ (-1 (-121) |#1| |#1|) $ $) 94) (($ $ $) 87 (|has| |#1| (-842)))) (-1979 (((-634 |#1|) $) 29 (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-2223 (((-568) $) 41 (|has| (-568) (-842)))) (-3268 (($ $ $) 79 (|has| |#1| (-842)))) (-3674 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-1550 ((|#1| $) 95 (-12 (|has| |#1| (-1047)) (|has| |#1| (-1002))))) (-2166 (((-121) $ (-763)) 10)) (-3678 ((|#1| $) 96 (-12 (|has| |#1| (-1047)) (|has| |#1| (-1002))))) (-4487 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4122 (($ |#1| $ (-568)) 55) (($ $ $ (-568)) 54)) (-4174 (((-634 (-568)) $) 43)) (-3578 (((-121) (-568) $) 44)) (-4022 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3876 ((|#1| $) 39 (|has| (-568) (-842)))) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 66)) (-3724 (($ $ |#1|) 38 (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) 14)) (-4467 (((-121) |#1| $) 42 (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) 45)) (-3084 (((-121) $) 11)) (-3248 (($) 12)) (-2779 ((|#1| $ (-568) |#1|) 47) ((|#1| $ (-568)) 46) (($ $ (-1210 (-568))) 58)) (-3682 ((|#1| $ $) 99 (|has| |#1| (-1047)))) (-2826 (($ $ (-568)) 57) (($ $ (-1210 (-568))) 56)) (-2748 (($ $ $) 97 (|has| |#1| (-1047)))) (-4168 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4519))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4519))))) (-2256 (($ $ $ (-568)) 84 (|has| $ (-6 -4520)))) (-3863 (($ $) 13)) (-4278 (((-541) $) 74 (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) 65)) (-2768 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-634 $)) 60)) (-2745 (((-850) $) 20 (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4519)))) (-1751 (((-121) $ $) 77 (|has| |#1| (-842)))) (-1738 (((-121) $ $) 76 (|has| |#1| (-842)))) (-1717 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1745 (((-121) $ $) 78 (|has| |#1| (-842)))) (-1732 (((-121) $ $) 75 (|has| |#1| (-842)))) (-1773 (($ $) 104 (|has| |#1| (-21))) (($ $ $) 103 (|has| |#1| (-21)))) (-1767 (($ $ $) 106 (|has| |#1| (-25)))) (* (($ (-568) $) 102 (|has| |#1| (-21))) (($ |#1| $) 101 (|has| |#1| (-716))) (($ $ |#1|) 100 (|has| |#1| (-716)))) (-1697 (((-763) $) 6 (|has| $ (-6 -4519))))) 
+((-2512 (*1 *1 *2) (-12 (-5 *2 (-1141 (-2 (|:| |k| (-763)) (|:| |c| *3)))) (-4 *3 (-1047)) (-4 *1 (-1234 *3)))) (-3304 (*1 *2 *1) (-12 (-4 *1 (-1234 *3)) (-4 *3 (-1047)) (-5 *2 (-1141 *3)))) (-2512 (*1 *1 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-4 *1 (-1234 *3)))) (-3866 (*1 *1 *1) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1047)))) (-3698 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-568))) (-4 *1 (-1234 *3)) (-4 *3 (-1047)))) (-3808 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-1234 *4)) (-4 *4 (-1047)) (-5 *2 (-953 *4)))) (-3808 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-4 *1 (-1234 *4)) (-4 *4 (-1047)) (-5 *2 (-953 *4)))) (** (*1 *1 *1 *2) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) (-1845 (*1 *1 *1) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1047)) (-4 *2 (-43 (-409 (-568)))))) (-1845 (*1 *1 *1 *2) (-2199 (-12 (-5 *2 (-1161)) (-4 *1 (-1234 *3)) (-4 *3 (-1047)) (-12 (-4 *3 (-29 (-568))) (-4 *3 (-959)) (-4 *3 (-1181)) (-4 *3 (-43 (-409 (-568)))))) (-12 (-5 *2 (-1161)) (-4 *1 (-1234 *3)) (-4 *3 (-1047)) (-12 (|has| *3 (-15 -2057 ((-634 *2) *3))) (|has| *3 (-15 -1845 (*3 *3 *2))) (-4 *3 (-43 (-409 (-568))))))))) 
+(-13 (-1221 |t#1| (-763)) (-10 -8 (-15 -2512 ($ (-1141 (-2 (|:| |k| (-763)) (|:| |c| |t#1|))))) (-15 -3304 ((-1141 |t#1|) $)) (-15 -2512 ($ (-1141 |t#1|))) (-15 -3866 ($ $)) (-15 -3698 ($ (-1 |t#1| (-568)) $)) (-15 -3808 ((-953 |t#1|) $ (-763))) (-15 -3808 ((-953 |t#1|) $ (-763) (-763))) (IF (|has| |t#1| (-365)) (-15 ** ($ $ |t#1|)) |noBranch|) (IF (|has| |t#1| (-43 (-409 (-568)))) (PROGN (-15 -1845 ($ $)) (IF (|has| |t#1| (-15 -1845 (|t#1| |t#1| (-1161)))) (IF (|has| |t#1| (-15 -2057 ((-634 (-1161)) |t#1|))) (-15 -1845 ($ $ (-1161))) |noBranch|) |noBranch|) (IF (|has| |t#1| (-1181)) (IF (|has| |t#1| (-959)) (IF (|has| |t#1| (-29 (-568))) (-15 -1845 ($ $ (-1161))) |noBranch|) |noBranch|) |noBranch|) (-6 (-1002)) (-6 (-1181))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-52 |#1| (-763)) . T) ((-25) . T) ((-43 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-43 |#1|) |has| |#1| (-172)) ((-43 $) |has| |#1| (-558)) ((-40) |has| |#1| (-43 (-409 (-568)))) ((-98) |has| |#1| (-43 (-409 (-568)))) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-120 |#1| |#1|) . T) ((-120 $ $) -2199 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-137) . T) ((-148) |has| |#1| (-148)) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) -2199 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-225) |has| |#1| (-15 * (|#1| (-763) |#1|))) ((-279) |has| |#1| (-43 (-409 (-568)))) ((-281 $ $) |has| (-763) (-1102)) ((-285) |has| |#1| (-558)) ((-502) |has| |#1| (-43 (-409 (-568)))) ((-558) |has| |#1| (-558)) ((-637 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-707 |#1|) |has| |#1| (-172)) ((-707 $) |has| |#1| (-558)) ((-716) . T) ((-895 (-1161)) -12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161)))) ((-974 |#1| (-763) (-1075)) . T) ((-1002) |has| |#1| (-43 (-409 (-568)))) ((-1053 (-409 (-568))) |has| |#1| (-43 (-409 (-568)))) ((-1053 |#1|) . T) ((-1053 $) -2199 (|has| |#1| (-558)) (|has| |#1| (-172))) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1181) |has| |#1| (-43 (-409 (-568)))) ((-1184) |has| |#1| (-43 (-409 (-568)))) ((-1221 |#1| (-763)) . T)) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2057 (((-634 (-1075)) $) NIL)) (-3325 (((-1161) $) 86)) (-1802 (((-1216 |#2| |#1|) $ (-763)) 73)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) 135 (|has| |#1| (-558)))) (-4179 (($ $ (-763)) 120) (($ $ (-763) (-763)) 122)) (-2013 (((-1141 (-2 (|:| |k| (-763)) (|:| |c| |#1|))) $) 42)) (-1984 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1935 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2689 (((-3 $ "failed") $ $) NIL)) (-1904 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1976 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2788 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2512 (($ (-1141 (-2 (|:| |k| (-763)) (|:| |c| |#1|)))) 53) (($ (-1141 |#1|)) NIL)) (-1992 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1943 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4490 (($) NIL T CONST)) (-3409 (($ $) 126)) (-2116 (($ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-3866 (($ $) 133)) (-3808 (((-953 |#1|) $ (-763)) 63) (((-953 |#1|) $ (-763) (-763)) 65)) (-1302 (((-121) $) NIL)) (-1899 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1844 (((-763) $) NIL) (((-763) $ (-763)) NIL)) (-1598 (((-121) $) NIL)) (-1304 (($ $) 110)) (-1550 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4384 (($ (-568) (-568) $) 128)) (-4168 (($ $ (-917)) 132)) (-3698 (($ (-1 |#1| (-568)) $) 104)) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| (-763)) 15) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-2797 (($ (-1 |#1| |#1|) $) 92)) (-4418 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-1893 (((-1143) $) NIL)) (-2517 (($ $) 108)) (-2101 (($ $) 106)) (-1588 (($ (-568) (-568) $) 130)) (-1845 (($ $) 143 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) 149 (-2199 (-12 (|has| |#1| (-15 -1845 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2057 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181))))) (($ $ (-1240 |#2|)) 144 (|has| |#1| (-43 (-409 (-568)))))) (-4025 (((-1108) $) NIL)) (-3638 (($ $ (-568) (-568)) 114)) (-2168 (($ $ (-763)) 116)) (-2597 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-1894 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4109 (($ $) 112)) (-1339 (((-1141 |#1|) $ |#1|) 94 (|has| |#1| (-15 ** (|#1| |#1| (-763)))))) (-2781 ((|#1| $ (-763)) 89) (($ $ $) 124 (|has| (-763) (-1102)))) (-4191 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) 101 (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $) 96 (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $ (-1240 |#2|)) 97)) (-1836 (((-763) $) NIL)) (-1996 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1947 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1988 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1939 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1980 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2792 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2188 (($ $) 118)) (-2747 (((-850) $) NIL) (($ (-568)) 24) (($ (-409 (-568))) 141 (|has| |#1| (-43 (-409 (-568))))) (($ $) NIL (|has| |#1| (-558))) (($ |#1|) 23 (|has| |#1| (-172))) (($ (-1216 |#2| |#1|)) 79) (($ (-1240 |#2|)) 20)) (-3304 (((-1141 |#1|) $) NIL)) (-2079 ((|#1| $ (-763)) 88)) (-3385 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-3425 (((-763)) NIL)) (-1374 ((|#1| $) 87)) (-2008 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1959 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2000 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1951 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2016 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1968 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3999 ((|#1| $ (-763)) 85 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-763)))) (|has| |#1| (-15 -2747 (|#1| (-1161))))))) (-1439 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1972 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2012 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1964 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2004 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1955 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 17 T CONST)) (-1557 (($) 13 T CONST)) (-3192 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) 100)) (-1769 (($ $ $) 18)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ |#1|) 138 (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ $ |#1|) NIL) (($ |#1| $) 99) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
+(((-1235 |#1| |#2| |#3|) (-13 (-1234 |#1|) (-10 -8 (-15 -2747 ($ (-1216 |#2| |#1|))) (-15 -1802 ((-1216 |#2| |#1|) $ (-763))) (-15 -2747 ($ (-1240 |#2|))) (-15 -4191 ($ $ (-1240 |#2|))) (-15 -2101 ($ $)) (-15 -2517 ($ $)) (-15 -1304 ($ $)) (-15 -4109 ($ $)) (-15 -3638 ($ $ (-568) (-568))) (-15 -3409 ($ $)) (-15 -4384 ($ (-568) (-568) $)) (-15 -1588 ($ (-568) (-568) $)) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -1845 ($ $ (-1240 |#2|))) |noBranch|))) (-1047) (-1161) |#1|) (T -1235)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1216 *4 *3)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3) (-5 *1 (-1235 *3 *4 *5)))) (-1802 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1216 *5 *4)) (-5 *1 (-1235 *4 *5 *6)) (-4 *4 (-1047)) (-14 *5 (-1161)) (-14 *6 *4))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-4191 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) (-2101 (*1 *1 *1) (-12 (-5 *1 (-1235 *2 *3 *4)) (-4 *2 (-1047)) (-14 *3 (-1161)) (-14 *4 *2))) (-2517 (*1 *1 *1) (-12 (-5 *1 (-1235 *2 *3 *4)) (-4 *2 (-1047)) (-14 *3 (-1161)) (-14 *4 *2))) (-1304 (*1 *1 *1) (-12 (-5 *1 (-1235 *2 *3 *4)) (-4 *2 (-1047)) (-14 *3 (-1161)) (-14 *4 *2))) (-4109 (*1 *1 *1) (-12 (-5 *1 (-1235 *2 *3 *4)) (-4 *2 (-1047)) (-14 *3 (-1161)) (-14 *4 *2))) (-3638 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3))) (-3409 (*1 *1 *1) (-12 (-5 *1 (-1235 *2 *3 *4)) (-4 *2 (-1047)) (-14 *3 (-1161)) (-14 *4 *2))) (-4384 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3))) (-1588 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3))) (-1845 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3)))) 
+(-13 (-1234 |#1|) (-10 -8 (-15 -2747 ($ (-1216 |#2| |#1|))) (-15 -1802 ((-1216 |#2| |#1|) $ (-763))) (-15 -2747 ($ (-1240 |#2|))) (-15 -4191 ($ $ (-1240 |#2|))) (-15 -2101 ($ $)) (-15 -2517 ($ $)) (-15 -1304 ($ $)) (-15 -4109 ($ $)) (-15 -3638 ($ $ (-568) (-568))) (-15 -3409 ($ $)) (-15 -4384 ($ (-568) (-568) $)) (-15 -1588 ($ (-568) (-568) $)) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -1845 ($ $ (-1240 |#2|))) |noBranch|))) 
+((-2599 (((-1 (-1141 |#1|) (-634 (-1141 |#1|))) (-1 |#2| (-634 |#2|))) 24)) (-4184 (((-1 (-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) (-1 |#2| |#2| |#2|)) 16)) (-2223 (((-1 (-1141 |#1|) (-1141 |#1|)) (-1 |#2| |#2|)) 13)) (-1944 ((|#2| (-1 |#2| |#2| |#2|) |#1| |#1|) 48)) (-2564 ((|#2| (-1 |#2| |#2|) |#1|) 46)) (-3473 ((|#2| (-1 |#2| (-634 |#2|)) (-634 |#1|)) 54)) (-2128 (((-634 |#2|) (-634 |#1|) (-634 (-1 |#2| (-634 |#2|)))) 61)) (-1456 ((|#2| |#2| |#2|) 43))) 
+(((-1236 |#1| |#2|) (-10 -7 (-15 -2223 ((-1 (-1141 |#1|) (-1141 |#1|)) (-1 |#2| |#2|))) (-15 -4184 ((-1 (-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) (-1 |#2| |#2| |#2|))) (-15 -2599 ((-1 (-1141 |#1|) (-634 (-1141 |#1|))) (-1 |#2| (-634 |#2|)))) (-15 -1456 (|#2| |#2| |#2|)) (-15 -2564 (|#2| (-1 |#2| |#2|) |#1|)) (-15 -1944 (|#2| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -3473 (|#2| (-1 |#2| (-634 |#2|)) (-634 |#1|))) (-15 -2128 ((-634 |#2|) (-634 |#1|) (-634 (-1 |#2| (-634 |#2|)))))) (-43 (-409 (-568))) (-1234 |#1|)) (T -1236)) 
+((-2128 (*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-1 *6 (-634 *6)))) (-4 *5 (-43 (-409 (-568)))) (-4 *6 (-1234 *5)) (-5 *2 (-634 *6)) (-5 *1 (-1236 *5 *6)))) (-3473 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 (-634 *2))) (-5 *4 (-634 *5)) (-4 *5 (-43 (-409 (-568)))) (-4 *2 (-1234 *5)) (-5 *1 (-1236 *5 *2)))) (-1944 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1234 *4)) (-5 *1 (-1236 *4 *2)) (-4 *4 (-43 (-409 (-568)))))) (-2564 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 *2)) (-4 *2 (-1234 *4)) (-5 *1 (-1236 *4 *2)) (-4 *4 (-43 (-409 (-568)))))) (-1456 (*1 *2 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1236 *3 *2)) (-4 *2 (-1234 *3)))) (-2599 (*1 *2 *3) (-12 (-5 *3 (-1 *5 (-634 *5))) (-4 *5 (-1234 *4)) (-4 *4 (-43 (-409 (-568)))) (-5 *2 (-1 (-1141 *4) (-634 (-1141 *4)))) (-5 *1 (-1236 *4 *5)))) (-4184 (*1 *2 *3) (-12 (-5 *3 (-1 *5 *5 *5)) (-4 *5 (-1234 *4)) (-4 *4 (-43 (-409 (-568)))) (-5 *2 (-1 (-1141 *4) (-1141 *4) (-1141 *4))) (-5 *1 (-1236 *4 *5)))) (-2223 (*1 *2 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-1234 *4)) (-4 *4 (-43 (-409 (-568)))) (-5 *2 (-1 (-1141 *4) (-1141 *4))) (-5 *1 (-1236 *4 *5))))) 
+(-10 -7 (-15 -2223 ((-1 (-1141 |#1|) (-1141 |#1|)) (-1 |#2| |#2|))) (-15 -4184 ((-1 (-1141 |#1|) (-1141 |#1|) (-1141 |#1|)) (-1 |#2| |#2| |#2|))) (-15 -2599 ((-1 (-1141 |#1|) (-634 (-1141 |#1|))) (-1 |#2| (-634 |#2|)))) (-15 -1456 (|#2| |#2| |#2|)) (-15 -2564 (|#2| (-1 |#2| |#2|) |#1|)) (-15 -1944 (|#2| (-1 |#2| |#2| |#2|) |#1| |#1|)) (-15 -3473 (|#2| (-1 |#2| (-634 |#2|)) (-634 |#1|))) (-15 -2128 ((-634 |#2|) (-634 |#1|) (-634 (-1 |#2| (-634 |#2|)))))) 
+((-3658 ((|#2| |#4| (-763)) 30)) (-2648 ((|#4| |#2|) 25)) (-2674 ((|#4| (-409 |#2|)) 51 (|has| |#1| (-558)))) (-2348 (((-1 |#4| (-634 |#4|)) |#3|) 45))) 
+(((-1237 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -2648 (|#4| |#2|)) (-15 -3658 (|#2| |#4| (-763))) (-15 -2348 ((-1 |#4| (-634 |#4|)) |#3|)) (IF (|has| |#1| (-558)) (-15 -2674 (|#4| (-409 |#2|))) |noBranch|)) (-1047) (-1219 |#1|) (-646 |#2|) (-1234 |#1|)) (T -1237)) 
+((-2674 (*1 *2 *3) (-12 (-5 *3 (-409 *5)) (-4 *5 (-1219 *4)) (-4 *4 (-558)) (-4 *4 (-1047)) (-4 *2 (-1234 *4)) (-5 *1 (-1237 *4 *5 *6 *2)) (-4 *6 (-646 *5)))) (-2348 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-1219 *4)) (-5 *2 (-1 *6 (-634 *6))) (-5 *1 (-1237 *4 *5 *3 *6)) (-4 *3 (-646 *5)) (-4 *6 (-1234 *4)))) (-3658 (*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-1047)) (-4 *2 (-1219 *5)) (-5 *1 (-1237 *5 *2 *6 *3)) (-4 *6 (-646 *2)) (-4 *3 (-1234 *5)))) (-2648 (*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *3 (-1219 *4)) (-4 *2 (-1234 *4)) (-5 *1 (-1237 *4 *3 *5 *2)) (-4 *5 (-646 *3))))) 
+(-10 -7 (-15 -2648 (|#4| |#2|)) (-15 -3658 (|#2| |#4| (-763))) (-15 -2348 ((-1 |#4| (-634 |#4|)) |#3|)) (IF (|has| |#1| (-558)) (-15 -2674 (|#4| (-409 |#2|))) |noBranch|)) 
+((-2873 ((|#2| (-1 |#3| |#3|) (-634 |#1|)) 67))) 
+(((-1238 |#1| |#2| |#3|) (-10 -7 (-15 -2873 (|#2| (-1 |#3| |#3|) (-634 |#1|)))) (-365) (-1234 |#1|) (-1234 (-1155 |#1|))) (T -1238)) 
+((-2873 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *6)) (-5 *4 (-634 *5)) (-4 *5 (-365)) (-4 *6 (-1234 (-1155 *5))) (-4 *2 (-1234 *5)) (-5 *1 (-1238 *5 *2 *6))))) 
+(-10 -7 (-15 -2873 (|#2| (-1 |#3| |#3|) (-634 |#1|)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2057 (((-634 (-1075)) $) NIL)) (-3325 (((-1161) $) 79)) (-1802 (((-1216 |#2| |#1|) $ (-763)) 68)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) NIL (|has| |#1| (-558)))) (-3661 (($ $) NIL (|has| |#1| (-558)))) (-4426 (((-121) $) 128 (|has| |#1| (-558)))) (-4179 (($ $ (-763)) 113) (($ $ (-763) (-763)) 115)) (-2013 (((-1141 (-2 (|:| |k| (-763)) (|:| |c| |#1|))) $) 38)) (-1984 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1935 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2689 (((-3 $ "failed") $ $) NIL)) (-1904 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1976 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2788 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2512 (($ (-1141 (-2 (|:| |k| (-763)) (|:| |c| |#1|)))) 51) (($ (-1141 |#1|)) NIL)) (-1992 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1943 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4490 (($) NIL T CONST)) (-3409 (($ $) 119)) (-2116 (($ $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-3866 (($ $) 126)) (-3808 (((-953 |#1|) $ (-763)) 59) (((-953 |#1|) $ (-763) (-763)) 61)) (-1302 (((-121) $) NIL)) (-1899 (($) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1844 (((-763) $) NIL) (((-763) $ (-763)) NIL)) (-1598 (((-121) $) NIL)) (-1304 (($ $) 103)) (-1550 (($ $ (-568)) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4384 (($ (-568) (-568) $) 121)) (-4168 (($ $ (-917)) 125)) (-3698 (($ (-1 |#1| (-568)) $) 97)) (-2171 (((-121) $) NIL)) (-2049 (($ |#1| (-763)) 12) (($ $ (-1075) (-763)) NIL) (($ $ (-634 (-1075)) (-634 (-763))) NIL)) (-2797 (($ (-1 |#1| |#1|) $) 85)) (-4418 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2099 (($ $) NIL)) (-2104 ((|#1| $) NIL)) (-1893 (((-1143) $) NIL)) (-2517 (($ $) 101)) (-2101 (($ $) 99)) (-1588 (($ (-568) (-568) $) 123)) (-1845 (($ $) 136 (|has| |#1| (-43 (-409 (-568))))) (($ $ (-1161)) 139 (-2199 (-12 (|has| |#1| (-15 -1845 (|#1| |#1| (-1161)))) (|has| |#1| (-15 -2057 ((-634 (-1161)) |#1|))) (|has| |#1| (-43 (-409 (-568))))) (-12 (|has| |#1| (-29 (-568))) (|has| |#1| (-43 (-409 (-568)))) (|has| |#1| (-959)) (|has| |#1| (-1181))))) (($ $ (-1240 |#2|)) 137 (|has| |#1| (-43 (-409 (-568)))))) (-4025 (((-1108) $) NIL)) (-3638 (($ $ (-568) (-568)) 107)) (-2168 (($ $ (-763)) 109)) (-2597 (((-3 $ "failed") $ $) NIL (|has| |#1| (-558)))) (-1894 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-4109 (($ $) 105)) (-1339 (((-1141 |#1|) $ |#1|) 87 (|has| |#1| (-15 ** (|#1| |#1| (-763)))))) (-2781 ((|#1| $ (-763)) 82) (($ $ $) 117 (|has| (-763) (-1102)))) (-4191 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) 92 (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $) 89 (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $ (-1240 |#2|)) 90)) (-1836 (((-763) $) NIL)) (-1996 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1947 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1988 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1939 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1980 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2792 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2188 (($ $) 111)) (-2747 (((-850) $) NIL) (($ (-568)) 18) (($ (-409 (-568))) 134 (|has| |#1| (-43 (-409 (-568))))) (($ $) NIL (|has| |#1| (-558))) (($ |#1|) 17 (|has| |#1| (-172))) (($ (-1216 |#2| |#1|)) 73) (($ (-1240 |#2|)) 14)) (-3304 (((-1141 |#1|) $) NIL)) (-2079 ((|#1| $ (-763)) 81)) (-3385 (((-3 $ "failed") $) NIL (|has| |#1| (-148)))) (-3425 (((-763)) NIL)) (-1374 ((|#1| $) 80)) (-2008 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1959 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2273 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2000 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1951 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2016 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1968 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-3999 ((|#1| $ (-763)) 78 (-12 (|has| |#1| (-15 ** (|#1| |#1| (-763)))) (|has| |#1| (-15 -2747 (|#1| (-1161))))))) (-1439 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1972 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2012 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1964 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-2004 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1955 (($ $) NIL (|has| |#1| (-43 (-409 (-568)))))) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 44 T CONST)) (-1557 (($) 9 T CONST)) (-3192 (($ $ (-634 (-1161)) (-634 (-763))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161) (-763)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-634 (-1161))) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-1161)) NIL (-12 (|has| |#1| (-15 * (|#1| (-763) |#1|))) (|has| |#1| (-895 (-1161))))) (($ $ (-763)) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|)))) (($ $) NIL (|has| |#1| (-15 * (|#1| (-763) |#1|))))) (-1719 (((-121) $ $) NIL)) (-1781 (($ $ |#1|) NIL (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) 94)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL) (($ $ |#1|) 131 (|has| |#1| (-365))) (($ $ $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568)))))) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 93) (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ (-409 (-568)) $) NIL (|has| |#1| (-43 (-409 (-568))))) (($ $ (-409 (-568))) NIL (|has| |#1| (-43 (-409 (-568))))))) 
+(((-1239 |#1| |#2|) (-13 (-1234 |#1|) (-10 -8 (-15 -2747 ($ (-1216 |#2| |#1|))) (-15 -1802 ((-1216 |#2| |#1|) $ (-763))) (-15 -2747 ($ (-1240 |#2|))) (-15 -4191 ($ $ (-1240 |#2|))) (-15 -2101 ($ $)) (-15 -2517 ($ $)) (-15 -1304 ($ $)) (-15 -4109 ($ $)) (-15 -3638 ($ $ (-568) (-568))) (-15 -3409 ($ $)) (-15 -4384 ($ (-568) (-568) $)) (-15 -1588 ($ (-568) (-568) $)) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -1845 ($ $ (-1240 |#2|))) |noBranch|))) (-1047) (-1161)) (T -1239)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-1216 *4 *3)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-5 *1 (-1239 *3 *4)))) (-1802 (*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1216 *5 *4)) (-5 *1 (-1239 *4 *5)) (-4 *4 (-1047)) (-14 *5 (-1161)))) (-2747 (*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-1047)))) (-4191 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-1047)))) (-2101 (*1 *1 *1) (-12 (-5 *1 (-1239 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-1161)))) (-2517 (*1 *1 *1) (-12 (-5 *1 (-1239 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-1161)))) (-1304 (*1 *1 *1) (-12 (-5 *1 (-1239 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-1161)))) (-4109 (*1 *1 *1) (-12 (-5 *1 (-1239 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-1161)))) (-3638 (*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-1161)))) (-3409 (*1 *1 *1) (-12 (-5 *1 (-1239 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-1161)))) (-4384 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-1161)))) (-1588 (*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-1161)))) (-1845 (*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047))))) 
+(-13 (-1234 |#1|) (-10 -8 (-15 -2747 ($ (-1216 |#2| |#1|))) (-15 -1802 ((-1216 |#2| |#1|) $ (-763))) (-15 -2747 ($ (-1240 |#2|))) (-15 -4191 ($ $ (-1240 |#2|))) (-15 -2101 ($ $)) (-15 -2517 ($ $)) (-15 -1304 ($ $)) (-15 -4109 ($ $)) (-15 -3638 ($ $ (-568) (-568))) (-15 -3409 ($ $)) (-15 -4384 ($ (-568) (-568) $)) (-15 -1588 ($ (-568) (-568) $)) (IF (|has| |#1| (-43 (-409 (-568)))) (-15 -1845 ($ $ (-1240 |#2|))) |noBranch|))) 
+((-2449 (((-121) $ $) NIL)) (-3325 (((-1161)) 12)) (-1893 (((-1143) $) 17)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 11) (((-1161) $) 8)) (-1719 (((-121) $ $) 14))) 
+(((-1240 |#1|) (-13 (-1090) (-608 (-1161)) (-10 -8 (-15 -2747 ((-1161) $)) (-15 -3325 ((-1161))))) (-1161)) (T -1240)) 
+((-2747 (*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-1240 *3)) (-14 *3 *2))) (-3325 (*1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1240 *3)) (-14 *3 *2)))) 
+(-13 (-1090) (-608 (-1161)) (-10 -8 (-15 -2747 ((-1161) $)) (-15 -3325 ((-1161))))) 
+((-3207 (($ (-763)) 16)) (-1804 (((-679 |#2|) $ $) 37)) (-4303 ((|#2| $) 46)) (-3680 ((|#2| $) 45)) (-2286 ((|#2| $ $) 33)) (-3372 (($ $ $) 42)) (-1775 (($ $) 20) (($ $ $) 26)) (-1769 (($ $ $) 13)) (* (($ (-568) $) 23) (($ |#2| $) 29) (($ $ |#2|) 28))) 
+(((-1241 |#1| |#2|) (-10 -8 (-15 -4303 (|#2| |#1|)) (-15 -3680 (|#2| |#1|)) (-15 -3372 (|#1| |#1| |#1|)) (-15 -1804 ((-679 |#2|) |#1| |#1|)) (-15 -2286 (|#2| |#1| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 -1775 (|#1| |#1| |#1|)) (-15 -1775 (|#1| |#1|)) (-15 -3207 (|#1| (-763))) (-15 -1769 (|#1| |#1| |#1|))) (-1242 |#2|) (-1195)) (T -1241)) 
+NIL 
+(-10 -8 (-15 -4303 (|#2| |#1|)) (-15 -3680 (|#2| |#1|)) (-15 -3372 (|#1| |#1| |#1|)) (-15 -1804 ((-679 |#2|) |#1| |#1|)) (-15 -2286 (|#2| |#1| |#1|)) (-15 * (|#1| |#1| |#2|)) (-15 * (|#1| |#2| |#1|)) (-15 * (|#1| (-568) |#1|)) (-15 -1775 (|#1| |#1| |#1|)) (-15 -1775 (|#1| |#1|)) (-15 -3207 (|#1| (-763))) (-15 -1769 (|#1| |#1| |#1|))) 
+((-2449 (((-121) $ $) 18 (|has| |#1| (-1090)))) (-3207 (($ (-763)) 105 (|has| |#1| (-23)))) (-2481 (((-1249) $ (-568) (-568)) 37 (|has| $ (-6 -4522)))) (-1324 (((-121) (-1 (-121) |#1| |#1|) $) 91) (((-121) $) 85 (|has| |#1| (-842)))) (-2109 (($ (-1 (-121) |#1| |#1|) $) 82 (|has| $ (-6 -4522))) (($ $) 81 (-12 (|has| |#1| (-842)) (|has| $ (-6 -4522))))) (-3647 (($ (-1 (-121) |#1| |#1|) $) 92) (($ $) 86 (|has| |#1| (-842)))) (-1667 (((-121) $ (-763)) 8)) (-2438 ((|#1| $ (-568) |#1|) 49 (|has| $ (-6 -4522))) ((|#1| $ (-1210 (-568)) |#1|) 53 (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) |#1|) $) 70 (|has| $ (-6 -4521)))) (-4490 (($) 7 T CONST)) (-4452 (($ $) 83 (|has| $ (-6 -4522)))) (-3945 (($ $) 93)) (-3926 (($ $) 73 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-4330 (($ |#1| $) 72 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) (($ (-1 (-121) |#1|) $) 69 (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) 71 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) 68 (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) 67 (|has| $ (-6 -4521)))) (-1292 ((|#1| $ (-568) |#1|) 50 (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-568)) 48)) (-2766 (((-568) (-1 (-121) |#1|) $) 90) (((-568) |#1| $) 89 (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) 88 (|has| |#1| (-1090)))) (-3317 (((-634 |#1|) $) 30 (|has| $ (-6 -4521)))) (-1804 (((-679 |#1|) $ $) 98 (|has| |#1| (-1047)))) (-1851 (($ (-763) |#1|) 64)) (-3791 (((-121) $ (-763)) 9)) (-2539 (((-568) $) 40 (|has| (-568) (-842)))) (-1732 (($ $ $) 80 (|has| |#1| (-842)))) (-3645 (($ (-1 (-121) |#1| |#1|) $ $) 94) (($ $ $) 87 (|has| |#1| (-842)))) (-4406 (((-634 |#1|) $) 29 (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) 27 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3631 (((-568) $) 41 (|has| (-568) (-842)))) (-2047 (($ $ $) 79 (|has| |#1| (-842)))) (-2253 (($ (-1 |#1| |#1|) $) 34 (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) 35) (($ (-1 |#1| |#1| |#1|) $ $) 59)) (-4303 ((|#1| $) 95 (-12 (|has| |#1| (-1047)) (|has| |#1| (-1002))))) (-3796 (((-121) $ (-763)) 10)) (-3680 ((|#1| $) 96 (-12 (|has| |#1| (-1047)) (|has| |#1| (-1002))))) (-1893 (((-1143) $) 22 (|has| |#1| (-1090)))) (-4124 (($ |#1| $ (-568)) 55) (($ $ $ (-568)) 54)) (-3948 (((-634 (-568)) $) 43)) (-2916 (((-121) (-568) $) 44)) (-4025 (((-1108) $) 21 (|has| |#1| (-1090)))) (-3877 ((|#1| $) 39 (|has| (-568) (-842)))) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) 66)) (-2490 (($ $ |#1|) 38 (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) |#1|) $) 32 (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) 26 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) 25 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) 24 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) 23 (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) 14)) (-1801 (((-121) |#1| $) 42 (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) 45)) (-2436 (((-121) $) 11)) (-1990 (($) 12)) (-2781 ((|#1| $ (-568) |#1|) 47) ((|#1| $ (-568)) 46) (($ $ (-1210 (-568))) 58)) (-2286 ((|#1| $ $) 99 (|has| |#1| (-1047)))) (-2828 (($ $ (-568)) 57) (($ $ (-1210 (-568))) 56)) (-3372 (($ $ $) 97 (|has| |#1| (-1047)))) (-4170 (((-763) (-1 (-121) |#1|) $) 31 (|has| $ (-6 -4521))) (((-763) |#1| $) 28 (-12 (|has| |#1| (-1090)) (|has| $ (-6 -4521))))) (-3306 (($ $ $ (-568)) 84 (|has| $ (-6 -4522)))) (-3865 (($ $) 13)) (-4280 (((-541) $) 74 (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) 65)) (-2770 (($ $ |#1|) 63) (($ |#1| $) 62) (($ $ $) 61) (($ (-634 $)) 60)) (-2747 (((-850) $) 20 (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) 33 (|has| $ (-6 -4521)))) (-1753 (((-121) $ $) 77 (|has| |#1| (-842)))) (-1740 (((-121) $ $) 76 (|has| |#1| (-842)))) (-1719 (((-121) $ $) 19 (|has| |#1| (-1090)))) (-1747 (((-121) $ $) 78 (|has| |#1| (-842)))) (-1734 (((-121) $ $) 75 (|has| |#1| (-842)))) (-1775 (($ $) 104 (|has| |#1| (-21))) (($ $ $) 103 (|has| |#1| (-21)))) (-1769 (($ $ $) 106 (|has| |#1| (-25)))) (* (($ (-568) $) 102 (|has| |#1| (-21))) (($ |#1| $) 101 (|has| |#1| (-716))) (($ $ |#1|) 100 (|has| |#1| (-716)))) (-1699 (((-763) $) 6 (|has| $ (-6 -4521))))) 
 (((-1242 |#1|) (-1275) (-1195)) (T -1242)) 
-((-1767 (*1 *1 *1 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-25)))) (-3205 (*1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1242 *3)) (-4 *3 (-23)) (-4 *3 (-1195)))) (-1773 (*1 *1 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-21)))) (-1773 (*1 *1 *1 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-21)))) (* (*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-4 *1 (-1242 *3)) (-4 *3 (-1195)) (-4 *3 (-21)))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-716)))) (* (*1 *1 *1 *2) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-716)))) (-3682 (*1 *2 *1 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-1047)))) (-1802 (*1 *2 *1 *1) (-12 (-4 *1 (-1242 *3)) (-4 *3 (-1195)) (-4 *3 (-1047)) (-5 *2 (-679 *3)))) (-2748 (*1 *1 *1 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-1047)))) (-3678 (*1 *2 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-1002)) (-4 *2 (-1047)))) (-1550 (*1 *2 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-1002)) (-4 *2 (-1047))))) 
-(-13 (-19 |t#1|) (-10 -8 (IF (|has| |t#1| (-25)) (-15 -1767 ($ $ $)) |noBranch|) (IF (|has| |t#1| (-23)) (-15 -3205 ($ (-763))) |noBranch|) (IF (|has| |t#1| (-21)) (PROGN (-15 -1773 ($ $)) (-15 -1773 ($ $ $)) (-15 * ($ (-568) $))) |noBranch|) (IF (|has| |t#1| (-716)) (PROGN (-15 * ($ |t#1| $)) (-15 * ($ $ |t#1|))) |noBranch|) (IF (|has| |t#1| (-1047)) (PROGN (-15 -3682 (|t#1| $ $)) (-15 -1802 ((-679 |t#1|) $ $)) (-15 -2748 ($ $ $))) |noBranch|) (IF (|has| |t#1| (-1002)) (IF (|has| |t#1| (-1047)) (PROGN (-15 -3678 (|t#1| $)) (-15 -1550 (|t#1| $))) |noBranch|) |noBranch|))) 
-(((-39) . T) ((-105) -2198 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-608 (-850)) -2198 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-154 |#1|) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-281 (-568) |#1|) . T) ((-283 (-568) |#1|) . T) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-375 |#1|) . T) ((-499 |#1|) . T) ((-601 (-568) |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-640 |#1|) . T) ((-19 |#1|) . T) ((-842) |has| |#1| (-842)) ((-1090) -2198 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-1195) . T)) 
-((-2512 (((-1244 |#2|) (-1 |#2| |#1| |#2|) (-1244 |#1|) |#2|) 13)) (-3092 ((|#2| (-1 |#2| |#1| |#2|) (-1244 |#1|) |#2|) 15)) (-2795 (((-3 (-1244 |#2|) "failed") (-1 (-3 |#2| "failed") |#1|) (-1244 |#1|)) 28) (((-1244 |#2|) (-1 |#2| |#1|) (-1244 |#1|)) 18))) 
-(((-1243 |#1| |#2|) (-10 -7 (-15 -2512 ((-1244 |#2|) (-1 |#2| |#1| |#2|) (-1244 |#1|) |#2|)) (-15 -3092 (|#2| (-1 |#2| |#1| |#2|) (-1244 |#1|) |#2|)) (-15 -2795 ((-1244 |#2|) (-1 |#2| |#1|) (-1244 |#1|))) (-15 -2795 ((-3 (-1244 |#2|) "failed") (-1 (-3 |#2| "failed") |#1|) (-1244 |#1|)))) (-1195) (-1195)) (T -1243)) 
-((-2795 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *6 "failed") *5)) (-5 *4 (-1244 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1244 *6)) (-5 *1 (-1243 *5 *6)))) (-2795 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1244 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1244 *6)) (-5 *1 (-1243 *5 *6)))) (-3092 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-1244 *5)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-1243 *5 *2)))) (-2512 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-1244 *6)) (-4 *6 (-1195)) (-4 *5 (-1195)) (-5 *2 (-1244 *5)) (-5 *1 (-1243 *6 *5))))) 
-(-10 -7 (-15 -2512 ((-1244 |#2|) (-1 |#2| |#1| |#2|) (-1244 |#1|) |#2|)) (-15 -3092 (|#2| (-1 |#2| |#1| |#2|) (-1244 |#1|) |#2|)) (-15 -2795 ((-1244 |#2|) (-1 |#2| |#1|) (-1244 |#1|))) (-15 -2795 ((-3 (-1244 |#2|) "failed") (-1 (-3 |#2| "failed") |#1|) (-1244 |#1|)))) 
-((-2447 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3205 (($ (-763)) NIL (|has| |#1| (-23)))) (-4209 (($ (-634 |#1|)) 9)) (-1868 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4520)))) (-2016 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-842)))) (-3908 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4520))) (($ $) NIL (-12 (|has| $ (-6 -4520)) (|has| |#1| (-842))))) (-3644 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-842)))) (-2510 (((-121) $ (-763)) NIL)) (-2436 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4520))) ((|#1| $ (-1210 (-568)) |#1|) NIL (|has| $ (-6 -4520)))) (-2801 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-2671 (($) NIL T CONST)) (-1578 (($ $) NIL (|has| $ (-6 -4520)))) (-3943 (($ $) NIL)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-4328 (($ |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-3092 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4519))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4519)))) (-3989 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4520)))) (-2602 ((|#1| $ (-568)) NIL)) (-2764 (((-568) (-1 (-121) |#1|) $) NIL) (((-568) |#1| $) NIL (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) NIL (|has| |#1| (-1090)))) (-4360 (((-634 |#1|) $) 15 (|has| $ (-6 -4519)))) (-1802 (((-679 |#1|) $ $) NIL (|has| |#1| (-1047)))) (-1849 (($ (-763) |#1|) NIL)) (-1737 (((-121) $ (-763)) NIL)) (-1881 (((-568) $) NIL (|has| (-568) (-842)))) (-2521 (($ $ $) NIL (|has| |#1| (-842)))) (-1347 (($ (-1 (-121) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-842)))) (-1979 (((-634 |#1|) $) NIL (|has| $ (-6 -4519)))) (-3109 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2223 (((-568) $) NIL (|has| (-568) (-842)))) (-3268 (($ $ $) NIL (|has| |#1| (-842)))) (-3674 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-1550 ((|#1| $) NIL (-12 (|has| |#1| (-1002)) (|has| |#1| (-1047))))) (-2166 (((-121) $ (-763)) NIL)) (-3678 ((|#1| $) NIL (-12 (|has| |#1| (-1002)) (|has| |#1| (-1047))))) (-4487 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4122 (($ |#1| $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-4174 (((-634 (-568)) $) NIL)) (-3578 (((-121) (-568) $) NIL)) (-4022 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3876 ((|#1| $) NIL (|has| (-568) (-842)))) (-3775 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-3724 (($ $ |#1|) NIL (|has| $ (-6 -4520)))) (-1387 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-3171 (((-121) $ $) NIL)) (-4467 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2041 (((-634 |#1|) $) NIL)) (-3084 (((-121) $) NIL)) (-3248 (($) NIL)) (-2779 ((|#1| $ (-568) |#1|) NIL) ((|#1| $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-3682 ((|#1| $ $) NIL (|has| |#1| (-1047)))) (-2826 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-2748 (($ $ $) NIL (|has| |#1| (-1047)))) (-4168 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#1| (-1090))))) (-2256 (($ $ $ (-568)) NIL (|has| $ (-6 -4520)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) 19 (|has| |#1| (-609 (-541))))) (-4287 (($ (-634 |#1|)) 8)) (-2768 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-634 $)) NIL)) (-2745 (((-850) $) NIL (|has| |#1| (-1090)))) (-1319 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4519)))) (-1751 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1738 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1717 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1745 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1732 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1773 (($ $) NIL (|has| |#1| (-21))) (($ $ $) NIL (|has| |#1| (-21)))) (-1767 (($ $ $) NIL (|has| |#1| (-25)))) (* (($ (-568) $) NIL (|has| |#1| (-21))) (($ |#1| $) NIL (|has| |#1| (-716))) (($ $ |#1|) NIL (|has| |#1| (-716)))) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-1244 |#1|) (-13 (-1242 |#1|) (-10 -8 (-15 -4209 ($ (-634 |#1|))))) (-1195)) (T -1244)) 
-((-4209 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-1244 *3))))) 
-(-13 (-1242 |#1|) (-10 -8 (-15 -4209 ($ (-634 |#1|))))) 
-((-2447 (((-121) $ $) NIL)) (-2323 (((-1143) $ (-1143)) 87) (((-1143) $ (-1143) (-1143)) 85) (((-1143) $ (-1143) (-634 (-1143))) 84)) (-2638 (($) 56)) (-2967 (((-1249) $ (-473) (-917)) 42)) (-2832 (((-1249) $ (-917) (-1143)) 70) (((-1249) $ (-917) (-869)) 71)) (-1859 (((-1249) $ (-917) (-381) (-381)) 45)) (-1784 (((-1249) $ (-1143)) 66)) (-1647 (((-1249) $ (-917) (-1143)) 75)) (-3646 (((-1249) $ (-917) (-381) (-381)) 46)) (-1476 (((-1249) $ (-917) (-917)) 43)) (-2316 (((-1249) $) 67)) (-1419 (((-1249) $ (-917) (-1143)) 74)) (-1502 (((-1249) $ (-473) (-917)) 30)) (-1526 (((-1249) $ (-917) (-1143)) 73)) (-1480 (((-634 (-256)) $) 22) (($ $ (-634 (-256))) 23)) (-2618 (((-1249) $ (-763) (-763)) 40)) (-3202 (($ $) 57) (($ (-473) (-634 (-256))) 58)) (-4487 (((-1143) $) NIL)) (-3649 (((-568) $) 37)) (-4022 (((-1108) $) NIL)) (-2978 (((-1244 (-3 (-473) "undefined")) $) 36)) (-3150 (((-1244 (-2 (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)) (|:| -1526 (-568)) (|:| -4257 (-568)) (|:| |spline| (-568)) (|:| -1718 (-568)) (|:| |axesColor| (-869)) (|:| -2832 (-568)) (|:| |unitsColor| (-869)) (|:| |showing| (-568)))) $) 35)) (-2549 (((-1249) $ (-917) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-568) (-869) (-568) (-869) (-568)) 65)) (-2935 (((-634 (-944 (-215))) $) NIL)) (-2799 (((-473) $ (-917)) 32)) (-3523 (((-1249) $ (-763) (-763) (-917) (-917)) 39)) (-3299 (((-1249) $ (-1143)) 76)) (-4257 (((-1249) $ (-917) (-1143)) 72)) (-2745 (((-850) $) 82)) (-4092 (((-1249) $) 77)) (-1718 (((-1249) $ (-917) (-1143)) 68) (((-1249) $ (-917) (-869)) 69)) (-1717 (((-121) $ $) NIL))) 
-(((-1245) (-13 (-1090) (-10 -8 (-15 -2935 ((-634 (-944 (-215))) $)) (-15 -2638 ($)) (-15 -3202 ($ $)) (-15 -1480 ((-634 (-256)) $)) (-15 -1480 ($ $ (-634 (-256)))) (-15 -3202 ($ (-473) (-634 (-256)))) (-15 -2549 ((-1249) $ (-917) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-568) (-869) (-568) (-869) (-568))) (-15 -3150 ((-1244 (-2 (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)) (|:| -1526 (-568)) (|:| -4257 (-568)) (|:| |spline| (-568)) (|:| -1718 (-568)) (|:| |axesColor| (-869)) (|:| -2832 (-568)) (|:| |unitsColor| (-869)) (|:| |showing| (-568)))) $)) (-15 -2978 ((-1244 (-3 (-473) "undefined")) $)) (-15 -1784 ((-1249) $ (-1143))) (-15 -1502 ((-1249) $ (-473) (-917))) (-15 -2799 ((-473) $ (-917))) (-15 -1718 ((-1249) $ (-917) (-1143))) (-15 -1718 ((-1249) $ (-917) (-869))) (-15 -2832 ((-1249) $ (-917) (-1143))) (-15 -2832 ((-1249) $ (-917) (-869))) (-15 -1526 ((-1249) $ (-917) (-1143))) (-15 -1419 ((-1249) $ (-917) (-1143))) (-15 -4257 ((-1249) $ (-917) (-1143))) (-15 -3299 ((-1249) $ (-1143))) (-15 -4092 ((-1249) $)) (-15 -3523 ((-1249) $ (-763) (-763) (-917) (-917))) (-15 -3646 ((-1249) $ (-917) (-381) (-381))) (-15 -1859 ((-1249) $ (-917) (-381) (-381))) (-15 -1647 ((-1249) $ (-917) (-1143))) (-15 -2618 ((-1249) $ (-763) (-763))) (-15 -2967 ((-1249) $ (-473) (-917))) (-15 -1476 ((-1249) $ (-917) (-917))) (-15 -2323 ((-1143) $ (-1143))) (-15 -2323 ((-1143) $ (-1143) (-1143))) (-15 -2323 ((-1143) $ (-1143) (-634 (-1143)))) (-15 -2316 ((-1249) $)) (-15 -3649 ((-568) $)) (-15 -2745 ((-850) $))))) (T -1245)) 
-((-2745 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1245)))) (-2935 (*1 *2 *1) (-12 (-5 *2 (-634 (-944 (-215)))) (-5 *1 (-1245)))) (-2638 (*1 *1) (-5 *1 (-1245))) (-3202 (*1 *1 *1) (-5 *1 (-1245))) (-1480 (*1 *2 *1) (-12 (-5 *2 (-634 (-256))) (-5 *1 (-1245)))) (-1480 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-256))) (-5 *1 (-1245)))) (-3202 (*1 *1 *2 *3) (-12 (-5 *2 (-473)) (-5 *3 (-634 (-256))) (-5 *1 (-1245)))) (-2549 (*1 *2 *1 *3 *4 *4 *4 *4 *5 *5 *5 *5 *6 *5 *6 *5) (-12 (-5 *3 (-917)) (-5 *4 (-215)) (-5 *5 (-568)) (-5 *6 (-869)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-3150 (*1 *2 *1) (-12 (-5 *2 (-1244 (-2 (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)) (|:| -1526 (-568)) (|:| -4257 (-568)) (|:| |spline| (-568)) (|:| -1718 (-568)) (|:| |axesColor| (-869)) (|:| -2832 (-568)) (|:| |unitsColor| (-869)) (|:| |showing| (-568))))) (-5 *1 (-1245)))) (-2978 (*1 *2 *1) (-12 (-5 *2 (-1244 (-3 (-473) "undefined"))) (-5 *1 (-1245)))) (-1784 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-1502 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-473)) (-5 *4 (-917)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-2799 (*1 *2 *1 *3) (-12 (-5 *3 (-917)) (-5 *2 (-473)) (-5 *1 (-1245)))) (-1718 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-1718 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-869)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-2832 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-2832 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-869)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-1526 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-1419 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-4257 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-3299 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-4092 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-1245)))) (-3523 (*1 *2 *1 *3 *3 *4 *4) (-12 (-5 *3 (-763)) (-5 *4 (-917)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-3646 (*1 *2 *1 *3 *4 *4) (-12 (-5 *3 (-917)) (-5 *4 (-381)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-1859 (*1 *2 *1 *3 *4 *4) (-12 (-5 *3 (-917)) (-5 *4 (-381)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-1647 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-2618 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-2967 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-473)) (-5 *4 (-917)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-1476 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-2323 (*1 *2 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1245)))) (-2323 (*1 *2 *1 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1245)))) (-2323 (*1 *2 *1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-1143)) (-5 *1 (-1245)))) (-2316 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-1245)))) (-3649 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1245))))) 
-(-13 (-1090) (-10 -8 (-15 -2935 ((-634 (-944 (-215))) $)) (-15 -2638 ($)) (-15 -3202 ($ $)) (-15 -1480 ((-634 (-256)) $)) (-15 -1480 ($ $ (-634 (-256)))) (-15 -3202 ($ (-473) (-634 (-256)))) (-15 -2549 ((-1249) $ (-917) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-568) (-869) (-568) (-869) (-568))) (-15 -3150 ((-1244 (-2 (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)) (|:| -1526 (-568)) (|:| -4257 (-568)) (|:| |spline| (-568)) (|:| -1718 (-568)) (|:| |axesColor| (-869)) (|:| -2832 (-568)) (|:| |unitsColor| (-869)) (|:| |showing| (-568)))) $)) (-15 -2978 ((-1244 (-3 (-473) "undefined")) $)) (-15 -1784 ((-1249) $ (-1143))) (-15 -1502 ((-1249) $ (-473) (-917))) (-15 -2799 ((-473) $ (-917))) (-15 -1718 ((-1249) $ (-917) (-1143))) (-15 -1718 ((-1249) $ (-917) (-869))) (-15 -2832 ((-1249) $ (-917) (-1143))) (-15 -2832 ((-1249) $ (-917) (-869))) (-15 -1526 ((-1249) $ (-917) (-1143))) (-15 -1419 ((-1249) $ (-917) (-1143))) (-15 -4257 ((-1249) $ (-917) (-1143))) (-15 -3299 ((-1249) $ (-1143))) (-15 -4092 ((-1249) $)) (-15 -3523 ((-1249) $ (-763) (-763) (-917) (-917))) (-15 -3646 ((-1249) $ (-917) (-381) (-381))) (-15 -1859 ((-1249) $ (-917) (-381) (-381))) (-15 -1647 ((-1249) $ (-917) (-1143))) (-15 -2618 ((-1249) $ (-763) (-763))) (-15 -2967 ((-1249) $ (-473) (-917))) (-15 -1476 ((-1249) $ (-917) (-917))) (-15 -2323 ((-1143) $ (-1143))) (-15 -2323 ((-1143) $ (-1143) (-1143))) (-15 -2323 ((-1143) $ (-1143) (-634 (-1143)))) (-15 -2316 ((-1249) $)) (-15 -3649 ((-568) $)) (-15 -2745 ((-850) $)))) 
-((-2447 (((-121) $ $) NIL)) (-2868 (((-1249) $ (-381)) 138) (((-1249) $ (-381) (-381) (-381)) 139)) (-2323 (((-1143) $ (-1143)) 146) (((-1143) $ (-1143) (-1143)) 144) (((-1143) $ (-1143) (-634 (-1143))) 143)) (-3482 (($) 49)) (-2501 (((-1249) $ (-381) (-381) (-381) (-381) (-381)) 114) (((-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))) $) 112) (((-1249) $ (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)))) 113) (((-1249) $ (-568) (-568) (-381) (-381) (-381)) 115) (((-1249) $ (-381) (-381)) 116) (((-1249) $ (-381) (-381) (-381)) 123)) (-2474 (((-381)) 96) (((-381) (-381)) 97)) (-3397 (((-381)) 91) (((-381) (-381)) 93)) (-2194 (((-381)) 94) (((-381) (-381)) 95)) (-1598 (((-381)) 100) (((-381) (-381)) 101)) (-1479 (((-381)) 98) (((-381) (-381)) 99)) (-1859 (((-1249) $ (-381) (-381)) 140)) (-1784 (((-1249) $ (-1143)) 124)) (-2141 (((-1121 (-215)) $) 50) (($ $ (-1121 (-215))) 51)) (-3707 (((-1249) $ (-1143)) 152)) (-2358 (((-1249) $ (-1143)) 153)) (-1646 (((-1249) $ (-381) (-381)) 122) (((-1249) $ (-568) (-568)) 137)) (-1476 (((-1249) $ (-917) (-917)) 130)) (-2316 (((-1249) $) 110)) (-1931 (((-1249) $ (-1143)) 151)) (-4072 (((-1249) $ (-1143)) 107)) (-1480 (((-634 (-256)) $) 52) (($ $ (-634 (-256))) 53)) (-2618 (((-1249) $ (-763) (-763)) 129)) (-1524 (((-1249) $ (-763) (-944 (-215))) 158)) (-4215 (($ $) 56) (($ (-1121 (-215)) (-1143)) 57) (($ (-1121 (-215)) (-634 (-256))) 58)) (-2557 (((-1249) $ (-381) (-381) (-381)) 104)) (-4487 (((-1143) $) NIL)) (-3649 (((-568) $) 102)) (-3997 (((-1249) $ (-381)) 141)) (-3012 (((-1249) $ (-381)) 156)) (-4022 (((-1108) $) NIL)) (-3321 (((-1249) $ (-381)) 155)) (-2105 (((-1249) $ (-1143)) 109)) (-3523 (((-1249) $ (-763) (-763) (-917) (-917)) 128)) (-1839 (((-1249) $ (-1143)) 106)) (-3299 (((-1249) $ (-1143)) 108)) (-3941 (((-1249) $ (-158) (-158)) 127)) (-2745 (((-850) $) 135)) (-4092 (((-1249) $) 111)) (-2147 (((-1249) $ (-1143)) 154)) (-1718 (((-1249) $ (-1143)) 105)) (-1717 (((-121) $ $) NIL))) 
-(((-1246) (-13 (-1090) (-10 -8 (-15 -3397 ((-381))) (-15 -3397 ((-381) (-381))) (-15 -2194 ((-381))) (-15 -2194 ((-381) (-381))) (-15 -2474 ((-381))) (-15 -2474 ((-381) (-381))) (-15 -1479 ((-381))) (-15 -1479 ((-381) (-381))) (-15 -1598 ((-381))) (-15 -1598 ((-381) (-381))) (-15 -3482 ($)) (-15 -4215 ($ $)) (-15 -4215 ($ (-1121 (-215)) (-1143))) (-15 -4215 ($ (-1121 (-215)) (-634 (-256)))) (-15 -2141 ((-1121 (-215)) $)) (-15 -2141 ($ $ (-1121 (-215)))) (-15 -1524 ((-1249) $ (-763) (-944 (-215)))) (-15 -1480 ((-634 (-256)) $)) (-15 -1480 ($ $ (-634 (-256)))) (-15 -2618 ((-1249) $ (-763) (-763))) (-15 -1476 ((-1249) $ (-917) (-917))) (-15 -1784 ((-1249) $ (-1143))) (-15 -3523 ((-1249) $ (-763) (-763) (-917) (-917))) (-15 -2501 ((-1249) $ (-381) (-381) (-381) (-381) (-381))) (-15 -2501 ((-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))) $)) (-15 -2501 ((-1249) $ (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))))) (-15 -2501 ((-1249) $ (-568) (-568) (-381) (-381) (-381))) (-15 -2501 ((-1249) $ (-381) (-381))) (-15 -2501 ((-1249) $ (-381) (-381) (-381))) (-15 -3299 ((-1249) $ (-1143))) (-15 -1718 ((-1249) $ (-1143))) (-15 -1839 ((-1249) $ (-1143))) (-15 -4072 ((-1249) $ (-1143))) (-15 -2105 ((-1249) $ (-1143))) (-15 -1646 ((-1249) $ (-381) (-381))) (-15 -1646 ((-1249) $ (-568) (-568))) (-15 -2868 ((-1249) $ (-381))) (-15 -2868 ((-1249) $ (-381) (-381) (-381))) (-15 -1859 ((-1249) $ (-381) (-381))) (-15 -1931 ((-1249) $ (-1143))) (-15 -3321 ((-1249) $ (-381))) (-15 -3012 ((-1249) $ (-381))) (-15 -3707 ((-1249) $ (-1143))) (-15 -2358 ((-1249) $ (-1143))) (-15 -2147 ((-1249) $ (-1143))) (-15 -2557 ((-1249) $ (-381) (-381) (-381))) (-15 -3997 ((-1249) $ (-381))) (-15 -2316 ((-1249) $)) (-15 -3941 ((-1249) $ (-158) (-158))) (-15 -2323 ((-1143) $ (-1143))) (-15 -2323 ((-1143) $ (-1143) (-1143))) (-15 -2323 ((-1143) $ (-1143) (-634 (-1143)))) (-15 -4092 ((-1249) $)) (-15 -3649 ((-568) $))))) (T -1246)) 
-((-3397 (*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) (-3397 (*1 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) (-2194 (*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) (-2194 (*1 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) (-2474 (*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) (-2474 (*1 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) (-1479 (*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) (-1479 (*1 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) (-1598 (*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) (-1598 (*1 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) (-3482 (*1 *1) (-5 *1 (-1246))) (-4215 (*1 *1 *1) (-5 *1 (-1246))) (-4215 (*1 *1 *2 *3) (-12 (-5 *2 (-1121 (-215))) (-5 *3 (-1143)) (-5 *1 (-1246)))) (-4215 (*1 *1 *2 *3) (-12 (-5 *2 (-1121 (-215))) (-5 *3 (-634 (-256))) (-5 *1 (-1246)))) (-2141 (*1 *2 *1) (-12 (-5 *2 (-1121 (-215))) (-5 *1 (-1246)))) (-2141 (*1 *1 *1 *2) (-12 (-5 *2 (-1121 (-215))) (-5 *1 (-1246)))) (-1524 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-763)) (-5 *4 (-944 (-215))) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-1480 (*1 *2 *1) (-12 (-5 *2 (-634 (-256))) (-5 *1 (-1246)))) (-1480 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-256))) (-5 *1 (-1246)))) (-2618 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-1476 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-1784 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-3523 (*1 *2 *1 *3 *3 *4 *4) (-12 (-5 *3 (-763)) (-5 *4 (-917)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-2501 (*1 *2 *1 *3 *3 *3 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-2501 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)))) (-5 *1 (-1246)))) (-2501 (*1 *2 *1 *3) (-12 (-5 *3 (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)))) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-2501 (*1 *2 *1 *3 *3 *4 *4 *4) (-12 (-5 *3 (-568)) (-5 *4 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-2501 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-2501 (*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-3299 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-1718 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-1839 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-4072 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-2105 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-1646 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-1646 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-2868 (*1 *2 *1 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-2868 (*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-1859 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-1931 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-3321 (*1 *2 *1 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-3012 (*1 *2 *1 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-3707 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-2358 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-2147 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-2557 (*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-3997 (*1 *2 *1 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-2316 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-1246)))) (-3941 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-158)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-2323 (*1 *2 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1246)))) (-2323 (*1 *2 *1 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1246)))) (-2323 (*1 *2 *1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-1143)) (-5 *1 (-1246)))) (-4092 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-1246)))) (-3649 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1246))))) 
-(-13 (-1090) (-10 -8 (-15 -3397 ((-381))) (-15 -3397 ((-381) (-381))) (-15 -2194 ((-381))) (-15 -2194 ((-381) (-381))) (-15 -2474 ((-381))) (-15 -2474 ((-381) (-381))) (-15 -1479 ((-381))) (-15 -1479 ((-381) (-381))) (-15 -1598 ((-381))) (-15 -1598 ((-381) (-381))) (-15 -3482 ($)) (-15 -4215 ($ $)) (-15 -4215 ($ (-1121 (-215)) (-1143))) (-15 -4215 ($ (-1121 (-215)) (-634 (-256)))) (-15 -2141 ((-1121 (-215)) $)) (-15 -2141 ($ $ (-1121 (-215)))) (-15 -1524 ((-1249) $ (-763) (-944 (-215)))) (-15 -1480 ((-634 (-256)) $)) (-15 -1480 ($ $ (-634 (-256)))) (-15 -2618 ((-1249) $ (-763) (-763))) (-15 -1476 ((-1249) $ (-917) (-917))) (-15 -1784 ((-1249) $ (-1143))) (-15 -3523 ((-1249) $ (-763) (-763) (-917) (-917))) (-15 -2501 ((-1249) $ (-381) (-381) (-381) (-381) (-381))) (-15 -2501 ((-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))) $)) (-15 -2501 ((-1249) $ (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))))) (-15 -2501 ((-1249) $ (-568) (-568) (-381) (-381) (-381))) (-15 -2501 ((-1249) $ (-381) (-381))) (-15 -2501 ((-1249) $ (-381) (-381) (-381))) (-15 -3299 ((-1249) $ (-1143))) (-15 -1718 ((-1249) $ (-1143))) (-15 -1839 ((-1249) $ (-1143))) (-15 -4072 ((-1249) $ (-1143))) (-15 -2105 ((-1249) $ (-1143))) (-15 -1646 ((-1249) $ (-381) (-381))) (-15 -1646 ((-1249) $ (-568) (-568))) (-15 -2868 ((-1249) $ (-381))) (-15 -2868 ((-1249) $ (-381) (-381) (-381))) (-15 -1859 ((-1249) $ (-381) (-381))) (-15 -1931 ((-1249) $ (-1143))) (-15 -3321 ((-1249) $ (-381))) (-15 -3012 ((-1249) $ (-381))) (-15 -3707 ((-1249) $ (-1143))) (-15 -2358 ((-1249) $ (-1143))) (-15 -2147 ((-1249) $ (-1143))) (-15 -2557 ((-1249) $ (-381) (-381) (-381))) (-15 -3997 ((-1249) $ (-381))) (-15 -2316 ((-1249) $)) (-15 -3941 ((-1249) $ (-158) (-158))) (-15 -2323 ((-1143) $ (-1143))) (-15 -2323 ((-1143) $ (-1143) (-1143))) (-15 -2323 ((-1143) $ (-1143) (-634 (-1143)))) (-15 -4092 ((-1249) $)) (-15 -3649 ((-568) $)))) 
-((-4233 (((-634 (-1143)) (-634 (-1143))) 94) (((-634 (-1143))) 89)) (-1376 (((-634 (-1143))) 87)) (-4365 (((-634 (-917)) (-634 (-917))) 62) (((-634 (-917))) 59)) (-3096 (((-634 (-763)) (-634 (-763))) 56) (((-634 (-763))) 52)) (-3655 (((-1249)) 64)) (-2015 (((-917) (-917)) 80) (((-917)) 79)) (-2398 (((-917) (-917)) 78) (((-917)) 77)) (-3645 (((-869) (-869)) 74) (((-869)) 73)) (-4008 (((-215)) 84) (((-215) (-381)) 86)) (-2431 (((-917)) 81) (((-917) (-917)) 82)) (-3756 (((-917) (-917)) 76) (((-917)) 75)) (-2486 (((-869) (-869)) 68) (((-869)) 66)) (-2852 (((-869) (-869)) 70) (((-869)) 69)) (-1321 (((-869) (-869)) 72) (((-869)) 71))) 
-(((-1247) (-10 -7 (-15 -2486 ((-869))) (-15 -2486 ((-869) (-869))) (-15 -2852 ((-869))) (-15 -2852 ((-869) (-869))) (-15 -1321 ((-869))) (-15 -1321 ((-869) (-869))) (-15 -3645 ((-869))) (-15 -3645 ((-869) (-869))) (-15 -3756 ((-917))) (-15 -3756 ((-917) (-917))) (-15 -3096 ((-634 (-763)))) (-15 -3096 ((-634 (-763)) (-634 (-763)))) (-15 -4365 ((-634 (-917)))) (-15 -4365 ((-634 (-917)) (-634 (-917)))) (-15 -3655 ((-1249))) (-15 -4233 ((-634 (-1143)))) (-15 -4233 ((-634 (-1143)) (-634 (-1143)))) (-15 -1376 ((-634 (-1143)))) (-15 -2398 ((-917))) (-15 -2015 ((-917))) (-15 -2398 ((-917) (-917))) (-15 -2015 ((-917) (-917))) (-15 -2431 ((-917) (-917))) (-15 -2431 ((-917))) (-15 -4008 ((-215) (-381))) (-15 -4008 ((-215))))) (T -1247)) 
-((-4008 (*1 *2) (-12 (-5 *2 (-215)) (-5 *1 (-1247)))) (-4008 (*1 *2 *3) (-12 (-5 *3 (-381)) (-5 *2 (-215)) (-5 *1 (-1247)))) (-2431 (*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) (-2431 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) (-2015 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) (-2398 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) (-2015 (*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) (-2398 (*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) (-1376 (*1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1247)))) (-4233 (*1 *2 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1247)))) (-4233 (*1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1247)))) (-3655 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1247)))) (-4365 (*1 *2 *2) (-12 (-5 *2 (-634 (-917))) (-5 *1 (-1247)))) (-4365 (*1 *2) (-12 (-5 *2 (-634 (-917))) (-5 *1 (-1247)))) (-3096 (*1 *2 *2) (-12 (-5 *2 (-634 (-763))) (-5 *1 (-1247)))) (-3096 (*1 *2) (-12 (-5 *2 (-634 (-763))) (-5 *1 (-1247)))) (-3756 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) (-3756 (*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) (-3645 (*1 *2 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247)))) (-3645 (*1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247)))) (-1321 (*1 *2 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247)))) (-1321 (*1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247)))) (-2852 (*1 *2 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247)))) (-2852 (*1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247)))) (-2486 (*1 *2 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247)))) (-2486 (*1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247))))) 
-(-10 -7 (-15 -2486 ((-869))) (-15 -2486 ((-869) (-869))) (-15 -2852 ((-869))) (-15 -2852 ((-869) (-869))) (-15 -1321 ((-869))) (-15 -1321 ((-869) (-869))) (-15 -3645 ((-869))) (-15 -3645 ((-869) (-869))) (-15 -3756 ((-917))) (-15 -3756 ((-917) (-917))) (-15 -3096 ((-634 (-763)))) (-15 -3096 ((-634 (-763)) (-634 (-763)))) (-15 -4365 ((-634 (-917)))) (-15 -4365 ((-634 (-917)) (-634 (-917)))) (-15 -3655 ((-1249))) (-15 -4233 ((-634 (-1143)))) (-15 -4233 ((-634 (-1143)) (-634 (-1143)))) (-15 -1376 ((-634 (-1143)))) (-15 -2398 ((-917))) (-15 -2015 ((-917))) (-15 -2398 ((-917) (-917))) (-15 -2015 ((-917) (-917))) (-15 -2431 ((-917) (-917))) (-15 -2431 ((-917))) (-15 -4008 ((-215) (-381))) (-15 -4008 ((-215)))) 
-((-3623 (((-473) (-634 (-634 (-944 (-215)))) (-634 (-256))) 17) (((-473) (-634 (-634 (-944 (-215))))) 16) (((-473) (-634 (-634 (-944 (-215)))) (-869) (-869) (-917) (-634 (-256))) 15)) (-3317 (((-1245) (-634 (-634 (-944 (-215)))) (-634 (-256))) 23) (((-1245) (-634 (-634 (-944 (-215)))) (-869) (-869) (-917) (-634 (-256))) 22)) (-2745 (((-1245) (-473)) 34))) 
-(((-1248) (-10 -7 (-15 -3623 ((-473) (-634 (-634 (-944 (-215)))) (-869) (-869) (-917) (-634 (-256)))) (-15 -3623 ((-473) (-634 (-634 (-944 (-215)))))) (-15 -3623 ((-473) (-634 (-634 (-944 (-215)))) (-634 (-256)))) (-15 -3317 ((-1245) (-634 (-634 (-944 (-215)))) (-869) (-869) (-917) (-634 (-256)))) (-15 -3317 ((-1245) (-634 (-634 (-944 (-215)))) (-634 (-256)))) (-15 -2745 ((-1245) (-473))))) (T -1248)) 
-((-2745 (*1 *2 *3) (-12 (-5 *3 (-473)) (-5 *2 (-1245)) (-5 *1 (-1248)))) (-3317 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *4 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-1248)))) (-3317 (*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *4 (-869)) (-5 *5 (-917)) (-5 *6 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-1248)))) (-3623 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *4 (-634 (-256))) (-5 *2 (-473)) (-5 *1 (-1248)))) (-3623 (*1 *2 *3) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *2 (-473)) (-5 *1 (-1248)))) (-3623 (*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *4 (-869)) (-5 *5 (-917)) (-5 *6 (-634 (-256))) (-5 *2 (-473)) (-5 *1 (-1248))))) 
-(-10 -7 (-15 -3623 ((-473) (-634 (-634 (-944 (-215)))) (-869) (-869) (-917) (-634 (-256)))) (-15 -3623 ((-473) (-634 (-634 (-944 (-215)))))) (-15 -3623 ((-473) (-634 (-634 (-944 (-215)))) (-634 (-256)))) (-15 -3317 ((-1245) (-634 (-634 (-944 (-215)))) (-869) (-869) (-917) (-634 (-256)))) (-15 -3317 ((-1245) (-634 (-634 (-944 (-215)))) (-634 (-256)))) (-15 -2745 ((-1245) (-473)))) 
-((-3611 (($) 7)) (-2745 (((-850) $) 10))) 
-(((-1249) (-10 -8 (-15 -3611 ($)) (-15 -2745 ((-850) $)))) (T -1249)) 
-((-2745 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1249)))) (-3611 (*1 *1) (-5 *1 (-1249)))) 
-(-10 -8 (-15 -3611 ($)) (-15 -2745 ((-850) $))) 
-((-1779 (($ $ |#2|) 10))) 
-(((-1250 |#1| |#2|) (-10 -8 (-15 -1779 (|#1| |#1| |#2|))) (-1251 |#2|) (-365)) (T -1250)) 
-NIL 
-(-10 -8 (-15 -1779 (|#1| |#1| |#2|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-4321 (((-139)) 25)) (-2745 (((-850) $) 11)) (-3056 (($) 17 T CONST)) (-1717 (((-121) $ $) 6)) (-1779 (($ $ |#1|) 26)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ |#1| $) 22) (($ $ |#1|) 24))) 
+((-1769 (*1 *1 *1 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-25)))) (-3207 (*1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1242 *3)) (-4 *3 (-23)) (-4 *3 (-1195)))) (-1775 (*1 *1 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-21)))) (-1775 (*1 *1 *1 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-21)))) (* (*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-4 *1 (-1242 *3)) (-4 *3 (-1195)) (-4 *3 (-21)))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-716)))) (* (*1 *1 *1 *2) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-716)))) (-2286 (*1 *2 *1 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-1047)))) (-1804 (*1 *2 *1 *1) (-12 (-4 *1 (-1242 *3)) (-4 *3 (-1195)) (-4 *3 (-1047)) (-5 *2 (-679 *3)))) (-3372 (*1 *1 *1 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-1047)))) (-3680 (*1 *2 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-1002)) (-4 *2 (-1047)))) (-4303 (*1 *2 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-1002)) (-4 *2 (-1047))))) 
+(-13 (-19 |t#1|) (-10 -8 (IF (|has| |t#1| (-25)) (-15 -1769 ($ $ $)) |noBranch|) (IF (|has| |t#1| (-23)) (-15 -3207 ($ (-763))) |noBranch|) (IF (|has| |t#1| (-21)) (PROGN (-15 -1775 ($ $)) (-15 -1775 ($ $ $)) (-15 * ($ (-568) $))) |noBranch|) (IF (|has| |t#1| (-716)) (PROGN (-15 * ($ |t#1| $)) (-15 * ($ $ |t#1|))) |noBranch|) (IF (|has| |t#1| (-1047)) (PROGN (-15 -2286 (|t#1| $ $)) (-15 -1804 ((-679 |t#1|) $ $)) (-15 -3372 ($ $ $))) |noBranch|) (IF (|has| |t#1| (-1002)) (IF (|has| |t#1| (-1047)) (PROGN (-15 -3680 (|t#1| $)) (-15 -4303 (|t#1| $))) |noBranch|) |noBranch|))) 
+(((-39) . T) ((-105) -2199 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-608 (-850)) -2199 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-154 |#1|) . T) ((-609 (-541)) |has| |#1| (-609 (-541))) ((-281 (-568) |#1|) . T) ((-283 (-568) |#1|) . T) ((-303 |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-375 |#1|) . T) ((-499 |#1|) . T) ((-601 (-568) |#1|) . T) ((-523 |#1| |#1|) -12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))) ((-640 |#1|) . T) ((-19 |#1|) . T) ((-842) |has| |#1| (-842)) ((-1090) -2199 (|has| |#1| (-1090)) (|has| |#1| (-842))) ((-1195) . T)) 
+((-1678 (((-1244 |#2|) (-1 |#2| |#1| |#2|) (-1244 |#1|) |#2|) 13)) (-3094 ((|#2| (-1 |#2| |#1| |#2|) (-1244 |#1|) |#2|) 15)) (-2797 (((-3 (-1244 |#2|) "failed") (-1 (-3 |#2| "failed") |#1|) (-1244 |#1|)) 28) (((-1244 |#2|) (-1 |#2| |#1|) (-1244 |#1|)) 18))) 
+(((-1243 |#1| |#2|) (-10 -7 (-15 -1678 ((-1244 |#2|) (-1 |#2| |#1| |#2|) (-1244 |#1|) |#2|)) (-15 -3094 (|#2| (-1 |#2| |#1| |#2|) (-1244 |#1|) |#2|)) (-15 -2797 ((-1244 |#2|) (-1 |#2| |#1|) (-1244 |#1|))) (-15 -2797 ((-3 (-1244 |#2|) "failed") (-1 (-3 |#2| "failed") |#1|) (-1244 |#1|)))) (-1195) (-1195)) (T -1243)) 
+((-2797 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *6 "failed") *5)) (-5 *4 (-1244 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1244 *6)) (-5 *1 (-1243 *5 *6)))) (-2797 (*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1244 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1244 *6)) (-5 *1 (-1243 *5 *6)))) (-3094 (*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-1244 *5)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-1243 *5 *2)))) (-1678 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-1244 *6)) (-4 *6 (-1195)) (-4 *5 (-1195)) (-5 *2 (-1244 *5)) (-5 *1 (-1243 *6 *5))))) 
+(-10 -7 (-15 -1678 ((-1244 |#2|) (-1 |#2| |#1| |#2|) (-1244 |#1|) |#2|)) (-15 -3094 (|#2| (-1 |#2| |#1| |#2|) (-1244 |#1|) |#2|)) (-15 -2797 ((-1244 |#2|) (-1 |#2| |#1|) (-1244 |#1|))) (-15 -2797 ((-3 (-1244 |#2|) "failed") (-1 (-3 |#2| "failed") |#1|) (-1244 |#1|)))) 
+((-2449 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-3207 (($ (-763)) NIL (|has| |#1| (-23)))) (-4211 (($ (-634 |#1|)) 9)) (-2481 (((-1249) $ (-568) (-568)) NIL (|has| $ (-6 -4522)))) (-1324 (((-121) (-1 (-121) |#1| |#1|) $) NIL) (((-121) $) NIL (|has| |#1| (-842)))) (-2109 (($ (-1 (-121) |#1| |#1|) $) NIL (|has| $ (-6 -4522))) (($ $) NIL (-12 (|has| $ (-6 -4522)) (|has| |#1| (-842))))) (-3647 (($ (-1 (-121) |#1| |#1|) $) NIL) (($ $) NIL (|has| |#1| (-842)))) (-1667 (((-121) $ (-763)) NIL)) (-2438 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4522))) ((|#1| $ (-1210 (-568)) |#1|) NIL (|has| $ (-6 -4522)))) (-2803 (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-4490 (($) NIL T CONST)) (-4452 (($ $) NIL (|has| $ (-6 -4522)))) (-3945 (($ $) NIL)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-4330 (($ |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) (($ (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-3094 ((|#1| (-1 |#1| |#1| |#1|) $ |#1| |#1|) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090)))) ((|#1| (-1 |#1| |#1| |#1|) $ |#1|) NIL (|has| $ (-6 -4521))) ((|#1| (-1 |#1| |#1| |#1|) $) NIL (|has| $ (-6 -4521)))) (-1292 ((|#1| $ (-568) |#1|) NIL (|has| $ (-6 -4522)))) (-2069 ((|#1| $ (-568)) NIL)) (-2766 (((-568) (-1 (-121) |#1|) $) NIL) (((-568) |#1| $) NIL (|has| |#1| (-1090))) (((-568) |#1| $ (-568)) NIL (|has| |#1| (-1090)))) (-3317 (((-634 |#1|) $) 15 (|has| $ (-6 -4521)))) (-1804 (((-679 |#1|) $ $) NIL (|has| |#1| (-1047)))) (-1851 (($ (-763) |#1|) NIL)) (-3791 (((-121) $ (-763)) NIL)) (-2539 (((-568) $) NIL (|has| (-568) (-842)))) (-1732 (($ $ $) NIL (|has| |#1| (-842)))) (-3645 (($ (-1 (-121) |#1| |#1|) $ $) NIL) (($ $ $) NIL (|has| |#1| (-842)))) (-4406 (((-634 |#1|) $) NIL (|has| $ (-6 -4521)))) (-2551 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3631 (((-568) $) NIL (|has| (-568) (-842)))) (-2047 (($ $ $) NIL (|has| |#1| (-842)))) (-2253 (($ (-1 |#1| |#1|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#1| |#1|) $) NIL) (($ (-1 |#1| |#1| |#1|) $ $) NIL)) (-4303 ((|#1| $) NIL (-12 (|has| |#1| (-1002)) (|has| |#1| (-1047))))) (-3796 (((-121) $ (-763)) NIL)) (-3680 ((|#1| $) NIL (-12 (|has| |#1| (-1002)) (|has| |#1| (-1047))))) (-1893 (((-1143) $) NIL (|has| |#1| (-1090)))) (-4124 (($ |#1| $ (-568)) NIL) (($ $ $ (-568)) NIL)) (-3948 (((-634 (-568)) $) NIL)) (-2916 (((-121) (-568) $) NIL)) (-4025 (((-1108) $) NIL (|has| |#1| (-1090)))) (-3877 ((|#1| $) NIL (|has| (-568) (-842)))) (-2712 (((-3 |#1| "failed") (-1 (-121) |#1|) $) NIL)) (-2490 (($ $ |#1|) NIL (|has| $ (-6 -4522)))) (-3951 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 (-288 |#1|))) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-288 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ |#1| |#1|) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090)))) (($ $ (-634 |#1|) (-634 |#1|)) NIL (-12 (|has| |#1| (-303 |#1|)) (|has| |#1| (-1090))))) (-1702 (((-121) $ $) NIL)) (-1801 (((-121) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-1480 (((-634 |#1|) $) NIL)) (-2436 (((-121) $) NIL)) (-1990 (($) NIL)) (-2781 ((|#1| $ (-568) |#1|) NIL) ((|#1| $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-2286 ((|#1| $ $) NIL (|has| |#1| (-1047)))) (-2828 (($ $ (-568)) NIL) (($ $ (-1210 (-568))) NIL)) (-3372 (($ $ $) NIL (|has| |#1| (-1047)))) (-4170 (((-763) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521))) (((-763) |#1| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#1| (-1090))))) (-3306 (($ $ $ (-568)) NIL (|has| $ (-6 -4522)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) 19 (|has| |#1| (-609 (-541))))) (-4289 (($ (-634 |#1|)) 8)) (-2770 (($ $ |#1|) NIL) (($ |#1| $) NIL) (($ $ $) NIL) (($ (-634 $)) NIL)) (-2747 (((-850) $) NIL (|has| |#1| (-1090)))) (-3437 (((-121) (-1 (-121) |#1|) $) NIL (|has| $ (-6 -4521)))) (-1753 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1740 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1719 (((-121) $ $) NIL (|has| |#1| (-1090)))) (-1747 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1734 (((-121) $ $) NIL (|has| |#1| (-842)))) (-1775 (($ $) NIL (|has| |#1| (-21))) (($ $ $) NIL (|has| |#1| (-21)))) (-1769 (($ $ $) NIL (|has| |#1| (-25)))) (* (($ (-568) $) NIL (|has| |#1| (-21))) (($ |#1| $) NIL (|has| |#1| (-716))) (($ $ |#1|) NIL (|has| |#1| (-716)))) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-1244 |#1|) (-13 (-1242 |#1|) (-10 -8 (-15 -4211 ($ (-634 |#1|))))) (-1195)) (T -1244)) 
+((-4211 (*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-1244 *3))))) 
+(-13 (-1242 |#1|) (-10 -8 (-15 -4211 ($ (-634 |#1|))))) 
+((-2449 (((-121) $ $) NIL)) (-2325 (((-1143) $ (-1143)) 87) (((-1143) $ (-1143) (-1143)) 85) (((-1143) $ (-1143) (-634 (-1143))) 84)) (-4305 (($) 56)) (-2969 (((-1249) $ (-473) (-917)) 42)) (-2833 (((-1249) $ (-917) (-1143)) 70) (((-1249) $ (-917) (-869)) 71)) (-1861 (((-1249) $ (-917) (-381) (-381)) 45)) (-4037 (((-1249) $ (-1143)) 66)) (-1649 (((-1249) $ (-917) (-1143)) 75)) (-3225 (((-1249) $ (-917) (-381) (-381)) 46)) (-2492 (((-1249) $ (-917) (-917)) 43)) (-2318 (((-1249) $) 67)) (-2176 (((-1249) $ (-917) (-1143)) 74)) (-2619 (((-1249) $ (-473) (-917)) 30)) (-4158 (((-1249) $ (-917) (-1143)) 73)) (-2508 (((-634 (-256)) $) 22) (($ $ (-634 (-256))) 23)) (-4186 (((-1249) $ (-763) (-763)) 40)) (-1828 (($ $) 57) (($ (-473) (-634 (-256))) 58)) (-1893 (((-1143) $) NIL)) (-3651 (((-568) $) 37)) (-4025 (((-1108) $) NIL)) (-3066 (((-1244 (-3 (-473) "undefined")) $) 36)) (-2746 (((-1244 (-2 (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)) (|:| -4158 (-568)) (|:| -2887 (-568)) (|:| |spline| (-568)) (|:| -3705 (-568)) (|:| |axesColor| (-869)) (|:| -2833 (-568)) (|:| |unitsColor| (-869)) (|:| |showing| (-568)))) $) 35)) (-1874 (((-1249) $ (-917) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-568) (-869) (-568) (-869) (-568)) 65)) (-2927 (((-634 (-944 (-215))) $) NIL)) (-3639 (((-473) $ (-917)) 32)) (-4076 (((-1249) $ (-763) (-763) (-917) (-917)) 39)) (-4225 (((-1249) $ (-1143)) 76)) (-2887 (((-1249) $ (-917) (-1143)) 72)) (-2747 (((-850) $) 82)) (-4094 (((-1249) $) 77)) (-3705 (((-1249) $ (-917) (-1143)) 68) (((-1249) $ (-917) (-869)) 69)) (-1719 (((-121) $ $) NIL))) 
+(((-1245) (-13 (-1090) (-10 -8 (-15 -2927 ((-634 (-944 (-215))) $)) (-15 -4305 ($)) (-15 -1828 ($ $)) (-15 -2508 ((-634 (-256)) $)) (-15 -2508 ($ $ (-634 (-256)))) (-15 -1828 ($ (-473) (-634 (-256)))) (-15 -1874 ((-1249) $ (-917) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-568) (-869) (-568) (-869) (-568))) (-15 -2746 ((-1244 (-2 (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)) (|:| -4158 (-568)) (|:| -2887 (-568)) (|:| |spline| (-568)) (|:| -3705 (-568)) (|:| |axesColor| (-869)) (|:| -2833 (-568)) (|:| |unitsColor| (-869)) (|:| |showing| (-568)))) $)) (-15 -3066 ((-1244 (-3 (-473) "undefined")) $)) (-15 -4037 ((-1249) $ (-1143))) (-15 -2619 ((-1249) $ (-473) (-917))) (-15 -3639 ((-473) $ (-917))) (-15 -3705 ((-1249) $ (-917) (-1143))) (-15 -3705 ((-1249) $ (-917) (-869))) (-15 -2833 ((-1249) $ (-917) (-1143))) (-15 -2833 ((-1249) $ (-917) (-869))) (-15 -4158 ((-1249) $ (-917) (-1143))) (-15 -2176 ((-1249) $ (-917) (-1143))) (-15 -2887 ((-1249) $ (-917) (-1143))) (-15 -4225 ((-1249) $ (-1143))) (-15 -4094 ((-1249) $)) (-15 -4076 ((-1249) $ (-763) (-763) (-917) (-917))) (-15 -3225 ((-1249) $ (-917) (-381) (-381))) (-15 -1861 ((-1249) $ (-917) (-381) (-381))) (-15 -1649 ((-1249) $ (-917) (-1143))) (-15 -4186 ((-1249) $ (-763) (-763))) (-15 -2969 ((-1249) $ (-473) (-917))) (-15 -2492 ((-1249) $ (-917) (-917))) (-15 -2325 ((-1143) $ (-1143))) (-15 -2325 ((-1143) $ (-1143) (-1143))) (-15 -2325 ((-1143) $ (-1143) (-634 (-1143)))) (-15 -2318 ((-1249) $)) (-15 -3651 ((-568) $)) (-15 -2747 ((-850) $))))) (T -1245)) 
+((-2747 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1245)))) (-2927 (*1 *2 *1) (-12 (-5 *2 (-634 (-944 (-215)))) (-5 *1 (-1245)))) (-4305 (*1 *1) (-5 *1 (-1245))) (-1828 (*1 *1 *1) (-5 *1 (-1245))) (-2508 (*1 *2 *1) (-12 (-5 *2 (-634 (-256))) (-5 *1 (-1245)))) (-2508 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-256))) (-5 *1 (-1245)))) (-1828 (*1 *1 *2 *3) (-12 (-5 *2 (-473)) (-5 *3 (-634 (-256))) (-5 *1 (-1245)))) (-1874 (*1 *2 *1 *3 *4 *4 *4 *4 *5 *5 *5 *5 *6 *5 *6 *5) (-12 (-5 *3 (-917)) (-5 *4 (-215)) (-5 *5 (-568)) (-5 *6 (-869)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-2746 (*1 *2 *1) (-12 (-5 *2 (-1244 (-2 (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)) (|:| -4158 (-568)) (|:| -2887 (-568)) (|:| |spline| (-568)) (|:| -3705 (-568)) (|:| |axesColor| (-869)) (|:| -2833 (-568)) (|:| |unitsColor| (-869)) (|:| |showing| (-568))))) (-5 *1 (-1245)))) (-3066 (*1 *2 *1) (-12 (-5 *2 (-1244 (-3 (-473) "undefined"))) (-5 *1 (-1245)))) (-4037 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-2619 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-473)) (-5 *4 (-917)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-3639 (*1 *2 *1 *3) (-12 (-5 *3 (-917)) (-5 *2 (-473)) (-5 *1 (-1245)))) (-3705 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-3705 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-869)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-2833 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-2833 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-869)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-4158 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-2176 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-2887 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-4225 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-4094 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-1245)))) (-4076 (*1 *2 *1 *3 *3 *4 *4) (-12 (-5 *3 (-763)) (-5 *4 (-917)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-3225 (*1 *2 *1 *3 *4 *4) (-12 (-5 *3 (-917)) (-5 *4 (-381)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-1861 (*1 *2 *1 *3 *4 *4) (-12 (-5 *3 (-917)) (-5 *4 (-381)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-1649 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-4186 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-2969 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-473)) (-5 *4 (-917)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-2492 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1249)) (-5 *1 (-1245)))) (-2325 (*1 *2 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1245)))) (-2325 (*1 *2 *1 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1245)))) (-2325 (*1 *2 *1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-1143)) (-5 *1 (-1245)))) (-2318 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-1245)))) (-3651 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1245))))) 
+(-13 (-1090) (-10 -8 (-15 -2927 ((-634 (-944 (-215))) $)) (-15 -4305 ($)) (-15 -1828 ($ $)) (-15 -2508 ((-634 (-256)) $)) (-15 -2508 ($ $ (-634 (-256)))) (-15 -1828 ($ (-473) (-634 (-256)))) (-15 -1874 ((-1249) $ (-917) (-215) (-215) (-215) (-215) (-568) (-568) (-568) (-568) (-869) (-568) (-869) (-568))) (-15 -2746 ((-1244 (-2 (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)) (|:| -4158 (-568)) (|:| -2887 (-568)) (|:| |spline| (-568)) (|:| -3705 (-568)) (|:| |axesColor| (-869)) (|:| -2833 (-568)) (|:| |unitsColor| (-869)) (|:| |showing| (-568)))) $)) (-15 -3066 ((-1244 (-3 (-473) "undefined")) $)) (-15 -4037 ((-1249) $ (-1143))) (-15 -2619 ((-1249) $ (-473) (-917))) (-15 -3639 ((-473) $ (-917))) (-15 -3705 ((-1249) $ (-917) (-1143))) (-15 -3705 ((-1249) $ (-917) (-869))) (-15 -2833 ((-1249) $ (-917) (-1143))) (-15 -2833 ((-1249) $ (-917) (-869))) (-15 -4158 ((-1249) $ (-917) (-1143))) (-15 -2176 ((-1249) $ (-917) (-1143))) (-15 -2887 ((-1249) $ (-917) (-1143))) (-15 -4225 ((-1249) $ (-1143))) (-15 -4094 ((-1249) $)) (-15 -4076 ((-1249) $ (-763) (-763) (-917) (-917))) (-15 -3225 ((-1249) $ (-917) (-381) (-381))) (-15 -1861 ((-1249) $ (-917) (-381) (-381))) (-15 -1649 ((-1249) $ (-917) (-1143))) (-15 -4186 ((-1249) $ (-763) (-763))) (-15 -2969 ((-1249) $ (-473) (-917))) (-15 -2492 ((-1249) $ (-917) (-917))) (-15 -2325 ((-1143) $ (-1143))) (-15 -2325 ((-1143) $ (-1143) (-1143))) (-15 -2325 ((-1143) $ (-1143) (-634 (-1143)))) (-15 -2318 ((-1249) $)) (-15 -3651 ((-568) $)) (-15 -2747 ((-850) $)))) 
+((-2449 (((-121) $ $) NIL)) (-4075 (((-1249) $ (-381)) 138) (((-1249) $ (-381) (-381) (-381)) 139)) (-2325 (((-1143) $ (-1143)) 146) (((-1143) $ (-1143) (-1143)) 144) (((-1143) $ (-1143) (-634 (-1143))) 143)) (-3803 (($) 49)) (-1627 (((-1249) $ (-381) (-381) (-381) (-381) (-381)) 114) (((-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))) $) 112) (((-1249) $ (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)))) 113) (((-1249) $ (-568) (-568) (-381) (-381) (-381)) 115) (((-1249) $ (-381) (-381)) 116) (((-1249) $ (-381) (-381) (-381)) 123)) (-2637 (((-381)) 96) (((-381) (-381)) 97)) (-1520 (((-381)) 91) (((-381) (-381)) 93)) (-3052 (((-381)) 94) (((-381) (-381)) 95)) (-1319 (((-381)) 100) (((-381) (-381)) 101)) (-2503 (((-381)) 98) (((-381) (-381)) 99)) (-1861 (((-1249) $ (-381) (-381)) 140)) (-4037 (((-1249) $ (-1143)) 124)) (-3503 (((-1121 (-215)) $) 50) (($ $ (-1121 (-215))) 51)) (-2401 (((-1249) $ (-1143)) 152)) (-4017 (((-1249) $ (-1143)) 153)) (-3287 (((-1249) $ (-381) (-381)) 122) (((-1249) $ (-568) (-568)) 137)) (-2492 (((-1249) $ (-917) (-917)) 130)) (-2318 (((-1249) $) 110)) (-4192 (((-1249) $ (-1143)) 151)) (-1652 (((-1249) $ (-1143)) 107)) (-2508 (((-634 (-256)) $) 52) (($ $ (-634 (-256))) 53)) (-4186 (((-1249) $ (-763) (-763)) 129)) (-4143 (((-1249) $ (-763) (-944 (-215))) 158)) (-4162 (($ $) 56) (($ (-1121 (-215)) (-1143)) 57) (($ (-1121 (-215)) (-634 (-256))) 58)) (-1910 (((-1249) $ (-381) (-381) (-381)) 104)) (-1893 (((-1143) $) NIL)) (-3651 (((-568) $) 102)) (-1317 (((-1249) $ (-381)) 141)) (-3203 (((-1249) $ (-381)) 156)) (-4025 (((-1108) $) NIL)) (-4343 (((-1249) $ (-381)) 155)) (-3235 (((-1249) $ (-1143)) 109)) (-4076 (((-1249) $ (-763) (-763) (-917) (-917)) 128)) (-2346 (((-1249) $ (-1143)) 106)) (-4225 (((-1249) $ (-1143)) 108)) (-4319 (((-1249) $ (-158) (-158)) 127)) (-2747 (((-850) $) 135)) (-4094 (((-1249) $) 111)) (-3545 (((-1249) $ (-1143)) 154)) (-3705 (((-1249) $ (-1143)) 105)) (-1719 (((-121) $ $) NIL))) 
+(((-1246) (-13 (-1090) (-10 -8 (-15 -1520 ((-381))) (-15 -1520 ((-381) (-381))) (-15 -3052 ((-381))) (-15 -3052 ((-381) (-381))) (-15 -2637 ((-381))) (-15 -2637 ((-381) (-381))) (-15 -2503 ((-381))) (-15 -2503 ((-381) (-381))) (-15 -1319 ((-381))) (-15 -1319 ((-381) (-381))) (-15 -3803 ($)) (-15 -4162 ($ $)) (-15 -4162 ($ (-1121 (-215)) (-1143))) (-15 -4162 ($ (-1121 (-215)) (-634 (-256)))) (-15 -3503 ((-1121 (-215)) $)) (-15 -3503 ($ $ (-1121 (-215)))) (-15 -4143 ((-1249) $ (-763) (-944 (-215)))) (-15 -2508 ((-634 (-256)) $)) (-15 -2508 ($ $ (-634 (-256)))) (-15 -4186 ((-1249) $ (-763) (-763))) (-15 -2492 ((-1249) $ (-917) (-917))) (-15 -4037 ((-1249) $ (-1143))) (-15 -4076 ((-1249) $ (-763) (-763) (-917) (-917))) (-15 -1627 ((-1249) $ (-381) (-381) (-381) (-381) (-381))) (-15 -1627 ((-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))) $)) (-15 -1627 ((-1249) $ (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))))) (-15 -1627 ((-1249) $ (-568) (-568) (-381) (-381) (-381))) (-15 -1627 ((-1249) $ (-381) (-381))) (-15 -1627 ((-1249) $ (-381) (-381) (-381))) (-15 -4225 ((-1249) $ (-1143))) (-15 -3705 ((-1249) $ (-1143))) (-15 -2346 ((-1249) $ (-1143))) (-15 -1652 ((-1249) $ (-1143))) (-15 -3235 ((-1249) $ (-1143))) (-15 -3287 ((-1249) $ (-381) (-381))) (-15 -3287 ((-1249) $ (-568) (-568))) (-15 -4075 ((-1249) $ (-381))) (-15 -4075 ((-1249) $ (-381) (-381) (-381))) (-15 -1861 ((-1249) $ (-381) (-381))) (-15 -4192 ((-1249) $ (-1143))) (-15 -4343 ((-1249) $ (-381))) (-15 -3203 ((-1249) $ (-381))) (-15 -2401 ((-1249) $ (-1143))) (-15 -4017 ((-1249) $ (-1143))) (-15 -3545 ((-1249) $ (-1143))) (-15 -1910 ((-1249) $ (-381) (-381) (-381))) (-15 -1317 ((-1249) $ (-381))) (-15 -2318 ((-1249) $)) (-15 -4319 ((-1249) $ (-158) (-158))) (-15 -2325 ((-1143) $ (-1143))) (-15 -2325 ((-1143) $ (-1143) (-1143))) (-15 -2325 ((-1143) $ (-1143) (-634 (-1143)))) (-15 -4094 ((-1249) $)) (-15 -3651 ((-568) $))))) (T -1246)) 
+((-1520 (*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) (-1520 (*1 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) (-3052 (*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) (-3052 (*1 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) (-2637 (*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) (-2637 (*1 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) (-2503 (*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) (-2503 (*1 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) (-1319 (*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) (-1319 (*1 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) (-3803 (*1 *1) (-5 *1 (-1246))) (-4162 (*1 *1 *1) (-5 *1 (-1246))) (-4162 (*1 *1 *2 *3) (-12 (-5 *2 (-1121 (-215))) (-5 *3 (-1143)) (-5 *1 (-1246)))) (-4162 (*1 *1 *2 *3) (-12 (-5 *2 (-1121 (-215))) (-5 *3 (-634 (-256))) (-5 *1 (-1246)))) (-3503 (*1 *2 *1) (-12 (-5 *2 (-1121 (-215))) (-5 *1 (-1246)))) (-3503 (*1 *1 *1 *2) (-12 (-5 *2 (-1121 (-215))) (-5 *1 (-1246)))) (-4143 (*1 *2 *1 *3 *4) (-12 (-5 *3 (-763)) (-5 *4 (-944 (-215))) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-2508 (*1 *2 *1) (-12 (-5 *2 (-634 (-256))) (-5 *1 (-1246)))) (-2508 (*1 *1 *1 *2) (-12 (-5 *2 (-634 (-256))) (-5 *1 (-1246)))) (-4186 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-2492 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-4037 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-4076 (*1 *2 *1 *3 *3 *4 *4) (-12 (-5 *3 (-763)) (-5 *4 (-917)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-1627 (*1 *2 *1 *3 *3 *3 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-1627 (*1 *2 *1) (-12 (-5 *2 (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)))) (-5 *1 (-1246)))) (-1627 (*1 *2 *1 *3) (-12 (-5 *3 (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)))) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-1627 (*1 *2 *1 *3 *3 *4 *4 *4) (-12 (-5 *3 (-568)) (-5 *4 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-1627 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-1627 (*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-4225 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-3705 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-2346 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-1652 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-3235 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-3287 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-3287 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-4075 (*1 *2 *1 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-4075 (*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-1861 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-4192 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-4343 (*1 *2 *1 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-3203 (*1 *2 *1 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-2401 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-4017 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-3545 (*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-1910 (*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-1317 (*1 *2 *1 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-2318 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-1246)))) (-4319 (*1 *2 *1 *3 *3) (-12 (-5 *3 (-158)) (-5 *2 (-1249)) (-5 *1 (-1246)))) (-2325 (*1 *2 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1246)))) (-2325 (*1 *2 *1 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1246)))) (-2325 (*1 *2 *1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-1143)) (-5 *1 (-1246)))) (-4094 (*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-1246)))) (-3651 (*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1246))))) 
+(-13 (-1090) (-10 -8 (-15 -1520 ((-381))) (-15 -1520 ((-381) (-381))) (-15 -3052 ((-381))) (-15 -3052 ((-381) (-381))) (-15 -2637 ((-381))) (-15 -2637 ((-381) (-381))) (-15 -2503 ((-381))) (-15 -2503 ((-381) (-381))) (-15 -1319 ((-381))) (-15 -1319 ((-381) (-381))) (-15 -3803 ($)) (-15 -4162 ($ $)) (-15 -4162 ($ (-1121 (-215)) (-1143))) (-15 -4162 ($ (-1121 (-215)) (-634 (-256)))) (-15 -3503 ((-1121 (-215)) $)) (-15 -3503 ($ $ (-1121 (-215)))) (-15 -4143 ((-1249) $ (-763) (-944 (-215)))) (-15 -2508 ((-634 (-256)) $)) (-15 -2508 ($ $ (-634 (-256)))) (-15 -4186 ((-1249) $ (-763) (-763))) (-15 -2492 ((-1249) $ (-917) (-917))) (-15 -4037 ((-1249) $ (-1143))) (-15 -4076 ((-1249) $ (-763) (-763) (-917) (-917))) (-15 -1627 ((-1249) $ (-381) (-381) (-381) (-381) (-381))) (-15 -1627 ((-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))) $)) (-15 -1627 ((-1249) $ (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215))))) (-15 -1627 ((-1249) $ (-568) (-568) (-381) (-381) (-381))) (-15 -1627 ((-1249) $ (-381) (-381))) (-15 -1627 ((-1249) $ (-381) (-381) (-381))) (-15 -4225 ((-1249) $ (-1143))) (-15 -3705 ((-1249) $ (-1143))) (-15 -2346 ((-1249) $ (-1143))) (-15 -1652 ((-1249) $ (-1143))) (-15 -3235 ((-1249) $ (-1143))) (-15 -3287 ((-1249) $ (-381) (-381))) (-15 -3287 ((-1249) $ (-568) (-568))) (-15 -4075 ((-1249) $ (-381))) (-15 -4075 ((-1249) $ (-381) (-381) (-381))) (-15 -1861 ((-1249) $ (-381) (-381))) (-15 -4192 ((-1249) $ (-1143))) (-15 -4343 ((-1249) $ (-381))) (-15 -3203 ((-1249) $ (-381))) (-15 -2401 ((-1249) $ (-1143))) (-15 -4017 ((-1249) $ (-1143))) (-15 -3545 ((-1249) $ (-1143))) (-15 -1910 ((-1249) $ (-381) (-381) (-381))) (-15 -1317 ((-1249) $ (-381))) (-15 -2318 ((-1249) $)) (-15 -4319 ((-1249) $ (-158) (-158))) (-15 -2325 ((-1143) $ (-1143))) (-15 -2325 ((-1143) $ (-1143) (-1143))) (-15 -2325 ((-1143) $ (-1143) (-634 (-1143)))) (-15 -4094 ((-1249) $)) (-15 -3651 ((-568) $)))) 
+((-4257 (((-634 (-1143)) (-634 (-1143))) 94) (((-634 (-1143))) 89)) (-3876 (((-634 (-1143))) 87)) (-3345 (((-634 (-917)) (-634 (-917))) 62) (((-634 (-917))) 59)) (-2489 (((-634 (-763)) (-634 (-763))) 56) (((-634 (-763))) 52)) (-3283 (((-1249)) 64)) (-1320 (((-917) (-917)) 80) (((-917)) 79)) (-2274 (((-917) (-917)) 78) (((-917)) 77)) (-3218 (((-869) (-869)) 74) (((-869)) 73)) (-1378 (((-215)) 84) (((-215) (-381)) 86)) (-2423 (((-917)) 81) (((-917) (-917)) 82)) (-2639 (((-917) (-917)) 76) (((-917)) 75)) (-2701 (((-869) (-869)) 68) (((-869)) 66)) (-3978 (((-869) (-869)) 70) (((-869)) 69)) (-3454 (((-869) (-869)) 72) (((-869)) 71))) 
+(((-1247) (-10 -7 (-15 -2701 ((-869))) (-15 -2701 ((-869) (-869))) (-15 -3978 ((-869))) (-15 -3978 ((-869) (-869))) (-15 -3454 ((-869))) (-15 -3454 ((-869) (-869))) (-15 -3218 ((-869))) (-15 -3218 ((-869) (-869))) (-15 -2639 ((-917))) (-15 -2639 ((-917) (-917))) (-15 -2489 ((-634 (-763)))) (-15 -2489 ((-634 (-763)) (-634 (-763)))) (-15 -3345 ((-634 (-917)))) (-15 -3345 ((-634 (-917)) (-634 (-917)))) (-15 -3283 ((-1249))) (-15 -4257 ((-634 (-1143)))) (-15 -4257 ((-634 (-1143)) (-634 (-1143)))) (-15 -3876 ((-634 (-1143)))) (-15 -2274 ((-917))) (-15 -1320 ((-917))) (-15 -2274 ((-917) (-917))) (-15 -1320 ((-917) (-917))) (-15 -2423 ((-917) (-917))) (-15 -2423 ((-917))) (-15 -1378 ((-215) (-381))) (-15 -1378 ((-215))))) (T -1247)) 
+((-1378 (*1 *2) (-12 (-5 *2 (-215)) (-5 *1 (-1247)))) (-1378 (*1 *2 *3) (-12 (-5 *3 (-381)) (-5 *2 (-215)) (-5 *1 (-1247)))) (-2423 (*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) (-2423 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) (-1320 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) (-2274 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) (-1320 (*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) (-2274 (*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) (-3876 (*1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1247)))) (-4257 (*1 *2 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1247)))) (-4257 (*1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1247)))) (-3283 (*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1247)))) (-3345 (*1 *2 *2) (-12 (-5 *2 (-634 (-917))) (-5 *1 (-1247)))) (-3345 (*1 *2) (-12 (-5 *2 (-634 (-917))) (-5 *1 (-1247)))) (-2489 (*1 *2 *2) (-12 (-5 *2 (-634 (-763))) (-5 *1 (-1247)))) (-2489 (*1 *2) (-12 (-5 *2 (-634 (-763))) (-5 *1 (-1247)))) (-2639 (*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) (-2639 (*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) (-3218 (*1 *2 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247)))) (-3218 (*1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247)))) (-3454 (*1 *2 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247)))) (-3454 (*1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247)))) (-3978 (*1 *2 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247)))) (-3978 (*1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247)))) (-2701 (*1 *2 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247)))) (-2701 (*1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247))))) 
+(-10 -7 (-15 -2701 ((-869))) (-15 -2701 ((-869) (-869))) (-15 -3978 ((-869))) (-15 -3978 ((-869) (-869))) (-15 -3454 ((-869))) (-15 -3454 ((-869) (-869))) (-15 -3218 ((-869))) (-15 -3218 ((-869) (-869))) (-15 -2639 ((-917))) (-15 -2639 ((-917) (-917))) (-15 -2489 ((-634 (-763)))) (-15 -2489 ((-634 (-763)) (-634 (-763)))) (-15 -3345 ((-634 (-917)))) (-15 -3345 ((-634 (-917)) (-634 (-917)))) (-15 -3283 ((-1249))) (-15 -4257 ((-634 (-1143)))) (-15 -4257 ((-634 (-1143)) (-634 (-1143)))) (-15 -3876 ((-634 (-1143)))) (-15 -2274 ((-917))) (-15 -1320 ((-917))) (-15 -2274 ((-917) (-917))) (-15 -1320 ((-917) (-917))) (-15 -2423 ((-917) (-917))) (-15 -2423 ((-917))) (-15 -1378 ((-215) (-381))) (-15 -1378 ((-215)))) 
+((-3101 (((-473) (-634 (-634 (-944 (-215)))) (-634 (-256))) 17) (((-473) (-634 (-634 (-944 (-215))))) 16) (((-473) (-634 (-634 (-944 (-215)))) (-869) (-869) (-917) (-634 (-256))) 15)) (-4318 (((-1245) (-634 (-634 (-944 (-215)))) (-634 (-256))) 23) (((-1245) (-634 (-634 (-944 (-215)))) (-869) (-869) (-917) (-634 (-256))) 22)) (-2747 (((-1245) (-473)) 34))) 
+(((-1248) (-10 -7 (-15 -3101 ((-473) (-634 (-634 (-944 (-215)))) (-869) (-869) (-917) (-634 (-256)))) (-15 -3101 ((-473) (-634 (-634 (-944 (-215)))))) (-15 -3101 ((-473) (-634 (-634 (-944 (-215)))) (-634 (-256)))) (-15 -4318 ((-1245) (-634 (-634 (-944 (-215)))) (-869) (-869) (-917) (-634 (-256)))) (-15 -4318 ((-1245) (-634 (-634 (-944 (-215)))) (-634 (-256)))) (-15 -2747 ((-1245) (-473))))) (T -1248)) 
+((-2747 (*1 *2 *3) (-12 (-5 *3 (-473)) (-5 *2 (-1245)) (-5 *1 (-1248)))) (-4318 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *4 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-1248)))) (-4318 (*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *4 (-869)) (-5 *5 (-917)) (-5 *6 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-1248)))) (-3101 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *4 (-634 (-256))) (-5 *2 (-473)) (-5 *1 (-1248)))) (-3101 (*1 *2 *3) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *2 (-473)) (-5 *1 (-1248)))) (-3101 (*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *4 (-869)) (-5 *5 (-917)) (-5 *6 (-634 (-256))) (-5 *2 (-473)) (-5 *1 (-1248))))) 
+(-10 -7 (-15 -3101 ((-473) (-634 (-634 (-944 (-215)))) (-869) (-869) (-917) (-634 (-256)))) (-15 -3101 ((-473) (-634 (-634 (-944 (-215)))))) (-15 -3101 ((-473) (-634 (-634 (-944 (-215)))) (-634 (-256)))) (-15 -4318 ((-1245) (-634 (-634 (-944 (-215)))) (-869) (-869) (-917) (-634 (-256)))) (-15 -4318 ((-1245) (-634 (-634 (-944 (-215)))) (-634 (-256)))) (-15 -2747 ((-1245) (-473)))) 
+((-3613 (($) 7)) (-2747 (((-850) $) 10))) 
+(((-1249) (-10 -8 (-15 -3613 ($)) (-15 -2747 ((-850) $)))) (T -1249)) 
+((-2747 (*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1249)))) (-3613 (*1 *1) (-5 *1 (-1249)))) 
+(-10 -8 (-15 -3613 ($)) (-15 -2747 ((-850) $))) 
+((-1781 (($ $ |#2|) 10))) 
+(((-1250 |#1| |#2|) (-10 -8 (-15 -1781 (|#1| |#1| |#2|))) (-1251 |#2|) (-365)) (T -1250)) 
+NIL 
+(-10 -8 (-15 -1781 (|#1| |#1| |#2|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-3108 (((-139)) 25)) (-2747 (((-850) $) 11)) (-3058 (($) 17 T CONST)) (-1719 (((-121) $ $) 6)) (-1781 (($ $ |#1|) 26)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ |#1| $) 22) (($ $ |#1|) 24))) 
 (((-1251 |#1|) (-1275) (-365)) (T -1251)) 
-((-1779 (*1 *1 *1 *2) (-12 (-4 *1 (-1251 *2)) (-4 *2 (-365)))) (-4321 (*1 *2) (-12 (-4 *1 (-1251 *3)) (-4 *3 (-365)) (-5 *2 (-139))))) 
-(-13 (-707 |t#1|) (-10 -8 (-15 -1779 ($ $ |t#1|)) (-15 -4321 ((-139))))) 
+((-1781 (*1 *1 *1 *2) (-12 (-4 *1 (-1251 *2)) (-4 *2 (-365)))) (-3108 (*1 *2) (-12 (-4 *1 (-1251 *3)) (-4 *3 (-365)) (-5 *2 (-139))))) 
+(-13 (-707 |t#1|) (-10 -8 (-15 -1781 ($ $ |t#1|)) (-15 -3108 ((-139))))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-105) . T) ((-120 |#1| |#1|) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 |#1|) . T) ((-707 |#1|) . T) ((-1053 |#1|) . T) ((-1090) . T)) 
-((-1740 (((-634 (-1190 |#1|)) (-1161) (-1190 |#1|)) 78)) (-2619 (((-1141 (-1141 (-953 |#1|))) (-1161) (-1141 (-953 |#1|))) 57)) (-1363 (((-1 (-1141 (-1190 |#1|)) (-1141 (-1190 |#1|))) (-763) (-1190 |#1|) (-1141 (-1190 |#1|))) 68)) (-2809 (((-1 (-1141 (-953 |#1|)) (-1141 (-953 |#1|))) (-763)) 59)) (-4259 (((-1 (-1157 (-953 |#1|)) (-953 |#1|)) (-1161)) 27)) (-1405 (((-1 (-1141 (-953 |#1|)) (-1141 (-953 |#1|))) (-763)) 58))) 
-(((-1252 |#1|) (-10 -7 (-15 -2809 ((-1 (-1141 (-953 |#1|)) (-1141 (-953 |#1|))) (-763))) (-15 -1405 ((-1 (-1141 (-953 |#1|)) (-1141 (-953 |#1|))) (-763))) (-15 -2619 ((-1141 (-1141 (-953 |#1|))) (-1161) (-1141 (-953 |#1|)))) (-15 -4259 ((-1 (-1157 (-953 |#1|)) (-953 |#1|)) (-1161))) (-15 -1740 ((-634 (-1190 |#1|)) (-1161) (-1190 |#1|))) (-15 -1363 ((-1 (-1141 (-1190 |#1|)) (-1141 (-1190 |#1|))) (-763) (-1190 |#1|) (-1141 (-1190 |#1|))))) (-365)) (T -1252)) 
-((-1363 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-763)) (-4 *6 (-365)) (-5 *4 (-1190 *6)) (-5 *2 (-1 (-1141 *4) (-1141 *4))) (-5 *1 (-1252 *6)) (-5 *5 (-1141 *4)))) (-1740 (*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-4 *5 (-365)) (-5 *2 (-634 (-1190 *5))) (-5 *1 (-1252 *5)) (-5 *4 (-1190 *5)))) (-4259 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-1157 (-953 *4)) (-953 *4))) (-5 *1 (-1252 *4)) (-4 *4 (-365)))) (-2619 (*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-4 *5 (-365)) (-5 *2 (-1141 (-1141 (-953 *5)))) (-5 *1 (-1252 *5)) (-5 *4 (-1141 (-953 *5))))) (-1405 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-1141 (-953 *4)) (-1141 (-953 *4)))) (-5 *1 (-1252 *4)) (-4 *4 (-365)))) (-2809 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-1141 (-953 *4)) (-1141 (-953 *4)))) (-5 *1 (-1252 *4)) (-4 *4 (-365))))) 
-(-10 -7 (-15 -2809 ((-1 (-1141 (-953 |#1|)) (-1141 (-953 |#1|))) (-763))) (-15 -1405 ((-1 (-1141 (-953 |#1|)) (-1141 (-953 |#1|))) (-763))) (-15 -2619 ((-1141 (-1141 (-953 |#1|))) (-1161) (-1141 (-953 |#1|)))) (-15 -4259 ((-1 (-1157 (-953 |#1|)) (-953 |#1|)) (-1161))) (-15 -1740 ((-634 (-1190 |#1|)) (-1161) (-1190 |#1|))) (-15 -1363 ((-1 (-1141 (-1190 |#1|)) (-1141 (-1190 |#1|))) (-763) (-1190 |#1|) (-1141 (-1190 |#1|))))) 
-((-3714 (((-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) |#2|) 74)) (-3661 (((-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|)))) 73))) 
-(((-1253 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3661 ((-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))))) (-15 -3714 ((-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) |#2|))) (-350) (-1219 |#1|) (-1219 |#2|) (-411 |#2| |#3|)) (T -1253)) 
-((-3714 (*1 *2 *3) (-12 (-4 *4 (-350)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 *3)) (-5 *2 (-2 (|:| -3746 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-5 *1 (-1253 *4 *3 *5 *6)) (-4 *6 (-411 *3 *5)))) (-3661 (*1 *2) (-12 (-4 *3 (-350)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| -3746 (-679 *4)) (|:| |basisDen| *4) (|:| |basisInv| (-679 *4)))) (-5 *1 (-1253 *3 *4 *5 *6)) (-4 *6 (-411 *4 *5))))) 
-(-10 -7 (-15 -3661 ((-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))))) (-15 -3714 ((-2 (|:| -3746 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) |#2|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 41)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-2925 (((-3 $ "failed") $) NIL)) (-2735 (((-121) $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2745 (((-850) $) 62) (($ (-568)) NIL) ((|#4| $) 52) (($ |#4|) 47) (($ |#1|) NIL (|has| |#1| (-172)))) (-4078 (((-763)) NIL)) (-4366 (((-1249) (-763)) 16)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 26 T CONST)) (-1556 (($) 65 T CONST)) (-1717 (((-121) $ $) 67)) (-1779 (((-3 $ "failed") $ $) NIL (|has| |#1| (-365)))) (-1773 (($ $) 69) (($ $ $) NIL)) (-1767 (($ $ $) 45)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 71) (($ |#1| $) NIL (|has| |#1| (-172))) (($ $ |#1|) NIL (|has| |#1| (-172))))) 
-(((-1254 |#1| |#2| |#3| |#4| |#5| |#6| |#7|) (-13 (-1047) (-10 -8 (IF (|has| |#1| (-172)) (-6 (-43 |#1|)) |noBranch|) (-15 -2745 (|#4| $)) (IF (|has| |#1| (-365)) (-15 -1779 ((-3 $ "failed") $ $)) |noBranch|) (-15 -2745 ($ |#4|)) (-15 -4366 ((-1249) (-763))))) (-1047) (-842) (-788) (-950 |#1| |#3| |#2|) (-634 |#2|) (-634 (-763)) (-763)) (T -1254)) 
-((-2745 (*1 *2 *1) (-12 (-4 *2 (-950 *3 *5 *4)) (-5 *1 (-1254 *3 *4 *5 *2 *6 *7 *8)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-788)) (-14 *6 (-634 *4)) (-14 *7 (-634 (-763))) (-14 *8 (-763)))) (-1779 (*1 *1 *1 *1) (|partial| -12 (-4 *2 (-365)) (-4 *2 (-1047)) (-4 *3 (-842)) (-4 *4 (-788)) (-14 *6 (-634 *3)) (-5 *1 (-1254 *2 *3 *4 *5 *6 *7 *8)) (-4 *5 (-950 *2 *4 *3)) (-14 *7 (-634 (-763))) (-14 *8 (-763)))) (-2745 (*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-788)) (-14 *6 (-634 *4)) (-5 *1 (-1254 *3 *4 *5 *2 *6 *7 *8)) (-4 *2 (-950 *3 *5 *4)) (-14 *7 (-634 (-763))) (-14 *8 (-763)))) (-4366 (*1 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-1047)) (-4 *5 (-842)) (-4 *6 (-788)) (-14 *8 (-634 *5)) (-5 *2 (-1249)) (-5 *1 (-1254 *4 *5 *6 *7 *8 *9 *10)) (-4 *7 (-950 *4 *6 *5)) (-14 *9 (-634 *3)) (-14 *10 *3)))) 
-(-13 (-1047) (-10 -8 (IF (|has| |#1| (-172)) (-6 (-43 |#1|)) |noBranch|) (-15 -2745 (|#4| $)) (IF (|has| |#1| (-365)) (-15 -1779 ((-3 $ "failed") $ $)) |noBranch|) (-15 -2745 ($ |#4|)) (-15 -4366 ((-1249) (-763))))) 
-((-2447 (((-121) $ $) NIL)) (-2387 (((-634 (-2 (|:| -4092 $) (|:| -1798 (-634 |#4|)))) (-634 |#4|)) NIL)) (-2415 (((-634 $) (-634 |#4|)) 87)) (-2055 (((-634 |#3|) $) NIL)) (-4211 (((-121) $) NIL)) (-3824 (((-121) $) NIL (|has| |#1| (-558)))) (-3300 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-2819 ((|#4| |#4| $) NIL)) (-3644 (((-2 (|:| |under| $) (|:| -1519 $) (|:| |upper| $)) $ |#3|) NIL)) (-2510 (((-121) $ (-763)) NIL)) (-2801 (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519))) (((-3 |#4| "failed") $ |#3|) NIL)) (-2671 (($) NIL T CONST)) (-1565 (((-121) $) NIL (|has| |#1| (-558)))) (-3846 (((-121) $ $) NIL (|has| |#1| (-558)))) (-3106 (((-121) $ $) NIL (|has| |#1| (-558)))) (-3695 (((-121) $) NIL (|has| |#1| (-558)))) (-4275 (((-634 |#4|) (-634 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 27)) (-2355 (((-634 |#4|) (-634 |#4|) $) 24 (|has| |#1| (-558)))) (-2492 (((-634 |#4|) (-634 |#4|) $) NIL (|has| |#1| (-558)))) (-3666 (((-3 $ "failed") (-634 |#4|)) NIL)) (-2854 (($ (-634 |#4|)) NIL)) (-3935 (((-3 $ "failed") $) 69)) (-2062 ((|#4| |#4| $) 74)) (-3924 (($ $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090))))) (-4328 (($ |#4| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090)))) (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-1500 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-558)))) (-1281 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) NIL)) (-4079 ((|#4| |#4| $) NIL)) (-3092 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) NIL (|has| $ (-6 -4519))) ((|#4| (-1 |#4| |#4| |#4|) $) NIL (|has| $ (-6 -4519))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-3635 (((-2 (|:| -4092 (-634 |#4|)) (|:| -1798 (-634 |#4|))) $) NIL)) (-4360 (((-634 |#4|) $) NIL (|has| $ (-6 -4519)))) (-1362 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-2356 ((|#3| $) 75)) (-1737 (((-121) $ (-763)) NIL)) (-1979 (((-634 |#4|) $) 28 (|has| $ (-6 -4519)))) (-3109 (((-121) |#4| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090))))) (-3942 (((-3 $ "failed") (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|)) 31) (((-3 $ "failed") (-634 |#4|)) 34)) (-3674 (($ (-1 |#4| |#4|) $) NIL (|has| $ (-6 -4520)))) (-2795 (($ (-1 |#4| |#4|) $) NIL)) (-1432 (((-634 |#3|) $) NIL)) (-3392 (((-121) |#3| $) NIL)) (-2166 (((-121) $ (-763)) NIL)) (-4487 (((-1143) $) NIL)) (-4162 (((-3 |#4| "failed") $) NIL)) (-1377 (((-634 |#4|) $) 49)) (-1415 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-2682 ((|#4| |#4| $) 73)) (-2644 (((-121) $ $) 84)) (-2705 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-558)))) (-4347 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-4025 ((|#4| |#4| $) NIL)) (-4022 (((-1108) $) NIL)) (-3876 (((-3 |#4| "failed") $) 68)) (-3775 (((-3 |#4| "failed") (-1 (-121) |#4|) $) NIL)) (-1665 (((-3 $ "failed") $ |#4|) NIL)) (-1807 (($ $ |#4|) NIL)) (-1387 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-1339 (($ $ (-634 |#4|) (-634 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 (-288 |#4|))) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-3171 (((-121) $ $) NIL)) (-3084 (((-121) $) 66)) (-3248 (($) 41)) (-3206 (((-763) $) NIL)) (-4168 (((-763) |#4| $) NIL (-12 (|has| $ (-6 -4519)) (|has| |#4| (-1090)))) (((-763) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-3863 (($ $) NIL)) (-4278 (((-541) $) NIL (|has| |#4| (-609 (-541))))) (-4287 (($ (-634 |#4|)) NIL)) (-1290 (($ $ |#3|) NIL)) (-3732 (($ $ |#3|) NIL)) (-1567 (($ $) NIL)) (-3944 (($ $ |#3|) NIL)) (-2745 (((-850) $) NIL) (((-634 |#4|) $) 56)) (-1878 (((-763) $) NIL (|has| |#3| (-370)))) (-3884 (((-3 $ "failed") (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|)) 39) (((-3 $ "failed") (-634 |#4|)) 40)) (-2598 (((-634 $) (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|)) 64) (((-634 $) (-634 |#4|)) 65)) (-3556 (((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4| |#4|)) 23) (((-3 (-2 (|:| |bas| $) (|:| -2616 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-3292 (((-121) $ (-1 (-121) |#4| (-634 |#4|))) NIL)) (-1319 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4519)))) (-2739 (((-634 |#3|) $) NIL)) (-4390 (((-121) |#3| $) NIL)) (-1717 (((-121) $ $) NIL)) (-1697 (((-763) $) NIL (|has| $ (-6 -4519))))) 
-(((-1255 |#1| |#2| |#3| |#4|) (-13 (-1189 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3942 ((-3 $ "failed") (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -3942 ((-3 $ "failed") (-634 |#4|))) (-15 -3884 ((-3 $ "failed") (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -3884 ((-3 $ "failed") (-634 |#4|))) (-15 -2598 ((-634 $) (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -2598 ((-634 $) (-634 |#4|))))) (-558) (-788) (-842) (-1061 |#1| |#2| |#3|)) (T -1255)) 
-((-3942 (*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-634 *8)) (-5 *3 (-1 (-121) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1255 *5 *6 *7 *8)))) (-3942 (*1 *1 *2) (|partial| -12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-1255 *3 *4 *5 *6)))) (-3884 (*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-634 *8)) (-5 *3 (-1 (-121) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1255 *5 *6 *7 *8)))) (-3884 (*1 *1 *2) (|partial| -12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-1255 *3 *4 *5 *6)))) (-2598 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 *9)) (-5 *4 (-1 (-121) *9 *9)) (-5 *5 (-1 *9 *9 *9)) (-4 *9 (-1061 *6 *7 *8)) (-4 *6 (-558)) (-4 *7 (-788)) (-4 *8 (-842)) (-5 *2 (-634 (-1255 *6 *7 *8 *9))) (-5 *1 (-1255 *6 *7 *8 *9)))) (-2598 (*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 (-1255 *4 *5 *6 *7))) (-5 *1 (-1255 *4 *5 *6 *7))))) 
-(-13 (-1189 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -3942 ((-3 $ "failed") (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -3942 ((-3 $ "failed") (-634 |#4|))) (-15 -3884 ((-3 $ "failed") (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -3884 ((-3 $ "failed") (-634 |#4|))) (-15 -2598 ((-634 $) (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -2598 ((-634 $) (-634 |#4|))))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3134 (((-3 $ "failed") $ $) 18)) (-2671 (($) 16 T CONST)) (-2925 (((-3 $ "failed") $) 33)) (-2735 (((-121) $) 30)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 37)) (-4078 (((-763)) 28)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 39) (($ |#1| $) 38))) 
+((-3809 (((-634 (-1190 |#1|)) (-1161) (-1190 |#1|)) 78)) (-4193 (((-1141 (-1141 (-953 |#1|))) (-1161) (-1141 (-953 |#1|))) 57)) (-3772 (((-1 (-1141 (-1190 |#1|)) (-1141 (-1190 |#1|))) (-763) (-1190 |#1|) (-1141 (-1190 |#1|))) 68)) (-3707 (((-1 (-1141 (-953 |#1|)) (-1141 (-953 |#1|))) (-763)) 59)) (-2894 (((-1 (-1157 (-953 |#1|)) (-953 |#1|)) (-1161)) 27)) (-2111 (((-1 (-1141 (-953 |#1|)) (-1141 (-953 |#1|))) (-763)) 58))) 
+(((-1252 |#1|) (-10 -7 (-15 -3707 ((-1 (-1141 (-953 |#1|)) (-1141 (-953 |#1|))) (-763))) (-15 -2111 ((-1 (-1141 (-953 |#1|)) (-1141 (-953 |#1|))) (-763))) (-15 -4193 ((-1141 (-1141 (-953 |#1|))) (-1161) (-1141 (-953 |#1|)))) (-15 -2894 ((-1 (-1157 (-953 |#1|)) (-953 |#1|)) (-1161))) (-15 -3809 ((-634 (-1190 |#1|)) (-1161) (-1190 |#1|))) (-15 -3772 ((-1 (-1141 (-1190 |#1|)) (-1141 (-1190 |#1|))) (-763) (-1190 |#1|) (-1141 (-1190 |#1|))))) (-365)) (T -1252)) 
+((-3772 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-763)) (-4 *6 (-365)) (-5 *4 (-1190 *6)) (-5 *2 (-1 (-1141 *4) (-1141 *4))) (-5 *1 (-1252 *6)) (-5 *5 (-1141 *4)))) (-3809 (*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-4 *5 (-365)) (-5 *2 (-634 (-1190 *5))) (-5 *1 (-1252 *5)) (-5 *4 (-1190 *5)))) (-2894 (*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-1157 (-953 *4)) (-953 *4))) (-5 *1 (-1252 *4)) (-4 *4 (-365)))) (-4193 (*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-4 *5 (-365)) (-5 *2 (-1141 (-1141 (-953 *5)))) (-5 *1 (-1252 *5)) (-5 *4 (-1141 (-953 *5))))) (-2111 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-1141 (-953 *4)) (-1141 (-953 *4)))) (-5 *1 (-1252 *4)) (-4 *4 (-365)))) (-3707 (*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-1141 (-953 *4)) (-1141 (-953 *4)))) (-5 *1 (-1252 *4)) (-4 *4 (-365))))) 
+(-10 -7 (-15 -3707 ((-1 (-1141 (-953 |#1|)) (-1141 (-953 |#1|))) (-763))) (-15 -2111 ((-1 (-1141 (-953 |#1|)) (-1141 (-953 |#1|))) (-763))) (-15 -4193 ((-1141 (-1141 (-953 |#1|))) (-1161) (-1141 (-953 |#1|)))) (-15 -2894 ((-1 (-1157 (-953 |#1|)) (-953 |#1|)) (-1161))) (-15 -3809 ((-634 (-1190 |#1|)) (-1161) (-1190 |#1|))) (-15 -3772 ((-1 (-1141 (-1190 |#1|)) (-1141 (-1190 |#1|))) (-763) (-1190 |#1|) (-1141 (-1190 |#1|))))) 
+((-2443 (((-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) |#2|) 74)) (-3330 (((-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|)))) 73))) 
+(((-1253 |#1| |#2| |#3| |#4|) (-10 -7 (-15 -3330 ((-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))))) (-15 -2443 ((-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) |#2|))) (-350) (-1219 |#1|) (-1219 |#2|) (-411 |#2| |#3|)) (T -1253)) 
+((-2443 (*1 *2 *3) (-12 (-4 *4 (-350)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 *3)) (-5 *2 (-2 (|:| -2588 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-5 *1 (-1253 *4 *3 *5 *6)) (-4 *6 (-411 *3 *5)))) (-3330 (*1 *2) (-12 (-4 *3 (-350)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| -2588 (-679 *4)) (|:| |basisDen| *4) (|:| |basisInv| (-679 *4)))) (-5 *1 (-1253 *3 *4 *5 *6)) (-4 *6 (-411 *4 *5))))) 
+(-10 -7 (-15 -3330 ((-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))))) (-15 -2443 ((-2 (|:| -2588 (-679 |#2|)) (|:| |basisDen| |#2|) (|:| |basisInv| (-679 |#2|))) |#2|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 41)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-2902 (((-3 $ "failed") $) NIL)) (-1598 (((-121) $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2747 (((-850) $) 62) (($ (-568)) NIL) ((|#4| $) 52) (($ |#4|) 47) (($ |#1|) NIL (|has| |#1| (-172)))) (-3425 (((-763)) NIL)) (-3352 (((-1249) (-763)) 16)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 26 T CONST)) (-1557 (($) 65 T CONST)) (-1719 (((-121) $ $) 67)) (-1781 (((-3 $ "failed") $ $) NIL (|has| |#1| (-365)))) (-1775 (($ $) 69) (($ $ $) NIL)) (-1769 (($ $ $) 45)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 71) (($ |#1| $) NIL (|has| |#1| (-172))) (($ $ |#1|) NIL (|has| |#1| (-172))))) 
+(((-1254 |#1| |#2| |#3| |#4| |#5| |#6| |#7|) (-13 (-1047) (-10 -8 (IF (|has| |#1| (-172)) (-6 (-43 |#1|)) |noBranch|) (-15 -2747 (|#4| $)) (IF (|has| |#1| (-365)) (-15 -1781 ((-3 $ "failed") $ $)) |noBranch|) (-15 -2747 ($ |#4|)) (-15 -3352 ((-1249) (-763))))) (-1047) (-842) (-788) (-950 |#1| |#3| |#2|) (-634 |#2|) (-634 (-763)) (-763)) (T -1254)) 
+((-2747 (*1 *2 *1) (-12 (-4 *2 (-950 *3 *5 *4)) (-5 *1 (-1254 *3 *4 *5 *2 *6 *7 *8)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-788)) (-14 *6 (-634 *4)) (-14 *7 (-634 (-763))) (-14 *8 (-763)))) (-1781 (*1 *1 *1 *1) (|partial| -12 (-4 *2 (-365)) (-4 *2 (-1047)) (-4 *3 (-842)) (-4 *4 (-788)) (-14 *6 (-634 *3)) (-5 *1 (-1254 *2 *3 *4 *5 *6 *7 *8)) (-4 *5 (-950 *2 *4 *3)) (-14 *7 (-634 (-763))) (-14 *8 (-763)))) (-2747 (*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-788)) (-14 *6 (-634 *4)) (-5 *1 (-1254 *3 *4 *5 *2 *6 *7 *8)) (-4 *2 (-950 *3 *5 *4)) (-14 *7 (-634 (-763))) (-14 *8 (-763)))) (-3352 (*1 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-1047)) (-4 *5 (-842)) (-4 *6 (-788)) (-14 *8 (-634 *5)) (-5 *2 (-1249)) (-5 *1 (-1254 *4 *5 *6 *7 *8 *9 *10)) (-4 *7 (-950 *4 *6 *5)) (-14 *9 (-634 *3)) (-14 *10 *3)))) 
+(-13 (-1047) (-10 -8 (IF (|has| |#1| (-172)) (-6 (-43 |#1|)) |noBranch|) (-15 -2747 (|#4| $)) (IF (|has| |#1| (-365)) (-15 -1781 ((-3 $ "failed") $ $)) |noBranch|) (-15 -2747 ($ |#4|)) (-15 -3352 ((-1249) (-763))))) 
+((-2449 (((-121) $ $) NIL)) (-2213 (((-634 (-2 (|:| -4094 $) (|:| -2133 (-634 |#4|)))) (-634 |#4|)) NIL)) (-2353 (((-634 $) (-634 |#4|)) 87)) (-2057 (((-634 |#3|) $) NIL)) (-4141 (((-121) $) NIL)) (-1794 (((-121) $) NIL (|has| |#1| (-558)))) (-4231 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-3767 ((|#4| |#4| $) NIL)) (-3647 (((-2 (|:| |under| $) (|:| -4115 $) (|:| |upper| $)) $ |#3|) NIL)) (-1667 (((-121) $ (-763)) NIL)) (-2803 (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521))) (((-3 |#4| "failed") $ |#3|) NIL)) (-4490 (($) NIL T CONST)) (-4382 (((-121) $) NIL (|has| |#1| (-558)))) (-1880 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2536 (((-121) $ $) NIL (|has| |#1| (-558)))) (-2343 (((-121) $) NIL (|has| |#1| (-558)))) (-2941 (((-634 |#4|) (-634 |#4|) $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) 27)) (-3993 (((-634 |#4|) (-634 |#4|) $) 24 (|has| |#1| (-558)))) (-2727 (((-634 |#4|) (-634 |#4|) $) NIL (|has| |#1| (-558)))) (-3668 (((-3 $ "failed") (-634 |#4|)) NIL)) (-2857 (($ (-634 |#4|)) NIL)) (-3936 (((-3 $ "failed") $) 69)) (-3255 ((|#4| |#4| $) 74)) (-3926 (($ $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090))))) (-4330 (($ |#4| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090)))) (($ (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-2607 (((-2 (|:| |rnum| |#1|) (|:| |polnum| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-558)))) (-1359 (((-121) |#4| $ (-1 (-121) |#4| |#4|)) NIL)) (-3434 ((|#4| |#4| $) NIL)) (-3094 ((|#4| (-1 |#4| |#4| |#4|) $ |#4| |#4|) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090)))) ((|#4| (-1 |#4| |#4| |#4|) $ |#4|) NIL (|has| $ (-6 -4521))) ((|#4| (-1 |#4| |#4| |#4|) $) NIL (|has| $ (-6 -4521))) ((|#4| |#4| $ (-1 |#4| |#4| |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-3158 (((-2 (|:| -4094 (-634 |#4|)) (|:| -2133 (-634 |#4|))) $) NIL)) (-3317 (((-634 |#4|) $) NIL (|has| $ (-6 -4521)))) (-3764 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-4001 ((|#3| $) 75)) (-3791 (((-121) $ (-763)) NIL)) (-4406 (((-634 |#4|) $) 28 (|has| $ (-6 -4521)))) (-2551 (((-121) |#4| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090))))) (-4325 (((-3 $ "failed") (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|)) 31) (((-3 $ "failed") (-634 |#4|)) 34)) (-2253 (($ (-1 |#4| |#4|) $) NIL (|has| $ (-6 -4522)))) (-2797 (($ (-1 |#4| |#4|) $) NIL)) (-2249 (((-634 |#3|) $) NIL)) (-1495 (((-121) |#3| $) NIL)) (-3796 (((-121) $ (-763)) NIL)) (-1893 (((-1143) $) NIL)) (-4164 (((-3 |#4| "failed") $) NIL)) (-3882 (((-634 |#4|) $) 49)) (-2157 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-1315 ((|#4| |#4| $) 73)) (-4342 (((-121) $ $) 84)) (-1440 (((-2 (|:| |num| |#4|) (|:| |den| |#1|)) |#4| $) NIL (|has| |#1| (-558)))) (-3236 (((-121) |#4| $) NIL) (((-121) $) NIL)) (-1452 ((|#4| |#4| $) NIL)) (-4025 (((-1108) $) NIL)) (-3877 (((-3 |#4| "failed") $) 68)) (-2712 (((-3 |#4| "failed") (-1 (-121) |#4|) $) NIL)) (-3413 (((-3 $ "failed") $ |#4|) NIL)) (-2168 (($ $ |#4|) NIL)) (-3951 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-1339 (($ $ (-634 |#4|) (-634 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ |#4| |#4|) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-288 |#4|)) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090)))) (($ $ (-634 (-288 |#4|))) NIL (-12 (|has| |#4| (-303 |#4|)) (|has| |#4| (-1090))))) (-1702 (((-121) $ $) NIL)) (-2436 (((-121) $) 66)) (-1990 (($) 41)) (-1836 (((-763) $) NIL)) (-4170 (((-763) |#4| $) NIL (-12 (|has| $ (-6 -4521)) (|has| |#4| (-1090)))) (((-763) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-3865 (($ $) NIL)) (-4280 (((-541) $) NIL (|has| |#4| (-609 (-541))))) (-4289 (($ (-634 |#4|)) NIL)) (-3206 (($ $ |#3|) NIL)) (-2527 (($ $ |#3|) NIL)) (-4392 (($ $) NIL)) (-4332 (($ $ |#3|) NIL)) (-2747 (((-850) $) NIL) (((-634 |#4|) $) 56)) (-2524 (((-763) $) NIL (|has| |#3| (-370)))) (-2015 (((-3 $ "failed") (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|)) 39) (((-3 $ "failed") (-634 |#4|)) 40)) (-2058 (((-634 $) (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|)) 64) (((-634 $) (-634 |#4|)) 65)) (-2835 (((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4| |#4|)) 23) (((-3 (-2 (|:| |bas| $) (|:| -2618 (-634 |#4|))) "failed") (-634 |#4|) (-1 (-121) |#4|) (-1 (-121) |#4| |#4|)) NIL)) (-2145 (((-121) $ (-1 (-121) |#4| (-634 |#4|))) NIL)) (-3437 (((-121) (-1 (-121) |#4|) $) NIL (|has| $ (-6 -4521)))) (-3321 (((-634 |#3|) $) NIL)) (-1413 (((-121) |#3| $) NIL)) (-1719 (((-121) $ $) NIL)) (-1699 (((-763) $) NIL (|has| $ (-6 -4521))))) 
+(((-1255 |#1| |#2| |#3| |#4|) (-13 (-1189 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -4325 ((-3 $ "failed") (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -4325 ((-3 $ "failed") (-634 |#4|))) (-15 -2015 ((-3 $ "failed") (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -2015 ((-3 $ "failed") (-634 |#4|))) (-15 -2058 ((-634 $) (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -2058 ((-634 $) (-634 |#4|))))) (-558) (-788) (-842) (-1061 |#1| |#2| |#3|)) (T -1255)) 
+((-4325 (*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-634 *8)) (-5 *3 (-1 (-121) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1255 *5 *6 *7 *8)))) (-4325 (*1 *1 *2) (|partial| -12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-1255 *3 *4 *5 *6)))) (-2015 (*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-634 *8)) (-5 *3 (-1 (-121) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1255 *5 *6 *7 *8)))) (-2015 (*1 *1 *2) (|partial| -12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-1255 *3 *4 *5 *6)))) (-2058 (*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 *9)) (-5 *4 (-1 (-121) *9 *9)) (-5 *5 (-1 *9 *9 *9)) (-4 *9 (-1061 *6 *7 *8)) (-4 *6 (-558)) (-4 *7 (-788)) (-4 *8 (-842)) (-5 *2 (-634 (-1255 *6 *7 *8 *9))) (-5 *1 (-1255 *6 *7 *8 *9)))) (-2058 (*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 (-1255 *4 *5 *6 *7))) (-5 *1 (-1255 *4 *5 *6 *7))))) 
+(-13 (-1189 |#1| |#2| |#3| |#4|) (-10 -8 (-15 -4325 ((-3 $ "failed") (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -4325 ((-3 $ "failed") (-634 |#4|))) (-15 -2015 ((-3 $ "failed") (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -2015 ((-3 $ "failed") (-634 |#4|))) (-15 -2058 ((-634 $) (-634 |#4|) (-1 (-121) |#4| |#4|) (-1 |#4| |#4| |#4|))) (-15 -2058 ((-634 $) (-634 |#4|))))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2689 (((-3 $ "failed") $ $) 18)) (-4490 (($) 16 T CONST)) (-2902 (((-3 $ "failed") $) 33)) (-1598 (((-121) $) 30)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ |#1|) 37)) (-3425 (((-763)) 28)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ |#1|) 39) (($ |#1| $) 38))) 
 (((-1256 |#1|) (-1275) (-1047)) (T -1256)) 
-((-2745 (*1 *1 *2) (-12 (-4 *1 (-1256 *2)) (-4 *2 (-1047))))) 
-(-13 (-1047) (-120 |t#1| |t#1|) (-10 -8 (-15 -2745 ($ |t#1|)) (IF (|has| |t#1| (-172)) (-6 (-43 |t#1|)) |noBranch|))) 
+((-2747 (*1 *1 *2) (-12 (-4 *1 (-1256 *2)) (-4 *2 (-1047))))) 
+(-13 (-1047) (-120 |t#1| |t#1|) (-10 -8 (-15 -2747 ($ |t#1|)) (IF (|has| |t#1| (-172)) (-6 (-43 |t#1|)) |noBranch|))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#1|) |has| |#1| (-172)) ((-105) . T) ((-120 |#1| |#1|) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 |#1|) . T) ((-637 $) . T) ((-707 |#1|) |has| |#1| (-172)) ((-716) . T) ((-1053 |#1|) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3595 (((-634 |#1|) $) 45)) (-2821 (($ $ (-763)) 39)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2238 (($ $ (-763)) 17 (|has| |#2| (-172))) (($ $ $) 18 (|has| |#2| (-172)))) (-2671 (($) NIL T CONST)) (-2628 (($ $ $) 61) (($ $ (-814 |#1|)) 48) (($ $ |#1|) 52)) (-3666 (((-3 (-814 |#1|) "failed") $) NIL)) (-2854 (((-814 |#1|) $) NIL)) (-2114 (($ $) 32)) (-2925 (((-3 $ "failed") $) NIL)) (-3363 (((-121) $) NIL)) (-2207 (($ $) NIL)) (-2735 (((-121) $) NIL)) (-4178 (((-763) $) NIL)) (-2976 (((-634 $) $) NIL)) (-3921 (((-121) $) NIL)) (-2354 (($ (-814 |#1|) |#2|) 31)) (-2407 (($ $) 33)) (-3169 (((-2 (|:| |k| (-814 |#1|)) (|:| |c| |#2|)) $) 11)) (-2018 (((-814 |#1|) $) NIL)) (-1666 (((-814 |#1|) $) 34)) (-2795 (($ (-1 |#2| |#2|) $) NIL)) (-2532 (($ $ $) 60) (($ $ (-814 |#1|)) 50) (($ $ |#1|) 54)) (-4297 (((-634 (-2 (|:| |k| (-814 |#1|)) (|:| |c| |#2|))) $) NIL)) (-2315 (((-2 (|:| |k| (-814 |#1|)) (|:| |c| |#2|)) $) NIL)) (-2097 (((-814 |#1|) $) 28)) (-2102 ((|#2| $) 30)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-3206 (((-763) $) 36)) (-1867 (((-121) $) 40)) (-3495 ((|#2| $) NIL)) (-2745 (((-850) $) NIL) (($ (-814 |#1|)) 24) (($ |#1|) 25) (($ |#2|) NIL) (($ (-568)) NIL)) (-1302 (((-634 |#2|) $) NIL)) (-2604 ((|#2| $ (-814 |#1|)) NIL)) (-2348 ((|#2| $ $) 63) ((|#2| $ (-814 |#1|)) NIL)) (-4078 (((-763)) NIL)) (-1887 (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (-3056 (($) 12 T CONST)) (-1556 (($) 14 T CONST)) (-1717 (((-121) $ $) 38)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) 21)) (** (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ |#2| $) 20) (($ $ |#2|) 59) (($ |#2| (-814 |#1|)) NIL) (($ |#1| $) 27) (($ $ $) NIL))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2981 (((-634 |#1|) $) 45)) (-3784 (($ $ (-763)) 39)) (-2689 (((-3 $ "failed") $ $) NIL)) (-2726 (($ $ (-763)) 17 (|has| |#2| (-172))) (($ $ $) 18 (|has| |#2| (-172)))) (-4490 (($) NIL T CONST)) (-4242 (($ $ $) 61) (($ $ (-814 |#1|)) 48) (($ $ |#1|) 52)) (-3668 (((-3 (-814 |#1|) "failed") $) NIL)) (-2857 (((-814 |#1|) $) NIL)) (-2116 (($ $) 32)) (-2902 (((-3 $ "failed") $) NIL)) (-1335 (((-121) $) NIL)) (-3201 (($ $) NIL)) (-1598 (((-121) $) NIL)) (-3971 (((-763) $) NIL)) (-3062 (((-634 $) $) NIL)) (-2171 (((-121) $) NIL)) (-2356 (($ (-814 |#1|) |#2|) 31)) (-2310 (($ $) 33)) (-1690 (((-2 (|:| |k| (-814 |#1|)) (|:| |c| |#2|)) $) 11)) (-1341 (((-814 |#1|) $) NIL)) (-3421 (((-814 |#1|) $) 34)) (-2797 (($ (-1 |#2| |#2|) $) NIL)) (-1797 (($ $ $) 60) (($ $ (-814 |#1|)) 50) (($ $ |#1|) 54)) (-3016 (((-634 (-2 (|:| |k| (-814 |#1|)) (|:| |c| |#2|))) $) NIL)) (-3749 (((-2 (|:| |k| (-814 |#1|)) (|:| |c| |#2|)) $) NIL)) (-2099 (((-814 |#1|) $) 28)) (-2104 ((|#2| $) 30)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-1836 (((-763) $) 36)) (-2475 (((-121) $) 40)) (-3497 ((|#2| $) NIL)) (-2747 (((-850) $) NIL) (($ (-814 |#1|)) 24) (($ |#1|) 25) (($ |#2|) NIL) (($ (-568)) NIL)) (-3304 (((-634 |#2|) $) NIL)) (-2079 ((|#2| $ (-814 |#1|)) NIL)) (-2350 ((|#2| $ $) 63) ((|#2| $ (-814 |#1|)) NIL)) (-3425 (((-763)) NIL)) (-1889 (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (-3058 (($) 12 T CONST)) (-1557 (($) 14 T CONST)) (-1719 (((-121) $ $) 38)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) 21)) (** (($ $ (-763)) NIL) (($ $ (-917)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ |#2| $) 20) (($ $ |#2|) 59) (($ |#2| (-814 |#1|)) NIL) (($ |#1| $) 27) (($ $ $) NIL))) 
 (((-1257 |#1| |#2|) (-13 (-384 |#2| (-814 |#1|)) (-1263 |#1| |#2|)) (-842) (-1047)) (T -1257)) 
 NIL 
 (-13 (-384 |#2| (-814 |#1|)) (-1263 |#1| |#2|)) 
-((-4416 ((|#3| |#3| (-763)) 23)) (-1892 ((|#3| |#3| (-763)) 28)) (-2665 ((|#3| |#3| |#3| (-763)) 29))) 
-(((-1258 |#1| |#2| |#3|) (-10 -7 (-15 -1892 (|#3| |#3| (-763))) (-15 -4416 (|#3| |#3| (-763))) (-15 -2665 (|#3| |#3| |#3| (-763)))) (-13 (-1047) (-707 (-409 (-568)))) (-842) (-1263 |#2| |#1|)) (T -1258)) 
-((-2665 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-13 (-1047) (-707 (-409 (-568))))) (-4 *5 (-842)) (-5 *1 (-1258 *4 *5 *2)) (-4 *2 (-1263 *5 *4)))) (-4416 (*1 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-13 (-1047) (-707 (-409 (-568))))) (-4 *5 (-842)) (-5 *1 (-1258 *4 *5 *2)) (-4 *2 (-1263 *5 *4)))) (-1892 (*1 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-13 (-1047) (-707 (-409 (-568))))) (-4 *5 (-842)) (-5 *1 (-1258 *4 *5 *2)) (-4 *2 (-1263 *5 *4))))) 
-(-10 -7 (-15 -1892 (|#3| |#3| (-763))) (-15 -4416 (|#3| |#3| (-763))) (-15 -2665 (|#3| |#3| |#3| (-763)))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3595 (((-634 |#1|) $) 39)) (-3134 (((-3 $ "failed") $ $) 18)) (-2238 (($ $ $) 42 (|has| |#2| (-172))) (($ $ (-763)) 41 (|has| |#2| (-172)))) (-2671 (($) 16 T CONST)) (-2628 (($ $ |#1|) 53) (($ $ (-814 |#1|)) 52) (($ $ $) 51)) (-3666 (((-3 (-814 |#1|) "failed") $) 63)) (-2854 (((-814 |#1|) $) 62)) (-2925 (((-3 $ "failed") $) 33)) (-3363 (((-121) $) 44)) (-2207 (($ $) 43)) (-2735 (((-121) $) 30)) (-3921 (((-121) $) 49)) (-2354 (($ (-814 |#1|) |#2|) 50)) (-2407 (($ $) 48)) (-3169 (((-2 (|:| |k| (-814 |#1|)) (|:| |c| |#2|)) $) 59)) (-2018 (((-814 |#1|) $) 60)) (-2795 (($ (-1 |#2| |#2|) $) 40)) (-2532 (($ $ |#1|) 56) (($ $ (-814 |#1|)) 55) (($ $ $) 54)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-1867 (((-121) $) 46)) (-3495 ((|#2| $) 45)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ |#2|) 67) (($ (-814 |#1|)) 64) (($ |#1|) 47)) (-2348 ((|#2| $ (-814 |#1|)) 58) ((|#2| $ $) 57)) (-4078 (((-763)) 28)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ |#2| $) 66) (($ $ |#2|) 65) (($ |#1| $) 61))) 
+((-4418 ((|#3| |#3| (-763)) 23)) (-1894 ((|#3| |#3| (-763)) 28)) (-4460 ((|#3| |#3| |#3| (-763)) 29))) 
+(((-1258 |#1| |#2| |#3|) (-10 -7 (-15 -1894 (|#3| |#3| (-763))) (-15 -4418 (|#3| |#3| (-763))) (-15 -4460 (|#3| |#3| |#3| (-763)))) (-13 (-1047) (-707 (-409 (-568)))) (-842) (-1263 |#2| |#1|)) (T -1258)) 
+((-4460 (*1 *2 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-13 (-1047) (-707 (-409 (-568))))) (-4 *5 (-842)) (-5 *1 (-1258 *4 *5 *2)) (-4 *2 (-1263 *5 *4)))) (-4418 (*1 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-13 (-1047) (-707 (-409 (-568))))) (-4 *5 (-842)) (-5 *1 (-1258 *4 *5 *2)) (-4 *2 (-1263 *5 *4)))) (-1894 (*1 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-13 (-1047) (-707 (-409 (-568))))) (-4 *5 (-842)) (-5 *1 (-1258 *4 *5 *2)) (-4 *2 (-1263 *5 *4))))) 
+(-10 -7 (-15 -1894 (|#3| |#3| (-763))) (-15 -4418 (|#3| |#3| (-763))) (-15 -4460 (|#3| |#3| |#3| (-763)))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2981 (((-634 |#1|) $) 39)) (-2689 (((-3 $ "failed") $ $) 18)) (-2726 (($ $ $) 42 (|has| |#2| (-172))) (($ $ (-763)) 41 (|has| |#2| (-172)))) (-4490 (($) 16 T CONST)) (-4242 (($ $ |#1|) 53) (($ $ (-814 |#1|)) 52) (($ $ $) 51)) (-3668 (((-3 (-814 |#1|) "failed") $) 63)) (-2857 (((-814 |#1|) $) 62)) (-2902 (((-3 $ "failed") $) 33)) (-1335 (((-121) $) 44)) (-3201 (($ $) 43)) (-1598 (((-121) $) 30)) (-2171 (((-121) $) 49)) (-2356 (($ (-814 |#1|) |#2|) 50)) (-2310 (($ $) 48)) (-1690 (((-2 (|:| |k| (-814 |#1|)) (|:| |c| |#2|)) $) 59)) (-1341 (((-814 |#1|) $) 60)) (-2797 (($ (-1 |#2| |#2|) $) 40)) (-1797 (($ $ |#1|) 56) (($ $ (-814 |#1|)) 55) (($ $ $) 54)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-2475 (((-121) $) 46)) (-3497 ((|#2| $) 45)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ |#2|) 67) (($ (-814 |#1|)) 64) (($ |#1|) 47)) (-2350 ((|#2| $ (-814 |#1|)) 58) ((|#2| $ $) 57)) (-3425 (((-763)) 28)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ |#2| $) 66) (($ $ |#2|) 65) (($ |#1| $) 61))) 
 (((-1259 |#1| |#2|) (-1275) (-842) (-1047)) (T -1259)) 
-((* (*1 *1 *1 *2) (-12 (-4 *1 (-1259 *3 *2)) (-4 *3 (-842)) (-4 *2 (-1047)))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) (-2018 (*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-814 *3)))) (-3169 (*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-2 (|:| |k| (-814 *3)) (|:| |c| *4))))) (-2348 (*1 *2 *1 *3) (-12 (-5 *3 (-814 *4)) (-4 *1 (-1259 *4 *2)) (-4 *4 (-842)) (-4 *2 (-1047)))) (-2348 (*1 *2 *1 *1) (-12 (-4 *1 (-1259 *3 *2)) (-4 *3 (-842)) (-4 *2 (-1047)))) (-2532 (*1 *1 *1 *2) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) (-2532 (*1 *1 *1 *2) (-12 (-5 *2 (-814 *3)) (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)))) (-2532 (*1 *1 *1 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) (-2628 (*1 *1 *1 *2) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) (-2628 (*1 *1 *1 *2) (-12 (-5 *2 (-814 *3)) (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)))) (-2628 (*1 *1 *1 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) (-2354 (*1 *1 *2 *3) (-12 (-5 *2 (-814 *4)) (-4 *4 (-842)) (-4 *1 (-1259 *4 *3)) (-4 *3 (-1047)))) (-3921 (*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-121)))) (-2407 (*1 *1 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) (-2745 (*1 *1 *2) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) (-1867 (*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-121)))) (-3495 (*1 *2 *1) (-12 (-4 *1 (-1259 *3 *2)) (-4 *3 (-842)) (-4 *2 (-1047)))) (-3363 (*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-121)))) (-2207 (*1 *1 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) (-2238 (*1 *1 *1 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)) (-4 *3 (-172)))) (-2238 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-4 *4 (-172)))) (-2795 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)))) (-3595 (*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-634 *3))))) 
-(-13 (-1047) (-1256 |t#2|) (-1037 (-814 |t#1|)) (-10 -8 (-15 * ($ |t#1| $)) (-15 * ($ $ |t#2|)) (-15 -2018 ((-814 |t#1|) $)) (-15 -3169 ((-2 (|:| |k| (-814 |t#1|)) (|:| |c| |t#2|)) $)) (-15 -2348 (|t#2| $ (-814 |t#1|))) (-15 -2348 (|t#2| $ $)) (-15 -2532 ($ $ |t#1|)) (-15 -2532 ($ $ (-814 |t#1|))) (-15 -2532 ($ $ $)) (-15 -2628 ($ $ |t#1|)) (-15 -2628 ($ $ (-814 |t#1|))) (-15 -2628 ($ $ $)) (-15 -2354 ($ (-814 |t#1|) |t#2|)) (-15 -3921 ((-121) $)) (-15 -2407 ($ $)) (-15 -2745 ($ |t#1|)) (-15 -1867 ((-121) $)) (-15 -3495 (|t#2| $)) (-15 -3363 ((-121) $)) (-15 -2207 ($ $)) (IF (|has| |t#2| (-172)) (PROGN (-15 -2238 ($ $ $)) (-15 -2238 ($ $ (-763)))) |noBranch|) (-15 -2795 ($ (-1 |t#2| |t#2|) $)) (-15 -3595 ((-634 |t#1|) $)) (IF (|has| |t#2| (-6 -4512)) (-6 -4512) |noBranch|))) 
+((* (*1 *1 *1 *2) (-12 (-4 *1 (-1259 *3 *2)) (-4 *3 (-842)) (-4 *2 (-1047)))) (* (*1 *1 *2 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) (-1341 (*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-814 *3)))) (-1690 (*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-2 (|:| |k| (-814 *3)) (|:| |c| *4))))) (-2350 (*1 *2 *1 *3) (-12 (-5 *3 (-814 *4)) (-4 *1 (-1259 *4 *2)) (-4 *4 (-842)) (-4 *2 (-1047)))) (-2350 (*1 *2 *1 *1) (-12 (-4 *1 (-1259 *3 *2)) (-4 *3 (-842)) (-4 *2 (-1047)))) (-1797 (*1 *1 *1 *2) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) (-1797 (*1 *1 *1 *2) (-12 (-5 *2 (-814 *3)) (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)))) (-1797 (*1 *1 *1 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) (-4242 (*1 *1 *1 *2) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) (-4242 (*1 *1 *1 *2) (-12 (-5 *2 (-814 *3)) (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)))) (-4242 (*1 *1 *1 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) (-2356 (*1 *1 *2 *3) (-12 (-5 *2 (-814 *4)) (-4 *4 (-842)) (-4 *1 (-1259 *4 *3)) (-4 *3 (-1047)))) (-2171 (*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-121)))) (-2310 (*1 *1 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) (-2747 (*1 *1 *2) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) (-2475 (*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-121)))) (-3497 (*1 *2 *1) (-12 (-4 *1 (-1259 *3 *2)) (-4 *3 (-842)) (-4 *2 (-1047)))) (-1335 (*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-121)))) (-3201 (*1 *1 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) (-2726 (*1 *1 *1 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)) (-4 *3 (-172)))) (-2726 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-4 *4 (-172)))) (-2797 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)))) (-2981 (*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-634 *3))))) 
+(-13 (-1047) (-1256 |t#2|) (-1037 (-814 |t#1|)) (-10 -8 (-15 * ($ |t#1| $)) (-15 * ($ $ |t#2|)) (-15 -1341 ((-814 |t#1|) $)) (-15 -1690 ((-2 (|:| |k| (-814 |t#1|)) (|:| |c| |t#2|)) $)) (-15 -2350 (|t#2| $ (-814 |t#1|))) (-15 -2350 (|t#2| $ $)) (-15 -1797 ($ $ |t#1|)) (-15 -1797 ($ $ (-814 |t#1|))) (-15 -1797 ($ $ $)) (-15 -4242 ($ $ |t#1|)) (-15 -4242 ($ $ (-814 |t#1|))) (-15 -4242 ($ $ $)) (-15 -2356 ($ (-814 |t#1|) |t#2|)) (-15 -2171 ((-121) $)) (-15 -2310 ($ $)) (-15 -2747 ($ |t#1|)) (-15 -2475 ((-121) $)) (-15 -3497 (|t#2| $)) (-15 -1335 ((-121) $)) (-15 -3201 ($ $)) (IF (|has| |t#2| (-172)) (PROGN (-15 -2726 ($ $ $)) (-15 -2726 ($ $ (-763)))) |noBranch|) (-15 -2797 ($ (-1 |t#2| |t#2|) $)) (-15 -2981 ((-634 |t#1|) $)) (IF (|has| |t#2| (-6 -4514)) (-6 -4514) |noBranch|))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#2|) |has| |#2| (-172)) ((-105) . T) ((-120 |#2| |#2|) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 |#2|) . T) ((-637 $) . T) ((-707 |#2|) |has| |#2| (-172)) ((-716) . T) ((-1037 (-814 |#1|)) . T) ((-1053 |#2|) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1256 |#2|) . T)) 
-((-2615 (((-121) $) 13)) (-4390 (((-121) $) 12)) (-1316 (($ $) 17) (($ $ (-763)) 18))) 
-(((-1260 |#1| |#2|) (-10 -8 (-15 -1316 (|#1| |#1| (-763))) (-15 -1316 (|#1| |#1|)) (-15 -2615 ((-121) |#1|)) (-15 -4390 ((-121) |#1|))) (-1261 |#2|) (-365)) (T -1260)) 
+((-2134 (((-121) $) 13)) (-1413 (((-121) $) 12)) (-3412 (($ $) 17) (($ $ (-763)) 18))) 
+(((-1260 |#1| |#2|) (-10 -8 (-15 -3412 (|#1| |#1| (-763))) (-15 -3412 (|#1| |#1|)) (-15 -2134 ((-121) |#1|)) (-15 -1413 ((-121) |#1|))) (-1261 |#2|) (-365)) (T -1260)) 
 NIL 
-(-10 -8 (-15 -1316 (|#1| |#1| (-763))) (-15 -1316 (|#1| |#1|)) (-15 -2615 ((-121) |#1|)) (-15 -4390 ((-121) |#1|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3712 (((-2 (|:| -2295 $) (|:| -4506 $) (|:| |associate| $)) $) 40)) (-2227 (($ $) 39)) (-1573 (((-121) $) 37)) (-2615 (((-121) $) 90)) (-1739 (((-763)) 86)) (-3134 (((-3 $ "failed") $ $) 18)) (-4305 (($ $) 71)) (-1678 (((-420 $) $) 70)) (-1497 (((-121) $ $) 57)) (-2671 (($) 16 T CONST)) (-3666 (((-3 |#1| "failed") $) 97)) (-2854 ((|#1| $) 96)) (-2401 (($ $ $) 53)) (-2925 (((-3 $ "failed") $) 33)) (-2412 (($ $ $) 54)) (-1983 (((-2 (|:| -2348 (-634 $)) (|:| -2704 $)) (-634 $)) 49)) (-3218 (($ $ (-763)) 83 (-2198 (|has| |#1| (-148)) (|has| |#1| (-370)))) (($ $) 82 (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3927 (((-121) $) 69)) (-4477 (((-828 (-917)) $) 80 (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-2735 (((-121) $) 30)) (-3562 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-2495 (($ $ $) 45) (($ (-634 $)) 44)) (-4487 (((-1143) $) 9)) (-2081 (($ $) 68)) (-2864 (((-121) $) 89)) (-4022 (((-1108) $) 10)) (-2155 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2721 (($ $ $) 47) (($ (-634 $)) 46)) (-3848 (((-420 $) $) 72)) (-1553 (((-828 (-917))) 87)) (-4497 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2704 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2595 (((-3 $ "failed") $ $) 41)) (-2344 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-2709 (((-763) $) 56)) (-3210 (((-2 (|:| -3961 $) (|:| -1500 $)) $ $) 55)) (-3143 (((-3 (-763) "failed") $ $) 81 (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-4321 (((-139)) 95)) (-3206 (((-828 (-917)) $) 88)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63) (($ |#1|) 98)) (-4371 (((-3 $ "failed") $) 79 (-2198 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-4078 (((-763)) 28)) (-1826 (((-121) $ $) 38)) (-4390 (((-121) $) 91)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1316 (($ $) 85 (|has| |#1| (-370))) (($ $ (-763)) 84 (|has| |#1| (-370)))) (-1717 (((-121) $ $) 6)) (-1779 (($ $ $) 62) (($ $ |#1|) 94)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64) (($ $ |#1|) 93) (($ |#1| $) 92))) 
+(-10 -8 (-15 -3412 (|#1| |#1| (-763))) (-15 -3412 (|#1| |#1|)) (-15 -2134 ((-121) |#1|)) (-15 -1413 ((-121) |#1|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2431 (((-2 (|:| -3591 $) (|:| -4508 $) (|:| |associate| $)) $) 40)) (-3661 (($ $) 39)) (-4426 (((-121) $) 37)) (-2134 (((-121) $) 90)) (-3800 (((-763)) 86)) (-2689 (((-3 $ "failed") $ $) 18)) (-3045 (($ $) 71)) (-3498 (((-420 $) $) 70)) (-2589 (((-121) $ $) 57)) (-4490 (($) 16 T CONST)) (-3668 (((-3 |#1| "failed") $) 97)) (-2857 ((|#1| $) 96)) (-2403 (($ $ $) 53)) (-2902 (((-3 $ "failed") $) 33)) (-2414 (($ $ $) 54)) (-4422 (((-2 (|:| -2350 (-634 $)) (|:| -2707 $)) (-634 $)) 49)) (-1887 (($ $ (-763)) 83 (-2199 (|has| |#1| (-148)) (|has| |#1| (-370)))) (($ $) 82 (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-2197 (((-121) $) 69)) (-1844 (((-828 (-917)) $) 80 (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-1598 (((-121) $) 30)) (-2855 (((-3 (-634 $) "failed") (-634 $) $) 50)) (-2498 (($ $ $) 45) (($ (-634 $)) 44)) (-1893 (((-1143) $) 9)) (-2083 (($ $) 68)) (-4051 (((-121) $) 89)) (-4025 (((-1108) $) 10)) (-3603 (((-1157 $) (-1157 $) (-1157 $)) 43)) (-2723 (($ $ $) 47) (($ (-634 $)) 46)) (-3850 (((-420 $) $) 72)) (-4321 (((-828 (-917))) 87)) (-3833 (((-2 (|:| |coef1| $) (|:| |coef2| $) (|:| -2707 $)) $ $) 52) (((-3 (-2 (|:| |coef1| $) (|:| |coef2| $)) "failed") $ $ $) 51)) (-2597 (((-3 $ "failed") $ $) 41)) (-3922 (((-3 (-634 $) "failed") (-634 $) $) 48)) (-1466 (((-763) $) 56)) (-1854 (((-2 (|:| -4409 $) (|:| -2607 $)) $ $) 55)) (-2721 (((-3 (-763) "failed") $ $) 81 (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3108 (((-139)) 95)) (-1836 (((-828 (-917)) $) 88)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ $) 42) (($ (-409 (-568))) 63) (($ |#1|) 98)) (-3385 (((-3 $ "failed") $) 79 (-2199 (|has| |#1| (-148)) (|has| |#1| (-370))))) (-3425 (((-763)) 28)) (-2273 (((-121) $ $) 38)) (-1413 (((-121) $) 91)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32) (($ $ (-568)) 67)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-3412 (($ $) 85 (|has| |#1| (-370))) (($ $ (-763)) 84 (|has| |#1| (-370)))) (-1719 (((-121) $ $) 6)) (-1781 (($ $ $) 62) (($ $ |#1|) 94)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31) (($ $ (-568)) 66)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ $ (-409 (-568))) 65) (($ (-409 (-568)) $) 64) (($ $ |#1|) 93) (($ |#1| $) 92))) 
 (((-1261 |#1|) (-1275) (-365)) (T -1261)) 
-((-4390 (*1 *2 *1) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-121)))) (-2615 (*1 *2 *1) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-121)))) (-2864 (*1 *2 *1) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-121)))) (-3206 (*1 *2 *1) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-828 (-917))))) (-1553 (*1 *2) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-828 (-917))))) (-1739 (*1 *2) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-763)))) (-1316 (*1 *1 *1) (-12 (-4 *1 (-1261 *2)) (-4 *2 (-365)) (-4 *2 (-370)))) (-1316 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-4 *3 (-370))))) 
-(-13 (-365) (-1037 |t#1|) (-1251 |t#1|) (-10 -8 (IF (|has| |t#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |t#1| (-148)) (-6 (-404)) |noBranch|) (-15 -4390 ((-121) $)) (-15 -2615 ((-121) $)) (-15 -2864 ((-121) $)) (-15 -3206 ((-828 (-917)) $)) (-15 -1553 ((-828 (-917)))) (-15 -1739 ((-763))) (IF (|has| |t#1| (-370)) (PROGN (-6 (-404)) (-15 -1316 ($ $)) (-15 -1316 ($ $ (-763)))) |noBranch|))) 
-(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 |#1| |#1|) . T) ((-120 $ $) . T) ((-137) . T) ((-148) -2198 (|has| |#1| (-370)) (|has| |#1| (-148))) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) . T) ((-238) . T) ((-285) . T) ((-301) . T) ((-365) . T) ((-404) -2198 (|has| |#1| (-370)) (|has| |#1| (-148))) ((-453) . T) ((-558) . T) ((-637 (-409 (-568))) . T) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) . T) ((-707 |#1|) . T) ((-707 $) . T) ((-716) . T) ((-916) . T) ((-1037 |#1|) . T) ((-1053 (-409 (-568))) . T) ((-1053 |#1|) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1199) . T) ((-1251 |#1|) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3595 (((-634 |#1|) $) 84)) (-2821 (($ $ (-763)) 87)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2238 (($ $ $) NIL (|has| |#2| (-172))) (($ $ (-763)) NIL (|has| |#2| (-172)))) (-2671 (($) NIL T CONST)) (-2628 (($ $ |#1|) NIL) (($ $ (-814 |#1|)) NIL) (($ $ $) NIL)) (-3666 (((-3 (-814 |#1|) "failed") $) NIL) (((-3 (-888 |#1|) "failed") $) NIL)) (-2854 (((-814 |#1|) $) NIL) (((-888 |#1|) $) NIL)) (-2114 (($ $) 86)) (-2925 (((-3 $ "failed") $) NIL)) (-3363 (((-121) $) 75)) (-2207 (($ $) 79)) (-3272 (($ $ $ (-763)) 88)) (-2735 (((-121) $) NIL)) (-4178 (((-763) $) NIL)) (-2976 (((-634 $) $) NIL)) (-3921 (((-121) $) NIL)) (-2354 (($ (-814 |#1|) |#2|) NIL) (($ (-888 |#1|) |#2|) 25)) (-2407 (($ $) 101)) (-3169 (((-2 (|:| |k| (-814 |#1|)) (|:| |c| |#2|)) $) NIL)) (-2018 (((-814 |#1|) $) NIL)) (-1666 (((-814 |#1|) $) NIL)) (-2795 (($ (-1 |#2| |#2|) $) NIL)) (-2532 (($ $ |#1|) NIL) (($ $ (-814 |#1|)) NIL) (($ $ $) NIL)) (-4416 (($ $ (-763)) 95 (|has| |#2| (-707 (-409 (-568)))))) (-4297 (((-634 (-2 (|:| |k| (-888 |#1|)) (|:| |c| |#2|))) $) NIL)) (-2315 (((-2 (|:| |k| (-888 |#1|)) (|:| |c| |#2|)) $) NIL)) (-2097 (((-888 |#1|) $) 69)) (-2102 ((|#2| $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-1892 (($ $ (-763)) 92 (|has| |#2| (-707 (-409 (-568)))))) (-3206 (((-763) $) 85)) (-1867 (((-121) $) 70)) (-3495 ((|#2| $) 74)) (-2745 (((-850) $) 56) (($ (-568)) NIL) (($ |#2|) 50) (($ (-814 |#1|)) NIL) (($ |#1|) 58) (($ (-888 |#1|)) NIL) (($ (-656 |#1| |#2|)) 42) (((-1257 |#1| |#2|) $) 63) (((-1266 |#1| |#2|) $) 68)) (-1302 (((-634 |#2|) $) NIL)) (-2604 ((|#2| $ (-888 |#1|)) NIL)) (-2348 ((|#2| $ (-814 |#1|)) NIL) ((|#2| $ $) NIL)) (-4078 (((-763)) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 21 T CONST)) (-1556 (($) 24 T CONST)) (-2253 (((-3 (-656 |#1| |#2|) "failed") $) 100)) (-1717 (((-121) $ $) 64)) (-1773 (($ $) 94) (($ $ $) 93)) (-1767 (($ $ $) 20)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 43) (($ |#2| $) 19) (($ $ |#2|) NIL) (($ |#1| $) NIL) (($ |#2| (-888 |#1|)) NIL))) 
-(((-1262 |#1| |#2|) (-13 (-1263 |#1| |#2|) (-384 |#2| (-888 |#1|)) (-10 -8 (-15 -2745 ($ (-656 |#1| |#2|))) (-15 -2745 ((-1257 |#1| |#2|) $)) (-15 -2745 ((-1266 |#1| |#2|) $)) (-15 -2253 ((-3 (-656 |#1| |#2|) "failed") $)) (-15 -3272 ($ $ $ (-763))) (IF (|has| |#2| (-707 (-409 (-568)))) (PROGN (-15 -1892 ($ $ (-763))) (-15 -4416 ($ $ (-763)))) |noBranch|))) (-842) (-172)) (T -1262)) 
-((-2745 (*1 *1 *2) (-12 (-5 *2 (-656 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *1 (-1262 *3 *4)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-1257 *3 *4)) (-5 *1 (-1262 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) (-2745 (*1 *2 *1) (-12 (-5 *2 (-1266 *3 *4)) (-5 *1 (-1262 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) (-2253 (*1 *2 *1) (|partial| -12 (-5 *2 (-656 *3 *4)) (-5 *1 (-1262 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) (-3272 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1262 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) (-1892 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1262 *3 *4)) (-4 *4 (-707 (-409 (-568)))) (-4 *3 (-842)) (-4 *4 (-172)))) (-4416 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1262 *3 *4)) (-4 *4 (-707 (-409 (-568)))) (-4 *3 (-842)) (-4 *4 (-172))))) 
-(-13 (-1263 |#1| |#2|) (-384 |#2| (-888 |#1|)) (-10 -8 (-15 -2745 ($ (-656 |#1| |#2|))) (-15 -2745 ((-1257 |#1| |#2|) $)) (-15 -2745 ((-1266 |#1| |#2|) $)) (-15 -2253 ((-3 (-656 |#1| |#2|) "failed") $)) (-15 -3272 ($ $ $ (-763))) (IF (|has| |#2| (-707 (-409 (-568)))) (PROGN (-15 -1892 ($ $ (-763))) (-15 -4416 ($ $ (-763)))) |noBranch|))) 
-((-2447 (((-121) $ $) 7)) (-2537 (((-121) $) 15)) (-3595 (((-634 |#1|) $) 39)) (-2821 (($ $ (-763)) 68)) (-3134 (((-3 $ "failed") $ $) 18)) (-2238 (($ $ $) 42 (|has| |#2| (-172))) (($ $ (-763)) 41 (|has| |#2| (-172)))) (-2671 (($) 16 T CONST)) (-2628 (($ $ |#1|) 53) (($ $ (-814 |#1|)) 52) (($ $ $) 51)) (-3666 (((-3 (-814 |#1|) "failed") $) 63)) (-2854 (((-814 |#1|) $) 62)) (-2925 (((-3 $ "failed") $) 33)) (-3363 (((-121) $) 44)) (-2207 (($ $) 43)) (-2735 (((-121) $) 30)) (-3921 (((-121) $) 49)) (-2354 (($ (-814 |#1|) |#2|) 50)) (-2407 (($ $) 48)) (-3169 (((-2 (|:| |k| (-814 |#1|)) (|:| |c| |#2|)) $) 59)) (-2018 (((-814 |#1|) $) 60)) (-1666 (((-814 |#1|) $) 70)) (-2795 (($ (-1 |#2| |#2|) $) 40)) (-2532 (($ $ |#1|) 56) (($ $ (-814 |#1|)) 55) (($ $ $) 54)) (-4487 (((-1143) $) 9)) (-4022 (((-1108) $) 10)) (-3206 (((-763) $) 69)) (-1867 (((-121) $) 46)) (-3495 ((|#2| $) 45)) (-2745 (((-850) $) 11) (($ (-568)) 27) (($ |#2|) 67) (($ (-814 |#1|)) 64) (($ |#1|) 47)) (-2348 ((|#2| $ (-814 |#1|)) 58) ((|#2| $ $) 57)) (-4078 (((-763)) 28)) (-1887 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3056 (($) 17 T CONST)) (-1556 (($) 29 T CONST)) (-1717 (((-121) $ $) 6)) (-1773 (($ $) 21) (($ $ $) 20)) (-1767 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ |#2| $) 66) (($ $ |#2|) 65) (($ |#1| $) 61))) 
+((-1413 (*1 *2 *1) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-121)))) (-2134 (*1 *2 *1) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-121)))) (-4051 (*1 *2 *1) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-121)))) (-1836 (*1 *2 *1) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-828 (-917))))) (-4321 (*1 *2) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-828 (-917))))) (-3800 (*1 *2) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-763)))) (-3412 (*1 *1 *1) (-12 (-4 *1 (-1261 *2)) (-4 *2 (-365)) (-4 *2 (-370)))) (-3412 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-4 *3 (-370))))) 
+(-13 (-365) (-1037 |t#1|) (-1251 |t#1|) (-10 -8 (IF (|has| |t#1| (-150)) (-6 (-150)) |noBranch|) (IF (|has| |t#1| (-148)) (-6 (-404)) |noBranch|) (-15 -1413 ((-121) $)) (-15 -2134 ((-121) $)) (-15 -4051 ((-121) $)) (-15 -1836 ((-828 (-917)) $)) (-15 -4321 ((-828 (-917)))) (-15 -3800 ((-763))) (IF (|has| |t#1| (-370)) (PROGN (-6 (-404)) (-15 -3412 ($ $)) (-15 -3412 ($ $ (-763)))) |noBranch|))) 
+(((-21) . T) ((-23) . T) ((-25) . T) ((-43 (-409 (-568))) . T) ((-43 $) . T) ((-105) . T) ((-120 (-409 (-568)) (-409 (-568))) . T) ((-120 |#1| |#1|) . T) ((-120 $ $) . T) ((-137) . T) ((-148) -2199 (|has| |#1| (-370)) (|has| |#1| (-148))) ((-150) |has| |#1| (-150)) ((-608 (-850)) . T) ((-172) . T) ((-238) . T) ((-285) . T) ((-301) . T) ((-365) . T) ((-404) -2199 (|has| |#1| (-370)) (|has| |#1| (-148))) ((-453) . T) ((-558) . T) ((-637 (-409 (-568))) . T) ((-637 |#1|) . T) ((-637 $) . T) ((-707 (-409 (-568))) . T) ((-707 |#1|) . T) ((-707 $) . T) ((-716) . T) ((-916) . T) ((-1037 |#1|) . T) ((-1053 (-409 (-568))) . T) ((-1053 |#1|) . T) ((-1053 $) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1199) . T) ((-1251 |#1|) . T)) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2981 (((-634 |#1|) $) 84)) (-3784 (($ $ (-763)) 87)) (-2689 (((-3 $ "failed") $ $) NIL)) (-2726 (($ $ $) NIL (|has| |#2| (-172))) (($ $ (-763)) NIL (|has| |#2| (-172)))) (-4490 (($) NIL T CONST)) (-4242 (($ $ |#1|) NIL) (($ $ (-814 |#1|)) NIL) (($ $ $) NIL)) (-3668 (((-3 (-814 |#1|) "failed") $) NIL) (((-3 (-888 |#1|) "failed") $) NIL)) (-2857 (((-814 |#1|) $) NIL) (((-888 |#1|) $) NIL)) (-2116 (($ $) 86)) (-2902 (((-3 $ "failed") $) NIL)) (-1335 (((-121) $) 75)) (-3201 (($ $) 79)) (-2062 (($ $ $ (-763)) 88)) (-1598 (((-121) $) NIL)) (-3971 (((-763) $) NIL)) (-3062 (((-634 $) $) NIL)) (-2171 (((-121) $) NIL)) (-2356 (($ (-814 |#1|) |#2|) NIL) (($ (-888 |#1|) |#2|) 25)) (-2310 (($ $) 101)) (-1690 (((-2 (|:| |k| (-814 |#1|)) (|:| |c| |#2|)) $) NIL)) (-1341 (((-814 |#1|) $) NIL)) (-3421 (((-814 |#1|) $) NIL)) (-2797 (($ (-1 |#2| |#2|) $) NIL)) (-1797 (($ $ |#1|) NIL) (($ $ (-814 |#1|)) NIL) (($ $ $) NIL)) (-4418 (($ $ (-763)) 95 (|has| |#2| (-707 (-409 (-568)))))) (-3016 (((-634 (-2 (|:| |k| (-888 |#1|)) (|:| |c| |#2|))) $) NIL)) (-3749 (((-2 (|:| |k| (-888 |#1|)) (|:| |c| |#2|)) $) NIL)) (-2099 (((-888 |#1|) $) 69)) (-2104 ((|#2| $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-1894 (($ $ (-763)) 92 (|has| |#2| (-707 (-409 (-568)))))) (-1836 (((-763) $) 85)) (-2475 (((-121) $) 70)) (-3497 ((|#2| $) 74)) (-2747 (((-850) $) 56) (($ (-568)) NIL) (($ |#2|) 50) (($ (-814 |#1|)) NIL) (($ |#1|) 58) (($ (-888 |#1|)) NIL) (($ (-656 |#1| |#2|)) 42) (((-1257 |#1| |#2|) $) 63) (((-1266 |#1| |#2|) $) 68)) (-3304 (((-634 |#2|) $) NIL)) (-2079 ((|#2| $ (-888 |#1|)) NIL)) (-2350 ((|#2| $ (-814 |#1|)) NIL) ((|#2| $ $) NIL)) (-3425 (((-763)) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 21 T CONST)) (-1557 (($) 24 T CONST)) (-3288 (((-3 (-656 |#1| |#2|) "failed") $) 100)) (-1719 (((-121) $ $) 64)) (-1775 (($ $) 94) (($ $ $) 93)) (-1769 (($ $ $) 20)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 43) (($ |#2| $) 19) (($ $ |#2|) NIL) (($ |#1| $) NIL) (($ |#2| (-888 |#1|)) NIL))) 
+(((-1262 |#1| |#2|) (-13 (-1263 |#1| |#2|) (-384 |#2| (-888 |#1|)) (-10 -8 (-15 -2747 ($ (-656 |#1| |#2|))) (-15 -2747 ((-1257 |#1| |#2|) $)) (-15 -2747 ((-1266 |#1| |#2|) $)) (-15 -3288 ((-3 (-656 |#1| |#2|) "failed") $)) (-15 -2062 ($ $ $ (-763))) (IF (|has| |#2| (-707 (-409 (-568)))) (PROGN (-15 -1894 ($ $ (-763))) (-15 -4418 ($ $ (-763)))) |noBranch|))) (-842) (-172)) (T -1262)) 
+((-2747 (*1 *1 *2) (-12 (-5 *2 (-656 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *1 (-1262 *3 *4)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-1257 *3 *4)) (-5 *1 (-1262 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) (-2747 (*1 *2 *1) (-12 (-5 *2 (-1266 *3 *4)) (-5 *1 (-1262 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) (-3288 (*1 *2 *1) (|partial| -12 (-5 *2 (-656 *3 *4)) (-5 *1 (-1262 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) (-2062 (*1 *1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1262 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) (-1894 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1262 *3 *4)) (-4 *4 (-707 (-409 (-568)))) (-4 *3 (-842)) (-4 *4 (-172)))) (-4418 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1262 *3 *4)) (-4 *4 (-707 (-409 (-568)))) (-4 *3 (-842)) (-4 *4 (-172))))) 
+(-13 (-1263 |#1| |#2|) (-384 |#2| (-888 |#1|)) (-10 -8 (-15 -2747 ($ (-656 |#1| |#2|))) (-15 -2747 ((-1257 |#1| |#2|) $)) (-15 -2747 ((-1266 |#1| |#2|) $)) (-15 -3288 ((-3 (-656 |#1| |#2|) "failed") $)) (-15 -2062 ($ $ $ (-763))) (IF (|has| |#2| (-707 (-409 (-568)))) (PROGN (-15 -1894 ($ $ (-763))) (-15 -4418 ($ $ (-763)))) |noBranch|))) 
+((-2449 (((-121) $ $) 7)) (-1819 (((-121) $) 15)) (-2981 (((-634 |#1|) $) 39)) (-3784 (($ $ (-763)) 68)) (-2689 (((-3 $ "failed") $ $) 18)) (-2726 (($ $ $) 42 (|has| |#2| (-172))) (($ $ (-763)) 41 (|has| |#2| (-172)))) (-4490 (($) 16 T CONST)) (-4242 (($ $ |#1|) 53) (($ $ (-814 |#1|)) 52) (($ $ $) 51)) (-3668 (((-3 (-814 |#1|) "failed") $) 63)) (-2857 (((-814 |#1|) $) 62)) (-2902 (((-3 $ "failed") $) 33)) (-1335 (((-121) $) 44)) (-3201 (($ $) 43)) (-1598 (((-121) $) 30)) (-2171 (((-121) $) 49)) (-2356 (($ (-814 |#1|) |#2|) 50)) (-2310 (($ $) 48)) (-1690 (((-2 (|:| |k| (-814 |#1|)) (|:| |c| |#2|)) $) 59)) (-1341 (((-814 |#1|) $) 60)) (-3421 (((-814 |#1|) $) 70)) (-2797 (($ (-1 |#2| |#2|) $) 40)) (-1797 (($ $ |#1|) 56) (($ $ (-814 |#1|)) 55) (($ $ $) 54)) (-1893 (((-1143) $) 9)) (-4025 (((-1108) $) 10)) (-1836 (((-763) $) 69)) (-2475 (((-121) $) 46)) (-3497 ((|#2| $) 45)) (-2747 (((-850) $) 11) (($ (-568)) 27) (($ |#2|) 67) (($ (-814 |#1|)) 64) (($ |#1|) 47)) (-2350 ((|#2| $ (-814 |#1|)) 58) ((|#2| $ $) 57)) (-3425 (((-763)) 28)) (-1889 (($ $ (-917)) 25) (($ $ (-763)) 32)) (-3058 (($) 17 T CONST)) (-1557 (($) 29 T CONST)) (-1719 (((-121) $ $) 6)) (-1775 (($ $) 21) (($ $ $) 20)) (-1769 (($ $ $) 13)) (** (($ $ (-917)) 24) (($ $ (-763)) 31)) (* (($ (-917) $) 12) (($ (-763) $) 14) (($ (-568) $) 19) (($ $ $) 23) (($ |#2| $) 66) (($ $ |#2|) 65) (($ |#1| $) 61))) 
 (((-1263 |#1| |#2|) (-1275) (-842) (-1047)) (T -1263)) 
-((-1666 (*1 *2 *1) (-12 (-4 *1 (-1263 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-814 *3)))) (-3206 (*1 *2 *1) (-12 (-4 *1 (-1263 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-763)))) (-2821 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1263 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047))))) 
-(-13 (-1259 |t#1| |t#2|) (-10 -8 (-15 -1666 ((-814 |t#1|) $)) (-15 -3206 ((-763) $)) (-15 -2821 ($ $ (-763))))) 
+((-3421 (*1 *2 *1) (-12 (-4 *1 (-1263 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-814 *3)))) (-1836 (*1 *2 *1) (-12 (-4 *1 (-1263 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-763)))) (-3784 (*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1263 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047))))) 
+(-13 (-1259 |t#1| |t#2|) (-10 -8 (-15 -3421 ((-814 |t#1|) $)) (-15 -1836 ((-763) $)) (-15 -3784 ($ $ (-763))))) 
 (((-21) . T) ((-23) . T) ((-25) . T) ((-43 |#2|) |has| |#2| (-172)) ((-105) . T) ((-120 |#2| |#2|) . T) ((-137) . T) ((-608 (-850)) . T) ((-637 |#2|) . T) ((-637 $) . T) ((-707 |#2|) |has| |#2| (-172)) ((-716) . T) ((-1037 (-814 |#1|)) . T) ((-1053 |#2|) . T) ((-1047) . T) ((-1054) . T) ((-1102) . T) ((-1090) . T) ((-1256 |#2|) . T) ((-1259 |#1| |#2|) . T)) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3595 (((-634 (-1161)) $) NIL)) (-2703 (($ (-1257 (-1161) |#1|)) NIL)) (-2821 (($ $ (-763)) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2238 (($ $ $) NIL (|has| |#1| (-172))) (($ $ (-763)) NIL (|has| |#1| (-172)))) (-2671 (($) NIL T CONST)) (-2628 (($ $ (-1161)) NIL) (($ $ (-814 (-1161))) NIL) (($ $ $) NIL)) (-3666 (((-3 (-814 (-1161)) "failed") $) NIL)) (-2854 (((-814 (-1161)) $) NIL)) (-2925 (((-3 $ "failed") $) NIL)) (-3363 (((-121) $) NIL)) (-2207 (($ $) NIL)) (-2735 (((-121) $) NIL)) (-3921 (((-121) $) NIL)) (-2354 (($ (-814 (-1161)) |#1|) NIL)) (-2407 (($ $) NIL)) (-3169 (((-2 (|:| |k| (-814 (-1161))) (|:| |c| |#1|)) $) NIL)) (-2018 (((-814 (-1161)) $) NIL)) (-1666 (((-814 (-1161)) $) NIL)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-2532 (($ $ (-1161)) NIL) (($ $ (-814 (-1161))) NIL) (($ $ $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2789 (((-1257 (-1161) |#1|) $) NIL)) (-3206 (((-763) $) NIL)) (-1867 (((-121) $) NIL)) (-3495 ((|#1| $) NIL)) (-2745 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL) (($ (-814 (-1161))) NIL) (($ (-1161)) NIL)) (-2348 ((|#1| $ (-814 (-1161))) NIL) ((|#1| $ $) NIL)) (-4078 (((-763)) NIL)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) NIL T CONST)) (-3788 (((-634 (-2 (|:| |k| (-1161)) (|:| |c| $))) $) NIL)) (-1556 (($) NIL T CONST)) (-1717 (((-121) $ $) NIL)) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ (-1161) $) NIL))) 
-(((-1264 |#1|) (-13 (-1263 (-1161) |#1|) (-10 -8 (-15 -2789 ((-1257 (-1161) |#1|) $)) (-15 -2703 ($ (-1257 (-1161) |#1|))) (-15 -3788 ((-634 (-2 (|:| |k| (-1161)) (|:| |c| $))) $)))) (-1047)) (T -1264)) 
-((-2789 (*1 *2 *1) (-12 (-5 *2 (-1257 (-1161) *3)) (-5 *1 (-1264 *3)) (-4 *3 (-1047)))) (-2703 (*1 *1 *2) (-12 (-5 *2 (-1257 (-1161) *3)) (-4 *3 (-1047)) (-5 *1 (-1264 *3)))) (-3788 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |k| (-1161)) (|:| |c| (-1264 *3))))) (-5 *1 (-1264 *3)) (-4 *3 (-1047))))) 
-(-13 (-1263 (-1161) |#1|) (-10 -8 (-15 -2789 ((-1257 (-1161) |#1|) $)) (-15 -2703 ($ (-1257 (-1161) |#1|))) (-15 -3788 ((-634 (-2 (|:| |k| (-1161)) (|:| |c| $))) $)))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2671 (($) NIL T CONST)) (-3666 (((-3 |#2| "failed") $) NIL)) (-2854 ((|#2| $) NIL)) (-2114 (($ $) NIL)) (-2925 (((-3 $ "failed") $) 34)) (-3363 (((-121) $) 29)) (-2207 (($ $) 30)) (-2735 (((-121) $) NIL)) (-4178 (((-763) $) NIL)) (-2976 (((-634 $) $) NIL)) (-3921 (((-121) $) NIL)) (-2354 (($ |#2| |#1|) NIL)) (-2018 ((|#2| $) 19)) (-1666 ((|#2| $) 16)) (-2795 (($ (-1 |#1| |#1|) $) NIL)) (-4297 (((-634 (-2 (|:| |k| |#2|) (|:| |c| |#1|))) $) NIL)) (-2315 (((-2 (|:| |k| |#2|) (|:| |c| |#1|)) $) NIL)) (-2097 ((|#2| $) NIL)) (-2102 ((|#1| $) NIL)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-1867 (((-121) $) 27)) (-3495 ((|#1| $) 28)) (-2745 (((-850) $) 53) (($ (-568)) 38) (($ |#1|) 33) (($ |#2|) NIL)) (-1302 (((-634 |#1|) $) NIL)) (-2604 ((|#1| $ |#2|) NIL)) (-2348 ((|#1| $ |#2|) 24)) (-4078 (((-763)) 14)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 25 T CONST)) (-1556 (($) 11 T CONST)) (-1717 (((-121) $ $) 26)) (-1779 (($ $ |#1|) 55 (|has| |#1| (-365)))) (-1773 (($ $) NIL) (($ $ $) NIL)) (-1767 (($ $ $) 42)) (** (($ $ (-917)) NIL) (($ $ (-763)) 44)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 43) (($ |#1| $) 39) (($ $ |#1|) NIL) (($ |#1| |#2|) NIL)) (-1697 (((-763) $) 15))) 
-(((-1265 |#1| |#2|) (-13 (-1047) (-1256 |#1|) (-384 |#1| |#2|) (-10 -8 (-15 * ($ $ |#1|)) (-15 -1697 ((-763) $)) (-15 -2745 ($ |#2|)) (-15 -1666 (|#2| $)) (-15 -2018 (|#2| $)) (-15 -2114 ($ $)) (-15 -2348 (|#1| $ |#2|)) (-15 -1867 ((-121) $)) (-15 -3495 (|#1| $)) (-15 -3363 ((-121) $)) (-15 -2207 ($ $)) (-15 -2795 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-365)) (-15 -1779 ($ $ |#1|)) |noBranch|) (IF (|has| |#1| (-6 -4512)) (-6 -4512) |noBranch|) (IF (|has| |#1| (-6 -4516)) (-6 -4516) |noBranch|) (IF (|has| |#1| (-6 -4517)) (-6 -4517) |noBranch|))) (-1047) (-838)) (T -1265)) 
-((* (*1 *1 *1 *2) (-12 (-5 *1 (-1265 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-838)))) (-2114 (*1 *1 *1) (-12 (-5 *1 (-1265 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-838)))) (-2795 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-1265 *3 *4)) (-4 *4 (-838)))) (-2745 (*1 *1 *2) (-12 (-5 *1 (-1265 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-838)))) (-1697 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1265 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-838)))) (-1666 (*1 *2 *1) (-12 (-4 *2 (-838)) (-5 *1 (-1265 *3 *2)) (-4 *3 (-1047)))) (-2018 (*1 *2 *1) (-12 (-4 *2 (-838)) (-5 *1 (-1265 *3 *2)) (-4 *3 (-1047)))) (-2348 (*1 *2 *1 *3) (-12 (-4 *2 (-1047)) (-5 *1 (-1265 *2 *3)) (-4 *3 (-838)))) (-1867 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1265 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-838)))) (-3495 (*1 *2 *1) (-12 (-4 *2 (-1047)) (-5 *1 (-1265 *2 *3)) (-4 *3 (-838)))) (-3363 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1265 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-838)))) (-2207 (*1 *1 *1) (-12 (-5 *1 (-1265 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-838)))) (-1779 (*1 *1 *1 *2) (-12 (-5 *1 (-1265 *2 *3)) (-4 *2 (-365)) (-4 *2 (-1047)) (-4 *3 (-838))))) 
-(-13 (-1047) (-1256 |#1|) (-384 |#1| |#2|) (-10 -8 (-15 * ($ $ |#1|)) (-15 -1697 ((-763) $)) (-15 -2745 ($ |#2|)) (-15 -1666 (|#2| $)) (-15 -2018 (|#2| $)) (-15 -2114 ($ $)) (-15 -2348 (|#1| $ |#2|)) (-15 -1867 ((-121) $)) (-15 -3495 (|#1| $)) (-15 -3363 ((-121) $)) (-15 -2207 ($ $)) (-15 -2795 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-365)) (-15 -1779 ($ $ |#1|)) |noBranch|) (IF (|has| |#1| (-6 -4512)) (-6 -4512) |noBranch|) (IF (|has| |#1| (-6 -4516)) (-6 -4516) |noBranch|) (IF (|has| |#1| (-6 -4517)) (-6 -4517) |noBranch|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) NIL)) (-3595 (((-634 |#1|) $) 119)) (-2703 (($ (-1257 |#1| |#2|)) 43)) (-2821 (($ $ (-763)) 31)) (-3134 (((-3 $ "failed") $ $) NIL)) (-2238 (($ $ $) 47 (|has| |#2| (-172))) (($ $ (-763)) 45 (|has| |#2| (-172)))) (-2671 (($) NIL T CONST)) (-2628 (($ $ |#1|) 101) (($ $ (-814 |#1|)) 102) (($ $ $) 25)) (-3666 (((-3 (-814 |#1|) "failed") $) NIL)) (-2854 (((-814 |#1|) $) NIL)) (-2925 (((-3 $ "failed") $) 109)) (-3363 (((-121) $) 104)) (-2207 (($ $) 105)) (-2735 (((-121) $) NIL)) (-3921 (((-121) $) NIL)) (-2354 (($ (-814 |#1|) |#2|) 19)) (-2407 (($ $) NIL)) (-3169 (((-2 (|:| |k| (-814 |#1|)) (|:| |c| |#2|)) $) NIL)) (-2018 (((-814 |#1|) $) 110)) (-1666 (((-814 |#1|) $) 113)) (-2795 (($ (-1 |#2| |#2|) $) 118)) (-2532 (($ $ |#1|) 99) (($ $ (-814 |#1|)) 100) (($ $ $) 55)) (-4487 (((-1143) $) NIL)) (-4022 (((-1108) $) NIL)) (-2789 (((-1257 |#1| |#2|) $) 83)) (-3206 (((-763) $) 116)) (-1867 (((-121) $) 69)) (-3495 ((|#2| $) 27)) (-2745 (((-850) $) 62) (($ (-568)) 76) (($ |#2|) 73) (($ (-814 |#1|)) 17) (($ |#1|) 72)) (-2348 ((|#2| $ (-814 |#1|)) 103) ((|#2| $ $) 26)) (-4078 (((-763)) 107)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 14 T CONST)) (-3788 (((-634 (-2 (|:| |k| |#1|) (|:| |c| $))) $) 52)) (-1556 (($) 28 T CONST)) (-1717 (((-121) $ $) 13)) (-1773 (($ $) 87) (($ $ $) 90)) (-1767 (($ $ $) 54)) (** (($ $ (-917)) NIL) (($ $ (-763)) 48)) (* (($ (-917) $) NIL) (($ (-763) $) 46) (($ (-568) $) 93) (($ $ $) 21) (($ |#2| $) 18) (($ $ |#2|) 20) (($ |#1| $) 81))) 
-(((-1266 |#1| |#2|) (-13 (-1263 |#1| |#2|) (-10 -8 (-15 -2789 ((-1257 |#1| |#2|) $)) (-15 -2703 ($ (-1257 |#1| |#2|))) (-15 -3788 ((-634 (-2 (|:| |k| |#1|) (|:| |c| $))) $)))) (-842) (-1047)) (T -1266)) 
-((-2789 (*1 *2 *1) (-12 (-5 *2 (-1257 *3 *4)) (-5 *1 (-1266 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)))) (-2703 (*1 *1 *2) (-12 (-5 *2 (-1257 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *1 (-1266 *3 *4)))) (-3788 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |k| *3) (|:| |c| (-1266 *3 *4))))) (-5 *1 (-1266 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047))))) 
-(-13 (-1263 |#1| |#2|) (-10 -8 (-15 -2789 ((-1257 |#1| |#2|) $)) (-15 -2703 ($ (-1257 |#1| |#2|))) (-15 -3788 ((-634 (-2 (|:| |k| |#1|) (|:| |c| $))) $)))) 
-((-2926 (((-634 (-1141 |#1|)) (-1 (-634 (-1141 |#1|)) (-634 (-1141 |#1|))) (-568)) 15) (((-1141 |#1|) (-1 (-1141 |#1|) (-1141 |#1|))) 11))) 
-(((-1267 |#1|) (-10 -7 (-15 -2926 ((-1141 |#1|) (-1 (-1141 |#1|) (-1141 |#1|)))) (-15 -2926 ((-634 (-1141 |#1|)) (-1 (-634 (-1141 |#1|)) (-634 (-1141 |#1|))) (-568)))) (-1195)) (T -1267)) 
-((-2926 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-634 (-1141 *5)) (-634 (-1141 *5)))) (-5 *4 (-568)) (-5 *2 (-634 (-1141 *5))) (-5 *1 (-1267 *5)) (-4 *5 (-1195)))) (-2926 (*1 *2 *3) (-12 (-5 *3 (-1 (-1141 *4) (-1141 *4))) (-5 *2 (-1141 *4)) (-5 *1 (-1267 *4)) (-4 *4 (-1195))))) 
-(-10 -7 (-15 -2926 ((-1141 |#1|) (-1 (-1141 |#1|) (-1141 |#1|)))) (-15 -2926 ((-634 (-1141 |#1|)) (-1 (-634 (-1141 |#1|)) (-634 (-1141 |#1|))) (-568)))) 
-((-3328 (((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-634 (-953 |#1|))) 145) (((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121)) 144) (((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121) (-121)) 143) (((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121) (-121) (-121)) 142) (((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-1044 |#1| |#2|)) 127)) (-2009 (((-634 (-1044 |#1| |#2|)) (-634 (-953 |#1|))) 70) (((-634 (-1044 |#1| |#2|)) (-634 (-953 |#1|)) (-121)) 69) (((-634 (-1044 |#1| |#2|)) (-634 (-953 |#1|)) (-121) (-121)) 68)) (-1678 (((-634 (-1131 |#1| (-534 (-852 |#3|)) (-852 |#3|) (-775 |#1| (-852 |#3|)))) (-1044 |#1| |#2|)) 59)) (-3105 (((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|))) 112) (((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121)) 111) (((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121) (-121)) 110) (((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121) (-121) (-121)) 109) (((-634 (-634 (-1023 (-409 |#1|)))) (-1044 |#1| |#2|)) 104)) (-2040 (((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|))) 117) (((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121)) 116) (((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121) (-121)) 115) (((-634 (-634 (-1023 (-409 |#1|)))) (-1044 |#1| |#2|)) 114)) (-4278 (((-634 (-775 |#1| (-852 |#3|))) (-1131 |#1| (-534 (-852 |#3|)) (-852 |#3|) (-775 |#1| (-852 |#3|)))) 96) (((-1157 (-1023 (-409 |#1|))) (-1157 |#1|)) 87) (((-953 (-1023 (-409 |#1|))) (-775 |#1| (-852 |#3|))) 94) (((-953 (-1023 (-409 |#1|))) (-953 |#1|)) 92) (((-775 |#1| (-852 |#3|)) (-775 |#1| (-852 |#2|))) 32))) 
-(((-1268 |#1| |#2| |#3|) (-10 -7 (-15 -2009 ((-634 (-1044 |#1| |#2|)) (-634 (-953 |#1|)) (-121) (-121))) (-15 -2009 ((-634 (-1044 |#1| |#2|)) (-634 (-953 |#1|)) (-121))) (-15 -2009 ((-634 (-1044 |#1| |#2|)) (-634 (-953 |#1|)))) (-15 -3328 ((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-1044 |#1| |#2|))) (-15 -3328 ((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121) (-121) (-121))) (-15 -3328 ((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121) (-121))) (-15 -3328 ((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121))) (-15 -3328 ((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-634 (-953 |#1|)))) (-15 -3105 ((-634 (-634 (-1023 (-409 |#1|)))) (-1044 |#1| |#2|))) (-15 -3105 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121) (-121) (-121))) (-15 -3105 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121) (-121))) (-15 -3105 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121))) (-15 -3105 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)))) (-15 -2040 ((-634 (-634 (-1023 (-409 |#1|)))) (-1044 |#1| |#2|))) (-15 -2040 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121) (-121))) (-15 -2040 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121))) (-15 -2040 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)))) (-15 -1678 ((-634 (-1131 |#1| (-534 (-852 |#3|)) (-852 |#3|) (-775 |#1| (-852 |#3|)))) (-1044 |#1| |#2|))) (-15 -4278 ((-775 |#1| (-852 |#3|)) (-775 |#1| (-852 |#2|)))) (-15 -4278 ((-953 (-1023 (-409 |#1|))) (-953 |#1|))) (-15 -4278 ((-953 (-1023 (-409 |#1|))) (-775 |#1| (-852 |#3|)))) (-15 -4278 ((-1157 (-1023 (-409 |#1|))) (-1157 |#1|))) (-15 -4278 ((-634 (-775 |#1| (-852 |#3|))) (-1131 |#1| (-534 (-852 |#3|)) (-852 |#3|) (-775 |#1| (-852 |#3|)))))) (-13 (-840) (-301) (-150) (-1021)) (-634 (-1161)) (-634 (-1161))) (T -1268)) 
-((-4278 (*1 *2 *3) (-12 (-5 *3 (-1131 *4 (-534 (-852 *6)) (-852 *6) (-775 *4 (-852 *6)))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-775 *4 (-852 *6)))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))))) (-4278 (*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-1157 (-1023 (-409 *4)))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161))))) (-4278 (*1 *2 *3) (-12 (-5 *3 (-775 *4 (-852 *6))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *6 (-634 (-1161))) (-5 *2 (-953 (-1023 (-409 *4)))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))))) (-4278 (*1 *2 *3) (-12 (-5 *3 (-953 *4)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-953 (-1023 (-409 *4)))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161))))) (-4278 (*1 *2 *3) (-12 (-5 *3 (-775 *4 (-852 *5))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *5 (-634 (-1161))) (-5 *2 (-775 *4 (-852 *6))) (-5 *1 (-1268 *4 *5 *6)) (-14 *6 (-634 (-1161))))) (-1678 (*1 *2 *3) (-12 (-5 *3 (-1044 *4 *5)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *5 (-634 (-1161))) (-5 *2 (-634 (-1131 *4 (-534 (-852 *6)) (-852 *6) (-775 *4 (-852 *6))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *6 (-634 (-1161))))) (-2040 (*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *4))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161))))) (-2040 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *5))))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) (-2040 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *5))))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) (-2040 (*1 *2 *3) (-12 (-5 *3 (-1044 *4 *5)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *5 (-634 (-1161))) (-5 *2 (-634 (-634 (-1023 (-409 *4))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *6 (-634 (-1161))))) (-3105 (*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *4))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161))))) (-3105 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *5))))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) (-3105 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *5))))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) (-3105 (*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *5))))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) (-3105 (*1 *2 *3) (-12 (-5 *3 (-1044 *4 *5)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *5 (-634 (-1161))) (-5 *2 (-634 (-634 (-1023 (-409 *4))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *6 (-634 (-1161))))) (-3328 (*1 *2 *3) (-12 (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-2 (|:| -3471 (-1157 *4)) (|:| -4073 (-634 (-953 *4)))))) (-5 *1 (-1268 *4 *5 *6)) (-5 *3 (-634 (-953 *4))) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161))))) (-3328 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-2 (|:| -3471 (-1157 *5)) (|:| -4073 (-634 (-953 *5)))))) (-5 *1 (-1268 *5 *6 *7)) (-5 *3 (-634 (-953 *5))) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) (-3328 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-2 (|:| -3471 (-1157 *5)) (|:| -4073 (-634 (-953 *5)))))) (-5 *1 (-1268 *5 *6 *7)) (-5 *3 (-634 (-953 *5))) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) (-3328 (*1 *2 *3 *4 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-2 (|:| -3471 (-1157 *5)) (|:| -4073 (-634 (-953 *5)))))) (-5 *1 (-1268 *5 *6 *7)) (-5 *3 (-634 (-953 *5))) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) (-3328 (*1 *2 *3) (-12 (-5 *3 (-1044 *4 *5)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *5 (-634 (-1161))) (-5 *2 (-634 (-2 (|:| -3471 (-1157 *4)) (|:| -4073 (-634 (-953 *4)))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *6 (-634 (-1161))))) (-2009 (*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-1044 *4 *5))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161))))) (-2009 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-1044 *5 *6))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) (-2009 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-1044 *5 *6))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161)))))) 
-(-10 -7 (-15 -2009 ((-634 (-1044 |#1| |#2|)) (-634 (-953 |#1|)) (-121) (-121))) (-15 -2009 ((-634 (-1044 |#1| |#2|)) (-634 (-953 |#1|)) (-121))) (-15 -2009 ((-634 (-1044 |#1| |#2|)) (-634 (-953 |#1|)))) (-15 -3328 ((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-1044 |#1| |#2|))) (-15 -3328 ((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121) (-121) (-121))) (-15 -3328 ((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121) (-121))) (-15 -3328 ((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121))) (-15 -3328 ((-634 (-2 (|:| -3471 (-1157 |#1|)) (|:| -4073 (-634 (-953 |#1|))))) (-634 (-953 |#1|)))) (-15 -3105 ((-634 (-634 (-1023 (-409 |#1|)))) (-1044 |#1| |#2|))) (-15 -3105 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121) (-121) (-121))) (-15 -3105 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121) (-121))) (-15 -3105 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121))) (-15 -3105 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)))) (-15 -2040 ((-634 (-634 (-1023 (-409 |#1|)))) (-1044 |#1| |#2|))) (-15 -2040 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121) (-121))) (-15 -2040 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121))) (-15 -2040 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)))) (-15 -1678 ((-634 (-1131 |#1| (-534 (-852 |#3|)) (-852 |#3|) (-775 |#1| (-852 |#3|)))) (-1044 |#1| |#2|))) (-15 -4278 ((-775 |#1| (-852 |#3|)) (-775 |#1| (-852 |#2|)))) (-15 -4278 ((-953 (-1023 (-409 |#1|))) (-953 |#1|))) (-15 -4278 ((-953 (-1023 (-409 |#1|))) (-775 |#1| (-852 |#3|)))) (-15 -4278 ((-1157 (-1023 (-409 |#1|))) (-1157 |#1|))) (-15 -4278 ((-634 (-775 |#1| (-852 |#3|))) (-1131 |#1| (-534 (-852 |#3|)) (-852 |#3|) (-775 |#1| (-852 |#3|)))))) 
-((-3634 (((-3 (-1244 (-409 (-568))) "failed") (-1244 |#1|) |#1|) 17)) (-2970 (((-121) (-1244 |#1|)) 11)) (-4378 (((-3 (-1244 (-568)) "failed") (-1244 |#1|)) 14))) 
-(((-1269 |#1|) (-10 -7 (-15 -2970 ((-121) (-1244 |#1|))) (-15 -4378 ((-3 (-1244 (-568)) "failed") (-1244 |#1|))) (-15 -3634 ((-3 (-1244 (-409 (-568))) "failed") (-1244 |#1|) |#1|))) (-630 (-568))) (T -1269)) 
-((-3634 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1244 *4)) (-4 *4 (-630 (-568))) (-5 *2 (-1244 (-409 (-568)))) (-5 *1 (-1269 *4)))) (-4378 (*1 *2 *3) (|partial| -12 (-5 *3 (-1244 *4)) (-4 *4 (-630 (-568))) (-5 *2 (-1244 (-568))) (-5 *1 (-1269 *4)))) (-2970 (*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-630 (-568))) (-5 *2 (-121)) (-5 *1 (-1269 *4))))) 
-(-10 -7 (-15 -2970 ((-121) (-1244 |#1|))) (-15 -4378 ((-3 (-1244 (-568)) "failed") (-1244 |#1|))) (-15 -3634 ((-3 (-1244 (-409 (-568))) "failed") (-1244 |#1|) |#1|))) 
-((-2447 (((-121) $ $) NIL)) (-2537 (((-121) $) 11)) (-3134 (((-3 $ "failed") $ $) NIL)) (-3983 (((-763)) 8)) (-2671 (($) NIL T CONST)) (-2925 (((-3 $ "failed") $) 43)) (-1731 (($) 36)) (-2735 (((-121) $) NIL)) (-3038 (((-3 $ "failed") $) 29)) (-3683 (((-917) $) 15)) (-4487 (((-1143) $) NIL)) (-4434 (($) 25 T CONST)) (-4355 (($ (-917)) 37)) (-4022 (((-1108) $) NIL)) (-4278 (((-568) $) 13)) (-2745 (((-850) $) 22) (($ (-568)) 19)) (-4078 (((-763)) 9)) (-1887 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3056 (($) 23 T CONST)) (-1556 (($) 24 T CONST)) (-1717 (((-121) $ $) 27)) (-1773 (($ $) 38) (($ $ $) 35)) (-1767 (($ $ $) 26)) (** (($ $ (-917)) NIL) (($ $ (-763)) 40)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 32) (($ $ $) 31))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2981 (((-634 (-1161)) $) NIL)) (-1437 (($ (-1257 (-1161) |#1|)) NIL)) (-3784 (($ $ (-763)) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-2726 (($ $ $) NIL (|has| |#1| (-172))) (($ $ (-763)) NIL (|has| |#1| (-172)))) (-4490 (($) NIL T CONST)) (-4242 (($ $ (-1161)) NIL) (($ $ (-814 (-1161))) NIL) (($ $ $) NIL)) (-3668 (((-3 (-814 (-1161)) "failed") $) NIL)) (-2857 (((-814 (-1161)) $) NIL)) (-2902 (((-3 $ "failed") $) NIL)) (-1335 (((-121) $) NIL)) (-3201 (($ $) NIL)) (-1598 (((-121) $) NIL)) (-2171 (((-121) $) NIL)) (-2356 (($ (-814 (-1161)) |#1|) NIL)) (-2310 (($ $) NIL)) (-1690 (((-2 (|:| |k| (-814 (-1161))) (|:| |c| |#1|)) $) NIL)) (-1341 (((-814 (-1161)) $) NIL)) (-3421 (((-814 (-1161)) $) NIL)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-1797 (($ $ (-1161)) NIL) (($ $ (-814 (-1161))) NIL) (($ $ $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2791 (((-1257 (-1161) |#1|) $) NIL)) (-1836 (((-763) $) NIL)) (-2475 (((-121) $) NIL)) (-3497 ((|#1| $) NIL)) (-2747 (((-850) $) NIL) (($ (-568)) NIL) (($ |#1|) NIL) (($ (-814 (-1161))) NIL) (($ (-1161)) NIL)) (-2350 ((|#1| $ (-814 (-1161))) NIL) ((|#1| $ $) NIL)) (-3425 (((-763)) NIL)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) NIL T CONST)) (-2759 (((-634 (-2 (|:| |k| (-1161)) (|:| |c| $))) $) NIL)) (-1557 (($) NIL T CONST)) (-1719 (((-121) $ $) NIL)) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) NIL)) (** (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) NIL) (($ |#1| $) NIL) (($ $ |#1|) NIL) (($ (-1161) $) NIL))) 
+(((-1264 |#1|) (-13 (-1263 (-1161) |#1|) (-10 -8 (-15 -2791 ((-1257 (-1161) |#1|) $)) (-15 -1437 ($ (-1257 (-1161) |#1|))) (-15 -2759 ((-634 (-2 (|:| |k| (-1161)) (|:| |c| $))) $)))) (-1047)) (T -1264)) 
+((-2791 (*1 *2 *1) (-12 (-5 *2 (-1257 (-1161) *3)) (-5 *1 (-1264 *3)) (-4 *3 (-1047)))) (-1437 (*1 *1 *2) (-12 (-5 *2 (-1257 (-1161) *3)) (-4 *3 (-1047)) (-5 *1 (-1264 *3)))) (-2759 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |k| (-1161)) (|:| |c| (-1264 *3))))) (-5 *1 (-1264 *3)) (-4 *3 (-1047))))) 
+(-13 (-1263 (-1161) |#1|) (-10 -8 (-15 -2791 ((-1257 (-1161) |#1|) $)) (-15 -1437 ($ (-1257 (-1161) |#1|))) (-15 -2759 ((-634 (-2 (|:| |k| (-1161)) (|:| |c| $))) $)))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2689 (((-3 $ "failed") $ $) NIL)) (-4490 (($) NIL T CONST)) (-3668 (((-3 |#2| "failed") $) NIL)) (-2857 ((|#2| $) NIL)) (-2116 (($ $) NIL)) (-2902 (((-3 $ "failed") $) 34)) (-1335 (((-121) $) 29)) (-3201 (($ $) 30)) (-1598 (((-121) $) NIL)) (-3971 (((-763) $) NIL)) (-3062 (((-634 $) $) NIL)) (-2171 (((-121) $) NIL)) (-2356 (($ |#2| |#1|) NIL)) (-1341 ((|#2| $) 19)) (-3421 ((|#2| $) 16)) (-2797 (($ (-1 |#1| |#1|) $) NIL)) (-3016 (((-634 (-2 (|:| |k| |#2|) (|:| |c| |#1|))) $) NIL)) (-3749 (((-2 (|:| |k| |#2|) (|:| |c| |#1|)) $) NIL)) (-2099 ((|#2| $) NIL)) (-2104 ((|#1| $) NIL)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2475 (((-121) $) 27)) (-3497 ((|#1| $) 28)) (-2747 (((-850) $) 53) (($ (-568)) 38) (($ |#1|) 33) (($ |#2|) NIL)) (-3304 (((-634 |#1|) $) NIL)) (-2079 ((|#1| $ |#2|) NIL)) (-2350 ((|#1| $ |#2|) 24)) (-3425 (((-763)) 14)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 25 T CONST)) (-1557 (($) 11 T CONST)) (-1719 (((-121) $ $) 26)) (-1781 (($ $ |#1|) 55 (|has| |#1| (-365)))) (-1775 (($ $) NIL) (($ $ $) NIL)) (-1769 (($ $ $) 42)) (** (($ $ (-917)) NIL) (($ $ (-763)) 44)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) NIL) (($ $ $) 43) (($ |#1| $) 39) (($ $ |#1|) NIL) (($ |#1| |#2|) NIL)) (-1699 (((-763) $) 15))) 
+(((-1265 |#1| |#2|) (-13 (-1047) (-1256 |#1|) (-384 |#1| |#2|) (-10 -8 (-15 * ($ $ |#1|)) (-15 -1699 ((-763) $)) (-15 -2747 ($ |#2|)) (-15 -3421 (|#2| $)) (-15 -1341 (|#2| $)) (-15 -2116 ($ $)) (-15 -2350 (|#1| $ |#2|)) (-15 -2475 ((-121) $)) (-15 -3497 (|#1| $)) (-15 -1335 ((-121) $)) (-15 -3201 ($ $)) (-15 -2797 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-365)) (-15 -1781 ($ $ |#1|)) |noBranch|) (IF (|has| |#1| (-6 -4514)) (-6 -4514) |noBranch|) (IF (|has| |#1| (-6 -4518)) (-6 -4518) |noBranch|) (IF (|has| |#1| (-6 -4519)) (-6 -4519) |noBranch|))) (-1047) (-838)) (T -1265)) 
+((* (*1 *1 *1 *2) (-12 (-5 *1 (-1265 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-838)))) (-2116 (*1 *1 *1) (-12 (-5 *1 (-1265 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-838)))) (-2797 (*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-1265 *3 *4)) (-4 *4 (-838)))) (-2747 (*1 *1 *2) (-12 (-5 *1 (-1265 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-838)))) (-1699 (*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1265 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-838)))) (-3421 (*1 *2 *1) (-12 (-4 *2 (-838)) (-5 *1 (-1265 *3 *2)) (-4 *3 (-1047)))) (-1341 (*1 *2 *1) (-12 (-4 *2 (-838)) (-5 *1 (-1265 *3 *2)) (-4 *3 (-1047)))) (-2350 (*1 *2 *1 *3) (-12 (-4 *2 (-1047)) (-5 *1 (-1265 *2 *3)) (-4 *3 (-838)))) (-2475 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1265 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-838)))) (-3497 (*1 *2 *1) (-12 (-4 *2 (-1047)) (-5 *1 (-1265 *2 *3)) (-4 *3 (-838)))) (-1335 (*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1265 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-838)))) (-3201 (*1 *1 *1) (-12 (-5 *1 (-1265 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-838)))) (-1781 (*1 *1 *1 *2) (-12 (-5 *1 (-1265 *2 *3)) (-4 *2 (-365)) (-4 *2 (-1047)) (-4 *3 (-838))))) 
+(-13 (-1047) (-1256 |#1|) (-384 |#1| |#2|) (-10 -8 (-15 * ($ $ |#1|)) (-15 -1699 ((-763) $)) (-15 -2747 ($ |#2|)) (-15 -3421 (|#2| $)) (-15 -1341 (|#2| $)) (-15 -2116 ($ $)) (-15 -2350 (|#1| $ |#2|)) (-15 -2475 ((-121) $)) (-15 -3497 (|#1| $)) (-15 -1335 ((-121) $)) (-15 -3201 ($ $)) (-15 -2797 ($ (-1 |#1| |#1|) $)) (IF (|has| |#1| (-365)) (-15 -1781 ($ $ |#1|)) |noBranch|) (IF (|has| |#1| (-6 -4514)) (-6 -4514) |noBranch|) (IF (|has| |#1| (-6 -4518)) (-6 -4518) |noBranch|) (IF (|has| |#1| (-6 -4519)) (-6 -4519) |noBranch|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) NIL)) (-2981 (((-634 |#1|) $) 119)) (-1437 (($ (-1257 |#1| |#2|)) 43)) (-3784 (($ $ (-763)) 31)) (-2689 (((-3 $ "failed") $ $) NIL)) (-2726 (($ $ $) 47 (|has| |#2| (-172))) (($ $ (-763)) 45 (|has| |#2| (-172)))) (-4490 (($) NIL T CONST)) (-4242 (($ $ |#1|) 101) (($ $ (-814 |#1|)) 102) (($ $ $) 25)) (-3668 (((-3 (-814 |#1|) "failed") $) NIL)) (-2857 (((-814 |#1|) $) NIL)) (-2902 (((-3 $ "failed") $) 109)) (-1335 (((-121) $) 104)) (-3201 (($ $) 105)) (-1598 (((-121) $) NIL)) (-2171 (((-121) $) NIL)) (-2356 (($ (-814 |#1|) |#2|) 19)) (-2310 (($ $) NIL)) (-1690 (((-2 (|:| |k| (-814 |#1|)) (|:| |c| |#2|)) $) NIL)) (-1341 (((-814 |#1|) $) 110)) (-3421 (((-814 |#1|) $) 113)) (-2797 (($ (-1 |#2| |#2|) $) 118)) (-1797 (($ $ |#1|) 99) (($ $ (-814 |#1|)) 100) (($ $ $) 55)) (-1893 (((-1143) $) NIL)) (-4025 (((-1108) $) NIL)) (-2791 (((-1257 |#1| |#2|) $) 83)) (-1836 (((-763) $) 116)) (-2475 (((-121) $) 69)) (-3497 ((|#2| $) 27)) (-2747 (((-850) $) 62) (($ (-568)) 76) (($ |#2|) 73) (($ (-814 |#1|)) 17) (($ |#1|) 72)) (-2350 ((|#2| $ (-814 |#1|)) 103) ((|#2| $ $) 26)) (-3425 (((-763)) 107)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 14 T CONST)) (-2759 (((-634 (-2 (|:| |k| |#1|) (|:| |c| $))) $) 52)) (-1557 (($) 28 T CONST)) (-1719 (((-121) $ $) 13)) (-1775 (($ $) 87) (($ $ $) 90)) (-1769 (($ $ $) 54)) (** (($ $ (-917)) NIL) (($ $ (-763)) 48)) (* (($ (-917) $) NIL) (($ (-763) $) 46) (($ (-568) $) 93) (($ $ $) 21) (($ |#2| $) 18) (($ $ |#2|) 20) (($ |#1| $) 81))) 
+(((-1266 |#1| |#2|) (-13 (-1263 |#1| |#2|) (-10 -8 (-15 -2791 ((-1257 |#1| |#2|) $)) (-15 -1437 ($ (-1257 |#1| |#2|))) (-15 -2759 ((-634 (-2 (|:| |k| |#1|) (|:| |c| $))) $)))) (-842) (-1047)) (T -1266)) 
+((-2791 (*1 *2 *1) (-12 (-5 *2 (-1257 *3 *4)) (-5 *1 (-1266 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)))) (-1437 (*1 *1 *2) (-12 (-5 *2 (-1257 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *1 (-1266 *3 *4)))) (-2759 (*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |k| *3) (|:| |c| (-1266 *3 *4))))) (-5 *1 (-1266 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047))))) 
+(-13 (-1263 |#1| |#2|) (-10 -8 (-15 -2791 ((-1257 |#1| |#2|) $)) (-15 -1437 ($ (-1257 |#1| |#2|))) (-15 -2759 ((-634 (-2 (|:| |k| |#1|) (|:| |c| $))) $)))) 
+((-2928 (((-634 (-1141 |#1|)) (-1 (-634 (-1141 |#1|)) (-634 (-1141 |#1|))) (-568)) 15) (((-1141 |#1|) (-1 (-1141 |#1|) (-1141 |#1|))) 11))) 
+(((-1267 |#1|) (-10 -7 (-15 -2928 ((-1141 |#1|) (-1 (-1141 |#1|) (-1141 |#1|)))) (-15 -2928 ((-634 (-1141 |#1|)) (-1 (-634 (-1141 |#1|)) (-634 (-1141 |#1|))) (-568)))) (-1195)) (T -1267)) 
+((-2928 (*1 *2 *3 *4) (-12 (-5 *3 (-1 (-634 (-1141 *5)) (-634 (-1141 *5)))) (-5 *4 (-568)) (-5 *2 (-634 (-1141 *5))) (-5 *1 (-1267 *5)) (-4 *5 (-1195)))) (-2928 (*1 *2 *3) (-12 (-5 *3 (-1 (-1141 *4) (-1141 *4))) (-5 *2 (-1141 *4)) (-5 *1 (-1267 *4)) (-4 *4 (-1195))))) 
+(-10 -7 (-15 -2928 ((-1141 |#1|) (-1 (-1141 |#1|) (-1141 |#1|)))) (-15 -2928 ((-634 (-1141 |#1|)) (-1 (-634 (-1141 |#1|)) (-634 (-1141 |#1|))) (-568)))) 
+((-4385 (((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-634 (-953 |#1|))) 145) (((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121)) 144) (((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121) (-121)) 143) (((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121) (-121) (-121)) 142) (((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-1044 |#1| |#2|)) 127)) (-1299 (((-634 (-1044 |#1| |#2|)) (-634 (-953 |#1|))) 70) (((-634 (-1044 |#1| |#2|)) (-634 (-953 |#1|)) (-121)) 69) (((-634 (-1044 |#1| |#2|)) (-634 (-953 |#1|)) (-121) (-121)) 68)) (-3498 (((-634 (-1131 |#1| (-534 (-852 |#3|)) (-852 |#3|) (-775 |#1| (-852 |#3|)))) (-1044 |#1| |#2|)) 59)) (-2531 (((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|))) 112) (((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121)) 111) (((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121) (-121)) 110) (((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121) (-121) (-121)) 109) (((-634 (-634 (-1023 (-409 |#1|)))) (-1044 |#1| |#2|)) 104)) (-1473 (((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|))) 117) (((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121)) 116) (((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121) (-121)) 115) (((-634 (-634 (-1023 (-409 |#1|)))) (-1044 |#1| |#2|)) 114)) (-4280 (((-634 (-775 |#1| (-852 |#3|))) (-1131 |#1| (-534 (-852 |#3|)) (-852 |#3|) (-775 |#1| (-852 |#3|)))) 96) (((-1157 (-1023 (-409 |#1|))) (-1157 |#1|)) 87) (((-953 (-1023 (-409 |#1|))) (-775 |#1| (-852 |#3|))) 94) (((-953 (-1023 (-409 |#1|))) (-953 |#1|)) 92) (((-775 |#1| (-852 |#3|)) (-775 |#1| (-852 |#2|))) 32))) 
+(((-1268 |#1| |#2| |#3|) (-10 -7 (-15 -1299 ((-634 (-1044 |#1| |#2|)) (-634 (-953 |#1|)) (-121) (-121))) (-15 -1299 ((-634 (-1044 |#1| |#2|)) (-634 (-953 |#1|)) (-121))) (-15 -1299 ((-634 (-1044 |#1| |#2|)) (-634 (-953 |#1|)))) (-15 -4385 ((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-1044 |#1| |#2|))) (-15 -4385 ((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121) (-121) (-121))) (-15 -4385 ((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121) (-121))) (-15 -4385 ((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121))) (-15 -4385 ((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-634 (-953 |#1|)))) (-15 -2531 ((-634 (-634 (-1023 (-409 |#1|)))) (-1044 |#1| |#2|))) (-15 -2531 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121) (-121) (-121))) (-15 -2531 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121) (-121))) (-15 -2531 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121))) (-15 -2531 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)))) (-15 -1473 ((-634 (-634 (-1023 (-409 |#1|)))) (-1044 |#1| |#2|))) (-15 -1473 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121) (-121))) (-15 -1473 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121))) (-15 -1473 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)))) (-15 -3498 ((-634 (-1131 |#1| (-534 (-852 |#3|)) (-852 |#3|) (-775 |#1| (-852 |#3|)))) (-1044 |#1| |#2|))) (-15 -4280 ((-775 |#1| (-852 |#3|)) (-775 |#1| (-852 |#2|)))) (-15 -4280 ((-953 (-1023 (-409 |#1|))) (-953 |#1|))) (-15 -4280 ((-953 (-1023 (-409 |#1|))) (-775 |#1| (-852 |#3|)))) (-15 -4280 ((-1157 (-1023 (-409 |#1|))) (-1157 |#1|))) (-15 -4280 ((-634 (-775 |#1| (-852 |#3|))) (-1131 |#1| (-534 (-852 |#3|)) (-852 |#3|) (-775 |#1| (-852 |#3|)))))) (-13 (-840) (-301) (-150) (-1021)) (-634 (-1161)) (-634 (-1161))) (T -1268)) 
+((-4280 (*1 *2 *3) (-12 (-5 *3 (-1131 *4 (-534 (-852 *6)) (-852 *6) (-775 *4 (-852 *6)))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-775 *4 (-852 *6)))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))))) (-4280 (*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-1157 (-1023 (-409 *4)))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161))))) (-4280 (*1 *2 *3) (-12 (-5 *3 (-775 *4 (-852 *6))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *6 (-634 (-1161))) (-5 *2 (-953 (-1023 (-409 *4)))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))))) (-4280 (*1 *2 *3) (-12 (-5 *3 (-953 *4)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-953 (-1023 (-409 *4)))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161))))) (-4280 (*1 *2 *3) (-12 (-5 *3 (-775 *4 (-852 *5))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *5 (-634 (-1161))) (-5 *2 (-775 *4 (-852 *6))) (-5 *1 (-1268 *4 *5 *6)) (-14 *6 (-634 (-1161))))) (-3498 (*1 *2 *3) (-12 (-5 *3 (-1044 *4 *5)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *5 (-634 (-1161))) (-5 *2 (-634 (-1131 *4 (-534 (-852 *6)) (-852 *6) (-775 *4 (-852 *6))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *6 (-634 (-1161))))) (-1473 (*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *4))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161))))) (-1473 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *5))))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) (-1473 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *5))))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) (-1473 (*1 *2 *3) (-12 (-5 *3 (-1044 *4 *5)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *5 (-634 (-1161))) (-5 *2 (-634 (-634 (-1023 (-409 *4))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *6 (-634 (-1161))))) (-2531 (*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *4))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161))))) (-2531 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *5))))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) (-2531 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *5))))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) (-2531 (*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *5))))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) (-2531 (*1 *2 *3) (-12 (-5 *3 (-1044 *4 *5)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *5 (-634 (-1161))) (-5 *2 (-634 (-634 (-1023 (-409 *4))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *6 (-634 (-1161))))) (-4385 (*1 *2 *3) (-12 (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-2 (|:| -3722 (-1157 *4)) (|:| -1656 (-634 (-953 *4)))))) (-5 *1 (-1268 *4 *5 *6)) (-5 *3 (-634 (-953 *4))) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161))))) (-4385 (*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-2 (|:| -3722 (-1157 *5)) (|:| -1656 (-634 (-953 *5)))))) (-5 *1 (-1268 *5 *6 *7)) (-5 *3 (-634 (-953 *5))) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) (-4385 (*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-2 (|:| -3722 (-1157 *5)) (|:| -1656 (-634 (-953 *5)))))) (-5 *1 (-1268 *5 *6 *7)) (-5 *3 (-634 (-953 *5))) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) (-4385 (*1 *2 *3 *4 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-2 (|:| -3722 (-1157 *5)) (|:| -1656 (-634 (-953 *5)))))) (-5 *1 (-1268 *5 *6 *7)) (-5 *3 (-634 (-953 *5))) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) (-4385 (*1 *2 *3) (-12 (-5 *3 (-1044 *4 *5)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *5 (-634 (-1161))) (-5 *2 (-634 (-2 (|:| -3722 (-1157 *4)) (|:| -1656 (-634 (-953 *4)))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *6 (-634 (-1161))))) (-1299 (*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-1044 *4 *5))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161))))) (-1299 (*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-1044 *5 *6))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) (-1299 (*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-1044 *5 *6))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161)))))) 
+(-10 -7 (-15 -1299 ((-634 (-1044 |#1| |#2|)) (-634 (-953 |#1|)) (-121) (-121))) (-15 -1299 ((-634 (-1044 |#1| |#2|)) (-634 (-953 |#1|)) (-121))) (-15 -1299 ((-634 (-1044 |#1| |#2|)) (-634 (-953 |#1|)))) (-15 -4385 ((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-1044 |#1| |#2|))) (-15 -4385 ((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121) (-121) (-121))) (-15 -4385 ((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121) (-121))) (-15 -4385 ((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-634 (-953 |#1|)) (-121))) (-15 -4385 ((-634 (-2 (|:| -3722 (-1157 |#1|)) (|:| -1656 (-634 (-953 |#1|))))) (-634 (-953 |#1|)))) (-15 -2531 ((-634 (-634 (-1023 (-409 |#1|)))) (-1044 |#1| |#2|))) (-15 -2531 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121) (-121) (-121))) (-15 -2531 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121) (-121))) (-15 -2531 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121))) (-15 -2531 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)))) (-15 -1473 ((-634 (-634 (-1023 (-409 |#1|)))) (-1044 |#1| |#2|))) (-15 -1473 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121) (-121))) (-15 -1473 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)) (-121))) (-15 -1473 ((-634 (-634 (-1023 (-409 |#1|)))) (-634 (-953 |#1|)))) (-15 -3498 ((-634 (-1131 |#1| (-534 (-852 |#3|)) (-852 |#3|) (-775 |#1| (-852 |#3|)))) (-1044 |#1| |#2|))) (-15 -4280 ((-775 |#1| (-852 |#3|)) (-775 |#1| (-852 |#2|)))) (-15 -4280 ((-953 (-1023 (-409 |#1|))) (-953 |#1|))) (-15 -4280 ((-953 (-1023 (-409 |#1|))) (-775 |#1| (-852 |#3|)))) (-15 -4280 ((-1157 (-1023 (-409 |#1|))) (-1157 |#1|))) (-15 -4280 ((-634 (-775 |#1| (-852 |#3|))) (-1131 |#1| (-534 (-852 |#3|)) (-852 |#3|) (-775 |#1| (-852 |#3|)))))) 
+((-3151 (((-3 (-1244 (-409 (-568))) "failed") (-1244 |#1|) |#1|) 17)) (-3040 (((-121) (-1244 |#1|)) 11)) (-1342 (((-3 (-1244 (-568)) "failed") (-1244 |#1|)) 14))) 
+(((-1269 |#1|) (-10 -7 (-15 -3040 ((-121) (-1244 |#1|))) (-15 -1342 ((-3 (-1244 (-568)) "failed") (-1244 |#1|))) (-15 -3151 ((-3 (-1244 (-409 (-568))) "failed") (-1244 |#1|) |#1|))) (-630 (-568))) (T -1269)) 
+((-3151 (*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1244 *4)) (-4 *4 (-630 (-568))) (-5 *2 (-1244 (-409 (-568)))) (-5 *1 (-1269 *4)))) (-1342 (*1 *2 *3) (|partial| -12 (-5 *3 (-1244 *4)) (-4 *4 (-630 (-568))) (-5 *2 (-1244 (-568))) (-5 *1 (-1269 *4)))) (-3040 (*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-630 (-568))) (-5 *2 (-121)) (-5 *1 (-1269 *4))))) 
+(-10 -7 (-15 -3040 ((-121) (-1244 |#1|))) (-15 -1342 ((-3 (-1244 (-568)) "failed") (-1244 |#1|))) (-15 -3151 ((-3 (-1244 (-409 (-568))) "failed") (-1244 |#1|) |#1|))) 
+((-2449 (((-121) $ $) NIL)) (-1819 (((-121) $) 11)) (-2689 (((-3 $ "failed") $ $) NIL)) (-3986 (((-763)) 8)) (-4490 (($) NIL T CONST)) (-2902 (((-3 $ "failed") $) 43)) (-1733 (($) 36)) (-1598 (((-121) $) NIL)) (-2214 (((-3 $ "failed") $) 29)) (-2291 (((-917) $) 15)) (-1893 (((-1143) $) NIL)) (-4436 (($) 25 T CONST)) (-4357 (($ (-917)) 37)) (-4025 (((-1108) $) NIL)) (-4280 (((-568) $) 13)) (-2747 (((-850) $) 22) (($ (-568)) 19)) (-3425 (((-763)) 9)) (-1889 (($ $ (-917)) NIL) (($ $ (-763)) NIL)) (-3058 (($) 23 T CONST)) (-1557 (($) 24 T CONST)) (-1719 (((-121) $ $) 27)) (-1775 (($ $) 38) (($ $ $) 35)) (-1769 (($ $ $) 26)) (** (($ $ (-917)) NIL) (($ $ (-763)) 40)) (* (($ (-917) $) NIL) (($ (-763) $) NIL) (($ (-568) $) 32) (($ $ $) 31))) 
 (((-1270 |#1|) (-13 (-172) (-370) (-609 (-568)) (-1136)) (-917)) (T -1270)) 
 NIL 
 (-13 (-172) (-370) (-609 (-568)) (-1136)) 
@@ -5225,4 +5225,4 @@ NIL
 NIL 
 NIL 
 NIL 
-((-1275 3579006 3579011 3579016 "NIL" NIL T NIL (NIL) NIL NIL NIL) (-3 3578991 3578996 3579001 "NIL" NIL NIL NIL (NIL) -8 NIL NIL) (-2 3578976 3578981 3578986 "NIL" NIL NIL NIL (NIL) -8 NIL NIL) (-1 3578961 3578966 3578971 "NIL" NIL NIL NIL (NIL) -8 NIL NIL) (0 3578946 3578951 3578956 "NIL" NIL NIL NIL (NIL) -8 NIL NIL) (-1270 3578076 3578821 3578898 "ZMOD" 3578903 NIL ZMOD (NIL NIL) -8 NIL NIL) (-1269 3577186 3577350 3577559 "ZLINDEP" 3577908 NIL ZLINDEP (NIL T) -7 NIL NIL) (-1268 3566490 3568254 3570226 "ZDSOLVE" 3575316 NIL ZDSOLVE (NIL T NIL NIL) -7 NIL NIL) (-1267 3565736 3565877 3566066 "YSTREAM" 3566336 NIL YSTREAM (NIL T) -7 NIL NIL) (-1266 3563501 3565037 3565241 "XRPOLY" 3565579 NIL XRPOLY (NIL T T) -8 NIL NIL) (-1265 3559955 3561284 3561864 "XPR" 3562968 NIL XPR (NIL T T) -8 NIL NIL) (-1264 3557665 3559286 3559490 "XPOLY" 3559786 NIL XPOLY (NIL T) -8 NIL NIL) (-1263 3555469 3556847 3556903 "XPOLYC" 3557191 NIL XPOLYC (NIL T T) -9 NIL 3557304) (-1262 3551843 3553988 3554375 "XPBWPOLY" 3555128 NIL XPBWPOLY (NIL T T) -8 NIL NIL) (-1261 3547721 3550031 3550074 "XF" 3550695 NIL XF (NIL T) -9 NIL 3551092) (-1260 3547342 3547430 3547599 "XF-" 3547604 NIL XF- (NIL T T) -8 NIL NIL) (-1259 3542691 3543990 3544046 "XFALG" 3546218 NIL XFALG (NIL T T) -9 NIL 3547005) (-1258 3541824 3541928 3542133 "XEXPPKG" 3542583 NIL XEXPPKG (NIL T T T) -7 NIL NIL) (-1257 3539921 3541674 3541770 "XDPOLY" 3541775 NIL XDPOLY (NIL T T) -8 NIL NIL) (-1256 3538793 3539403 3539447 "XALG" 3539510 NIL XALG (NIL T) -9 NIL 3539629) (-1255 3532262 3536770 3537264 "WUTSET" 3538385 NIL WUTSET (NIL T T T T) -8 NIL NIL) (-1254 3530071 3530878 3531229 "WP" 3532045 NIL WP (NIL T T T T NIL NIL NIL) -8 NIL NIL) (-1253 3528957 3529155 3529450 "WFFINTBS" 3529868 NIL WFFINTBS (NIL T T T T) -7 NIL NIL) (-1252 3526861 3527288 3527750 "WEIER" 3528529 NIL WEIER (NIL T) -7 NIL NIL) (-1251 3526007 3526431 3526474 "VSPACE" 3526610 NIL VSPACE (NIL T) -9 NIL 3526684) (-1250 3525845 3525872 3525963 "VSPACE-" 3525968 NIL VSPACE- (NIL T T) -8 NIL NIL) (-1249 3525591 3525634 3525705 "VOID" 3525796 T VOID (NIL) -8 NIL NIL) (-1248 3523727 3524086 3524492 "VIEW" 3525207 T VIEW (NIL) -7 NIL NIL) (-1247 3520152 3520790 3521527 "VIEWDEF" 3523012 T VIEWDEF (NIL) -7 NIL NIL) (-1246 3509491 3511700 3513873 "VIEW3D" 3518001 T VIEW3D (NIL) -8 NIL NIL) (-1245 3501773 3503402 3504981 "VIEW2D" 3507934 T VIEW2D (NIL) -8 NIL NIL) (-1244 3497181 3501543 3501635 "VECTOR" 3501716 NIL VECTOR (NIL T) -8 NIL NIL) (-1243 3495758 3496017 3496335 "VECTOR2" 3496911 NIL VECTOR2 (NIL T T) -7 NIL NIL) (-1242 3489323 3493569 3493613 "VECTCAT" 3494608 NIL VECTCAT (NIL T) -9 NIL 3495188) (-1241 3488337 3488591 3488981 "VECTCAT-" 3488986 NIL VECTCAT- (NIL T T) -8 NIL NIL) (-1240 3487818 3487988 3488108 "VARIABLE" 3488252 NIL VARIABLE (NIL NIL) -8 NIL NIL) (-1239 3479860 3485651 3486129 "UTSZ" 3487388 NIL UTSZ (NIL T NIL) -8 NIL NIL) (-1238 3479466 3479516 3479650 "UTSSOL" 3479804 NIL UTSSOL (NIL T T T) -7 NIL NIL) (-1237 3478298 3478452 3478713 "UTSODETL" 3479293 NIL UTSODETL (NIL T T T T) -7 NIL NIL) (-1236 3475738 3476198 3476722 "UTSODE" 3477839 NIL UTSODE (NIL T T) -7 NIL NIL) (-1235 3467571 3473366 3473854 "UTS" 3475308 NIL UTS (NIL T NIL NIL) -8 NIL NIL) (-1234 3458857 3464217 3464261 "UTSCAT" 3465373 NIL UTSCAT (NIL T) -9 NIL 3466124) (-1233 3456212 3456927 3457916 "UTSCAT-" 3457921 NIL UTSCAT- (NIL T T) -8 NIL NIL) (-1232 3455839 3455882 3456015 "UTS2" 3456163 NIL UTS2 (NIL T T T T) -7 NIL NIL) (-1231 3450153 3452712 3452756 "URAGG" 3454826 NIL URAGG (NIL T) -9 NIL 3455548) (-1230 3447092 3447955 3449078 "URAGG-" 3449083 NIL URAGG- (NIL T T) -8 NIL NIL) (-1229 3442770 3445706 3446178 "UPXSSING" 3446756 NIL UPXSSING (NIL T T NIL NIL) -8 NIL NIL) (-1228 3434657 3441887 3442168 "UPXS" 3442547 NIL UPXS (NIL T NIL NIL) -8 NIL NIL) (-1227 3427685 3434561 3434633 "UPXSCONS" 3434638 NIL UPXSCONS (NIL T T) -8 NIL NIL) (-1226 3417897 3424722 3424785 "UPXSCCA" 3425441 NIL UPXSCCA (NIL T T) -9 NIL 3425683) (-1225 3417535 3417620 3417794 "UPXSCCA-" 3417799 NIL UPXSCCA- (NIL T T T) -8 NIL NIL) (-1224 3407679 3414277 3414321 "UPXSCAT" 3414969 NIL UPXSCAT (NIL T) -9 NIL 3415571) (-1223 3407109 3407188 3407367 "UPXS2" 3407594 NIL UPXS2 (NIL T T NIL NIL NIL NIL) -7 NIL NIL) (-1222 3405763 3406016 3406367 "UPSQFREE" 3406852 NIL UPSQFREE (NIL T T) -7 NIL NIL) (-1221 3399598 3402648 3402704 "UPSCAT" 3403865 NIL UPSCAT (NIL T T) -9 NIL 3404633) (-1220 3398802 3399009 3399336 "UPSCAT-" 3399341 NIL UPSCAT- (NIL T T T) -8 NIL NIL) (-1219 3384791 3392831 3392875 "UPOLYC" 3394976 NIL UPOLYC (NIL T) -9 NIL 3396191) (-1218 3376120 3378545 3381692 "UPOLYC-" 3381697 NIL UPOLYC- (NIL T T) -8 NIL NIL) (-1217 3375747 3375790 3375923 "UPOLYC2" 3376071 NIL UPOLYC2 (NIL T T T T) -7 NIL NIL) (-1216 3367158 3375313 3375451 "UP" 3375657 NIL UP (NIL NIL T) -8 NIL NIL) (-1215 3366497 3366604 3366768 "UPMP" 3367047 NIL UPMP (NIL T T) -7 NIL NIL) (-1214 3366050 3366131 3366270 "UPDIVP" 3366410 NIL UPDIVP (NIL T T) -7 NIL NIL) (-1213 3364618 3364867 3365183 "UPDECOMP" 3365799 NIL UPDECOMP (NIL T T) -7 NIL NIL) (-1212 3363853 3363965 3364150 "UPCDEN" 3364502 NIL UPCDEN (NIL T T T) -7 NIL NIL) (-1211 3363372 3363441 3363590 "UP2" 3363778 NIL UP2 (NIL NIL T NIL T) -7 NIL NIL) (-1210 3361893 3362580 3362855 "UNISEG" 3363132 NIL UNISEG (NIL T) -8 NIL NIL) (-1209 3361110 3361237 3361441 "UNISEG2" 3361737 NIL UNISEG2 (NIL T T) -7 NIL NIL) (-1208 3360170 3360350 3360576 "UNIFACT" 3360926 NIL UNIFACT (NIL T) -7 NIL NIL) (-1207 3344054 3359349 3359599 "ULS" 3359978 NIL ULS (NIL T NIL NIL) -8 NIL NIL) (-1206 3332009 3343958 3344030 "ULSCONS" 3344035 NIL ULSCONS (NIL T T) -8 NIL NIL) (-1205 3314676 3326693 3326756 "ULSCCAT" 3327476 NIL ULSCCAT (NIL T T) -9 NIL 3327772) (-1204 3313726 3313971 3314359 "ULSCCAT-" 3314364 NIL ULSCCAT- (NIL T T T) -8 NIL NIL) (-1203 3303662 3310174 3310218 "ULSCAT" 3311081 NIL ULSCAT (NIL T) -9 NIL 3311804) (-1202 3303092 3303171 3303350 "ULS2" 3303577 NIL ULS2 (NIL T T NIL NIL NIL NIL) -7 NIL NIL) (-1201 3295230 3301083 3301583 "UFPS" 3302627 NIL UFPS (NIL T) -8 NIL NIL) (-1200 3294927 3294984 3295082 "UFPS1" 3295167 NIL UFPS1 (NIL T) -7 NIL NIL) (-1199 3293320 3294287 3294318 "UFD" 3294530 T UFD (NIL) -9 NIL 3294644) (-1198 3293114 3293160 3293255 "UFD-" 3293260 NIL UFD- (NIL T) -8 NIL NIL) (-1197 3292196 3292379 3292595 "UDVO" 3292920 T UDVO (NIL) -7 NIL NIL) (-1196 3290014 3290423 3290893 "UDPO" 3291761 NIL UDPO (NIL T) -7 NIL NIL) (-1195 3289946 3289951 3289982 "TYPE" 3289987 T TYPE (NIL) -9 NIL NIL) (-1194 3288917 3289119 3289359 "TWOFACT" 3289740 NIL TWOFACT (NIL T) -7 NIL NIL) (-1193 3287989 3288320 3288519 "TUPLE" 3288753 NIL TUPLE (NIL T) -8 NIL NIL) (-1192 3285680 3286199 3286738 "TUBETOOL" 3287472 T TUBETOOL (NIL) -7 NIL NIL) (-1191 3284529 3284734 3284975 "TUBE" 3285473 NIL TUBE (NIL T) -8 NIL NIL) (-1190 3279249 3283503 3283785 "TS" 3284282 NIL TS (NIL T) -8 NIL NIL) (-1189 3267923 3272008 3272106 "TSETCAT" 3277375 NIL TSETCAT (NIL T T T T) -9 NIL 3278905) (-1188 3262658 3264255 3266146 "TSETCAT-" 3266151 NIL TSETCAT- (NIL T T T T T) -8 NIL NIL) (-1187 3256929 3257775 3258713 "TRMANIP" 3261798 NIL TRMANIP (NIL T T) -7 NIL NIL) (-1186 3256370 3256433 3256596 "TRIMAT" 3256861 NIL TRIMAT (NIL T T T T) -7 NIL NIL) (-1185 3254166 3254403 3254767 "TRIGMNIP" 3256119 NIL TRIGMNIP (NIL T T) -7 NIL NIL) (-1184 3253685 3253798 3253829 "TRIGCAT" 3254042 T TRIGCAT (NIL) -9 NIL NIL) (-1183 3253354 3253433 3253574 "TRIGCAT-" 3253579 NIL TRIGCAT- (NIL T) -8 NIL NIL) (-1182 3250257 3252212 3252493 "TREE" 3253108 NIL TREE (NIL T) -8 NIL NIL) (-1181 3249530 3250058 3250089 "TRANFUN" 3250124 T TRANFUN (NIL) -9 NIL 3250190) (-1180 3248809 3249000 3249280 "TRANFUN-" 3249285 NIL TRANFUN- (NIL T) -8 NIL NIL) (-1179 3248613 3248645 3248706 "TOPSP" 3248770 T TOPSP (NIL) -7 NIL NIL) (-1178 3247961 3248076 3248230 "TOOLSIGN" 3248494 NIL TOOLSIGN (NIL T) -7 NIL NIL) (-1177 3246596 3247138 3247377 "TEXTFILE" 3247744 T TEXTFILE (NIL) -8 NIL NIL) (-1176 3244461 3244975 3245413 "TEX" 3246180 T TEX (NIL) -8 NIL NIL) (-1175 3244242 3244273 3244345 "TEX1" 3244424 NIL TEX1 (NIL T) -7 NIL NIL) (-1174 3243890 3243953 3244043 "TEMUTL" 3244174 T TEMUTL (NIL) -7 NIL NIL) (-1173 3242044 3242324 3242649 "TBCMPPK" 3243613 NIL TBCMPPK (NIL T T) -7 NIL NIL) (-1172 3233789 3240049 3240106 "TBAGG" 3240506 NIL TBAGG (NIL T T) -9 NIL 3240717) (-1171 3228859 3230347 3232101 "TBAGG-" 3232106 NIL TBAGG- (NIL T T T) -8 NIL NIL) (-1170 3228243 3228350 3228495 "TANEXP" 3228748 NIL TANEXP (NIL T) -7 NIL NIL) (-1169 3221756 3228100 3228193 "TABLE" 3228198 NIL TABLE (NIL T T) -8 NIL NIL) (-1168 3221169 3221267 3221405 "TABLEAU" 3221653 NIL TABLEAU (NIL T) -8 NIL NIL) (-1167 3215777 3216997 3218245 "TABLBUMP" 3219955 NIL TABLBUMP (NIL T) -7 NIL NIL) (-1166 3212240 3212935 3213718 "SYSSOLP" 3215028 NIL SYSSOLP (NIL T) -7 NIL NIL) (-1165 3209374 3209982 3210620 "SYMTAB" 3211624 T SYMTAB (NIL) -8 NIL NIL) (-1164 3204623 3205525 3206508 "SYMS" 3208413 T SYMS (NIL) -8 NIL NIL) (-1163 3201855 3204087 3204314 "SYMPOLY" 3204431 NIL SYMPOLY (NIL T) -8 NIL NIL) (-1162 3201372 3201447 3201570 "SYMFUNC" 3201767 NIL SYMFUNC (NIL T) -7 NIL NIL) (-1161 3197350 3198609 3199431 "SYMBOL" 3200572 T SYMBOL (NIL) -8 NIL NIL) (-1160 3190889 3192578 3194298 "SWITCH" 3195652 T SWITCH (NIL) -8 NIL NIL) (-1159 3184115 3189712 3190014 "SUTS" 3190645 NIL SUTS (NIL T NIL NIL) -8 NIL NIL) (-1158 3176001 3183232 3183513 "SUPXS" 3183892 NIL SUPXS (NIL T NIL NIL) -8 NIL NIL) (-1157 3167486 3175619 3175745 "SUP" 3175910 NIL SUP (NIL T) -8 NIL NIL) (-1156 3166645 3166772 3166989 "SUPFRACF" 3167354 NIL SUPFRACF (NIL T T T T) -7 NIL NIL) (-1155 3157217 3166447 3166561 "SUPEXPR" 3166566 NIL SUPEXPR (NIL T) -8 NIL NIL) (-1154 3156838 3156897 3157010 "SUP2" 3157152 NIL SUP2 (NIL T T) -7 NIL NIL) (-1153 3155251 3155525 3155888 "SUMRF" 3156537 NIL SUMRF (NIL T) -7 NIL NIL) (-1152 3154565 3154631 3154830 "SUMFS" 3155172 NIL SUMFS (NIL T T) -7 NIL NIL) (-1151 3138489 3153744 3153994 "SULS" 3154373 NIL SULS (NIL T NIL NIL) -8 NIL NIL) (-1150 3137811 3138014 3138154 "SUCH" 3138397 NIL SUCH (NIL T T) -8 NIL NIL) (-1149 3131705 3132717 3133676 "SUBSPACE" 3136899 NIL SUBSPACE (NIL NIL T) -8 NIL NIL) (-1148 3131137 3131227 3131390 "SUBRESP" 3131594 NIL SUBRESP (NIL T T) -7 NIL NIL) (-1147 3124506 3125802 3127113 "STTF" 3129873 NIL STTF (NIL T) -7 NIL NIL) (-1146 3118679 3119799 3120946 "STTFNC" 3123406 NIL STTFNC (NIL T) -7 NIL NIL) (-1145 3109998 3111865 3113657 "STTAYLOR" 3116922 NIL STTAYLOR (NIL T) -7 NIL NIL) (-1144 3103254 3109862 3109945 "STRTBL" 3109950 NIL STRTBL (NIL T) -8 NIL NIL) (-1143 3098645 3103209 3103240 "STRING" 3103245 T STRING (NIL) -8 NIL NIL) (-1142 3093509 3097987 3098018 "STRICAT" 3098077 T STRICAT (NIL) -9 NIL 3098139) (-1141 3086236 3091036 3091654 "STREAM" 3092926 NIL STREAM (NIL T) -8 NIL NIL) (-1140 3085746 3085823 3085967 "STREAM3" 3086153 NIL STREAM3 (NIL T T T) -7 NIL NIL) (-1139 3084728 3084911 3085146 "STREAM2" 3085559 NIL STREAM2 (NIL T T) -7 NIL NIL) (-1138 3084416 3084468 3084561 "STREAM1" 3084670 NIL STREAM1 (NIL T) -7 NIL NIL) (-1137 3083432 3083613 3083844 "STINPROD" 3084232 NIL STINPROD (NIL T) -7 NIL NIL) (-1136 3083009 3083193 3083224 "STEP" 3083304 T STEP (NIL) -9 NIL 3083382) (-1135 3076564 3082908 3082985 "STBL" 3082990 NIL STBL (NIL T T NIL) -8 NIL NIL) (-1134 3071778 3075816 3075860 "STAGG" 3076013 NIL STAGG (NIL T) -9 NIL 3076102) (-1133 3069480 3070082 3070954 "STAGG-" 3070959 NIL STAGG- (NIL T T) -8 NIL NIL) (-1132 3062972 3064541 3065656 "STACK" 3068400 NIL STACK (NIL T) -8 NIL NIL) (-1131 3055697 3061113 3061569 "SREGSET" 3062602 NIL SREGSET (NIL T T T T) -8 NIL NIL) (-1130 3048123 3049491 3051004 "SRDCMPK" 3054303 NIL SRDCMPK (NIL T T T T T) -7 NIL NIL) (-1129 3041101 3045561 3045592 "SRAGG" 3046895 T SRAGG (NIL) -9 NIL 3047503) (-1128 3040118 3040373 3040752 "SRAGG-" 3040757 NIL SRAGG- (NIL T) -8 NIL NIL) (-1127 3034566 3039041 3039465 "SQMATRIX" 3039741 NIL SQMATRIX (NIL NIL T) -8 NIL NIL) (-1126 3028322 3031284 3032011 "SPLTREE" 3033911 NIL SPLTREE (NIL T T) -8 NIL NIL) (-1125 3024312 3024978 3025624 "SPLNODE" 3027748 NIL SPLNODE (NIL T T) -8 NIL NIL) (-1124 3023358 3023591 3023622 "SPFCAT" 3024066 T SPFCAT (NIL) -9 NIL NIL) (-1123 3022095 3022305 3022569 "SPECOUT" 3023116 T SPECOUT (NIL) -7 NIL NIL) (-1122 3014065 3015812 3015856 "SPACEC" 3020229 NIL SPACEC (NIL T) -9 NIL 3022045) (-1121 3012236 3013997 3014046 "SPACE3" 3014051 NIL SPACE3 (NIL T) -8 NIL NIL) (-1120 3010990 3011161 3011451 "SORTPAK" 3012042 NIL SORTPAK (NIL T T) -7 NIL NIL) (-1119 3009040 3009343 3009762 "SOLVETRA" 3010654 NIL SOLVETRA (NIL T) -7 NIL NIL) (-1118 3008051 3008273 3008547 "SOLVESER" 3008813 NIL SOLVESER (NIL T) -7 NIL NIL) (-1117 3003271 3004152 3005154 "SOLVERAD" 3007103 NIL SOLVERAD (NIL T) -7 NIL NIL) (-1116 2999086 2999695 3000424 "SOLVEFOR" 3002638 NIL SOLVEFOR (NIL T T) -7 NIL NIL) (-1115 2993389 2998434 2998532 "SNTSCAT" 2998537 NIL SNTSCAT (NIL T T T T) -9 NIL 2998607) (-1114 2987487 2991714 2992104 "SMTS" 2993080 NIL SMTS (NIL T T T) -8 NIL NIL) (-1113 2981891 2987375 2987452 "SMP" 2987457 NIL SMP (NIL T T) -8 NIL NIL) (-1112 2980050 2980351 2980749 "SMITH" 2981588 NIL SMITH (NIL T T T T) -7 NIL NIL) (-1111 2972992 2977190 2977294 "SMATCAT" 2978645 NIL SMATCAT (NIL NIL T T T) -9 NIL 2979192) (-1110 2969932 2970755 2971933 "SMATCAT-" 2971938 NIL SMATCAT- (NIL T NIL T T T) -8 NIL NIL) (-1109 2967685 2969202 2969246 "SKAGG" 2969507 NIL SKAGG (NIL T) -9 NIL 2969642) (-1108 2963743 2966789 2967067 "SINT" 2967429 T SINT (NIL) -8 NIL NIL) (-1107 2963515 2963553 2963619 "SIMPAN" 2963699 T SIMPAN (NIL) -7 NIL NIL) (-1106 2962353 2962574 2962849 "SIGNRF" 2963274 NIL SIGNRF (NIL T) -7 NIL NIL) (-1105 2961158 2961309 2961600 "SIGNEF" 2962182 NIL SIGNEF (NIL T T) -7 NIL NIL) (-1104 2958850 2959304 2959809 "SHP" 2960700 NIL SHP (NIL T NIL) -7 NIL NIL) (-1103 2952674 2958751 2958827 "SHDP" 2958832 NIL SHDP (NIL NIL NIL T) -8 NIL NIL) (-1102 2952162 2952354 2952385 "SGROUP" 2952537 T SGROUP (NIL) -9 NIL 2952624) (-1101 2951932 2951984 2952088 "SGROUP-" 2952093 NIL SGROUP- (NIL T) -8 NIL NIL) (-1100 2948768 2949465 2950188 "SGCF" 2951231 T SGCF (NIL) -7 NIL NIL) (-1099 2943169 2948214 2948312 "SFRTCAT" 2948317 NIL SFRTCAT (NIL T T T T) -9 NIL 2948356) (-1098 2936593 2937608 2938744 "SFRGCD" 2942152 NIL SFRGCD (NIL T T T T T) -7 NIL NIL) (-1097 2929721 2930792 2931978 "SFQCMPK" 2935526 NIL SFQCMPK (NIL T T T T T) -7 NIL NIL) (-1096 2929343 2929432 2929542 "SFORT" 2929662 NIL SFORT (NIL T T) -8 NIL NIL) (-1095 2928488 2929183 2929304 "SEXOF" 2929309 NIL SEXOF (NIL T T T T T) -8 NIL NIL) (-1094 2927622 2928369 2928437 "SEX" 2928442 T SEX (NIL) -8 NIL NIL) (-1093 2922397 2923086 2923182 "SEXCAT" 2926953 NIL SEXCAT (NIL T T T T T) -9 NIL 2927572) (-1092 2919577 2922331 2922379 "SET" 2922384 NIL SET (NIL T) -8 NIL NIL) (-1091 2917828 2918290 2918595 "SETMN" 2919318 NIL SETMN (NIL NIL NIL) -8 NIL NIL) (-1090 2917433 2917559 2917590 "SETCAT" 2917707 T SETCAT (NIL) -9 NIL 2917792) (-1089 2917213 2917265 2917364 "SETCAT-" 2917369 NIL SETCAT- (NIL T) -8 NIL NIL) (-1088 2916876 2917026 2917057 "SETCATD" 2917116 T SETCATD (NIL) -9 NIL 2917163) (-1087 2913262 2915336 2915380 "SETAGG" 2916250 NIL SETAGG (NIL T) -9 NIL 2916590) (-1086 2912720 2912836 2913073 "SETAGG-" 2913078 NIL SETAGG- (NIL T T) -8 NIL NIL) (-1085 2911923 2912216 2912278 "SEGXCAT" 2912564 NIL SEGXCAT (NIL T T) -9 NIL 2912684) (-1084 2910983 2911593 2911773 "SEG" 2911778 NIL SEG (NIL T) -8 NIL NIL) (-1083 2909889 2910102 2910146 "SEGCAT" 2910728 NIL SEGCAT (NIL T) -9 NIL 2910966) (-1082 2908940 2909270 2909469 "SEGBIND" 2909725 NIL SEGBIND (NIL T) -8 NIL NIL) (-1081 2908561 2908620 2908733 "SEGBIND2" 2908875 NIL SEGBIND2 (NIL T T) -7 NIL NIL) (-1080 2907782 2907908 2908111 "SEG2" 2908406 NIL SEG2 (NIL T T) -7 NIL NIL) (-1079 2907219 2907717 2907764 "SDVAR" 2907769 NIL SDVAR (NIL T) -8 NIL NIL) (-1078 2899463 2906989 2907119 "SDPOL" 2907124 NIL SDPOL (NIL T) -8 NIL NIL) (-1077 2898056 2898322 2898641 "SCPKG" 2899178 NIL SCPKG (NIL T) -7 NIL NIL) (-1076 2897277 2897410 2897589 "SCACHE" 2897911 NIL SCACHE (NIL T) -7 NIL NIL) (-1075 2896716 2897037 2897122 "SAOS" 2897214 T SAOS (NIL) -8 NIL NIL) (-1074 2896281 2896316 2896489 "SAERFFC" 2896675 NIL SAERFFC (NIL T T T) -7 NIL NIL) (-1073 2890170 2896178 2896258 "SAE" 2896263 NIL SAE (NIL T T NIL) -8 NIL NIL) (-1072 2889763 2889798 2889957 "SAEFACT" 2890129 NIL SAEFACT (NIL T T T) -7 NIL NIL) (-1071 2888084 2888398 2888799 "RURPK" 2889429 NIL RURPK (NIL T NIL) -7 NIL NIL) (-1070 2886720 2886999 2887311 "RULESET" 2887918 NIL RULESET (NIL T T T) -8 NIL NIL) (-1069 2883907 2884410 2884875 "RULE" 2886401 NIL RULE (NIL T T T) -8 NIL NIL) (-1068 2883546 2883701 2883784 "RULECOLD" 2883859 NIL RULECOLD (NIL NIL) -8 NIL NIL) (-1067 2878395 2879189 2880109 "RSETGCD" 2882745 NIL RSETGCD (NIL T T T T T) -7 NIL NIL) (-1066 2867658 2872703 2872801 "RSETCAT" 2876920 NIL RSETCAT (NIL T T T T) -9 NIL 2878017) (-1065 2865585 2866124 2866948 "RSETCAT-" 2866953 NIL RSETCAT- (NIL T T T T T) -8 NIL NIL) (-1064 2857972 2859347 2860867 "RSDCMPK" 2864184 NIL RSDCMPK (NIL T T T T T) -7 NIL NIL) (-1063 2855976 2856417 2856492 "RRCC" 2857578 NIL RRCC (NIL T T) -9 NIL 2857922) (-1062 2855327 2855501 2855780 "RRCC-" 2855785 NIL RRCC- (NIL T T T) -8 NIL NIL) (-1061 2829474 2839103 2839171 "RPOLCAT" 2849835 NIL RPOLCAT (NIL T T T) -9 NIL 2852983) (-1060 2820974 2823312 2826434 "RPOLCAT-" 2826439 NIL RPOLCAT- (NIL T T T T) -8 NIL NIL) (-1059 2812033 2819185 2819667 "ROUTINE" 2820514 T ROUTINE (NIL) -8 NIL NIL) (-1058 2808733 2811584 2811733 "ROMAN" 2811906 T ROMAN (NIL) -8 NIL NIL) (-1057 2807008 2807593 2807853 "ROIRC" 2808538 NIL ROIRC (NIL T T) -8 NIL NIL) (-1056 2803346 2805646 2805677 "RNS" 2805981 T RNS (NIL) -9 NIL 2806255) (-1055 2801855 2802238 2802772 "RNS-" 2802847 NIL RNS- (NIL T) -8 NIL NIL) (-1054 2801277 2801685 2801716 "RNG" 2801721 T RNG (NIL) -9 NIL 2801742) (-1053 2800668 2801030 2801074 "RMODULE" 2801136 NIL RMODULE (NIL T) -9 NIL 2801178) (-1052 2799504 2799598 2799934 "RMCAT2" 2800569 NIL RMCAT2 (NIL NIL NIL T T T T T T T T) -7 NIL NIL) (-1051 2796213 2798682 2799005 "RMATRIX" 2799240 NIL RMATRIX (NIL NIL NIL T) -8 NIL NIL) (-1050 2789159 2791393 2791509 "RMATCAT" 2794868 NIL RMATCAT (NIL NIL NIL T T T) -9 NIL 2795845) (-1049 2788534 2788681 2788988 "RMATCAT-" 2788993 NIL RMATCAT- (NIL T NIL NIL T T T) -8 NIL NIL) (-1048 2788101 2788176 2788304 "RINTERP" 2788453 NIL RINTERP (NIL NIL T) -7 NIL NIL) (-1047 2787144 2787708 2787739 "RING" 2787851 T RING (NIL) -9 NIL 2787946) (-1046 2786936 2786980 2787077 "RING-" 2787082 NIL RING- (NIL T) -8 NIL NIL) (-1045 2785777 2786014 2786272 "RIDIST" 2786700 T RIDIST (NIL) -7 NIL NIL) (-1044 2777093 2785245 2785451 "RGCHAIN" 2785625 NIL RGCHAIN (NIL T NIL) -8 NIL NIL) (-1043 2775893 2776134 2776413 "RFP" 2776848 NIL RFP (NIL T) -7 NIL NIL) (-1042 2772887 2773501 2774171 "RF" 2775257 NIL RF (NIL T) -7 NIL NIL) (-1041 2772533 2772596 2772699 "RFFACTOR" 2772818 NIL RFFACTOR (NIL T) -7 NIL NIL) (-1040 2772258 2772293 2772390 "RFFACT" 2772492 NIL RFFACT (NIL T) -7 NIL NIL) (-1039 2770375 2770739 2771121 "RFDIST" 2771898 T RFDIST (NIL) -7 NIL NIL) (-1038 2769828 2769920 2770083 "RETSOL" 2770277 NIL RETSOL (NIL T T) -7 NIL NIL) (-1037 2769415 2769495 2769539 "RETRACT" 2769732 NIL RETRACT (NIL T) -9 NIL NIL) (-1036 2769264 2769289 2769376 "RETRACT-" 2769381 NIL RETRACT- (NIL T T) -8 NIL NIL) (-1035 2762130 2768917 2769044 "RESULT" 2769159 T RESULT (NIL) -8 NIL NIL) (-1034 2760710 2761399 2761598 "RESRING" 2762033 NIL RESRING (NIL T T T T NIL) -8 NIL NIL) (-1033 2760346 2760395 2760493 "RESLATC" 2760647 NIL RESLATC (NIL T) -7 NIL NIL) (-1032 2760052 2760086 2760193 "REPSQ" 2760305 NIL REPSQ (NIL T) -7 NIL NIL) (-1031 2757474 2758054 2758656 "REP" 2759472 T REP (NIL) -7 NIL NIL) (-1030 2757172 2757206 2757317 "REPDB" 2757433 NIL REPDB (NIL T) -7 NIL NIL) (-1029 2751090 2752469 2753688 "REP2" 2755988 NIL REP2 (NIL T) -7 NIL NIL) (-1028 2747471 2748152 2748958 "REP1" 2750319 NIL REP1 (NIL T) -7 NIL NIL) (-1027 2740197 2745612 2746068 "REGSET" 2747101 NIL REGSET (NIL T T T T) -8 NIL NIL) (-1026 2739012 2739347 2739596 "REF" 2739983 NIL REF (NIL T) -8 NIL NIL) (-1025 2738389 2738492 2738659 "REDORDER" 2738896 NIL REDORDER (NIL T T) -7 NIL NIL) (-1024 2735251 2735717 2736326 "RECOP" 2737923 NIL RECOP (NIL T T) -7 NIL NIL) (-1023 2731191 2734464 2734691 "RECLOS" 2735079 NIL RECLOS (NIL T) -8 NIL NIL) (-1022 2730243 2730424 2730639 "REALSOLV" 2730998 T REALSOLV (NIL) -7 NIL NIL) (-1021 2730088 2730129 2730160 "REAL" 2730165 T REAL (NIL) -9 NIL 2730200) (-1020 2726571 2727373 2728257 "REAL0Q" 2729253 NIL REAL0Q (NIL T) -7 NIL NIL) (-1019 2722172 2723160 2724221 "REAL0" 2725552 NIL REAL0 (NIL T) -7 NIL NIL) (-1018 2721577 2721649 2721856 "RDIV" 2722094 NIL RDIV (NIL T T T T T) -7 NIL NIL) (-1017 2720645 2720819 2721032 "RDIST" 2721399 NIL RDIST (NIL T) -7 NIL NIL) (-1016 2719242 2719529 2719901 "RDETRS" 2720353 NIL RDETRS (NIL T T) -7 NIL NIL) (-1015 2717054 2717508 2718046 "RDETR" 2718784 NIL RDETR (NIL T T) -7 NIL NIL) (-1014 2715665 2715943 2716347 "RDEEFS" 2716770 NIL RDEEFS (NIL T T) -7 NIL NIL) (-1013 2714160 2714466 2714898 "RDEEF" 2715353 NIL RDEEF (NIL T T) -7 NIL NIL) (-1012 2708351 2711286 2711317 "RCFIELD" 2712612 T RCFIELD (NIL) -9 NIL 2713343) (-1011 2706415 2706919 2707615 "RCFIELD-" 2707690 NIL RCFIELD- (NIL T) -8 NIL NIL) (-1010 2702773 2704552 2704596 "RCAGG" 2705680 NIL RCAGG (NIL T) -9 NIL 2706143) (-1009 2702401 2702495 2702658 "RCAGG-" 2702663 NIL RCAGG- (NIL T T) -8 NIL NIL) (-1008 2701737 2701848 2702013 "RATRET" 2702285 NIL RATRET (NIL T) -7 NIL NIL) (-1007 2701290 2701357 2701478 "RATFACT" 2701665 NIL RATFACT (NIL T) -7 NIL NIL) (-1006 2700598 2700718 2700870 "RANDSRC" 2701160 T RANDSRC (NIL) -7 NIL NIL) (-1005 2700332 2700376 2700449 "RADUTIL" 2700547 T RADUTIL (NIL) -7 NIL NIL) (-1004 2693320 2699065 2699384 "RADIX" 2700047 NIL RADIX (NIL NIL) -8 NIL NIL) (-1003 2684883 2693162 2693292 "RADFF" 2693297 NIL RADFF (NIL T T T NIL NIL) -8 NIL NIL) (-1002 2684529 2684604 2684635 "RADCAT" 2684795 T RADCAT (NIL) -9 NIL NIL) (-1001 2684311 2684359 2684459 "RADCAT-" 2684464 NIL RADCAT- (NIL T) -8 NIL NIL) (-1000 2677558 2679176 2680329 "QUEUE" 2683193 NIL QUEUE (NIL T) -8 NIL NIL) (-999 2674049 2677495 2677540 "QUAT" 2677545 NIL QUAT (NIL T) -8 NIL NIL) (-998 2673687 2673730 2673857 "QUATCT2" 2674000 NIL QUATCT2 (NIL T T T T) -7 NIL NIL) (-997 2667424 2670808 2670849 "QUATCAT" 2671629 NIL QUATCAT (NIL T) -9 NIL 2672387) (-996 2663568 2664605 2665992 "QUATCAT-" 2666086 NIL QUATCAT- (NIL T T) -8 NIL NIL) (-995 2661128 2662686 2662728 "QUAGG" 2663103 NIL QUAGG (NIL T) -9 NIL 2663278) (-994 2660053 2660526 2660698 "QFORM" 2661000 NIL QFORM (NIL NIL T) -8 NIL NIL) (-993 2651280 2656547 2656588 "QFCAT" 2657246 NIL QFCAT (NIL T) -9 NIL 2658235) (-992 2646852 2648053 2649644 "QFCAT-" 2649738 NIL QFCAT- (NIL T T) -8 NIL NIL) (-991 2646490 2646533 2646660 "QFCAT2" 2646803 NIL QFCAT2 (NIL T T T T) -7 NIL NIL) (-990 2645950 2646060 2646190 "QEQUAT" 2646380 T QEQUAT (NIL) -8 NIL NIL) (-989 2639098 2640169 2641353 "QCMPACK" 2644883 NIL QCMPACK (NIL T T T T T) -7 NIL NIL) (-988 2636678 2637099 2637525 "QALGSET" 2638755 NIL QALGSET (NIL T T T T) -8 NIL NIL) (-987 2635923 2636097 2636329 "QALGSET2" 2636498 NIL QALGSET2 (NIL NIL NIL) -7 NIL NIL) (-986 2634614 2634837 2635154 "PWFFINTB" 2635696 NIL PWFFINTB (NIL T T T T) -7 NIL NIL) (-985 2632796 2632964 2633318 "PUSHVAR" 2634428 NIL PUSHVAR (NIL T T T T) -7 NIL NIL) (-984 2628713 2629767 2629809 "PTRANFN" 2631693 NIL PTRANFN (NIL T) -9 NIL NIL) (-983 2627115 2627406 2627728 "PTPACK" 2628424 NIL PTPACK (NIL T) -7 NIL NIL) (-982 2626747 2626804 2626913 "PTFUNC2" 2627052 NIL PTFUNC2 (NIL T T) -7 NIL NIL) (-981 2621247 2625581 2625623 "PTCAT" 2625996 NIL PTCAT (NIL T) -9 NIL 2626158) (-980 2620905 2620940 2621064 "PSQFR" 2621206 NIL PSQFR (NIL T T T T) -7 NIL NIL) (-979 2619492 2619792 2620128 "PSEUDLIN" 2620601 NIL PSEUDLIN (NIL T) -7 NIL NIL) (-978 2606268 2608632 2610953 "PSETPK" 2617255 NIL PSETPK (NIL T T T T) -7 NIL NIL) (-977 2599312 2602026 2602123 "PSETCAT" 2605144 NIL PSETCAT (NIL T T T T) -9 NIL 2605957) (-976 2597148 2597782 2598603 "PSETCAT-" 2598608 NIL PSETCAT- (NIL T T T T T) -8 NIL NIL) (-975 2596497 2596661 2596690 "PSCURVE" 2596958 T PSCURVE (NIL) -9 NIL 2597125) (-974 2592886 2594412 2594478 "PSCAT" 2595322 NIL PSCAT (NIL T T T) -9 NIL 2595562) (-973 2591949 2592165 2592565 "PSCAT-" 2592570 NIL PSCAT- (NIL T T T T) -8 NIL NIL) (-972 2590602 2591234 2591448 "PRTITION" 2591755 T PRTITION (NIL) -8 NIL NIL) (-971 2587766 2588415 2588456 "PRSPCAT" 2589970 NIL PRSPCAT (NIL T) -9 NIL 2590538) (-970 2576866 2579072 2581259 "PRS" 2585629 NIL PRS (NIL T T) -7 NIL NIL) (-969 2574764 2576250 2576291 "PRQAGG" 2576474 NIL PRQAGG (NIL T) -9 NIL 2576576) (-968 2574033 2574689 2574746 "PROJSP" 2574751 NIL PROJSP (NIL NIL T) -8 NIL NIL) (-967 2573215 2573956 2574008 "PROJPLPS" 2574013 NIL PROJPLPS (NIL T) -8 NIL NIL) (-966 2572474 2573152 2573197 "PROJPL" 2573202 NIL PROJPL (NIL T) -8 NIL NIL) (-965 2566280 2570672 2571476 "PRODUCT" 2571716 NIL PRODUCT (NIL T T) -8 NIL NIL) (-964 2563555 2565744 2565975 "PR" 2566094 NIL PR (NIL T T) -8 NIL NIL) (-963 2562107 2562264 2562559 "PRJALGPK" 2563395 NIL PRJALGPK (NIL T NIL T T T) -7 NIL NIL) (-962 2561903 2561935 2561994 "PRINT" 2562068 T PRINT (NIL) -7 NIL NIL) (-961 2561243 2561360 2561512 "PRIMES" 2561783 NIL PRIMES (NIL T) -7 NIL NIL) (-960 2559308 2559709 2560175 "PRIMELT" 2560822 NIL PRIMELT (NIL T) -7 NIL NIL) (-959 2559036 2559085 2559114 "PRIMCAT" 2559238 T PRIMCAT (NIL) -9 NIL NIL) (-958 2555203 2558974 2559019 "PRIMARR" 2559024 NIL PRIMARR (NIL T) -8 NIL NIL) (-957 2554210 2554388 2554616 "PRIMARR2" 2555021 NIL PRIMARR2 (NIL T T) -7 NIL NIL) (-956 2553853 2553909 2554020 "PREASSOC" 2554148 NIL PREASSOC (NIL T T) -7 NIL NIL) (-955 2553328 2553460 2553489 "PPCURVE" 2553694 T PPCURVE (NIL) -9 NIL 2553830) (-954 2550689 2551088 2551679 "POLYROOT" 2552910 NIL POLYROOT (NIL T T T T T) -7 NIL NIL) (-953 2544590 2550295 2550454 "POLY" 2550563 NIL POLY (NIL T) -8 NIL NIL) (-952 2543973 2544031 2544265 "POLYLIFT" 2544526 NIL POLYLIFT (NIL T T T T T) -7 NIL NIL) (-951 2540248 2540697 2541326 "POLYCATQ" 2543518 NIL POLYCATQ (NIL T T T T T) -7 NIL NIL) (-950 2527210 2532610 2532676 "POLYCAT" 2536190 NIL POLYCAT (NIL T T T) -9 NIL 2538103) (-949 2520660 2522521 2524905 "POLYCAT-" 2524910 NIL POLYCAT- (NIL T T T T) -8 NIL NIL) (-948 2520247 2520315 2520435 "POLY2UP" 2520586 NIL POLY2UP (NIL NIL T) -7 NIL NIL) (-947 2519879 2519936 2520045 "POLY2" 2520184 NIL POLY2 (NIL T T) -7 NIL NIL) (-946 2518566 2518805 2519080 "POLUTIL" 2519654 NIL POLUTIL (NIL T T) -7 NIL NIL) (-945 2516921 2517198 2517529 "POLTOPOL" 2518288 NIL POLTOPOL (NIL NIL T) -7 NIL NIL) (-944 2512443 2516857 2516903 "POINT" 2516908 NIL POINT (NIL T) -8 NIL NIL) (-943 2510630 2510987 2511362 "PNTHEORY" 2512088 T PNTHEORY (NIL) -7 NIL NIL) (-942 2509049 2509346 2509758 "PMTOOLS" 2510328 NIL PMTOOLS (NIL T T T) -7 NIL NIL) (-941 2508642 2508720 2508837 "PMSYM" 2508965 NIL PMSYM (NIL T) -7 NIL NIL) (-940 2508152 2508221 2508395 "PMQFCAT" 2508567 NIL PMQFCAT (NIL T T T) -7 NIL NIL) (-939 2507507 2507617 2507773 "PMPRED" 2508029 NIL PMPRED (NIL T) -7 NIL NIL) (-938 2506903 2506989 2507150 "PMPREDFS" 2507408 NIL PMPREDFS (NIL T T T) -7 NIL NIL) (-937 2505548 2505756 2506140 "PMPLCAT" 2506666 NIL PMPLCAT (NIL T T T T T) -7 NIL NIL) (-936 2505080 2505159 2505311 "PMLSAGG" 2505463 NIL PMLSAGG (NIL T T T) -7 NIL NIL) (-935 2504555 2504631 2504812 "PMKERNEL" 2504998 NIL PMKERNEL (NIL T T) -7 NIL NIL) (-934 2504172 2504247 2504360 "PMINS" 2504474 NIL PMINS (NIL T) -7 NIL NIL) (-933 2503600 2503669 2503885 "PMFS" 2504097 NIL PMFS (NIL T T T) -7 NIL NIL) (-932 2502828 2502946 2503151 "PMDOWN" 2503477 NIL PMDOWN (NIL T T T) -7 NIL NIL) (-931 2501991 2502150 2502332 "PMASS" 2502666 T PMASS (NIL) -7 NIL NIL) (-930 2501265 2501376 2501539 "PMASSFS" 2501877 NIL PMASSFS (NIL T T) -7 NIL NIL) (-929 2499025 2499278 2499661 "PLPKCRV" 2500989 NIL PLPKCRV (NIL T T T NIL T) -7 NIL NIL) (-928 2498680 2498748 2498842 "PLOTTOOL" 2498951 T PLOTTOOL (NIL) -7 NIL NIL) (-927 2493302 2494491 2495639 "PLOT" 2497552 T PLOT (NIL) -8 NIL NIL) (-926 2489116 2490150 2491071 "PLOT3D" 2492401 T PLOT3D (NIL) -8 NIL NIL) (-925 2488028 2488205 2488440 "PLOT1" 2488920 NIL PLOT1 (NIL T) -7 NIL NIL) (-924 2463423 2468094 2472945 "PLEQN" 2483294 NIL PLEQN (NIL T T T T) -7 NIL NIL) (-923 2462663 2463333 2463400 "PLCS" 2463405 NIL PLCS (NIL T T) -8 NIL NIL) (-922 2461814 2462548 2462619 "PLACESPS" 2462624 NIL PLACESPS (NIL T) -8 NIL NIL) (-921 2461021 2461727 2461784 "PLACES" 2461789 NIL PLACES (NIL T) -8 NIL NIL) (-920 2457745 2458409 2458468 "PLACESC" 2460386 NIL PLACESC (NIL T T) -9 NIL 2460957) (-919 2457063 2457185 2457365 "PINTERP" 2457610 NIL PINTERP (NIL NIL T) -7 NIL NIL) (-918 2456756 2456803 2456906 "PINTERPA" 2457010 NIL PINTERPA (NIL T T) -7 NIL NIL) (-917 2455983 2456550 2456643 "PI" 2456683 T PI (NIL) -8 NIL NIL) (-916 2454370 2455355 2455384 "PID" 2455566 T PID (NIL) -9 NIL 2455700) (-915 2454095 2454132 2454220 "PICOERCE" 2454327 NIL PICOERCE (NIL T) -7 NIL NIL) (-914 2453416 2453554 2453730 "PGROEB" 2453951 NIL PGROEB (NIL T) -7 NIL NIL) (-913 2449003 2449817 2450722 "PGE" 2452531 T PGE (NIL) -7 NIL NIL) (-912 2447127 2447373 2447739 "PGCD" 2448720 NIL PGCD (NIL T T T T) -7 NIL NIL) (-911 2446465 2446568 2446729 "PFRPAC" 2447011 NIL PFRPAC (NIL T) -7 NIL NIL) (-910 2443080 2445013 2445366 "PFR" 2446144 NIL PFR (NIL T) -8 NIL NIL) (-909 2441469 2441713 2442038 "PFOTOOLS" 2442827 NIL PFOTOOLS (NIL T T) -7 NIL NIL) (-908 2436334 2436999 2437748 "PFORP" 2440811 NIL PFORP (NIL T T T NIL) -7 NIL NIL) (-907 2434867 2435106 2435457 "PFOQ" 2436091 NIL PFOQ (NIL T T T) -7 NIL NIL) (-906 2433340 2433552 2433915 "PFO" 2434651 NIL PFO (NIL T T T T T) -7 NIL NIL) (-905 2429863 2433229 2433298 "PF" 2433303 NIL PF (NIL NIL) -8 NIL NIL) (-904 2427288 2428569 2428598 "PFECAT" 2429183 T PFECAT (NIL) -9 NIL 2429566) (-903 2426733 2426887 2427101 "PFECAT-" 2427106 NIL PFECAT- (NIL T) -8 NIL NIL) (-902 2425337 2425588 2425889 "PFBRU" 2426482 NIL PFBRU (NIL T T) -7 NIL NIL) (-901 2423204 2423555 2423987 "PFBR" 2424988 NIL PFBR (NIL T T T T) -7 NIL NIL) (-900 2419060 2420584 2421258 "PERM" 2422563 NIL PERM (NIL T) -8 NIL NIL) (-899 2414327 2415267 2416137 "PERMGRP" 2418223 NIL PERMGRP (NIL T) -8 NIL NIL) (-898 2412398 2413391 2413433 "PERMCAT" 2413879 NIL PERMCAT (NIL T) -9 NIL 2414182) (-897 2412051 2412092 2412216 "PERMAN" 2412351 NIL PERMAN (NIL NIL T) -7 NIL NIL) (-896 2409497 2411620 2411751 "PENDTREE" 2411953 NIL PENDTREE (NIL T) -8 NIL NIL) (-895 2407565 2408343 2408385 "PDRING" 2409042 NIL PDRING (NIL T) -9 NIL 2409328) (-894 2406668 2406886 2407248 "PDRING-" 2407253 NIL PDRING- (NIL T T) -8 NIL NIL) (-893 2403810 2404560 2405251 "PDEPROB" 2405997 T PDEPROB (NIL) -8 NIL NIL) (-892 2401357 2401859 2402414 "PDEPACK" 2403275 T PDEPACK (NIL) -7 NIL NIL) (-891 2400269 2400459 2400710 "PDECOMP" 2401156 NIL PDECOMP (NIL T T) -7 NIL NIL) (-890 2397873 2398690 2398719 "PDECAT" 2399506 T PDECAT (NIL) -9 NIL 2400219) (-889 2397624 2397657 2397747 "PCOMP" 2397834 NIL PCOMP (NIL T T) -7 NIL NIL) (-888 2395829 2396425 2396722 "PBWLB" 2397353 NIL PBWLB (NIL T) -8 NIL NIL) (-887 2388334 2389902 2391240 "PATTERN" 2394512 NIL PATTERN (NIL T) -8 NIL NIL) (-886 2387966 2388023 2388132 "PATTERN2" 2388271 NIL PATTERN2 (NIL T T) -7 NIL NIL) (-885 2385723 2386111 2386568 "PATTERN1" 2387555 NIL PATTERN1 (NIL T T) -7 NIL NIL) (-884 2383118 2383672 2384153 "PATRES" 2385288 NIL PATRES (NIL T T) -8 NIL NIL) (-883 2382682 2382749 2382881 "PATRES2" 2383045 NIL PATRES2 (NIL T T T) -7 NIL NIL) (-882 2380565 2380970 2381377 "PATMATCH" 2382349 NIL PATMATCH (NIL T T T) -7 NIL NIL) (-881 2380100 2380283 2380325 "PATMAB" 2380432 NIL PATMAB (NIL T) -9 NIL 2380515) (-880 2378645 2378954 2379212 "PATLRES" 2379905 NIL PATLRES (NIL T T T) -8 NIL NIL) (-879 2378192 2378315 2378357 "PATAB" 2378362 NIL PATAB (NIL T) -9 NIL 2378532) (-878 2375673 2376205 2376778 "PARTPERM" 2377639 T PARTPERM (NIL) -7 NIL NIL) (-877 2375294 2375357 2375459 "PARSURF" 2375604 NIL PARSURF (NIL T) -8 NIL NIL) (-876 2374926 2374983 2375092 "PARSU2" 2375231 NIL PARSU2 (NIL T T) -7 NIL NIL) (-875 2374547 2374610 2374712 "PARSCURV" 2374857 NIL PARSCURV (NIL T) -8 NIL NIL) (-874 2374179 2374236 2374345 "PARSC2" 2374484 NIL PARSC2 (NIL T T) -7 NIL NIL) (-873 2373818 2373876 2373973 "PARPCURV" 2374115 NIL PARPCURV (NIL T) -8 NIL NIL) (-872 2373450 2373507 2373616 "PARPC2" 2373755 NIL PARPC2 (NIL T T) -7 NIL NIL) (-871 2371930 2372048 2372367 "PARAMP" 2373305 NIL PARAMP (NIL T NIL T T T T T) -7 NIL NIL) (-870 2371450 2371536 2371655 "PAN2EXPR" 2371831 T PAN2EXPR (NIL) -7 NIL NIL) (-869 2370256 2370571 2370799 "PALETTE" 2371242 T PALETTE (NIL) -8 NIL NIL) (-868 2357889 2360055 2362171 "PAFF" 2368204 NIL PAFF (NIL T NIL T) -7 NIL NIL) (-867 2344885 2347213 2349424 "PAFFFF" 2355742 NIL PAFFFF (NIL T NIL T) -7 NIL NIL) (-866 2338726 2344144 2344338 "PADICRC" 2344740 NIL PADICRC (NIL NIL T) -8 NIL NIL) (-865 2331925 2338072 2338256 "PADICRAT" 2338574 NIL PADICRAT (NIL NIL) -8 NIL NIL) (-864 2330229 2331862 2331907 "PADIC" 2331912 NIL PADIC (NIL NIL) -8 NIL NIL) (-863 2327429 2329003 2329044 "PADICCT" 2329625 NIL PADICCT (NIL NIL) -9 NIL 2329907) (-862 2326386 2326586 2326854 "PADEPAC" 2327216 NIL PADEPAC (NIL T NIL NIL) -7 NIL NIL) (-861 2325598 2325731 2325937 "PADE" 2326248 NIL PADE (NIL T T T) -7 NIL NIL) (-860 2322075 2325216 2325335 "PACRAT" 2325499 T PACRAT (NIL) -8 NIL NIL) (-859 2318136 2321186 2321215 "PACRATC" 2321220 T PACRATC (NIL) -9 NIL 2321300) (-858 2314258 2316223 2316252 "PACPERC" 2317198 T PACPERC (NIL) -9 NIL 2317638) (-857 2310928 2314032 2314123 "PACOFF" 2314199 NIL PACOFF (NIL T) -8 NIL NIL) (-856 2307623 2310283 2310312 "PACFFC" 2310317 T PACFFC (NIL) -9 NIL 2310338) (-855 2303713 2307306 2307407 "PACEXT" 2307554 NIL PACEXT (NIL NIL) -8 NIL NIL) (-854 2299091 2302608 2302637 "PACEXTC" 2302642 T PACEXTC (NIL) -9 NIL 2302686) (-853 2297099 2297931 2298246 "OWP" 2298860 NIL OWP (NIL T NIL NIL NIL) -8 NIL NIL) (-852 2296208 2296704 2296876 "OVAR" 2296967 NIL OVAR (NIL NIL) -8 NIL NIL) (-851 2295472 2295593 2295754 "OUT" 2296067 T OUT (NIL) -7 NIL NIL) (-850 2284518 2286697 2288867 "OUTFORM" 2293322 T OUTFORM (NIL) -8 NIL NIL) (-849 2283926 2284247 2284336 "OSI" 2284449 T OSI (NIL) -8 NIL NIL) (-848 2282673 2282900 2283184 "ORTHPOL" 2283674 NIL ORTHPOL (NIL T) -7 NIL NIL) (-847 2280035 2282330 2282470 "OREUP" 2282616 NIL OREUP (NIL NIL T NIL NIL) -8 NIL NIL) (-846 2277422 2279724 2279852 "ORESUP" 2279977 NIL ORESUP (NIL T NIL NIL) -8 NIL NIL) (-845 2274930 2275436 2276001 "OREPCTO" 2276907 NIL OREPCTO (NIL T T) -7 NIL NIL) (-844 2268800 2271011 2271053 "OREPCAT" 2273401 NIL OREPCAT (NIL T) -9 NIL 2274501) (-843 2265947 2266729 2267787 "OREPCAT-" 2267792 NIL OREPCAT- (NIL T T) -8 NIL NIL) (-842 2265123 2265395 2265424 "ORDSET" 2265733 T ORDSET (NIL) -9 NIL 2265897) (-841 2264642 2264764 2264957 "ORDSET-" 2264962 NIL ORDSET- (NIL T) -8 NIL NIL) (-840 2263251 2264052 2264081 "ORDRING" 2264283 T ORDRING (NIL) -9 NIL 2264408) (-839 2262896 2262990 2263134 "ORDRING-" 2263139 NIL ORDRING- (NIL T) -8 NIL NIL) (-838 2262270 2262751 2262780 "ORDMON" 2262785 T ORDMON (NIL) -9 NIL 2262806) (-837 2261432 2261579 2261774 "ORDFUNS" 2262119 NIL ORDFUNS (NIL NIL T) -7 NIL NIL) (-836 2260942 2261301 2261330 "ORDFIN" 2261335 T ORDFIN (NIL) -9 NIL 2261356) (-835 2257454 2259534 2259940 "ORDCOMP" 2260569 NIL ORDCOMP (NIL T) -8 NIL NIL) (-834 2256720 2256847 2257033 "ORDCOMP2" 2257314 NIL ORDCOMP2 (NIL T T) -7 NIL NIL) (-833 2253228 2254110 2254947 "OPTPROB" 2255903 T OPTPROB (NIL) -8 NIL NIL) (-832 2250030 2250669 2251373 "OPTPACK" 2252544 T OPTPACK (NIL) -7 NIL NIL) (-831 2247742 2248482 2248511 "OPTCAT" 2249330 T OPTCAT (NIL) -9 NIL 2249980) (-830 2247510 2247549 2247615 "OPQUERY" 2247696 T OPQUERY (NIL) -7 NIL NIL) (-829 2244636 2245827 2246328 "OP" 2247042 NIL OP (NIL T) -8 NIL NIL) (-828 2241401 2243439 2243805 "ONECOMP" 2244303 NIL ONECOMP (NIL T) -8 NIL NIL) (-827 2240706 2240821 2240995 "ONECOMP2" 2241273 NIL ONECOMP2 (NIL T T) -7 NIL NIL) (-826 2240125 2240231 2240361 "OMSERVER" 2240596 T OMSERVER (NIL) -7 NIL NIL) (-825 2237012 2239564 2239605 "OMSAGG" 2239666 NIL OMSAGG (NIL T) -9 NIL 2239730) (-824 2235635 2235898 2236180 "OMPKG" 2236750 T OMPKG (NIL) -7 NIL NIL) (-823 2235064 2235167 2235196 "OM" 2235495 T OM (NIL) -9 NIL NIL) (-822 2233602 2234615 2234783 "OMLO" 2234946 NIL OMLO (NIL T T) -8 NIL NIL) (-821 2232527 2232674 2232901 "OMEXPR" 2233428 NIL OMEXPR (NIL T) -7 NIL NIL) (-820 2231845 2232073 2232209 "OMERR" 2232411 T OMERR (NIL) -8 NIL NIL) (-819 2231023 2231266 2231426 "OMERRK" 2231705 T OMERRK (NIL) -8 NIL NIL) (-818 2230501 2230700 2230808 "OMENC" 2230935 T OMENC (NIL) -8 NIL NIL) (-817 2224396 2225581 2226752 "OMDEV" 2229350 T OMDEV (NIL) -8 NIL NIL) (-816 2223465 2223636 2223830 "OMCONN" 2224222 T OMCONN (NIL) -8 NIL NIL) (-815 2222076 2223062 2223091 "OINTDOM" 2223096 T OINTDOM (NIL) -9 NIL 2223117) (-814 2217727 2218982 2219726 "OFMONOID" 2221364 NIL OFMONOID (NIL T) -8 NIL NIL) (-813 2217165 2217664 2217709 "ODVAR" 2217714 NIL ODVAR (NIL T) -8 NIL NIL) (-812 2214292 2216664 2216848 "ODR" 2217041 NIL ODR (NIL T T NIL) -8 NIL NIL) (-811 2206590 2214068 2214194 "ODPOL" 2214199 NIL ODPOL (NIL T) -8 NIL NIL) (-810 2200384 2206462 2206567 "ODP" 2206572 NIL ODP (NIL NIL T NIL) -8 NIL NIL) (-809 2199150 2199365 2199640 "ODETOOLS" 2200158 NIL ODETOOLS (NIL T T) -7 NIL NIL) (-808 2196119 2196775 2197491 "ODESYS" 2198483 NIL ODESYS (NIL T T) -7 NIL NIL) (-807 2191003 2191911 2192935 "ODERTRIC" 2195195 NIL ODERTRIC (NIL T T) -7 NIL NIL) (-806 2190429 2190511 2190705 "ODERED" 2190915 NIL ODERED (NIL T T T T T) -7 NIL NIL) (-805 2187317 2187865 2188542 "ODERAT" 2189852 NIL ODERAT (NIL T T) -7 NIL NIL) (-804 2184277 2184741 2185338 "ODEPRRIC" 2186846 NIL ODEPRRIC (NIL T T T T) -7 NIL NIL) (-803 2182148 2182715 2183224 "ODEPROB" 2183788 T ODEPROB (NIL) -8 NIL NIL) (-802 2178670 2179153 2179800 "ODEPRIM" 2181627 NIL ODEPRIM (NIL T T T T) -7 NIL NIL) (-801 2177919 2178021 2178281 "ODEPAL" 2178562 NIL ODEPAL (NIL T T T T) -7 NIL NIL) (-800 2174081 2174872 2175736 "ODEPACK" 2177075 T ODEPACK (NIL) -7 NIL NIL) (-799 2173114 2173221 2173450 "ODEINT" 2173970 NIL ODEINT (NIL T T) -7 NIL NIL) (-798 2167215 2168640 2170087 "ODEIFTBL" 2171687 T ODEIFTBL (NIL) -8 NIL NIL) (-797 2162550 2163336 2164295 "ODEEF" 2166374 NIL ODEEF (NIL T T) -7 NIL NIL) (-796 2161885 2161974 2162204 "ODECONST" 2162455 NIL ODECONST (NIL T T T) -7 NIL NIL) (-795 2160035 2160670 2160699 "ODECAT" 2161304 T ODECAT (NIL) -9 NIL 2161835) (-794 2156896 2159747 2159866 "OCT" 2159948 NIL OCT (NIL T) -8 NIL NIL) (-793 2156534 2156577 2156704 "OCTCT2" 2156847 NIL OCTCT2 (NIL T T T T) -7 NIL NIL) (-792 2151358 2153802 2153843 "OC" 2154940 NIL OC (NIL T) -9 NIL 2155790) (-791 2148585 2149333 2150323 "OC-" 2150417 NIL OC- (NIL T T) -8 NIL NIL) (-790 2147962 2148404 2148433 "OCAMON" 2148438 T OCAMON (NIL) -9 NIL 2148459) (-789 2147414 2147821 2147850 "OASGP" 2147855 T OASGP (NIL) -9 NIL 2147875) (-788 2146700 2147163 2147192 "OAMONS" 2147232 T OAMONS (NIL) -9 NIL 2147275) (-787 2146139 2146546 2146575 "OAMON" 2146580 T OAMON (NIL) -9 NIL 2146600) (-786 2145442 2145934 2145963 "OAGROUP" 2145968 T OAGROUP (NIL) -9 NIL 2145988) (-785 2145132 2145182 2145270 "NUMTUBE" 2145386 NIL NUMTUBE (NIL T) -7 NIL NIL) (-784 2138705 2140223 2141759 "NUMQUAD" 2143616 T NUMQUAD (NIL) -7 NIL NIL) (-783 2134461 2135449 2136474 "NUMODE" 2137700 T NUMODE (NIL) -7 NIL NIL) (-782 2131841 2132695 2132724 "NUMINT" 2133647 T NUMINT (NIL) -9 NIL 2134411) (-781 2130789 2130986 2131204 "NUMFMT" 2131643 T NUMFMT (NIL) -7 NIL NIL) (-780 2117167 2120109 2122633 "NUMERIC" 2128304 NIL NUMERIC (NIL T) -7 NIL NIL) (-779 2111570 2116615 2116711 "NTSCAT" 2116716 NIL NTSCAT (NIL T T T T) -9 NIL 2116755) (-778 2110766 2110931 2111123 "NTPOLFN" 2111410 NIL NTPOLFN (NIL T) -7 NIL NIL) (-777 2098562 2107593 2108404 "NSUP" 2109988 NIL NSUP (NIL T) -8 NIL NIL) (-776 2098194 2098251 2098360 "NSUP2" 2098499 NIL NSUP2 (NIL T T) -7 NIL NIL) (-775 2088145 2097968 2098101 "NSMP" 2098106 NIL NSMP (NIL T T) -8 NIL NIL) (-774 2076237 2087727 2087891 "NSDPS" 2088013 NIL NSDPS (NIL T) -8 NIL NIL) (-773 2074669 2074970 2075327 "NREP" 2075925 NIL NREP (NIL T) -7 NIL NIL) (-772 2071758 2072306 2072955 "NPOLYGON" 2074111 NIL NPOLYGON (NIL T T T NIL) -7 NIL NIL) (-771 2070349 2070601 2070959 "NPCOEF" 2071501 NIL NPCOEF (NIL T T T T T) -7 NIL NIL) (-770 2069631 2070133 2070217 "NOTTING" 2070297 NIL NOTTING (NIL T) -8 NIL NIL) (-769 2068697 2068812 2069028 "NORMRETR" 2069512 NIL NORMRETR (NIL T T T T NIL) -7 NIL NIL) (-768 2066738 2067028 2067437 "NORMPK" 2068405 NIL NORMPK (NIL T T T T T) -7 NIL NIL) (-767 2066423 2066451 2066575 "NORMMA" 2066704 NIL NORMMA (NIL T T T T) -7 NIL NIL) (-766 2066250 2066380 2066409 "NONE" 2066414 T NONE (NIL) -8 NIL NIL) (-765 2066039 2066068 2066137 "NONE1" 2066214 NIL NONE1 (NIL T) -7 NIL NIL) (-764 2065522 2065584 2065770 "NODE1" 2065971 NIL NODE1 (NIL T T) -7 NIL NIL) (-763 2063816 2064685 2064940 "NNI" 2065287 T NNI (NIL) -8 NIL NIL) (-762 2062236 2062549 2062913 "NLINSOL" 2063484 NIL NLINSOL (NIL T) -7 NIL NIL) (-761 2058404 2059371 2060293 "NIPROB" 2061334 T NIPROB (NIL) -8 NIL NIL) (-760 2057161 2057395 2057697 "NFINTBAS" 2058166 NIL NFINTBAS (NIL T T) -7 NIL NIL) (-759 2056890 2056933 2057014 "NEWTON" 2057112 NIL NEWTON (NIL T) -7 NIL NIL) (-758 2055598 2055829 2056110 "NCODIV" 2056658 NIL NCODIV (NIL T T) -7 NIL NIL) (-757 2055360 2055397 2055472 "NCNTFRAC" 2055555 NIL NCNTFRAC (NIL T) -7 NIL NIL) (-756 2053540 2053904 2054324 "NCEP" 2054985 NIL NCEP (NIL T) -7 NIL NIL) (-755 2052450 2053189 2053218 "NASRING" 2053328 T NASRING (NIL) -9 NIL 2053402) (-754 2052245 2052289 2052383 "NASRING-" 2052388 NIL NASRING- (NIL T) -8 NIL NIL) (-753 2051397 2051896 2051925 "NARNG" 2052042 T NARNG (NIL) -9 NIL 2052133) (-752 2051089 2051156 2051290 "NARNG-" 2051295 NIL NARNG- (NIL T) -8 NIL NIL) (-751 2049968 2050175 2050410 "NAGSP" 2050874 T NAGSP (NIL) -7 NIL NIL) (-750 2041240 2042924 2044597 "NAGS" 2048315 T NAGS (NIL) -7 NIL NIL) (-749 2039788 2040096 2040427 "NAGF07" 2040929 T NAGF07 (NIL) -7 NIL NIL) (-748 2034326 2035617 2036924 "NAGF04" 2038501 T NAGF04 (NIL) -7 NIL NIL) (-747 2027294 2028908 2030541 "NAGF02" 2032713 T NAGF02 (NIL) -7 NIL NIL) (-746 2022518 2023618 2024735 "NAGF01" 2026197 T NAGF01 (NIL) -7 NIL NIL) (-745 2016146 2017712 2019297 "NAGE04" 2020953 T NAGE04 (NIL) -7 NIL NIL) (-744 2007315 2009436 2011566 "NAGE02" 2014036 T NAGE02 (NIL) -7 NIL NIL) (-743 2003268 2004215 2005179 "NAGE01" 2006371 T NAGE01 (NIL) -7 NIL NIL) (-742 2001063 2001597 2002155 "NAGD03" 2002730 T NAGD03 (NIL) -7 NIL NIL) (-741 1992813 1994741 1996695 "NAGD02" 1999129 T NAGD02 (NIL) -7 NIL NIL) (-740 1986624 1988049 1989489 "NAGD01" 1991393 T NAGD01 (NIL) -7 NIL NIL) (-739 1982833 1983655 1984492 "NAGC06" 1985807 T NAGC06 (NIL) -7 NIL NIL) (-738 1981298 1981630 1981986 "NAGC05" 1982497 T NAGC05 (NIL) -7 NIL NIL) (-737 1980674 1980793 1980937 "NAGC02" 1981174 T NAGC02 (NIL) -7 NIL NIL) (-736 1979733 1980290 1980331 "NAALG" 1980410 NIL NAALG (NIL T) -9 NIL 1980471) (-735 1979568 1979597 1979687 "NAALG-" 1979692 NIL NAALG- (NIL T T) -8 NIL NIL) (-734 1970444 1978684 1978959 "MYUP" 1979339 NIL MYUP (NIL NIL T) -8 NIL NIL) (-733 1960807 1968900 1969271 "MYEXPR" 1970139 NIL MYEXPR (NIL NIL T) -8 NIL NIL) (-732 1954757 1955865 1957052 "MULTSQFR" 1959703 NIL MULTSQFR (NIL T T T T) -7 NIL NIL) (-731 1954076 1954151 1954335 "MULTFACT" 1954669 NIL MULTFACT (NIL T T T T) -7 NIL NIL) (-730 1947201 1951110 1951164 "MTSCAT" 1952234 NIL MTSCAT (NIL T T) -9 NIL 1952748) (-729 1946913 1946967 1947059 "MTHING" 1947141 NIL MTHING (NIL T) -7 NIL NIL) (-728 1946705 1946738 1946798 "MSYSCMD" 1946873 T MSYSCMD (NIL) -7 NIL NIL) (-727 1942817 1945460 1945780 "MSET" 1946418 NIL MSET (NIL T) -8 NIL NIL) (-726 1939911 1942377 1942419 "MSETAGG" 1942424 NIL MSETAGG (NIL T) -9 NIL 1942458) (-725 1935760 1937302 1938041 "MRING" 1939217 NIL MRING (NIL T T) -8 NIL NIL) (-724 1935326 1935393 1935524 "MRF2" 1935687 NIL MRF2 (NIL T T T) -7 NIL NIL) (-723 1934944 1934979 1935123 "MRATFAC" 1935285 NIL MRATFAC (NIL T T T T) -7 NIL NIL) (-722 1932556 1932851 1933282 "MPRFF" 1934649 NIL MPRFF (NIL T T T T) -7 NIL NIL) (-721 1926570 1932410 1932507 "MPOLY" 1932512 NIL MPOLY (NIL NIL T) -8 NIL NIL) (-720 1926060 1926095 1926303 "MPCPF" 1926529 NIL MPCPF (NIL T T T T) -7 NIL NIL) (-719 1925574 1925617 1925801 "MPC3" 1926011 NIL MPC3 (NIL T T T T T T T) -7 NIL NIL) (-718 1924769 1924850 1925071 "MPC2" 1925489 NIL MPC2 (NIL T T T T T T T) -7 NIL NIL) (-717 1923070 1923407 1923797 "MONOTOOL" 1924429 NIL MONOTOOL (NIL T T) -7 NIL NIL) (-716 1922193 1922528 1922557 "MONOID" 1922834 T MONOID (NIL) -9 NIL 1923006) (-715 1921571 1921734 1921977 "MONOID-" 1921982 NIL MONOID- (NIL T) -8 NIL NIL) (-714 1912497 1918482 1918542 "MONOGEN" 1919216 NIL MONOGEN (NIL T T) -9 NIL 1919669) (-713 1909715 1910450 1911450 "MONOGEN-" 1911569 NIL MONOGEN- (NIL T T T) -8 NIL NIL) (-712 1908573 1908993 1909022 "MONADWU" 1909414 T MONADWU (NIL) -9 NIL 1909652) (-711 1907945 1908104 1908352 "MONADWU-" 1908357 NIL MONADWU- (NIL T) -8 NIL NIL) (-710 1907329 1907547 1907576 "MONAD" 1907783 T MONAD (NIL) -9 NIL 1907895) (-709 1907014 1907092 1907224 "MONAD-" 1907229 NIL MONAD- (NIL T) -8 NIL NIL) (-708 1905265 1905927 1906206 "MOEBIUS" 1906767 NIL MOEBIUS (NIL T) -8 NIL NIL) (-707 1904656 1905034 1905075 "MODULE" 1905080 NIL MODULE (NIL T) -9 NIL 1905106) (-706 1904224 1904320 1904510 "MODULE-" 1904515 NIL MODULE- (NIL T T) -8 NIL NIL) (-705 1901893 1902588 1902915 "MODRING" 1904048 NIL MODRING (NIL T T NIL NIL NIL) -8 NIL NIL) (-704 1898839 1900004 1900522 "MODOP" 1901425 NIL MODOP (NIL T T) -8 NIL NIL) (-703 1897026 1897478 1897819 "MODMONOM" 1898638 NIL MODMONOM (NIL T T NIL) -8 NIL NIL) (-702 1886691 1895222 1895643 "MODMON" 1896656 NIL MODMON (NIL T T) -8 NIL NIL) (-701 1883817 1885535 1885811 "MODFIELD" 1886566 NIL MODFIELD (NIL T T NIL NIL NIL) -8 NIL NIL) (-700 1882821 1883098 1883288 "MMLFORM" 1883647 T MMLFORM (NIL) -8 NIL NIL) (-699 1882347 1882390 1882569 "MMAP" 1882772 NIL MMAP (NIL T T T T T T) -7 NIL NIL) (-698 1880572 1881349 1881391 "MLO" 1881814 NIL MLO (NIL T) -9 NIL 1882055) (-697 1877939 1878454 1879056 "MLIFT" 1880053 NIL MLIFT (NIL T T T T) -7 NIL NIL) (-696 1877330 1877414 1877568 "MKUCFUNC" 1877850 NIL MKUCFUNC (NIL T T T) -7 NIL NIL) (-695 1876929 1876999 1877122 "MKRECORD" 1877253 NIL MKRECORD (NIL T T) -7 NIL NIL) (-694 1875977 1876138 1876366 "MKFUNC" 1876740 NIL MKFUNC (NIL T) -7 NIL NIL) (-693 1875365 1875469 1875625 "MKFLCFN" 1875860 NIL MKFLCFN (NIL T) -7 NIL NIL) (-692 1874791 1875158 1875247 "MKCHSET" 1875309 NIL MKCHSET (NIL T) -8 NIL NIL) (-691 1874068 1874170 1874355 "MKBCFUNC" 1874684 NIL MKBCFUNC (NIL T T T T) -7 NIL NIL) (-690 1870752 1873622 1873758 "MINT" 1873952 T MINT (NIL) -8 NIL NIL) (-689 1869564 1869807 1870084 "MHROWRED" 1870507 NIL MHROWRED (NIL T) -7 NIL NIL) (-688 1864831 1868005 1868431 "MFLOAT" 1869158 T MFLOAT (NIL) -8 NIL NIL) (-687 1864188 1864264 1864435 "MFINFACT" 1864743 NIL MFINFACT (NIL T T T T) -7 NIL NIL) (-686 1860503 1861351 1862235 "MESH" 1863324 T MESH (NIL) -7 NIL NIL) (-685 1858893 1859205 1859558 "MDDFACT" 1860190 NIL MDDFACT (NIL T) -7 NIL NIL) (-684 1855775 1858086 1858128 "MDAGG" 1858383 NIL MDAGG (NIL T) -9 NIL 1858526) (-683 1845463 1855068 1855275 "MCMPLX" 1855588 T MCMPLX (NIL) -8 NIL NIL) (-682 1844604 1844750 1844950 "MCDEN" 1845312 NIL MCDEN (NIL T T) -7 NIL NIL) (-681 1842494 1842764 1843144 "MCALCFN" 1844334 NIL MCALCFN (NIL T T T T) -7 NIL NIL) (-680 1840106 1840629 1841191 "MATSTOR" 1841965 NIL MATSTOR (NIL T) -7 NIL NIL) (-679 1836020 1839482 1839728 "MATRIX" 1839893 NIL MATRIX (NIL T) -8 NIL NIL) (-678 1831796 1832499 1833232 "MATLIN" 1835380 NIL MATLIN (NIL T T T T) -7 NIL NIL) (-677 1821561 1824782 1824860 "MATCAT" 1829990 NIL MATCAT (NIL T T T) -9 NIL 1831497) (-676 1817760 1818828 1820239 "MATCAT-" 1820244 NIL MATCAT- (NIL T T T T) -8 NIL NIL) (-675 1816354 1816507 1816840 "MATCAT2" 1817595 NIL MATCAT2 (NIL T T T T T T T T) -7 NIL NIL) (-674 1815094 1815360 1815675 "MAPPKG4" 1816085 NIL MAPPKG4 (NIL T T) -7 NIL NIL) (-673 1813206 1813530 1813914 "MAPPKG3" 1814769 NIL MAPPKG3 (NIL T T T) -7 NIL NIL) (-672 1812187 1812360 1812582 "MAPPKG2" 1813030 NIL MAPPKG2 (NIL T T) -7 NIL NIL) (-671 1810686 1810970 1811297 "MAPPKG1" 1811893 NIL MAPPKG1 (NIL T) -7 NIL NIL) (-670 1810297 1810355 1810478 "MAPHACK3" 1810622 NIL MAPHACK3 (NIL T T T) -7 NIL NIL) (-669 1809889 1809950 1810064 "MAPHACK2" 1810229 NIL MAPHACK2 (NIL T T) -7 NIL NIL) (-668 1809327 1809430 1809572 "MAPHACK1" 1809780 NIL MAPHACK1 (NIL T) -7 NIL NIL) (-667 1807433 1808027 1808331 "MAGMA" 1809055 NIL MAGMA (NIL T) -8 NIL NIL) (-666 1803908 1805674 1806134 "M3D" 1807006 NIL M3D (NIL T) -8 NIL NIL) (-665 1798102 1802308 1802350 "LZSTAGG" 1803132 NIL LZSTAGG (NIL T) -9 NIL 1803427) (-664 1794076 1795233 1796690 "LZSTAGG-" 1796695 NIL LZSTAGG- (NIL T T) -8 NIL NIL) (-663 1791190 1791967 1792454 "LWORD" 1793621 NIL LWORD (NIL T) -8 NIL NIL) (-662 1784345 1790961 1791095 "LSQM" 1791100 NIL LSQM (NIL NIL T) -8 NIL NIL) (-661 1783569 1783708 1783936 "LSPP" 1784200 NIL LSPP (NIL T T T T) -7 NIL NIL) (-660 1781381 1781682 1782138 "LSMP" 1783258 NIL LSMP (NIL T T T T) -7 NIL NIL) (-659 1778160 1778834 1779564 "LSMP1" 1780683 NIL LSMP1 (NIL T) -7 NIL NIL) (-658 1772117 1777350 1777392 "LSAGG" 1777454 NIL LSAGG (NIL T) -9 NIL 1777532) (-657 1768812 1769736 1770949 "LSAGG-" 1770954 NIL LSAGG- (NIL T T) -8 NIL NIL) (-656 1766438 1767956 1768205 "LPOLY" 1768607 NIL LPOLY (NIL T T) -8 NIL NIL) (-655 1766020 1766105 1766228 "LPEFRAC" 1766347 NIL LPEFRAC (NIL T) -7 NIL NIL) (-654 1763584 1763833 1764265 "LPARSPT" 1765762 NIL LPARSPT (NIL T NIL T T T T T) -7 NIL NIL) (-653 1762059 1762386 1762746 "LOP" 1763256 NIL LOP (NIL T) -7 NIL NIL) (-652 1760408 1761155 1761407 "LO" 1761892 NIL LO (NIL T T T) -8 NIL NIL) (-651 1760059 1760171 1760200 "LOGIC" 1760311 T LOGIC (NIL) -9 NIL 1760392) (-650 1759921 1759944 1760015 "LOGIC-" 1760020 NIL LOGIC- (NIL T) -8 NIL NIL) (-649 1759114 1759254 1759447 "LODOOPS" 1759777 NIL LODOOPS (NIL T T) -7 NIL NIL) (-648 1756526 1759030 1759096 "LODO" 1759101 NIL LODO (NIL T NIL) -8 NIL NIL) (-647 1755066 1755301 1755653 "LODOF" 1756274 NIL LODOF (NIL T T) -7 NIL NIL) (-646 1751465 1753906 1753948 "LODOCAT" 1754386 NIL LODOCAT (NIL T) -9 NIL 1754596) (-645 1751198 1751256 1751383 "LODOCAT-" 1751388 NIL LODOCAT- (NIL T T) -8 NIL NIL) (-644 1748507 1751039 1751157 "LODO2" 1751162 NIL LODO2 (NIL T T) -8 NIL NIL) (-643 1745931 1748444 1748489 "LODO1" 1748494 NIL LODO1 (NIL T) -8 NIL NIL) (-642 1744791 1744956 1745268 "LODEEF" 1745754 NIL LODEEF (NIL T T T) -7 NIL NIL) (-641 1737618 1741783 1741824 "LOCPOWC" 1743286 NIL LOCPOWC (NIL T) -9 NIL 1743863) (-640 1732942 1735780 1735822 "LNAGG" 1736769 NIL LNAGG (NIL T) -9 NIL 1737212) (-639 1732089 1732303 1732645 "LNAGG-" 1732650 NIL LNAGG- (NIL T T) -8 NIL NIL) (-638 1728252 1729014 1729653 "LMOPS" 1731504 NIL LMOPS (NIL T T NIL) -8 NIL NIL) (-637 1727646 1728008 1728050 "LMODULE" 1728111 NIL LMODULE (NIL T) -9 NIL 1728153) (-636 1724898 1727291 1727414 "LMDICT" 1727556 NIL LMDICT (NIL T) -8 NIL NIL) (-635 1724055 1724189 1724376 "LISYSER" 1724760 NIL LISYSER (NIL T T) -7 NIL NIL) (-634 1717292 1723005 1723301 "LIST" 1723792 NIL LIST (NIL T) -8 NIL NIL) (-633 1716817 1716891 1717030 "LIST3" 1717212 NIL LIST3 (NIL T T T) -7 NIL NIL) (-632 1715824 1716002 1716230 "LIST2" 1716635 NIL LIST2 (NIL T T) -7 NIL NIL) (-631 1713958 1714270 1714669 "LIST2MAP" 1715471 NIL LIST2MAP (NIL T T) -7 NIL NIL) (-630 1712663 1713343 1713385 "LINEXP" 1713640 NIL LINEXP (NIL T) -9 NIL 1713789) (-629 1711310 1711570 1711867 "LINDEP" 1712415 NIL LINDEP (NIL T T) -7 NIL NIL) (-628 1708077 1708796 1709573 "LIMITRF" 1710565 NIL LIMITRF (NIL T) -7 NIL NIL) (-627 1706354 1706648 1707064 "LIMITPS" 1707772 NIL LIMITPS (NIL T T) -7 NIL NIL) (-626 1700813 1705869 1706095 "LIE" 1706177 NIL LIE (NIL T T) -8 NIL NIL) (-625 1699862 1700305 1700346 "LIECAT" 1700486 NIL LIECAT (NIL T) -9 NIL 1700636) (-624 1699703 1699730 1699818 "LIECAT-" 1699823 NIL LIECAT- (NIL T T) -8 NIL NIL) (-623 1692237 1699082 1699265 "LIB" 1699540 T LIB (NIL) -8 NIL NIL) (-622 1687874 1688755 1689690 "LGROBP" 1691354 NIL LGROBP (NIL NIL T) -7 NIL NIL) (-621 1685729 1686003 1686366 "LF" 1687595 NIL LF (NIL T T) -7 NIL NIL) (-620 1684568 1685260 1685289 "LFCAT" 1685496 T LFCAT (NIL) -9 NIL 1685635) (-619 1681472 1682100 1682788 "LEXTRIPK" 1683932 NIL LEXTRIPK (NIL T NIL) -7 NIL NIL) (-618 1678178 1679042 1679545 "LEXP" 1681052 NIL LEXP (NIL T T NIL) -8 NIL NIL) (-617 1676576 1676889 1677290 "LEADCDET" 1677860 NIL LEADCDET (NIL T T T T) -7 NIL NIL) (-616 1675766 1675840 1676069 "LAZM3PK" 1676497 NIL LAZM3PK (NIL T T T T T T) -7 NIL NIL) (-615 1670682 1673849 1674384 "LAUPOL" 1675281 NIL LAUPOL (NIL T T) -8 NIL NIL) (-614 1670247 1670291 1670459 "LAPLACE" 1670632 NIL LAPLACE (NIL T T) -7 NIL NIL) (-613 1668177 1669350 1669600 "LA" 1670081 NIL LA (NIL T T T) -8 NIL NIL) (-612 1667233 1667827 1667869 "LALG" 1667931 NIL LALG (NIL T) -9 NIL 1667990) (-611 1666947 1667006 1667142 "LALG-" 1667147 NIL LALG- (NIL T T) -8 NIL NIL) (-610 1665851 1666038 1666337 "KOVACIC" 1666747 NIL KOVACIC (NIL T T) -7 NIL NIL) (-609 1665685 1665709 1665751 "KONVERT" 1665813 NIL KONVERT (NIL T) -9 NIL NIL) (-608 1665519 1665543 1665585 "KOERCE" 1665647 NIL KOERCE (NIL T) -9 NIL NIL) (-607 1663255 1664015 1664407 "KERNEL" 1665159 NIL KERNEL (NIL T) -8 NIL NIL) (-606 1662757 1662838 1662968 "KERNEL2" 1663169 NIL KERNEL2 (NIL T T) -7 NIL NIL) (-605 1656440 1661122 1661177 "KDAGG" 1661554 NIL KDAGG (NIL T T) -9 NIL 1661760) (-604 1655969 1656093 1656298 "KDAGG-" 1656303 NIL KDAGG- (NIL T T T) -8 NIL NIL) (-603 1649118 1655630 1655785 "KAFILE" 1655847 NIL KAFILE (NIL T) -8 NIL NIL) (-602 1643577 1648633 1648859 "JORDAN" 1648941 NIL JORDAN (NIL T T) -8 NIL NIL) (-601 1639920 1641820 1641875 "IXAGG" 1642804 NIL IXAGG (NIL T T) -9 NIL 1643259) (-600 1638839 1639145 1639564 "IXAGG-" 1639569 NIL IXAGG- (NIL T T T) -8 NIL NIL) (-599 1634423 1638761 1638820 "IVECTOR" 1638825 NIL IVECTOR (NIL T NIL) -8 NIL NIL) (-598 1633189 1633426 1633692 "ITUPLE" 1634190 NIL ITUPLE (NIL T) -8 NIL NIL) (-597 1631613 1631790 1632098 "ITRIGMNP" 1633011 NIL ITRIGMNP (NIL T T T) -7 NIL NIL) (-596 1630358 1630562 1630845 "ITFUN3" 1631389 NIL ITFUN3 (NIL T T T) -7 NIL NIL) (-595 1629990 1630047 1630156 "ITFUN2" 1630295 NIL ITFUN2 (NIL T T) -7 NIL NIL) (-594 1627783 1628854 1629152 "ITAYLOR" 1629725 NIL ITAYLOR (NIL T) -8 NIL NIL) (-593 1616722 1621922 1623084 "ISUPS" 1626654 NIL ISUPS (NIL T) -8 NIL NIL) (-592 1615826 1615966 1616202 "ISUMP" 1616569 NIL ISUMP (NIL T T T T) -7 NIL NIL) (-591 1611096 1615627 1615706 "ISTRING" 1615779 NIL ISTRING (NIL NIL) -8 NIL NIL) (-590 1610306 1610387 1610603 "IRURPK" 1611010 NIL IRURPK (NIL T T T T T) -7 NIL NIL) (-589 1609242 1609443 1609683 "IRSN" 1610086 T IRSN (NIL) -7 NIL NIL) (-588 1607273 1607628 1608063 "IRRF2F" 1608881 NIL IRRF2F (NIL T) -7 NIL NIL) (-587 1607020 1607058 1607134 "IRREDFFX" 1607229 NIL IRREDFFX (NIL T) -7 NIL NIL) (-586 1605635 1605894 1606193 "IROOT" 1606753 NIL IROOT (NIL T) -7 NIL NIL) (-585 1602271 1603323 1604013 "IR" 1604977 NIL IR (NIL T) -8 NIL NIL) (-584 1599884 1600379 1600945 "IR2" 1601749 NIL IR2 (NIL T T) -7 NIL NIL) (-583 1598956 1599069 1599290 "IR2F" 1599767 NIL IR2F (NIL T T) -7 NIL NIL) (-582 1598747 1598781 1598841 "IPRNTPK" 1598916 T IPRNTPK (NIL) -7 NIL NIL) (-581 1595301 1598636 1598705 "IPF" 1598710 NIL IPF (NIL NIL) -8 NIL NIL) (-580 1593618 1595226 1595283 "IPADIC" 1595288 NIL IPADIC (NIL NIL NIL) -8 NIL NIL) (-579 1593115 1593173 1593363 "INVLAPLA" 1593554 NIL INVLAPLA (NIL T T) -7 NIL NIL) (-578 1582764 1585117 1587503 "INTTR" 1590779 NIL INTTR (NIL T T) -7 NIL NIL) (-577 1579122 1579864 1580721 "INTTOOLS" 1581956 NIL INTTOOLS (NIL T T) -7 NIL NIL) (-576 1578708 1578799 1578916 "INTSLPE" 1579025 T INTSLPE (NIL) -7 NIL NIL) (-575 1576658 1578631 1578690 "INTRVL" 1578695 NIL INTRVL (NIL T) -8 NIL NIL) (-574 1574260 1574772 1575347 "INTRF" 1576143 NIL INTRF (NIL T) -7 NIL NIL) (-573 1573671 1573768 1573910 "INTRET" 1574158 NIL INTRET (NIL T) -7 NIL NIL) (-572 1571668 1572057 1572527 "INTRAT" 1573279 NIL INTRAT (NIL T T) -7 NIL NIL) (-571 1568904 1569487 1570109 "INTPM" 1571157 NIL INTPM (NIL T T) -7 NIL NIL) (-570 1565609 1566208 1566952 "INTPAF" 1568291 NIL INTPAF (NIL T T T) -7 NIL NIL) (-569 1560788 1561750 1562801 "INTPACK" 1564578 T INTPACK (NIL) -7 NIL NIL) (-568 1557642 1560517 1560644 "INT" 1560681 T INT (NIL) -8 NIL NIL) (-567 1556894 1557046 1557254 "INTHERTR" 1557484 NIL INTHERTR (NIL T T) -7 NIL NIL) (-566 1556333 1556413 1556601 "INTHERAL" 1556808 NIL INTHERAL (NIL T T T T) -7 NIL NIL) (-565 1554179 1554622 1555079 "INTHEORY" 1555896 T INTHEORY (NIL) -7 NIL NIL) (-564 1545490 1547110 1548888 "INTG0" 1552532 NIL INTG0 (NIL T T T) -7 NIL NIL) (-563 1526063 1530853 1535663 "INTFTBL" 1540700 T INTFTBL (NIL) -8 NIL NIL) (-562 1524100 1524307 1524708 "INTFRSP" 1525853 NIL INTFRSP (NIL T NIL T T T T T T) -7 NIL NIL) (-561 1523349 1523487 1523660 "INTFACT" 1523959 NIL INTFACT (NIL T) -7 NIL NIL) (-560 1522939 1522981 1523132 "INTERGB" 1523301 NIL INTERGB (NIL T NIL T T T) -7 NIL NIL) (-559 1520324 1520770 1521334 "INTEF" 1522493 NIL INTEF (NIL T T) -7 NIL NIL) (-558 1518781 1519530 1519559 "INTDOM" 1519860 T INTDOM (NIL) -9 NIL 1520067) (-557 1518150 1518324 1518566 "INTDOM-" 1518571 NIL INTDOM- (NIL T) -8 NIL NIL) (-556 1516754 1516859 1517249 "INTDIVP" 1518040 NIL INTDIVP (NIL T NIL T T T T T T T T T) -7 NIL NIL) (-555 1513240 1515170 1515225 "INTCAT" 1516024 NIL INTCAT (NIL T) -9 NIL 1516345) (-554 1512713 1512815 1512943 "INTBIT" 1513132 T INTBIT (NIL) -7 NIL NIL) (-553 1511384 1511538 1511852 "INTALG" 1512558 NIL INTALG (NIL T T T T T) -7 NIL NIL) (-552 1510841 1510931 1511101 "INTAF" 1511288 NIL INTAF (NIL T T) -7 NIL NIL) (-551 1504307 1510651 1510791 "INTABL" 1510796 NIL INTABL (NIL T T T) -8 NIL NIL) (-550 1499252 1501978 1502007 "INS" 1502975 T INS (NIL) -9 NIL 1503658) (-549 1496492 1497263 1498237 "INS-" 1498310 NIL INS- (NIL T) -8 NIL NIL) (-548 1495267 1495494 1495792 "INPSIGN" 1496245 NIL INPSIGN (NIL T T) -7 NIL NIL) (-547 1494385 1494502 1494699 "INPRODPF" 1495147 NIL INPRODPF (NIL T T) -7 NIL NIL) (-546 1493279 1493396 1493633 "INPRODFF" 1494265 NIL INPRODFF (NIL T T T T) -7 NIL NIL) (-545 1492279 1492431 1492691 "INNMFACT" 1493115 NIL INNMFACT (NIL T T T T) -7 NIL NIL) (-544 1491476 1491573 1491761 "INMODGCD" 1492178 NIL INMODGCD (NIL T T NIL NIL) -7 NIL NIL) (-543 1489985 1490229 1490553 "INFSP" 1491221 NIL INFSP (NIL T T T) -7 NIL NIL) (-542 1489169 1489286 1489469 "INFPROD0" 1489865 NIL INFPROD0 (NIL T T) -7 NIL NIL) (-541 1486050 1487234 1487749 "INFORM" 1488662 T INFORM (NIL) -8 NIL NIL) (-540 1485660 1485720 1485818 "INFORM1" 1485985 NIL INFORM1 (NIL T) -7 NIL NIL) (-539 1485183 1485272 1485386 "INFINITY" 1485566 T INFINITY (NIL) -7 NIL NIL) (-538 1482866 1483863 1484206 "INFCLSPT" 1485043 NIL INFCLSPT (NIL T NIL T T T T T T T) -8 NIL NIL) (-537 1480743 1481988 1482282 "INFCLSPS" 1482636 NIL INFCLSPS (NIL T NIL T) -8 NIL NIL) (-536 1473293 1474216 1474437 "INFCLCT" 1479868 NIL INFCLCT (NIL T NIL T T T T T T T) -9 NIL 1480679) (-535 1471911 1472159 1472480 "INEP" 1473041 NIL INEP (NIL T T T) -7 NIL NIL) (-534 1471187 1471808 1471873 "INDE" 1471878 NIL INDE (NIL T) -8 NIL NIL) (-533 1470751 1470819 1470936 "INCRMAPS" 1471114 NIL INCRMAPS (NIL T) -7 NIL NIL) (-532 1466062 1466987 1467931 "INBFF" 1469839 NIL INBFF (NIL T) -7 NIL NIL) (-531 1462457 1465906 1466010 "IMATRIX" 1466015 NIL IMATRIX (NIL T NIL NIL) -8 NIL NIL) (-530 1461171 1461294 1461608 "IMATQF" 1462314 NIL IMATQF (NIL T T T T T T T T) -7 NIL NIL) (-529 1459393 1459620 1459956 "IMATLIN" 1460928 NIL IMATLIN (NIL T T T T) -7 NIL NIL) (-528 1454025 1459317 1459375 "ILIST" 1459380 NIL ILIST (NIL T NIL) -8 NIL NIL) (-527 1451984 1453885 1453998 "IIARRAY2" 1454003 NIL IIARRAY2 (NIL T NIL NIL T T) -8 NIL NIL) (-526 1447352 1451895 1451959 "IFF" 1451964 NIL IFF (NIL NIL NIL) -8 NIL NIL) (-525 1442401 1446644 1446832 "IFARRAY" 1447209 NIL IFARRAY (NIL T NIL) -8 NIL NIL) (-524 1441608 1442305 1442378 "IFAMON" 1442383 NIL IFAMON (NIL T T NIL) -8 NIL NIL) (-523 1441191 1441256 1441311 "IEVALAB" 1441518 NIL IEVALAB (NIL T T) -9 NIL NIL) (-522 1440866 1440934 1441094 "IEVALAB-" 1441099 NIL IEVALAB- (NIL T T T) -8 NIL NIL) (-521 1440524 1440780 1440843 "IDPO" 1440848 NIL IDPO (NIL T T) -8 NIL NIL) (-520 1439801 1440413 1440488 "IDPOAMS" 1440493 NIL IDPOAMS (NIL T T) -8 NIL NIL) (-519 1439135 1439690 1439765 "IDPOAM" 1439770 NIL IDPOAM (NIL T T) -8 NIL NIL) (-518 1438219 1438469 1438523 "IDPC" 1438936 NIL IDPC (NIL T T) -9 NIL 1439085) (-517 1437715 1438111 1438184 "IDPAM" 1438189 NIL IDPAM (NIL T T) -8 NIL NIL) (-516 1437118 1437607 1437680 "IDPAG" 1437685 NIL IDPAG (NIL T T) -8 NIL NIL) (-515 1433373 1434221 1435116 "IDECOMP" 1436275 NIL IDECOMP (NIL NIL NIL) -7 NIL NIL) (-514 1426249 1427298 1428344 "IDEAL" 1432410 NIL IDEAL (NIL T T T T) -8 NIL NIL) (-513 1424266 1425413 1425686 "ICP" 1426040 NIL ICP (NIL T NIL T) -8 NIL NIL) (-512 1423430 1423542 1423741 "ICDEN" 1424150 NIL ICDEN (NIL T T T T) -7 NIL NIL) (-511 1422529 1422910 1423057 "ICARD" 1423303 T ICARD (NIL) -8 NIL NIL) (-510 1420589 1420902 1421307 "IBPTOOLS" 1422206 NIL IBPTOOLS (NIL T T T T) -7 NIL NIL) (-509 1416203 1420209 1420322 "IBITS" 1420508 NIL IBITS (NIL NIL) -8 NIL NIL) (-508 1412926 1413502 1414197 "IBATOOL" 1415620 NIL IBATOOL (NIL T T T) -7 NIL NIL) (-507 1410706 1411167 1411700 "IBACHIN" 1412461 NIL IBACHIN (NIL T T T) -7 NIL NIL) (-506 1408589 1410552 1410655 "IARRAY2" 1410660 NIL IARRAY2 (NIL T NIL NIL) -8 NIL NIL) (-505 1404748 1408515 1408572 "IARRAY1" 1408577 NIL IARRAY1 (NIL T NIL) -8 NIL NIL) (-504 1398678 1403160 1403641 "IAN" 1404287 T IAN (NIL) -8 NIL NIL) (-503 1398189 1398246 1398419 "IALGFACT" 1398615 NIL IALGFACT (NIL T T T T) -7 NIL NIL) (-502 1397716 1397829 1397858 "HYPCAT" 1398065 T HYPCAT (NIL) -9 NIL NIL) (-501 1397254 1397371 1397557 "HYPCAT-" 1397562 NIL HYPCAT- (NIL T) -8 NIL NIL) (-500 1396258 1396535 1396725 "HTMLFORM" 1397084 T HTMLFORM (NIL) -8 NIL NIL) (-499 1393047 1394372 1394414 "HOAGG" 1395395 NIL HOAGG (NIL T) -9 NIL 1396004) (-498 1391641 1392040 1392566 "HOAGG-" 1392571 NIL HOAGG- (NIL T T) -8 NIL NIL) (-497 1385459 1391079 1391246 "HEXADEC" 1391494 T HEXADEC (NIL) -8 NIL NIL) (-496 1384207 1384429 1384692 "HEUGCD" 1385236 NIL HEUGCD (NIL T) -7 NIL NIL) (-495 1383310 1384044 1384174 "HELLFDIV" 1384179 NIL HELLFDIV (NIL T T T T) -8 NIL NIL) (-494 1377027 1378570 1379651 "HEAP" 1382261 NIL HEAP (NIL T) -8 NIL NIL) (-493 1370865 1376942 1377004 "HDP" 1377009 NIL HDP (NIL NIL T) -8 NIL NIL) (-492 1364570 1370500 1370652 "HDMP" 1370766 NIL HDMP (NIL NIL T) -8 NIL NIL) (-491 1363895 1364034 1364198 "HB" 1364426 T HB (NIL) -7 NIL NIL) (-490 1357404 1363741 1363845 "HASHTBL" 1363850 NIL HASHTBL (NIL T T NIL) -8 NIL NIL) (-489 1355151 1357026 1357208 "HACKPI" 1357242 T HACKPI (NIL) -8 NIL NIL) (-488 1337299 1341168 1345171 "GUESSUP" 1351181 NIL GUESSUP (NIL NIL) -7 NIL NIL) (-487 1308396 1315437 1322133 "GUESSP" 1330623 T GUESSP (NIL) -7 NIL NIL) (-486 1275211 1280482 1285866 "GUESS" 1303340 NIL GUESS (NIL T T T T NIL NIL) -7 NIL NIL) (-485 1248716 1255113 1261249 "GUESSINT" 1269095 T GUESSINT (NIL) -7 NIL NIL) (-484 1224087 1229537 1235104 "GUESSF" 1243201 NIL GUESSF (NIL T) -7 NIL NIL) (-483 1223809 1223846 1223941 "GUESSF1" 1224044 NIL GUESSF1 (NIL T) -7 NIL NIL) (-482 1199970 1205504 1211119 "GUESSAN" 1218214 T GUESSAN (NIL) -7 NIL NIL) (-481 1195665 1199823 1199936 "GTSET" 1199941 NIL GTSET (NIL T T T T) -8 NIL NIL) (-480 1189203 1195543 1195641 "GSTBL" 1195646 NIL GSTBL (NIL T T T NIL) -8 NIL NIL) (-479 1181433 1188236 1188500 "GSERIES" 1188995 NIL GSERIES (NIL T NIL NIL) -8 NIL NIL) (-478 1180454 1180907 1180936 "GROUP" 1181197 T GROUP (NIL) -9 NIL 1181356) (-477 1179570 1179793 1180137 "GROUP-" 1180142 NIL GROUP- (NIL T) -8 NIL NIL) (-476 1177939 1178258 1178645 "GROEBSOL" 1179247 NIL GROEBSOL (NIL NIL T T) -7 NIL NIL) (-475 1176878 1177140 1177192 "GRMOD" 1177721 NIL GRMOD (NIL T T) -9 NIL 1177889) (-474 1176646 1176682 1176810 "GRMOD-" 1176815 NIL GRMOD- (NIL T T T) -8 NIL NIL) (-473 1171975 1173000 1174000 "GRIMAGE" 1175666 T GRIMAGE (NIL) -8 NIL NIL) (-472 1170442 1170702 1171026 "GRDEF" 1171671 T GRDEF (NIL) -7 NIL NIL) (-471 1169886 1170002 1170143 "GRAY" 1170321 T GRAY (NIL) -7 NIL NIL) (-470 1169116 1169496 1169548 "GRALG" 1169701 NIL GRALG (NIL T T) -9 NIL 1169794) (-469 1168777 1168850 1169013 "GRALG-" 1169018 NIL GRALG- (NIL T T T) -8 NIL NIL) (-468 1165581 1168362 1168540 "GPOLSET" 1168684 NIL GPOLSET (NIL T T T T) -8 NIL NIL) (-467 1147784 1149274 1150863 "GPAFF" 1164272 NIL GPAFF (NIL T NIL T T T T T T T T T) -7 NIL NIL) (-466 1147138 1147195 1147453 "GOSPER" 1147721 NIL GOSPER (NIL T T T T T) -7 NIL NIL) (-465 1144531 1145125 1145614 "GOPT" 1146669 T GOPT (NIL) -8 NIL NIL) (-464 1141752 1142393 1142930 "GOPT0" 1144014 T GOPT0 (NIL) -8 NIL NIL) (-463 1137511 1138190 1138716 "GMODPOL" 1141451 NIL GMODPOL (NIL NIL T T T NIL T) -8 NIL NIL) (-462 1136516 1136700 1136938 "GHENSEL" 1137323 NIL GHENSEL (NIL T T) -7 NIL NIL) (-461 1130567 1131410 1132437 "GENUPS" 1135600 NIL GENUPS (NIL T T) -7 NIL NIL) (-460 1130264 1130315 1130404 "GENUFACT" 1130510 NIL GENUFACT (NIL T) -7 NIL NIL) (-459 1129676 1129753 1129918 "GENPGCD" 1130182 NIL GENPGCD (NIL T T T T) -7 NIL NIL) (-458 1129150 1129185 1129398 "GENMFACT" 1129635 NIL GENMFACT (NIL T T T T T) -7 NIL NIL) (-457 1127718 1127973 1128280 "GENEEZ" 1128893 NIL GENEEZ (NIL T T) -7 NIL NIL) (-456 1126262 1126539 1126863 "GDRAW" 1127414 T GDRAW (NIL) -7 NIL NIL) (-455 1120129 1125873 1126035 "GDMP" 1126185 NIL GDMP (NIL NIL T T) -8 NIL NIL) (-454 1109513 1113902 1115007 "GCNAALG" 1119113 NIL GCNAALG (NIL T NIL NIL NIL) -8 NIL NIL) (-453 1107930 1108802 1108831 "GCDDOM" 1109086 T GCDDOM (NIL) -9 NIL 1109243) (-452 1107400 1107527 1107742 "GCDDOM-" 1107747 NIL GCDDOM- (NIL T) -8 NIL NIL) (-451 1106074 1106259 1106562 "GB" 1107180 NIL GB (NIL T T T T) -7 NIL NIL) (-450 1094694 1097020 1099412 "GBINTERN" 1103765 NIL GBINTERN (NIL T T T T) -7 NIL NIL) (-449 1092531 1092823 1093244 "GBF" 1094369 NIL GBF (NIL T T T T) -7 NIL NIL) (-448 1091312 1091477 1091744 "GBEUCLID" 1092347 NIL GBEUCLID (NIL T T T T) -7 NIL NIL) (-447 1090661 1090786 1090935 "GAUSSFAC" 1091183 T GAUSSFAC (NIL) -7 NIL NIL) (-446 1089030 1089332 1089645 "GALUTIL" 1090381 NIL GALUTIL (NIL T) -7 NIL NIL) (-445 1087338 1087612 1087936 "GALPOLYU" 1088757 NIL GALPOLYU (NIL T T) -7 NIL NIL) (-444 1084703 1084993 1085400 "GALFACTU" 1087035 NIL GALFACTU (NIL T T T) -7 NIL NIL) (-443 1076509 1078008 1079616 "GALFACT" 1083135 NIL GALFACT (NIL T) -7 NIL NIL) (-442 1073897 1074554 1074583 "FVFUN" 1075739 T FVFUN (NIL) -9 NIL 1076459) (-441 1073163 1073344 1073373 "FVC" 1073664 T FVC (NIL) -9 NIL 1073847) (-440 1072805 1072960 1073041 "FUNCTION" 1073115 NIL FUNCTION (NIL NIL) -8 NIL NIL) (-439 1070475 1071026 1071515 "FT" 1072336 T FT (NIL) -8 NIL NIL) (-438 1069267 1069776 1069979 "FTEM" 1070292 T FTEM (NIL) -8 NIL NIL) (-437 1067525 1067814 1068217 "FSUPFACT" 1068959 NIL FSUPFACT (NIL T T T) -7 NIL NIL) (-436 1065922 1066211 1066543 "FST" 1067213 T FST (NIL) -8 NIL NIL) (-435 1065093 1065199 1065394 "FSRED" 1065804 NIL FSRED (NIL T T) -7 NIL NIL) (-434 1063774 1064029 1064382 "FSPRMELT" 1064809 NIL FSPRMELT (NIL T T) -7 NIL NIL) (-433 1059140 1059845 1060602 "FSPECF" 1063079 NIL FSPECF (NIL T T) -7 NIL NIL) (-432 1041398 1049987 1050028 "FS" 1053876 NIL FS (NIL T) -9 NIL 1056154) (-431 1030048 1033038 1037094 "FS-" 1037391 NIL FS- (NIL T T) -8 NIL NIL) (-430 1029562 1029616 1029793 "FSINT" 1029989 NIL FSINT (NIL T T) -7 NIL NIL) (-429 1027847 1028559 1028860 "FSERIES" 1029343 NIL FSERIES (NIL T T) -8 NIL NIL) (-428 1026861 1026977 1027208 "FSCINT" 1027727 NIL FSCINT (NIL T T) -7 NIL NIL) (-427 1023096 1025806 1025848 "FSAGG" 1026218 NIL FSAGG (NIL T) -9 NIL 1026475) (-426 1020858 1021459 1022255 "FSAGG-" 1022350 NIL FSAGG- (NIL T T) -8 NIL NIL) (-425 1019900 1020043 1020270 "FSAGG2" 1020711 NIL FSAGG2 (NIL T T T T) -7 NIL NIL) (-424 1017555 1017834 1018388 "FS2UPS" 1019618 NIL FS2UPS (NIL T T T T T NIL) -7 NIL NIL) (-423 1017137 1017180 1017335 "FS2" 1017506 NIL FS2 (NIL T T T T) -7 NIL NIL) (-422 1015994 1016165 1016474 "FS2EXPXP" 1016962 NIL FS2EXPXP (NIL T T NIL NIL) -7 NIL NIL) (-421 1015420 1015535 1015687 "FRUTIL" 1015874 NIL FRUTIL (NIL T) -7 NIL NIL) (-420 1006846 1010931 1012281 "FR" 1014102 NIL FR (NIL T) -8 NIL NIL) (-419 1001926 1004564 1004605 "FRNAALG" 1006001 NIL FRNAALG (NIL T) -9 NIL 1006607) (-418 997605 998675 999950 "FRNAALG-" 1000700 NIL FRNAALG- (NIL T T) -8 NIL NIL) (-417 997243 997286 997413 "FRNAAF2" 997556 NIL FRNAAF2 (NIL T T T T) -7 NIL NIL) (-416 995606 996099 996393 "FRMOD" 997056 NIL FRMOD (NIL T T T T NIL) -8 NIL NIL) (-415 993321 993989 994306 "FRIDEAL" 995397 NIL FRIDEAL (NIL T T T T) -8 NIL NIL) (-414 992516 992603 992892 "FRIDEAL2" 993228 NIL FRIDEAL2 (NIL T T T T T T T T) -7 NIL NIL) (-413 991759 992173 992215 "FRETRCT" 992220 NIL FRETRCT (NIL T) -9 NIL 992394) (-412 990871 991102 991453 "FRETRCT-" 991458 NIL FRETRCT- (NIL T T) -8 NIL NIL) (-411 988076 989296 989356 "FRAMALG" 990238 NIL FRAMALG (NIL T T) -9 NIL 990530) (-410 986209 986665 987295 "FRAMALG-" 987518 NIL FRAMALG- (NIL T T T) -8 NIL NIL) (-409 980112 985694 985965 "FRAC" 985970 NIL FRAC (NIL T) -8 NIL NIL) (-408 979748 979805 979912 "FRAC2" 980049 NIL FRAC2 (NIL T T) -7 NIL NIL) (-407 979384 979441 979548 "FR2" 979685 NIL FR2 (NIL T T) -7 NIL NIL) (-406 974006 976915 976944 "FPS" 978063 T FPS (NIL) -9 NIL 978617) (-405 973455 973564 973728 "FPS-" 973874 NIL FPS- (NIL T) -8 NIL NIL) (-404 970851 972548 972577 "FPC" 972802 T FPC (NIL) -9 NIL 972944) (-403 970644 970684 970781 "FPC-" 970786 NIL FPC- (NIL T) -8 NIL NIL) (-402 969523 970133 970175 "FPATMAB" 970180 NIL FPATMAB (NIL T) -9 NIL 970330) (-401 967223 967699 968125 "FPARFRAC" 969160 NIL FPARFRAC (NIL T T) -8 NIL NIL) (-400 962618 963115 963797 "FORTRAN" 966655 NIL FORTRAN (NIL NIL NIL NIL NIL) -8 NIL NIL) (-399 960334 960834 961373 "FORT" 962099 T FORT (NIL) -7 NIL NIL) (-398 958010 958571 958600 "FORTFN" 959660 T FORTFN (NIL) -9 NIL 960284) (-397 957773 957823 957852 "FORTCAT" 957911 T FORTCAT (NIL) -9 NIL 957973) (-396 955833 956316 956715 "FORMULA" 957394 T FORMULA (NIL) -8 NIL NIL) (-395 955621 955651 955720 "FORMULA1" 955797 NIL FORMULA1 (NIL T) -7 NIL NIL) (-394 955144 955196 955369 "FORDER" 955563 NIL FORDER (NIL T T T T) -7 NIL NIL) (-393 954240 954404 954597 "FOP" 954971 T FOP (NIL) -7 NIL NIL) (-392 952848 953520 953694 "FNLA" 954122 NIL FNLA (NIL NIL NIL T) -8 NIL NIL) (-391 951515 951904 951933 "FNCAT" 952505 T FNCAT (NIL) -9 NIL 952798) (-390 951081 951474 951502 "FNAME" 951507 T FNAME (NIL) -8 NIL NIL) (-389 949734 950707 950736 "FMTC" 950741 T FMTC (NIL) -9 NIL 950777) (-388 946052 947259 947887 "FMONOID" 949139 NIL FMONOID (NIL T) -8 NIL NIL) (-387 945273 945796 945944 "FM" 945949 NIL FM (NIL T T) -8 NIL NIL) (-386 942697 943342 943371 "FMFUN" 944515 T FMFUN (NIL) -9 NIL 945223) (-385 941966 942146 942175 "FMC" 942465 T FMC (NIL) -9 NIL 942647) (-384 939178 940012 940067 "FMCAT" 941262 NIL FMCAT (NIL T T) -9 NIL 941756) (-383 938071 938944 939044 "FM1" 939123 NIL FM1 (NIL T T) -8 NIL NIL) (-382 935845 936261 936755 "FLOATRP" 937622 NIL FLOATRP (NIL T) -7 NIL NIL) (-381 929332 933501 934131 "FLOAT" 935235 T FLOAT (NIL) -8 NIL NIL) (-380 926770 927270 927848 "FLOATCP" 928799 NIL FLOATCP (NIL T) -7 NIL NIL) (-379 925555 926403 926445 "FLINEXP" 926450 NIL FLINEXP (NIL T) -9 NIL 926542) (-378 924709 924944 925272 "FLINEXP-" 925277 NIL FLINEXP- (NIL T T) -8 NIL NIL) (-377 923785 923929 924153 "FLASORT" 924561 NIL FLASORT (NIL T T) -7 NIL NIL) (-376 921001 921843 921896 "FLALG" 923123 NIL FLALG (NIL T T) -9 NIL 923590) (-375 914820 918514 918556 "FLAGG" 919818 NIL FLAGG (NIL T) -9 NIL 920466) (-374 913546 913885 914375 "FLAGG-" 914380 NIL FLAGG- (NIL T T) -8 NIL NIL) (-373 912588 912731 912958 "FLAGG2" 913399 NIL FLAGG2 (NIL T T T T) -7 NIL NIL) (-372 909559 910577 910637 "FINRALG" 911765 NIL FINRALG (NIL T T) -9 NIL 912270) (-371 908719 908948 909287 "FINRALG-" 909292 NIL FINRALG- (NIL T T T) -8 NIL NIL) (-370 908124 908337 908366 "FINITE" 908562 T FINITE (NIL) -9 NIL 908669) (-369 900582 902743 902784 "FINAALG" 906451 NIL FINAALG (NIL T) -9 NIL 907903) (-368 895922 896964 898108 "FINAALG-" 899487 NIL FINAALG- (NIL T T) -8 NIL NIL) (-367 895292 895677 895780 "FILE" 895852 NIL FILE (NIL T) -8 NIL NIL) (-366 893832 894169 894224 "FILECAT" 895002 NIL FILECAT (NIL T T) -9 NIL 895242) (-365 891642 893198 893227 "FIELD" 893267 T FIELD (NIL) -9 NIL 893347) (-364 890262 890647 891158 "FIELD-" 891163 NIL FIELD- (NIL T) -8 NIL NIL) (-363 888075 888897 889244 "FGROUP" 889948 NIL FGROUP (NIL T) -8 NIL NIL) (-362 887165 887329 887549 "FGLMICPK" 887907 NIL FGLMICPK (NIL T NIL) -7 NIL NIL) (-361 882967 887090 887147 "FFX" 887152 NIL FFX (NIL T NIL) -8 NIL NIL) (-360 882507 882574 882696 "FFSQFR" 882895 NIL FFSQFR (NIL T T) -7 NIL NIL) (-359 882108 882169 882304 "FFSLPE" 882440 NIL FFSLPE (NIL T T T) -7 NIL NIL) (-358 878104 878880 879676 "FFPOLY" 881344 NIL FFPOLY (NIL T) -7 NIL NIL) (-357 877608 877644 877853 "FFPOLY2" 878062 NIL FFPOLY2 (NIL T T) -7 NIL NIL) (-356 873430 877527 877590 "FFP" 877595 NIL FFP (NIL T NIL) -8 NIL NIL) (-355 868798 873341 873405 "FF" 873410 NIL FF (NIL NIL NIL) -8 NIL NIL) (-354 863894 868141 868331 "FFNBX" 868652 NIL FFNBX (NIL T NIL) -8 NIL NIL) (-353 858804 863029 863287 "FFNBP" 863748 NIL FFNBP (NIL T NIL) -8 NIL NIL) (-352 853407 858088 858299 "FFNB" 858637 NIL FFNB (NIL NIL NIL) -8 NIL NIL) (-351 852239 852437 852752 "FFINTBAS" 853204 NIL FFINTBAS (NIL T T T) -7 NIL NIL) (-350 848415 850650 850679 "FFIELDC" 851299 T FFIELDC (NIL) -9 NIL 851675) (-349 847078 847448 847945 "FFIELDC-" 847950 NIL FFIELDC- (NIL T) -8 NIL NIL) (-348 846648 846693 846817 "FFHOM" 847020 NIL FFHOM (NIL T T T) -7 NIL NIL) (-347 844346 844830 845347 "FFF" 846163 NIL FFF (NIL T) -7 NIL NIL) (-346 840042 840807 841651 "FFFG" 843570 NIL FFFG (NIL T T) -7 NIL NIL) (-345 838768 838977 839299 "FFFGF" 839820 NIL FFFGF (NIL T T T) -7 NIL NIL) (-344 837519 837716 837964 "FFFACTSE" 838570 NIL FFFACTSE (NIL T T) -7 NIL NIL) (-343 833107 837261 837362 "FFCGX" 837462 NIL FFCGX (NIL T NIL) -8 NIL NIL) (-342 828709 832839 832946 "FFCGP" 833050 NIL FFCGP (NIL T NIL) -8 NIL NIL) (-341 823862 828436 828544 "FFCG" 828645 NIL FFCG (NIL NIL NIL) -8 NIL NIL) (-340 805651 814773 814860 "FFCAT" 820025 NIL FFCAT (NIL T T T) -9 NIL 821510) (-339 800849 801896 803210 "FFCAT-" 804440 NIL FFCAT- (NIL T T T T) -8 NIL NIL) (-338 800260 800303 800538 "FFCAT2" 800800 NIL FFCAT2 (NIL T T T T T T T T) -7 NIL NIL) (-337 789430 793236 794454 "FEXPR" 799114 NIL FEXPR (NIL NIL NIL T) -8 NIL NIL) (-336 788432 788867 788909 "FEVALAB" 788993 NIL FEVALAB (NIL T) -9 NIL 789251) (-335 787591 787801 788139 "FEVALAB-" 788144 NIL FEVALAB- (NIL T T) -8 NIL NIL) (-334 786184 786974 787177 "FDIV" 787490 NIL FDIV (NIL T T T T) -8 NIL NIL) (-333 783249 783964 784080 "FDIVCAT" 785648 NIL FDIVCAT (NIL T T T T) -9 NIL 786085) (-332 783011 783038 783208 "FDIVCAT-" 783213 NIL FDIVCAT- (NIL T T T T T) -8 NIL NIL) (-331 782231 782318 782595 "FDIV2" 782918 NIL FDIV2 (NIL T T T T T T T T) -7 NIL NIL) (-330 780917 781176 781465 "FCPAK1" 781962 T FCPAK1 (NIL) -7 NIL NIL) (-329 780045 780417 780558 "FCOMP" 780808 NIL FCOMP (NIL T) -8 NIL NIL) (-328 763673 767088 770651 "FC" 776502 T FC (NIL) -8 NIL NIL) (-327 756217 760260 760301 "FAXF" 762103 NIL FAXF (NIL T) -9 NIL 762794) (-326 753497 754151 754976 "FAXF-" 755441 NIL FAXF- (NIL T T) -8 NIL NIL) (-325 748603 752873 753049 "FARRAY" 753354 NIL FARRAY (NIL T) -8 NIL NIL) (-324 743921 745997 746051 "FAMR" 747074 NIL FAMR (NIL T T) -9 NIL 747531) (-323 742811 743113 743548 "FAMR-" 743553 NIL FAMR- (NIL T T T) -8 NIL NIL) (-322 742399 742442 742593 "FAMR2" 742762 NIL FAMR2 (NIL T T T T T) -7 NIL NIL) (-321 741595 742321 742374 "FAMONOID" 742379 NIL FAMONOID (NIL T) -8 NIL NIL) (-320 739425 740109 740163 "FAMONC" 741104 NIL FAMONC (NIL T T) -9 NIL 741489) (-319 738119 739181 739317 "FAGROUP" 739322 NIL FAGROUP (NIL T) -8 NIL NIL) (-318 735914 736233 736636 "FACUTIL" 737800 NIL FACUTIL (NIL T T T T) -7 NIL NIL) (-317 735330 735439 735585 "FACTRN" 735800 NIL FACTRN (NIL T) -7 NIL NIL) (-316 734429 734614 734836 "FACTFUNC" 735140 NIL FACTFUNC (NIL T) -7 NIL NIL) (-315 733845 733954 734100 "FACTEXT" 734315 NIL FACTEXT (NIL T) -7 NIL NIL) (-314 726165 733096 733308 "EXPUPXS" 733701 NIL EXPUPXS (NIL T NIL NIL) -8 NIL NIL) (-313 723648 724188 724774 "EXPRTUBE" 725599 T EXPRTUBE (NIL) -7 NIL NIL) (-312 722819 722914 723134 "EXPRSOL" 723548 NIL EXPRSOL (NIL T T T T) -7 NIL NIL) (-311 719013 719605 720342 "EXPRODE" 722158 NIL EXPRODE (NIL T T) -7 NIL NIL) (-310 704114 717674 718099 "EXPR" 718620 NIL EXPR (NIL T) -8 NIL NIL) (-309 698521 699108 699921 "EXPR2UPS" 703412 NIL EXPR2UPS (NIL T T) -7 NIL NIL) (-308 698157 698214 698321 "EXPR2" 698458 NIL EXPR2 (NIL T T) -7 NIL NIL) (-307 689497 697289 697586 "EXPEXPAN" 697994 NIL EXPEXPAN (NIL T T NIL NIL) -8 NIL NIL) (-306 689209 689260 689337 "EXP3D" 689440 T EXP3D (NIL) -7 NIL NIL) (-305 689036 689166 689195 "EXIT" 689200 T EXIT (NIL) -8 NIL NIL) (-304 688663 688725 688838 "EVALCYC" 688968 NIL EVALCYC (NIL T) -7 NIL NIL) (-303 688205 688321 688363 "EVALAB" 688533 NIL EVALAB (NIL T) -9 NIL 688637) (-302 687686 687808 688029 "EVALAB-" 688034 NIL EVALAB- (NIL T T) -8 NIL NIL) (-301 685144 686456 686485 "EUCDOM" 687040 T EUCDOM (NIL) -9 NIL 687390) (-300 683549 683991 684581 "EUCDOM-" 684586 NIL EUCDOM- (NIL T) -8 NIL NIL) (-299 671089 673847 676597 "ESTOOLS" 680819 T ESTOOLS (NIL) -7 NIL NIL) (-298 670721 670778 670887 "ESTOOLS2" 671026 NIL ESTOOLS2 (NIL T T) -7 NIL NIL) (-297 670472 670514 670594 "ESTOOLS1" 670673 NIL ESTOOLS1 (NIL T) -7 NIL NIL) (-296 664398 666126 666155 "ES" 668923 T ES (NIL) -9 NIL 670330) (-295 659346 660632 662449 "ES-" 662613 NIL ES- (NIL T) -8 NIL NIL) (-294 655721 656481 657261 "ESCONT" 658586 T ESCONT (NIL) -7 NIL NIL) (-293 655466 655498 655580 "ESCONT1" 655683 NIL ESCONT1 (NIL NIL NIL) -7 NIL NIL) (-292 655141 655191 655291 "ES2" 655410 NIL ES2 (NIL T T) -7 NIL NIL) (-291 654771 654829 654938 "ES1" 655077 NIL ES1 (NIL T T) -7 NIL NIL) (-290 653987 654116 654292 "ERROR" 654615 T ERROR (NIL) -7 NIL NIL) (-289 647502 653846 653937 "EQTBL" 653942 NIL EQTBL (NIL T T) -8 NIL NIL) (-288 639961 642844 644279 "EQ" 646100 NIL -2993 (NIL T) -8 NIL NIL) (-287 639593 639650 639759 "EQ2" 639898 NIL EQ2 (NIL T T) -7 NIL NIL) (-286 634885 635931 637024 "EP" 638532 NIL EP (NIL T) -7 NIL NIL) (-285 634039 634603 634632 "ENTIRER" 634637 T ENTIRER (NIL) -9 NIL 634683) (-284 630495 631994 632364 "EMR" 633838 NIL EMR (NIL T T T NIL NIL NIL) -8 NIL NIL) (-283 629641 629824 629879 "ELTAGG" 630259 NIL ELTAGG (NIL T T) -9 NIL 630469) (-282 629360 629422 629563 "ELTAGG-" 629568 NIL ELTAGG- (NIL T T T) -8 NIL NIL) (-281 629148 629177 629232 "ELTAB" 629316 NIL ELTAB (NIL T T) -9 NIL NIL) (-280 628274 628420 628619 "ELFUTS" 628999 NIL ELFUTS (NIL T T) -7 NIL NIL) (-279 628015 628071 628100 "ELEMFUN" 628205 T ELEMFUN (NIL) -9 NIL NIL) (-278 627885 627906 627974 "ELEMFUN-" 627979 NIL ELEMFUN- (NIL T) -8 NIL NIL) (-277 622815 626018 626060 "ELAGG" 627000 NIL ELAGG (NIL T) -9 NIL 627461) (-276 621100 621534 622197 "ELAGG-" 622202 NIL ELAGG- (NIL T T) -8 NIL NIL) (-275 613970 615769 616595 "EFUPXS" 620377 NIL EFUPXS (NIL T T T T) -8 NIL NIL) (-274 607422 609223 610032 "EFULS" 613247 NIL EFULS (NIL T T T) -8 NIL NIL) (-273 604844 605202 605681 "EFSTRUC" 607054 NIL EFSTRUC (NIL T T) -7 NIL NIL) (-272 593856 595421 596982 "EF" 603359 NIL EF (NIL T T) -7 NIL NIL) (-271 592957 593341 593490 "EAB" 593727 T EAB (NIL) -8 NIL NIL) (-270 592166 592916 592944 "E04UCFA" 592949 T E04UCFA (NIL) -8 NIL NIL) (-269 591375 592125 592153 "E04NAFA" 592158 T E04NAFA (NIL) -8 NIL NIL) (-268 590584 591334 591362 "E04MBFA" 591367 T E04MBFA (NIL) -8 NIL NIL) (-267 589793 590543 590571 "E04JAFA" 590576 T E04JAFA (NIL) -8 NIL NIL) (-266 589004 589752 589780 "E04GCFA" 589785 T E04GCFA (NIL) -8 NIL NIL) (-265 588215 588963 588991 "E04FDFA" 588996 T E04FDFA (NIL) -8 NIL NIL) (-264 587424 588174 588202 "E04DGFA" 588207 T E04DGFA (NIL) -8 NIL NIL) (-263 581603 582949 584313 "E04AGNT" 586080 T E04AGNT (NIL) -7 NIL NIL) (-262 580326 580806 580847 "DVARCAT" 581322 NIL DVARCAT (NIL T) -9 NIL 581521) (-261 579530 579742 580056 "DVARCAT-" 580061 NIL DVARCAT- (NIL T T) -8 NIL NIL) (-260 572499 572981 573730 "DTP" 579061 NIL DTP (NIL T NIL T T T T T T T T T) -7 NIL NIL) (-259 569948 571921 572078 "DSTREE" 572375 NIL DSTREE (NIL T) -8 NIL NIL) (-258 567417 569262 569304 "DSTRCAT" 569523 NIL DSTRCAT (NIL T) -9 NIL 569657) (-257 560271 567216 567345 "DSMP" 567350 NIL DSMP (NIL T T T) -8 NIL NIL) (-256 555081 556216 557284 "DROPT" 559223 T DROPT (NIL) -8 NIL NIL) (-255 554746 554805 554903 "DROPT1" 555016 NIL DROPT1 (NIL T) -7 NIL NIL) (-254 549861 550987 552124 "DROPT0" 553629 T DROPT0 (NIL) -7 NIL NIL) (-253 548206 548531 548917 "DRAWPT" 549495 T DRAWPT (NIL) -7 NIL NIL) (-252 542793 543716 544795 "DRAW" 547180 NIL DRAW (NIL T) -7 NIL NIL) (-251 542426 542479 542597 "DRAWHACK" 542734 NIL DRAWHACK (NIL T) -7 NIL NIL) (-250 541157 541426 541717 "DRAWCX" 542155 T DRAWCX (NIL) -7 NIL NIL) (-249 540673 540741 540892 "DRAWCURV" 541083 NIL DRAWCURV (NIL T T) -7 NIL NIL) (-248 531145 533103 535218 "DRAWCFUN" 538578 T DRAWCFUN (NIL) -7 NIL NIL) (-247 527998 529874 529916 "DQAGG" 530545 NIL DQAGG (NIL T) -9 NIL 530818) (-246 516426 523167 523251 "DPOLCAT" 525103 NIL DPOLCAT (NIL T T T T) -9 NIL 525647) (-245 511265 512611 514569 "DPOLCAT-" 514574 NIL DPOLCAT- (NIL T T T T T) -8 NIL NIL) (-244 504004 511126 511224 "DPMO" 511229 NIL DPMO (NIL NIL T T) -8 NIL NIL) (-243 496646 503784 503951 "DPMM" 503956 NIL DPMM (NIL NIL T T T) -8 NIL NIL) (-242 490351 496281 496433 "DMP" 496547 NIL DMP (NIL NIL T) -8 NIL NIL) (-241 489951 490007 490151 "DLP" 490289 NIL DLP (NIL T) -7 NIL NIL) (-240 483601 489052 489279 "DLIST" 489756 NIL DLIST (NIL T) -8 NIL NIL) (-239 480486 482489 482531 "DLAGG" 483081 NIL DLAGG (NIL T) -9 NIL 483310) (-238 479143 479835 479864 "DIVRING" 480014 T DIVRING (NIL) -9 NIL 480122) (-237 478131 478384 478777 "DIVRING-" 478782 NIL DIVRING- (NIL T) -8 NIL NIL) (-236 476559 477724 477860 "DIV" 478028 NIL DIV (NIL T) -8 NIL NIL) (-235 474053 475121 475163 "DIVCAT" 475997 NIL DIVCAT (NIL T) -9 NIL 476328) (-234 472155 472512 472918 "DISPLAY" 473667 T DISPLAY (NIL) -7 NIL NIL) (-233 469648 470861 471243 "DIRRING" 471806 NIL DIRRING (NIL T) -8 NIL NIL) (-232 463508 469562 469625 "DIRPROD" 469630 NIL DIRPROD (NIL NIL T) -8 NIL NIL) (-231 462356 462559 462824 "DIRPROD2" 463301 NIL DIRPROD2 (NIL NIL T T) -7 NIL NIL) (-230 451920 457949 458003 "DIRPCAT" 458261 NIL DIRPCAT (NIL NIL T) -9 NIL 459105) (-229 449246 449888 450769 "DIRPCAT-" 451106 NIL DIRPCAT- (NIL T NIL T) -8 NIL NIL) (-228 448533 448693 448879 "DIOSP" 449080 T DIOSP (NIL) -7 NIL NIL) (-227 445276 447480 447522 "DIOPS" 447956 NIL DIOPS (NIL T) -9 NIL 448184) (-226 444825 444939 445130 "DIOPS-" 445135 NIL DIOPS- (NIL T T) -8 NIL NIL) (-225 443692 444330 444359 "DIFRING" 444546 T DIFRING (NIL) -9 NIL 444656) (-224 443338 443415 443567 "DIFRING-" 443572 NIL DIFRING- (NIL T) -8 NIL NIL) (-223 441120 442402 442444 "DIFEXT" 442807 NIL DIFEXT (NIL T) -9 NIL 443099) (-222 439405 439833 440499 "DIFEXT-" 440504 NIL DIFEXT- (NIL T T) -8 NIL NIL) (-221 436767 438971 439013 "DIAGG" 439018 NIL DIAGG (NIL T) -9 NIL 439038) (-220 436151 436308 436560 "DIAGG-" 436565 NIL DIAGG- (NIL T T) -8 NIL NIL) (-219 431521 435110 435387 "DHMATRIX" 435920 NIL DHMATRIX (NIL T) -8 NIL NIL) (-218 426732 431335 431409 "DFVEC" 431467 T DFVEC (NIL) -8 NIL NIL) (-217 420616 421905 423286 "DFSFUN" 425371 T DFSFUN (NIL) -7 NIL NIL) (-216 416877 420387 420481 "DFMAT" 420542 T DFMAT (NIL) -8 NIL NIL) (-215 411154 415331 415764 "DFLOAT" 416464 T DFLOAT (NIL) -8 NIL NIL) (-214 409382 409663 410059 "DFINTTLS" 410862 NIL DFINTTLS (NIL T T) -7 NIL NIL) (-213 406401 407403 407803 "DERHAM" 409048 NIL DERHAM (NIL T NIL) -8 NIL NIL) (-212 398014 399931 401366 "DEQUEUE" 404999 NIL DEQUEUE (NIL T) -8 NIL NIL) (-211 397229 397362 397558 "DEGRED" 397876 NIL DEGRED (NIL T T) -7 NIL NIL) (-210 393624 394369 395222 "DEFINTRF" 396457 NIL DEFINTRF (NIL T) -7 NIL NIL) (-209 391151 391620 392219 "DEFINTEF" 393143 NIL DEFINTEF (NIL T T) -7 NIL NIL) (-208 384969 390589 390756 "DECIMAL" 391004 T DECIMAL (NIL) -8 NIL NIL) (-207 382481 382939 383445 "DDFACT" 384513 NIL DDFACT (NIL T T) -7 NIL NIL) (-206 382077 382120 382271 "DBLRESP" 382432 NIL DBLRESP (NIL T T T T) -7 NIL NIL) (-205 379787 380121 380490 "DBASE" 381835 NIL DBASE (NIL T) -8 NIL NIL) (-204 378920 379746 379774 "D03FAFA" 379779 T D03FAFA (NIL) -8 NIL NIL) (-203 378054 378879 378907 "D03EEFA" 378912 T D03EEFA (NIL) -8 NIL NIL) (-202 376004 376470 376959 "D03AGNT" 377585 T D03AGNT (NIL) -7 NIL NIL) (-201 375320 375963 375991 "D02EJFA" 375996 T D02EJFA (NIL) -8 NIL NIL) (-200 374636 375279 375307 "D02CJFA" 375312 T D02CJFA (NIL) -8 NIL NIL) (-199 373952 374595 374623 "D02BHFA" 374628 T D02BHFA (NIL) -8 NIL NIL) (-198 373268 373911 373939 "D02BBFA" 373944 T D02BBFA (NIL) -8 NIL NIL) (-197 366467 368054 369660 "D02AGNT" 371682 T D02AGNT (NIL) -7 NIL NIL) (-196 364236 364758 365304 "D01WGTS" 365941 T D01WGTS (NIL) -7 NIL NIL) (-195 363331 364195 364223 "D01TRNS" 364228 T D01TRNS (NIL) -8 NIL NIL) (-194 362426 363290 363318 "D01GBFA" 363323 T D01GBFA (NIL) -8 NIL NIL) (-193 361521 362385 362413 "D01FCFA" 362418 T D01FCFA (NIL) -8 NIL NIL) (-192 360616 361480 361508 "D01ASFA" 361513 T D01ASFA (NIL) -8 NIL NIL) (-191 359711 360575 360603 "D01AQFA" 360608 T D01AQFA (NIL) -8 NIL NIL) (-190 358806 359670 359698 "D01APFA" 359703 T D01APFA (NIL) -8 NIL NIL) (-189 357901 358765 358793 "D01ANFA" 358798 T D01ANFA (NIL) -8 NIL NIL) (-188 356996 357860 357888 "D01AMFA" 357893 T D01AMFA (NIL) -8 NIL NIL) (-187 356091 356955 356983 "D01ALFA" 356988 T D01ALFA (NIL) -8 NIL NIL) (-186 355186 356050 356078 "D01AKFA" 356083 T D01AKFA (NIL) -8 NIL NIL) (-185 354281 355145 355173 "D01AJFA" 355178 T D01AJFA (NIL) -8 NIL NIL) (-184 347578 349129 350690 "D01AGNT" 352740 T D01AGNT (NIL) -7 NIL NIL) (-183 346915 347043 347195 "CYCLOTOM" 347446 T CYCLOTOM (NIL) -7 NIL NIL) (-182 343650 344363 345090 "CYCLES" 346208 T CYCLES (NIL) -7 NIL NIL) (-181 342962 343096 343267 "CVMP" 343511 NIL CVMP (NIL T) -7 NIL NIL) (-180 340734 340991 341367 "CTRIGMNP" 342690 NIL CTRIGMNP (NIL T T) -7 NIL NIL) (-179 340108 340207 340360 "CSTTOOLS" 340631 NIL CSTTOOLS (NIL T T) -7 NIL NIL) (-178 335907 336564 337322 "CRFP" 339420 NIL CRFP (NIL T T) -7 NIL NIL) (-177 334954 335139 335367 "CRAPACK" 335711 NIL CRAPACK (NIL T) -7 NIL NIL) (-176 334340 334441 334644 "CPMATCH" 334831 NIL CPMATCH (NIL T T T) -7 NIL NIL) (-175 334065 334093 334199 "CPIMA" 334306 NIL CPIMA (NIL T T T) -7 NIL NIL) (-174 330413 331085 331804 "COORDSYS" 333400 NIL COORDSYS (NIL T) -7 NIL NIL) (-173 326274 328416 328908 "CONTFRAC" 329953 NIL CONTFRAC (NIL T) -8 NIL NIL) (-172 325422 325986 326015 "COMRING" 326020 T COMRING (NIL) -9 NIL 326072) (-171 324503 324780 324964 "COMPPROP" 325258 T COMPPROP (NIL) -8 NIL NIL) (-170 324164 324199 324327 "COMPLPAT" 324462 NIL COMPLPAT (NIL T T T) -7 NIL NIL) (-169 314135 323975 324083 "COMPLEX" 324088 NIL COMPLEX (NIL T) -8 NIL NIL) (-168 313771 313828 313935 "COMPLEX2" 314072 NIL COMPLEX2 (NIL T T) -7 NIL NIL) (-167 313489 313524 313622 "COMPFACT" 313730 NIL COMPFACT (NIL T T) -7 NIL NIL) (-166 297741 308041 308082 "COMPCAT" 309086 NIL COMPCAT (NIL T) -9 NIL 310467) (-165 287257 290180 293807 "COMPCAT-" 294163 NIL COMPCAT- (NIL T T) -8 NIL NIL) (-164 286986 287014 287117 "COMMUPC" 287223 NIL COMMUPC (NIL T T T) -7 NIL NIL) (-163 286781 286814 286873 "COMMONOP" 286947 T COMMONOP (NIL) -7 NIL NIL) (-162 286364 286532 286619 "COMM" 286714 T COMM (NIL) -8 NIL NIL) (-161 285612 285806 285835 "COMBOPC" 286173 T COMBOPC (NIL) -9 NIL 286348) (-160 284508 284718 284960 "COMBINAT" 285402 NIL COMBINAT (NIL T) -7 NIL NIL) (-159 280706 281279 281919 "COMBF" 283930 NIL COMBF (NIL T T) -7 NIL NIL) (-158 279492 279822 280057 "COLOR" 280491 T COLOR (NIL) -8 NIL NIL) (-157 279132 279179 279304 "CMPLXRT" 279439 NIL CMPLXRT (NIL T T) -7 NIL NIL) (-156 274634 275662 276742 "CLIP" 278072 T CLIP (NIL) -7 NIL NIL) (-155 272970 273740 273979 "CLIF" 274461 NIL CLIF (NIL NIL T NIL) -8 NIL NIL) (-154 269235 271153 271195 "CLAGG" 272124 NIL CLAGG (NIL T) -9 NIL 272657) (-153 267657 268114 268697 "CLAGG-" 268702 NIL CLAGG- (NIL T T) -8 NIL NIL) (-152 267201 267286 267426 "CINTSLPE" 267566 NIL CINTSLPE (NIL T T) -7 NIL NIL) (-151 264702 265173 265721 "CHVAR" 266729 NIL CHVAR (NIL T T T) -7 NIL NIL) (-150 263920 264484 264513 "CHARZ" 264518 T CHARZ (NIL) -9 NIL 264533) (-149 263674 263714 263792 "CHARPOL" 263874 NIL CHARPOL (NIL T) -7 NIL NIL) (-148 262776 263373 263402 "CHARNZ" 263449 T CHARNZ (NIL) -9 NIL 263505) (-147 260799 261466 261801 "CHAR" 262461 T CHAR (NIL) -8 NIL NIL) (-146 260524 260585 260614 "CFCAT" 260725 T CFCAT (NIL) -9 NIL NIL) (-145 254657 260181 260299 "CDFVEC" 260426 T CDFVEC (NIL) -8 NIL NIL) (-144 250372 254414 254515 "CDFMAT" 254576 T CDFMAT (NIL) -8 NIL NIL) (-143 249617 249728 249910 "CDEN" 250256 NIL CDEN (NIL T T T) -7 NIL NIL) (-142 245609 248770 249050 "CCLASS" 249357 T CCLASS (NIL) -8 NIL NIL) (-141 240662 241638 242391 "CARTEN" 244912 NIL CARTEN (NIL NIL NIL T) -8 NIL NIL) (-140 239770 239918 240139 "CARTEN2" 240509 NIL CARTEN2 (NIL NIL NIL T T) -7 NIL NIL) (-139 238065 238920 239177 "CARD" 239533 T CARD (NIL) -8 NIL NIL) (-138 237436 237764 237793 "CACHSET" 237925 T CACHSET (NIL) -9 NIL 238002) (-137 236931 237227 237256 "CABMON" 237306 T CABMON (NIL) -9 NIL 237362) (-136 234494 236623 236730 "BTREE" 236857 NIL BTREE (NIL T) -8 NIL NIL) (-135 231998 234142 234264 "BTOURN" 234404 NIL BTOURN (NIL T) -8 NIL NIL) (-134 229455 231502 231544 "BTCAT" 231612 NIL BTCAT (NIL T) -9 NIL 231689) (-133 229122 229202 229351 "BTCAT-" 229356 NIL BTCAT- (NIL T T) -8 NIL NIL) (-132 224312 228182 228211 "BTAGG" 228467 T BTAGG (NIL) -9 NIL 228646) (-131 223735 223879 224109 "BTAGG-" 224114 NIL BTAGG- (NIL T) -8 NIL NIL) (-130 220785 223013 223228 "BSTREE" 223552 NIL BSTREE (NIL T) -8 NIL NIL) (-129 219923 220049 220233 "BRILL" 220641 NIL BRILL (NIL T) -7 NIL NIL) (-128 216663 218684 218726 "BRAGG" 219375 NIL BRAGG (NIL T) -9 NIL 219632) (-127 215192 215598 216153 "BRAGG-" 216158 NIL BRAGG- (NIL T T) -8 NIL NIL) (-126 208391 214538 214722 "BPADICRT" 215040 NIL BPADICRT (NIL NIL) -8 NIL NIL) (-125 206695 208328 208373 "BPADIC" 208378 NIL BPADIC (NIL NIL) -8 NIL NIL) (-124 206393 206423 206537 "BOUNDZRO" 206659 NIL BOUNDZRO (NIL T T) -7 NIL NIL) (-123 201908 202999 203866 "BOP" 205546 T BOP (NIL) -8 NIL NIL) (-122 199531 199975 200494 "BOP1" 201422 NIL BOP1 (NIL T) -7 NIL NIL) (-121 197884 198574 198868 "BOOLEAN" 199257 T BOOLEAN (NIL) -8 NIL NIL) (-120 197245 197623 197678 "BMODULE" 197683 NIL BMODULE (NIL T T) -9 NIL 197748) (-119 193588 194258 195044 "BLUPPACK" 196577 NIL BLUPPACK (NIL T NIL T T T) -7 NIL NIL) (-118 192980 193465 193534 "BLQT" 193539 T BLQT (NIL) -8 NIL NIL) (-117 191409 191884 191913 "BLMETCT" 192558 T BLMETCT (NIL) -9 NIL 192930) (-116 190808 191290 191357 "BLHN" 191362 T BLHN (NIL) -8 NIL NIL) (-115 189626 189885 190168 "BLAS1" 190545 T BLAS1 (NIL) -7 NIL NIL) (-114 185436 189424 189497 "BITS" 189573 T BITS (NIL) -8 NIL NIL) (-113 184507 184968 185120 "BINFILE" 185304 T BINFILE (NIL) -8 NIL NIL) (-112 178329 183948 184114 "BINARY" 184361 T BINARY (NIL) -8 NIL NIL) (-111 176196 177618 177660 "BGAGG" 177920 NIL BGAGG (NIL T) -9 NIL 178057) (-110 176027 176059 176150 "BGAGG-" 176155 NIL BGAGG- (NIL T T) -8 NIL NIL) (-109 175125 175411 175616 "BFUNCT" 175842 T BFUNCT (NIL) -8 NIL NIL) (-108 173817 173995 174282 "BEZOUT" 174950 NIL BEZOUT (NIL T T T T T) -7 NIL NIL) (-107 172780 173002 173261 "BEZIER" 173591 NIL BEZIER (NIL T) -7 NIL NIL) (-106 169303 171632 171962 "BBTREE" 172483 NIL BBTREE (NIL T) -8 NIL NIL) (-105 169036 169089 169118 "BASTYPE" 169237 T BASTYPE (NIL) -9 NIL NIL) (-104 168889 168917 168990 "BASTYPE-" 168995 NIL BASTYPE- (NIL T) -8 NIL NIL) (-103 168323 168399 168551 "BALFACT" 168800 NIL BALFACT (NIL T T) -7 NIL NIL) (-102 167687 167810 167958 "AXSERV" 168195 T AXSERV (NIL) -7 NIL NIL) (-101 166500 167097 167285 "AUTOMOR" 167532 NIL AUTOMOR (NIL T) -8 NIL NIL) (-100 166212 166217 166246 "ATTREG" 166251 T ATTREG (NIL) -9 NIL NIL) (-99 164491 164909 165261 "ATTRBUT" 165878 T ATTRBUT (NIL) -8 NIL NIL) (-98 164026 164139 164166 "ATRIG" 164367 T ATRIG (NIL) -9 NIL NIL) (-97 163835 163876 163963 "ATRIG-" 163968 NIL ATRIG- (NIL T) -8 NIL NIL) (-96 157395 158964 160075 "ASTACK" 162755 NIL ASTACK (NIL T) -8 NIL NIL) (-95 155902 156199 156563 "ASSOCEQ" 157078 NIL ASSOCEQ (NIL T T) -7 NIL NIL) (-94 154934 155561 155685 "ASP9" 155809 NIL ASP9 (NIL NIL) -8 NIL NIL) (-93 154698 154882 154921 "ASP8" 154926 NIL ASP8 (NIL NIL) -8 NIL NIL) (-92 153568 154303 154445 "ASP80" 154587 NIL ASP80 (NIL NIL) -8 NIL NIL) (-91 152467 153203 153335 "ASP7" 153467 NIL ASP7 (NIL NIL) -8 NIL NIL) (-90 151423 152144 152262 "ASP78" 152380 NIL ASP78 (NIL NIL) -8 NIL NIL) (-89 150394 151103 151220 "ASP77" 151337 NIL ASP77 (NIL NIL) -8 NIL NIL) (-88 149309 150032 150163 "ASP74" 150294 NIL ASP74 (NIL NIL) -8 NIL NIL) (-87 148210 148944 149076 "ASP73" 149208 NIL ASP73 (NIL NIL) -8 NIL NIL) (-86 147165 147887 148005 "ASP6" 148123 NIL ASP6 (NIL NIL) -8 NIL NIL) (-85 146114 146842 146960 "ASP55" 147078 NIL ASP55 (NIL NIL) -8 NIL NIL) (-84 145064 145788 145907 "ASP50" 146026 NIL ASP50 (NIL NIL) -8 NIL NIL) (-83 144152 144765 144875 "ASP4" 144985 NIL ASP4 (NIL NIL) -8 NIL NIL) (-82 143240 143853 143963 "ASP49" 144073 NIL ASP49 (NIL NIL) -8 NIL NIL) (-81 142025 142779 142947 "ASP42" 143129 NIL ASP42 (NIL NIL NIL NIL) -8 NIL NIL) (-80 140803 141558 141728 "ASP41" 141912 NIL ASP41 (NIL NIL NIL NIL) -8 NIL NIL) (-79 139755 140480 140598 "ASP35" 140716 NIL ASP35 (NIL NIL) -8 NIL NIL) (-78 139520 139703 139742 "ASP34" 139747 NIL ASP34 (NIL NIL) -8 NIL NIL) (-77 139257 139324 139400 "ASP33" 139475 NIL ASP33 (NIL NIL) -8 NIL NIL) (-76 138153 138892 139024 "ASP31" 139156 NIL ASP31 (NIL NIL) -8 NIL NIL) (-75 137918 138101 138140 "ASP30" 138145 NIL ASP30 (NIL NIL) -8 NIL NIL) (-74 137653 137722 137798 "ASP29" 137873 NIL ASP29 (NIL NIL) -8 NIL NIL) (-73 137418 137601 137640 "ASP28" 137645 NIL ASP28 (NIL NIL) -8 NIL NIL) (-72 137183 137366 137405 "ASP27" 137410 NIL ASP27 (NIL NIL) -8 NIL NIL) (-71 136267 136881 136992 "ASP24" 137103 NIL ASP24 (NIL NIL) -8 NIL NIL) (-70 135184 135908 136038 "ASP20" 136168 NIL ASP20 (NIL NIL) -8 NIL NIL) (-69 134272 134885 134995 "ASP1" 135105 NIL ASP1 (NIL NIL) -8 NIL NIL) (-68 133216 133946 134065 "ASP19" 134184 NIL ASP19 (NIL NIL) -8 NIL NIL) (-67 132953 133020 133096 "ASP12" 133171 NIL ASP12 (NIL NIL) -8 NIL NIL) (-66 131806 132552 132696 "ASP10" 132840 NIL ASP10 (NIL NIL) -8 NIL NIL) (-65 129711 131650 131741 "ARRAY2" 131746 NIL ARRAY2 (NIL T) -8 NIL NIL) (-64 125533 129359 129473 "ARRAY1" 129628 NIL ARRAY1 (NIL T) -8 NIL NIL) (-63 124565 124738 124959 "ARRAY12" 125356 NIL ARRAY12 (NIL T T) -7 NIL NIL) (-62 118964 120829 120905 "ARR2CAT" 123535 NIL ARR2CAT (NIL T T T) -9 NIL 124293) (-61 116398 117142 118096 "ARR2CAT-" 118101 NIL ARR2CAT- (NIL T T T T) -8 NIL NIL) (-60 115146 115298 115604 "APPRULE" 116234 NIL APPRULE (NIL T T T) -7 NIL NIL) (-59 114797 114845 114964 "APPLYORE" 115092 NIL APPLYORE (NIL T T T) -7 NIL NIL) (-58 114321 114409 114519 "API" 114705 T API (NIL) -7 NIL NIL) (-57 113295 113586 113781 "ANY" 114144 T ANY (NIL) -8 NIL NIL) (-56 112573 112696 112853 "ANY1" 113169 NIL ANY1 (NIL T) -7 NIL NIL) (-55 110092 111010 111337 "ANTISYM" 112297 NIL ANTISYM (NIL T NIL) -8 NIL NIL) (-54 109919 110051 110078 "ANON" 110083 T ANON (NIL) -8 NIL NIL) (-53 103986 108458 108912 "AN" 109483 T AN (NIL) -8 NIL NIL) (-52 100281 101679 101731 "AMR" 102479 NIL AMR (NIL T T) -9 NIL 103073) (-51 99393 99614 99977 "AMR-" 99982 NIL AMR- (NIL T T T) -8 NIL NIL) (-50 83955 99310 99371 "ALIST" 99376 NIL ALIST (NIL T T) -8 NIL NIL) (-49 80792 83549 83718 "ALGSC" 83873 NIL ALGSC (NIL T NIL NIL NIL) -8 NIL NIL) (-48 77350 77904 78510 "ALGPKG" 80233 NIL ALGPKG (NIL T T) -7 NIL NIL) (-47 76627 76728 76912 "ALGMFACT" 77236 NIL ALGMFACT (NIL T T T) -7 NIL NIL) (-46 72375 73059 73710 "ALGMANIP" 76154 NIL ALGMANIP (NIL T T) -7 NIL NIL) (-45 63689 72001 72151 "ALGFF" 72308 NIL ALGFF (NIL T T T NIL) -8 NIL NIL) (-44 62885 63016 63195 "ALGFACT" 63547 NIL ALGFACT (NIL T) -7 NIL NIL) (-43 61870 62480 62519 "ALGEBRA" 62579 NIL ALGEBRA (NIL T) -9 NIL 62638) (-42 61588 61647 61779 "ALGEBRA-" 61784 NIL ALGEBRA- (NIL T T) -8 NIL NIL) (-41 43395 59120 59173 "ALAGG" 59309 NIL ALAGG (NIL T T) -9 NIL 59470) (-40 42930 43043 43070 "AHYP" 43271 T AHYP (NIL) -9 NIL NIL) (-39 41861 42109 42136 "AGG" 42635 T AGG (NIL) -9 NIL 42913) (-38 41295 41457 41671 "AGG-" 41676 NIL AGG- (NIL T) -8 NIL NIL) (-37 38844 39425 39464 "AFSPCAT" 40736 NIL AFSPCAT (NIL T) -9 NIL 41231) (-36 36523 36945 37362 "AF" 38487 NIL AF (NIL T T) -7 NIL NIL) (-35 35863 36452 36506 "AFFSP" 36511 NIL AFFSP (NIL NIL T) -8 NIL NIL) (-34 35120 35790 35839 "AFFPLPS" 35844 NIL AFFPLPS (NIL T) -8 NIL NIL) (-33 34454 35061 35103 "AFFPL" 35108 NIL AFFPL (NIL T) -8 NIL NIL) (-32 31167 31654 32282 "AFALGRES" 33959 NIL AFALGRES (NIL T NIL T T T) -7 NIL NIL) (-31 29813 29990 30304 "AFALGGRO" 30986 NIL AFALGGRO (NIL T NIL T T T) -7 NIL NIL) (-30 29082 29340 29496 "ACPLOT" 29675 T ACPLOT (NIL) -8 NIL NIL) (-29 18442 26425 26477 "ACFS" 27188 NIL ACFS (NIL T) -9 NIL 27427) (-28 16456 16946 17721 "ACFS-" 17726 NIL ACFS- (NIL T T) -8 NIL NIL) (-27 12669 14625 14652 "ACF" 15531 T ACF (NIL) -9 NIL 15944) (-26 11373 11707 12200 "ACF-" 12205 NIL ACF- (NIL T) -8 NIL NIL) (-25 10970 11139 11166 "ABELSG" 11258 T ABELSG (NIL) -9 NIL 11323) (-24 10837 10862 10928 "ABELSG-" 10933 NIL ABELSG- (NIL T) -8 NIL NIL) (-23 10205 10466 10493 "ABELMON" 10663 T ABELMON (NIL) -9 NIL 10775) (-22 9869 9953 10091 "ABELMON-" 10096 NIL ABELMON- (NIL T) -8 NIL NIL) (-21 9202 9548 9575 "ABELGRP" 9700 T ABELGRP (NIL) -9 NIL 9782) (-20 8665 8794 9010 "ABELGRP-" 9015 NIL ABELGRP- (NIL T) -8 NIL NIL) (-19 4333 8027 8067 "A1AGG" 8072 NIL A1AGG (NIL T) -9 NIL 8112) (-18 30 1251 2813 "A1AGG-" 2818 NIL A1AGG- (NIL T T) -8 NIL NIL)) 
\ No newline at end of file
+((-1275 3579603 3579608 3579613 "NIL" NIL T NIL (NIL) NIL NIL NIL) (-3 3579588 3579593 3579598 "NIL" NIL NIL NIL (NIL) -8 NIL NIL) (-2 3579573 3579578 3579583 "NIL" NIL NIL NIL (NIL) -8 NIL NIL) (-1 3579558 3579563 3579568 "NIL" NIL NIL NIL (NIL) -8 NIL NIL) (0 3579543 3579548 3579553 "NIL" NIL NIL NIL (NIL) -8 NIL NIL) (-1270 3578673 3579418 3579495 "ZMOD" 3579500 NIL ZMOD (NIL NIL) -8 NIL NIL) (-1269 3577783 3577947 3578156 "ZLINDEP" 3578505 NIL ZLINDEP (NIL T) -7 NIL NIL) (-1268 3567087 3568851 3570823 "ZDSOLVE" 3575913 NIL ZDSOLVE (NIL T NIL NIL) -7 NIL NIL) (-1267 3566333 3566474 3566663 "YSTREAM" 3566933 NIL YSTREAM (NIL T) -7 NIL NIL) (-1266 3564098 3565634 3565838 "XRPOLY" 3566176 NIL XRPOLY (NIL T T) -8 NIL NIL) (-1265 3560552 3561881 3562461 "XPR" 3563565 NIL XPR (NIL T T) -8 NIL NIL) (-1264 3558262 3559883 3560087 "XPOLY" 3560383 NIL XPOLY (NIL T) -8 NIL NIL) (-1263 3556066 3557444 3557500 "XPOLYC" 3557788 NIL XPOLYC (NIL T T) -9 NIL 3557901) (-1262 3552440 3554585 3554972 "XPBWPOLY" 3555725 NIL XPBWPOLY (NIL T T) -8 NIL NIL) (-1261 3548318 3550628 3550671 "XF" 3551292 NIL XF (NIL T) -9 NIL 3551689) (-1260 3547939 3548027 3548196 "XF-" 3548201 NIL XF- (NIL T T) -8 NIL NIL) (-1259 3543288 3544587 3544643 "XFALG" 3546815 NIL XFALG (NIL T T) -9 NIL 3547602) (-1258 3542421 3542525 3542730 "XEXPPKG" 3543180 NIL XEXPPKG (NIL T T T) -7 NIL NIL) (-1257 3540518 3542271 3542367 "XDPOLY" 3542372 NIL XDPOLY (NIL T T) -8 NIL NIL) (-1256 3539390 3540000 3540044 "XALG" 3540107 NIL XALG (NIL T) -9 NIL 3540226) (-1255 3532859 3537367 3537861 "WUTSET" 3538982 NIL WUTSET (NIL T T T T) -8 NIL NIL) (-1254 3530668 3531475 3531826 "WP" 3532642 NIL WP (NIL T T T T NIL NIL NIL) -8 NIL NIL) (-1253 3529554 3529752 3530047 "WFFINTBS" 3530465 NIL WFFINTBS (NIL T T T T) -7 NIL NIL) (-1252 3527458 3527885 3528347 "WEIER" 3529126 NIL WEIER (NIL T) -7 NIL NIL) (-1251 3526604 3527028 3527071 "VSPACE" 3527207 NIL VSPACE (NIL T) -9 NIL 3527281) (-1250 3526442 3526469 3526560 "VSPACE-" 3526565 NIL VSPACE- (NIL T T) -8 NIL NIL) (-1249 3526188 3526231 3526302 "VOID" 3526393 T VOID (NIL) -8 NIL NIL) (-1248 3524324 3524683 3525089 "VIEW" 3525804 T VIEW (NIL) -7 NIL NIL) (-1247 3520749 3521387 3522124 "VIEWDEF" 3523609 T VIEWDEF (NIL) -7 NIL NIL) (-1246 3510088 3512297 3514470 "VIEW3D" 3518598 T VIEW3D (NIL) -8 NIL NIL) (-1245 3502370 3503999 3505578 "VIEW2D" 3508531 T VIEW2D (NIL) -8 NIL NIL) (-1244 3497778 3502140 3502232 "VECTOR" 3502313 NIL VECTOR (NIL T) -8 NIL NIL) (-1243 3496355 3496614 3496932 "VECTOR2" 3497508 NIL VECTOR2 (NIL T T) -7 NIL NIL) (-1242 3489920 3494166 3494210 "VECTCAT" 3495205 NIL VECTCAT (NIL T) -9 NIL 3495785) (-1241 3488934 3489188 3489578 "VECTCAT-" 3489583 NIL VECTCAT- (NIL T T) -8 NIL NIL) (-1240 3488415 3488585 3488705 "VARIABLE" 3488849 NIL VARIABLE (NIL NIL) -8 NIL NIL) (-1239 3480457 3486248 3486726 "UTSZ" 3487985 NIL UTSZ (NIL T NIL) -8 NIL NIL) (-1238 3480063 3480113 3480247 "UTSSOL" 3480401 NIL UTSSOL (NIL T T T) -7 NIL NIL) (-1237 3478895 3479049 3479310 "UTSODETL" 3479890 NIL UTSODETL (NIL T T T T) -7 NIL NIL) (-1236 3476335 3476795 3477319 "UTSODE" 3478436 NIL UTSODE (NIL T T) -7 NIL NIL) (-1235 3468168 3473963 3474451 "UTS" 3475905 NIL UTS (NIL T NIL NIL) -8 NIL NIL) (-1234 3459454 3464814 3464858 "UTSCAT" 3465970 NIL UTSCAT (NIL T) -9 NIL 3466721) (-1233 3456809 3457524 3458513 "UTSCAT-" 3458518 NIL UTSCAT- (NIL T T) -8 NIL NIL) (-1232 3456436 3456479 3456612 "UTS2" 3456760 NIL UTS2 (NIL T T T T) -7 NIL NIL) (-1231 3450750 3453309 3453353 "URAGG" 3455423 NIL URAGG (NIL T) -9 NIL 3456145) (-1230 3447689 3448552 3449675 "URAGG-" 3449680 NIL URAGG- (NIL T T) -8 NIL NIL) (-1229 3443367 3446303 3446775 "UPXSSING" 3447353 NIL UPXSSING (NIL T T NIL NIL) -8 NIL NIL) (-1228 3435254 3442484 3442765 "UPXS" 3443144 NIL UPXS (NIL T NIL NIL) -8 NIL NIL) (-1227 3428282 3435158 3435230 "UPXSCONS" 3435235 NIL UPXSCONS (NIL T T) -8 NIL NIL) (-1226 3418494 3425319 3425382 "UPXSCCA" 3426038 NIL UPXSCCA (NIL T T) -9 NIL 3426280) (-1225 3418132 3418217 3418391 "UPXSCCA-" 3418396 NIL UPXSCCA- (NIL T T T) -8 NIL NIL) (-1224 3408276 3414874 3414918 "UPXSCAT" 3415566 NIL UPXSCAT (NIL T) -9 NIL 3416168) (-1223 3407706 3407785 3407964 "UPXS2" 3408191 NIL UPXS2 (NIL T T NIL NIL NIL NIL) -7 NIL NIL) (-1222 3406360 3406613 3406964 "UPSQFREE" 3407449 NIL UPSQFREE (NIL T T) -7 NIL NIL) (-1221 3400195 3403245 3403301 "UPSCAT" 3404462 NIL UPSCAT (NIL T T) -9 NIL 3405230) (-1220 3399399 3399606 3399933 "UPSCAT-" 3399938 NIL UPSCAT- (NIL T T T) -8 NIL NIL) (-1219 3385388 3393428 3393472 "UPOLYC" 3395573 NIL UPOLYC (NIL T) -9 NIL 3396788) (-1218 3376717 3379142 3382289 "UPOLYC-" 3382294 NIL UPOLYC- (NIL T T) -8 NIL NIL) (-1217 3376344 3376387 3376520 "UPOLYC2" 3376668 NIL UPOLYC2 (NIL T T T T) -7 NIL NIL) (-1216 3367755 3375910 3376048 "UP" 3376254 NIL UP (NIL NIL T) -8 NIL NIL) (-1215 3367094 3367201 3367365 "UPMP" 3367644 NIL UPMP (NIL T T) -7 NIL NIL) (-1214 3366647 3366728 3366867 "UPDIVP" 3367007 NIL UPDIVP (NIL T T) -7 NIL NIL) (-1213 3365215 3365464 3365780 "UPDECOMP" 3366396 NIL UPDECOMP (NIL T T) -7 NIL NIL) (-1212 3364450 3364562 3364747 "UPCDEN" 3365099 NIL UPCDEN (NIL T T T) -7 NIL NIL) (-1211 3363969 3364038 3364187 "UP2" 3364375 NIL UP2 (NIL NIL T NIL T) -7 NIL NIL) (-1210 3362490 3363177 3363452 "UNISEG" 3363729 NIL UNISEG (NIL T) -8 NIL NIL) (-1209 3361707 3361834 3362038 "UNISEG2" 3362334 NIL UNISEG2 (NIL T T) -7 NIL NIL) (-1208 3360767 3360947 3361173 "UNIFACT" 3361523 NIL UNIFACT (NIL T) -7 NIL NIL) (-1207 3344651 3359946 3360196 "ULS" 3360575 NIL ULS (NIL T NIL NIL) -8 NIL NIL) (-1206 3332606 3344555 3344627 "ULSCONS" 3344632 NIL ULSCONS (NIL T T) -8 NIL NIL) (-1205 3315273 3327290 3327353 "ULSCCAT" 3328073 NIL ULSCCAT (NIL T T) -9 NIL 3328369) (-1204 3314323 3314568 3314956 "ULSCCAT-" 3314961 NIL ULSCCAT- (NIL T T T) -8 NIL NIL) (-1203 3304259 3310771 3310815 "ULSCAT" 3311678 NIL ULSCAT (NIL T) -9 NIL 3312401) (-1202 3303689 3303768 3303947 "ULS2" 3304174 NIL ULS2 (NIL T T NIL NIL NIL NIL) -7 NIL NIL) (-1201 3295827 3301680 3302180 "UFPS" 3303224 NIL UFPS (NIL T) -8 NIL NIL) (-1200 3295524 3295581 3295679 "UFPS1" 3295764 NIL UFPS1 (NIL T) -7 NIL NIL) (-1199 3293917 3294884 3294915 "UFD" 3295127 T UFD (NIL) -9 NIL 3295241) (-1198 3293711 3293757 3293852 "UFD-" 3293857 NIL UFD- (NIL T) -8 NIL NIL) (-1197 3292793 3292976 3293192 "UDVO" 3293517 T UDVO (NIL) -7 NIL NIL) (-1196 3290611 3291020 3291490 "UDPO" 3292358 NIL UDPO (NIL T) -7 NIL NIL) (-1195 3290543 3290548 3290579 "TYPE" 3290584 T TYPE (NIL) -9 NIL NIL) (-1194 3289514 3289716 3289956 "TWOFACT" 3290337 NIL TWOFACT (NIL T) -7 NIL NIL) (-1193 3288586 3288917 3289116 "TUPLE" 3289350 NIL TUPLE (NIL T) -8 NIL NIL) (-1192 3286277 3286796 3287335 "TUBETOOL" 3288069 T TUBETOOL (NIL) -7 NIL NIL) (-1191 3285126 3285331 3285572 "TUBE" 3286070 NIL TUBE (NIL T) -8 NIL NIL) (-1190 3279846 3284100 3284382 "TS" 3284879 NIL TS (NIL T) -8 NIL NIL) (-1189 3268520 3272605 3272703 "TSETCAT" 3277972 NIL TSETCAT (NIL T T T T) -9 NIL 3279502) (-1188 3263255 3264852 3266743 "TSETCAT-" 3266748 NIL TSETCAT- (NIL T T T T T) -8 NIL NIL) (-1187 3257526 3258372 3259310 "TRMANIP" 3262395 NIL TRMANIP (NIL T T) -7 NIL NIL) (-1186 3256967 3257030 3257193 "TRIMAT" 3257458 NIL TRIMAT (NIL T T T T) -7 NIL NIL) (-1185 3254763 3255000 3255364 "TRIGMNIP" 3256716 NIL TRIGMNIP (NIL T T) -7 NIL NIL) (-1184 3254282 3254395 3254426 "TRIGCAT" 3254639 T TRIGCAT (NIL) -9 NIL NIL) (-1183 3253951 3254030 3254171 "TRIGCAT-" 3254176 NIL TRIGCAT- (NIL T) -8 NIL NIL) (-1182 3250854 3252809 3253090 "TREE" 3253705 NIL TREE (NIL T) -8 NIL NIL) (-1181 3250127 3250655 3250686 "TRANFUN" 3250721 T TRANFUN (NIL) -9 NIL 3250787) (-1180 3249406 3249597 3249877 "TRANFUN-" 3249882 NIL TRANFUN- (NIL T) -8 NIL NIL) (-1179 3249210 3249242 3249303 "TOPSP" 3249367 T TOPSP (NIL) -7 NIL NIL) (-1178 3248558 3248673 3248827 "TOOLSIGN" 3249091 NIL TOOLSIGN (NIL T) -7 NIL NIL) (-1177 3247193 3247735 3247974 "TEXTFILE" 3248341 T TEXTFILE (NIL) -8 NIL NIL) (-1176 3245058 3245572 3246010 "TEX" 3246777 T TEX (NIL) -8 NIL NIL) (-1175 3244839 3244870 3244942 "TEX1" 3245021 NIL TEX1 (NIL T) -7 NIL NIL) (-1174 3244487 3244550 3244640 "TEMUTL" 3244771 T TEMUTL (NIL) -7 NIL NIL) (-1173 3242641 3242921 3243246 "TBCMPPK" 3244210 NIL TBCMPPK (NIL T T) -7 NIL NIL) (-1172 3234386 3240646 3240703 "TBAGG" 3241103 NIL TBAGG (NIL T T) -9 NIL 3241314) (-1171 3229456 3230944 3232698 "TBAGG-" 3232703 NIL TBAGG- (NIL T T T) -8 NIL NIL) (-1170 3228840 3228947 3229092 "TANEXP" 3229345 NIL TANEXP (NIL T) -7 NIL NIL) (-1169 3222353 3228697 3228790 "TABLE" 3228795 NIL TABLE (NIL T T) -8 NIL NIL) (-1168 3221766 3221864 3222002 "TABLEAU" 3222250 NIL TABLEAU (NIL T) -8 NIL NIL) (-1167 3216374 3217594 3218842 "TABLBUMP" 3220552 NIL TABLBUMP (NIL T) -7 NIL NIL) (-1166 3212837 3213532 3214315 "SYSSOLP" 3215625 NIL SYSSOLP (NIL T) -7 NIL NIL) (-1165 3209971 3210579 3211217 "SYMTAB" 3212221 T SYMTAB (NIL) -8 NIL NIL) (-1164 3205220 3206122 3207105 "SYMS" 3209010 T SYMS (NIL) -8 NIL NIL) (-1163 3202452 3204684 3204911 "SYMPOLY" 3205028 NIL SYMPOLY (NIL T) -8 NIL NIL) (-1162 3201969 3202044 3202167 "SYMFUNC" 3202364 NIL SYMFUNC (NIL T) -7 NIL NIL) (-1161 3197947 3199206 3200028 "SYMBOL" 3201169 T SYMBOL (NIL) -8 NIL NIL) (-1160 3191486 3193175 3194895 "SWITCH" 3196249 T SWITCH (NIL) -8 NIL NIL) (-1159 3184712 3190309 3190611 "SUTS" 3191242 NIL SUTS (NIL T NIL NIL) -8 NIL NIL) (-1158 3176598 3183829 3184110 "SUPXS" 3184489 NIL SUPXS (NIL T NIL NIL) -8 NIL NIL) (-1157 3168083 3176216 3176342 "SUP" 3176507 NIL SUP (NIL T) -8 NIL NIL) (-1156 3167242 3167369 3167586 "SUPFRACF" 3167951 NIL SUPFRACF (NIL T T T T) -7 NIL NIL) (-1155 3157814 3167044 3167158 "SUPEXPR" 3167163 NIL SUPEXPR (NIL T) -8 NIL NIL) (-1154 3157435 3157494 3157607 "SUP2" 3157749 NIL SUP2 (NIL T T) -7 NIL NIL) (-1153 3155848 3156122 3156485 "SUMRF" 3157134 NIL SUMRF (NIL T) -7 NIL NIL) (-1152 3155162 3155228 3155427 "SUMFS" 3155769 NIL SUMFS (NIL T T) -7 NIL NIL) (-1151 3139086 3154341 3154591 "SULS" 3154970 NIL SULS (NIL T NIL NIL) -8 NIL NIL) (-1150 3138408 3138611 3138751 "SUCH" 3138994 NIL SUCH (NIL T T) -8 NIL NIL) (-1149 3132302 3133314 3134273 "SUBSPACE" 3137496 NIL SUBSPACE (NIL NIL T) -8 NIL NIL) (-1148 3131734 3131824 3131987 "SUBRESP" 3132191 NIL SUBRESP (NIL T T) -7 NIL NIL) (-1147 3125103 3126399 3127710 "STTF" 3130470 NIL STTF (NIL T) -7 NIL NIL) (-1146 3119276 3120396 3121543 "STTFNC" 3124003 NIL STTFNC (NIL T) -7 NIL NIL) (-1145 3110595 3112462 3114254 "STTAYLOR" 3117519 NIL STTAYLOR (NIL T) -7 NIL NIL) (-1144 3103851 3110459 3110542 "STRTBL" 3110547 NIL STRTBL (NIL T) -8 NIL NIL) (-1143 3099242 3103806 3103837 "STRING" 3103842 T STRING (NIL) -8 NIL NIL) (-1142 3094106 3098584 3098615 "STRICAT" 3098674 T STRICAT (NIL) -9 NIL 3098736) (-1141 3086833 3091633 3092251 "STREAM" 3093523 NIL STREAM (NIL T) -8 NIL NIL) (-1140 3086343 3086420 3086564 "STREAM3" 3086750 NIL STREAM3 (NIL T T T) -7 NIL NIL) (-1139 3085325 3085508 3085743 "STREAM2" 3086156 NIL STREAM2 (NIL T T) -7 NIL NIL) (-1138 3085013 3085065 3085158 "STREAM1" 3085267 NIL STREAM1 (NIL T) -7 NIL NIL) (-1137 3084029 3084210 3084441 "STINPROD" 3084829 NIL STINPROD (NIL T) -7 NIL NIL) (-1136 3083606 3083790 3083821 "STEP" 3083901 T STEP (NIL) -9 NIL 3083979) (-1135 3077161 3083505 3083582 "STBL" 3083587 NIL STBL (NIL T T NIL) -8 NIL NIL) (-1134 3072375 3076413 3076457 "STAGG" 3076610 NIL STAGG (NIL T) -9 NIL 3076699) (-1133 3070077 3070679 3071551 "STAGG-" 3071556 NIL STAGG- (NIL T T) -8 NIL NIL) (-1132 3063569 3065138 3066253 "STACK" 3068997 NIL STACK (NIL T) -8 NIL NIL) (-1131 3056294 3061710 3062166 "SREGSET" 3063199 NIL SREGSET (NIL T T T T) -8 NIL NIL) (-1130 3048720 3050088 3051601 "SRDCMPK" 3054900 NIL SRDCMPK (NIL T T T T T) -7 NIL NIL) (-1129 3041698 3046158 3046189 "SRAGG" 3047492 T SRAGG (NIL) -9 NIL 3048100) (-1128 3040715 3040970 3041349 "SRAGG-" 3041354 NIL SRAGG- (NIL T) -8 NIL NIL) (-1127 3035163 3039638 3040062 "SQMATRIX" 3040338 NIL SQMATRIX (NIL NIL T) -8 NIL NIL) (-1126 3028919 3031881 3032608 "SPLTREE" 3034508 NIL SPLTREE (NIL T T) -8 NIL NIL) (-1125 3024909 3025575 3026221 "SPLNODE" 3028345 NIL SPLNODE (NIL T T) -8 NIL NIL) (-1124 3023955 3024188 3024219 "SPFCAT" 3024663 T SPFCAT (NIL) -9 NIL NIL) (-1123 3022692 3022902 3023166 "SPECOUT" 3023713 T SPECOUT (NIL) -7 NIL NIL) (-1122 3014662 3016409 3016453 "SPACEC" 3020826 NIL SPACEC (NIL T) -9 NIL 3022642) (-1121 3012833 3014594 3014643 "SPACE3" 3014648 NIL SPACE3 (NIL T) -8 NIL NIL) (-1120 3011587 3011758 3012048 "SORTPAK" 3012639 NIL SORTPAK (NIL T T) -7 NIL NIL) (-1119 3009637 3009940 3010359 "SOLVETRA" 3011251 NIL SOLVETRA (NIL T) -7 NIL NIL) (-1118 3008648 3008870 3009144 "SOLVESER" 3009410 NIL SOLVESER (NIL T) -7 NIL NIL) (-1117 3003868 3004749 3005751 "SOLVERAD" 3007700 NIL SOLVERAD (NIL T) -7 NIL NIL) (-1116 2999683 3000292 3001021 "SOLVEFOR" 3003235 NIL SOLVEFOR (NIL T T) -7 NIL NIL) (-1115 2993986 2999031 2999129 "SNTSCAT" 2999134 NIL SNTSCAT (NIL T T T T) -9 NIL 2999204) (-1114 2988084 2992311 2992701 "SMTS" 2993677 NIL SMTS (NIL T T T) -8 NIL NIL) (-1113 2982488 2987972 2988049 "SMP" 2988054 NIL SMP (NIL T T) -8 NIL NIL) (-1112 2980647 2980948 2981346 "SMITH" 2982185 NIL SMITH (NIL T T T T) -7 NIL NIL) (-1111 2973589 2977787 2977891 "SMATCAT" 2979242 NIL SMATCAT (NIL NIL T T T) -9 NIL 2979789) (-1110 2970529 2971352 2972530 "SMATCAT-" 2972535 NIL SMATCAT- (NIL T NIL T T T) -8 NIL NIL) (-1109 2968282 2969799 2969843 "SKAGG" 2970104 NIL SKAGG (NIL T) -9 NIL 2970239) (-1108 2964340 2967386 2967664 "SINT" 2968026 T SINT (NIL) -8 NIL NIL) (-1107 2964112 2964150 2964216 "SIMPAN" 2964296 T SIMPAN (NIL) -7 NIL NIL) (-1106 2962950 2963171 2963446 "SIGNRF" 2963871 NIL SIGNRF (NIL T) -7 NIL NIL) (-1105 2961755 2961906 2962197 "SIGNEF" 2962779 NIL SIGNEF (NIL T T) -7 NIL NIL) (-1104 2959447 2959901 2960406 "SHP" 2961297 NIL SHP (NIL T NIL) -7 NIL NIL) (-1103 2953271 2959348 2959424 "SHDP" 2959429 NIL SHDP (NIL NIL NIL T) -8 NIL NIL) (-1102 2952759 2952951 2952982 "SGROUP" 2953134 T SGROUP (NIL) -9 NIL 2953221) (-1101 2952529 2952581 2952685 "SGROUP-" 2952690 NIL SGROUP- (NIL T) -8 NIL NIL) (-1100 2949365 2950062 2950785 "SGCF" 2951828 T SGCF (NIL) -7 NIL NIL) (-1099 2943766 2948811 2948909 "SFRTCAT" 2948914 NIL SFRTCAT (NIL T T T T) -9 NIL 2948953) (-1098 2937190 2938205 2939341 "SFRGCD" 2942749 NIL SFRGCD (NIL T T T T T) -7 NIL NIL) (-1097 2930318 2931389 2932575 "SFQCMPK" 2936123 NIL SFQCMPK (NIL T T T T T) -7 NIL NIL) (-1096 2929940 2930029 2930139 "SFORT" 2930259 NIL SFORT (NIL T T) -8 NIL NIL) (-1095 2929085 2929780 2929901 "SEXOF" 2929906 NIL SEXOF (NIL T T T T T) -8 NIL NIL) (-1094 2928219 2928966 2929034 "SEX" 2929039 T SEX (NIL) -8 NIL NIL) (-1093 2922994 2923683 2923779 "SEXCAT" 2927550 NIL SEXCAT (NIL T T T T T) -9 NIL 2928169) (-1092 2920174 2922928 2922976 "SET" 2922981 NIL SET (NIL T) -8 NIL NIL) (-1091 2918425 2918887 2919192 "SETMN" 2919915 NIL SETMN (NIL NIL NIL) -8 NIL NIL) (-1090 2918030 2918156 2918187 "SETCAT" 2918304 T SETCAT (NIL) -9 NIL 2918389) (-1089 2917810 2917862 2917961 "SETCAT-" 2917966 NIL SETCAT- (NIL T) -8 NIL NIL) (-1088 2917473 2917623 2917654 "SETCATD" 2917713 T SETCATD (NIL) -9 NIL 2917760) (-1087 2913859 2915933 2915977 "SETAGG" 2916847 NIL SETAGG (NIL T) -9 NIL 2917187) (-1086 2913317 2913433 2913670 "SETAGG-" 2913675 NIL SETAGG- (NIL T T) -8 NIL NIL) (-1085 2912520 2912813 2912875 "SEGXCAT" 2913161 NIL SEGXCAT (NIL T T) -9 NIL 2913281) (-1084 2911580 2912190 2912370 "SEG" 2912375 NIL SEG (NIL T) -8 NIL NIL) (-1083 2910486 2910699 2910743 "SEGCAT" 2911325 NIL SEGCAT (NIL T) -9 NIL 2911563) (-1082 2909537 2909867 2910066 "SEGBIND" 2910322 NIL SEGBIND (NIL T) -8 NIL NIL) (-1081 2909158 2909217 2909330 "SEGBIND2" 2909472 NIL SEGBIND2 (NIL T T) -7 NIL NIL) (-1080 2908379 2908505 2908708 "SEG2" 2909003 NIL SEG2 (NIL T T) -7 NIL NIL) (-1079 2907816 2908314 2908361 "SDVAR" 2908366 NIL SDVAR (NIL T) -8 NIL NIL) (-1078 2900060 2907586 2907716 "SDPOL" 2907721 NIL SDPOL (NIL T) -8 NIL NIL) (-1077 2898653 2898919 2899238 "SCPKG" 2899775 NIL SCPKG (NIL T) -7 NIL NIL) (-1076 2897874 2898007 2898186 "SCACHE" 2898508 NIL SCACHE (NIL T) -7 NIL NIL) (-1075 2897313 2897634 2897719 "SAOS" 2897811 T SAOS (NIL) -8 NIL NIL) (-1074 2896878 2896913 2897086 "SAERFFC" 2897272 NIL SAERFFC (NIL T T T) -7 NIL NIL) (-1073 2890767 2896775 2896855 "SAE" 2896860 NIL SAE (NIL T T NIL) -8 NIL NIL) (-1072 2890360 2890395 2890554 "SAEFACT" 2890726 NIL SAEFACT (NIL T T T) -7 NIL NIL) (-1071 2888681 2888995 2889396 "RURPK" 2890026 NIL RURPK (NIL T NIL) -7 NIL NIL) (-1070 2887317 2887596 2887908 "RULESET" 2888515 NIL RULESET (NIL T T T) -8 NIL NIL) (-1069 2884504 2885007 2885472 "RULE" 2886998 NIL RULE (NIL T T T) -8 NIL NIL) (-1068 2884143 2884298 2884381 "RULECOLD" 2884456 NIL RULECOLD (NIL NIL) -8 NIL NIL) (-1067 2878992 2879786 2880706 "RSETGCD" 2883342 NIL RSETGCD (NIL T T T T T) -7 NIL NIL) (-1066 2868255 2873300 2873398 "RSETCAT" 2877517 NIL RSETCAT (NIL T T T T) -9 NIL 2878614) (-1065 2866182 2866721 2867545 "RSETCAT-" 2867550 NIL RSETCAT- (NIL T T T T T) -8 NIL NIL) (-1064 2858569 2859944 2861464 "RSDCMPK" 2864781 NIL RSDCMPK (NIL T T T T T) -7 NIL NIL) (-1063 2856573 2857014 2857089 "RRCC" 2858175 NIL RRCC (NIL T T) -9 NIL 2858519) (-1062 2855924 2856098 2856377 "RRCC-" 2856382 NIL RRCC- (NIL T T T) -8 NIL NIL) (-1061 2830071 2839700 2839768 "RPOLCAT" 2850432 NIL RPOLCAT (NIL T T T) -9 NIL 2853580) (-1060 2821571 2823909 2827031 "RPOLCAT-" 2827036 NIL RPOLCAT- (NIL T T T T) -8 NIL NIL) (-1059 2812630 2819782 2820264 "ROUTINE" 2821111 T ROUTINE (NIL) -8 NIL NIL) (-1058 2809330 2812181 2812330 "ROMAN" 2812503 T ROMAN (NIL) -8 NIL NIL) (-1057 2807605 2808190 2808450 "ROIRC" 2809135 NIL ROIRC (NIL T T) -8 NIL NIL) (-1056 2803943 2806243 2806274 "RNS" 2806578 T RNS (NIL) -9 NIL 2806852) (-1055 2802452 2802835 2803369 "RNS-" 2803444 NIL RNS- (NIL T) -8 NIL NIL) (-1054 2801874 2802282 2802313 "RNG" 2802318 T RNG (NIL) -9 NIL 2802339) (-1053 2801265 2801627 2801671 "RMODULE" 2801733 NIL RMODULE (NIL T) -9 NIL 2801775) (-1052 2800101 2800195 2800531 "RMCAT2" 2801166 NIL RMCAT2 (NIL NIL NIL T T T T T T T T) -7 NIL NIL) (-1051 2796810 2799279 2799602 "RMATRIX" 2799837 NIL RMATRIX (NIL NIL NIL T) -8 NIL NIL) (-1050 2789756 2791990 2792106 "RMATCAT" 2795465 NIL RMATCAT (NIL NIL NIL T T T) -9 NIL 2796442) (-1049 2789131 2789278 2789585 "RMATCAT-" 2789590 NIL RMATCAT- (NIL T NIL NIL T T T) -8 NIL NIL) (-1048 2788698 2788773 2788901 "RINTERP" 2789050 NIL RINTERP (NIL NIL T) -7 NIL NIL) (-1047 2787741 2788305 2788336 "RING" 2788448 T RING (NIL) -9 NIL 2788543) (-1046 2787533 2787577 2787674 "RING-" 2787679 NIL RING- (NIL T) -8 NIL NIL) (-1045 2786374 2786611 2786869 "RIDIST" 2787297 T RIDIST (NIL) -7 NIL NIL) (-1044 2777690 2785842 2786048 "RGCHAIN" 2786222 NIL RGCHAIN (NIL T NIL) -8 NIL NIL) (-1043 2776490 2776731 2777010 "RFP" 2777445 NIL RFP (NIL T) -7 NIL NIL) (-1042 2773484 2774098 2774768 "RF" 2775854 NIL RF (NIL T) -7 NIL NIL) (-1041 2773130 2773193 2773296 "RFFACTOR" 2773415 NIL RFFACTOR (NIL T) -7 NIL NIL) (-1040 2772855 2772890 2772987 "RFFACT" 2773089 NIL RFFACT (NIL T) -7 NIL NIL) (-1039 2770972 2771336 2771718 "RFDIST" 2772495 T RFDIST (NIL) -7 NIL NIL) (-1038 2770425 2770517 2770680 "RETSOL" 2770874 NIL RETSOL (NIL T T) -7 NIL NIL) (-1037 2770012 2770092 2770136 "RETRACT" 2770329 NIL RETRACT (NIL T) -9 NIL NIL) (-1036 2769861 2769886 2769973 "RETRACT-" 2769978 NIL RETRACT- (NIL T T) -8 NIL NIL) (-1035 2762727 2769514 2769641 "RESULT" 2769756 T RESULT (NIL) -8 NIL NIL) (-1034 2761307 2761996 2762195 "RESRING" 2762630 NIL RESRING (NIL T T T T NIL) -8 NIL NIL) (-1033 2760943 2760992 2761090 "RESLATC" 2761244 NIL RESLATC (NIL T) -7 NIL NIL) (-1032 2760649 2760683 2760790 "REPSQ" 2760902 NIL REPSQ (NIL T) -7 NIL NIL) (-1031 2758071 2758651 2759253 "REP" 2760069 T REP (NIL) -7 NIL NIL) (-1030 2757769 2757803 2757914 "REPDB" 2758030 NIL REPDB (NIL T) -7 NIL NIL) (-1029 2751687 2753066 2754285 "REP2" 2756585 NIL REP2 (NIL T) -7 NIL NIL) (-1028 2748068 2748749 2749555 "REP1" 2750916 NIL REP1 (NIL T) -7 NIL NIL) (-1027 2740794 2746209 2746665 "REGSET" 2747698 NIL REGSET (NIL T T T T) -8 NIL NIL) (-1026 2739609 2739944 2740193 "REF" 2740580 NIL REF (NIL T) -8 NIL NIL) (-1025 2738986 2739089 2739256 "REDORDER" 2739493 NIL REDORDER (NIL T T) -7 NIL NIL) (-1024 2735848 2736314 2736923 "RECOP" 2738520 NIL RECOP (NIL T T) -7 NIL NIL) (-1023 2731788 2735061 2735288 "RECLOS" 2735676 NIL RECLOS (NIL T) -8 NIL NIL) (-1022 2730840 2731021 2731236 "REALSOLV" 2731595 T REALSOLV (NIL) -7 NIL NIL) (-1021 2730685 2730726 2730757 "REAL" 2730762 T REAL (NIL) -9 NIL 2730797) (-1020 2727168 2727970 2728854 "REAL0Q" 2729850 NIL REAL0Q (NIL T) -7 NIL NIL) (-1019 2722769 2723757 2724818 "REAL0" 2726149 NIL REAL0 (NIL T) -7 NIL NIL) (-1018 2722174 2722246 2722453 "RDIV" 2722691 NIL RDIV (NIL T T T T T) -7 NIL NIL) (-1017 2721242 2721416 2721629 "RDIST" 2721996 NIL RDIST (NIL T) -7 NIL NIL) (-1016 2719839 2720126 2720498 "RDETRS" 2720950 NIL RDETRS (NIL T T) -7 NIL NIL) (-1015 2717651 2718105 2718643 "RDETR" 2719381 NIL RDETR (NIL T T) -7 NIL NIL) (-1014 2716262 2716540 2716944 "RDEEFS" 2717367 NIL RDEEFS (NIL T T) -7 NIL NIL) (-1013 2714757 2715063 2715495 "RDEEF" 2715950 NIL RDEEF (NIL T T) -7 NIL NIL) (-1012 2708948 2711883 2711914 "RCFIELD" 2713209 T RCFIELD (NIL) -9 NIL 2713940) (-1011 2707012 2707516 2708212 "RCFIELD-" 2708287 NIL RCFIELD- (NIL T) -8 NIL NIL) (-1010 2703370 2705149 2705193 "RCAGG" 2706277 NIL RCAGG (NIL T) -9 NIL 2706740) (-1009 2702998 2703092 2703255 "RCAGG-" 2703260 NIL RCAGG- (NIL T T) -8 NIL NIL) (-1008 2702334 2702445 2702610 "RATRET" 2702882 NIL RATRET (NIL T) -7 NIL NIL) (-1007 2701887 2701954 2702075 "RATFACT" 2702262 NIL RATFACT (NIL T) -7 NIL NIL) (-1006 2701195 2701315 2701467 "RANDSRC" 2701757 T RANDSRC (NIL) -7 NIL NIL) (-1005 2700929 2700973 2701046 "RADUTIL" 2701144 T RADUTIL (NIL) -7 NIL NIL) (-1004 2693917 2699662 2699981 "RADIX" 2700644 NIL RADIX (NIL NIL) -8 NIL NIL) (-1003 2685480 2693759 2693889 "RADFF" 2693894 NIL RADFF (NIL T T T NIL NIL) -8 NIL NIL) (-1002 2685126 2685201 2685232 "RADCAT" 2685392 T RADCAT (NIL) -9 NIL NIL) (-1001 2684908 2684956 2685056 "RADCAT-" 2685061 NIL RADCAT- (NIL T) -8 NIL NIL) (-1000 2678155 2679773 2680926 "QUEUE" 2683790 NIL QUEUE (NIL T) -8 NIL NIL) (-999 2674646 2678092 2678137 "QUAT" 2678142 NIL QUAT (NIL T) -8 NIL NIL) (-998 2674284 2674327 2674454 "QUATCT2" 2674597 NIL QUATCT2 (NIL T T T T) -7 NIL NIL) (-997 2668021 2671405 2671446 "QUATCAT" 2672226 NIL QUATCAT (NIL T) -9 NIL 2672984) (-996 2664165 2665202 2666589 "QUATCAT-" 2666683 NIL QUATCAT- (NIL T T) -8 NIL NIL) (-995 2661725 2663283 2663325 "QUAGG" 2663700 NIL QUAGG (NIL T) -9 NIL 2663875) (-994 2660650 2661123 2661295 "QFORM" 2661597 NIL QFORM (NIL NIL T) -8 NIL NIL) (-993 2651877 2657144 2657185 "QFCAT" 2657843 NIL QFCAT (NIL T) -9 NIL 2658832) (-992 2647449 2648650 2650241 "QFCAT-" 2650335 NIL QFCAT- (NIL T T) -8 NIL NIL) (-991 2647087 2647130 2647257 "QFCAT2" 2647400 NIL QFCAT2 (NIL T T T T) -7 NIL NIL) (-990 2646547 2646657 2646787 "QEQUAT" 2646977 T QEQUAT (NIL) -8 NIL NIL) (-989 2639695 2640766 2641950 "QCMPACK" 2645480 NIL QCMPACK (NIL T T T T T) -7 NIL NIL) (-988 2637275 2637696 2638122 "QALGSET" 2639352 NIL QALGSET (NIL T T T T) -8 NIL NIL) (-987 2636520 2636694 2636926 "QALGSET2" 2637095 NIL QALGSET2 (NIL NIL NIL) -7 NIL NIL) (-986 2635211 2635434 2635751 "PWFFINTB" 2636293 NIL PWFFINTB (NIL T T T T) -7 NIL NIL) (-985 2633393 2633561 2633915 "PUSHVAR" 2635025 NIL PUSHVAR (NIL T T T T) -7 NIL NIL) (-984 2629310 2630364 2630406 "PTRANFN" 2632290 NIL PTRANFN (NIL T) -9 NIL NIL) (-983 2627712 2628003 2628325 "PTPACK" 2629021 NIL PTPACK (NIL T) -7 NIL NIL) (-982 2627344 2627401 2627510 "PTFUNC2" 2627649 NIL PTFUNC2 (NIL T T) -7 NIL NIL) (-981 2621844 2626178 2626220 "PTCAT" 2626593 NIL PTCAT (NIL T) -9 NIL 2626755) (-980 2621502 2621537 2621661 "PSQFR" 2621803 NIL PSQFR (NIL T T T T) -7 NIL NIL) (-979 2620089 2620389 2620725 "PSEUDLIN" 2621198 NIL PSEUDLIN (NIL T) -7 NIL NIL) (-978 2606865 2609229 2611550 "PSETPK" 2617852 NIL PSETPK (NIL T T T T) -7 NIL NIL) (-977 2599909 2602623 2602720 "PSETCAT" 2605741 NIL PSETCAT (NIL T T T T) -9 NIL 2606554) (-976 2597745 2598379 2599200 "PSETCAT-" 2599205 NIL PSETCAT- (NIL T T T T T) -8 NIL NIL) (-975 2597094 2597258 2597287 "PSCURVE" 2597555 T PSCURVE (NIL) -9 NIL 2597722) (-974 2593483 2595009 2595075 "PSCAT" 2595919 NIL PSCAT (NIL T T T) -9 NIL 2596159) (-973 2592546 2592762 2593162 "PSCAT-" 2593167 NIL PSCAT- (NIL T T T T) -8 NIL NIL) (-972 2591199 2591831 2592045 "PRTITION" 2592352 T PRTITION (NIL) -8 NIL NIL) (-971 2588363 2589012 2589053 "PRSPCAT" 2590567 NIL PRSPCAT (NIL T) -9 NIL 2591135) (-970 2577463 2579669 2581856 "PRS" 2586226 NIL PRS (NIL T T) -7 NIL NIL) (-969 2575361 2576847 2576888 "PRQAGG" 2577071 NIL PRQAGG (NIL T) -9 NIL 2577173) (-968 2574630 2575286 2575343 "PROJSP" 2575348 NIL PROJSP (NIL NIL T) -8 NIL NIL) (-967 2573812 2574553 2574605 "PROJPLPS" 2574610 NIL PROJPLPS (NIL T) -8 NIL NIL) (-966 2573071 2573749 2573794 "PROJPL" 2573799 NIL PROJPL (NIL T) -8 NIL NIL) (-965 2566877 2571269 2572073 "PRODUCT" 2572313 NIL PRODUCT (NIL T T) -8 NIL NIL) (-964 2564152 2566341 2566572 "PR" 2566691 NIL PR (NIL T T) -8 NIL NIL) (-963 2562704 2562861 2563156 "PRJALGPK" 2563992 NIL PRJALGPK (NIL T NIL T T T) -7 NIL NIL) (-962 2562500 2562532 2562591 "PRINT" 2562665 T PRINT (NIL) -7 NIL NIL) (-961 2561840 2561957 2562109 "PRIMES" 2562380 NIL PRIMES (NIL T) -7 NIL NIL) (-960 2559905 2560306 2560772 "PRIMELT" 2561419 NIL PRIMELT (NIL T) -7 NIL NIL) (-959 2559633 2559682 2559711 "PRIMCAT" 2559835 T PRIMCAT (NIL) -9 NIL NIL) (-958 2555800 2559571 2559616 "PRIMARR" 2559621 NIL PRIMARR (NIL T) -8 NIL NIL) (-957 2554807 2554985 2555213 "PRIMARR2" 2555618 NIL PRIMARR2 (NIL T T) -7 NIL NIL) (-956 2554450 2554506 2554617 "PREASSOC" 2554745 NIL PREASSOC (NIL T T) -7 NIL NIL) (-955 2553925 2554057 2554086 "PPCURVE" 2554291 T PPCURVE (NIL) -9 NIL 2554427) (-954 2551286 2551685 2552276 "POLYROOT" 2553507 NIL POLYROOT (NIL T T T T T) -7 NIL NIL) (-953 2545187 2550892 2551051 "POLY" 2551160 NIL POLY (NIL T) -8 NIL NIL) (-952 2544570 2544628 2544862 "POLYLIFT" 2545123 NIL POLYLIFT (NIL T T T T T) -7 NIL NIL) (-951 2540845 2541294 2541923 "POLYCATQ" 2544115 NIL POLYCATQ (NIL T T T T T) -7 NIL NIL) (-950 2527807 2533207 2533273 "POLYCAT" 2536787 NIL POLYCAT (NIL T T T) -9 NIL 2538700) (-949 2521257 2523118 2525502 "POLYCAT-" 2525507 NIL POLYCAT- (NIL T T T T) -8 NIL NIL) (-948 2520844 2520912 2521032 "POLY2UP" 2521183 NIL POLY2UP (NIL NIL T) -7 NIL NIL) (-947 2520476 2520533 2520642 "POLY2" 2520781 NIL POLY2 (NIL T T) -7 NIL NIL) (-946 2519163 2519402 2519677 "POLUTIL" 2520251 NIL POLUTIL (NIL T T) -7 NIL NIL) (-945 2517518 2517795 2518126 "POLTOPOL" 2518885 NIL POLTOPOL (NIL NIL T) -7 NIL NIL) (-944 2513040 2517454 2517500 "POINT" 2517505 NIL POINT (NIL T) -8 NIL NIL) (-943 2511227 2511584 2511959 "PNTHEORY" 2512685 T PNTHEORY (NIL) -7 NIL NIL) (-942 2509646 2509943 2510355 "PMTOOLS" 2510925 NIL PMTOOLS (NIL T T T) -7 NIL NIL) (-941 2509239 2509317 2509434 "PMSYM" 2509562 NIL PMSYM (NIL T) -7 NIL NIL) (-940 2508749 2508818 2508992 "PMQFCAT" 2509164 NIL PMQFCAT (NIL T T T) -7 NIL NIL) (-939 2508104 2508214 2508370 "PMPRED" 2508626 NIL PMPRED (NIL T) -7 NIL NIL) (-938 2507500 2507586 2507747 "PMPREDFS" 2508005 NIL PMPREDFS (NIL T T T) -7 NIL NIL) (-937 2506145 2506353 2506737 "PMPLCAT" 2507263 NIL PMPLCAT (NIL T T T T T) -7 NIL NIL) (-936 2505677 2505756 2505908 "PMLSAGG" 2506060 NIL PMLSAGG (NIL T T T) -7 NIL NIL) (-935 2505152 2505228 2505409 "PMKERNEL" 2505595 NIL PMKERNEL (NIL T T) -7 NIL NIL) (-934 2504769 2504844 2504957 "PMINS" 2505071 NIL PMINS (NIL T) -7 NIL NIL) (-933 2504197 2504266 2504482 "PMFS" 2504694 NIL PMFS (NIL T T T) -7 NIL NIL) (-932 2503425 2503543 2503748 "PMDOWN" 2504074 NIL PMDOWN (NIL T T T) -7 NIL NIL) (-931 2502588 2502747 2502929 "PMASS" 2503263 T PMASS (NIL) -7 NIL NIL) (-930 2501862 2501973 2502136 "PMASSFS" 2502474 NIL PMASSFS (NIL T T) -7 NIL NIL) (-929 2499622 2499875 2500258 "PLPKCRV" 2501586 NIL PLPKCRV (NIL T T T NIL T) -7 NIL NIL) (-928 2499277 2499345 2499439 "PLOTTOOL" 2499548 T PLOTTOOL (NIL) -7 NIL NIL) (-927 2493899 2495088 2496236 "PLOT" 2498149 T PLOT (NIL) -8 NIL NIL) (-926 2489713 2490747 2491668 "PLOT3D" 2492998 T PLOT3D (NIL) -8 NIL NIL) (-925 2488625 2488802 2489037 "PLOT1" 2489517 NIL PLOT1 (NIL T) -7 NIL NIL) (-924 2464020 2468691 2473542 "PLEQN" 2483891 NIL PLEQN (NIL T T T T) -7 NIL NIL) (-923 2463260 2463930 2463997 "PLCS" 2464002 NIL PLCS (NIL T T) -8 NIL NIL) (-922 2462411 2463145 2463216 "PLACESPS" 2463221 NIL PLACESPS (NIL T) -8 NIL NIL) (-921 2461618 2462324 2462381 "PLACES" 2462386 NIL PLACES (NIL T) -8 NIL NIL) (-920 2458342 2459006 2459065 "PLACESC" 2460983 NIL PLACESC (NIL T T) -9 NIL 2461554) (-919 2457660 2457782 2457962 "PINTERP" 2458207 NIL PINTERP (NIL NIL T) -7 NIL NIL) (-918 2457353 2457400 2457503 "PINTERPA" 2457607 NIL PINTERPA (NIL T T) -7 NIL NIL) (-917 2456580 2457147 2457240 "PI" 2457280 T PI (NIL) -8 NIL NIL) (-916 2454967 2455952 2455981 "PID" 2456163 T PID (NIL) -9 NIL 2456297) (-915 2454692 2454729 2454817 "PICOERCE" 2454924 NIL PICOERCE (NIL T) -7 NIL NIL) (-914 2454013 2454151 2454327 "PGROEB" 2454548 NIL PGROEB (NIL T) -7 NIL NIL) (-913 2449600 2450414 2451319 "PGE" 2453128 T PGE (NIL) -7 NIL NIL) (-912 2447724 2447970 2448336 "PGCD" 2449317 NIL PGCD (NIL T T T T) -7 NIL NIL) (-911 2447062 2447165 2447326 "PFRPAC" 2447608 NIL PFRPAC (NIL T) -7 NIL NIL) (-910 2443677 2445610 2445963 "PFR" 2446741 NIL PFR (NIL T) -8 NIL NIL) (-909 2442066 2442310 2442635 "PFOTOOLS" 2443424 NIL PFOTOOLS (NIL T T) -7 NIL NIL) (-908 2436931 2437596 2438345 "PFORP" 2441408 NIL PFORP (NIL T T T NIL) -7 NIL NIL) (-907 2435464 2435703 2436054 "PFOQ" 2436688 NIL PFOQ (NIL T T T) -7 NIL NIL) (-906 2433937 2434149 2434512 "PFO" 2435248 NIL PFO (NIL T T T T T) -7 NIL NIL) (-905 2430460 2433826 2433895 "PF" 2433900 NIL PF (NIL NIL) -8 NIL NIL) (-904 2427885 2429166 2429195 "PFECAT" 2429780 T PFECAT (NIL) -9 NIL 2430163) (-903 2427330 2427484 2427698 "PFECAT-" 2427703 NIL PFECAT- (NIL T) -8 NIL NIL) (-902 2425934 2426185 2426486 "PFBRU" 2427079 NIL PFBRU (NIL T T) -7 NIL NIL) (-901 2423801 2424152 2424584 "PFBR" 2425585 NIL PFBR (NIL T T T T) -7 NIL NIL) (-900 2419657 2421181 2421855 "PERM" 2423160 NIL PERM (NIL T) -8 NIL NIL) (-899 2414924 2415864 2416734 "PERMGRP" 2418820 NIL PERMGRP (NIL T) -8 NIL NIL) (-898 2412995 2413988 2414030 "PERMCAT" 2414476 NIL PERMCAT (NIL T) -9 NIL 2414779) (-897 2412648 2412689 2412813 "PERMAN" 2412948 NIL PERMAN (NIL NIL T) -7 NIL NIL) (-896 2410094 2412217 2412348 "PENDTREE" 2412550 NIL PENDTREE (NIL T) -8 NIL NIL) (-895 2408162 2408940 2408982 "PDRING" 2409639 NIL PDRING (NIL T) -9 NIL 2409925) (-894 2407265 2407483 2407845 "PDRING-" 2407850 NIL PDRING- (NIL T T) -8 NIL NIL) (-893 2404407 2405157 2405848 "PDEPROB" 2406594 T PDEPROB (NIL) -8 NIL NIL) (-892 2401954 2402456 2403011 "PDEPACK" 2403872 T PDEPACK (NIL) -7 NIL NIL) (-891 2400866 2401056 2401307 "PDECOMP" 2401753 NIL PDECOMP (NIL T T) -7 NIL NIL) (-890 2398470 2399287 2399316 "PDECAT" 2400103 T PDECAT (NIL) -9 NIL 2400816) (-889 2398221 2398254 2398344 "PCOMP" 2398431 NIL PCOMP (NIL T T) -7 NIL NIL) (-888 2396426 2397022 2397319 "PBWLB" 2397950 NIL PBWLB (NIL T) -8 NIL NIL) (-887 2388931 2390499 2391837 "PATTERN" 2395109 NIL PATTERN (NIL T) -8 NIL NIL) (-886 2388563 2388620 2388729 "PATTERN2" 2388868 NIL PATTERN2 (NIL T T) -7 NIL NIL) (-885 2386320 2386708 2387165 "PATTERN1" 2388152 NIL PATTERN1 (NIL T T) -7 NIL NIL) (-884 2383715 2384269 2384750 "PATRES" 2385885 NIL PATRES (NIL T T) -8 NIL NIL) (-883 2383279 2383346 2383478 "PATRES2" 2383642 NIL PATRES2 (NIL T T T) -7 NIL NIL) (-882 2381162 2381567 2381974 "PATMATCH" 2382946 NIL PATMATCH (NIL T T T) -7 NIL NIL) (-881 2380697 2380880 2380922 "PATMAB" 2381029 NIL PATMAB (NIL T) -9 NIL 2381112) (-880 2379242 2379551 2379809 "PATLRES" 2380502 NIL PATLRES (NIL T T T) -8 NIL NIL) (-879 2378789 2378912 2378954 "PATAB" 2378959 NIL PATAB (NIL T) -9 NIL 2379129) (-878 2376270 2376802 2377375 "PARTPERM" 2378236 T PARTPERM (NIL) -7 NIL NIL) (-877 2375891 2375954 2376056 "PARSURF" 2376201 NIL PARSURF (NIL T) -8 NIL NIL) (-876 2375523 2375580 2375689 "PARSU2" 2375828 NIL PARSU2 (NIL T T) -7 NIL NIL) (-875 2375144 2375207 2375309 "PARSCURV" 2375454 NIL PARSCURV (NIL T) -8 NIL NIL) (-874 2374776 2374833 2374942 "PARSC2" 2375081 NIL PARSC2 (NIL T T) -7 NIL NIL) (-873 2374415 2374473 2374570 "PARPCURV" 2374712 NIL PARPCURV (NIL T) -8 NIL NIL) (-872 2374047 2374104 2374213 "PARPC2" 2374352 NIL PARPC2 (NIL T T) -7 NIL NIL) (-871 2372527 2372645 2372964 "PARAMP" 2373902 NIL PARAMP (NIL T NIL T T T T T) -7 NIL NIL) (-870 2372047 2372133 2372252 "PAN2EXPR" 2372428 T PAN2EXPR (NIL) -7 NIL NIL) (-869 2370853 2371168 2371396 "PALETTE" 2371839 T PALETTE (NIL) -8 NIL NIL) (-868 2358486 2360652 2362768 "PAFF" 2368801 NIL PAFF (NIL T NIL T) -7 NIL NIL) (-867 2345482 2347810 2350021 "PAFFFF" 2356339 NIL PAFFFF (NIL T NIL T) -7 NIL NIL) (-866 2339323 2344741 2344935 "PADICRC" 2345337 NIL PADICRC (NIL NIL T) -8 NIL NIL) (-865 2332522 2338669 2338853 "PADICRAT" 2339171 NIL PADICRAT (NIL NIL) -8 NIL NIL) (-864 2330826 2332459 2332504 "PADIC" 2332509 NIL PADIC (NIL NIL) -8 NIL NIL) (-863 2328026 2329600 2329641 "PADICCT" 2330222 NIL PADICCT (NIL NIL) -9 NIL 2330504) (-862 2326983 2327183 2327451 "PADEPAC" 2327813 NIL PADEPAC (NIL T NIL NIL) -7 NIL NIL) (-861 2326195 2326328 2326534 "PADE" 2326845 NIL PADE (NIL T T T) -7 NIL NIL) (-860 2322672 2325813 2325932 "PACRAT" 2326096 T PACRAT (NIL) -8 NIL NIL) (-859 2318733 2321783 2321812 "PACRATC" 2321817 T PACRATC (NIL) -9 NIL 2321897) (-858 2314855 2316820 2316849 "PACPERC" 2317795 T PACPERC (NIL) -9 NIL 2318235) (-857 2311525 2314629 2314720 "PACOFF" 2314796 NIL PACOFF (NIL T) -8 NIL NIL) (-856 2308220 2310880 2310909 "PACFFC" 2310914 T PACFFC (NIL) -9 NIL 2310935) (-855 2304310 2307903 2308004 "PACEXT" 2308151 NIL PACEXT (NIL NIL) -8 NIL NIL) (-854 2299688 2303205 2303234 "PACEXTC" 2303239 T PACEXTC (NIL) -9 NIL 2303283) (-853 2297696 2298528 2298843 "OWP" 2299457 NIL OWP (NIL T NIL NIL NIL) -8 NIL NIL) (-852 2296805 2297301 2297473 "OVAR" 2297564 NIL OVAR (NIL NIL) -8 NIL NIL) (-851 2296069 2296190 2296351 "OUT" 2296664 T OUT (NIL) -7 NIL NIL) (-850 2285115 2287294 2289464 "OUTFORM" 2293919 T OUTFORM (NIL) -8 NIL NIL) (-849 2284523 2284844 2284933 "OSI" 2285046 T OSI (NIL) -8 NIL NIL) (-848 2283270 2283497 2283781 "ORTHPOL" 2284271 NIL ORTHPOL (NIL T) -7 NIL NIL) (-847 2280632 2282927 2283067 "OREUP" 2283213 NIL OREUP (NIL NIL T NIL NIL) -8 NIL NIL) (-846 2278019 2280321 2280449 "ORESUP" 2280574 NIL ORESUP (NIL T NIL NIL) -8 NIL NIL) (-845 2275527 2276033 2276598 "OREPCTO" 2277504 NIL OREPCTO (NIL T T) -7 NIL NIL) (-844 2269397 2271608 2271650 "OREPCAT" 2273998 NIL OREPCAT (NIL T) -9 NIL 2275098) (-843 2266544 2267326 2268384 "OREPCAT-" 2268389 NIL OREPCAT- (NIL T T) -8 NIL NIL) (-842 2265720 2265992 2266021 "ORDSET" 2266330 T ORDSET (NIL) -9 NIL 2266494) (-841 2265239 2265361 2265554 "ORDSET-" 2265559 NIL ORDSET- (NIL T) -8 NIL NIL) (-840 2263848 2264649 2264678 "ORDRING" 2264880 T ORDRING (NIL) -9 NIL 2265005) (-839 2263493 2263587 2263731 "ORDRING-" 2263736 NIL ORDRING- (NIL T) -8 NIL NIL) (-838 2262867 2263348 2263377 "ORDMON" 2263382 T ORDMON (NIL) -9 NIL 2263403) (-837 2262029 2262176 2262371 "ORDFUNS" 2262716 NIL ORDFUNS (NIL NIL T) -7 NIL NIL) (-836 2261539 2261898 2261927 "ORDFIN" 2261932 T ORDFIN (NIL) -9 NIL 2261953) (-835 2258051 2260131 2260537 "ORDCOMP" 2261166 NIL ORDCOMP (NIL T) -8 NIL NIL) (-834 2257317 2257444 2257630 "ORDCOMP2" 2257911 NIL ORDCOMP2 (NIL T T) -7 NIL NIL) (-833 2253825 2254707 2255544 "OPTPROB" 2256500 T OPTPROB (NIL) -8 NIL NIL) (-832 2250627 2251266 2251970 "OPTPACK" 2253141 T OPTPACK (NIL) -7 NIL NIL) (-831 2248339 2249079 2249108 "OPTCAT" 2249927 T OPTCAT (NIL) -9 NIL 2250577) (-830 2248107 2248146 2248212 "OPQUERY" 2248293 T OPQUERY (NIL) -7 NIL NIL) (-829 2245233 2246424 2246925 "OP" 2247639 NIL OP (NIL T) -8 NIL NIL) (-828 2241998 2244036 2244402 "ONECOMP" 2244900 NIL ONECOMP (NIL T) -8 NIL NIL) (-827 2241303 2241418 2241592 "ONECOMP2" 2241870 NIL ONECOMP2 (NIL T T) -7 NIL NIL) (-826 2240722 2240828 2240958 "OMSERVER" 2241193 T OMSERVER (NIL) -7 NIL NIL) (-825 2237609 2240161 2240202 "OMSAGG" 2240263 NIL OMSAGG (NIL T) -9 NIL 2240327) (-824 2236232 2236495 2236777 "OMPKG" 2237347 T OMPKG (NIL) -7 NIL NIL) (-823 2235661 2235764 2235793 "OM" 2236092 T OM (NIL) -9 NIL NIL) (-822 2234199 2235212 2235380 "OMLO" 2235543 NIL OMLO (NIL T T) -8 NIL NIL) (-821 2233124 2233271 2233498 "OMEXPR" 2234025 NIL OMEXPR (NIL T) -7 NIL NIL) (-820 2232442 2232670 2232806 "OMERR" 2233008 T OMERR (NIL) -8 NIL NIL) (-819 2231620 2231863 2232023 "OMERRK" 2232302 T OMERRK (NIL) -8 NIL NIL) (-818 2231098 2231297 2231405 "OMENC" 2231532 T OMENC (NIL) -8 NIL NIL) (-817 2224993 2226178 2227349 "OMDEV" 2229947 T OMDEV (NIL) -8 NIL NIL) (-816 2224062 2224233 2224427 "OMCONN" 2224819 T OMCONN (NIL) -8 NIL NIL) (-815 2222673 2223659 2223688 "OINTDOM" 2223693 T OINTDOM (NIL) -9 NIL 2223714) (-814 2218324 2219579 2220323 "OFMONOID" 2221961 NIL OFMONOID (NIL T) -8 NIL NIL) (-813 2217762 2218261 2218306 "ODVAR" 2218311 NIL ODVAR (NIL T) -8 NIL NIL) (-812 2214889 2217261 2217445 "ODR" 2217638 NIL ODR (NIL T T NIL) -8 NIL NIL) (-811 2207187 2214665 2214791 "ODPOL" 2214796 NIL ODPOL (NIL T) -8 NIL NIL) (-810 2200981 2207059 2207164 "ODP" 2207169 NIL ODP (NIL NIL T NIL) -8 NIL NIL) (-809 2199747 2199962 2200237 "ODETOOLS" 2200755 NIL ODETOOLS (NIL T T) -7 NIL NIL) (-808 2196716 2197372 2198088 "ODESYS" 2199080 NIL ODESYS (NIL T T) -7 NIL NIL) (-807 2191600 2192508 2193532 "ODERTRIC" 2195792 NIL ODERTRIC (NIL T T) -7 NIL NIL) (-806 2191026 2191108 2191302 "ODERED" 2191512 NIL ODERED (NIL T T T T T) -7 NIL NIL) (-805 2187914 2188462 2189139 "ODERAT" 2190449 NIL ODERAT (NIL T T) -7 NIL NIL) (-804 2184874 2185338 2185935 "ODEPRRIC" 2187443 NIL ODEPRRIC (NIL T T T T) -7 NIL NIL) (-803 2182745 2183312 2183821 "ODEPROB" 2184385 T ODEPROB (NIL) -8 NIL NIL) (-802 2179267 2179750 2180397 "ODEPRIM" 2182224 NIL ODEPRIM (NIL T T T T) -7 NIL NIL) (-801 2178516 2178618 2178878 "ODEPAL" 2179159 NIL ODEPAL (NIL T T T T) -7 NIL NIL) (-800 2174678 2175469 2176333 "ODEPACK" 2177672 T ODEPACK (NIL) -7 NIL NIL) (-799 2173711 2173818 2174047 "ODEINT" 2174567 NIL ODEINT (NIL T T) -7 NIL NIL) (-798 2167812 2169237 2170684 "ODEIFTBL" 2172284 T ODEIFTBL (NIL) -8 NIL NIL) (-797 2163147 2163933 2164892 "ODEEF" 2166971 NIL ODEEF (NIL T T) -7 NIL NIL) (-796 2162482 2162571 2162801 "ODECONST" 2163052 NIL ODECONST (NIL T T T) -7 NIL NIL) (-795 2160632 2161267 2161296 "ODECAT" 2161901 T ODECAT (NIL) -9 NIL 2162432) (-794 2157493 2160344 2160463 "OCT" 2160545 NIL OCT (NIL T) -8 NIL NIL) (-793 2157131 2157174 2157301 "OCTCT2" 2157444 NIL OCTCT2 (NIL T T T T) -7 NIL NIL) (-792 2151955 2154399 2154440 "OC" 2155537 NIL OC (NIL T) -9 NIL 2156387) (-791 2149182 2149930 2150920 "OC-" 2151014 NIL OC- (NIL T T) -8 NIL NIL) (-790 2148559 2149001 2149030 "OCAMON" 2149035 T OCAMON (NIL) -9 NIL 2149056) (-789 2148011 2148418 2148447 "OASGP" 2148452 T OASGP (NIL) -9 NIL 2148472) (-788 2147297 2147760 2147789 "OAMONS" 2147829 T OAMONS (NIL) -9 NIL 2147872) (-787 2146736 2147143 2147172 "OAMON" 2147177 T OAMON (NIL) -9 NIL 2147197) (-786 2146039 2146531 2146560 "OAGROUP" 2146565 T OAGROUP (NIL) -9 NIL 2146585) (-785 2145729 2145779 2145867 "NUMTUBE" 2145983 NIL NUMTUBE (NIL T) -7 NIL NIL) (-784 2139302 2140820 2142356 "NUMQUAD" 2144213 T NUMQUAD (NIL) -7 NIL NIL) (-783 2135058 2136046 2137071 "NUMODE" 2138297 T NUMODE (NIL) -7 NIL NIL) (-782 2132438 2133292 2133321 "NUMINT" 2134244 T NUMINT (NIL) -9 NIL 2135008) (-781 2131386 2131583 2131801 "NUMFMT" 2132240 T NUMFMT (NIL) -7 NIL NIL) (-780 2117764 2120706 2123230 "NUMERIC" 2128901 NIL NUMERIC (NIL T) -7 NIL NIL) (-779 2112167 2117212 2117308 "NTSCAT" 2117313 NIL NTSCAT (NIL T T T T) -9 NIL 2117352) (-778 2111363 2111528 2111720 "NTPOLFN" 2112007 NIL NTPOLFN (NIL T) -7 NIL NIL) (-777 2099159 2108190 2109001 "NSUP" 2110585 NIL NSUP (NIL T) -8 NIL NIL) (-776 2098791 2098848 2098957 "NSUP2" 2099096 NIL NSUP2 (NIL T T) -7 NIL NIL) (-775 2088742 2098565 2098698 "NSMP" 2098703 NIL NSMP (NIL T T) -8 NIL NIL) (-774 2076834 2088324 2088488 "NSDPS" 2088610 NIL NSDPS (NIL T) -8 NIL NIL) (-773 2075266 2075567 2075924 "NREP" 2076522 NIL NREP (NIL T) -7 NIL NIL) (-772 2072355 2072903 2073552 "NPOLYGON" 2074708 NIL NPOLYGON (NIL T T T NIL) -7 NIL NIL) (-771 2070946 2071198 2071556 "NPCOEF" 2072098 NIL NPCOEF (NIL T T T T T) -7 NIL NIL) (-770 2070228 2070730 2070814 "NOTTING" 2070894 NIL NOTTING (NIL T) -8 NIL NIL) (-769 2069294 2069409 2069625 "NORMRETR" 2070109 NIL NORMRETR (NIL T T T T NIL) -7 NIL NIL) (-768 2067335 2067625 2068034 "NORMPK" 2069002 NIL NORMPK (NIL T T T T T) -7 NIL NIL) (-767 2067020 2067048 2067172 "NORMMA" 2067301 NIL NORMMA (NIL T T T T) -7 NIL NIL) (-766 2066847 2066977 2067006 "NONE" 2067011 T NONE (NIL) -8 NIL NIL) (-765 2066636 2066665 2066734 "NONE1" 2066811 NIL NONE1 (NIL T) -7 NIL NIL) (-764 2066119 2066181 2066367 "NODE1" 2066568 NIL NODE1 (NIL T T) -7 NIL NIL) (-763 2064413 2065282 2065537 "NNI" 2065884 T NNI (NIL) -8 NIL NIL) (-762 2062833 2063146 2063510 "NLINSOL" 2064081 NIL NLINSOL (NIL T) -7 NIL NIL) (-761 2059001 2059968 2060890 "NIPROB" 2061931 T NIPROB (NIL) -8 NIL NIL) (-760 2057758 2057992 2058294 "NFINTBAS" 2058763 NIL NFINTBAS (NIL T T) -7 NIL NIL) (-759 2057487 2057530 2057611 "NEWTON" 2057709 NIL NEWTON (NIL T) -7 NIL NIL) (-758 2056195 2056426 2056707 "NCODIV" 2057255 NIL NCODIV (NIL T T) -7 NIL NIL) (-757 2055957 2055994 2056069 "NCNTFRAC" 2056152 NIL NCNTFRAC (NIL T) -7 NIL NIL) (-756 2054137 2054501 2054921 "NCEP" 2055582 NIL NCEP (NIL T) -7 NIL NIL) (-755 2053047 2053786 2053815 "NASRING" 2053925 T NASRING (NIL) -9 NIL 2053999) (-754 2052842 2052886 2052980 "NASRING-" 2052985 NIL NASRING- (NIL T) -8 NIL NIL) (-753 2051994 2052493 2052522 "NARNG" 2052639 T NARNG (NIL) -9 NIL 2052730) (-752 2051686 2051753 2051887 "NARNG-" 2051892 NIL NARNG- (NIL T) -8 NIL NIL) (-751 2050565 2050772 2051007 "NAGSP" 2051471 T NAGSP (NIL) -7 NIL NIL) (-750 2041837 2043521 2045194 "NAGS" 2048912 T NAGS (NIL) -7 NIL NIL) (-749 2040385 2040693 2041024 "NAGF07" 2041526 T NAGF07 (NIL) -7 NIL NIL) (-748 2034923 2036214 2037521 "NAGF04" 2039098 T NAGF04 (NIL) -7 NIL NIL) (-747 2027891 2029505 2031138 "NAGF02" 2033310 T NAGF02 (NIL) -7 NIL NIL) (-746 2023115 2024215 2025332 "NAGF01" 2026794 T NAGF01 (NIL) -7 NIL NIL) (-745 2016743 2018309 2019894 "NAGE04" 2021550 T NAGE04 (NIL) -7 NIL NIL) (-744 2007912 2010033 2012163 "NAGE02" 2014633 T NAGE02 (NIL) -7 NIL NIL) (-743 2003865 2004812 2005776 "NAGE01" 2006968 T NAGE01 (NIL) -7 NIL NIL) (-742 2001660 2002194 2002752 "NAGD03" 2003327 T NAGD03 (NIL) -7 NIL NIL) (-741 1993410 1995338 1997292 "NAGD02" 1999726 T NAGD02 (NIL) -7 NIL NIL) (-740 1987221 1988646 1990086 "NAGD01" 1991990 T NAGD01 (NIL) -7 NIL NIL) (-739 1983430 1984252 1985089 "NAGC06" 1986404 T NAGC06 (NIL) -7 NIL NIL) (-738 1981895 1982227 1982583 "NAGC05" 1983094 T NAGC05 (NIL) -7 NIL NIL) (-737 1981271 1981390 1981534 "NAGC02" 1981771 T NAGC02 (NIL) -7 NIL NIL) (-736 1980330 1980887 1980928 "NAALG" 1981007 NIL NAALG (NIL T) -9 NIL 1981068) (-735 1980165 1980194 1980284 "NAALG-" 1980289 NIL NAALG- (NIL T T) -8 NIL NIL) (-734 1971041 1979281 1979556 "MYUP" 1979936 NIL MYUP (NIL NIL T) -8 NIL NIL) (-733 1961404 1969497 1969868 "MYEXPR" 1970736 NIL MYEXPR (NIL NIL T) -8 NIL NIL) (-732 1955354 1956462 1957649 "MULTSQFR" 1960300 NIL MULTSQFR (NIL T T T T) -7 NIL NIL) (-731 1954673 1954748 1954932 "MULTFACT" 1955266 NIL MULTFACT (NIL T T T T) -7 NIL NIL) (-730 1947798 1951707 1951761 "MTSCAT" 1952831 NIL MTSCAT (NIL T T) -9 NIL 1953345) (-729 1947510 1947564 1947656 "MTHING" 1947738 NIL MTHING (NIL T) -7 NIL NIL) (-728 1947302 1947335 1947395 "MSYSCMD" 1947470 T MSYSCMD (NIL) -7 NIL NIL) (-727 1943414 1946057 1946377 "MSET" 1947015 NIL MSET (NIL T) -8 NIL NIL) (-726 1940508 1942974 1943016 "MSETAGG" 1943021 NIL MSETAGG (NIL T) -9 NIL 1943055) (-725 1936357 1937899 1938638 "MRING" 1939814 NIL MRING (NIL T T) -8 NIL NIL) (-724 1935923 1935990 1936121 "MRF2" 1936284 NIL MRF2 (NIL T T T) -7 NIL NIL) (-723 1935541 1935576 1935720 "MRATFAC" 1935882 NIL MRATFAC (NIL T T T T) -7 NIL NIL) (-722 1933153 1933448 1933879 "MPRFF" 1935246 NIL MPRFF (NIL T T T T) -7 NIL NIL) (-721 1927167 1933007 1933104 "MPOLY" 1933109 NIL MPOLY (NIL NIL T) -8 NIL NIL) (-720 1926657 1926692 1926900 "MPCPF" 1927126 NIL MPCPF (NIL T T T T) -7 NIL NIL) (-719 1926171 1926214 1926398 "MPC3" 1926608 NIL MPC3 (NIL T T T T T T T) -7 NIL NIL) (-718 1925366 1925447 1925668 "MPC2" 1926086 NIL MPC2 (NIL T T T T T T T) -7 NIL NIL) (-717 1923667 1924004 1924394 "MONOTOOL" 1925026 NIL MONOTOOL (NIL T T) -7 NIL NIL) (-716 1922790 1923125 1923154 "MONOID" 1923431 T MONOID (NIL) -9 NIL 1923603) (-715 1922168 1922331 1922574 "MONOID-" 1922579 NIL MONOID- (NIL T) -8 NIL NIL) (-714 1913094 1919079 1919139 "MONOGEN" 1919813 NIL MONOGEN (NIL T T) -9 NIL 1920266) (-713 1910312 1911047 1912047 "MONOGEN-" 1912166 NIL MONOGEN- (NIL T T T) -8 NIL NIL) (-712 1909170 1909590 1909619 "MONADWU" 1910011 T MONADWU (NIL) -9 NIL 1910249) (-711 1908542 1908701 1908949 "MONADWU-" 1908954 NIL MONADWU- (NIL T) -8 NIL NIL) (-710 1907926 1908144 1908173 "MONAD" 1908380 T MONAD (NIL) -9 NIL 1908492) (-709 1907611 1907689 1907821 "MONAD-" 1907826 NIL MONAD- (NIL T) -8 NIL NIL) (-708 1905862 1906524 1906803 "MOEBIUS" 1907364 NIL MOEBIUS (NIL T) -8 NIL NIL) (-707 1905253 1905631 1905672 "MODULE" 1905677 NIL MODULE (NIL T) -9 NIL 1905703) (-706 1904821 1904917 1905107 "MODULE-" 1905112 NIL MODULE- (NIL T T) -8 NIL NIL) (-705 1902490 1903185 1903512 "MODRING" 1904645 NIL MODRING (NIL T T NIL NIL NIL) -8 NIL NIL) (-704 1899436 1900601 1901119 "MODOP" 1902022 NIL MODOP (NIL T T) -8 NIL NIL) (-703 1897623 1898075 1898416 "MODMONOM" 1899235 NIL MODMONOM (NIL T T NIL) -8 NIL NIL) (-702 1887288 1895819 1896240 "MODMON" 1897253 NIL MODMON (NIL T T) -8 NIL NIL) (-701 1884414 1886132 1886408 "MODFIELD" 1887163 NIL MODFIELD (NIL T T NIL NIL NIL) -8 NIL NIL) (-700 1883418 1883695 1883885 "MMLFORM" 1884244 T MMLFORM (NIL) -8 NIL NIL) (-699 1882944 1882987 1883166 "MMAP" 1883369 NIL MMAP (NIL T T T T T T) -7 NIL NIL) (-698 1881169 1881946 1881988 "MLO" 1882411 NIL MLO (NIL T) -9 NIL 1882652) (-697 1878536 1879051 1879653 "MLIFT" 1880650 NIL MLIFT (NIL T T T T) -7 NIL NIL) (-696 1877927 1878011 1878165 "MKUCFUNC" 1878447 NIL MKUCFUNC (NIL T T T) -7 NIL NIL) (-695 1877526 1877596 1877719 "MKRECORD" 1877850 NIL MKRECORD (NIL T T) -7 NIL NIL) (-694 1876574 1876735 1876963 "MKFUNC" 1877337 NIL MKFUNC (NIL T) -7 NIL NIL) (-693 1875962 1876066 1876222 "MKFLCFN" 1876457 NIL MKFLCFN (NIL T) -7 NIL NIL) (-692 1875388 1875755 1875844 "MKCHSET" 1875906 NIL MKCHSET (NIL T) -8 NIL NIL) (-691 1874665 1874767 1874952 "MKBCFUNC" 1875281 NIL MKBCFUNC (NIL T T T T) -7 NIL NIL) (-690 1871349 1874219 1874355 "MINT" 1874549 T MINT (NIL) -8 NIL NIL) (-689 1870161 1870404 1870681 "MHROWRED" 1871104 NIL MHROWRED (NIL T) -7 NIL NIL) (-688 1865428 1868602 1869028 "MFLOAT" 1869755 T MFLOAT (NIL) -8 NIL NIL) (-687 1864785 1864861 1865032 "MFINFACT" 1865340 NIL MFINFACT (NIL T T T T) -7 NIL NIL) (-686 1861100 1861948 1862832 "MESH" 1863921 T MESH (NIL) -7 NIL NIL) (-685 1859490 1859802 1860155 "MDDFACT" 1860787 NIL MDDFACT (NIL T) -7 NIL NIL) (-684 1856372 1858683 1858725 "MDAGG" 1858980 NIL MDAGG (NIL T) -9 NIL 1859123) (-683 1846060 1855665 1855872 "MCMPLX" 1856185 T MCMPLX (NIL) -8 NIL NIL) (-682 1845201 1845347 1845547 "MCDEN" 1845909 NIL MCDEN (NIL T T) -7 NIL NIL) (-681 1843091 1843361 1843741 "MCALCFN" 1844931 NIL MCALCFN (NIL T T T T) -7 NIL NIL) (-680 1840703 1841226 1841788 "MATSTOR" 1842562 NIL MATSTOR (NIL T) -7 NIL NIL) (-679 1836617 1840079 1840325 "MATRIX" 1840490 NIL MATRIX (NIL T) -8 NIL NIL) (-678 1832393 1833096 1833829 "MATLIN" 1835977 NIL MATLIN (NIL T T T T) -7 NIL NIL) (-677 1822158 1825379 1825457 "MATCAT" 1830587 NIL MATCAT (NIL T T T) -9 NIL 1832094) (-676 1818357 1819425 1820836 "MATCAT-" 1820841 NIL MATCAT- (NIL T T T T) -8 NIL NIL) (-675 1816951 1817104 1817437 "MATCAT2" 1818192 NIL MATCAT2 (NIL T T T T T T T T) -7 NIL NIL) (-674 1815691 1815957 1816272 "MAPPKG4" 1816682 NIL MAPPKG4 (NIL T T) -7 NIL NIL) (-673 1813803 1814127 1814511 "MAPPKG3" 1815366 NIL MAPPKG3 (NIL T T T) -7 NIL NIL) (-672 1812784 1812957 1813179 "MAPPKG2" 1813627 NIL MAPPKG2 (NIL T T) -7 NIL NIL) (-671 1811283 1811567 1811894 "MAPPKG1" 1812490 NIL MAPPKG1 (NIL T) -7 NIL NIL) (-670 1810894 1810952 1811075 "MAPHACK3" 1811219 NIL MAPHACK3 (NIL T T T) -7 NIL NIL) (-669 1810486 1810547 1810661 "MAPHACK2" 1810826 NIL MAPHACK2 (NIL T T) -7 NIL NIL) (-668 1809924 1810027 1810169 "MAPHACK1" 1810377 NIL MAPHACK1 (NIL T) -7 NIL NIL) (-667 1808030 1808624 1808928 "MAGMA" 1809652 NIL MAGMA (NIL T) -8 NIL NIL) (-666 1804505 1806271 1806731 "M3D" 1807603 NIL M3D (NIL T) -8 NIL NIL) (-665 1798699 1802905 1802947 "LZSTAGG" 1803729 NIL LZSTAGG (NIL T) -9 NIL 1804024) (-664 1794673 1795830 1797287 "LZSTAGG-" 1797292 NIL LZSTAGG- (NIL T T) -8 NIL NIL) (-663 1791787 1792564 1793051 "LWORD" 1794218 NIL LWORD (NIL T) -8 NIL NIL) (-662 1784942 1791558 1791692 "LSQM" 1791697 NIL LSQM (NIL NIL T) -8 NIL NIL) (-661 1784166 1784305 1784533 "LSPP" 1784797 NIL LSPP (NIL T T T T) -7 NIL NIL) (-660 1781978 1782279 1782735 "LSMP" 1783855 NIL LSMP (NIL T T T T) -7 NIL NIL) (-659 1778757 1779431 1780161 "LSMP1" 1781280 NIL LSMP1 (NIL T) -7 NIL NIL) (-658 1772714 1777947 1777989 "LSAGG" 1778051 NIL LSAGG (NIL T) -9 NIL 1778129) (-657 1769409 1770333 1771546 "LSAGG-" 1771551 NIL LSAGG- (NIL T T) -8 NIL NIL) (-656 1767035 1768553 1768802 "LPOLY" 1769204 NIL LPOLY (NIL T T) -8 NIL NIL) (-655 1766617 1766702 1766825 "LPEFRAC" 1766944 NIL LPEFRAC (NIL T) -7 NIL NIL) (-654 1764181 1764430 1764862 "LPARSPT" 1766359 NIL LPARSPT (NIL T NIL T T T T T) -7 NIL NIL) (-653 1762656 1762983 1763343 "LOP" 1763853 NIL LOP (NIL T) -7 NIL NIL) (-652 1761005 1761752 1762004 "LO" 1762489 NIL LO (NIL T T T) -8 NIL NIL) (-651 1760656 1760768 1760797 "LOGIC" 1760908 T LOGIC (NIL) -9 NIL 1760989) (-650 1760518 1760541 1760612 "LOGIC-" 1760617 NIL LOGIC- (NIL T) -8 NIL NIL) (-649 1759711 1759851 1760044 "LODOOPS" 1760374 NIL LODOOPS (NIL T T) -7 NIL NIL) (-648 1757123 1759627 1759693 "LODO" 1759698 NIL LODO (NIL T NIL) -8 NIL NIL) (-647 1755663 1755898 1756250 "LODOF" 1756871 NIL LODOF (NIL T T) -7 NIL NIL) (-646 1752062 1754503 1754545 "LODOCAT" 1754983 NIL LODOCAT (NIL T) -9 NIL 1755193) (-645 1751795 1751853 1751980 "LODOCAT-" 1751985 NIL LODOCAT- (NIL T T) -8 NIL NIL) (-644 1749104 1751636 1751754 "LODO2" 1751759 NIL LODO2 (NIL T T) -8 NIL NIL) (-643 1746528 1749041 1749086 "LODO1" 1749091 NIL LODO1 (NIL T) -8 NIL NIL) (-642 1745388 1745553 1745865 "LODEEF" 1746351 NIL LODEEF (NIL T T T) -7 NIL NIL) (-641 1738215 1742380 1742421 "LOCPOWC" 1743883 NIL LOCPOWC (NIL T) -9 NIL 1744460) (-640 1733539 1736377 1736419 "LNAGG" 1737366 NIL LNAGG (NIL T) -9 NIL 1737809) (-639 1732686 1732900 1733242 "LNAGG-" 1733247 NIL LNAGG- (NIL T T) -8 NIL NIL) (-638 1728849 1729611 1730250 "LMOPS" 1732101 NIL LMOPS (NIL T T NIL) -8 NIL NIL) (-637 1728243 1728605 1728647 "LMODULE" 1728708 NIL LMODULE (NIL T) -9 NIL 1728750) (-636 1725495 1727888 1728011 "LMDICT" 1728153 NIL LMDICT (NIL T) -8 NIL NIL) (-635 1724652 1724786 1724973 "LISYSER" 1725357 NIL LISYSER (NIL T T) -7 NIL NIL) (-634 1717889 1723602 1723898 "LIST" 1724389 NIL LIST (NIL T) -8 NIL NIL) (-633 1717414 1717488 1717627 "LIST3" 1717809 NIL LIST3 (NIL T T T) -7 NIL NIL) (-632 1716421 1716599 1716827 "LIST2" 1717232 NIL LIST2 (NIL T T) -7 NIL NIL) (-631 1714555 1714867 1715266 "LIST2MAP" 1716068 NIL LIST2MAP (NIL T T) -7 NIL NIL) (-630 1713260 1713940 1713982 "LINEXP" 1714237 NIL LINEXP (NIL T) -9 NIL 1714386) (-629 1711907 1712167 1712464 "LINDEP" 1713012 NIL LINDEP (NIL T T) -7 NIL NIL) (-628 1708674 1709393 1710170 "LIMITRF" 1711162 NIL LIMITRF (NIL T) -7 NIL NIL) (-627 1706950 1707245 1707661 "LIMITPS" 1708369 NIL LIMITPS (NIL T T) -7 NIL NIL) (-626 1701409 1706465 1706691 "LIE" 1706773 NIL LIE (NIL T T) -8 NIL NIL) (-625 1700458 1700901 1700942 "LIECAT" 1701082 NIL LIECAT (NIL T) -9 NIL 1701232) (-624 1700299 1700326 1700414 "LIECAT-" 1700419 NIL LIECAT- (NIL T T) -8 NIL NIL) (-623 1692833 1699678 1699861 "LIB" 1700136 T LIB (NIL) -8 NIL NIL) (-622 1688470 1689351 1690286 "LGROBP" 1691950 NIL LGROBP (NIL NIL T) -7 NIL NIL) (-621 1685951 1686275 1686686 "LF" 1688143 NIL LF (NIL T T) -7 NIL NIL) (-620 1684648 1685378 1685407 "LFCAT" 1685682 T LFCAT (NIL) -9 NIL 1685857) (-619 1681552 1682180 1682868 "LEXTRIPK" 1684012 NIL LEXTRIPK (NIL T NIL) -7 NIL NIL) (-618 1678258 1679122 1679625 "LEXP" 1681132 NIL LEXP (NIL T T NIL) -8 NIL NIL) (-617 1676656 1676969 1677370 "LEADCDET" 1677940 NIL LEADCDET (NIL T T T T) -7 NIL NIL) (-616 1675846 1675920 1676149 "LAZM3PK" 1676577 NIL LAZM3PK (NIL T T T T T T) -7 NIL NIL) (-615 1670762 1673929 1674464 "LAUPOL" 1675361 NIL LAUPOL (NIL T T) -8 NIL NIL) (-614 1670327 1670371 1670539 "LAPLACE" 1670712 NIL LAPLACE (NIL T T) -7 NIL NIL) (-613 1668257 1669430 1669680 "LA" 1670161 NIL LA (NIL T T T) -8 NIL NIL) (-612 1667313 1667907 1667949 "LALG" 1668011 NIL LALG (NIL T) -9 NIL 1668070) (-611 1667027 1667086 1667222 "LALG-" 1667227 NIL LALG- (NIL T T) -8 NIL NIL) (-610 1665931 1666118 1666417 "KOVACIC" 1666827 NIL KOVACIC (NIL T T) -7 NIL NIL) (-609 1665765 1665789 1665831 "KONVERT" 1665893 NIL KONVERT (NIL T) -9 NIL NIL) (-608 1665599 1665623 1665665 "KOERCE" 1665727 NIL KOERCE (NIL T) -9 NIL NIL) (-607 1663335 1664095 1664487 "KERNEL" 1665239 NIL KERNEL (NIL T) -8 NIL NIL) (-606 1662837 1662918 1663048 "KERNEL2" 1663249 NIL KERNEL2 (NIL T T) -7 NIL NIL) (-605 1656520 1661202 1661257 "KDAGG" 1661634 NIL KDAGG (NIL T T) -9 NIL 1661840) (-604 1656049 1656173 1656378 "KDAGG-" 1656383 NIL KDAGG- (NIL T T T) -8 NIL NIL) (-603 1649198 1655710 1655865 "KAFILE" 1655927 NIL KAFILE (NIL T) -8 NIL NIL) (-602 1643657 1648713 1648939 "JORDAN" 1649021 NIL JORDAN (NIL T T) -8 NIL NIL) (-601 1640000 1641900 1641955 "IXAGG" 1642884 NIL IXAGG (NIL T T) -9 NIL 1643339) (-600 1638919 1639225 1639644 "IXAGG-" 1639649 NIL IXAGG- (NIL T T T) -8 NIL NIL) (-599 1634503 1638841 1638900 "IVECTOR" 1638905 NIL IVECTOR (NIL T NIL) -8 NIL NIL) (-598 1633269 1633506 1633772 "ITUPLE" 1634270 NIL ITUPLE (NIL T) -8 NIL NIL) (-597 1631693 1631870 1632178 "ITRIGMNP" 1633091 NIL ITRIGMNP (NIL T T T) -7 NIL NIL) (-596 1630438 1630642 1630925 "ITFUN3" 1631469 NIL ITFUN3 (NIL T T T) -7 NIL NIL) (-595 1630070 1630127 1630236 "ITFUN2" 1630375 NIL ITFUN2 (NIL T T) -7 NIL NIL) (-594 1627863 1628934 1629232 "ITAYLOR" 1629805 NIL ITAYLOR (NIL T) -8 NIL NIL) (-593 1616802 1622002 1623164 "ISUPS" 1626734 NIL ISUPS (NIL T) -8 NIL NIL) (-592 1615906 1616046 1616282 "ISUMP" 1616649 NIL ISUMP (NIL T T T T) -7 NIL NIL) (-591 1611176 1615707 1615786 "ISTRING" 1615859 NIL ISTRING (NIL NIL) -8 NIL NIL) (-590 1610386 1610467 1610683 "IRURPK" 1611090 NIL IRURPK (NIL T T T T T) -7 NIL NIL) (-589 1609322 1609523 1609763 "IRSN" 1610166 T IRSN (NIL) -7 NIL NIL) (-588 1607353 1607708 1608143 "IRRF2F" 1608961 NIL IRRF2F (NIL T) -7 NIL NIL) (-587 1607100 1607138 1607214 "IRREDFFX" 1607309 NIL IRREDFFX (NIL T) -7 NIL NIL) (-586 1605715 1605974 1606273 "IROOT" 1606833 NIL IROOT (NIL T) -7 NIL NIL) (-585 1602351 1603403 1604093 "IR" 1605057 NIL IR (NIL T) -8 NIL NIL) (-584 1599964 1600459 1601025 "IR2" 1601829 NIL IR2 (NIL T T) -7 NIL NIL) (-583 1599036 1599149 1599370 "IR2F" 1599847 NIL IR2F (NIL T T) -7 NIL NIL) (-582 1598827 1598861 1598921 "IPRNTPK" 1598996 T IPRNTPK (NIL) -7 NIL NIL) (-581 1595381 1598716 1598785 "IPF" 1598790 NIL IPF (NIL NIL) -8 NIL NIL) (-580 1593698 1595306 1595363 "IPADIC" 1595368 NIL IPADIC (NIL NIL NIL) -8 NIL NIL) (-579 1593195 1593253 1593443 "INVLAPLA" 1593634 NIL INVLAPLA (NIL T T) -7 NIL NIL) (-578 1582844 1585197 1587583 "INTTR" 1590859 NIL INTTR (NIL T T) -7 NIL NIL) (-577 1579202 1579944 1580801 "INTTOOLS" 1582036 NIL INTTOOLS (NIL T T) -7 NIL NIL) (-576 1578788 1578879 1578996 "INTSLPE" 1579105 T INTSLPE (NIL) -7 NIL NIL) (-575 1576738 1578711 1578770 "INTRVL" 1578775 NIL INTRVL (NIL T) -8 NIL NIL) (-574 1574340 1574852 1575427 "INTRF" 1576223 NIL INTRF (NIL T) -7 NIL NIL) (-573 1573751 1573848 1573990 "INTRET" 1574238 NIL INTRET (NIL T) -7 NIL NIL) (-572 1571748 1572137 1572607 "INTRAT" 1573359 NIL INTRAT (NIL T T) -7 NIL NIL) (-571 1568984 1569567 1570189 "INTPM" 1571237 NIL INTPM (NIL T T) -7 NIL NIL) (-570 1565689 1566288 1567032 "INTPAF" 1568371 NIL INTPAF (NIL T T T) -7 NIL NIL) (-569 1560868 1561830 1562881 "INTPACK" 1564658 T INTPACK (NIL) -7 NIL NIL) (-568 1557722 1560597 1560724 "INT" 1560761 T INT (NIL) -8 NIL NIL) (-567 1556974 1557126 1557334 "INTHERTR" 1557564 NIL INTHERTR (NIL T T) -7 NIL NIL) (-566 1556413 1556493 1556681 "INTHERAL" 1556888 NIL INTHERAL (NIL T T T T) -7 NIL NIL) (-565 1554259 1554702 1555159 "INTHEORY" 1555976 T INTHEORY (NIL) -7 NIL NIL) (-564 1545570 1547190 1548968 "INTG0" 1552612 NIL INTG0 (NIL T T T) -7 NIL NIL) (-563 1526143 1530933 1535743 "INTFTBL" 1540780 T INTFTBL (NIL) -8 NIL NIL) (-562 1524180 1524387 1524788 "INTFRSP" 1525933 NIL INTFRSP (NIL T NIL T T T T T T) -7 NIL NIL) (-561 1523429 1523567 1523740 "INTFACT" 1524039 NIL INTFACT (NIL T) -7 NIL NIL) (-560 1523019 1523061 1523212 "INTERGB" 1523381 NIL INTERGB (NIL T NIL T T T) -7 NIL NIL) (-559 1520404 1520850 1521414 "INTEF" 1522573 NIL INTEF (NIL T T) -7 NIL NIL) (-558 1518861 1519610 1519639 "INTDOM" 1519940 T INTDOM (NIL) -9 NIL 1520147) (-557 1518230 1518404 1518646 "INTDOM-" 1518651 NIL INTDOM- (NIL T) -8 NIL NIL) (-556 1516834 1516939 1517329 "INTDIVP" 1518120 NIL INTDIVP (NIL T NIL T T T T T T T T T) -7 NIL NIL) (-555 1513320 1515250 1515305 "INTCAT" 1516104 NIL INTCAT (NIL T) -9 NIL 1516425) (-554 1512793 1512895 1513023 "INTBIT" 1513212 T INTBIT (NIL) -7 NIL NIL) (-553 1511464 1511618 1511932 "INTALG" 1512638 NIL INTALG (NIL T T T T T) -7 NIL NIL) (-552 1510921 1511011 1511181 "INTAF" 1511368 NIL INTAF (NIL T T) -7 NIL NIL) (-551 1504387 1510731 1510871 "INTABL" 1510876 NIL INTABL (NIL T T T) -8 NIL NIL) (-550 1499332 1502058 1502087 "INS" 1503055 T INS (NIL) -9 NIL 1503738) (-549 1496572 1497343 1498317 "INS-" 1498390 NIL INS- (NIL T) -8 NIL NIL) (-548 1495347 1495574 1495872 "INPSIGN" 1496325 NIL INPSIGN (NIL T T) -7 NIL NIL) (-547 1494465 1494582 1494779 "INPRODPF" 1495227 NIL INPRODPF (NIL T T) -7 NIL NIL) (-546 1493359 1493476 1493713 "INPRODFF" 1494345 NIL INPRODFF (NIL T T T T) -7 NIL NIL) (-545 1492359 1492511 1492771 "INNMFACT" 1493195 NIL INNMFACT (NIL T T T T) -7 NIL NIL) (-544 1491556 1491653 1491841 "INMODGCD" 1492258 NIL INMODGCD (NIL T T NIL NIL) -7 NIL NIL) (-543 1490065 1490309 1490633 "INFSP" 1491301 NIL INFSP (NIL T T T) -7 NIL NIL) (-542 1489249 1489366 1489549 "INFPROD0" 1489945 NIL INFPROD0 (NIL T T) -7 NIL NIL) (-541 1486130 1487314 1487829 "INFORM" 1488742 T INFORM (NIL) -8 NIL NIL) (-540 1485740 1485800 1485898 "INFORM1" 1486065 NIL INFORM1 (NIL T) -7 NIL NIL) (-539 1485263 1485352 1485466 "INFINITY" 1485646 T INFINITY (NIL) -7 NIL NIL) (-538 1482946 1483943 1484286 "INFCLSPT" 1485123 NIL INFCLSPT (NIL T NIL T T T T T T T) -8 NIL NIL) (-537 1480823 1482068 1482362 "INFCLSPS" 1482716 NIL INFCLSPS (NIL T NIL T) -8 NIL NIL) (-536 1473373 1474296 1474517 "INFCLCT" 1479948 NIL INFCLCT (NIL T NIL T T T T T T T) -9 NIL 1480759) (-535 1471991 1472239 1472560 "INEP" 1473121 NIL INEP (NIL T T T) -7 NIL NIL) (-534 1471267 1471888 1471953 "INDE" 1471958 NIL INDE (NIL T) -8 NIL NIL) (-533 1470831 1470899 1471016 "INCRMAPS" 1471194 NIL INCRMAPS (NIL T) -7 NIL NIL) (-532 1466142 1467067 1468011 "INBFF" 1469919 NIL INBFF (NIL T) -7 NIL NIL) (-531 1462537 1465986 1466090 "IMATRIX" 1466095 NIL IMATRIX (NIL T NIL NIL) -8 NIL NIL) (-530 1461251 1461374 1461688 "IMATQF" 1462394 NIL IMATQF (NIL T T T T T T T T) -7 NIL NIL) (-529 1459473 1459700 1460036 "IMATLIN" 1461008 NIL IMATLIN (NIL T T T T) -7 NIL NIL) (-528 1454105 1459397 1459455 "ILIST" 1459460 NIL ILIST (NIL T NIL) -8 NIL NIL) (-527 1452064 1453965 1454078 "IIARRAY2" 1454083 NIL IIARRAY2 (NIL T NIL NIL T T) -8 NIL NIL) (-526 1447432 1451975 1452039 "IFF" 1452044 NIL IFF (NIL NIL NIL) -8 NIL NIL) (-525 1442481 1446724 1446912 "IFARRAY" 1447289 NIL IFARRAY (NIL T NIL) -8 NIL NIL) (-524 1441688 1442385 1442458 "IFAMON" 1442463 NIL IFAMON (NIL T T NIL) -8 NIL NIL) (-523 1441271 1441336 1441391 "IEVALAB" 1441598 NIL IEVALAB (NIL T T) -9 NIL NIL) (-522 1440946 1441014 1441174 "IEVALAB-" 1441179 NIL IEVALAB- (NIL T T T) -8 NIL NIL) (-521 1440604 1440860 1440923 "IDPO" 1440928 NIL IDPO (NIL T T) -8 NIL NIL) (-520 1439881 1440493 1440568 "IDPOAMS" 1440573 NIL IDPOAMS (NIL T T) -8 NIL NIL) (-519 1439215 1439770 1439845 "IDPOAM" 1439850 NIL IDPOAM (NIL T T) -8 NIL NIL) (-518 1438299 1438549 1438603 "IDPC" 1439016 NIL IDPC (NIL T T) -9 NIL 1439165) (-517 1437795 1438191 1438264 "IDPAM" 1438269 NIL IDPAM (NIL T T) -8 NIL NIL) (-516 1437198 1437687 1437760 "IDPAG" 1437765 NIL IDPAG (NIL T T) -8 NIL NIL) (-515 1433453 1434301 1435196 "IDECOMP" 1436355 NIL IDECOMP (NIL NIL NIL) -7 NIL NIL) (-514 1426329 1427378 1428424 "IDEAL" 1432490 NIL IDEAL (NIL T T T T) -8 NIL NIL) (-513 1424346 1425493 1425766 "ICP" 1426120 NIL ICP (NIL T NIL T) -8 NIL NIL) (-512 1423510 1423622 1423821 "ICDEN" 1424230 NIL ICDEN (NIL T T T T) -7 NIL NIL) (-511 1422609 1422990 1423137 "ICARD" 1423383 T ICARD (NIL) -8 NIL NIL) (-510 1420669 1420982 1421387 "IBPTOOLS" 1422286 NIL IBPTOOLS (NIL T T T T) -7 NIL NIL) (-509 1416283 1420289 1420402 "IBITS" 1420588 NIL IBITS (NIL NIL) -8 NIL NIL) (-508 1413006 1413582 1414277 "IBATOOL" 1415700 NIL IBATOOL (NIL T T T) -7 NIL NIL) (-507 1410786 1411247 1411780 "IBACHIN" 1412541 NIL IBACHIN (NIL T T T) -7 NIL NIL) (-506 1408669 1410632 1410735 "IARRAY2" 1410740 NIL IARRAY2 (NIL T NIL NIL) -8 NIL NIL) (-505 1404828 1408595 1408652 "IARRAY1" 1408657 NIL IARRAY1 (NIL T NIL) -8 NIL NIL) (-504 1398758 1403240 1403721 "IAN" 1404367 T IAN (NIL) -8 NIL NIL) (-503 1398269 1398326 1398499 "IALGFACT" 1398695 NIL IALGFACT (NIL T T T T) -7 NIL NIL) (-502 1397796 1397909 1397938 "HYPCAT" 1398145 T HYPCAT (NIL) -9 NIL NIL) (-501 1397334 1397451 1397637 "HYPCAT-" 1397642 NIL HYPCAT- (NIL T) -8 NIL NIL) (-500 1396338 1396615 1396805 "HTMLFORM" 1397164 T HTMLFORM (NIL) -8 NIL NIL) (-499 1393127 1394452 1394494 "HOAGG" 1395475 NIL HOAGG (NIL T) -9 NIL 1396084) (-498 1391721 1392120 1392646 "HOAGG-" 1392651 NIL HOAGG- (NIL T T) -8 NIL NIL) (-497 1385539 1391159 1391326 "HEXADEC" 1391574 T HEXADEC (NIL) -8 NIL NIL) (-496 1384287 1384509 1384772 "HEUGCD" 1385316 NIL HEUGCD (NIL T) -7 NIL NIL) (-495 1383390 1384124 1384254 "HELLFDIV" 1384259 NIL HELLFDIV (NIL T T T T) -8 NIL NIL) (-494 1377107 1378650 1379731 "HEAP" 1382341 NIL HEAP (NIL T) -8 NIL NIL) (-493 1370945 1377022 1377084 "HDP" 1377089 NIL HDP (NIL NIL T) -8 NIL NIL) (-492 1364650 1370580 1370732 "HDMP" 1370846 NIL HDMP (NIL NIL T) -8 NIL NIL) (-491 1363975 1364114 1364278 "HB" 1364506 T HB (NIL) -7 NIL NIL) (-490 1357484 1363821 1363925 "HASHTBL" 1363930 NIL HASHTBL (NIL T T NIL) -8 NIL NIL) (-489 1355231 1357106 1357288 "HACKPI" 1357322 T HACKPI (NIL) -8 NIL NIL) (-488 1337379 1341248 1345251 "GUESSUP" 1351261 NIL GUESSUP (NIL NIL) -7 NIL NIL) (-487 1308476 1315517 1322213 "GUESSP" 1330703 T GUESSP (NIL) -7 NIL NIL) (-486 1275291 1280562 1285946 "GUESS" 1303420 NIL GUESS (NIL T T T T NIL NIL) -7 NIL NIL) (-485 1248796 1255193 1261329 "GUESSINT" 1269175 T GUESSINT (NIL) -7 NIL NIL) (-484 1224167 1229617 1235184 "GUESSF" 1243281 NIL GUESSF (NIL T) -7 NIL NIL) (-483 1223889 1223926 1224021 "GUESSF1" 1224124 NIL GUESSF1 (NIL T) -7 NIL NIL) (-482 1200050 1205584 1211199 "GUESSAN" 1218294 T GUESSAN (NIL) -7 NIL NIL) (-481 1195745 1199903 1200016 "GTSET" 1200021 NIL GTSET (NIL T T T T) -8 NIL NIL) (-480 1189283 1195623 1195721 "GSTBL" 1195726 NIL GSTBL (NIL T T T NIL) -8 NIL NIL) (-479 1181513 1188316 1188580 "GSERIES" 1189075 NIL GSERIES (NIL T NIL NIL) -8 NIL NIL) (-478 1180534 1180987 1181016 "GROUP" 1181277 T GROUP (NIL) -9 NIL 1181436) (-477 1179650 1179873 1180217 "GROUP-" 1180222 NIL GROUP- (NIL T) -8 NIL NIL) (-476 1178019 1178338 1178725 "GROEBSOL" 1179327 NIL GROEBSOL (NIL NIL T T) -7 NIL NIL) (-475 1176958 1177220 1177272 "GRMOD" 1177801 NIL GRMOD (NIL T T) -9 NIL 1177969) (-474 1176726 1176762 1176890 "GRMOD-" 1176895 NIL GRMOD- (NIL T T T) -8 NIL NIL) (-473 1172055 1173080 1174080 "GRIMAGE" 1175746 T GRIMAGE (NIL) -8 NIL NIL) (-472 1170522 1170782 1171106 "GRDEF" 1171751 T GRDEF (NIL) -7 NIL NIL) (-471 1169966 1170082 1170223 "GRAY" 1170401 T GRAY (NIL) -7 NIL NIL) (-470 1169196 1169576 1169628 "GRALG" 1169781 NIL GRALG (NIL T T) -9 NIL 1169874) (-469 1168857 1168930 1169093 "GRALG-" 1169098 NIL GRALG- (NIL T T T) -8 NIL NIL) (-468 1165661 1168442 1168620 "GPOLSET" 1168764 NIL GPOLSET (NIL T T T T) -8 NIL NIL) (-467 1147864 1149354 1150943 "GPAFF" 1164352 NIL GPAFF (NIL T NIL T T T T T T T T T) -7 NIL NIL) (-466 1147218 1147275 1147533 "GOSPER" 1147801 NIL GOSPER (NIL T T T T T) -7 NIL NIL) (-465 1144611 1145205 1145694 "GOPT" 1146749 T GOPT (NIL) -8 NIL NIL) (-464 1141832 1142473 1143010 "GOPT0" 1144094 T GOPT0 (NIL) -8 NIL NIL) (-463 1137591 1138270 1138796 "GMODPOL" 1141531 NIL GMODPOL (NIL NIL T T T NIL T) -8 NIL NIL) (-462 1136596 1136780 1137018 "GHENSEL" 1137403 NIL GHENSEL (NIL T T) -7 NIL NIL) (-461 1130647 1131490 1132517 "GENUPS" 1135680 NIL GENUPS (NIL T T) -7 NIL NIL) (-460 1130344 1130395 1130484 "GENUFACT" 1130590 NIL GENUFACT (NIL T) -7 NIL NIL) (-459 1129756 1129833 1129998 "GENPGCD" 1130262 NIL GENPGCD (NIL T T T T) -7 NIL NIL) (-458 1129230 1129265 1129478 "GENMFACT" 1129715 NIL GENMFACT (NIL T T T T T) -7 NIL NIL) (-457 1127798 1128053 1128360 "GENEEZ" 1128973 NIL GENEEZ (NIL T T) -7 NIL NIL) (-456 1126342 1126619 1126943 "GDRAW" 1127494 T GDRAW (NIL) -7 NIL NIL) (-455 1120209 1125953 1126115 "GDMP" 1126265 NIL GDMP (NIL NIL T T) -8 NIL NIL) (-454 1109593 1113982 1115087 "GCNAALG" 1119193 NIL GCNAALG (NIL T NIL NIL NIL) -8 NIL NIL) (-453 1108010 1108882 1108911 "GCDDOM" 1109166 T GCDDOM (NIL) -9 NIL 1109323) (-452 1107480 1107607 1107822 "GCDDOM-" 1107827 NIL GCDDOM- (NIL T) -8 NIL NIL) (-451 1106154 1106339 1106642 "GB" 1107260 NIL GB (NIL T T T T) -7 NIL NIL) (-450 1094774 1097100 1099492 "GBINTERN" 1103845 NIL GBINTERN (NIL T T T T) -7 NIL NIL) (-449 1092611 1092903 1093324 "GBF" 1094449 NIL GBF (NIL T T T T) -7 NIL NIL) (-448 1091392 1091557 1091824 "GBEUCLID" 1092427 NIL GBEUCLID (NIL T T T T) -7 NIL NIL) (-447 1090741 1090866 1091015 "GAUSSFAC" 1091263 T GAUSSFAC (NIL) -7 NIL NIL) (-446 1089110 1089412 1089725 "GALUTIL" 1090461 NIL GALUTIL (NIL T) -7 NIL NIL) (-445 1087418 1087692 1088016 "GALPOLYU" 1088837 NIL GALPOLYU (NIL T T) -7 NIL NIL) (-444 1084783 1085073 1085480 "GALFACTU" 1087115 NIL GALFACTU (NIL T T T) -7 NIL NIL) (-443 1076589 1078088 1079696 "GALFACT" 1083215 NIL GALFACT (NIL T) -7 NIL NIL) (-442 1073977 1074634 1074663 "FVFUN" 1075819 T FVFUN (NIL) -9 NIL 1076539) (-441 1073243 1073424 1073453 "FVC" 1073744 T FVC (NIL) -9 NIL 1073927) (-440 1072885 1073040 1073121 "FUNCTION" 1073195 NIL FUNCTION (NIL NIL) -8 NIL NIL) (-439 1070555 1071106 1071595 "FT" 1072416 T FT (NIL) -8 NIL NIL) (-438 1069347 1069856 1070059 "FTEM" 1070372 T FTEM (NIL) -8 NIL NIL) (-437 1067605 1067894 1068297 "FSUPFACT" 1069039 NIL FSUPFACT (NIL T T T) -7 NIL NIL) (-436 1066002 1066291 1066623 "FST" 1067293 T FST (NIL) -8 NIL NIL) (-435 1065173 1065279 1065474 "FSRED" 1065884 NIL FSRED (NIL T T) -7 NIL NIL) (-434 1063854 1064109 1064462 "FSPRMELT" 1064889 NIL FSPRMELT (NIL T T) -7 NIL NIL) (-433 1059220 1059925 1060682 "FSPECF" 1063159 NIL FSPECF (NIL T T) -7 NIL NIL) (-432 1041478 1050067 1050108 "FS" 1053956 NIL FS (NIL T) -9 NIL 1056234) (-431 1030128 1033118 1037174 "FS-" 1037471 NIL FS- (NIL T T) -8 NIL NIL) (-430 1029642 1029696 1029873 "FSINT" 1030069 NIL FSINT (NIL T T) -7 NIL NIL) (-429 1027927 1028639 1028940 "FSERIES" 1029423 NIL FSERIES (NIL T T) -8 NIL NIL) (-428 1026941 1027057 1027288 "FSCINT" 1027807 NIL FSCINT (NIL T T) -7 NIL NIL) (-427 1023176 1025886 1025928 "FSAGG" 1026298 NIL FSAGG (NIL T) -9 NIL 1026555) (-426 1020938 1021539 1022335 "FSAGG-" 1022430 NIL FSAGG- (NIL T T) -8 NIL NIL) (-425 1019980 1020123 1020350 "FSAGG2" 1020791 NIL FSAGG2 (NIL T T T T) -7 NIL NIL) (-424 1017635 1017914 1018468 "FS2UPS" 1019698 NIL FS2UPS (NIL T T T T T NIL) -7 NIL NIL) (-423 1017217 1017260 1017415 "FS2" 1017586 NIL FS2 (NIL T T T T) -7 NIL NIL) (-422 1016074 1016245 1016554 "FS2EXPXP" 1017042 NIL FS2EXPXP (NIL T T NIL NIL) -7 NIL NIL) (-421 1015500 1015615 1015767 "FRUTIL" 1015954 NIL FRUTIL (NIL T) -7 NIL NIL) (-420 1006926 1011011 1012361 "FR" 1014182 NIL FR (NIL T) -8 NIL NIL) (-419 1002006 1004644 1004685 "FRNAALG" 1006081 NIL FRNAALG (NIL T) -9 NIL 1006687) (-418 997685 998755 1000030 "FRNAALG-" 1000780 NIL FRNAALG- (NIL T T) -8 NIL NIL) (-417 997323 997366 997493 "FRNAAF2" 997636 NIL FRNAAF2 (NIL T T T T) -7 NIL NIL) (-416 995686 996179 996473 "FRMOD" 997136 NIL FRMOD (NIL T T T T NIL) -8 NIL NIL) (-415 993401 994069 994386 "FRIDEAL" 995477 NIL FRIDEAL (NIL T T T T) -8 NIL NIL) (-414 992596 992683 992972 "FRIDEAL2" 993308 NIL FRIDEAL2 (NIL T T T T T T T T) -7 NIL NIL) (-413 991839 992253 992295 "FRETRCT" 992300 NIL FRETRCT (NIL T) -9 NIL 992474) (-412 990951 991182 991533 "FRETRCT-" 991538 NIL FRETRCT- (NIL T T) -8 NIL NIL) (-411 988156 989376 989436 "FRAMALG" 990318 NIL FRAMALG (NIL T T) -9 NIL 990610) (-410 986289 986745 987375 "FRAMALG-" 987598 NIL FRAMALG- (NIL T T T) -8 NIL NIL) (-409 980192 985774 986045 "FRAC" 986050 NIL FRAC (NIL T) -8 NIL NIL) (-408 979828 979885 979992 "FRAC2" 980129 NIL FRAC2 (NIL T T) -7 NIL NIL) (-407 979464 979521 979628 "FR2" 979765 NIL FR2 (NIL T T) -7 NIL NIL) (-406 974086 976995 977024 "FPS" 978143 T FPS (NIL) -9 NIL 978697) (-405 973535 973644 973808 "FPS-" 973954 NIL FPS- (NIL T) -8 NIL NIL) (-404 970931 972628 972657 "FPC" 972882 T FPC (NIL) -9 NIL 973024) (-403 970724 970764 970861 "FPC-" 970866 NIL FPC- (NIL T) -8 NIL NIL) (-402 969603 970213 970255 "FPATMAB" 970260 NIL FPATMAB (NIL T) -9 NIL 970410) (-401 967303 967779 968205 "FPARFRAC" 969240 NIL FPARFRAC (NIL T T) -8 NIL NIL) (-400 962698 963195 963877 "FORTRAN" 966735 NIL FORTRAN (NIL NIL NIL NIL NIL) -8 NIL NIL) (-399 960414 960914 961453 "FORT" 962179 T FORT (NIL) -7 NIL NIL) (-398 958090 958651 958680 "FORTFN" 959740 T FORTFN (NIL) -9 NIL 960364) (-397 957853 957903 957932 "FORTCAT" 957991 T FORTCAT (NIL) -9 NIL 958053) (-396 955913 956396 956795 "FORMULA" 957474 T FORMULA (NIL) -8 NIL NIL) (-395 955701 955731 955800 "FORMULA1" 955877 NIL FORMULA1 (NIL T) -7 NIL NIL) (-394 955224 955276 955449 "FORDER" 955643 NIL FORDER (NIL T T T T) -7 NIL NIL) (-393 954320 954484 954677 "FOP" 955051 T FOP (NIL) -7 NIL NIL) (-392 952928 953600 953774 "FNLA" 954202 NIL FNLA (NIL NIL NIL T) -8 NIL NIL) (-391 951595 951984 952013 "FNCAT" 952585 T FNCAT (NIL) -9 NIL 952878) (-390 951161 951554 951582 "FNAME" 951587 T FNAME (NIL) -8 NIL NIL) (-389 949814 950787 950816 "FMTC" 950821 T FMTC (NIL) -9 NIL 950857) (-388 946132 947339 947967 "FMONOID" 949219 NIL FMONOID (NIL T) -8 NIL NIL) (-387 945353 945876 946024 "FM" 946029 NIL FM (NIL T T) -8 NIL NIL) (-386 942777 943422 943451 "FMFUN" 944595 T FMFUN (NIL) -9 NIL 945303) (-385 942046 942226 942255 "FMC" 942545 T FMC (NIL) -9 NIL 942727) (-384 939258 940092 940147 "FMCAT" 941342 NIL FMCAT (NIL T T) -9 NIL 941836) (-383 938151 939024 939124 "FM1" 939203 NIL FM1 (NIL T T) -8 NIL NIL) (-382 935925 936341 936835 "FLOATRP" 937702 NIL FLOATRP (NIL T) -7 NIL NIL) (-381 929412 933581 934211 "FLOAT" 935315 T FLOAT (NIL) -8 NIL NIL) (-380 926850 927350 927928 "FLOATCP" 928879 NIL FLOATCP (NIL T) -7 NIL NIL) (-379 925635 926483 926525 "FLINEXP" 926530 NIL FLINEXP (NIL T) -9 NIL 926622) (-378 924789 925024 925352 "FLINEXP-" 925357 NIL FLINEXP- (NIL T T) -8 NIL NIL) (-377 923865 924009 924233 "FLASORT" 924641 NIL FLASORT (NIL T T) -7 NIL NIL) (-376 921081 921923 921976 "FLALG" 923203 NIL FLALG (NIL T T) -9 NIL 923670) (-375 914900 918594 918636 "FLAGG" 919898 NIL FLAGG (NIL T) -9 NIL 920546) (-374 913626 913965 914455 "FLAGG-" 914460 NIL FLAGG- (NIL T T) -8 NIL NIL) (-373 912668 912811 913038 "FLAGG2" 913479 NIL FLAGG2 (NIL T T T T) -7 NIL NIL) (-372 909639 910657 910717 "FINRALG" 911845 NIL FINRALG (NIL T T) -9 NIL 912350) (-371 908799 909028 909367 "FINRALG-" 909372 NIL FINRALG- (NIL T T T) -8 NIL NIL) (-370 908204 908417 908446 "FINITE" 908642 T FINITE (NIL) -9 NIL 908749) (-369 900662 902823 902864 "FINAALG" 906531 NIL FINAALG (NIL T) -9 NIL 907983) (-368 896002 897044 898188 "FINAALG-" 899567 NIL FINAALG- (NIL T T) -8 NIL NIL) (-367 895372 895757 895860 "FILE" 895932 NIL FILE (NIL T) -8 NIL NIL) (-366 893912 894249 894304 "FILECAT" 895082 NIL FILECAT (NIL T T) -9 NIL 895322) (-365 891722 893278 893307 "FIELD" 893347 T FIELD (NIL) -9 NIL 893427) (-364 890342 890727 891238 "FIELD-" 891243 NIL FIELD- (NIL T) -8 NIL NIL) (-363 888155 888977 889324 "FGROUP" 890028 NIL FGROUP (NIL T) -8 NIL NIL) (-362 887245 887409 887629 "FGLMICPK" 887987 NIL FGLMICPK (NIL T NIL) -7 NIL NIL) (-361 883047 887170 887227 "FFX" 887232 NIL FFX (NIL T NIL) -8 NIL NIL) (-360 882587 882654 882776 "FFSQFR" 882975 NIL FFSQFR (NIL T T) -7 NIL NIL) (-359 882188 882249 882384 "FFSLPE" 882520 NIL FFSLPE (NIL T T T) -7 NIL NIL) (-358 878184 878960 879756 "FFPOLY" 881424 NIL FFPOLY (NIL T) -7 NIL NIL) (-357 877688 877724 877933 "FFPOLY2" 878142 NIL FFPOLY2 (NIL T T) -7 NIL NIL) (-356 873510 877607 877670 "FFP" 877675 NIL FFP (NIL T NIL) -8 NIL NIL) (-355 868878 873421 873485 "FF" 873490 NIL FF (NIL NIL NIL) -8 NIL NIL) (-354 863974 868221 868411 "FFNBX" 868732 NIL FFNBX (NIL T NIL) -8 NIL NIL) (-353 858884 863109 863367 "FFNBP" 863828 NIL FFNBP (NIL T NIL) -8 NIL NIL) (-352 853487 858168 858379 "FFNB" 858717 NIL FFNB (NIL NIL NIL) -8 NIL NIL) (-351 852319 852517 852832 "FFINTBAS" 853284 NIL FFINTBAS (NIL T T T) -7 NIL NIL) (-350 848495 850730 850759 "FFIELDC" 851379 T FFIELDC (NIL) -9 NIL 851755) (-349 847158 847528 848025 "FFIELDC-" 848030 NIL FFIELDC- (NIL T) -8 NIL NIL) (-348 846728 846773 846897 "FFHOM" 847100 NIL FFHOM (NIL T T T) -7 NIL NIL) (-347 844426 844910 845427 "FFF" 846243 NIL FFF (NIL T) -7 NIL NIL) (-346 840122 840887 841731 "FFFG" 843650 NIL FFFG (NIL T T) -7 NIL NIL) (-345 838848 839057 839379 "FFFGF" 839900 NIL FFFGF (NIL T T T) -7 NIL NIL) (-344 837599 837796 838044 "FFFACTSE" 838650 NIL FFFACTSE (NIL T T) -7 NIL NIL) (-343 833187 837341 837442 "FFCGX" 837542 NIL FFCGX (NIL T NIL) -8 NIL NIL) (-342 828789 832919 833026 "FFCGP" 833130 NIL FFCGP (NIL T NIL) -8 NIL NIL) (-341 823942 828516 828624 "FFCG" 828725 NIL FFCG (NIL NIL NIL) -8 NIL NIL) (-340 805731 814853 814940 "FFCAT" 820105 NIL FFCAT (NIL T T T) -9 NIL 821590) (-339 800929 801976 803290 "FFCAT-" 804520 NIL FFCAT- (NIL T T T T) -8 NIL NIL) (-338 800340 800383 800618 "FFCAT2" 800880 NIL FFCAT2 (NIL T T T T T T T T) -7 NIL NIL) (-337 789510 793316 794534 "FEXPR" 799194 NIL FEXPR (NIL NIL NIL T) -8 NIL NIL) (-336 788512 788947 788989 "FEVALAB" 789073 NIL FEVALAB (NIL T) -9 NIL 789331) (-335 787671 787881 788219 "FEVALAB-" 788224 NIL FEVALAB- (NIL T T) -8 NIL NIL) (-334 786264 787054 787257 "FDIV" 787570 NIL FDIV (NIL T T T T) -8 NIL NIL) (-333 783329 784044 784160 "FDIVCAT" 785728 NIL FDIVCAT (NIL T T T T) -9 NIL 786165) (-332 783091 783118 783288 "FDIVCAT-" 783293 NIL FDIVCAT- (NIL T T T T T) -8 NIL NIL) (-331 782311 782398 782675 "FDIV2" 782998 NIL FDIV2 (NIL T T T T T T T T) -7 NIL NIL) (-330 780997 781256 781545 "FCPAK1" 782042 T FCPAK1 (NIL) -7 NIL NIL) (-329 780125 780497 780638 "FCOMP" 780888 NIL FCOMP (NIL T) -8 NIL NIL) (-328 763753 767168 770731 "FC" 776582 T FC (NIL) -8 NIL NIL) (-327 756297 760340 760381 "FAXF" 762183 NIL FAXF (NIL T) -9 NIL 762874) (-326 753577 754231 755056 "FAXF-" 755521 NIL FAXF- (NIL T T) -8 NIL NIL) (-325 748683 752953 753129 "FARRAY" 753434 NIL FARRAY (NIL T) -8 NIL NIL) (-324 744001 746077 746131 "FAMR" 747154 NIL FAMR (NIL T T) -9 NIL 747611) (-323 742891 743193 743628 "FAMR-" 743633 NIL FAMR- (NIL T T T) -8 NIL NIL) (-322 742479 742522 742673 "FAMR2" 742842 NIL FAMR2 (NIL T T T T T) -7 NIL NIL) (-321 741675 742401 742454 "FAMONOID" 742459 NIL FAMONOID (NIL T) -8 NIL NIL) (-320 739505 740189 740243 "FAMONC" 741184 NIL FAMONC (NIL T T) -9 NIL 741569) (-319 738199 739261 739397 "FAGROUP" 739402 NIL FAGROUP (NIL T) -8 NIL NIL) (-318 735994 736313 736716 "FACUTIL" 737880 NIL FACUTIL (NIL T T T T) -7 NIL NIL) (-317 735410 735519 735665 "FACTRN" 735880 NIL FACTRN (NIL T) -7 NIL NIL) (-316 734509 734694 734916 "FACTFUNC" 735220 NIL FACTFUNC (NIL T) -7 NIL NIL) (-315 733925 734034 734180 "FACTEXT" 734395 NIL FACTEXT (NIL T) -7 NIL NIL) (-314 726245 733176 733388 "EXPUPXS" 733781 NIL EXPUPXS (NIL T NIL NIL) -8 NIL NIL) (-313 723728 724268 724854 "EXPRTUBE" 725679 T EXPRTUBE (NIL) -7 NIL NIL) (-312 722899 722994 723214 "EXPRSOL" 723628 NIL EXPRSOL (NIL T T T T) -7 NIL NIL) (-311 719093 719685 720422 "EXPRODE" 722238 NIL EXPRODE (NIL T T) -7 NIL NIL) (-310 704114 717754 718179 "EXPR" 718700 NIL EXPR (NIL T) -8 NIL NIL) (-309 698521 699108 699921 "EXPR2UPS" 703412 NIL EXPR2UPS (NIL T T) -7 NIL NIL) (-308 698157 698214 698321 "EXPR2" 698458 NIL EXPR2 (NIL T T) -7 NIL NIL) (-307 689497 697289 697586 "EXPEXPAN" 697994 NIL EXPEXPAN (NIL T T NIL NIL) -8 NIL NIL) (-306 689209 689260 689337 "EXP3D" 689440 T EXP3D (NIL) -7 NIL NIL) (-305 689036 689166 689195 "EXIT" 689200 T EXIT (NIL) -8 NIL NIL) (-304 688663 688725 688838 "EVALCYC" 688968 NIL EVALCYC (NIL T) -7 NIL NIL) (-303 688205 688321 688363 "EVALAB" 688533 NIL EVALAB (NIL T) -9 NIL 688637) (-302 687686 687808 688029 "EVALAB-" 688034 NIL EVALAB- (NIL T T) -8 NIL NIL) (-301 685144 686456 686485 "EUCDOM" 687040 T EUCDOM (NIL) -9 NIL 687390) (-300 683549 683991 684581 "EUCDOM-" 684586 NIL EUCDOM- (NIL T) -8 NIL NIL) (-299 671089 673847 676597 "ESTOOLS" 680819 T ESTOOLS (NIL) -7 NIL NIL) (-298 670721 670778 670887 "ESTOOLS2" 671026 NIL ESTOOLS2 (NIL T T) -7 NIL NIL) (-297 670472 670514 670594 "ESTOOLS1" 670673 NIL ESTOOLS1 (NIL T) -7 NIL NIL) (-296 664398 666126 666155 "ES" 668923 T ES (NIL) -9 NIL 670330) (-295 659346 660632 662449 "ES-" 662613 NIL ES- (NIL T) -8 NIL NIL) (-294 655721 656481 657261 "ESCONT" 658586 T ESCONT (NIL) -7 NIL NIL) (-293 655466 655498 655580 "ESCONT1" 655683 NIL ESCONT1 (NIL NIL NIL) -7 NIL NIL) (-292 655141 655191 655291 "ES2" 655410 NIL ES2 (NIL T T) -7 NIL NIL) (-291 654771 654829 654938 "ES1" 655077 NIL ES1 (NIL T T) -7 NIL NIL) (-290 653987 654116 654292 "ERROR" 654615 T ERROR (NIL) -7 NIL NIL) (-289 647502 653846 653937 "EQTBL" 653942 NIL EQTBL (NIL T T) -8 NIL NIL) (-288 639961 642844 644279 "EQ" 646100 NIL -2995 (NIL T) -8 NIL NIL) (-287 639593 639650 639759 "EQ2" 639898 NIL EQ2 (NIL T T) -7 NIL NIL) (-286 634885 635931 637024 "EP" 638532 NIL EP (NIL T) -7 NIL NIL) (-285 634039 634603 634632 "ENTIRER" 634637 T ENTIRER (NIL) -9 NIL 634683) (-284 630495 631994 632364 "EMR" 633838 NIL EMR (NIL T T T NIL NIL NIL) -8 NIL NIL) (-283 629641 629824 629879 "ELTAGG" 630259 NIL ELTAGG (NIL T T) -9 NIL 630469) (-282 629360 629422 629563 "ELTAGG-" 629568 NIL ELTAGG- (NIL T T T) -8 NIL NIL) (-281 629148 629177 629232 "ELTAB" 629316 NIL ELTAB (NIL T T) -9 NIL NIL) (-280 628274 628420 628619 "ELFUTS" 628999 NIL ELFUTS (NIL T T) -7 NIL NIL) (-279 628015 628071 628100 "ELEMFUN" 628205 T ELEMFUN (NIL) -9 NIL NIL) (-278 627885 627906 627974 "ELEMFUN-" 627979 NIL ELEMFUN- (NIL T) -8 NIL NIL) (-277 622815 626018 626060 "ELAGG" 627000 NIL ELAGG (NIL T) -9 NIL 627461) (-276 621100 621534 622197 "ELAGG-" 622202 NIL ELAGG- (NIL T T) -8 NIL NIL) (-275 613970 615769 616595 "EFUPXS" 620377 NIL EFUPXS (NIL T T T T) -8 NIL NIL) (-274 607422 609223 610032 "EFULS" 613247 NIL EFULS (NIL T T T) -8 NIL NIL) (-273 604844 605202 605681 "EFSTRUC" 607054 NIL EFSTRUC (NIL T T) -7 NIL NIL) (-272 593856 595421 596982 "EF" 603359 NIL EF (NIL T T) -7 NIL NIL) (-271 592957 593341 593490 "EAB" 593727 T EAB (NIL) -8 NIL NIL) (-270 592166 592916 592944 "E04UCFA" 592949 T E04UCFA (NIL) -8 NIL NIL) (-269 591375 592125 592153 "E04NAFA" 592158 T E04NAFA (NIL) -8 NIL NIL) (-268 590584 591334 591362 "E04MBFA" 591367 T E04MBFA (NIL) -8 NIL NIL) (-267 589793 590543 590571 "E04JAFA" 590576 T E04JAFA (NIL) -8 NIL NIL) (-266 589004 589752 589780 "E04GCFA" 589785 T E04GCFA (NIL) -8 NIL NIL) (-265 588215 588963 588991 "E04FDFA" 588996 T E04FDFA (NIL) -8 NIL NIL) (-264 587424 588174 588202 "E04DGFA" 588207 T E04DGFA (NIL) -8 NIL NIL) (-263 581603 582949 584313 "E04AGNT" 586080 T E04AGNT (NIL) -7 NIL NIL) (-262 580326 580806 580847 "DVARCAT" 581322 NIL DVARCAT (NIL T) -9 NIL 581521) (-261 579530 579742 580056 "DVARCAT-" 580061 NIL DVARCAT- (NIL T T) -8 NIL NIL) (-260 572499 572981 573730 "DTP" 579061 NIL DTP (NIL T NIL T T T T T T T T T) -7 NIL NIL) (-259 569948 571921 572078 "DSTREE" 572375 NIL DSTREE (NIL T) -8 NIL NIL) (-258 567417 569262 569304 "DSTRCAT" 569523 NIL DSTRCAT (NIL T) -9 NIL 569657) (-257 560271 567216 567345 "DSMP" 567350 NIL DSMP (NIL T T T) -8 NIL NIL) (-256 555081 556216 557284 "DROPT" 559223 T DROPT (NIL) -8 NIL NIL) (-255 554746 554805 554903 "DROPT1" 555016 NIL DROPT1 (NIL T) -7 NIL NIL) (-254 549861 550987 552124 "DROPT0" 553629 T DROPT0 (NIL) -7 NIL NIL) (-253 548206 548531 548917 "DRAWPT" 549495 T DRAWPT (NIL) -7 NIL NIL) (-252 542793 543716 544795 "DRAW" 547180 NIL DRAW (NIL T) -7 NIL NIL) (-251 542426 542479 542597 "DRAWHACK" 542734 NIL DRAWHACK (NIL T) -7 NIL NIL) (-250 541157 541426 541717 "DRAWCX" 542155 T DRAWCX (NIL) -7 NIL NIL) (-249 540673 540741 540892 "DRAWCURV" 541083 NIL DRAWCURV (NIL T T) -7 NIL NIL) (-248 531145 533103 535218 "DRAWCFUN" 538578 T DRAWCFUN (NIL) -7 NIL NIL) (-247 527998 529874 529916 "DQAGG" 530545 NIL DQAGG (NIL T) -9 NIL 530818) (-246 516426 523167 523251 "DPOLCAT" 525103 NIL DPOLCAT (NIL T T T T) -9 NIL 525647) (-245 511265 512611 514569 "DPOLCAT-" 514574 NIL DPOLCAT- (NIL T T T T T) -8 NIL NIL) (-244 504004 511126 511224 "DPMO" 511229 NIL DPMO (NIL NIL T T) -8 NIL NIL) (-243 496646 503784 503951 "DPMM" 503956 NIL DPMM (NIL NIL T T T) -8 NIL NIL) (-242 490351 496281 496433 "DMP" 496547 NIL DMP (NIL NIL T) -8 NIL NIL) (-241 489951 490007 490151 "DLP" 490289 NIL DLP (NIL T) -7 NIL NIL) (-240 483601 489052 489279 "DLIST" 489756 NIL DLIST (NIL T) -8 NIL NIL) (-239 480486 482489 482531 "DLAGG" 483081 NIL DLAGG (NIL T) -9 NIL 483310) (-238 479143 479835 479864 "DIVRING" 480014 T DIVRING (NIL) -9 NIL 480122) (-237 478131 478384 478777 "DIVRING-" 478782 NIL DIVRING- (NIL T) -8 NIL NIL) (-236 476559 477724 477860 "DIV" 478028 NIL DIV (NIL T) -8 NIL NIL) (-235 474053 475121 475163 "DIVCAT" 475997 NIL DIVCAT (NIL T) -9 NIL 476328) (-234 472155 472512 472918 "DISPLAY" 473667 T DISPLAY (NIL) -7 NIL NIL) (-233 469648 470861 471243 "DIRRING" 471806 NIL DIRRING (NIL T) -8 NIL NIL) (-232 463508 469562 469625 "DIRPROD" 469630 NIL DIRPROD (NIL NIL T) -8 NIL NIL) (-231 462356 462559 462824 "DIRPROD2" 463301 NIL DIRPROD2 (NIL NIL T T) -7 NIL NIL) (-230 451920 457949 458003 "DIRPCAT" 458261 NIL DIRPCAT (NIL NIL T) -9 NIL 459105) (-229 449246 449888 450769 "DIRPCAT-" 451106 NIL DIRPCAT- (NIL T NIL T) -8 NIL NIL) (-228 448533 448693 448879 "DIOSP" 449080 T DIOSP (NIL) -7 NIL NIL) (-227 445276 447480 447522 "DIOPS" 447956 NIL DIOPS (NIL T) -9 NIL 448184) (-226 444825 444939 445130 "DIOPS-" 445135 NIL DIOPS- (NIL T T) -8 NIL NIL) (-225 443692 444330 444359 "DIFRING" 444546 T DIFRING (NIL) -9 NIL 444656) (-224 443338 443415 443567 "DIFRING-" 443572 NIL DIFRING- (NIL T) -8 NIL NIL) (-223 441120 442402 442444 "DIFEXT" 442807 NIL DIFEXT (NIL T) -9 NIL 443099) (-222 439405 439833 440499 "DIFEXT-" 440504 NIL DIFEXT- (NIL T T) -8 NIL NIL) (-221 436767 438971 439013 "DIAGG" 439018 NIL DIAGG (NIL T) -9 NIL 439038) (-220 436151 436308 436560 "DIAGG-" 436565 NIL DIAGG- (NIL T T) -8 NIL NIL) (-219 431521 435110 435387 "DHMATRIX" 435920 NIL DHMATRIX (NIL T) -8 NIL NIL) (-218 426732 431335 431409 "DFVEC" 431467 T DFVEC (NIL) -8 NIL NIL) (-217 420616 421905 423286 "DFSFUN" 425371 T DFSFUN (NIL) -7 NIL NIL) (-216 416877 420387 420481 "DFMAT" 420542 T DFMAT (NIL) -8 NIL NIL) (-215 411154 415331 415764 "DFLOAT" 416464 T DFLOAT (NIL) -8 NIL NIL) (-214 409382 409663 410059 "DFINTTLS" 410862 NIL DFINTTLS (NIL T T) -7 NIL NIL) (-213 406401 407403 407803 "DERHAM" 409048 NIL DERHAM (NIL T NIL) -8 NIL NIL) (-212 398014 399931 401366 "DEQUEUE" 404999 NIL DEQUEUE (NIL T) -8 NIL NIL) (-211 397229 397362 397558 "DEGRED" 397876 NIL DEGRED (NIL T T) -7 NIL NIL) (-210 393624 394369 395222 "DEFINTRF" 396457 NIL DEFINTRF (NIL T) -7 NIL NIL) (-209 391151 391620 392219 "DEFINTEF" 393143 NIL DEFINTEF (NIL T T) -7 NIL NIL) (-208 384969 390589 390756 "DECIMAL" 391004 T DECIMAL (NIL) -8 NIL NIL) (-207 382481 382939 383445 "DDFACT" 384513 NIL DDFACT (NIL T T) -7 NIL NIL) (-206 382077 382120 382271 "DBLRESP" 382432 NIL DBLRESP (NIL T T T T) -7 NIL NIL) (-205 379787 380121 380490 "DBASE" 381835 NIL DBASE (NIL T) -8 NIL NIL) (-204 378920 379746 379774 "D03FAFA" 379779 T D03FAFA (NIL) -8 NIL NIL) (-203 378054 378879 378907 "D03EEFA" 378912 T D03EEFA (NIL) -8 NIL NIL) (-202 376004 376470 376959 "D03AGNT" 377585 T D03AGNT (NIL) -7 NIL NIL) (-201 375320 375963 375991 "D02EJFA" 375996 T D02EJFA (NIL) -8 NIL NIL) (-200 374636 375279 375307 "D02CJFA" 375312 T D02CJFA (NIL) -8 NIL NIL) (-199 373952 374595 374623 "D02BHFA" 374628 T D02BHFA (NIL) -8 NIL NIL) (-198 373268 373911 373939 "D02BBFA" 373944 T D02BBFA (NIL) -8 NIL NIL) (-197 366467 368054 369660 "D02AGNT" 371682 T D02AGNT (NIL) -7 NIL NIL) (-196 364236 364758 365304 "D01WGTS" 365941 T D01WGTS (NIL) -7 NIL NIL) (-195 363331 364195 364223 "D01TRNS" 364228 T D01TRNS (NIL) -8 NIL NIL) (-194 362426 363290 363318 "D01GBFA" 363323 T D01GBFA (NIL) -8 NIL NIL) (-193 361521 362385 362413 "D01FCFA" 362418 T D01FCFA (NIL) -8 NIL NIL) (-192 360616 361480 361508 "D01ASFA" 361513 T D01ASFA (NIL) -8 NIL NIL) (-191 359711 360575 360603 "D01AQFA" 360608 T D01AQFA (NIL) -8 NIL NIL) (-190 358806 359670 359698 "D01APFA" 359703 T D01APFA (NIL) -8 NIL NIL) (-189 357901 358765 358793 "D01ANFA" 358798 T D01ANFA (NIL) -8 NIL NIL) (-188 356996 357860 357888 "D01AMFA" 357893 T D01AMFA (NIL) -8 NIL NIL) (-187 356091 356955 356983 "D01ALFA" 356988 T D01ALFA (NIL) -8 NIL NIL) (-186 355186 356050 356078 "D01AKFA" 356083 T D01AKFA (NIL) -8 NIL NIL) (-185 354281 355145 355173 "D01AJFA" 355178 T D01AJFA (NIL) -8 NIL NIL) (-184 347578 349129 350690 "D01AGNT" 352740 T D01AGNT (NIL) -7 NIL NIL) (-183 346915 347043 347195 "CYCLOTOM" 347446 T CYCLOTOM (NIL) -7 NIL NIL) (-182 343650 344363 345090 "CYCLES" 346208 T CYCLES (NIL) -7 NIL NIL) (-181 342962 343096 343267 "CVMP" 343511 NIL CVMP (NIL T) -7 NIL NIL) (-180 340734 340991 341367 "CTRIGMNP" 342690 NIL CTRIGMNP (NIL T T) -7 NIL NIL) (-179 340108 340207 340360 "CSTTOOLS" 340631 NIL CSTTOOLS (NIL T T) -7 NIL NIL) (-178 335907 336564 337322 "CRFP" 339420 NIL CRFP (NIL T T) -7 NIL NIL) (-177 334954 335139 335367 "CRAPACK" 335711 NIL CRAPACK (NIL T) -7 NIL NIL) (-176 334340 334441 334644 "CPMATCH" 334831 NIL CPMATCH (NIL T T T) -7 NIL NIL) (-175 334065 334093 334199 "CPIMA" 334306 NIL CPIMA (NIL T T T) -7 NIL NIL) (-174 330413 331085 331804 "COORDSYS" 333400 NIL COORDSYS (NIL T) -7 NIL NIL) (-173 326274 328416 328908 "CONTFRAC" 329953 NIL CONTFRAC (NIL T) -8 NIL NIL) (-172 325422 325986 326015 "COMRING" 326020 T COMRING (NIL) -9 NIL 326072) (-171 324503 324780 324964 "COMPPROP" 325258 T COMPPROP (NIL) -8 NIL NIL) (-170 324164 324199 324327 "COMPLPAT" 324462 NIL COMPLPAT (NIL T T T) -7 NIL NIL) (-169 314135 323975 324083 "COMPLEX" 324088 NIL COMPLEX (NIL T) -8 NIL NIL) (-168 313771 313828 313935 "COMPLEX2" 314072 NIL COMPLEX2 (NIL T T) -7 NIL NIL) (-167 313489 313524 313622 "COMPFACT" 313730 NIL COMPFACT (NIL T T) -7 NIL NIL) (-166 297741 308041 308082 "COMPCAT" 309086 NIL COMPCAT (NIL T) -9 NIL 310467) (-165 287257 290180 293807 "COMPCAT-" 294163 NIL COMPCAT- (NIL T T) -8 NIL NIL) (-164 286986 287014 287117 "COMMUPC" 287223 NIL COMMUPC (NIL T T T) -7 NIL NIL) (-163 286781 286814 286873 "COMMONOP" 286947 T COMMONOP (NIL) -7 NIL NIL) (-162 286364 286532 286619 "COMM" 286714 T COMM (NIL) -8 NIL NIL) (-161 285612 285806 285835 "COMBOPC" 286173 T COMBOPC (NIL) -9 NIL 286348) (-160 284508 284718 284960 "COMBINAT" 285402 NIL COMBINAT (NIL T) -7 NIL NIL) (-159 280706 281279 281919 "COMBF" 283930 NIL COMBF (NIL T T) -7 NIL NIL) (-158 279492 279822 280057 "COLOR" 280491 T COLOR (NIL) -8 NIL NIL) (-157 279132 279179 279304 "CMPLXRT" 279439 NIL CMPLXRT (NIL T T) -7 NIL NIL) (-156 274634 275662 276742 "CLIP" 278072 T CLIP (NIL) -7 NIL NIL) (-155 272970 273740 273979 "CLIF" 274461 NIL CLIF (NIL NIL T NIL) -8 NIL NIL) (-154 269235 271153 271195 "CLAGG" 272124 NIL CLAGG (NIL T) -9 NIL 272657) (-153 267657 268114 268697 "CLAGG-" 268702 NIL CLAGG- (NIL T T) -8 NIL NIL) (-152 267201 267286 267426 "CINTSLPE" 267566 NIL CINTSLPE (NIL T T) -7 NIL NIL) (-151 264702 265173 265721 "CHVAR" 266729 NIL CHVAR (NIL T T T) -7 NIL NIL) (-150 263920 264484 264513 "CHARZ" 264518 T CHARZ (NIL) -9 NIL 264533) (-149 263674 263714 263792 "CHARPOL" 263874 NIL CHARPOL (NIL T) -7 NIL NIL) (-148 262776 263373 263402 "CHARNZ" 263449 T CHARNZ (NIL) -9 NIL 263505) (-147 260799 261466 261801 "CHAR" 262461 T CHAR (NIL) -8 NIL NIL) (-146 260524 260585 260614 "CFCAT" 260725 T CFCAT (NIL) -9 NIL NIL) (-145 254657 260181 260299 "CDFVEC" 260426 T CDFVEC (NIL) -8 NIL NIL) (-144 250372 254414 254515 "CDFMAT" 254576 T CDFMAT (NIL) -8 NIL NIL) (-143 249617 249728 249910 "CDEN" 250256 NIL CDEN (NIL T T T) -7 NIL NIL) (-142 245609 248770 249050 "CCLASS" 249357 T CCLASS (NIL) -8 NIL NIL) (-141 240662 241638 242391 "CARTEN" 244912 NIL CARTEN (NIL NIL NIL T) -8 NIL NIL) (-140 239770 239918 240139 "CARTEN2" 240509 NIL CARTEN2 (NIL NIL NIL T T) -7 NIL NIL) (-139 238065 238920 239177 "CARD" 239533 T CARD (NIL) -8 NIL NIL) (-138 237436 237764 237793 "CACHSET" 237925 T CACHSET (NIL) -9 NIL 238002) (-137 236931 237227 237256 "CABMON" 237306 T CABMON (NIL) -9 NIL 237362) (-136 234494 236623 236730 "BTREE" 236857 NIL BTREE (NIL T) -8 NIL NIL) (-135 231998 234142 234264 "BTOURN" 234404 NIL BTOURN (NIL T) -8 NIL NIL) (-134 229455 231502 231544 "BTCAT" 231612 NIL BTCAT (NIL T) -9 NIL 231689) (-133 229122 229202 229351 "BTCAT-" 229356 NIL BTCAT- (NIL T T) -8 NIL NIL) (-132 224312 228182 228211 "BTAGG" 228467 T BTAGG (NIL) -9 NIL 228646) (-131 223735 223879 224109 "BTAGG-" 224114 NIL BTAGG- (NIL T) -8 NIL NIL) (-130 220785 223013 223228 "BSTREE" 223552 NIL BSTREE (NIL T) -8 NIL NIL) (-129 219923 220049 220233 "BRILL" 220641 NIL BRILL (NIL T) -7 NIL NIL) (-128 216663 218684 218726 "BRAGG" 219375 NIL BRAGG (NIL T) -9 NIL 219632) (-127 215192 215598 216153 "BRAGG-" 216158 NIL BRAGG- (NIL T T) -8 NIL NIL) (-126 208391 214538 214722 "BPADICRT" 215040 NIL BPADICRT (NIL NIL) -8 NIL NIL) (-125 206695 208328 208373 "BPADIC" 208378 NIL BPADIC (NIL NIL) -8 NIL NIL) (-124 206393 206423 206537 "BOUNDZRO" 206659 NIL BOUNDZRO (NIL T T) -7 NIL NIL) (-123 201908 202999 203866 "BOP" 205546 T BOP (NIL) -8 NIL NIL) (-122 199531 199975 200494 "BOP1" 201422 NIL BOP1 (NIL T) -7 NIL NIL) (-121 197884 198574 198868 "BOOLEAN" 199257 T BOOLEAN (NIL) -8 NIL NIL) (-120 197245 197623 197678 "BMODULE" 197683 NIL BMODULE (NIL T T) -9 NIL 197748) (-119 193588 194258 195044 "BLUPPACK" 196577 NIL BLUPPACK (NIL T NIL T T T) -7 NIL NIL) (-118 192980 193465 193534 "BLQT" 193539 T BLQT (NIL) -8 NIL NIL) (-117 191409 191884 191913 "BLMETCT" 192558 T BLMETCT (NIL) -9 NIL 192930) (-116 190808 191290 191357 "BLHN" 191362 T BLHN (NIL) -8 NIL NIL) (-115 189626 189885 190168 "BLAS1" 190545 T BLAS1 (NIL) -7 NIL NIL) (-114 185436 189424 189497 "BITS" 189573 T BITS (NIL) -8 NIL NIL) (-113 184507 184968 185120 "BINFILE" 185304 T BINFILE (NIL) -8 NIL NIL) (-112 178329 183948 184114 "BINARY" 184361 T BINARY (NIL) -8 NIL NIL) (-111 176196 177618 177660 "BGAGG" 177920 NIL BGAGG (NIL T) -9 NIL 178057) (-110 176027 176059 176150 "BGAGG-" 176155 NIL BGAGG- (NIL T T) -8 NIL NIL) (-109 175125 175411 175616 "BFUNCT" 175842 T BFUNCT (NIL) -8 NIL NIL) (-108 173817 173995 174282 "BEZOUT" 174950 NIL BEZOUT (NIL T T T T T) -7 NIL NIL) (-107 172780 173002 173261 "BEZIER" 173591 NIL BEZIER (NIL T) -7 NIL NIL) (-106 169303 171632 171962 "BBTREE" 172483 NIL BBTREE (NIL T) -8 NIL NIL) (-105 169036 169089 169118 "BASTYPE" 169237 T BASTYPE (NIL) -9 NIL NIL) (-104 168889 168917 168990 "BASTYPE-" 168995 NIL BASTYPE- (NIL T) -8 NIL NIL) (-103 168323 168399 168551 "BALFACT" 168800 NIL BALFACT (NIL T T) -7 NIL NIL) (-102 167687 167810 167958 "AXSERV" 168195 T AXSERV (NIL) -7 NIL NIL) (-101 166500 167097 167285 "AUTOMOR" 167532 NIL AUTOMOR (NIL T) -8 NIL NIL) (-100 166212 166217 166246 "ATTREG" 166251 T ATTREG (NIL) -9 NIL NIL) (-99 164491 164909 165261 "ATTRBUT" 165878 T ATTRBUT (NIL) -8 NIL NIL) (-98 164026 164139 164166 "ATRIG" 164367 T ATRIG (NIL) -9 NIL NIL) (-97 163835 163876 163963 "ATRIG-" 163968 NIL ATRIG- (NIL T) -8 NIL NIL) (-96 157395 158964 160075 "ASTACK" 162755 NIL ASTACK (NIL T) -8 NIL NIL) (-95 155902 156199 156563 "ASSOCEQ" 157078 NIL ASSOCEQ (NIL T T) -7 NIL NIL) (-94 154934 155561 155685 "ASP9" 155809 NIL ASP9 (NIL NIL) -8 NIL NIL) (-93 154698 154882 154921 "ASP8" 154926 NIL ASP8 (NIL NIL) -8 NIL NIL) (-92 153568 154303 154445 "ASP80" 154587 NIL ASP80 (NIL NIL) -8 NIL NIL) (-91 152467 153203 153335 "ASP7" 153467 NIL ASP7 (NIL NIL) -8 NIL NIL) (-90 151423 152144 152262 "ASP78" 152380 NIL ASP78 (NIL NIL) -8 NIL NIL) (-89 150394 151103 151220 "ASP77" 151337 NIL ASP77 (NIL NIL) -8 NIL NIL) (-88 149309 150032 150163 "ASP74" 150294 NIL ASP74 (NIL NIL) -8 NIL NIL) (-87 148210 148944 149076 "ASP73" 149208 NIL ASP73 (NIL NIL) -8 NIL NIL) (-86 147165 147887 148005 "ASP6" 148123 NIL ASP6 (NIL NIL) -8 NIL NIL) (-85 146114 146842 146960 "ASP55" 147078 NIL ASP55 (NIL NIL) -8 NIL NIL) (-84 145064 145788 145907 "ASP50" 146026 NIL ASP50 (NIL NIL) -8 NIL NIL) (-83 144152 144765 144875 "ASP4" 144985 NIL ASP4 (NIL NIL) -8 NIL NIL) (-82 143240 143853 143963 "ASP49" 144073 NIL ASP49 (NIL NIL) -8 NIL NIL) (-81 142025 142779 142947 "ASP42" 143129 NIL ASP42 (NIL NIL NIL NIL) -8 NIL NIL) (-80 140803 141558 141728 "ASP41" 141912 NIL ASP41 (NIL NIL NIL NIL) -8 NIL NIL) (-79 139755 140480 140598 "ASP35" 140716 NIL ASP35 (NIL NIL) -8 NIL NIL) (-78 139520 139703 139742 "ASP34" 139747 NIL ASP34 (NIL NIL) -8 NIL NIL) (-77 139257 139324 139400 "ASP33" 139475 NIL ASP33 (NIL NIL) -8 NIL NIL) (-76 138153 138892 139024 "ASP31" 139156 NIL ASP31 (NIL NIL) -8 NIL NIL) (-75 137918 138101 138140 "ASP30" 138145 NIL ASP30 (NIL NIL) -8 NIL NIL) (-74 137653 137722 137798 "ASP29" 137873 NIL ASP29 (NIL NIL) -8 NIL NIL) (-73 137418 137601 137640 "ASP28" 137645 NIL ASP28 (NIL NIL) -8 NIL NIL) (-72 137183 137366 137405 "ASP27" 137410 NIL ASP27 (NIL NIL) -8 NIL NIL) (-71 136267 136881 136992 "ASP24" 137103 NIL ASP24 (NIL NIL) -8 NIL NIL) (-70 135184 135908 136038 "ASP20" 136168 NIL ASP20 (NIL NIL) -8 NIL NIL) (-69 134272 134885 134995 "ASP1" 135105 NIL ASP1 (NIL NIL) -8 NIL NIL) (-68 133216 133946 134065 "ASP19" 134184 NIL ASP19 (NIL NIL) -8 NIL NIL) (-67 132953 133020 133096 "ASP12" 133171 NIL ASP12 (NIL NIL) -8 NIL NIL) (-66 131806 132552 132696 "ASP10" 132840 NIL ASP10 (NIL NIL) -8 NIL NIL) (-65 129711 131650 131741 "ARRAY2" 131746 NIL ARRAY2 (NIL T) -8 NIL NIL) (-64 125533 129359 129473 "ARRAY1" 129628 NIL ARRAY1 (NIL T) -8 NIL NIL) (-63 124565 124738 124959 "ARRAY12" 125356 NIL ARRAY12 (NIL T T) -7 NIL NIL) (-62 118964 120829 120905 "ARR2CAT" 123535 NIL ARR2CAT (NIL T T T) -9 NIL 124293) (-61 116398 117142 118096 "ARR2CAT-" 118101 NIL ARR2CAT- (NIL T T T T) -8 NIL NIL) (-60 115146 115298 115604 "APPRULE" 116234 NIL APPRULE (NIL T T T) -7 NIL NIL) (-59 114797 114845 114964 "APPLYORE" 115092 NIL APPLYORE (NIL T T T) -7 NIL NIL) (-58 114321 114409 114519 "API" 114705 T API (NIL) -7 NIL NIL) (-57 113295 113586 113781 "ANY" 114144 T ANY (NIL) -8 NIL NIL) (-56 112573 112696 112853 "ANY1" 113169 NIL ANY1 (NIL T) -7 NIL NIL) (-55 110092 111010 111337 "ANTISYM" 112297 NIL ANTISYM (NIL T NIL) -8 NIL NIL) (-54 109919 110051 110078 "ANON" 110083 T ANON (NIL) -8 NIL NIL) (-53 103986 108458 108912 "AN" 109483 T AN (NIL) -8 NIL NIL) (-52 100281 101679 101731 "AMR" 102479 NIL AMR (NIL T T) -9 NIL 103073) (-51 99393 99614 99977 "AMR-" 99982 NIL AMR- (NIL T T T) -8 NIL NIL) (-50 83955 99310 99371 "ALIST" 99376 NIL ALIST (NIL T T) -8 NIL NIL) (-49 80792 83549 83718 "ALGSC" 83873 NIL ALGSC (NIL T NIL NIL NIL) -8 NIL NIL) (-48 77350 77904 78510 "ALGPKG" 80233 NIL ALGPKG (NIL T T) -7 NIL NIL) (-47 76627 76728 76912 "ALGMFACT" 77236 NIL ALGMFACT (NIL T T T) -7 NIL NIL) (-46 72375 73059 73710 "ALGMANIP" 76154 NIL ALGMANIP (NIL T T) -7 NIL NIL) (-45 63689 72001 72151 "ALGFF" 72308 NIL ALGFF (NIL T T T NIL) -8 NIL NIL) (-44 62885 63016 63195 "ALGFACT" 63547 NIL ALGFACT (NIL T) -7 NIL NIL) (-43 61870 62480 62519 "ALGEBRA" 62579 NIL ALGEBRA (NIL T) -9 NIL 62638) (-42 61588 61647 61779 "ALGEBRA-" 61784 NIL ALGEBRA- (NIL T T) -8 NIL NIL) (-41 43395 59120 59173 "ALAGG" 59309 NIL ALAGG (NIL T T) -9 NIL 59470) (-40 42930 43043 43070 "AHYP" 43271 T AHYP (NIL) -9 NIL NIL) (-39 41861 42109 42136 "AGG" 42635 T AGG (NIL) -9 NIL 42913) (-38 41295 41457 41671 "AGG-" 41676 NIL AGG- (NIL T) -8 NIL NIL) (-37 38844 39425 39464 "AFSPCAT" 40736 NIL AFSPCAT (NIL T) -9 NIL 41231) (-36 36523 36945 37362 "AF" 38487 NIL AF (NIL T T) -7 NIL NIL) (-35 35863 36452 36506 "AFFSP" 36511 NIL AFFSP (NIL NIL T) -8 NIL NIL) (-34 35120 35790 35839 "AFFPLPS" 35844 NIL AFFPLPS (NIL T) -8 NIL NIL) (-33 34454 35061 35103 "AFFPL" 35108 NIL AFFPL (NIL T) -8 NIL NIL) (-32 31167 31654 32282 "AFALGRES" 33959 NIL AFALGRES (NIL T NIL T T T) -7 NIL NIL) (-31 29813 29990 30304 "AFALGGRO" 30986 NIL AFALGGRO (NIL T NIL T T T) -7 NIL NIL) (-30 29082 29340 29496 "ACPLOT" 29675 T ACPLOT (NIL) -8 NIL NIL) (-29 18442 26425 26477 "ACFS" 27188 NIL ACFS (NIL T) -9 NIL 27427) (-28 16456 16946 17721 "ACFS-" 17726 NIL ACFS- (NIL T T) -8 NIL NIL) (-27 12669 14625 14652 "ACF" 15531 T ACF (NIL) -9 NIL 15944) (-26 11373 11707 12200 "ACF-" 12205 NIL ACF- (NIL T) -8 NIL NIL) (-25 10970 11139 11166 "ABELSG" 11258 T ABELSG (NIL) -9 NIL 11323) (-24 10837 10862 10928 "ABELSG-" 10933 NIL ABELSG- (NIL T) -8 NIL NIL) (-23 10205 10466 10493 "ABELMON" 10663 T ABELMON (NIL) -9 NIL 10775) (-22 9869 9953 10091 "ABELMON-" 10096 NIL ABELMON- (NIL T) -8 NIL NIL) (-21 9202 9548 9575 "ABELGRP" 9700 T ABELGRP (NIL) -9 NIL 9782) (-20 8665 8794 9010 "ABELGRP-" 9015 NIL ABELGRP- (NIL T) -8 NIL NIL) (-19 4333 8027 8067 "A1AGG" 8072 NIL A1AGG (NIL T) -9 NIL 8112) (-18 30 1251 2813 "A1AGG-" 2818 NIL A1AGG- (NIL T T) -8 NIL NIL)) 
\ No newline at end of file
diff --git a/src/share/algebra/operation.daase b/src/share/algebra/operation.daase
index e804043..6f152f0 100644
--- a/src/share/algebra/operation.daase
+++ b/src/share/algebra/operation.daase
@@ -1,3227 +1,3229 @@
 
-(830305 . 3487447481)        
-(((*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-296)))) ((*1 *1 *1) (-4 *1 (-296))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) ((*1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047))))) 
-(((*1 *2 *1 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1))) (-4 *1 (-301)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2704 *1))) (-4 *1 (-301))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 *7 *5 *6)) (-5 *1 (-691 *4 *5 *6 *7)) (-4 *4 (-609 (-541))) (-4 *5 (-1195)) (-4 *6 (-1195)) (-4 *7 (-1195))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-409 *6)) (-4 *5 (-1199)) (-4 *6 (-1219 *5)) (-5 *2 (-2 (|:| -3438 (-763)) (|:| -2348 *3) (|:| |radicand| *6))) (-5 *1 (-151 *5 *6 *7)) (-5 *4 (-763)) (-4 *7 (-1219 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161)))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1 *1)) (-4 *1 (-641 *3)) (-4 *3 (-365)))) ((*1 *1 *2) (-12 (-5 *2 (-1 (-1141 *3))) (-5 *1 (-1141 *3)) (-4 *3 (-1195))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047))))) 
-(((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-381))) (-5 *5 (-1143)) (-5 *6 (-634 (-256))) (-5 *2 (-1249)) (-5 *1 (-456)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-381))) (-5 *5 (-1143)) (-5 *2 (-1249)) (-5 *1 (-456)))) ((*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-381))) (-5 *5 (-1143)) (-5 *6 (-634 (-256))) (-5 *2 (-1249)) (-5 *1 (-456)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-381))) (-5 *5 (-1143)) (-5 *2 (-1249)) (-5 *1 (-456))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-819))))) 
+(830583 . 3488060044)        
+(((*1 *2 *3 *4) (-12 (-5 *3 (-816)) (-5 *4 (-57)) (-5 *2 (-1249)) (-5 *1 (-826))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-392 *3 *4 *5)) (-14 *3 (-763)) (-14 *4 (-763)) (-4 *5 (-172))))) 
+(((*1 *1) (-5 *1 (-142))) ((*1 *1 *1) (-5 *1 (-147))) ((*1 *1 *1) (-4 *1 (-1129)))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-788)) (-4 *4 (-842)) (-4 *6 (-301)) (-5 *2 (-420 *3)) (-5 *1 (-732 *5 *4 *6 *3)) (-4 *3 (-950 *6 *5 *4))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-277 *2)) (-4 *2 (-1195)) (-4 *2 (-842)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (-4 *1 (-277 *3)) (-4 *3 (-1195)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-969 *2)) (-4 *2 (-842))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *3 (-1047)) (-4 *3 (-842)) (-5 *2 (-2 (|:| |val| *1) (|:| -3483 (-568)))) (-4 *1 (-432 *3)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |val| (-887 *3)) (|:| -3483 (-887 *3)))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-2 (|:| |val| *3) (|:| -3483 (-568)))) (-5 *1 (-951 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2747 ($ *7)) (-15 -2319 (*7 $)) (-15 -2326 (*7 $)))))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-3 (-1157 *4) (-1244 (-634 (-2 (|:| -2852 *4) (|:| -4357 (-1108))))))) (-5 *1 (-347 *4)) (-4 *4 (-350))))) 
 (((*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-1090)) (-5 *2 (-1143)))) ((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-568))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-679 *5)) (-5 *4 (-1244 *5)) (-4 *5 (-365)) (-5 *2 (-121)) (-5 *1 (-659 *5)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-13 (-375 *5) (-10 -7 (-6 -4520)))) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4520)))) (-5 *2 (-121)) (-5 *1 (-660 *5 *6 *4 *3)) (-4 *3 (-677 *5 *6 *4))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-360 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *2 *2 *2 *2 *3) (-12 (-5 *2 (-679 *4)) (-5 *3 (-763)) (-4 *4 (-1047)) (-5 *1 (-680 *4))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-2 (|:| |poly| *6) (|:| -1853 *3)))) (-5 *1 (-804 *5 *6 *3 *7)) (-4 *3 (-646 *6)) (-4 *7 (-646 (-409 *6))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-2 (|:| |poly| *6) (|:| -1853 (-644 *6 (-409 *6)))))) (-5 *1 (-807 *5 *6)) (-5 *3 (-644 *6 (-409 *6)))))) 
-(((*1 *2 *3) (-12 (-4 *1 (-340 *4 *3 *5)) (-4 *4 (-1199)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 (-409 *3))) (-5 *2 (-121)))) ((*1 *2 *3) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1216 *5 *4)) (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-568)) (-5 *1 (-1104 *4 *5))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-5 *1 (-1043 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-763)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-246 *4 *3 *5 *6)) (-4 *4 (-1047)) (-4 *3 (-842)) (-4 *5 (-262 *3)) (-4 *6 (-788)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-262 *3)) (-4 *3 (-842)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-350)) (-5 *2 (-917)))) ((*1 *2 *3) (-12 (-5 *3 (-334 *4 *5 *6 *7)) (-4 *4 (-13 (-370) (-365))) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-4 *7 (-340 *4 *5 *6)) (-5 *2 (-763)) (-5 *1 (-394 *4 *5 *6 *7)))) ((*1 *2 *1) (-12 (-4 *1 (-404)) (-5 *2 (-828 (-917))))) ((*1 *2 *1) (-12 (-4 *1 (-406)) (-5 *2 (-568)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-594 *3)) (-4 *3 (-1047)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-594 *3)) (-4 *3 (-1047)))) ((*1 *2 *1) (-12 (-4 *3 (-558)) (-5 *2 (-568)) (-5 *1 (-615 *3 *4)) (-4 *4 (-1219 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-641 *3)) (-4 *3 (-365)) (-5 *2 (-568)))) ((*1 *2 *1) (-12 (-4 *1 (-641 *3)) (-4 *3 (-365)) (-5 *2 (-568)))) ((*1 *2 *1 *3 *2) (-12 (-5 *2 (-763)) (-4 *1 (-730 *4 *3)) (-4 *4 (-1047)) (-4 *3 (-842)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-730 *4 *3)) (-4 *4 (-1047)) (-4 *3 (-842)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-863 *3)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-334 *5 *6 *7 *8)) (-4 *5 (-432 *4)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-4 *8 (-340 *5 *6 *7)) (-4 *4 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-763)) (-5 *1 (-906 *4 *5 *6 *7 *8)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-334 (-409 (-568)) *4 *5 *6)) (-4 *4 (-1219 (-409 (-568)))) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 (-409 (-568)) *4 *5)) (-5 *2 (-763)) (-5 *1 (-907 *4 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-334 *6 *7 *4 *8)) (-5 *5 (-1 *9 *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-4 *4 (-1219 (-409 *7))) (-4 *8 (-340 *6 *7 *4)) (-4 *9 (-13 (-370) (-365))) (-5 *2 (-763)) (-5 *1 (-1018 *6 *7 *4 *8 *9)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1219 *3)) (-4 *3 (-1047)) (-4 *3 (-558)) (-5 *2 (-763)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-1221 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787)))) ((*1 *2 *1) (-12 (-4 *1 (-1221 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787))))) 
-(((*1 *2 *1 *2) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *2 *10)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *2 (-235 *9)) (-4 *10 (-117))))) 
-(((*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-763)) (-5 *6 (-121)) (-4 *7 (-453)) (-4 *8 (-788)) (-4 *9 (-842)) (-4 *3 (-1061 *7 *8 *9)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1064 *7 *8 *9 *3 *4)) (-4 *4 (-1066 *7 *8 *9 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-763)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1064 *6 *7 *8 *3 *4)) (-4 *4 (-1066 *6 *7 *8 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1064 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-763)) (-5 *6 (-121)) (-4 *7 (-453)) (-4 *8 (-788)) (-4 *9 (-842)) (-4 *3 (-1061 *7 *8 *9)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1130 *7 *8 *9 *3 *4)) (-4 *4 (-1099 *7 *8 *9 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-763)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1130 *6 *7 *8 *3 *4)) (-4 *4 (-1099 *6 *7 *8 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1130 *5 *6 *7 *3 *4)) (-4 *4 (-1099 *5 *6 *7 *3))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-634 (-409 *6))) (-5 *3 (-409 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-572 *5 *6))))) 
-(((*1 *2 *2) (-12 (-5 *1 (-160 *2)) (-4 *2 (-550)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-972))))) 
-(((*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-679 (-409 *4)))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1 *3 *3 (-568))) (-4 *3 (-1047)) (-5 *1 (-101 *3)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-101 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-101 *3))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-944 *5)) (-4 *5 (-1047)) (-5 *2 (-763)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-763)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)) (-4 *5 (-1047)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-944 *5)) (-4 *5 (-1047)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436)))) ((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-573 *3)) (-4 *3 (-1037 (-568))))) ((*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-5 *2 (-634 (-2 (|:| C (-679 *5)) (|:| |g| (-1244 *5))))) (-5 *1 (-979 *5)) (-5 *3 (-679 *5)) (-5 *4 (-1244 *5))))) 
-(((*1 *2 *3 *1) (-12 (|has| *1 (-6 -4519)) (-4 *1 (-601 *4 *3)) (-4 *4 (-1090)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| |den| (-568)) (|:| |gcdnum| (-568))))) (-4 *4 (-1219 (-409 *2))) (-5 *2 (-568)) (-5 *1 (-909 *4 *5)) (-4 *5 (-1219 (-409 *4)))))) 
-(((*1 *1 *2 *3 *1) (-12 (-5 *2 (-1082 (-953 (-568)))) (-5 *3 (-953 (-568))) (-5 *1 (-328)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1082 (-953 (-568)))) (-5 *1 (-328))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1244 (-634 (-2 (|:| -2850 *4) (|:| -4355 (-1108)))))) (-4 *4 (-350)) (-5 *2 (-1249)) (-5 *1 (-532 *4))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *1 (-1012)) (-5 *2 (-850))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565)))) ((*1 *2 *3) (-12 (-5 *2 (-1157 (-409 (-568)))) (-5 *1 (-943)) (-5 *3 (-568))))) 
+(((*1 *2 *3 *3 *2) (-12 (-5 *2 (-1035)) (-5 *3 (-1161)) (-5 *1 (-184))))) 
+(((*1 *1) (-4 *1 (-23))) ((*1 *1) (-4 *1 (-39))) ((*1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) ((*1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172)))) ((*1 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) ((*1 *1) (-4 *1 (-716))) ((*1 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) ((*1 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) ((*1 *1) (-5 *1 (-1161)))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| |func| *3) (|:| |poly| *3) (|:| |c1| (-409 *5)) (|:| |c2| (-409 *5)) (|:| |deg| (-763)))) (-5 *1 (-151 *4 *5 *3)) (-4 *3 (-1219 (-409 *5)))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 (-492 *3 *4))) (-14 *3 (-634 (-1161))) (-4 *4 (-453)) (-5 *1 (-622 *3 *4))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *2 (-568)) (-5 *1 (-573 *3)) (-4 *3 (-1037 *2))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-453)) (-4 *3 (-842)) (-4 *3 (-1037 (-568))) (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-432 *3)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2319 ((-1113 *3 (-607 $)) $)) (-15 -2326 ((-1113 *3 (-607 $)) $)) (-15 -2747 ($ (-1113 *3 (-607 $)))))))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-139))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6))))) 
+(((*1 *2 *2 *3) (-12 (-4 *3 (-1047)) (-5 *1 (-445 *3 *2)) (-4 *2 (-1219 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-500)))) ((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-700))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-453)) (-4 *3 (-842)) (-4 *3 (-1037 (-568))) (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-432 *3)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2319 ((-1113 *3 (-607 $)) $)) (-15 -2326 ((-1113 *3 (-607 $)) $)) (-15 -2747 ($ (-1113 *3 (-607 $)))))))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-2 (|:| -4151 *6) (|:| |coeff| *6)) "failed") *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-5 *2 (-2 (|:| |answer| (-585 (-409 *7))) (|:| |a0| *6))) (-5 *1 (-578 *6 *7)) (-5 *3 (-409 *7))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1216 *5 *4)) (-4 *4 (-453)) (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-568)) (-5 *1 (-1104 *4 *5))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-172)))) ((*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-943)) (-5 *3 (-568))))) 
+(((*1 *2 *3 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-970 *5 *3)) (-4 *3 (-1219 *5))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-4 *1 (-555 *3)) (-4 *3 (-13 (-406) (-1181))))) ((*1 *1 *2) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181))))) ((*1 *1 *2 *2) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181)))))) 
+(((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-365)) (-5 *1 (-653 *3))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-679 *3)) (-4 *3 (-301)) (-5 *1 (-689 *3))))) 
+(((*1 *2 *2 *3 *2) (-12 (-5 *3 (-763)) (-4 *4 (-350)) (-5 *1 (-207 *4 *2)) (-4 *2 (-1219 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1699 *6) (-763))) (-5 *2 (-634 *8)) (-5 *1 (-31 *5 *6 *3 *7 *8)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1699 *6) (-763))) (-5 *2 (-3 (-634 *8) "failed" "Infinite" (-568))) (-5 *1 (-32 *5 *6 *3 *7 *8)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5))))) 
+(((*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 (-679 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-763)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-465))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-492 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-1047)) (-5 *2 (-953 *5)) (-5 *1 (-945 *4 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-57)) (-5 *1 (-824))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217)) (-5 *3 (-215))))) 
+(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
 (((*1 *2 *2 *3) (-12 (-5 *3 (-409 (-568))) (-4 *4 (-1037 (-568))) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-36 *4 *2)) (-4 *2 (-432 *4)))) ((*1 *1 *1 *1) (-5 *1 (-139))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *1 *1 *1) (-5 *1 (-215))) ((*1 *1 *1 *2) (-12 (-4 *1 (-238)) (-5 *2 (-568)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-409 (-568))) (-4 *4 (-365)) (-4 *4 (-43 *3)) (-4 *5 (-1234 *4)) (-5 *1 (-274 *4 *5 *2)) (-4 *2 (-1205 *4 *5)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-409 (-568))) (-4 *4 (-365)) (-4 *4 (-43 *3)) (-4 *5 (-1203 *4)) (-5 *1 (-275 *4 *5 *2 *6)) (-4 *2 (-1226 *4 *5)) (-4 *6 (-984 *5)))) ((*1 *1 *1 *1) (-4 *1 (-279))) ((*1 *1 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-363 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *1) (-5 *1 (-381))) ((*1 *1 *2 *3) (-12 (-5 *3 (-763)) (-5 *1 (-388 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-432 *3)) (-4 *3 (-842)) (-4 *3 (-1102)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-478)) (-5 *2 (-568)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-568)) (-4 *4 (-350)) (-5 *1 (-532 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-541)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-541)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1 *4 *4)) (-5 *3 (-763)) (-4 *4 (-1090)) (-5 *1 (-671 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-4 *3 (-365)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-679 *4)) (-5 *3 (-763)) (-4 *4 (-1047)) (-5 *1 (-680 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *3 (-1047)) (-5 *1 (-704 *3 *4)) (-4 *4 (-637 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-568)) (-4 *4 (-1047)) (-5 *1 (-704 *4 *5)) (-4 *5 (-637 *4)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-710)) (-5 *2 (-917)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-712)) (-5 *2 (-763)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-716)) (-5 *2 (-763)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-733 *2 *3)) (-14 *2 (-1161)) (-4 *3 (-13 (-1047) (-842) (-558))))) ((*1 *1 *2 *3) (-12 (-5 *3 (-763)) (-5 *1 (-814 *2)) (-4 *2 (-842)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-829 *3)) (-4 *3 (-1047)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-568)) (-5 *1 (-829 *4)) (-4 *4 (-1047)))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1002)) (-5 *2 (-409 (-568))))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1102)) (-5 *2 (-917)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-1111 *3 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-230 *3 *4)) (-4 *6 (-230 *3 *4)) (-4 *4 (-365)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-242 (-4287 (QUOTE X) (QUOTE -2926)) *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-5 *2 (-1 (-215) (-215))) (-5 *1 (-693 *3)) (-4 *3 (-609 (-541))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-1161)) (-5 *2 (-1 (-215) (-215) (-215))) (-5 *1 (-693 *3)) (-4 *3 (-609 (-541)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164)))) ((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1164))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-350)) (-5 *2 (-121)))) ((*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-350)) (-5 *2 (-121)) (-5 *1 (-358 *4))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-409 (-568))) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4)))))) 
-(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-1157 (-953 *4))) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4)))) ((*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-4 *3 (-365)) (-5 *2 (-1157 (-953 *3))))) ((*1 *2) (-12 (-5 *2 (-1157 (-409 (-953 *3)))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-381)) (-5 *1 (-1059))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-159 *4 *2)) (-4 *2 (-432 *4)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1082 *2)) (-4 *2 (-432 *4)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-159 *4 *2)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1082 *1)) (-4 *1 (-161)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-161)) (-5 *2 (-1161))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *6))) (-5 *4 (-634 (-1161))) (-4 *6 (-13 (-558) (-1037 *5))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *6)))))) (-5 *1 (-1038 *5 *6))))) 
-(((*1 *1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-111 *2)) (-4 *2 (-1195)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-130 *2)) (-4 *2 (-842)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-135 *2)) (-4 *2 (-842)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-277 *3)) (-4 *3 (-1195)))) ((*1 *1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-277 *2)) (-4 *2 (-1195)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| -3649 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) (-5 *1 (-563)))) ((*1 *1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-684 *2)) (-4 *2 (-1090)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| -3649 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381)))))) (-5 *1 (-798)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) ((*1 *2 *3 *4) (-12 (-5 *2 (-1249)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090))))) 
-(((*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121))))) 
-(((*1 *2 *3 *2) (|partial| -12 (-5 *3 (-917)) (-5 *1 (-443 *2)) (-4 *2 (-1219 (-568))))) ((*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-917)) (-5 *4 (-763)) (-5 *1 (-443 *2)) (-4 *2 (-1219 (-568))))) ((*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-917)) (-5 *4 (-634 (-763))) (-5 *1 (-443 *2)) (-4 *2 (-1219 (-568))))) ((*1 *2 *3 *2 *4 *5) (|partial| -12 (-5 *3 (-917)) (-5 *4 (-634 (-763))) (-5 *5 (-763)) (-5 *1 (-443 *2)) (-4 *2 (-1219 (-568))))) ((*1 *2 *3 *2 *4 *5 *6) (|partial| -12 (-5 *3 (-917)) (-5 *4 (-634 (-763))) (-5 *5 (-763)) (-5 *6 (-121)) (-5 *1 (-443 *2)) (-4 *2 (-1219 (-568))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-420 *2)) (-4 *2 (-1219 *5)) (-5 *1 (-445 *5 *2)) (-4 *5 (-1047))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-641 *2)) (-4 *2 (-365))))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1203 *4)) (-4 *4 (-1047)) (-4 *4 (-558)) (-5 *2 (-409 (-953 *4))))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1203 *4)) (-4 *4 (-1047)) (-4 *4 (-558)) (-5 *2 (-409 (-953 *4)))))) 
-(((*1 *2 *1 *3 *4 *4 *5) (-12 (-5 *3 (-944 (-215))) (-5 *4 (-869)) (-5 *5 (-917)) (-5 *2 (-1249)) (-5 *1 (-473)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-944 (-215))) (-5 *2 (-1249)) (-5 *1 (-473)))) ((*1 *2 *1 *3 *4 *4 *5) (-12 (-5 *3 (-634 (-944 (-215)))) (-5 *4 (-869)) (-5 *5 (-917)) (-5 *2 (-1249)) (-5 *1 (-473))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-586 *3)) (-4 *3 (-550))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1141 (-409 *3))) (-5 *1 (-173 *3)) (-4 *3 (-301))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-634 (-1141 *7))) (-4 *6 (-842)) (-4 *7 (-950 *5 (-534 *6) *6)) (-4 *5 (-1047)) (-5 *2 (-1 (-1141 *7) *7)) (-5 *1 (-1114 *5 *6 *7))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-215))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1219 (-568))) (-5 *1 (-496 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-215)) (-5 *1 (-817))))) 
-(((*1 *2) (-12 (-5 *2 (-1132 (-1143))) (-5 *1 (-393))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-1161))))) 
-(((*1 *1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-641 *2)) (-4 *2 (-365))))) 
+(((*1 *2 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-13 (-1047) (-707 (-409 (-568))))) (-4 *5 (-842)) (-5 *1 (-1258 *4 *5 *2)) (-4 *2 (-1263 *5 *4))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-4 *5 (-432 *4)) (-5 *2 (-420 *3)) (-5 *1 (-437 *4 *5 *3)) (-4 *3 (-1219 *5))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-679 (-169 (-409 (-568))))) (-5 *2 (-634 (-2 (|:| |outval| (-169 *4)) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 (-169 *4))))))) (-5 *1 (-756 *4)) (-4 *4 (-13 (-365) (-840)))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| -4194 (-123)) (|:| |w| (-215)))) (-5 *1 (-196))))) 
+(((*1 *1 *1) (-4 *1 (-863 *2)))) 
+(((*1 *1 *1 *2 *1) (-12 (-4 *1 (-134 *2)) (-4 *2 (-1090))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1699 *6) *4)) (-4 *9 (-971 *5)) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-4 *3 (-235 *11)) (-4 *12 (-536 *5 *6 *7 *8 *9 *10 *11 *3 *14)) (-4 *14 (-117)) (-5 *2 (-634 *7)) (-5 *1 (-467 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13 *14)) (-4 *13 (-258 *12)))) ((*1 *2 *3 *4 *5 *2) (-12 (-5 *2 (-634 *5)) (-4 *5 (-950 *6 *8 (-852 *7))) (-4 *8 (-230 (-1699 *7) *4)) (-5 *4 (-763)) (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *10 (-641 *6)) (-4 *11 (-920 *6 *10)) (-5 *1 (-562 *6 *7 *5 *8 *9 *10 *11 *3)) (-4 *9 (-971 *6)) (-4 *3 (-235 *11)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-236 (-922 *5))) (-5 *4 (-763)) (-4 *5 (-350)) (-5 *2 (-634 (-242 *6 *5))) (-5 *1 (-867 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-236 (-921 *5))) (-5 *4 (-763)) (-4 *5 (-365)) (-5 *2 (-634 (-242 *6 *5))) (-5 *1 (-868 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *2 (-3 (-634 *8) "failed" "Infinite" (-568))) (-5 *1 (-31 *4 *5 *6 *7 *8)) (-4 *8 (-971 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *2 (-3 (-634 *8) "failed" "Infinite" (-568))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *8 (-971 *4))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *1 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195)))) ((*1 *1 *1) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-375 *2)) (-4 *2 (-1195)))) ((*1 *1 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3)))) 
+(((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-1244 (-679 *4))) (-5 *1 (-95 *4 *5)) (-5 *3 (-679 *4)) (-4 *5 (-646 *4))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *4 (-365)) (-5 *2 (-634 *1)) (-4 *1 (-37 *4)))) ((*1 *2 *1) (-12 (-4 *3 (-365)) (-5 *2 (-634 *1)) (-4 *1 (-37 *3)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-898 *3)) (-4 *3 (-1090)) (-5 *2 (-1092 *3)))) ((*1 *2 *1 *3) (-12 (-4 *4 (-1090)) (-5 *2 (-1092 (-634 *4))) (-5 *1 (-899 *4)) (-5 *3 (-634 *4)))) ((*1 *2 *1 *3) (-12 (-4 *4 (-1090)) (-5 *2 (-1092 (-1092 *4))) (-5 *1 (-899 *4)) (-5 *3 (-1092 *4)))) ((*1 *2 *1 *3) (-12 (-5 *2 (-1092 *3)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *4 (-365)) (-5 *2 (-634 *1)) (-4 *1 (-971 *4)))) ((*1 *2 *1) (-12 (-4 *3 (-365)) (-5 *2 (-634 *1)) (-4 *1 (-971 *3))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-129 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *1 (-129 *3)) (-4 *3 (-1219 (-568)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-121))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-568)) (-5 *1 (-444 *4 *3 *5)) (-4 *3 (-1219 *4)) (-4 *5 (-13 (-406) (-1037 *4) (-365) (-1181) (-279)))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1219 (-53))))) ((*1 *2 *3 *1) (-12 (-5 *2 (-2 (|:| |less| (-130 *3)) (|:| |greater| (-130 *3)))) (-5 *1 (-130 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-4 *3 (-1090)) (-5 *2 (-634 *1)) (-4 *1 (-235 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-585 *4)) (-4 *4 (-13 (-29 *3) (-1181))) (-4 *3 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *1 (-583 *3 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-585 (-409 (-953 *3)))) (-4 *3 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *1 (-588 *3)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| -2244 *3) (|:| |special| *3))) (-5 *1 (-717 *5 *3)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1244 *5)) (-4 *5 (-365)) (-4 *5 (-1047)) (-5 *2 (-634 (-634 (-679 *5)))) (-5 *1 (-1029 *5)) (-5 *3 (-634 (-679 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1244 (-1244 *5))) (-4 *5 (-365)) (-4 *5 (-1047)) (-5 *2 (-634 (-634 (-679 *5)))) (-5 *1 (-1029 *5)) (-5 *3 (-634 (-679 *5))))) ((*1 *2 *1 *3) (-12 (-5 *3 (-142)) (-5 *2 (-634 *1)) (-4 *1 (-1129)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-147)) (-5 *2 (-634 *1)) (-4 *1 (-1129))))) 
+(((*1 *1 *1 *1) (-5 *1 (-121))) ((*1 *1 *1 *1) (-4 *1 (-132)))) 
+(((*1 *1 *2 *3 *4) (-12 (-5 *2 (-634 *1)) (-5 *3 (-634 (-763))) (-5 *4 (-568)) (-4 *1 (-641 *5)) (-4 *5 (-365))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-585 *2)) (-4 *2 (-13 (-29 *4) (-1181))) (-5 *1 (-583 *4 *2)) (-4 *4 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))))) ((*1 *2 *3) (-12 (-5 *3 (-585 (-409 (-953 *4)))) (-4 *4 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *2 (-310 *4)) (-5 *1 (-588 *4))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1195)) (-5 *2 (-763)) (-5 *1 (-179 *4 *3)) (-4 *3 (-665 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-381)) (-5 *1 (-197))))) 
+(((*1 *1 *1) (-12 (-4 *2 (-301)) (-4 *3 (-993 *2)) (-4 *4 (-1219 *3)) (-5 *1 (-415 *2 *3 *4 *5)) (-4 *5 (-13 (-411 *3 *4) (-1037 *3)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 *6)) (-4 *5 (-1090)) (-4 *6 (-1195)) (-5 *2 (-1 *6 *5)) (-5 *1 (-631 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 *2)) (-4 *5 (-1090)) (-4 *2 (-1195)) (-5 *1 (-631 *5 *2)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 *6)) (-5 *4 (-634 *5)) (-4 *6 (-1090)) (-4 *5 (-1195)) (-5 *2 (-1 *5 *6)) (-5 *1 (-631 *6 *5)))) ((*1 *2 *3 *4 *5 *2) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 *2)) (-4 *5 (-1090)) (-4 *2 (-1195)) (-5 *1 (-631 *5 *2)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-1 *6 *5)) (-5 *3 (-634 *5)) (-5 *4 (-634 *6)) (-4 *5 (-1090)) (-4 *6 (-1195)) (-5 *1 (-631 *5 *6)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 *2)) (-5 *6 (-1 *2 *5)) (-4 *5 (-1090)) (-4 *2 (-1195)) (-5 *1 (-631 *5 *2)))) ((*1 *2 *1 *1 *3) (-12 (-4 *1 (-1129)) (-5 *3 (-147)) (-5 *2 (-763))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-641 *2)) (-4 *2 (-365))))) 
+(((*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-1 (-585 *3) *3 (-1161))) (-5 *6 (-1 (-3 (-2 (|:| |special| *3) (|:| |integrand| *3)) "failed") *3 (-1161))) (-4 *3 (-279)) (-4 *3 (-620)) (-4 *3 (-1037 *4)) (-4 *3 (-432 *7)) (-5 *4 (-1161)) (-4 *7 (-609 (-887 (-568)))) (-4 *7 (-453)) (-4 *7 (-881 (-568))) (-4 *7 (-842)) (-5 *2 (-585 *3)) (-5 *1 (-577 *7 *3))))) 
 (((*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) ((*1 *1) (-4 *1 (-1136)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1244 (-634 (-2 (|:| -2850 *4) (|:| -4355 (-1108)))))) (-4 *4 (-350)) (-5 *2 (-763)) (-5 *1 (-347 *4)))) ((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-352 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917)))) ((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-353 *3 *4)) (-4 *3 (-350)) (-14 *4 (-3 (-1157 *3) (-1244 (-634 (-2 (|:| -2850 *3) (|:| -4355 (-1108))))))))) ((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-354 *3 *4)) (-4 *3 (-350)) (-14 *4 (-917))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-123)) (-4 *4 (-1047)) (-5 *1 (-704 *4 *2)) (-4 *2 (-637 *4)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-123)) (-5 *1 (-829 *2)) (-4 *2 (-1047))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-329 *3)) (-4 *3 (-842))))) 
-(((*1 *1 *2 *2) (-12 (-5 *1 (-873 *2)) (-4 *2 (-1195)))) ((*1 *1 *2 *2 *2) (-12 (-5 *1 (-875 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-944 *3))))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047))))) 
-(((*1 *2 *3) (-12 (-14 *4 (-634 (-1161))) (-14 *5 (-763)) (-5 *2 (-634 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568)))))) (-5 *1 (-515 *4 *5)) (-5 *3 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568)))))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 (-634 *6))) (-4 *6 (-950 *3 *5 *4)) (-4 *3 (-13 (-301) (-150))) (-4 *4 (-13 (-842) (-609 (-1161)))) (-4 *5 (-788)) (-5 *1 (-924 *3 *4 *5 *6))))) 
-(((*1 *2 *3 *2 *3 *2 *3) (-12 (-5 *2 (-958 (-215))) (-5 *3 (-1108)) (-5 *1 (-115))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-242 *3 *4)) (-14 *3 (-634 (-1161))) (-4 *4 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-14 *3 (-634 (-1161))) (-5 *1 (-455 *3 *4 *5)) (-4 *4 (-1047)) (-4 *5 (-230 (-1697 *3) (-763))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-492 *3 *4)) (-14 *3 (-634 (-1161))) (-4 *4 (-1047))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-634 *13)) (-4 *13 (-258 *12)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) *2)) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-5 *2 (-763)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-173 *3)) (-4 *3 (-301))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-766)) (-5 *1 (-57))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-842)) (-5 *2 (-1168 (-634 *4))) (-5 *1 (-1167 *4)) (-5 *3 (-634 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-350)) (-5 *2 (-1244 (-634 (-2 (|:| -2850 *4) (|:| -4355 (-1108)))))) (-5 *1 (-347 *4))))) 
-(((*1 *1 *1 *1 *1) (-4 *1 (-550)))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-777 *2)) (-4 *2 (-1047))))) 
-(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *1 *1) (-4 *1 (-279))) ((*1 *2 *3) (-12 (-5 *3 (-420 *4)) (-4 *4 (-558)) (-5 *2 (-634 (-2 (|:| -2348 (-763)) (|:| |logand| *4)))) (-5 *1 (-316 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) ((*1 *2 *1) (-12 (-5 *2 (-656 *3 *4)) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-13 (-1047) (-707 (-409 (-568))))) (-4 *5 (-842)) (-5 *1 (-1258 *4 *5 *2)) (-4 *2 (-1263 *5 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1262 *3 *4)) (-4 *4 (-707 (-409 (-568)))) (-4 *3 (-842)) (-4 *4 (-172))))) 
-(((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-634 *7)) (-5 *4 (-1 *7 (-763) (-763) *8)) (-5 *5 (-1244 *9)) (-5 *6 (-634 (-763))) (-4 *7 (-13 (-558) (-453))) (-4 *8 (-324 *7 (-763))) (-4 *9 (-324 (-409 *7) (-763))) (-5 *2 (-679 (-1157 *7))) (-5 *1 (-345 *7 *8 *9)))) ((*1 *2 *3 *4 *5 *6 *6) (-12 (-5 *3 (-634 *7)) (-5 *4 (-1 *7 (-763) (-763) *8)) (-5 *5 (-1244 *9)) (-5 *6 (-763)) (-4 *7 (-13 (-558) (-453))) (-4 *8 (-324 *7 *6)) (-4 *9 (-324 (-409 *7) *6)) (-5 *2 (-1141 (-679 (-1157 *7)))) (-5 *1 (-345 *7 *8 *9)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-634 *7)) (-5 *4 (-1 *7 (-763) (-763) *8)) (-5 *5 (-1244 *8)) (-5 *6 (-634 (-763))) (-4 *7 (-13 (-558) (-453))) (-4 *8 (-52 *7 (-763))) (-5 *2 (-679 (-1157 *7))) (-5 *1 (-346 *7 *8)))) ((*1 *2 *3 *4 *5 *6 *6) (-12 (-5 *3 (-634 *7)) (-5 *4 (-1 *7 (-763) (-763) *8)) (-5 *5 (-1244 *8)) (-5 *6 (-763)) (-4 *7 (-13 (-558) (-453))) (-4 *8 (-52 *7 *6)) (-5 *2 (-1141 (-679 (-1157 *7)))) (-5 *1 (-346 *7 *8))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1047)) (-5 *1 (-318 *4 *5 *2 *6)) (-4 *6 (-950 *2 *4 *5))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-643 (-409 *6))) (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-409 *6))) (-5 *1 (-807 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-643 (-409 *7))) (-5 *4 (-1 (-634 *6) *7)) (-5 *5 (-1 (-420 *7) *7)) (-4 *6 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *7 (-1219 *6)) (-5 *2 (-634 (-409 *7))) (-5 *1 (-807 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-644 *6 (-409 *6))) (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-409 *6))) (-5 *1 (-807 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-644 *7 (-409 *7))) (-5 *4 (-1 (-634 *6) *7)) (-5 *5 (-1 (-420 *7) *7)) (-4 *6 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *7 (-1219 *6)) (-5 *2 (-634 (-409 *7))) (-5 *1 (-807 *6 *7)))) ((*1 *2 *3) (-12 (-5 *3 (-643 (-409 *5))) (-4 *5 (-1219 *4)) (-4 *4 (-27)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-634 (-409 *5))) (-5 *1 (-807 *4 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-643 (-409 *6))) (-5 *4 (-1 (-420 *6) *6)) (-4 *6 (-1219 *5)) (-4 *5 (-27)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-634 (-409 *6))) (-5 *1 (-807 *5 *6)))) ((*1 *2 *3) (-12 (-5 *3 (-644 *5 (-409 *5))) (-4 *5 (-1219 *4)) (-4 *4 (-27)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-634 (-409 *5))) (-5 *1 (-807 *4 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-644 *6 (-409 *6))) (-5 *4 (-1 (-420 *6) *6)) (-4 *6 (-1219 *5)) (-4 *5 (-27)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-634 (-409 *6))) (-5 *1 (-807 *5 *6))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-183)) (-5 *3 (-568)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-778 *2)) (-4 *2 (-172)))) ((*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-943)) (-5 *3 (-568))))) 
-(((*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *3)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-4 *3 (-166 *6)) (-4 (-953 *6) (-881 *5)) (-4 *6 (-13 (-881 *5) (-172))) (-5 *1 (-176 *5 *6 *3)))) ((*1 *2 *1 *3 *2) (-12 (-5 *2 (-884 *4 *1)) (-5 *3 (-887 *4)) (-4 *1 (-881 *4)) (-4 *4 (-1090)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *6)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-4 *6 (-13 (-1090) (-1037 *3))) (-4 *3 (-881 *5)) (-5 *1 (-932 *5 *3 *6)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *3)) (-4 *5 (-1090)) (-4 *3 (-13 (-432 *6) (-609 *4) (-881 *5) (-1037 (-607 $)))) (-5 *4 (-887 *5)) (-4 *6 (-13 (-558) (-842) (-881 *5))) (-5 *1 (-933 *5 *6 *3)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 (-568) *3)) (-5 *4 (-887 (-568))) (-4 *3 (-550)) (-5 *1 (-934 *3)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *6)) (-5 *3 (-607 *6)) (-4 *5 (-1090)) (-4 *6 (-13 (-842) (-1037 (-607 $)) (-609 *4) (-881 *5))) (-5 *4 (-887 *5)) (-5 *1 (-935 *5 *6)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-880 *5 *6 *3)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-4 *6 (-881 *5)) (-4 *3 (-658 *6)) (-5 *1 (-936 *5 *6 *3)))) ((*1 *2 *3 *4 *2 *5) (-12 (-5 *5 (-1 (-884 *6 *3) *8 (-887 *6) (-884 *6 *3))) (-4 *8 (-842)) (-5 *2 (-884 *6 *3)) (-5 *4 (-887 *6)) (-4 *6 (-1090)) (-4 *3 (-13 (-950 *9 *7 *8) (-609 *4))) (-4 *7 (-788)) (-4 *9 (-13 (-1047) (-842) (-881 *6))) (-5 *1 (-937 *6 *7 *8 *9 *3)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *3)) (-4 *5 (-1090)) (-4 *3 (-13 (-950 *8 *6 *7) (-609 *4))) (-5 *4 (-887 *5)) (-4 *7 (-881 *5)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-13 (-1047) (-842) (-881 *5))) (-5 *1 (-937 *5 *6 *7 *8 *3)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *3)) (-4 *5 (-1090)) (-4 *3 (-993 *6)) (-4 *6 (-13 (-558) (-881 *5) (-609 *4))) (-5 *4 (-887 *5)) (-5 *1 (-940 *5 *6 *3)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 (-1161))) (-5 *3 (-1161)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-5 *1 (-941 *5)))) ((*1 *2 *3 *4 *5 *2 *6) (-12 (-5 *4 (-634 (-887 *7))) (-5 *5 (-1 *9 (-634 *9))) (-5 *6 (-1 (-884 *7 *9) *9 (-887 *7) (-884 *7 *9))) (-4 *7 (-1090)) (-4 *9 (-13 (-1047) (-609 (-887 *7)) (-1037 *8))) (-5 *2 (-884 *7 *9)) (-5 *3 (-634 *9)) (-4 *8 (-13 (-1047) (-842))) (-5 *1 (-942 *7 *8 *9))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-369 *2)) (-4 *2 (-172))))) 
-(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-1157 (-953 *4))) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4)))) ((*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-4 *3 (-365)) (-5 *2 (-1157 (-953 *3))))) ((*1 *2) (-12 (-5 *2 (-1157 (-409 (-953 *3)))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-634 (-1216 *5 *4))) (-5 *1 (-1104 *4 *5)) (-5 *3 (-1216 *5 *4))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-634 (-1161))) (-4 *6 (-365)) (-5 *2 (-634 (-288 (-953 *6)))) (-5 *1 (-543 *5 *6 *7)) (-4 *5 (-453)) (-4 *7 (-13 (-365) (-840)))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |mval| (-679 *3)) (|:| |invmval| (-679 *3)) (|:| |genIdeal| (-514 *3 *4 *5 *6)))) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-1215 *3 *2)) (-4 *2 (-1219 *3))))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-142)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-147))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *1 (-313)) (-5 *3 (-215))))) 
+(((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 (-763) *2)) (-5 *4 (-763)) (-4 *2 (-1090)) (-5 *1 (-668 *2)))) ((*1 *2 *2) (-12 (-5 *2 (-1 *3 (-763) *3)) (-4 *3 (-1090)) (-5 *1 (-671 *3))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-420 *3)) (-4 *3 (-558))))) 
+(((*1 *2 *3 *3) (-12 (-5 *2 (-1157 *3)) (-5 *1 (-910 *3)) (-4 *3 (-301))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-819)) (-5 *1 (-820))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-1157 *6)) (-5 *3 (-568)) (-4 *6 (-301)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-732 *4 *5 *6 *7)) (-4 *7 (-950 *6 *4 *5))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-171)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1191 *3)) (-4 *3 (-975))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1866 *7) (|:| -1844 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *5 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *5))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-944 *3))))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-558)) (-5 *2 (-121))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *3 *3 *4) (-12 (-5 *4 (-634 (-310 (-215)))) (-5 *3 (-215)) (-5 *2 (-121)) (-5 *1 (-202))))) 
+(((*1 *2 *3) (-12 (-4 *1 (-916)) (-5 *2 (-2 (|:| -2350 (-634 *1)) (|:| -2707 *1))) (-5 *3 (-634 *1))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-763))))) 
+(((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) ((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) ((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927))))) 
+(((*1 *2 *2 *2) (-12 (-4 *2 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *1 (-1116 *3 *2)) (-4 *3 (-1219 *2))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *1 *1) (-4 *1 (-279))) ((*1 *2 *3) (-12 (-5 *3 (-420 *4)) (-4 *4 (-558)) (-5 *2 (-634 (-2 (|:| -2350 (-763)) (|:| |logand| *4)))) (-5 *1 (-316 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) ((*1 *2 *1) (-12 (-5 *2 (-656 *3 *4)) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-13 (-1047) (-707 (-409 (-568))))) (-4 *5 (-842)) (-5 *1 (-1258 *4 *5 *2)) (-4 *2 (-1263 *5 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1262 *3 *4)) (-4 *4 (-707 (-409 (-568)))) (-4 *3 (-842)) (-4 *4 (-172))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-607 (-53)))) (-5 *1 (-53)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-607 (-53))) (-5 *1 (-53)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1157 (-53))) (-5 *3 (-634 (-607 (-53)))) (-5 *1 (-53)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1157 (-53))) (-5 *3 (-607 (-53))) (-5 *1 (-53)))) ((*1 *2 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)))) ((*1 *2 *3) (-12 (-4 *2 (-13 (-365) (-840))) (-5 *1 (-178 *2 *3)) (-4 *3 (-1219 (-169 *2))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)))) ((*1 *2 *1) (-12 (-4 *1 (-327 *2)) (-4 *2 (-365)))) ((*1 *2 *1) (-12 (-4 *1 (-372 *2 *3)) (-4 *3 (-1219 *2)) (-4 *2 (-172)))) ((*1 *2 *1) (-12 (-4 *4 (-1219 *2)) (-4 *2 (-993 *3)) (-5 *1 (-415 *3 *2 *4 *5)) (-4 *3 (-301)) (-4 *5 (-13 (-411 *2 *4) (-1037 *2))))) ((*1 *2 *1) (-12 (-4 *4 (-1219 *2)) (-4 *2 (-993 *3)) (-5 *1 (-416 *3 *2 *4 *5 *6)) (-4 *3 (-301)) (-4 *5 (-411 *2 *4)) (-14 *6 (-1244 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-1047)) (-4 *2 (-13 (-406) (-1037 *5) (-365) (-1181) (-279))) (-5 *1 (-444 *5 *3 *2)) (-4 *3 (-1219 *5)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-607 (-504)))) (-5 *1 (-504)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-607 (-504))) (-5 *1 (-504)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1157 (-504))) (-5 *3 (-634 (-607 (-504)))) (-5 *1 (-504)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1157 (-504))) (-5 *3 (-607 (-504))) (-5 *1 (-504)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-917)) (-4 *4 (-350)) (-5 *1 (-532 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-453)) (-4 *5 (-714 *4 *2)) (-4 *2 (-1219 *4)) (-5 *1 (-767 *4 *2 *5 *3)) (-4 *3 (-1219 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) ((*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172)))) ((*1 *1 *1) (-4 *1 (-1056)))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *2 *3 *1) (|partial| -12 (-5 *3 (-887 *4)) (-4 *4 (-1090)) (-4 *2 (-1090)) (-5 *1 (-884 *4 *2))))) 
+(((*1 *2 *2 *3 *2) (-12 (-5 *3 (-763)) (-4 *4 (-350)) (-5 *1 (-207 *4 *2)) (-4 *2 (-1219 *4)))) ((*1 *2 *2 *3 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-685 *2)) (-4 *2 (-1219 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-1244 (-688))) (-5 *1 (-299))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-5 *2 (-1249)) (-5 *1 (-1197)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-634 (-1161))) (-5 *2 (-1249)) (-5 *1 (-1197))))) 
+(((*1 *1) (-5 *1 (-818)))) 
+(((*1 *1 *1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *2)) (-4 *2 (-950 *3 *4 *5)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4))))) 
+(((*1 *2 *3) (|partial| -12 (-4 *5 (-1037 (-53))) (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-4 *5 (-432 *4)) (-5 *2 (-420 (-1157 (-53)))) (-5 *1 (-437 *4 *5 *3)) (-4 *3 (-1219 *5))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147))))) 
+(((*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-634 *3)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-634 *3)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-634 *3)) (-5 *1 (-494 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (|has| *1 (-6 -4521)) (-4 *1 (-499 *3)) (-4 *3 (-1195)) (-5 *2 (-634 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-727 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-634 *3)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-634 *3)) (-5 *1 (-1132 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-634 *6) "failed") (-568) *6 *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-5 *2 (-2 (|:| |answer| (-585 (-409 *7))) (|:| |a0| *6))) (-5 *1 (-578 *6 *7)) (-5 *3 (-409 *7))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-568))))) 
 (((*1 *1 *1) (-5 *1 (-121)))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 *4)) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2850 *4) (|:| -2183 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1236 *3 *2)) (-4 *2 (-1234 *3))))) 
-(((*1 *2) (-12 (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *9)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2) (-12 (-5 *2 (-634 (-922 *3))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-634 (-921 *3))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
-(((*1 *1 *1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558))))) 
+(((*1 *2) (-12 (-4 *3 (-1047)) (-5 *2 (-958 (-702 *3 *4))) (-5 *1 (-702 *3 *4)) (-4 *4 (-1219 *3))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-568)) (-5 *1 (-450 *4 *5 *6 *3)) (-4 *3 (-950 *4 *5 *6))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1047)) (-5 *2 (-1244 *3)) (-5 *1 (-702 *3 *4)) (-4 *4 (-1219 *3))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-634 (-1069 *4 *5 *2))) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-4 *2 (-13 (-432 *5) (-881 *4) (-609 (-887 *4)))) (-5 *1 (-60 *4 *5 *2)))) ((*1 *2 *3 *2 *4) (-12 (-5 *3 (-634 (-1069 *5 *6 *2))) (-5 *4 (-917)) (-4 *5 (-1090)) (-4 *6 (-13 (-1047) (-881 *5) (-842) (-609 (-887 *5)))) (-4 *2 (-13 (-432 *6) (-881 *5) (-609 (-887 *5)))) (-5 *1 (-60 *5 *6 *2))))) 
 (((*1 *2 *1) (|partial| -12 (-5 *2 (-1 (-541) (-634 (-541)))) (-5 *1 (-123)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 (-541) (-634 (-541)))) (-5 *1 (-123))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *2 *10)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-117)) (-4 *2 (-235 *9))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-842) (-1037 (-568)) (-453) (-630 (-568)))) (-5 *2 (-2 (|:| -1841 *3) (|:| |nconst| *3))) (-5 *1 (-571 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5)))))) 
-(((*1 *2 *3 *4 *5 *5) (-12 (-5 *5 (-763)) (-4 *6 (-1090)) (-4 *7 (-895 *6)) (-5 *2 (-679 *7)) (-5 *1 (-681 *6 *7 *3 *4)) (-4 *3 (-375 *7)) (-4 *4 (-13 (-375 *6) (-10 -7 (-6 -4519))))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-646 *2)) (-4 *2 (-1047)))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *4 (-172)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-2 (|:| |adjMat| *3) (|:| |detMat| *4))) (-5 *1 (-678 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-172)) (-4 *2 (-1047)) (-5 *1 (-704 *2 *3)) (-4 *3 (-637 *2)))) ((*1 *1 *1) (-12 (-4 *2 (-172)) (-4 *2 (-1047)) (-5 *1 (-704 *2 *3)) (-4 *3 (-637 *2)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-829 *2)) (-4 *2 (-172)) (-4 *2 (-1047)))) ((*1 *1 *1) (-12 (-5 *1 (-829 *2)) (-4 *2 (-172)) (-4 *2 (-1047))))) 
-(((*1 *2 *3 *1) (-12 (-4 *1 (-1189 *4 *5 *3 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *3 (-842)) (-4 *6 (-1061 *4 *5 *3)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-121))))) 
-(((*1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-393))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-634 *7)) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1697 *6) (-763))) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-5 *2 (-634 (-1244 *5))) (-5 *1 (-562 *5 *6 *7 *8 *9 *10 *11 *3)) (-4 *9 (-971 *5)) (-4 *3 (-235 *11))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1244 *1)) (-5 *4 (-1 *5 *5)) (-4 *5 (-365)) (-4 *1 (-714 *5 *6)) (-4 *5 (-172)) (-4 *6 (-1219 *5)) (-5 *2 (-679 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-869)))) ((*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *2)) (-5 *4 (-1 (-121) *2 *2)) (-5 *1 (-1196 *2)) (-4 *2 (-1090)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-1090)) (-4 *2 (-842)) (-5 *1 (-1196 *2))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1173 *4 *5)) (-4 *4 (-1090)) (-4 *5 (-1090))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-365)) (-4 *5 (-1219 *4)) (-5 *2 (-1249)) (-5 *1 (-45 *4 *5 *6 *7)) (-4 *6 (-1219 (-409 *5))) (-14 *7 *6)))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-1143)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *4 (-1061 *6 *7 *8)) (-5 *2 (-1249)) (-5 *1 (-768 *6 *7 *8 *4 *5)) (-4 *5 (-1066 *6 *7 *8 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-381))))) 
+(((*1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1164))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-904)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-950 *4 *5 *6)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-901 *4 *5 *6 *7)) (-5 *3 (-1157 *7)))) ((*1 *2 *3) (-12 (-4 *4 (-904)) (-4 *5 (-1219 *4)) (-5 *2 (-420 (-1157 *5))) (-5 *1 (-902 *4 *5)) (-5 *3 (-1157 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1141 (-1141 *4))) (-5 *2 (-1141 *4)) (-5 *1 (-1145 *4)) (-4 *4 (-43 (-409 (-568)))) (-4 *4 (-1047))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1189 *2 *3 *4 *5)) (-4 *2 (-558)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-1061 *2 *3 *4))))) 
+(((*1 *2 *1 *2 *3) (|partial| -12 (-5 *2 (-1143)) (-5 *3 (-568)) (-5 *1 (-1059))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-369 *2)) (-4 *2 (-172))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-150))) (-5 *1 (-542 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-4 *4 (-1219 *3)) (-4 *5 (-714 *3 *4)) (-5 *1 (-546 *3 *4 *5 *2)) (-4 *2 (-1234 *5)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-5 *1 (-547 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-13 (-558) (-150))) (-5 *1 (-1137 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-1182 *3))) (-5 *1 (-1182 *3)) (-4 *3 (-1090))))) 
+(((*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1044 *4 *5)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *5 (-634 (-1161))) (-5 *2 (-634 (-2 (|:| -3722 (-1157 *4)) (|:| -1656 (-634 (-953 *4)))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *6 (-634 (-1161))))) ((*1 *2 *3 *4 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-2 (|:| -3722 (-1157 *5)) (|:| -1656 (-634 (-953 *5)))))) (-5 *1 (-1268 *5 *6 *7)) (-5 *3 (-634 (-953 *5))) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-2 (|:| -3722 (-1157 *5)) (|:| -1656 (-634 (-953 *5)))))) (-5 *1 (-1268 *5 *6 *7)) (-5 *3 (-634 (-953 *5))) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-2 (|:| -3722 (-1157 *5)) (|:| -1656 (-634 (-953 *5)))))) (-5 *1 (-1268 *5 *6 *7)) (-5 *3 (-634 (-953 *5))) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-2 (|:| -3722 (-1157 *4)) (|:| -1656 (-634 (-953 *4)))))) (-5 *1 (-1268 *4 *5 *6)) (-5 *3 (-634 (-953 *4))) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161)))))) 
+(((*1 *2 *3 *3 *2) (-12 (-5 *2 (-1141 *4)) (-5 *3 (-568)) (-4 *4 (-1047)) (-5 *1 (-1145 *4)))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1201 *3)) (-4 *3 (-1047)))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-1161))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-1141 *4)) (-4 *4 (-43 *3)) (-4 *4 (-1047)) (-5 *3 (-409 (-568))) (-5 *1 (-1145 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-5 *2 (-121))))) 
 (((*1 *2 *3 *4 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-748))))) 
-(((*1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-1244 *4)) (-4 *4 (-630 (-568))) (-5 *2 (-1244 (-568))) (-5 *1 (-1269 *4))))) 
-(((*1 *2 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-558)) (-5 *1 (-970 *4 *2)) (-4 *2 (-1219 *4))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *8)) (|:| |neqzro| (-634 *8)) (|:| |wcond| (-634 (-953 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *5)))) (|:| -3746 (-634 (-1244 (-409 (-953 *5)))))))))) (-5 *1 (-924 *5 *6 *7 *8)) (-5 *4 (-634 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-5 *4 (-634 (-1161))) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *8)) (|:| |neqzro| (-634 *8)) (|:| |wcond| (-634 (-953 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *5)))) (|:| -3746 (-634 (-1244 (-409 (-953 *5)))))))))) (-5 *1 (-924 *5 *6 *7 *8)))) ((*1 *2 *3) (-12 (-5 *3 (-679 *7)) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *7)) (|:| |neqzro| (-634 *7)) (|:| |wcond| (-634 (-953 *4))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *4)))) (|:| -3746 (-634 (-1244 (-409 (-953 *4)))))))))) (-5 *1 (-924 *4 *5 *6 *7)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *9)) (-5 *5 (-917)) (-4 *9 (-950 *6 *8 *7)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-13 (-842) (-609 (-1161)))) (-4 *8 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *9)) (|:| |neqzro| (-634 *9)) (|:| |wcond| (-634 (-953 *6))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *6)))) (|:| -3746 (-634 (-1244 (-409 (-953 *6)))))))))) (-5 *1 (-924 *6 *7 *8 *9)) (-5 *4 (-634 *9)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *9)) (-5 *4 (-634 (-1161))) (-5 *5 (-917)) (-4 *9 (-950 *6 *8 *7)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-13 (-842) (-609 (-1161)))) (-4 *8 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *9)) (|:| |neqzro| (-634 *9)) (|:| |wcond| (-634 (-953 *6))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *6)))) (|:| -3746 (-634 (-1244 (-409 (-953 *6)))))))))) (-5 *1 (-924 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-5 *4 (-917)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *8)) (|:| |neqzro| (-634 *8)) (|:| |wcond| (-634 (-953 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *5)))) (|:| -3746 (-634 (-1244 (-409 (-953 *5)))))))))) (-5 *1 (-924 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *9)) (-5 *4 (-634 *9)) (-5 *5 (-1143)) (-4 *9 (-950 *6 *8 *7)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-13 (-842) (-609 (-1161)))) (-4 *8 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *6 *7 *8 *9)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *9)) (-5 *4 (-634 (-1161))) (-5 *5 (-1143)) (-4 *9 (-950 *6 *8 *7)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-13 (-842) (-609 (-1161)))) (-4 *8 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-5 *4 (-1143)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-679 *10)) (-5 *4 (-634 *10)) (-5 *5 (-917)) (-5 *6 (-1143)) (-4 *10 (-950 *7 *9 *8)) (-4 *7 (-13 (-301) (-150))) (-4 *8 (-13 (-842) (-609 (-1161)))) (-4 *9 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *7 *8 *9 *10)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-679 *10)) (-5 *4 (-634 (-1161))) (-5 *5 (-917)) (-5 *6 (-1143)) (-4 *10 (-950 *7 *9 *8)) (-4 *7 (-13 (-301) (-150))) (-4 *8 (-13 (-842) (-609 (-1161)))) (-4 *9 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *7 *8 *9 *10)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *9)) (-5 *4 (-917)) (-5 *5 (-1143)) (-4 *9 (-950 *6 *8 *7)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-13 (-842) (-609 (-1161)))) (-4 *8 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *6 *7 *8 *9))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-568)) (-5 *1 (-496 *4)) (-4 *4 (-1219 *2))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-820))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-736 *3)) (-4 *3 (-172))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-927))))) 
-(((*1 *1 *1) (|partial| -4 *1 (-148))) ((*1 *1 *1) (-4 *1 (-350))) ((*1 *1 *1) (|partial| -12 (-4 *1 (-148)) (-4 *1 (-904))))) 
-(((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-215)) (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-366 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-1219 *2)) (-4 *2 (-1199)) (-5 *1 (-151 *2 *4 *3)) (-4 *3 (-1219 (-409 *4)))))) 
+(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-13 (-558) (-453))) (-5 *2 (-634 *4)) (-5 *1 (-346 *4 *5)) (-4 *5 (-52 *4 *3))))) 
+(((*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-634 (-953 *6))) (-5 *4 (-634 (-1161))) (-4 *6 (-453)) (-5 *2 (-634 (-634 *7))) (-5 *1 (-543 *6 *7 *5)) (-4 *7 (-365)) (-4 *5 (-13 (-365) (-840)))))) 
+(((*1 *1 *1 *1 *1) (-4 *1 (-550)))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-958 *3)) (-5 *1 (-1148 *4 *3)) (-4 *3 (-1219 *4))))) 
 (((*1 *2 *3 *4 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-748))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-1219 *4)) (-4 *4 (-1199)) (-4 *1 (-340 *4 *3 *5)) (-4 *5 (-1219 (-409 *3)))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-13 (-365) (-150))) (-5 *2 (-634 (-2 (|:| -3438 (-763)) (|:| -1374 *4) (|:| |num| *4)))) (-5 *1 (-401 *3 *4)) (-4 *4 (-1219 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-853 *4 *5 *6 *7)) (-4 *4 (-1047)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 *3)) (-14 *7 *3))) ((*1 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-1047)) (-4 *5 (-842)) (-4 *6 (-788)) (-14 *8 (-634 *5)) (-5 *2 (-1249)) (-5 *1 (-1254 *4 *5 *6 *7 *8 *9 *10)) (-4 *7 (-950 *4 *6 *5)) (-14 *9 (-634 *3)) (-14 *10 *3)))) 
-(((*1 *2) (-12 (-5 *2 (-634 (-917))) (-5 *1 (-1247)))) ((*1 *2 *2) (-12 (-5 *2 (-634 (-917))) (-5 *1 (-1247))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-310 (-215)))) (-5 *2 (-121)) (-5 *1 (-263)))) ((*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-121)) (-5 *1 (-263)))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-842)) (-5 *2 (-634 (-634 (-634 *4)))) (-5 *1 (-1167 *4)) (-5 *3 (-634 (-634 *4)))))) 
+(((*1 *2 *3 *3 *4) (-12 (-5 *3 (-763)) (-4 *2 (-13 (-558) (-453))) (-5 *1 (-346 *2 *4)) (-4 *4 (-52 *2 *3))))) 
+(((*1 *1 *2 *3 *1) (-12 (-5 *2 (-887 *4)) (-4 *4 (-1090)) (-5 *1 (-884 *4 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217)))) ((*1 *1 *1) (-4 *1 (-620))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181)))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 *2))) (-5 *2 (-887 *3)) (-5 *1 (-1069 *3 *4 *5)) (-4 *5 (-13 (-432 *4) (-881 *3) (-609 *2)))))) 
 (((*1 *2 *3 *4 *3 *4 *4 *4) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-748))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-301)) (-5 *2 (-763)) (-5 *1 (-457 *5 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-568)) (-5 *1 (-234)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-568)) (-5 *1 (-234))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-634 *3)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-634 *3)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-634 *3)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-634 *3)) (-5 *1 (-494 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (|has| *1 (-6 -4519)) (-4 *1 (-499 *3)) (-4 *3 (-1195)) (-5 *2 (-634 *3)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-634 *3)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-634 *3)) (-5 *1 (-1132 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1035))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) ((*1 *2 *2 *1) (|partial| -12 (-5 *2 (-409 *1)) (-4 *1 (-1219 *3)) (-4 *3 (-1047)) (-4 *3 (-558)))) ((*1 *1 *1 *1) (|partial| -12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-558))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *3 (-1102)) (-4 *3 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-432 *3)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (|partial| -12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-950 *3 *4 *5)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-634 *3)) (-5 *1 (-951 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2747 ($ *7)) (-15 -2319 (*7 $)) (-15 -2326 (*7 $)))))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-679 (-409 (-953 (-568))))) (-5 *2 (-634 (-679 (-310 (-568))))) (-5 *1 (-1031)) (-5 *3 (-310 (-568)))))) 
 (((*1 *2 *3 *4 *3 *5 *5 *3 *5 *4) (-12 (-5 *4 (-679 (-215))) (-5 *5 (-679 (-568))) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-748))))) 
-(((*1 *2 *2 *3 *4) (-12 (-5 *3 (-634 (-607 *6))) (-5 *4 (-1161)) (-5 *2 (-607 *6)) (-4 *6 (-432 *5)) (-4 *5 (-842)) (-5 *1 (-577 *5 *6))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-370)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1244 *4)) (-5 *1 (-532 *4)) (-4 *4 (-350)))) ((*1 *2 *1) (-12 (-4 *2 (-842)) (-5 *1 (-703 *2 *3 *4)) (-4 *3 (-1090)) (-14 *4 (-1 (-121) (-2 (|:| -4355 *2) (|:| -3438 *3)) (-2 (|:| -4355 *2) (|:| -3438 *3))))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1191 *3)) (-4 *3 (-975))))) 
-(((*1 *1 *1) (-12 (-4 *2 (-150)) (-4 *2 (-301)) (-4 *2 (-453)) (-4 *3 (-842)) (-4 *4 (-788)) (-5 *1 (-988 *2 *3 *4 *5)) (-4 *5 (-950 *2 *4 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-53)) (-5 *2 (-310 (-568))) (-5 *1 (-1107)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-634 (-288 (-953 *4))))) (-5 *1 (-382 *4)) (-4 *4 (-13 (-840) (-365))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-288 (-409 (-953 (-568)))))) (-5 *2 (-634 (-634 (-288 (-953 *4))))) (-5 *1 (-382 *4)) (-4 *4 (-13 (-840) (-365))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 (-568)))) (-5 *2 (-634 (-288 (-953 *4)))) (-5 *1 (-382 *4)) (-4 *4 (-13 (-840) (-365))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-288 (-409 (-953 (-568))))) (-5 *2 (-634 (-288 (-953 *4)))) (-5 *1 (-382 *4)) (-4 *4 (-13 (-840) (-365))))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1161)) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-4 *4 (-13 (-29 *6) (-1181) (-959))) (-5 *2 (-2 (|:| |particular| *4) (|:| -3746 (-634 *4)))) (-5 *1 (-642 *6 *4 *3)) (-4 *3 (-646 *4)))) ((*1 *2 *3 *2 *4 *2 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-634 *2)) (-4 *2 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *1 (-642 *6 *2 *3)) (-4 *3 (-646 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-679 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| |particular| (-3 (-1244 *5) "failed")) (|:| -3746 (-634 (-1244 *5))))) (-5 *1 (-659 *5)) (-5 *4 (-1244 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-634 *5))) (-4 *5 (-365)) (-5 *2 (-2 (|:| |particular| (-3 (-1244 *5) "failed")) (|:| -3746 (-634 (-1244 *5))))) (-5 *1 (-659 *5)) (-5 *4 (-1244 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-679 *5)) (-4 *5 (-365)) (-5 *2 (-634 (-2 (|:| |particular| (-3 (-1244 *5) "failed")) (|:| -3746 (-634 (-1244 *5)))))) (-5 *1 (-659 *5)) (-5 *4 (-634 (-1244 *5))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-634 *5))) (-4 *5 (-365)) (-5 *2 (-634 (-2 (|:| |particular| (-3 (-1244 *5) "failed")) (|:| -3746 (-634 (-1244 *5)))))) (-5 *1 (-659 *5)) (-5 *4 (-634 (-1244 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-13 (-375 *5) (-10 -7 (-6 -4520)))) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4520)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -3746 (-634 *4)))) (-5 *1 (-660 *5 *6 *4 *3)) (-4 *3 (-677 *5 *6 *4)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-13 (-375 *5) (-10 -7 (-6 -4520)))) (-4 *7 (-13 (-375 *5) (-10 -7 (-6 -4520)))) (-5 *2 (-634 (-2 (|:| |particular| (-3 *7 "failed")) (|:| -3746 (-634 *7))))) (-5 *1 (-660 *5 *6 *7 *3)) (-5 *4 (-634 *7)) (-4 *3 (-677 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-634 (-1161))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *5)))))) (-5 *1 (-762 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *4)))))) (-5 *1 (-762 *4)))) ((*1 *2 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-1161)) (-4 *5 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *1 (-764 *5 *2)) (-4 *2 (-13 (-29 *5) (-1181) (-959))))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-679 *7)) (-5 *5 (-1161)) (-4 *7 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-2 (|:| |particular| (-1244 *7)) (|:| -3746 (-634 (-1244 *7))))) (-5 *1 (-797 *6 *7)) (-5 *4 (-1244 *7)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-679 *6)) (-5 *4 (-1161)) (-4 *6 (-13 (-29 *5) (-1181) (-959))) (-4 *5 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-1244 *6))) (-5 *1 (-797 *5 *6)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-634 (-288 *7))) (-5 *4 (-634 (-123))) (-5 *5 (-1161)) (-4 *7 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-2 (|:| |particular| (-1244 *7)) (|:| -3746 (-634 (-1244 *7))))) (-5 *1 (-797 *6 *7)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-634 *7)) (-5 *4 (-634 (-123))) (-5 *5 (-1161)) (-4 *7 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-2 (|:| |particular| (-1244 *7)) (|:| -3746 (-634 (-1244 *7))))) (-5 *1 (-797 *6 *7)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-288 *7)) (-5 *4 (-123)) (-5 *5 (-1161)) (-4 *7 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-3 (-2 (|:| |particular| *7) (|:| -3746 (-634 *7))) *7 "failed")) (-5 *1 (-797 *6 *7)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-123)) (-5 *5 (-1161)) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-3 (-2 (|:| |particular| *3) (|:| -3746 (-634 *3))) *3 "failed")) (-5 *1 (-797 *6 *3)) (-4 *3 (-13 (-29 *6) (-1181) (-959))))) ((*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *3 (-288 *2)) (-5 *4 (-123)) (-5 *5 (-634 *2)) (-4 *2 (-13 (-29 *6) (-1181) (-959))) (-5 *1 (-797 *6 *2)) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))))) ((*1 *2 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-288 *2)) (-5 *5 (-634 *2)) (-4 *2 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *1 (-797 *6 *2)))) ((*1 *2 *3) (-12 (-5 *3 (-803)) (-5 *2 (-1035)) (-5 *1 (-800)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-803)) (-5 *4 (-1059)) (-5 *2 (-1035)) (-5 *1 (-800)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1244 (-310 (-381)))) (-5 *4 (-381)) (-5 *5 (-634 *4)) (-5 *2 (-1035)) (-5 *1 (-800)))) ((*1 *2 *3 *4 *4 *5 *4) (-12 (-5 *3 (-1244 (-310 (-381)))) (-5 *4 (-381)) (-5 *5 (-634 *4)) (-5 *2 (-1035)) (-5 *1 (-800)))) ((*1 *2 *3 *4 *4 *5 *6 *4) (-12 (-5 *3 (-1244 (-310 *4))) (-5 *5 (-634 (-381))) (-5 *6 (-310 (-381))) (-5 *4 (-381)) (-5 *2 (-1035)) (-5 *1 (-800)))) ((*1 *2 *3 *4 *4 *5 *5 *4) (-12 (-5 *3 (-1244 (-310 (-381)))) (-5 *4 (-381)) (-5 *5 (-634 *4)) (-5 *2 (-1035)) (-5 *1 (-800)))) ((*1 *2 *3 *4 *4 *5 *6 *5 *4) (-12 (-5 *3 (-1244 (-310 *4))) (-5 *5 (-634 (-381))) (-5 *6 (-310 (-381))) (-5 *4 (-381)) (-5 *2 (-1035)) (-5 *1 (-800)))) ((*1 *2 *3 *4 *4 *5 *6 *5 *4 *4) (-12 (-5 *3 (-1244 (-310 *4))) (-5 *5 (-634 (-381))) (-5 *6 (-310 (-381))) (-5 *4 (-381)) (-5 *2 (-1035)) (-5 *1 (-800)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1 (-3 (-2 (|:| |particular| *6) (|:| -3746 (-634 *6))) "failed") *7 *6)) (-4 *6 (-365)) (-4 *7 (-646 *6)) (-5 *2 (-2 (|:| |particular| (-1244 *6)) (|:| -3746 (-679 *6)))) (-5 *1 (-808 *6 *7)) (-5 *3 (-679 *6)) (-5 *4 (-1244 *6)))) ((*1 *2 *3) (-12 (-5 *3 (-893)) (-5 *2 (-1035)) (-5 *1 (-892)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-893)) (-5 *4 (-1059)) (-5 *2 (-1035)) (-5 *1 (-892)))) ((*1 *2 *3 *3 *3 *3 *4 *4 *5 *6 *7 *8) (-12 (-5 *4 (-763)) (-5 *6 (-634 (-634 (-310 *3)))) (-5 *7 (-1143)) (-5 *8 (-215)) (-5 *5 (-634 (-310 (-381)))) (-5 *3 (-381)) (-5 *2 (-1035)) (-5 *1 (-892)))) ((*1 *2 *3 *3 *3 *3 *4 *4 *5 *6 *7) (-12 (-5 *4 (-763)) (-5 *6 (-634 (-634 (-310 *3)))) (-5 *7 (-1143)) (-5 *5 (-634 (-310 (-381)))) (-5 *3 (-381)) (-5 *2 (-1035)) (-5 *1 (-892)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-953 (-409 (-568)))) (-5 *2 (-634 (-381))) (-5 *1 (-1022)) (-5 *4 (-381)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-953 (-568))) (-5 *2 (-634 (-381))) (-5 *1 (-1022)) (-5 *4 (-381)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *4)) (-5 *1 (-1116 *3 *4)) (-4 *3 (-1219 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-288 (-310 *4)))) (-5 *1 (-1119 *4)) (-5 *3 (-310 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-288 (-310 *4)))) (-5 *1 (-1119 *4)) (-5 *3 (-288 (-310 *4))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-288 (-310 *5)))) (-5 *1 (-1119 *5)) (-5 *3 (-288 (-310 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-288 (-310 *5)))) (-5 *1 (-1119 *5)) (-5 *3 (-310 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-1161))) (-4 *5 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-634 (-288 (-310 *5))))) (-5 *1 (-1119 *5)) (-5 *3 (-634 (-288 (-310 *5)))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 *5)))) (-5 *4 (-634 (-1161))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *5)))))) (-5 *1 (-1166 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-1161))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *5)))))) (-5 *1 (-1166 *5)) (-5 *3 (-634 (-288 (-409 (-953 *5))))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 *4)))) (-4 *4 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *4)))))) (-5 *1 (-1166 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *4)))))) (-5 *1 (-1166 *4)) (-5 *3 (-634 (-288 (-409 (-953 *4))))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-558)) (-5 *2 (-634 (-288 (-409 (-953 *5))))) (-5 *1 (-1166 *5)) (-5 *3 (-409 (-953 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-558)) (-5 *2 (-634 (-288 (-409 (-953 *5))))) (-5 *1 (-1166 *5)) (-5 *3 (-288 (-409 (-953 *5)))))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 (-288 (-409 (-953 *4))))) (-5 *1 (-1166 *4)) (-5 *3 (-409 (-953 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 (-288 (-409 (-953 *4))))) (-5 *1 (-1166 *4)) (-5 *3 (-288 (-409 (-953 *4))))))) 
-(((*1 *2 *3 *3) (|partial| -12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (|partial| -12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7))))) 
+(((*1 *2 *2) (|partial| -12 (-5 *2 (-634 (-953 *3))) (-4 *3 (-453)) (-5 *1 (-362 *3 *4)) (-14 *4 (-634 (-1161))))) ((*1 *2 *2) (|partial| -12 (-5 *2 (-634 (-775 *3 (-852 *4)))) (-4 *3 (-453)) (-14 *4 (-634 (-1161))) (-5 *1 (-619 *3 *4))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-370)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1244 *4)) (-5 *1 (-532 *4)) (-4 *4 (-350)))) ((*1 *2 *1) (-12 (-4 *2 (-842)) (-5 *1 (-703 *2 *3 *4)) (-4 *3 (-1090)) (-14 *4 (-1 (-121) (-2 (|:| -4357 *2) (|:| -3483 *3)) (-2 (|:| -4357 *2) (|:| -3483 *3))))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-944 *3))))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-2 (|:| |num| (-1244 *4)) (|:| |den| *4)))))) 
+(((*1 *2) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-109))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-409 (-953 *4))) (-5 *1 (-924 *4 *5 *6 *3)) (-4 *3 (-950 *4 *6 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-679 *7)) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-679 (-409 (-953 *4)))) (-5 *1 (-924 *4 *5 *6 *7)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 (-409 (-953 *4)))) (-5 *1 (-924 *4 *5 *6 *7))))) 
 (((*1 *2 *3 *3 *4 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-748))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-215)) (-5 *1 (-299))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-1061 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1189 *4 *5 *6 *3)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
+(((*1 *1 *2 *3 *1) (-12 (-14 *4 (-634 (-1161))) (-4 *2 (-172)) (-4 *3 (-230 (-1699 *4) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4357 *5) (|:| -3483 *3)) (-2 (|:| -4357 *5) (|:| -3483 *3)))) (-5 *1 (-463 *4 *2 *5 *3 *6 *7)) (-4 *5 (-842)) (-4 *7 (-950 *2 *3 (-852 *4)))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436))))) 
+(((*1 *2 *3) (-12 (-4 *1 (-340 *4 *3 *5)) (-4 *4 (-1199)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 (-409 *3))) (-5 *2 (-121)))) ((*1 *2 *3) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121))))) 
 (((*1 *2 *3 *3 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-748))))) 
-(((*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1195)) (-5 *2 (-634 *1)) (-4 *1 (-1010 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-1149 *3 *4))) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-643 (-409 *2))) (-4 *2 (-1219 *4)) (-5 *1 (-805 *4 *2)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))))) ((*1 *2 *3) (-12 (-5 *3 (-644 *2 (-409 *2))) (-4 *2 (-1219 *4)) (-5 *1 (-805 *4 *2)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568)))))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *7 *7)) (-4 *7 (-1219 *6)) (-4 *6 (-13 (-27) (-432 *5))) (-4 *5 (-13 (-842) (-558) (-1037 (-568)))) (-4 *8 (-1219 (-409 *7))) (-5 *2 (-585 *3)) (-5 *1 (-553 *5 *6 *7 *8 *3)) (-4 *3 (-340 *6 *7 *8))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565))))) 
 (((*1 *2 *3 *3 *4 *3 *5 *3 *5 *4 *5 *5 *4 *4 *5 *3) (-12 (-5 *4 (-679 (-215))) (-5 *5 (-679 (-568))) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-748))))) 
-(((*1 *1 *1 *2 *2) (|partial| -12 (-5 *2 (-917)) (-5 *1 (-1091 *3 *4)) (-14 *3 *2) (-14 *4 *2)))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-230 *5 (-763))) (-5 *1 (-908 *4 *3 *2 *5)) (-4 *3 (-324 *4 *2)) (-14 *5 (-763))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39)))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-679 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-679 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1094)) (-5 *1 (-1165))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *1 (-340 *4 *5 *6)) (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-2 (|:| |num| (-679 *5)) (|:| |den| *5)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| -2908 (-679 (-409 (-953 *4)))) (|:| |vec| (-634 (-409 (-953 *4)))) (|:| -2371 (-763)) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568))))) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-2 (|:| |partsol| (-1244 (-409 (-953 *4)))) (|:| -2588 (-634 (-1244 (-409 (-953 *4))))))) (-5 *1 (-924 *4 *5 *6 *7)) (-4 *7 (-950 *4 *6 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-679 (-953 *4))) (-5 *1 (-1028 *4)) (-4 *4 (-1047))))) 
+(((*1 *2 *3 *4) (-12 (-4 *4 (-854)) (-5 *2 (-420 (-1157 *4))) (-5 *1 (-315 *4)) (-5 *3 (-1157 *4)))) ((*1 *2 *3 *4) (-12 (-4 *4 (-859)) (-5 *2 (-420 (-1157 *4))) (-5 *1 (-317 *4)) (-5 *3 (-1157 *4))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-568)) (-4 *4 (-350)) (-5 *1 (-532 *4))))) 
 (((*1 *2 *3 *4 *5 *6 *3 *3 *3 *3 *6 *3 *7 *8) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-121)) (-5 *6 (-215)) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-73 APROD)))) (-5 *8 (-3 (|:| |fn| (-390)) (|:| |fp| (-78 MSOLVE)))) (-5 *2 (-1035)) (-5 *1 (-748))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-777 *2)) (-4 *2 (-558)) (-4 *2 (-1047)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-970 *3 *2)) (-4 *2 (-1219 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) ((*1 *2 *3 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *1)))) (-4 *1 (-1066 *4 *5 *6 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1864 *7) (|:| -4477 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *5 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3)))) 
-(((*1 *1 *2 *1) (-12 (|has| *1 (-6 -4519)) (-4 *1 (-154 *2)) (-4 *2 (-1195)) (-4 *2 (-1090)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4519)) (-4 *1 (-154 *3)) (-4 *3 (-1195)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-665 *3)) (-4 *3 (-1195)))) ((*1 *1 *2 *1 *3) (-12 (-5 *2 (-1 (-121) *4)) (-5 *3 (-568)) (-4 *4 (-1090)) (-5 *1 (-727 *4)))) ((*1 *1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-727 *2)) (-4 *2 (-1090)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))) (-5 *1 (-1126 *3 *4))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1228 *3 *4 *5)) (-4 *3 (-13 (-365) (-842))) (-14 *4 (-1161)) (-14 *5 *3) (-5 *1 (-314 *3 *4 *5)))) ((*1 *2 *3) (-12 (-5 *2 (-1 (-381))) (-5 *1 (-1039)) (-5 *3 (-381))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 *3)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-235 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-977 *3 *4 *2 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *5 (-1061 *3 *4 *2))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436))))) 
+(((*1 *1 *2 *1) (-12 (|has| *1 (-6 -4521)) (-4 *1 (-154 *2)) (-4 *2 (-1195)) (-4 *2 (-1090)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4521)) (-4 *1 (-154 *3)) (-4 *3 (-1195)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-665 *3)) (-4 *3 (-1195)))) ((*1 *1 *2 *1 *3) (-12 (-5 *2 (-1 (-121) *4)) (-5 *3 (-568)) (-4 *4 (-1090)) (-5 *1 (-727 *4)))) ((*1 *1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-727 *2)) (-4 *2 (-1090)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))) (-5 *1 (-1126 *3 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-833)) (-5 *2 (-1035)) (-5 *1 (-832)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-310 (-381)))) (-5 *4 (-634 (-381))) (-5 *2 (-1035)) (-5 *1 (-832))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -2910 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
 (((*1 *2 *3 *4 *3 *4 *5 *3 *4 *3 *3 *3 *3) (-12 (-5 *4 (-679 (-215))) (-5 *5 (-679 (-568))) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-748))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *6)) (-5 *5 (-1 (-420 (-1157 *6)) (-1157 *6))) (-4 *6 (-365)) (-5 *2 (-634 (-2 (|:| |outval| *7) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 *7)))))) (-5 *1 (-535 *6 *7 *4)) (-4 *7 (-365)) (-4 *4 (-13 (-365) (-840)))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-310 (-568))) (-5 *1 (-483 *3)) (-4 *3 (-13 (-350) (-609 (-568))))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-5 *1 (-496 *2)) (-4 *2 (-1219 (-568)))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-900 *4)) (-4 *4 (-1090)) (-5 *2 (-634 (-763))) (-5 *1 (-899 *4))))) 
-(((*1 *2) (-12 (-14 *4 (-763)) (-4 *5 (-1195)) (-5 *2 (-139)) (-5 *1 (-229 *3 *4 *5)) (-4 *3 (-230 *4 *5)))) ((*1 *2) (-12 (-4 *4 (-365)) (-5 *2 (-139)) (-5 *1 (-326 *3 *4)) (-4 *3 (-327 *4)))) ((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-392 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-172)))) ((*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-568)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-842)) (-4 *4 (-365)) (-4 *5 (-788)) (-5 *2 (-568)) (-5 *1 (-514 *4 *5 *6 *7)) (-4 *7 (-950 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-981 *3)) (-4 *3 (-1047)) (-5 *2 (-917)))) ((*1 *2) (-12 (-4 *1 (-1251 *3)) (-4 *3 (-365)) (-5 *2 (-139))))) 
-(((*1 *2 *2 *3 *3 *4) (-12 (-5 *3 (-763)) (-4 *2 (-13 (-558) (-453))) (-5 *1 (-346 *2 *4)) (-4 *4 (-52 *2 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1866 *7) (|:| -1844 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *5 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3)))) 
+(((*1 *1 *2) (|partial| -12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-1255 *3 *4 *5 *6)))) ((*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-634 *8)) (-5 *3 (-1 (-121) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1255 *5 *6 *7 *8))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-438))))) 
+(((*1 *1) (-5 *1 (-798)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-121))))) 
+(((*1 *2) (-12 (-4 *4 (-365)) (-5 *2 (-917)) (-5 *1 (-326 *3 *4)) (-4 *3 (-327 *4)))) ((*1 *2) (-12 (-4 *4 (-365)) (-5 *2 (-828 (-917))) (-5 *1 (-326 *3 *4)) (-4 *3 (-327 *4)))) ((*1 *2) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-5 *2 (-917)))) ((*1 *2) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-828 (-917)))))) 
 (((*1 *2 *3 *3 *4 *4 *4 *4 *3 *3 *3 *3 *5 *3 *6) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-75 APROD)))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-748))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-852 *5))) (-14 *5 (-634 (-1161))) (-4 *6 (-453)) (-5 *2 (-2 (|:| |dpolys| (-634 (-242 *5 *6))) (|:| |coords| (-634 (-568))))) (-5 *1 (-476 *5 *6 *7)) (-5 *3 (-634 (-242 *5 *6))) (-4 *7 (-453))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-778 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-172))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1 *3)) (-5 *1 (-671 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *3 *2) (|partial| -12 (-5 *2 (-1244 *4)) (-5 *3 (-679 *4)) (-4 *4 (-365)) (-5 *1 (-659 *4)))) ((*1 *2 *3 *2) (|partial| -12 (-4 *4 (-365)) (-4 *5 (-13 (-375 *4) (-10 -7 (-6 -4520)))) (-4 *2 (-13 (-375 *4) (-10 -7 (-6 -4520)))) (-5 *1 (-660 *4 *5 *2 *3)) (-4 *3 (-677 *4 *5 *2)))) ((*1 *2 *3 *2 *4 *5) (|partial| -12 (-5 *4 (-634 *2)) (-5 *5 (-1 *2 *2)) (-4 *2 (-365)) (-5 *1 (-809 *2 *3)) (-4 *3 (-646 *2)))) ((*1 *2 *3) (-12 (-4 *2 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *1 (-1116 *3 *2)) (-4 *3 (-1219 *2))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-634 *5)) (-4 *1 (-920 *4 *5)) (-4 *4 (-365)) (-4 *5 (-641 *4)) (-5 *2 (-1249))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-158)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
+(((*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *4 (-869)) (-5 *5 (-917)) (-5 *6 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-1248)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *4 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-1248))))) 
+(((*1 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3)))) 
+(((*1 *2 *3) (-12 (-4 *4 (-453)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *3)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-1182 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-953 (-568))) (-5 *2 (-634 *1)) (-4 *1 (-1012)))) ((*1 *2 *3) (-12 (-5 *3 (-953 (-409 (-568)))) (-5 *2 (-634 *1)) (-4 *1 (-1012)))) ((*1 *2 *3) (-12 (-5 *3 (-953 *1)) (-4 *1 (-1012)) (-5 *2 (-634 *1)))) ((*1 *2 *3) (-12 (-5 *3 (-1157 (-568))) (-5 *2 (-634 *1)) (-4 *1 (-1012)))) ((*1 *2 *3) (-12 (-5 *3 (-1157 (-409 (-568)))) (-5 *2 (-634 *1)) (-4 *1 (-1012)))) ((*1 *2 *3) (-12 (-5 *3 (-1157 *1)) (-4 *1 (-1012)) (-5 *2 (-634 *1)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-840) (-365))) (-4 *3 (-1219 *4)) (-5 *2 (-634 *1)) (-4 *1 (-1063 *4 *3))))) 
-(((*1 *2 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-333 *3 *4 *5 *6)) (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 *3 *4 *5)) (-5 *2 (-415 *4 (-409 *4) *5 *6)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 *6)) (-4 *6 (-13 (-411 *4 *5) (-1037 *4))) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-4 *3 (-301)) (-5 *1 (-415 *3 *4 *5 *6)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-55 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-634 (-1161))))) ((*1 *1 *1) (-12 (-5 *1 (-213 *2 *3)) (-4 *2 (-13 (-1047) (-842))) (-14 *3 (-634 (-1161)))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *5 (-558)) (-5 *2 (-2 (|:| |minor| (-634 (-917))) (|:| -2410 *3) (|:| |minors| (-634 (-634 (-917)))) (|:| |ops| (-634 *3)))) (-5 *1 (-95 *5 *3)) (-5 *4 (-917)) (-4 *3 (-646 *5))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-634 (-763)))) (-5 *1 (-899 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *5 *7)) (-5 *4 (-1157 *7)) (-4 *5 (-1047)) (-4 *7 (-1047)) (-4 *2 (-1219 *5)) (-5 *1 (-510 *5 *2 *6 *7)) (-4 *6 (-1219 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-1047)) (-4 *7 (-1047)) (-4 *4 (-1219 *5)) (-5 *2 (-1157 *7)) (-5 *1 (-510 *5 *4 *6 *7)) (-4 *6 (-1219 *4))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-950 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453)))) ((*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *1)))) (-4 *1 (-1066 *4 *5 *6 *3)))) ((*1 *1 *1) (-4 *1 (-1199))) ((*1 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-1222 *3 *2)) (-4 *2 (-13 (-1219 *3) (-558) (-10 -8 (-15 -2721 ($ $ $)))))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-763)) (-5 *1 (-586 *2)) (-4 *2 (-550))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-365)) (-5 *1 (-891 *2 *4)) (-4 *2 (-1219 *4))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-123)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-123)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-246 *4 *3 *5 *6)) (-4 *4 (-1047)) (-4 *3 (-842)) (-4 *5 (-262 *3)) (-4 *6 (-788)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-262 *3)) (-4 *3 (-842)) (-5 *2 (-763))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-2 (|:| -1638 (-568)) (|:| -2075 (-634 *3)))) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *1) (-5 *1 (-1245)))) 
+(((*1 *1 *1) (-12 (-5 *1 (-1126 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-1002)) (-4 *2 (-1047))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-225)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-1 *1 (-763))) (-4 *1 (-246 *3 *4 *5 *6)))) ((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *3 (-842)) (-4 *5 (-262 *3)) (-4 *6 (-788)) (-5 *2 (-1 *1 (-763))) (-4 *1 (-246 *4 *3 *5 *6)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-262 *2)) (-4 *2 (-842))))) 
-(((*1 *1 *1) (-5 *1 (-215))) ((*1 *1 *1) (-5 *1 (-381))) ((*1 *1) (-5 *1 (-381)))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-917)) (-5 *2 (-1244 (-634 (-2 (|:| -2850 *4) (|:| -4355 (-1108)))))) (-5 *1 (-347 *4)) (-4 *4 (-350))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-634 (-2 (|:| |k| *4) (|:| |c| *3)))))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |k| (-888 *3)) (|:| |c| *4)))) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-663 *3))) (-5 *1 (-888 *3)) (-4 *3 (-842))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 *9)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-763)) (-5 *1 (-1064 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 *9)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1099 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-763)) (-5 *1 (-1130 *5 *6 *7 *8 *9))))) 
+(((*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-844 *3)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-558)) (-4 *5 (-1047)) (-5 *2 (-2 (|:| -4409 *3) (|:| -2607 *3))) (-5 *1 (-845 *5 *3)) (-4 *3 (-844 *5))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-824)) (-5 *3 (-1143))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-4 *1 (-37 *3))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-453)) (-5 *2 (-634 (-2 (|:| |eigval| (-3 (-409 (-953 *4)) (-1150 (-1161) (-953 *4)))) (|:| |geneigvec| (-634 (-679 (-409 (-953 *4)))))))) (-5 *1 (-286 *4)) (-5 *3 (-679 (-409 (-953 *4))))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2852 *4) (|:| -2185 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-917)) (-5 *2 (-121)) (-5 *1 (-233 *4)) (-4 *4 (-1047))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) (-5 *2 (-634 (-215))) (-5 *1 (-299))))) 
+(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-259 *3)) (-4 *3 (-1090)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-259 *3)) (-4 *3 (-1090)))) ((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-513 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-513 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-537 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-537 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-5 *2 (-121)) (-5 *1 (-538 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *7 (-971 *3)) (-4 *10 (-235 *9)) (-4 *11 (-117)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-5 *1 (-538 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *7 (-971 *3)) (-4 *10 (-235 *9)) (-4 *11 (-117)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-855 *3)) (-14 *3 (-860)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-857 *3)) (-4 *3 (-350)))) ((*1 *2 *1) (-12 (-4 *1 (-858)) (-5 *2 (-850)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-860))))) 
+(((*1 *1) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181)))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-121)) (-5 *1 (-180 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 (-169 *4)))))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-121)) (-5 *1 (-1185 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4)))))) 
+(((*1 *1) (-5 *1 (-818)))) 
 (((*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-169 (-215))) (-5 *5 (-568)) (-5 *6 (-1143)) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-121))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-4 *1 (-154 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3438 (-763)) (|:| -1374 *4) (|:| |num| *4)))) (-4 *4 (-1219 *3)) (-4 *3 (-13 (-365) (-150))) (-5 *1 (-401 *3 *4)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-121)) (-5 *1 (-439)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-5 *3 (-634 (-1161))) (-5 *4 (-121)) (-5 *1 (-439)))) ((*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-598 *3)) (-4 *3 (-1195)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-625 *2)) (-4 *2 (-172)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-663 *3)) (-4 *3 (-842)) (-5 *1 (-656 *3 *4)) (-4 *4 (-172)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-663 *3)) (-4 *3 (-842)) (-5 *1 (-656 *3 *4)) (-4 *4 (-172)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-663 *3)) (-4 *3 (-842)) (-5 *1 (-656 *3 *4)) (-4 *4 (-172)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-634 (-634 *3)))) (-4 *3 (-1090)) (-5 *1 (-666 *3)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-703 *2 *3 *4)) (-4 *2 (-842)) (-4 *3 (-1090)) (-14 *4 (-1 (-121) (-2 (|:| -4355 *2) (|:| -3438 *3)) (-2 (|:| -4355 *2) (|:| -3438 *3)))))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 *4)))) (-4 *4 (-1090)) (-5 *1 (-884 *3 *4)) (-4 *3 (-1090)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 *5)) (-4 *5 (-13 (-1090) (-39))) (-5 *2 (-634 (-1125 *3 *5))) (-5 *1 (-1125 *3 *5)) (-4 *3 (-13 (-1090) (-39))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| |val| *4) (|:| -3001 *5)))) (-4 *4 (-13 (-1090) (-39))) (-4 *5 (-13 (-1090) (-39))) (-5 *2 (-634 (-1125 *4 *5))) (-5 *1 (-1125 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |val| *3) (|:| -3001 *4))) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))) (-5 *1 (-1125 *3 *4)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) ((*1 *1 *2 *3 *4) (-12 (-5 *4 (-121)) (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) ((*1 *1 *2 *3 *2 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-13 (-1090) (-39))) (-5 *1 (-1126 *2 *3)) (-4 *2 (-13 (-1090) (-39))))) ((*1 *1 *2 *3 *4) (-12 (-5 *4 (-634 (-1125 *2 *3))) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))) (-5 *1 (-1126 *2 *3)))) ((*1 *1 *2 *3 *4) (-12 (-5 *4 (-634 (-1126 *2 *3))) (-5 *1 (-1126 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) ((*1 *1 *2) (-12 (-5 *2 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))) (-5 *1 (-1126 *3 *4)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-1150 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090))))) 
-(((*1 *2 *3 *1) (-12 (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121))))) 
-(((*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-763)) (-5 *1 (-734 *4 *3)) (-14 *4 (-1161)) (-4 *3 (-1047)))) ((*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-763)) (-5 *1 (-777 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2 *3 *1) (-12 (-5 *1 (-964 *3 *2)) (-4 *2 (-137)) (-4 *3 (-558)) (-4 *3 (-1047)) (-4 *2 (-787)))) ((*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1157 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-972)) (-4 *2 (-137)) (-5 *1 (-1163 *3)) (-4 *3 (-558)) (-4 *3 (-1047)))) ((*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1216 *4 *3)) (-14 *4 (-1161)) (-4 *3 (-1047))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3))) ((*1 *1 *2 *3 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3))) ((*1 *1 *1 *1) (-12 (-5 *1 (-666 *2)) (-4 *2 (-1047)) (-4 *2 (-1090))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-4 *1 (-154 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3483 (-763)) (|:| -1374 *4) (|:| |num| *4)))) (-4 *4 (-1219 *3)) (-4 *3 (-13 (-365) (-150))) (-5 *1 (-401 *3 *4)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-121)) (-5 *1 (-439)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-5 *3 (-634 (-1161))) (-5 *4 (-121)) (-5 *1 (-439)))) ((*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-598 *3)) (-4 *3 (-1195)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-625 *2)) (-4 *2 (-172)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-663 *3)) (-4 *3 (-842)) (-5 *1 (-656 *3 *4)) (-4 *4 (-172)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-663 *3)) (-4 *3 (-842)) (-5 *1 (-656 *3 *4)) (-4 *4 (-172)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-663 *3)) (-4 *3 (-842)) (-5 *1 (-656 *3 *4)) (-4 *4 (-172)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-634 (-634 *3)))) (-4 *3 (-1090)) (-5 *1 (-666 *3)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-703 *2 *3 *4)) (-4 *2 (-842)) (-4 *3 (-1090)) (-14 *4 (-1 (-121) (-2 (|:| -4357 *2) (|:| -3483 *3)) (-2 (|:| -4357 *2) (|:| -3483 *3)))))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 *4)))) (-4 *4 (-1090)) (-5 *1 (-884 *3 *4)) (-4 *3 (-1090)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 *5)) (-4 *5 (-13 (-1090) (-39))) (-5 *2 (-634 (-1125 *3 *5))) (-5 *1 (-1125 *3 *5)) (-4 *3 (-13 (-1090) (-39))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| |val| *4) (|:| -3145 *5)))) (-4 *4 (-13 (-1090) (-39))) (-4 *5 (-13 (-1090) (-39))) (-5 *2 (-634 (-1125 *4 *5))) (-5 *1 (-1125 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |val| *3) (|:| -3145 *4))) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))) (-5 *1 (-1125 *3 *4)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) ((*1 *1 *2 *3 *4) (-12 (-5 *4 (-121)) (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) ((*1 *1 *2 *3 *2 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-13 (-1090) (-39))) (-5 *1 (-1126 *2 *3)) (-4 *2 (-13 (-1090) (-39))))) ((*1 *1 *2 *3 *4) (-12 (-5 *4 (-634 (-1125 *2 *3))) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))) (-5 *1 (-1126 *2 *3)))) ((*1 *1 *2 *3 *4) (-12 (-5 *4 (-634 (-1126 *2 *3))) (-5 *1 (-1126 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) ((*1 *1 *2) (-12 (-5 *2 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))) (-5 *1 (-1126 *3 *4)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-1150 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-33 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) ((*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565))))) 
 (((*1 *1 *1) (-5 *1 (-541)))) 
-(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1164)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *3 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *4 *5 *6 *7 *3 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *9)) (-5 *1 (-467 *4 *5 *6 *7 *3 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2 *3) (-12 (-5 *3 (-967 *4)) (-4 *4 (-350)) (-5 *2 (-634 (-922 *4))) (-5 *1 (-867 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-966 *4)) (-4 *4 (-365)) (-5 *2 (-634 (-921 *4))) (-5 *1 (-868 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117))))) 
 (((*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-169 (-215))) (-5 *5 (-568)) (-5 *6 (-1143)) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1244 (-310 (-215)))) (-5 *2 (-2 (|:| |additions| (-568)) (|:| |multiplications| (-568)) (|:| |exponentiations| (-568)) (|:| |functionCalls| (-568)))) (-5 *1 (-299))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *3 (-1 (-634 *2) *2 *2 *2)) (-4 *2 (-1090)) (-5 *1 (-106 *2)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1090)) (-5 *1 (-106 *2))))) 
-(((*1 *2 *1) (-12 (-4 *2 (-13 (-840) (-365))) (-5 *1 (-1057 *2 *3)) (-4 *3 (-1219 *2))))) 
-(((*1 *2 *3) (-12 (-4 *5 (-13 (-609 *2) (-172))) (-5 *2 (-887 *4)) (-5 *1 (-170 *4 *5 *3)) (-4 *4 (-1090)) (-4 *3 (-166 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-1084 (-835 (-381))))) (-5 *2 (-634 (-1084 (-835 (-215))))) (-5 *1 (-299)))) ((*1 *1 *2) (-12 (-5 *2 (-215)) (-5 *1 (-381)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-850)) (-5 *3 (-568)) (-5 *1 (-396)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-172)) (-4 *1 (-411 *3 *4)) (-4 *4 (-1219 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-411 *3 *4)) (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-1244 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-172)) (-4 *1 (-419 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-1244 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-420 *1)) (-4 *1 (-432 *3)) (-4 *3 (-558)) (-4 *3 (-842)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-468 *3 *4 *5 *6)))) ((*1 *1 *2) (-12 (-5 *2 (-1094)) (-5 *1 (-541)))) ((*1 *2 *1) (-12 (-4 *1 (-609 *2)) (-4 *2 (-1195)))) ((*1 *1 *2) (-12 (-4 *3 (-172)) (-4 *1 (-714 *3 *2)) (-4 *2 (-1219 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1047)) (-4 *1 (-981 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1058)))) ((*1 *1 *2) (-12 (-5 *2 (-953 *3)) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *5 (-609 (-1161))) (-4 *4 (-788)) (-4 *5 (-842)))) ((*1 *1 *2) (-2198 (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-3044 (-4 *3 (-43 (-409 (-568))))) (-4 *3 (-43 (-568))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))))) ((*1 *1 *2) (-12 (-5 *2 (-953 (-409 (-568)))) (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)))) ((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |val| (-634 *7)) (|:| -3001 *8))) (-4 *7 (-1061 *4 *5 *6)) (-4 *8 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1143)) (-5 *1 (-1064 *4 *5 *6 *7 *8)))) ((*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-1075)))) ((*1 *1 *2) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195)))) ((*1 *1 *2) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *2)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-1090)))) ((*1 *1 *2) (-12 (-4 *1 (-1093 *3 *4 *5 *2 *6)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *2 (-1090)) (-4 *6 (-1090)))) ((*1 *1 *2) (-12 (-4 *1 (-1093 *3 *4 *2 *5 *6)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *2 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)))) ((*1 *1 *2) (-12 (-4 *1 (-1093 *3 *2 *4 *5 *6)) (-4 *3 (-1090)) (-4 *2 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)))) ((*1 *1 *2) (-12 (-4 *1 (-1093 *2 *3 *4 *5 *6)) (-4 *2 (-1090)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)))) ((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |val| (-634 *7)) (|:| -3001 *8))) (-4 *7 (-1061 *4 *5 *6)) (-4 *8 (-1099 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1143)) (-5 *1 (-1130 *4 *5 *6 *7 *8)))) ((*1 *1 *2 *3 *2) (-12 (-5 *2 (-850)) (-5 *3 (-568)) (-5 *1 (-1176)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-850)) (-5 *3 (-568)) (-5 *1 (-1176)))) ((*1 *2 *3) (-12 (-5 *3 (-775 *4 (-852 *5))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *5 (-634 (-1161))) (-5 *2 (-775 *4 (-852 *6))) (-5 *1 (-1268 *4 *5 *6)) (-14 *6 (-634 (-1161))))) ((*1 *2 *3) (-12 (-5 *3 (-953 *4)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-953 (-1023 (-409 *4)))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161))))) ((*1 *2 *3) (-12 (-5 *3 (-775 *4 (-852 *6))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *6 (-634 (-1161))) (-5 *2 (-953 (-1023 (-409 *4)))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))))) ((*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-1157 (-1023 (-409 *4)))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161))))) ((*1 *2 *3) (-12 (-5 *3 (-1131 *4 (-534 (-852 *6)) (-852 *6) (-775 *4 (-852 *6)))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-775 *4 (-852 *6)))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161)))))) 
-(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *2 (-950 *3 *5 (-852 *4))) (-4 *5 (-230 (-1697 *4) (-763))) (-4 *6 (-971 *3)) (-4 *7 (-641 *3)) (-4 *8 (-920 *3 *7)) (-4 *9 (-235 *8)) (-4 *10 (-536 *3 *4 *2 *5 *6 *7 *8 *9 *12)) (-4 *12 (-117)) (-5 *1 (-467 *3 *4 *2 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) ((*1 *2 *2) (-12 (-5 *2 (-242 *4 *3)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-5 *1 (-867 *3 *4 *5)) (-4 *5 (-117)))) ((*1 *2 *2) (-12 (-5 *2 (-242 *4 *3)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-5 *1 (-868 *3 *4 *5)) (-4 *5 (-117))))) 
-(((*1 *2 *2 *1 *3 *4) (-12 (-5 *2 (-634 *8)) (-5 *3 (-1 *8 *8 *8)) (-5 *4 (-1 (-121) *8 *8)) (-4 *1 (-1189 *5 *6 *7 *8)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7))))) 
+(((*1 *2 *2 *3 *4) (-12 (-5 *3 (-123)) (-5 *4 (-1161)) (-4 *5 (-13 (-842) (-558) (-609 (-541)))) (-4 *2 (-432 *5)) (-5 *1 (-312 *5 *2 *6 *7)) (-4 *6 (-1234 *2)) (-4 *7 (-1234 (-1155 *2)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-558)) (-5 *2 (-1157 *4)) (-5 *1 (-759 *4))))) 
+(((*1 *2 *3) (-12 (-4 *5 (-13 (-609 *2) (-172))) (-5 *2 (-887 *4)) (-5 *1 (-170 *4 *5 *3)) (-4 *4 (-1090)) (-4 *3 (-166 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-1084 (-835 (-381))))) (-5 *2 (-634 (-1084 (-835 (-215))))) (-5 *1 (-299)))) ((*1 *1 *2) (-12 (-5 *2 (-215)) (-5 *1 (-381)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-850)) (-5 *3 (-568)) (-5 *1 (-396)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-172)) (-4 *1 (-411 *3 *4)) (-4 *4 (-1219 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-411 *3 *4)) (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-1244 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-172)) (-4 *1 (-419 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-1244 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-420 *1)) (-4 *1 (-432 *3)) (-4 *3 (-558)) (-4 *3 (-842)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-468 *3 *4 *5 *6)))) ((*1 *1 *2) (-12 (-5 *2 (-1094)) (-5 *1 (-541)))) ((*1 *2 *1) (-12 (-4 *1 (-609 *2)) (-4 *2 (-1195)))) ((*1 *1 *2) (-12 (-4 *3 (-172)) (-4 *1 (-714 *3 *2)) (-4 *2 (-1219 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1047)) (-4 *1 (-981 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1058)))) ((*1 *1 *2) (-12 (-5 *2 (-953 *3)) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *5 (-609 (-1161))) (-4 *4 (-788)) (-4 *5 (-842)))) ((*1 *1 *2) (-2199 (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-3046 (-4 *3 (-43 (-409 (-568))))) (-4 *3 (-43 (-568))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))))) ((*1 *1 *2) (-12 (-5 *2 (-953 (-409 (-568)))) (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)))) ((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |val| (-634 *7)) (|:| -3145 *8))) (-4 *7 (-1061 *4 *5 *6)) (-4 *8 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1143)) (-5 *1 (-1064 *4 *5 *6 *7 *8)))) ((*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-1075)))) ((*1 *1 *2) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195)))) ((*1 *1 *2) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *2)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-1090)))) ((*1 *1 *2) (-12 (-4 *1 (-1093 *3 *4 *5 *2 *6)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *2 (-1090)) (-4 *6 (-1090)))) ((*1 *1 *2) (-12 (-4 *1 (-1093 *3 *4 *2 *5 *6)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *2 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)))) ((*1 *1 *2) (-12 (-4 *1 (-1093 *3 *2 *4 *5 *6)) (-4 *3 (-1090)) (-4 *2 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)))) ((*1 *1 *2) (-12 (-4 *1 (-1093 *2 *3 *4 *5 *6)) (-4 *2 (-1090)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)))) ((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |val| (-634 *7)) (|:| -3145 *8))) (-4 *7 (-1061 *4 *5 *6)) (-4 *8 (-1099 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1143)) (-5 *1 (-1130 *4 *5 *6 *7 *8)))) ((*1 *1 *2 *3 *2) (-12 (-5 *2 (-850)) (-5 *3 (-568)) (-5 *1 (-1176)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-850)) (-5 *3 (-568)) (-5 *1 (-1176)))) ((*1 *2 *3) (-12 (-5 *3 (-775 *4 (-852 *5))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *5 (-634 (-1161))) (-5 *2 (-775 *4 (-852 *6))) (-5 *1 (-1268 *4 *5 *6)) (-14 *6 (-634 (-1161))))) ((*1 *2 *3) (-12 (-5 *3 (-953 *4)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-953 (-1023 (-409 *4)))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161))))) ((*1 *2 *3) (-12 (-5 *3 (-775 *4 (-852 *6))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *6 (-634 (-1161))) (-5 *2 (-953 (-1023 (-409 *4)))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))))) ((*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-1157 (-1023 (-409 *4)))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161))))) ((*1 *2 *3) (-12 (-5 *3 (-1131 *4 (-534 (-852 *6)) (-852 *6) (-775 *4 (-852 *6)))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-775 *4 (-852 *6)))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161)))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-365)) (-5 *2 (-634 *3)) (-5 *1 (-946 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
 (((*1 *2 *3 *3 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) (-5 *2 (-1035)) (-5 *1 (-740))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-641 *3)) (-4 *3 (-365))))) 
-(((*1 *2 *3) (-12 (|has| *6 (-6 -4520)) (-4 *4 (-365)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-634 *6)) (-5 *1 (-529 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) ((*1 *2 *3) (-12 (|has| *9 (-6 -4520)) (-4 *4 (-558)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-4 *7 (-993 *4)) (-4 *8 (-375 *7)) (-4 *9 (-375 *7)) (-5 *2 (-634 *6)) (-5 *1 (-530 *4 *5 *6 *3 *7 *8 *9 *10)) (-4 *3 (-677 *4 *5 *6)) (-4 *10 (-677 *7 *8 *9)))) ((*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-4 *3 (-558)) (-5 *2 (-634 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *4 (-172)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-634 *6)) (-5 *1 (-678 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-4 *5 (-558)) (-5 *2 (-634 *7))))) 
-(((*1 *2 *2 *3 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-1108)) (-4 *4 (-350)) (-5 *1 (-532 *4))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-301)) (-5 *2 (-409 (-420 (-953 *4)))) (-5 *1 (-1041 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| |answer| *3) (|:| |polypart| *3))) (-5 *1 (-578 *5 *3))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-250))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-121)) (-5 *1 (-294))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *4 *5 *6)) (-4 *4 (-365)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-451 *4 *5 *6 *2)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-101 *6)) (-5 *5 (-1 *6 *6)) (-4 *6 (-365)) (-5 *2 (-2 (|:| R (-679 *6)) (|:| A (-679 *6)) (|:| |Ainv| (-679 *6)))) (-5 *1 (-979 *6)) (-5 *3 (-679 *6))))) 
+(((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-688)))) ((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-688))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-4 *7 (-950 *4 *6 *5)) (-5 *2 (-2 (|:| |sysok| (-121)) (|:| |z0| (-634 *7)) (|:| |n0| (-634 *7)))) (-5 *1 (-924 *4 *5 *6 *7)) (-5 *3 (-634 *7))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-409 (-568))) (-5 *1 (-435 *4 *3)) (-4 *3 (-432 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-607 *3)) (-4 *3 (-432 *5)) (-4 *5 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-1157 (-409 (-568)))) (-5 *1 (-435 *5 *3))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-840)) (-5 *1 (-297 *3))))) 
-(((*1 *1 *1 *1 *2) (-12 (-4 *1 (-950 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *3 (-172)))) ((*1 *2 *3 *3) (-12 (-4 *2 (-558)) (-5 *1 (-970 *2 *3)) (-4 *3 (-1219 *2)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-172))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-57))) (-5 *2 (-1249)) (-5 *1 (-851))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-817)) (-5 *2 (-57)) (-5 *1 (-824))))) 
+(((*1 *1 *1) (-5 *1 (-1059)))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
+(((*1 *2 *3 *1) (-12 (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3145 *1)))) (-4 *1 (-1066 *4 *5 *6 *3))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-777 *2)) (-4 *2 (-1047))))) 
 (((*1 *2 *3 *3 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) (-5 *2 (-1035)) (-5 *1 (-740))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3))))) 
-(((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-1157 (-953 *4)) (-953 *4))) (-5 *1 (-1252 *4)) (-4 *4 (-365))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-763)) (-5 *1 (-450 *4 *5 *6 *3)) (-4 *3 (-950 *4 *5 *6))))) 
-(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245))))) 
+(((*1 *2) (-12 (-4 *3 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-1249)) (-5 *1 (-435 *3 *4)) (-4 *4 (-432 *3))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-568))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-173 *3)) (-4 *3 (-301))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-372 *4 *5)) (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-679 *4)))) ((*1 *2) (-12 (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-679 *4)) (-5 *1 (-410 *3 *4 *5)) (-4 *3 (-411 *4 *5)))) ((*1 *2) (-12 (-4 *1 (-411 *3 *4)) (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-679 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *1 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-420 *2)) (-4 *2 (-558))))) 
+(((*1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1247)))) ((*1 *2 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1247))))) 
+(((*1 *1 *1 *1) (-5 *1 (-850)))) 
 (((*1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *2 *2) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195)))) ((*1 *1 *2) (-12 (-5 *1 (-1210 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-568)) (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *8 (-230 (-1697 *7) (-763))) (-4 *9 (-641 *6)) (-5 *2 (-634 *9)) (-5 *1 (-654 *6 *7 *4 *8 *3 *9 *10)) (-4 *4 (-950 *6 *8 (-852 *7))) (-4 *3 (-971 *6)) (-4 *10 (-920 *6 *9))))) 
-(((*1 *2 *3 *4 *3 *3) (-12 (-5 *3 (-288 *6)) (-5 *4 (-123)) (-4 *6 (-432 *5)) (-4 *5 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *5 *6)))) ((*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-288 *7)) (-5 *4 (-123)) (-5 *5 (-634 *7)) (-4 *7 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *7)))) ((*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-634 (-288 *7))) (-5 *4 (-634 (-123))) (-5 *5 (-288 *7)) (-4 *7 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *7)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-634 (-288 *8))) (-5 *4 (-634 (-123))) (-5 *5 (-288 *8)) (-5 *6 (-634 *8)) (-4 *8 (-432 *7)) (-4 *7 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *7 *8)))) ((*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-634 *7)) (-5 *4 (-634 (-123))) (-5 *5 (-288 *7)) (-4 *7 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *7)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 (-123))) (-5 *6 (-634 (-288 *8))) (-4 *8 (-432 *7)) (-5 *5 (-288 *8)) (-4 *7 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *7 *8)))) ((*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-288 *5)) (-5 *4 (-123)) (-4 *5 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *5)))) ((*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-123)) (-5 *5 (-288 *3)) (-4 *3 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *3)))) ((*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-123)) (-5 *5 (-288 *3)) (-4 *3 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *3)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-123)) (-5 *5 (-288 *3)) (-5 *6 (-634 *3)) (-4 *3 (-432 *7)) (-4 *7 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *7 *3)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-123)) (-5 *5 (-1161)) (-5 *6 (-634 *3)) (-4 *3 (-432 *7)) (-4 *7 (-13 (-842) (-558) (-609 (-541)))) (-4 *2 (-1234 *3)) (-5 *1 (-312 *7 *3 *2 *8)) (-4 *8 (-1234 (-1155 *3))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *6)) (-5 *4 (-634 *5)) (-4 *5 (-365)) (-4 *6 (-1234 (-1155 *5))) (-4 *2 (-1234 *5)) (-5 *1 (-1238 *5 *2 *6))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-207 *4 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-634 *3)) (-5 *1 (-344 *4 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-763))) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-763))) (-5 *5 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-1007 *3)) (-4 *3 (-1219 (-409 (-568)))))) ((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-1208 *3)) (-4 *3 (-1219 (-568)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-5 *1 (-563)))) ((*1 *2 *1) (-12 (-4 *1 (-605 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-5 *2 (-634 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-5 *1 (-798))))) 
 (((*1 *2 *3 *3 *4 *5 *3 *3 *4 *4 *4 *6) (-12 (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-740))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-953 (-568))) (-5 *2 (-328)) (-5 *1 (-330))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-536 *2 *3 *4 *5 *6 *7 *8 *9 *10)) (-4 *4 (-950 *2 *5 (-852 *3))) (-4 *5 (-230 (-1697 *3) (-763))) (-4 *6 (-971 *2)) (-4 *7 (-641 *2)) (-4 *8 (-920 *2 *7)) (-4 *9 (-235 *8)) (-4 *10 (-117)) (-4 *2 (-365))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-638 *3 *4 *5)) (-4 *3 (-1090)) (-4 *4 (-23)) (-14 *5 *4)))) 
-(((*1 *2 *3 *4 *5 *6 *2 *7 *8) (|partial| -12 (-5 *2 (-634 (-1157 *11))) (-5 *3 (-1157 *11)) (-5 *4 (-634 *10)) (-5 *5 (-634 *8)) (-5 *6 (-634 (-763))) (-5 *7 (-1244 (-634 (-1157 *8)))) (-4 *10 (-842)) (-4 *8 (-301)) (-4 *11 (-950 *8 *9 *10)) (-4 *9 (-788)) (-5 *1 (-697 *9 *10 *8 *11))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-2 (|:| |func| *3) (|:| |kers| (-634 (-607 *3))) (|:| |vals| (-634 *3)))) (-5 *1 (-273 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5)))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-1161))) (-5 *2 (-634 (-634 *5))) (-5 *1 (-382 *5)) (-4 *5 (-13 (-840) (-365))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 (-568)))) (-5 *2 (-634 *4)) (-5 *1 (-382 *4)) (-4 *4 (-13 (-840) (-365)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-366 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-5 *2 (-1143))))) 
+(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-926))))) 
+(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
 (((*1 *2 *3 *4 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) (-5 *2 (-1035)) (-5 *1 (-740))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-950 *4 *5 *6)) (-4 *6 (-609 (-1161))) (-4 *4 (-365)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1150 (-634 (-953 *4)) (-634 (-288 (-953 *4))))) (-5 *1 (-514 *4 *5 *6 *7))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-917)) (-4 *5 (-842)) (-5 *2 (-634 (-663 *5))) (-5 *1 (-663 *5))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-917)) (-5 *2 (-121)) (-5 *1 (-233 *4)) (-4 *4 (-1047))))) 
-(((*1 *1 *1 *2) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-57))) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3))))) 
+(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2852 *4) (|:| -2185 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568))))) 
+(((*1 *2 *2 *1) (-12 (-5 *2 (-1266 *3 *4)) (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *2) (|partial| -12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-814 *3)) (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047))))) 
+(((*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3))))) 
 (((*1 *2 *3 *3 *3 *4 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G)))) (-5 *2 (-1035)) (-5 *1 (-740))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-310 *3)) (-4 *3 (-13 (-1047) (-842))) (-5 *1 (-213 *3 *4)) (-14 *4 (-634 (-1161)))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2850 *4) (|:| -2183 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1177))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39)))))) 
-(((*1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1247)))) ((*1 *2 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1247))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-1161))) (-5 *2 (-634 (-634 *5))) (-5 *1 (-382 *5)) (-4 *5 (-13 (-840) (-365))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 (-568)))) (-5 *2 (-634 *4)) (-5 *1 (-382 *4)) (-4 *4 (-13 (-840) (-365)))))) 
-(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-123)) (-5 *1 (-122 *3)) (-4 *3 (-842)) (-4 *3 (-1090))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-887 *4)) (-4 *4 (-1090)) (-5 *2 (-634 *5)) (-5 *1 (-885 *4 *5)) (-4 *5 (-1195))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1108)) (-5 *1 (-328))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-634 (-634 (-944 *3)))))))) 
+(((*1 *2) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-1141 (-215))) (-5 *1 (-184)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-215))) (-5 *4 (-634 (-1161))) (-5 *5 (-1084 (-835 (-215)))) (-5 *2 (-1141 (-215))) (-5 *1 (-294)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1244 (-310 (-215)))) (-5 *4 (-634 (-1161))) (-5 *5 (-1084 (-835 (-215)))) (-5 *2 (-1141 (-215))) (-5 *1 (-294))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-634 (-634 (-215)))) (-5 *1 (-926))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 *5)))) (-5 *4 (-634 (-1161))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-953 *5)))) (-5 *1 (-1166 *5))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1189 *4 *5 *6 *3)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *4 (-950 *5 *7 (-852 *6))) (-4 *7 (-230 (-1699 *6) (-763))) (-4 *3 (-971 *5)) (-4 *8 (-641 *5)) (-4 *9 (-920 *5 *8)) (-4 *10 (-235 *9)) (-4 *12 (-117)) (-4 *2 (-258 *11)) (-5 *1 (-260 *5 *6 *4 *7 *3 *8 *9 *10 *11 *2 *12)) (-4 *11 (-536 *5 *6 *4 *7 *3 *8 *9 *10 *12))))) 
+(((*1 *2 *1) (-12 (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-880 *3 *4 *5)) (-4 *3 (-1090)) (-4 *5 (-658 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-884 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176))))) 
 (((*1 *2 *3 *3 *3 *3 *4 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G)))) (-5 *2 (-1035)) (-5 *1 (-740))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-215))))) 
-(((*1 *1 *2 *3) (-12 (-5 *1 (-429 *3 *2)) (-4 *3 (-13 (-172) (-43 (-409 (-568))))) (-4 *2 (-13 (-842) (-21)))))) 
-(((*1 *1 *1) (-5 *1 (-1059)))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-710)) (-5 *2 (-917)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-712)) (-5 *2 (-763))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
-(((*1 *1) (-4 *1 (-350))) ((*1 *2 *3) (-12 (-5 *3 (-634 *5)) (-4 *5 (-432 *4)) (-4 *4 (-13 (-558) (-842) (-150))) (-5 *2 (-2 (|:| |primelt| *5) (|:| |poly| (-634 (-1157 *5))) (|:| |prim| (-1157 *5)))) (-5 *1 (-434 *4 *5)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-558) (-842) (-150))) (-5 *2 (-2 (|:| |primelt| *3) (|:| |pol1| (-1157 *3)) (|:| |pol2| (-1157 *3)) (|:| |prim| (-1157 *3)))) (-5 *1 (-434 *4 *3)) (-4 *3 (-27)) (-4 *3 (-432 *4)))) ((*1 *2 *3 *4 *3 *4) (-12 (-5 *3 (-953 *5)) (-5 *4 (-1161)) (-4 *5 (-13 (-365) (-150))) (-5 *2 (-2 (|:| |coef1| (-568)) (|:| |coef2| (-568)) (|:| |prim| (-1157 *5)))) (-5 *1 (-960 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-634 (-1161))) (-4 *5 (-13 (-365) (-150))) (-5 *2 (-2 (|:| -2348 (-634 (-568))) (|:| |poly| (-634 (-1157 *5))) (|:| |prim| (-1157 *5)))) (-5 *1 (-960 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-953 *6))) (-5 *4 (-634 (-1161))) (-5 *5 (-1161)) (-4 *6 (-13 (-365) (-150))) (-5 *2 (-2 (|:| -2348 (-634 (-568))) (|:| |poly| (-634 (-1157 *6))) (|:| |prim| (-1157 *6)))) (-5 *1 (-960 *6))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 *5)))) (-5 *4 (-634 (-1161))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-953 *5)))) (-5 *1 (-1166 *5))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-57)) (-5 *1 (-887 *4)) (-4 *4 (-1090))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-301)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-2 (|:| |Smith| *3) (|:| |leftEqMat| *3) (|:| |rightEqMat| *3))) (-5 *1 (-1112 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-492 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-1047)) (-5 *2 (-242 *4 *5)) (-5 *1 (-945 *4 *5))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842))) (-4 *2 (-13 (-432 (-169 *4)) (-1002) (-1181))) (-5 *1 (-597 *4 *3 *2)) (-4 *3 (-13 (-432 *4) (-1002) (-1181)))))) 
-(((*1 *2 *2 *3 *3) (-12 (-5 *3 (-568)) (-4 *4 (-13 (-558) (-150))) (-5 *1 (-542 *4 *2)) (-4 *2 (-1234 *4)))) ((*1 *2 *2 *3 *3) (-12 (-5 *3 (-568)) (-4 *4 (-13 (-365) (-370) (-609 *3))) (-4 *5 (-1219 *4)) (-4 *6 (-714 *4 *5)) (-5 *1 (-546 *4 *5 *6 *2)) (-4 *2 (-1234 *6)))) ((*1 *2 *2 *3 *3) (-12 (-5 *3 (-568)) (-4 *4 (-13 (-365) (-370) (-609 *3))) (-5 *1 (-547 *4 *2)) (-4 *2 (-1234 *4)))) ((*1 *2 *2 *3 *3) (-12 (-5 *2 (-1141 *4)) (-5 *3 (-568)) (-4 *4 (-13 (-558) (-150))) (-5 *1 (-1137 *4))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-1121 (-215))) (-5 *3 (-634 (-256))) (-5 *1 (-1246)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1121 (-215))) (-5 *3 (-1143)) (-5 *1 (-1246)))) ((*1 *1 *1) (-5 *1 (-1246)))) 
+(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-215))))) 
+(((*1 *2 *2 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *2 (-1061 *4 *5 *6)) (-5 *1 (-768 *4 *5 *6 *2 *3)) (-4 *3 (-1066 *4 *5 *6 *2))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1143)) (-5 *1 (-781))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090))))) 
 (((*1 *2 *3 *3 *3 *3 *3 *4 *4 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G)))) (-5 *2 (-1035)) (-5 *1 (-740))))) 
-(((*1 *2 *3 *1) (-12 (-4 *4 (-365)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *4 *5 *6 *3)) (-4 *3 (-950 *4 *5 *6))))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-679 *4)))) ((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-679 *4)) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4)))) ((*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-679 *3))))) 
+(((*1 *1 *2 *3) (-12 (-5 *1 (-429 *3 *2)) (-4 *3 (-13 (-172) (-43 (-409 (-568))))) (-4 *2 (-13 (-842) (-21)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-840))) (-5 *1 (-178 *3 *2)) (-4 *2 (-1219 (-169 *3)))))) 
+(((*1 *2) (-12 (-5 *2 (-958 (-1108))) (-5 *1 (-341 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917)))) ((*1 *2) (-12 (-5 *2 (-958 (-1108))) (-5 *1 (-342 *3 *4)) (-4 *3 (-350)) (-14 *4 (-1157 *3)))) ((*1 *2) (-12 (-5 *2 (-958 (-1108))) (-5 *1 (-343 *3 *4)) (-4 *3 (-350)) (-14 *4 (-917))))) 
 (((*1 *1 *2) (-12 (-5 *2 (-634 (-169 (-215)))) (-5 *1 (-145)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-1244 *3))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-634 *14)) (-4 *14 (-258 *13)) (-4 *13 (-536 *5 *6 *7 *8 *9 *10 *11 *12 *15)) (-4 *15 (-117)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1697 *6) *3)) (-4 *9 (-971 *5)) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-4 *12 (-235 *11)) (-5 *3 (-763)) (-5 *2 (-568)) (-5 *1 (-260 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14 *15))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002)))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-235 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-944 (-215))) (-5 *4 (-869)) (-5 *2 (-1249)) (-5 *1 (-473)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1047)) (-4 *1 (-981 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-944 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-944 *3)) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) ((*1 *2 *3 *3 *3 *3) (-12 (-5 *2 (-944 (-215))) (-5 *1 (-1192)) (-5 *3 (-215))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568))))) 
+(((*1 *1 *1) (-5 *1 (-1059)))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-123)) (-4 *2 (-1090)) (-4 *2 (-842)) (-5 *1 (-122 *2))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-310 (-215)))) (-5 *4 (-763)) (-5 *2 (-679 (-215))) (-5 *1 (-263))))) 
 (((*1 *2 *3 *3 *3 *4 *4 *5 *5 *5 *3 *5 *5 *3 *6 *3 *3 *3) (-12 (-5 *5 (-679 (-215))) (-5 *6 (-679 (-568))) (-5 *3 (-568)) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-744))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *1 (-473))))) 
-(((*1 *2 *2 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *3 (-1219 *4)) (-5 *1 (-804 *4 *3 *2 *5)) (-4 *2 (-646 *3)) (-4 *5 (-646 (-409 *3))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-409 *5)) (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *1 (-804 *4 *5 *2 *6)) (-4 *2 (-646 *5)) (-4 *6 (-646 *3))))) 
-(((*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1143)) (-5 *1 (-299))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-4 *3 (-13 (-558) (-453))) (-5 *2 (-634 *3)) (-5 *1 (-346 *3 *5)) (-4 *5 (-52 *3 *4))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-710)) (-5 *2 (-917)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-712)) (-5 *2 (-763))))) 
+(((*1 *2) (|partial| -12 (-4 *4 (-1199)) (-4 *5 (-1219 (-409 *2))) (-4 *2 (-1219 *4)) (-5 *1 (-339 *3 *4 *2 *5)) (-4 *3 (-340 *4 *2 *5)))) ((*1 *2) (|partial| -12 (-4 *1 (-340 *3 *2 *4)) (-4 *3 (-1199)) (-4 *4 (-1219 (-409 *2))) (-4 *2 (-1219 *3))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-842) (-1037 (-568)) (-630 (-568)) (-453))) (-5 *2 (-835 *4)) (-5 *1 (-307 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1181) (-432 *3))) (-14 *5 (-1161)) (-14 *6 *4))) ((*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-842) (-1037 (-568)) (-630 (-568)) (-453))) (-5 *2 (-835 *4)) (-5 *1 (-1229 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1181) (-432 *3))) (-14 *5 (-1161)) (-14 *6 *4)))) 
+(((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-634 *7)) (|:| |badPols| (-634 *7)))) (-5 *1 (-978 *4 *5 *6 *7)) (-5 *3 (-634 *7))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-2 (|:| |zeros| (-1141 (-215))) (|:| |ones| (-1141 (-215))) (|:| |singularities| (-1141 (-215))))) (-5 *1 (-109))))) 
-(((*1 *1) (-5 *1 (-147))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-1121 (-215))) (-5 *1 (-256))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-99))))) 
+(((*1 *2 *3 *2) (-12 (-4 *2 (-13 (-365) (-840))) (-5 *1 (-178 *2 *3)) (-4 *3 (-1219 (-169 *2))))) ((*1 *2 *3) (-12 (-4 *2 (-13 (-365) (-840))) (-5 *1 (-178 *2 *3)) (-4 *3 (-1219 (-169 *2)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-817))))) 
 (((*1 *1 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-822 *2 *3)) (-4 *2 (-698 *3))))) 
-(((*1 *2 *2 *3) (-12 (-4 *3 (-365)) (-5 *1 (-280 *3 *2)) (-4 *2 (-1234 *3))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-995 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-4 *5 (-365)) (-5 *2 (-1141 (-1141 (-953 *5)))) (-5 *1 (-1252 *5)) (-5 *4 (-1141 (-953 *5)))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
 (((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1 *4 *4)) (-5 *3 (-763)) (-4 *1 (-223 *4)) (-4 *4 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-223 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-225)) (-5 *2 (-763)))) ((*1 *1 *1) (-4 *1 (-225))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-262 *3)) (-4 *3 (-842)))) ((*1 *1 *1) (-12 (-4 *1 (-262 *2)) (-4 *2 (-842)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *3 (-13 (-365) (-150))) (-5 *1 (-401 *3 *4)) (-4 *4 (-1219 *3)))) ((*1 *1 *1) (-12 (-4 *2 (-13 (-365) (-150))) (-5 *1 (-401 *2 *3)) (-4 *3 (-1219 *2)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-479 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *2 *1 *3) (-12 (-4 *2 (-365)) (-4 *2 (-895 *3)) (-5 *1 (-585 *2)) (-5 *3 (-1161)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1 *2 *2)) (-5 *1 (-585 *2)) (-4 *2 (-365)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-850)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *4)) (-5 *3 (-634 (-763))) (-4 *1 (-895 *4)) (-4 *4 (-1090)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-895 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *1 (-895 *3)) (-4 *3 (-1090)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-895 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1151 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1158 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1159 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 (QUOTE |x|))) (-5 *1 (-1201 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1207 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-1219 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1228 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-1047))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-634 (-953 *4))) (-5 *3 (-634 (-1161))) (-4 *4 (-453)) (-5 *1 (-914 *4))))) 
 (((*1 *2 *3 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-57))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-208))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) ((*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-141 *5 *6 *7)) (-14 *5 (-568)) (-14 *6 (-763)) (-4 *7 (-172)) (-4 *8 (-172)) (-5 *2 (-141 *5 *6 *8)) (-5 *1 (-140 *5 *6 *7 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *9)) (-4 *9 (-1047)) (-4 *5 (-842)) (-4 *6 (-788)) (-4 *8 (-1047)) (-4 *2 (-950 *9 *7 *5)) (-5 *1 (-718 *5 *6 *7 *8 *9 *4 *2)) (-4 *7 (-788)) (-4 *4 (-950 *8 *6 *5))))) 
+(((*1 *1) (-4 *1 (-350))) ((*1 *2 *3) (-12 (-5 *3 (-634 *5)) (-4 *5 (-432 *4)) (-4 *4 (-13 (-558) (-842) (-150))) (-5 *2 (-2 (|:| |primelt| *5) (|:| |poly| (-634 (-1157 *5))) (|:| |prim| (-1157 *5)))) (-5 *1 (-434 *4 *5)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-558) (-842) (-150))) (-5 *2 (-2 (|:| |primelt| *3) (|:| |pol1| (-1157 *3)) (|:| |pol2| (-1157 *3)) (|:| |prim| (-1157 *3)))) (-5 *1 (-434 *4 *3)) (-4 *3 (-27)) (-4 *3 (-432 *4)))) ((*1 *2 *3 *4 *3 *4) (-12 (-5 *3 (-953 *5)) (-5 *4 (-1161)) (-4 *5 (-13 (-365) (-150))) (-5 *2 (-2 (|:| |coef1| (-568)) (|:| |coef2| (-568)) (|:| |prim| (-1157 *5)))) (-5 *1 (-960 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-634 (-1161))) (-4 *5 (-13 (-365) (-150))) (-5 *2 (-2 (|:| -2350 (-634 (-568))) (|:| |poly| (-634 (-1157 *5))) (|:| |prim| (-1157 *5)))) (-5 *1 (-960 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-953 *6))) (-5 *4 (-634 (-1161))) (-5 *5 (-1161)) (-4 *6 (-13 (-365) (-150))) (-5 *2 (-2 (|:| -2350 (-634 (-568))) (|:| |poly| (-634 (-1157 *6))) (|:| |prim| (-1157 *6)))) (-5 *1 (-960 *6))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-1012)) (-5 *2 (-850))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-1245)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 *5 *5 *5)) (-4 *5 (-1234 *4)) (-4 *4 (-43 (-409 (-568)))) (-5 *2 (-1 (-1141 *4) (-1141 *4) (-1141 *4))) (-5 *1 (-1236 *4 *5))))) 
 (((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2) (-12 (-5 *2 (-679 (-905 *3))) (-5 *1 (-352 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917)))) ((*1 *2) (-12 (-5 *2 (-679 *3)) (-5 *1 (-353 *3 *4)) (-4 *3 (-350)) (-14 *4 (-3 (-1157 *3) (-1244 (-634 (-2 (|:| -2850 *3) (|:| -4355 (-1108))))))))) ((*1 *2) (-12 (-5 *2 (-679 *3)) (-5 *1 (-354 *3 *4)) (-4 *3 (-350)) (-14 *4 (-917))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-246 *2 *3 *4 *5)) (-4 *2 (-1047)) (-4 *3 (-842)) (-4 *4 (-262 *3)) (-4 *5 (-788))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-324 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-725 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-716))))) 
-(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3649 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381))))))) (-5 *1 (-798))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-141 *5 *6 *7)) (-14 *5 (-568)) (-14 *6 (-763)) (-4 *7 (-172)) (-4 *8 (-172)) (-5 *2 (-141 *5 *6 *8)) (-5 *1 (-140 *5 *6 *7 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *9)) (-4 *9 (-1047)) (-4 *5 (-842)) (-4 *6 (-788)) (-4 *8 (-1047)) (-4 *2 (-950 *9 *7 *5)) (-5 *1 (-718 *5 *6 *7 *8 *9 *4 *2)) (-4 *7 (-788)) (-4 *4 (-950 *8 *6 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-492 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-1047)) (-5 *2 (-242 *4 *5)) (-5 *1 (-945 *4 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-438))))) 
+(((*1 *1 *1) (-4 *1 (-1056))) ((*1 *1 *1 *2 *2) (-12 (-4 *1 (-1221 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1221 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787))))) 
+(((*1 *2 *3 *3 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-568)))) ((*1 *2 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-568)))) ((*1 *2 *3 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-568))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-840)) (-4 *4 (-365)) (-5 *2 (-763)) (-5 *1 (-946 *4 *5)) (-4 *5 (-1219 *4))))) 
 (((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-601 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1195)) (-5 *2 (-634 *3))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842))) (-5 *2 (-169 *5)) (-5 *1 (-597 *4 *5 *3)) (-4 *5 (-13 (-432 *4) (-1002) (-1181))) (-4 *3 (-13 (-432 (-169 *4)) (-1002) (-1181)))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-1047)) (-5 *1 (-702 *3 *4)) (-4 *4 (-1219 *3))))) 
-(((*1 *1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-324 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-4 *3 (-172))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842))) (-4 *2 (-13 (-432 (-169 *4)) (-1002) (-1181))) (-5 *1 (-597 *4 *3 *2)) (-4 *3 (-13 (-432 *4) (-1002) (-1181)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-121)) (-5 *1 (-924 *4 *5 *6 *7)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-121)) (-5 *1 (-924 *4 *5 *6 *7)) (-4 *7 (-950 *4 *6 *5))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) ((*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172))))) 
 (((*1 *2 *3 *3 *3 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-366 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-5 *2 (-1249))))) 
-(((*1 *2 *3 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-763)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-763)) (-5 *1 (-96 *4)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-763)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-763)) (-5 *1 (-212 *4)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-763)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-842)) (-5 *2 (-763)) (-5 *1 (-494 *4)))) ((*1 *2 *3 *1) (-12 (|has| *1 (-6 -4519)) (-4 *1 (-499 *3)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-763)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| *1 (-6 -4519)) (-4 *1 (-499 *4)) (-4 *4 (-1195)) (-5 *2 (-763)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-763)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-763)) (-5 *1 (-1000 *4)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-763)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-763)) (-5 *1 (-1132 *4))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-365)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-529 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-4 *7 (-993 *4)) (-4 *2 (-677 *7 *8 *9)) (-5 *1 (-530 *4 *5 *6 *3 *7 *8 *9 *2)) (-4 *3 (-677 *4 *5 *6)) (-4 *8 (-375 *7)) (-4 *9 (-375 *7)))) ((*1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (-4 *2 (-301)))) ((*1 *2 *2) (-12 (-4 *3 (-301)) (-4 *3 (-172)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-678 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-679 *3)) (-4 *3 (-301)) (-5 *1 (-689 *3)))) ((*1 *1 *1) (-12 (-4 *1 (-1050 *2 *3 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-230 *3 *4)) (-4 *6 (-230 *2 *4)) (-4 *4 (-301))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-1035)) (-5 *3 (-1161)) (-5 *1 (-263))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -4265 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-609 (-887 *3))) (-4 *3 (-881 *3)) (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-609 (-887 *3))) (-4 *2 (-881 *3)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-239 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1231 *3)) (-4 *3 (-1195)))) ((*1 *2 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002)))))) 
+(((*1 *2 *3 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-763)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-763)) (-5 *1 (-96 *4)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-763)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-763)) (-5 *1 (-212 *4)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-763)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-842)) (-5 *2 (-763)) (-5 *1 (-494 *4)))) ((*1 *2 *3 *1) (-12 (|has| *1 (-6 -4521)) (-4 *1 (-499 *3)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-763)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| *1 (-6 -4521)) (-4 *1 (-499 *4)) (-4 *4 (-1195)) (-5 *2 (-763)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-763)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-763)) (-5 *1 (-1000 *4)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-763)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-763)) (-5 *1 (-1132 *4))))) 
+(((*1 *2 *2 *3 *3) (-12 (-5 *3 (-568)) (-4 *4 (-13 (-558) (-150))) (-5 *1 (-542 *4 *2)) (-4 *2 (-1234 *4)))) ((*1 *2 *2 *3 *3) (-12 (-5 *3 (-568)) (-4 *4 (-13 (-365) (-370) (-609 *3))) (-4 *5 (-1219 *4)) (-4 *6 (-714 *4 *5)) (-5 *1 (-546 *4 *5 *6 *2)) (-4 *2 (-1234 *6)))) ((*1 *2 *2 *3 *3) (-12 (-5 *3 (-568)) (-4 *4 (-13 (-365) (-370) (-609 *3))) (-5 *1 (-547 *4 *2)) (-4 *2 (-1234 *4)))) ((*1 *2 *2 *3 *3) (-12 (-5 *2 (-1141 *4)) (-5 *3 (-568)) (-4 *4 (-13 (-558) (-150))) (-5 *1 (-1137 *4))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1219 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-1221 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-4 *1 (-1224 *3)) (-4 *3 (-1047))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-320 *2 *4)) (-4 *4 (-137)) (-4 *2 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-363 *2)) (-4 *2 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-388 *2)) (-4 *2 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-420 *2)) (-4 *2 (-558)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *2 (-1090)) (-5 *1 (-638 *2 *4 *5)) (-4 *4 (-23)) (-14 *5 *4))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-814 *2)) (-4 *2 (-842))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-272 *4 *3)) (-4 *3 (-13 (-432 *4) (-1002)))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-169 (-215))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1173 *4 *5)) (-4 *4 (-1090)) (-4 *5 (-1090))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-568)) (-4 *1 (-62 *4 *3 *5)) (-4 *4 (-1195)) (-4 *3 (-375 *4)) (-4 *5 (-375 *4))))) 
-(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1 *7 *7)) (-5 *5 (-634 (-409 *7))) (-4 *7 (-1219 *6)) (-5 *3 (-409 *7)) (-4 *6 (-365)) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-578 *6 *7))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-2 (|:| -1374 *5) (|:| -2783 *5)))) (-5 *1 (-802 *4 *5 *3 *6)) (-4 *3 (-646 *5)) (-4 *6 (-646 (-409 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *4 (-1219 *5)) (-5 *2 (-634 (-2 (|:| -1374 *4) (|:| -2783 *4)))) (-5 *1 (-802 *5 *4 *3 *6)) (-4 *3 (-646 *4)) (-4 *6 (-646 (-409 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-2 (|:| -1374 *5) (|:| -2783 *5)))) (-5 *1 (-802 *4 *5 *6 *3)) (-4 *6 (-646 *5)) (-4 *3 (-646 (-409 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *4 (-1219 *5)) (-5 *2 (-634 (-2 (|:| -1374 *4) (|:| -2783 *4)))) (-5 *1 (-802 *5 *4 *6 *3)) (-4 *6 (-646 *4)) (-4 *3 (-646 (-409 *4)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-1165))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-239 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1231 *3)) (-4 *3 (-1195)))) ((*1 *2 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *2 *3 *4 *4) (-12 (-5 *4 (-568)) (-4 *3 (-172)) (-4 *5 (-375 *3)) (-4 *6 (-375 *3)) (-5 *1 (-678 *3 *5 *6 *2)) (-4 *2 (-677 *3 *5 *6))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-1121 (-215))) (-5 *3 (-634 (-256))) (-5 *1 (-1246)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1121 (-215))) (-5 *3 (-1143)) (-5 *1 (-1246)))) ((*1 *1 *1) (-5 *1 (-1246)))) 
+(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-325 *3)) (-4 *3 (-1195)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-525 *3 *4)) (-4 *3 (-1195)) (-14 *4 (-568))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182))))) 
+(((*1 *1 *2 *3 *4) (-12 (-5 *3 (-568)) (-5 *4 (-3 "nil" "sqfr" "irred" "prime")) (-5 *1 (-420 *2)) (-4 *2 (-558))))) 
+(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-1109 *3)) (-4 *3 (-1195)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1132 *3)) (-4 *3 (-1090))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-21)) (-4 *2 (-1195))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-763)) (-4 *6 (-1090)) (-4 *3 (-895 *6)) (-5 *2 (-679 *3)) (-5 *1 (-681 *6 *3 *7 *4)) (-4 *7 (-375 *3)) (-4 *4 (-13 (-375 *6) (-10 -7 (-6 -4519))))))) 
+(((*1 *2 *3 *1) (-12 (-4 *4 (-365)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *4 *5 *6 *3)) (-4 *3 (-950 *4 *5 *6))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-857 *4))) (-4 *4 (-350)) (-5 *2 (-967 *4)) (-5 *1 (-867 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-5 *2 (-966 *4)) (-5 *1 (-868 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-4 *1 (-971 *3))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *2)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-1090))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-971 *3)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2 *2) (-12 (-5 *2 (-634 (-967 *3))) (-4 *3 (-350)) (-5 *1 (-867 *3 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2 *2) (-12 (-5 *2 (-634 (-966 *3))) (-4 *3 (-365)) (-5 *1 (-868 *3 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
+(((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-559 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4)))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-585 *2)) (-4 *2 (-365))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-365)) (-5 *1 (-758 *2 *3)) (-4 *2 (-698 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-1244 *6)) (-5 *1 (-334 *3 *4 *5 *6)) (-4 *6 (-340 *3 *4 *5))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-1161)) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-4 *4 (-13 (-29 *6) (-1181) (-959))) (-5 *2 (-2 (|:| |particular| *4) (|:| -3746 (-634 *4)))) (-5 *1 (-796 *6 *4 *3)) (-4 *3 (-646 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| -2348 *4) (|:| -3961 *3) (|:| -1500 *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-1061 *3 *4 *5)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -2348 *3) (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-1219 *3))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1226 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1203 *3)) (-5 *2 (-409 (-568)))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2723 (-777 *3)) (|:| |coef2| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -2723 *1) (|:| |coef2| *1))) (-4 *1 (-1061 *3 *4 *5))))) 
 (((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-1083 *3)) (-4 *3 (-1195))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-4 *3 (-895 *5)) (-5 *2 (-679 *3)) (-5 *1 (-681 *5 *3 *6 *4)) (-4 *6 (-375 *3)) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4519))))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1047)) (-5 *2 (-634 *1)) (-4 *1 (-1122 *3))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *3 (-944 *4)) (-4 *1 (-1122 *4)) (-4 *4 (-1047)))) ((*1 *2 *1 *3 *4) (-12 (-5 *3 (-763)) (-5 *4 (-944 (-215))) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-634 (-953 *4))) (-5 *3 (-634 (-1161))) (-4 *4 (-453)) (-5 *1 (-914 *4))))) 
-(((*1 *1 *2 *3 *1) (-12 (-5 *2 (-887 *4)) (-4 *4 (-1090)) (-5 *1 (-884 *4 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121))))) 
+(((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-446 *3)) (-4 *3 (-1047))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-1037 (-409 *2)))) (-5 *2 (-568)) (-5 *1 (-124 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *1) (-5 *1 (-439)))) 
+(((*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2707 *1))) (-4 *1 (-844 *3))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-271))))) 
 (((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1160)) (-5 *1 (-328)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1160)) (-5 *1 (-328))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1149 3 *3)) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) ((*1 *1) (-12 (-4 *1 (-1122 *2)) (-4 *2 (-1047))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-568))))) 
-(((*1 *2 *2) (-12 (-5 *1 (-961 *2)) (-4 *2 (-550))))) 
-(((*1 *1) (-5 *1 (-473)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-679 *4)))) ((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-679 *4)) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4)))) ((*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-679 *3))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-1090)) (-5 *1 (-900 *3))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-121)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)) (-4 *5 (-1047))))) 
+(((*1 *1 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-5 *2 (-1161)) (-5 *1 (-328))))) 
 (((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-67 *3)) (-14 *3 (-1161)))) ((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-74 *3)) (-14 *3 (-1161)))) ((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-77 *3)) (-14 *3 (-1161)))) ((*1 *2 *1) (-12 (-4 *1 (-397)) (-5 *2 (-1249)))) ((*1 *2 *3) (-12 (-5 *3 (-390)) (-5 *2 (-1249)) (-5 *1 (-399)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-850)) (-5 *2 (-1249)) (-5 *1 (-1123)))) ((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1249)) (-5 *1 (-1123)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-850))) (-5 *2 (-1249)) (-5 *1 (-1123))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *3 *3 *2) (-12 (-5 *2 (-381)) (-5 *3 (-1143)) (-5 *1 (-99)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-381)) (-5 *3 (-1143)) (-5 *1 (-99))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-1 (-850) (-850))) (-5 *1 (-123)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 (-850) (-634 (-850)))) (-5 *1 (-123)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-1 (-850) (-634 (-850)))) (-5 *1 (-123)))) ((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-205 *3)) (-4 *3 (-13 (-842) (-10 -8 (-15 -2779 ((-1143) $ (-1161))) (-15 -4125 (*2 $)) (-15 -1352 (*2 $))))))) ((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-396)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-396)))) ((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-500)))) ((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-700)))) ((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-1176)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-1176))))) 
-(((*1 *2 *3 *3 *3 *4 *5 *5 *6) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-3 (-1 (-215) (-215) (-215) (-215)) "undefined")) (-5 *5 (-1084 (-215))) (-5 *6 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-686)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-215))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-686)))) ((*1 *2 *2 *3 *4 *4 *5) (-12 (-5 *2 (-1121 (-215))) (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-215))) (-5 *5 (-634 (-256))) (-5 *1 (-686))))) 
-(((*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-844 *3)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-558)) (-4 *5 (-1047)) (-5 *2 (-2 (|:| -3961 *3) (|:| -1500 *3))) (-5 *1 (-845 *5 *3)) (-4 *3 (-844 *5))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-677 *4 *5 *6)) (-5 *1 (-108 *4 *3 *2 *5 *6)) (-4 *3 (-1219 *4)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-1 (-850) (-850))) (-5 *1 (-123)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 (-850) (-634 (-850)))) (-5 *1 (-123)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-1 (-850) (-634 (-850)))) (-5 *1 (-123)))) ((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-205 *3)) (-4 *3 (-13 (-842) (-10 -8 (-15 -2781 ((-1143) $ (-1161))) (-15 -4127 (*2 $)) (-15 -3687 (*2 $))))))) ((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-396)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-396)))) ((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-500)))) ((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-511)))) ((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-700)))) ((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-1176)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-1176))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-1000 *3))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3145 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
 (((*1 *1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) ((*1 *1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-640 *2)) (-4 *2 (-1195))))) 
-(((*1 *1 *1 *2 *1) (-12 (-5 *1 (-136 *2)) (-4 *2 (-1090)))) ((*1 *1 *2) (-12 (-5 *1 (-136 *2)) (-4 *2 (-1090))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-634 *14)) (-4 *14 (-258 *13)) (-4 *13 (-536 *5 *6 *7 *8 *9 *10 *11 *12 *15)) (-4 *15 (-117)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1699 *6) *3)) (-4 *9 (-971 *5)) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-4 *12 (-235 *11)) (-5 *3 (-763)) (-5 *2 (-568)) (-5 *1 (-260 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14 *15))))) 
 (((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-301)) (-5 *1 (-689 *3))))) 
 (((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-393))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) (-5 *2 (-121)) (-5 *1 (-202))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472))))) 
-(((*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| -1924 (-409 *6)) (|:| |coeff| (-409 *6)))) (-5 *1 (-578 *5 *6)) (-5 *3 (-409 *6))))) 
-(((*1 *2 *3 *1 *4) (-12 (-5 *3 (-1125 *5 *6)) (-5 *4 (-1 (-121) *6 *6)) (-4 *5 (-13 (-1090) (-39))) (-4 *6 (-13 (-1090) (-39))) (-5 *2 (-121)) (-5 *1 (-1126 *5 *6))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-993 *4)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4))) (-5 *1 (-143 *4 *5 *3)) (-4 *3 (-375 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-993 *4)) (-5 *2 (-2 (|:| |num| *6) (|:| |den| *4))) (-5 *1 (-512 *4 *5 *6 *3)) (-4 *6 (-375 *4)) (-4 *3 (-375 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-679 *5)) (-4 *5 (-993 *4)) (-4 *4 (-558)) (-5 *2 (-2 (|:| |num| (-679 *4)) (|:| |den| *4))) (-5 *1 (-682 *4 *5)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-2 (|:| -1853 *7) (|:| |rh| (-634 (-409 *6))))) (-5 *1 (-802 *5 *6 *7 *3)) (-5 *4 (-634 (-409 *6))) (-4 *7 (-646 *6)) (-4 *3 (-646 (-409 *6))))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-993 *4)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4))) (-5 *1 (-1212 *4 *5 *3)) (-4 *3 (-1219 *5))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *3 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *6)))) (-5 *4 (-1026 (-835 (-568)))) (-5 *5 (-1161)) (-5 *7 (-409 (-568))) (-4 *6 (-1047)) (-5 *2 (-850)) (-5 *1 (-593 *6))))) 
+(((*1 *1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842))))) 
+(((*1 *1 *2 *3) (-12 (-4 *4 (-365)) (-4 *6 (-230 (-1699 *5) (-763))) (-4 *7 (-641 *4)) (-4 *8 (-920 *4 *7)) (-4 *1 (-536 *4 *5 *3 *6 *2 *7 *8 *9 *10)) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *2 (-971 *4)) (-4 *9 (-235 *8)) (-4 *10 (-117)))) ((*1 *1 *2 *3 *4 *5 *6 *5 *7 *8 *9) (-12 (-5 *3 (-242 (-4289 (QUOTE X) (QUOTE -2928)) *8)) (-5 *4 (-33 *8)) (-5 *9 (-1161)) (-4 *8 (-365)) (-5 *5 (-763)) (-4 *12 (-230 (-1699 *10) *5)) (-4 *13 (-641 *8)) (-4 *14 (-920 *8 *13)) (-4 *1 (-536 *8 *10 *11 *12 *2 *13 *14 *7 *6)) (-4 *11 (-950 *8 *12 (-852 *10))) (-4 *2 (-971 *8)) (-4 *7 (-235 *14)) (-4 *6 (-117)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-4 *3 (-365)) (-4 *1 (-920 *3 *4)) (-4 *4 (-641 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-4 *1 (-920 *3 *4)) (-4 *4 (-641 *3)))) ((*1 *1) (-5 *1 (-1075)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)) (-4 *2 (-550)))) ((*1 *1 *1) (-4 *1 (-1056)))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
 (((*1 *1 *2 *2 *2) (-12 (-5 *2 (-1143)) (-4 *1 (-391))))) 
-(((*1 *2 *3) (-12 (-4 *1 (-795)) (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-1035))))) 
-(((*1 *1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1125 *4 *5))) (-5 *3 (-1 (-121) *5 *5)) (-4 *4 (-13 (-1090) (-39))) (-4 *5 (-13 (-1090) (-39))) (-5 *1 (-1126 *4 *5)))) ((*1 *1 *1 *1 *2) (-12 (-5 *2 (-634 (-1125 *3 *4))) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))) (-5 *1 (-1126 *3 *4))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-2 (|:| |totdeg| (-763)) (|:| -2700 *4))) (-5 *5 (-763)) (-4 *4 (-950 *6 *7 *8)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-5 *2 (-2 (|:| |lcmfij| *7) (|:| |totdeg| *5) (|:| |poli| *4) (|:| |polj| *4))) (-5 *1 (-450 *6 *7 *8 *4))))) 
-(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
-(((*1 *1 *2 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002)))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-173 *3)) (-4 *3 (-301))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1201 *2)) (-4 *2 (-1047)))) ((*1 *1 *1) (-12 (-5 *1 (-1235 *2 *3 *4)) (-4 *2 (-1047)) (-14 *3 (-1161)) (-14 *4 *2))) ((*1 *1 *1) (-12 (-5 *1 (-1239 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-1161))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-917)) (-5 *1 (-781))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-390)) (-5 *2 (-1249)) (-5 *1 (-393)))) ((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-393))))) 
-(((*1 *2 *2 *2 *3) (-12 (-5 *2 (-634 (-568))) (-5 *3 (-121)) (-5 *1 (-1100))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1864 *7) (|:| -4477 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *5 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *4))))) 
-(((*1 *1) (-5 *1 (-439)))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 (-439))))) (-5 *1 (-1165))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-235 *2)) (-4 *2 (-1090))))) 
+(((*1 *1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *1 *2 *2 *2 *2) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172))))) 
+(((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-492 *4 *5))) (-5 *3 (-634 (-852 *4))) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *1 (-476 *4 *5 *6)) (-4 *6 (-453))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 (-439))))) (-5 *1 (-1165))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *4 (-1161)) (-5 *6 (-121)) (-4 *7 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-4 *3 (-13 (-1181) (-959) (-29 *7))) (-5 *2 (-3 (|:| |f1| (-835 *3)) (|:| |f2| (-634 (-835 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-209 *7 *3)) (-5 *5 (-835 *3))))) 
-(((*1 *2 *3 *2 *4) (-12 (-5 *3 (-679 *2)) (-5 *4 (-763)) (-4 *2 (-13 (-301) (-10 -8 (-15 -1678 ((-420 $) $))))) (-4 *5 (-1219 *2)) (-5 *1 (-508 *2 *5 *6)) (-4 *6 (-411 *2 *5))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-927))))) 
-(((*1 *1 *2 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3)))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1061 *3 *4 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1157 *7)) (-4 *7 (-950 *6 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-5 *2 (-1157 *6)) (-5 *1 (-318 *4 *5 *6 *7))))) 
+(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-944 (-215))) (-5 *4 (-869)) (-5 *2 (-1249)) (-5 *1 (-473)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1047)) (-4 *1 (-981 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-944 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-944 *3)) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) ((*1 *2 *3 *3 *3 *3) (-12 (-5 *2 (-944 (-215))) (-5 *1 (-1192)) (-5 *3 (-215))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-565)) (-5 *3 (-568))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-679 *4)) (-4 *4 (-365)) (-5 *2 (-1157 *4)) (-5 *1 (-535 *4 *5 *6)) (-4 *5 (-365)) (-4 *6 (-13 (-365) (-840)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
 (((*1 *2 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-171)))) ((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-1245)))) ((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-1246))))) 
-(((*1 *2 *1) (-12 (-4 *2 (-1090)) (-5 *1 (-965 *2 *3)) (-4 *3 (-1090))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465)))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 *4 (-763) (-763) (-1157 *4))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 *4) (-763))))) (-5 *1 (-484 *4)) (-4 *4 (-13 (-350) (-609 (-568)))))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 *4 (-763) (-763) (-1157 *4))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 *4) (-763)))) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465)))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 *6) *6 (-1161))) (|:| A (-1 *5 (-763) (-763) (-1157 *5))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 *6 (-763) (-1161) *6)) (|:| C (-1 (-634 *5) (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 *6) *6 *3)) (|:| A (-1 *5 (-763) (-763) (-1157 *5))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 *6 (-763) *3 *6)) (|:| C (-1 (-634 *5) (-763)))) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465)))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 HPSPEC) (-5 *1 (-488 *4)) (-14 *4 (-1161)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 HPSPEC (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3)))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-420 *3)) (-4 *3 (-558)) (-5 *1 (-421 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-121)) (-5 *1 (-263))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-129 *3)) (-4 *3 (-1219 (-568)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *1 (-473))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-763)) (-4 *5 (-172)))) ((*1 *1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172)))) ((*1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) ((*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *1 (-677 *3 *2 *4)) (-4 *2 (-375 *3)) (-4 *4 (-375 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1127 *2 *3)) (-14 *2 (-763)) (-4 *3 (-1047))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-833)) (-5 *4 (-1059)) (-5 *2 (-1035)) (-5 *1 (-832)))) ((*1 *2 *3) (-12 (-5 *3 (-833)) (-5 *2 (-1035)) (-5 *1 (-832)))) ((*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-634 (-381))) (-5 *5 (-634 (-835 (-381)))) (-5 *6 (-634 (-310 (-381)))) (-5 *3 (-310 (-381))) (-5 *2 (-1035)) (-5 *1 (-832)))) ((*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-634 (-381))) (-5 *5 (-634 (-835 (-381)))) (-5 *2 (-1035)) (-5 *1 (-832)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-634 (-381))) (-5 *2 (-1035)) (-5 *1 (-832)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-310 (-381)))) (-5 *4 (-634 (-381))) (-5 *2 (-1035)) (-5 *1 (-832))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-1244 *5)) (-4 *5 (-630 *4)) (-4 *4 (-558)) (-5 *2 (-1244 *4)) (-5 *1 (-629 *4 *5))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *1 (-563))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1160)) (-5 *1 (-328))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-667 *3)) (-4 *3 (-842)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-814 *3)) (-4 *3 (-842))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-568)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-465))))) 
-(((*1 *2 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5))))) 
-(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-763)) (-5 *1 (-165 *3 *4)) (-4 *3 (-166 *4)))) ((*1 *2) (-12 (-14 *4 *2) (-4 *5 (-1195)) (-5 *2 (-763)) (-5 *1 (-229 *3 *4 *5)) (-4 *3 (-230 *4 *5)))) ((*1 *2) (-12 (-4 *4 (-842)) (-5 *2 (-763)) (-5 *1 (-431 *3 *4)) (-4 *3 (-432 *4)))) ((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-549 *3)) (-4 *3 (-550)))) ((*1 *2) (-12 (-4 *1 (-755)) (-5 *2 (-763)))) ((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-763)) (-5 *1 (-791 *3 *4)) (-4 *3 (-792 *4)))) ((*1 *2) (-12 (-4 *4 (-558)) (-5 *2 (-763)) (-5 *1 (-992 *3 *4)) (-4 *3 (-993 *4)))) ((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-763)) (-5 *1 (-996 *3 *4)) (-4 *3 (-997 *4)))) ((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1011 *3)) (-4 *3 (-1012)))) ((*1 *2) (-12 (-4 *1 (-1047)) (-5 *2 (-763)))) ((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1055 *3)) (-4 *3 (-1056))))) 
-(((*1 *1 *1) (-5 *1 (-1059)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *1 (-563))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-1 (-121) (-123) (-123))) (-5 *1 (-123))))) 
+(((*1 *2 *2 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *3 (-1219 *4)) (-5 *1 (-804 *4 *3 *2 *5)) (-4 *2 (-646 *3)) (-4 *5 (-646 (-409 *3))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-409 *5)) (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *1 (-804 *4 *5 *2 *6)) (-4 *2 (-646 *5)) (-4 *6 (-646 *3))))) 
+(((*1 *2 *1 *2) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *2)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *2 (-117))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-5 *2 (-634 *3))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-995 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 *3)) (-5 *1 (-924 *4 *5 *6 *3)) (-4 *3 (-950 *4 *6 *5))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-5 *2 (-568))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-634 (-634 (-634 *4)))) (-5 *3 (-634 *4)) (-4 *4 (-842)) (-5 *1 (-1167 *4))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1 (-944 (-215)) (-944 (-215)))) (-5 *1 (-256)))) ((*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-327 *4)) (-4 *4 (-365)) (-5 *2 (-679 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-5 *2 (-1244 *3)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-679 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-1244 *4)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-372 *4 *5)) (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-679 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-372 *4 *5)) (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-1244 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-411 *4 *5)) (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-679 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-411 *3 *4)) (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-1244 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-419 *4)) (-4 *4 (-172)) (-5 *2 (-679 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-1244 *3)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-679 *5))) (-5 *3 (-679 *5)) (-4 *5 (-365)) (-5 *2 (-1244 *5)) (-5 *1 (-1077 *5))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
+(((*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121))))) 
+(((*1 *2 *1 *3 *3 *4 *4) (-12 (-5 *3 (-763)) (-5 *4 (-917)) (-5 *2 (-1249)) (-5 *1 (-1245)))) ((*1 *2 *1 *3 *3 *4 *4) (-12 (-5 *3 (-763)) (-5 *4 (-917)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
+(((*1 *1 *1 *2 *2 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-926)))) ((*1 *1 *1 *2 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-927)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-927)))) ((*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-96 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-4 *1 (-111 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-212 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-494 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-1000 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-1132 *3))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-679 (-169 (-409 (-568))))) (-5 *2 (-634 (-169 *4))) (-5 *1 (-756 *4)) (-4 *4 (-13 (-365) (-840)))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-215)) (-5 *1 (-30)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-420 *4) *4)) (-4 *4 (-558)) (-5 *2 (-420 *4)) (-5 *1 (-421 *4)))) ((*1 *1 *1) (-5 *1 (-926))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-926)))) ((*1 *1 *1) (-5 *1 (-927))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-927)))) ((*1 *2 *3 *2 *4) (-12 (-5 *2 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) (-5 *4 (-409 (-568))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *2 *2) (|partial| -12 (-5 *2 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *2 *4) (-12 (-5 *2 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) (-5 *4 (-409 (-568))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *3 *2 *2) (|partial| -12 (-5 *2 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 (-409 (-568)))))) ((*1 *1 *1) (-12 (-4 *2 (-13 (-840) (-365))) (-5 *1 (-1057 *2 *3)) (-4 *3 (-1219 *2))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-850)))) ((*1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-121)) (-5 *1 (-207 *4 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-121)) (-5 *1 (-344 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2) (-12 (-5 *2 (-1132 (-1143))) (-5 *1 (-393))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1143)) (-5 *1 (-299))))) 
+(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-296)) (-4 *2 (-1195)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-607 *1))) (-5 *3 (-634 *1)) (-4 *1 (-296)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-288 *1))) (-4 *1 (-296)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-288 *1)) (-4 *1 (-296))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *2 (-634 (-1084 (-215)))) (-5 *1 (-928))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-5 *2 (-1249)) (-5 *1 (-1164)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-1161))) (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164)))) ((*1 *2 *3 *4 *1) (-12 (-5 *4 (-634 (-1161))) (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-4 *3 (-13 (-558) (-453))) (-5 *2 (-634 *3)) (-5 *1 (-346 *3 *5)) (-4 *5 (-52 *3 *4))))) 
 (((*1 *2 *1 *1 *3) (-12 (-4 *1 (-1129)) (-5 *3 (-147)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-1 (-944 (-215)) (-944 (-215)))) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-1 (-944 (-215)) (-944 (-215)))) (-5 *1 (-256)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-492 *5 *6))) (-5 *3 (-492 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-453)) (-5 *2 (-1244 *6)) (-5 *1 (-622 *5 *6))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-568)) (-5 *1 (-446 *3)) (-4 *3 (-406)) (-4 *3 (-1047))))) 
-(((*1 *2 *1 *3) (-12 (-4 *1 (-296)) (-5 *3 (-1161)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-296)) (-5 *2 (-121))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-1026 (-835 (-568)))) (-5 *3 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *4)))) (-4 *4 (-1047)) (-5 *1 (-593 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-4 *3 (-301)) (-5 *2 (-634 *5))))) 
+(((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-763)) (-5 *1 (-586 *2)) (-4 *2 (-550)))) ((*1 *2 *3) (-12 (-5 *2 (-2 (|:| -2404 *3) (|:| -3483 (-763)))) (-5 *1 (-586 *3)) (-4 *3 (-550))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-568)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-465))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-1161)) (-5 *2 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-5 *1 (-1164))))) 
-(((*1 *2 *3) (-12 (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *2 (-2 (|:| |glbase| (-634 (-242 *4 *5))) (|:| |glval| (-634 (-568))))) (-5 *1 (-622 *4 *5)) (-5 *3 (-634 (-242 *4 *5)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *3 *2) (-12 (-5 *2 (-1141 *4)) (-5 *3 (-568)) (-4 *4 (-1047)) (-5 *1 (-1145 *4)))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1201 *3)) (-4 *3 (-1047)))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-1161))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-2 (|:| |zeros| (-1141 (-215))) (|:| |ones| (-1141 (-215))) (|:| |singularities| (-1141 (-215))))) (-5 *1 (-109))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-358 *3)) (-4 *3 (-350))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *6)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-900 *3))) (-5 *1 (-899 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *4)))) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-917)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-256))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-99))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-310 (-381))) (-5 *2 (-310 (-215))) (-5 *1 (-299))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7))))) 
-(((*1 *1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *1) (-5 *1 (-147))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-1121 (-215))) (-5 *1 (-256))))) 
+(((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-239 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-121))))) 
+(((*1 *1 *1) (|partial| -12 (-5 *1 (-288 *2)) (-4 *2 (-716)) (-4 *2 (-1195))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1134 *3)) (-4 *3 (-1195)) (-5 *2 (-121))))) 
 (((*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-169 (-215))) (-5 *5 (-568)) (-5 *6 (-1143)) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *3 *3) (-12 (-4 *3 (-301)) (-4 *3 (-172)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-2 (|:| -3961 *3) (|:| -1500 *3))) (-5 *1 (-678 *3 *4 *5 *6)) (-4 *6 (-677 *3 *4 *5)))) ((*1 *2 *3 *3) (-12 (-5 *2 (-2 (|:| -3961 *3) (|:| -1500 *3))) (-5 *1 (-689 *3)) (-4 *3 (-301))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-420 *5)) (-4 *5 (-558)) (-5 *2 (-2 (|:| -3438 (-763)) (|:| -2348 *5) (|:| |radicand| (-634 *5)))) (-5 *1 (-316 *5)) (-5 *4 (-763)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1002)) (-5 *2 (-568))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-172))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *3 (-121)) (-5 *1 (-114)))) ((*1 *2 *2) (-12 (-5 *2 (-917)) (|has| *1 (-6 -4510)) (-4 *1 (-406)))) ((*1 *2) (-12 (-4 *1 (-406)) (-5 *2 (-917))))) 
-(((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *5 (-607 *4)) (-5 *6 (-1161)) (-4 *4 (-13 (-432 *7) (-27) (-1181))) (-4 *7 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -3746 (-634 *4)))) (-5 *1 (-570 *7 *4 *3)) (-4 *3 (-646 *4)) (-4 *3 (-1090))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-99))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-927))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002)))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1195)) (-5 *1 (-377 *4 *2)) (-4 *2 (-13 (-375 *4) (-10 -7 (-6 -4522))))))) 
+(((*1 *1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3))))) 
 (((*1 *2 *3 *4 *5 *6 *5) (-12 (-5 *4 (-169 (-215))) (-5 *5 (-568)) (-5 *6 (-1143)) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *2) (|partial| -12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3))))) 
-(((*1 *1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1143)) (-5 *1 (-299))))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-409 (-568))) (-5 *1 (-215)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-409 (-568))) (-5 *1 (-215)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-409 (-568))) (-5 *1 (-381)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-409 (-568))) (-5 *1 (-381))))) 
-(((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) ((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) ((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927))))) 
+(((*1 *2 *2 *3) (-12 (-4 *3 (-365)) (-5 *1 (-280 *3 *2)) (-4 *2 (-1234 *3))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-450 *3 *4 *5 *6))))) 
+(((*1 *1 *1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *3 (-558))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-1143)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-256)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
 (((*1 *2 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *2 (-432 *3)) (-5 *1 (-36 *3 *2)) (-4 *3 (-1037 *4)) (-4 *3 (-13 (-842) (-558)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 *9)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-763)) (-5 *1 (-1064 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 *9)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1099 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-763)) (-5 *1 (-1130 *5 *6 *7 *8 *9))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-1108)) (-5 *1 (-113))))) 
-(((*1 *2 *3) (-12 (-4 *1 (-890)) (-5 *3 (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) (-5 *2 (-1035))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-634 *5))) (-4 *5 (-324 *4 *6)) (-4 *6 (-230 *7 *2)) (-14 *7 *2) (-4 *4 (-1047)) (-5 *2 (-763)) (-5 *1 (-772 *4 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-230 *7 *2)) (-14 *7 *2) (-5 *2 (-763)) (-5 *1 (-929 *5 *3 *6 *7 *4)) (-4 *3 (-324 *5 *6)) (-4 *4 (-971 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-568)) (-4 *6 (-365)) (-4 *7 (-230 *8 *2)) (-14 *8 *2) (-5 *2 (-763)) (-5 *1 (-929 *6 *3 *7 *8 *4)) (-4 *3 (-324 *6 *7)) (-4 *4 (-971 *6))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-995 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090))))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1090)) (-4 *4 (-1195)) (-5 *2 (-121)) (-5 *1 (-1141 *4))))) 
+(((*1 *2 *3 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-970 *5 *3)) (-4 *3 (-1219 *5))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-420 *3)) (-5 *1 (-910 *3)) (-4 *3 (-301))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-1210 (-568))) (-4 *1 (-277 *3)) (-4 *3 (-1195)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-277 *3)) (-4 *3 (-1195))))) 
 (((*1 *2 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-514 (-409 (-568)) (-232 *4 (-763)) (-852 *3) (-242 *3 (-409 (-568))))) (-14 *3 (-634 (-1161))) (-14 *4 (-763)) (-5 *1 (-515 *3 *4))))) 
-(((*1 *2 *3 *4 *3 *5) (-12 (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *8 (-230 (-1697 *7) (-763))) (-4 *9 (-641 *6)) (-5 *2 (-2 (|:| |fnc| *3) (|:| |crv| *3) (|:| |chart| (-634 (-568))))) (-5 *1 (-654 *6 *7 *3 *8 *4 *9 *10)) (-5 *5 (-568)) (-4 *3 (-950 *6 *8 (-852 *7))) (-4 *4 (-971 *6)) (-4 *10 (-920 *6 *9))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5))))) 
-(((*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1039))))) 
-(((*1 *1 *1) (-4 *1 (-40))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *2 *3) (-12 (-4 *2 (-365)) (-4 *2 (-840)) (-5 *1 (-946 *2 *3)) (-4 *3 (-1219 *2))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-1108)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-1108)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-215)))) ((*1 *2 *1) (-12 (-5 *2 (-1108)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) ((*1 *1 *1) (-4 *1 (-550))) ((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-591 *3)) (-14 *3 *2))) ((*1 *2 *1) (-12 (-5 *2 (-1108)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-1090)) (-5 *2 (-1108)))) ((*1 *2 *1) (-12 (-5 *2 (-1108)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-561 *3)) (-4 *3 (-550))))) 
 (((*1 *2 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-636 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-842)) (-4 *4 (-365)) (-4 *5 (-788)) (-5 *2 (-121)) (-5 *1 (-514 *4 *5 *6 *7)) (-4 *7 (-950 *4 *5 *6))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-121)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-465)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-927))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-955)) (-5 *2 (-1084 (-215))))) ((*1 *2 *1) (-12 (-4 *1 (-975)) (-5 *2 (-1084 (-215)))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *1 (-1205 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1234 *3))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-57))) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) (-5 *2 (-381)) (-5 *1 (-263)))) ((*1 *2 *3) (-12 (-5 *3 (-1244 (-310 (-215)))) (-5 *2 (-381)) (-5 *1 (-299))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2317 ((-1113 *3 (-607 $)) $)) (-15 -2324 ((-1113 *3 (-607 $)) $)) (-15 -2745 ($ (-1113 *3 (-607 $))))))))) ((*1 *2 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2317 ((-1113 *3 (-607 $)) $)) (-15 -2324 ((-1113 *3 (-607 $)) $)) (-15 -2745 ($ (-1113 *3 (-607 $))))))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2317 ((-1113 *4 (-607 $)) $)) (-15 -2324 ((-1113 *4 (-607 $)) $)) (-15 -2745 ($ (-1113 *4 (-607 $))))))) (-4 *4 (-558)) (-5 *1 (-46 *4 *2)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-634 (-607 *2))) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2317 ((-1113 *4 (-607 $)) $)) (-15 -2324 ((-1113 *4 (-607 $)) $)) (-15 -2745 ($ (-1113 *4 (-607 $))))))) (-4 *4 (-558)) (-5 *1 (-46 *4 *2))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-57))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-679 *4)) (-5 *3 (-917)) (-4 *4 (-1047)) (-5 *1 (-1028 *4)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-634 (-679 *4))) (-5 *3 (-917)) (-4 *4 (-1047)) (-5 *1 (-1028 *4))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-44 *3)) (-4 *3 (-1219 (-53)))))) 
 (((*1 *2 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-234)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-1249)) (-5 *1 (-234))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927))))) 
-(((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-169 (-215)) (-169 (-215)))) (-5 *4 (-1084 (-215))) (-5 *5 (-121)) (-5 *2 (-1246)) (-5 *1 (-250))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-381)) (-5 *2 (-215)) (-5 *1 (-1247)))) ((*1 *2) (-12 (-5 *2 (-215)) (-5 *1 (-1247))))) 
-(((*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *12)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2) (-12 (-5 *2 (-634 (-259 (-537 *3 *4 *5)))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-634 (-259 (-513 *3 *4 *5)))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))) (-5 *2 (-409 (-568))) (-5 *1 (-1019 *4)) (-4 *4 (-1219 (-568)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-208))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-500)))) ((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-700))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) ((*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *1 *1) (-4 *1 (-1124)))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-230 *3 *4)) (-4 *4 (-1047)) (-4 *4 (-1195)))) ((*1 *1 *2) (-12 (-14 *3 (-634 (-1161))) (-4 *4 (-172)) (-4 *5 (-230 (-1699 *3) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4357 *2) (|:| -3483 *5)) (-2 (|:| -4357 *2) (|:| -3483 *5)))) (-5 *1 (-463 *3 *4 *2 *5 *6 *7)) (-4 *2 (-842)) (-4 *7 (-950 *4 *5 (-852 *3))))) ((*1 *2 *2) (-12 (-5 *2 (-944 (-215))) (-5 *1 (-1192))))) 
 (((*1 *2 *3 *3 *4 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-1143)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739))))) 
 (((*1 *1 *2 *2) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *4 *5 *6)) (-4 *4 (-301)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-448 *4 *5 *6 *2))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1195)) (-5 *1 (-377 *4 *2)) (-4 *2 (-13 (-375 *4) (-10 -7 (-6 -4520))))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1210 *3)) (-4 *3 (-1195))))) 
-(((*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-2 (|:| |ans| *6) (|:| -3284 *6) (|:| |sol?| (-121))) (-568) *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-5 *2 (-3 (-2 (|:| |answer| (-409 *7)) (|:| |a0| *6)) (-2 (|:| -1924 (-409 *7)) (|:| |coeff| (-409 *7))) "failed")) (-5 *1 (-578 *6 *7)) (-5 *3 (-409 *7))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-121)) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-4 *3 (-13 (-27) (-1181) (-432 *6) (-10 -8 (-15 -2745 ($ *7))))) (-4 *7 (-840)) (-4 *8 (-13 (-1221 *3 *7) (-365) (-1181) (-10 -8 (-15 -4189 ($ $)) (-15 -3837 ($ $))))) (-5 *2 (-3 (|:| |%series| *8) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143)))))) (-5 *1 (-424 *6 *3 *7 *8 *9 *10)) (-5 *5 (-1143)) (-4 *9 (-984 *8)) (-14 *10 (-1161))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
-(((*1 *2 *1 *3) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-126 *4)) (-14 *4 *3) (-5 *3 (-568)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-863 *3)) (-5 *2 (-568)))) ((*1 *2 *1 *3) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-865 *4)) (-14 *4 *3) (-5 *3 (-568)))) ((*1 *2 *1 *3) (-12 (-14 *4 *3) (-5 *2 (-409 (-568))) (-5 *1 (-866 *4 *5)) (-5 *3 (-568)) (-4 *5 (-863 *4)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1012)) (-5 *2 (-409 (-568))))) ((*1 *2 *3 *1 *2) (-12 (-4 *1 (-1063 *2 *3)) (-4 *2 (-13 (-840) (-365))) (-4 *3 (-1219 *2)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-1221 *2 *3)) (-4 *3 (-787)) (|has| *2 (-15 ** (*2 *2 *3))) (|has| *2 (-15 -2745 (*2 (-1161)))) (-4 *2 (-1047))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) ((*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-1182 *3))) (-5 *1 (-1182 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *2 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-1061 *3 *4 *2)) (-4 *2 (-842)))) ((*1 *2 *1) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147))))) 
+(((*1 *2 *1 *3) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-126 *4)) (-14 *4 *3) (-5 *3 (-568)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-863 *3)) (-5 *2 (-568)))) ((*1 *2 *1 *3) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-865 *4)) (-14 *4 *3) (-5 *3 (-568)))) ((*1 *2 *1 *3) (-12 (-14 *4 *3) (-5 *2 (-409 (-568))) (-5 *1 (-866 *4 *5)) (-5 *3 (-568)) (-4 *5 (-863 *4)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1012)) (-5 *2 (-409 (-568))))) ((*1 *2 *3 *1 *2) (-12 (-4 *1 (-1063 *2 *3)) (-4 *2 (-13 (-840) (-365))) (-4 *3 (-1219 *2)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-1221 *2 *3)) (-4 *3 (-787)) (|has| *2 (-15 ** (*2 *2 *3))) (|has| *2 (-15 -2747 (*2 (-1161)))) (-4 *2 (-1047))))) 
 (((*1 *2 *3 *3 *4 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-1143)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-447)) (-5 *3 (-568))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-594 *3)) (-4 *3 (-1047)))) ((*1 *2 *1) (-12 (-4 *1 (-974 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-787)) (-4 *5 (-842)) (-5 *2 (-121))))) 
-(((*1 *1 *2 *2 *1) (-12 (-5 *1 (-636 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-5 *2 (-2 (|:| A (-679 *5)) (|:| |eqs| (-634 (-2 (|:| C (-679 *5)) (|:| |g| (-1244 *5)) (|:| -1853 *6) (|:| |rh| *5)))))) (-5 *1 (-808 *5 *6)) (-5 *3 (-679 *5)) (-5 *4 (-1244 *5)) (-4 *6 (-646 *5)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-646 *5)) (-5 *2 (-2 (|:| -2928 (-679 *6)) (|:| |vec| (-1244 *5)))) (-5 *1 (-808 *5 *6)) (-5 *3 (-679 *6)) (-5 *4 (-1244 *5))))) 
-(((*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1195)) (-4 *4 (-375 *2)) (-4 *5 (-375 *2)))) ((*1 *2 *1 *3 *2) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-283 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195))))) 
-(((*1 *2 *3 *3 *4 *5 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-1143)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739))))) 
-(((*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-634 (-607 *2))) (-5 *4 (-1161)) (-4 *2 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *5 *2))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-139))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-781))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-365)) (-5 *1 (-653 *3))))) 
+(((*1 *2) (-12 (-5 *2 (-679 (-905 *3))) (-5 *1 (-352 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917)))) ((*1 *2) (-12 (-5 *2 (-679 *3)) (-5 *1 (-353 *3 *4)) (-4 *3 (-350)) (-14 *4 (-3 (-1157 *3) (-1244 (-634 (-2 (|:| -2852 *3) (|:| -4357 (-1108))))))))) ((*1 *2) (-12 (-5 *2 (-679 *3)) (-5 *1 (-354 *3 *4)) (-4 *3 (-350)) (-14 *4 (-917))))) 
 (((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *2 *3) (-12 (-4 *1 (-831)) (-5 *3 (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (-5 *2 (-1035)))) ((*1 *2 *3) (-12 (-4 *1 (-831)) (-5 *3 (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) (-5 *2 (-1035))))) 
+(((*1 *2 *2 *1) (-12 (-5 *2 (-634 *6)) (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-1201 *3)) (-4 *3 (-1047)) (-5 *1 (-1200 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-887 *4)) (-4 *4 (-1090)) (-5 *2 (-1 (-121) *5)) (-5 *1 (-885 *4 *5)) (-4 *5 (-1195))))) 
+(((*1 *2 *3 *3 *4 *5 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-1143)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739))))) 
+(((*1 *1 *2 *2 *1) (-12 (-5 *1 (-636 *2)) (-4 *2 (-1090))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-246 *2 *3 *4 *5)) (-4 *2 (-1047)) (-4 *3 (-842)) (-4 *4 (-262 *3)) (-4 *5 (-788))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-1161))))) 
 (((*1 *2) (-12 (-14 *4 *2) (-4 *5 (-1195)) (-5 *2 (-763)) (-5 *1 (-229 *3 *4 *5)) (-4 *3 (-230 *4 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-320 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-137)) (-5 *2 (-763)))) ((*1 *2) (-12 (-4 *4 (-365)) (-5 *2 (-763)) (-5 *1 (-326 *3 *4)) (-4 *3 (-327 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-363 *3)) (-4 *3 (-1090)))) ((*1 *2) (-12 (-4 *1 (-370)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-388 *3)) (-4 *3 (-1090)))) ((*1 *2) (-12 (-4 *4 (-1090)) (-5 *2 (-763)) (-5 *1 (-426 *3 *4)) (-4 *3 (-427 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-638 *3 *4 *5)) (-4 *3 (-1090)) (-4 *4 (-23)) (-14 *5 *4))) ((*1 *2) (-12 (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-763)) (-5 *1 (-713 *3 *4 *5)) (-4 *3 (-714 *4 *5)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-814 *3)) (-4 *3 (-842)))) ((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1006)))) ((*1 *2 *1) (-12 (-4 *2 (-13 (-840) (-365))) (-5 *1 (-1057 *2 *3)) (-4 *3 (-1219 *2))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565)))) ((*1 *2 *3) (-12 (-5 *2 (-1157 (-409 (-568)))) (-5 *1 (-943)) (-5 *3 (-568))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *2 (-568)) (-5 *1 (-573 *3)) (-4 *3 (-1037 *2))))) 
+(((*1 *1 *1 *1) (-4 *1 (-478))) ((*1 *1 *1 *1) (-4 *1 (-753)))) 
+(((*1 *2 *1) (-12 (-5 *1 (-1191 *2)) (-4 *2 (-975))))) 
+(((*1 *2 *3 *2 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-634 (-242 *5 *6))) (-4 *6 (-453)) (-5 *2 (-242 *5 *6)) (-14 *5 (-634 (-1161))) (-5 *1 (-622 *5 *6))))) 
 (((*1 *2 *3 *3 *4 *5 *5 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-1143)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739))))) 
-(((*1 *2 *2 *3) (-12 (-4 *3 (-1047)) (-5 *1 (-445 *3 *2)) (-4 *2 (-1219 *3))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-172)))) ((*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-943)) (-5 *3 (-568))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-679 *3)) (-4 *3 (-301)) (-5 *1 (-689 *3))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-641 *2)) (-4 *2 (-365))))) 
-(((*1 *1 *1) (-4 *1 (-863 *2)))) 
-(((*1 *1) (-12 (-5 *1 (-634 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247)))) ((*1 *2 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247))))) 
 (((*1 *1 *1 *1) (-12 (-5 *1 (-634 *2)) (-4 *2 (-1090)) (-4 *2 (-1195))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-1244 (-679 *4))) (-5 *1 (-95 *4 *5)) (-5 *3 (-679 *4)) (-4 *5 (-646 *4))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1219 (-53))))) ((*1 *2 *3 *1) (-12 (-5 *2 (-2 (|:| |less| (-130 *3)) (|:| |greater| (-130 *3)))) (-5 *1 (-130 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-4 *3 (-1090)) (-5 *2 (-634 *1)) (-4 *1 (-235 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-585 *4)) (-4 *4 (-13 (-29 *3) (-1181))) (-4 *3 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *1 (-583 *3 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-585 (-409 (-953 *3)))) (-4 *3 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *1 (-588 *3)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| -2242 *3) (|:| |special| *3))) (-5 *1 (-717 *5 *3)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1244 *5)) (-4 *5 (-365)) (-4 *5 (-1047)) (-5 *2 (-634 (-634 (-679 *5)))) (-5 *1 (-1029 *5)) (-5 *3 (-634 (-679 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1244 (-1244 *5))) (-4 *5 (-365)) (-4 *5 (-1047)) (-5 *2 (-634 (-634 (-679 *5)))) (-5 *1 (-1029 *5)) (-5 *3 (-634 (-679 *5))))) ((*1 *2 *1 *3) (-12 (-5 *3 (-142)) (-5 *2 (-634 *1)) (-4 *1 (-1129)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-147)) (-5 *2 (-634 *1)) (-4 *1 (-1129))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-381)) (-5 *1 (-197))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *1 (-313)) (-5 *3 (-215))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-1157 *6)) (-5 *3 (-568)) (-4 *6 (-301)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-732 *4 *5 *6 *7)) (-4 *7 (-950 *6 *4 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
-(((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) ((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) ((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-634 (-679 *4))) (-5 *2 (-679 *4)) (-4 *4 (-1047)) (-5 *1 (-1029 *4))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
 (((*1 *2 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739))))) 
-(((*1 *2 *3 *1) (|partial| -12 (-5 *3 (-887 *4)) (-4 *4 (-1090)) (-4 *2 (-1090)) (-5 *1 (-884 *4 *2))))) 
-(((*1 *1 *1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *2)) (-4 *2 (-950 *3 *4 *5)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4))))) 
+(((*1 *1) (-12 (-5 *1 (-634 *2)) (-4 *2 (-1195))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-310 *3)) (-4 *3 (-558)) (-4 *3 (-842))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-324 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-725 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-716))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-123)) (-5 *1 (-1024 *4 *3)) (-4 *3 (-13 (-432 *4) (-23) (-1037 (-568)) (-1037 (-1161)) (-895 (-1161)) (-161)))))) 
+(((*1 *1) (-5 *1 (-439)))) 
+(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *7 (-230 (-1699 *5) (-763))) (-5 *2 (-634 (-634 (-1157 (-1157 *4))))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-5 *3 (-634 (-1157 (-1157 *4)))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *8 (-971 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-763)) (-5 *4 (-1244 *2)) (-4 *5 (-301)) (-4 *6 (-993 *5)) (-4 *2 (-13 (-411 *6 *7) (-1037 *6))) (-5 *1 (-415 *5 *6 *7 *2)) (-4 *7 (-1219 *6))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-1161))))) 
+(((*1 *2 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739))))) 
+(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4521)) (-4 *1 (-227 *3)) (-4 *3 (-1090)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-277 *3)) (-4 *3 (-1195))))) 
 (((*1 *1 *1 *1) (-12 (-5 *1 (-634 *2)) (-4 *2 (-1090)) (-4 *2 (-1195))))) 
-(((*1 *2) (-12 (-4 *3 (-1047)) (-5 *2 (-958 (-702 *3 *4))) (-5 *1 (-702 *3 *4)) (-4 *4 (-1219 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-381))))) 
-(((*1 *2 *1 *2 *3) (|partial| -12 (-5 *2 (-1143)) (-5 *3 (-568)) (-5 *1 (-1059))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *2) (-12 (-5 *2 (-2 (|:| -3043 (-634 (-1161))) (|:| -3544 (-634 (-1161))))) (-5 *1 (-1197))))) 
+(((*1 *2 *3 *4) (-12 (-4 *6 (-558)) (-4 *2 (-950 *3 *5 *4)) (-5 *1 (-722 *5 *4 *6 *2)) (-5 *3 (-409 (-953 *6))) (-4 *5 (-788)) (-4 *4 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $)))))))) 
 (((*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739))))) 
-(((*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-215)) (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-634 (-953 *6))) (-5 *4 (-634 (-1161))) (-4 *6 (-453)) (-5 *2 (-634 (-634 *7))) (-5 *1 (-543 *6 *7 *5)) (-4 *7 (-365)) (-4 *5 (-13 (-365) (-840)))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-842)) (-5 *2 (-634 (-634 (-634 *4)))) (-5 *1 (-1167 *4)) (-5 *3 (-634 (-634 *4)))))) 
+(((*1 *1 *2 *3 *3 *3 *4) (-12 (-4 *4 (-365)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 (-409 *3))) (-4 *1 (-333 *4 *3 *5 *2)) (-4 *2 (-340 *4 *3 *5)))) ((*1 *1 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *2 (-365)) (-4 *4 (-1219 *2)) (-4 *5 (-1219 (-409 *4))) (-4 *1 (-333 *2 *4 *5 *6)) (-4 *6 (-340 *2 *4 *5)))) ((*1 *1 *2 *2) (-12 (-4 *2 (-365)) (-4 *3 (-1219 *2)) (-4 *4 (-1219 (-409 *3))) (-4 *1 (-333 *2 *3 *4 *5)) (-4 *5 (-340 *2 *3 *4)))) ((*1 *1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *1 (-333 *3 *4 *5 *2)) (-4 *2 (-340 *3 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-415 *4 (-409 *4) *5 *6)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 *3 *4 *5)) (-4 *3 (-365)) (-4 *1 (-333 *3 *4 *5 *6))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3651 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381))))))) (-5 *1 (-798))))) 
+(((*1 *2 *1) (-12 (-4 *2 (-698 *3)) (-5 *1 (-822 *2 *3)) (-4 *3 (-1047))))) 
 (((*1 *1 *1 *1) (-12 (-5 *1 (-634 *2)) (-4 *2 (-1090)) (-4 *2 (-1195))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) ((*1 *2 *2 *1) (|partial| -12 (-5 *2 (-409 *1)) (-4 *1 (-1219 *3)) (-4 *3 (-1047)) (-4 *3 (-558)))) ((*1 *1 *1 *1) (|partial| -12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-558))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-944 *3))))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047))))) 
+(((*1 *1 *1) (-4 *1 (-550)))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-1099 *5 *6 *7 *8)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-590 *5 *6 *7 *8 *3))))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-96 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-212 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-842)) (-5 *2 (-121)) (-5 *1 (-494 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| *1 (-6 -4521)) (-4 *1 (-499 *4)) (-4 *4 (-1195)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-1000 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-1132 *4))))) 
 (((*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-739))))) 
-(((*1 *1 *2 *3 *1) (-12 (-14 *4 (-634 (-1161))) (-4 *2 (-172)) (-4 *3 (-230 (-1697 *4) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4355 *5) (|:| -3438 *3)) (-2 (|:| -4355 *5) (|:| -3438 *3)))) (-5 *1 (-463 *4 *2 *5 *3 *6 *7)) (-4 *5 (-842)) (-4 *7 (-950 *2 *3 (-852 *4)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| -2928 (-679 (-409 (-953 *4)))) (|:| |vec| (-634 (-409 (-953 *4)))) (|:| -3700 (-763)) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568))))) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-2 (|:| |partsol| (-1244 (-409 (-953 *4)))) (|:| -3746 (-634 (-1244 (-409 (-953 *4))))))) (-5 *1 (-924 *4 *5 *6 *7)) (-4 *7 (-950 *4 *6 *5))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-235 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-977 *3 *4 *2 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *5 (-1061 *3 *4 *2))))) 
+(((*1 *2 *1) (-12 (-4 *2 (-1219 *3)) (-5 *1 (-401 *3 *2)) (-4 *3 (-13 (-365) (-150)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-601 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1195)) (-5 *2 (-634 *3))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-333 *3 *4 *5 *6)) (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 *3 *4 *5)) (-5 *2 (-2 (|:| -1716 (-415 *4 (-409 *4) *5 *6)) (|:| |principalPart| *6))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| |poly| *6) (|:| -2244 (-409 *6)) (|:| |special| (-409 *6)))) (-5 *1 (-717 *5 *6)) (-5 *3 (-409 *6)))) ((*1 *2 *3) (-12 (-4 *4 (-365)) (-5 *2 (-634 *3)) (-5 *1 (-891 *3 *4)) (-4 *3 (-1219 *4)))) ((*1 *2 *3 *4 *4) (|partial| -12 (-5 *4 (-763)) (-4 *5 (-365)) (-5 *2 (-2 (|:| -3030 *3) (|:| -3286 *3))) (-5 *1 (-891 *3 *5)) (-4 *3 (-1219 *5)))) ((*1 *2 *3 *2 *4 *4) (-12 (-5 *2 (-634 *9)) (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1064 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *2 *4 *4 *4 *4 *4) (-12 (-5 *2 (-634 *9)) (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1064 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *2 *4 *4) (-12 (-5 *2 (-634 *9)) (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1099 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1130 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *2 *4 *4 *4 *4 *4) (-12 (-5 *2 (-634 *9)) (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1099 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1130 *5 *6 *7 *8 *9))))) 
 (((*1 *1 *1) (-12 (-4 *1 (-375 *2)) (-4 *2 (-1195)))) ((*1 *2 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-445 *3 *2)) (-4 *2 (-1219 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3)))) 
-(((*1 *1 *2) (|partial| -12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-1255 *3 *4 *5 *6)))) ((*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-634 *8)) (-5 *3 (-1 (-121) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1255 *5 *6 *7 *8))))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-158)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
+(((*1 *2 *3 *4 *2) (-12 (-5 *2 (-634 (-2 (|:| |totdeg| (-763)) (|:| -1416 *3)))) (-5 *4 (-763)) (-4 *3 (-950 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-450 *5 *6 *7 *3))))) 
+(((*1 *1 *1 *2 *1) (-12 (-4 *1 (-1129)) (-5 *2 (-1210 (-568)))))) 
 (((*1 *2 *3 *3 *3 *3 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 -1478)))) (-5 *2 (-1035)) (-5 *1 (-738))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-55 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-634 (-1161))))) ((*1 *1 *1) (-12 (-5 *1 (-213 *2 *3)) (-4 *2 (-13 (-1047) (-842))) (-14 *3 (-634 (-1161)))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-2 (|:| -4068 (-568)) (|:| -3276 (-634 *3)))) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568)))))) 
-(((*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-844 *3)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-558)) (-4 *5 (-1047)) (-5 *2 (-2 (|:| -3961 *3) (|:| -1500 *3))) (-5 *1 (-845 *5 *3)) (-4 *3 (-844 *5))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-259 *3)) (-4 *3 (-1090)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-259 *3)) (-4 *3 (-1090)))) ((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-513 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-513 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-537 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-537 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-5 *2 (-121)) (-5 *1 (-538 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *7 (-971 *3)) (-4 *10 (-235 *9)) (-4 *11 (-117)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-5 *1 (-538 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *7 (-971 *3)) (-4 *10 (-235 *9)) (-4 *11 (-117)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-855 *3)) (-14 *3 (-860)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-857 *3)) (-4 *3 (-350)))) ((*1 *2 *1) (-12 (-4 *1 (-858)) (-5 *2 (-850)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-860))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-634 (-1157 (-568)))) (-5 *1 (-183)) (-5 *3 (-568))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842))) (-5 *2 (-169 *5)) (-5 *1 (-597 *4 *5 *3)) (-4 *5 (-13 (-432 *4) (-1002) (-1181))) (-4 *3 (-13 (-432 (-169 *4)) (-1002) (-1181)))))) 
+(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-679 *5)) (-4 *5 (-1047)) (-5 *1 (-1051 *3 *4 *5)) (-14 *3 (-763)) (-14 *4 (-763))))) 
+(((*1 *1 *1) (-12 (-4 *2 (-453)) (-4 *3 (-842)) (-4 *4 (-788)) (-5 *1 (-988 *2 *3 *4 *5)) (-4 *5 (-950 *2 *4 *3))))) 
 (((*1 *1 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-842)))) ((*1 *1 *1) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) ((*1 *1 *1) (-12 (-5 *1 (-888 *2)) (-4 *2 (-842)))) ((*1 *1 *1) (|partial| -12 (-4 *1 (-1189 *2 *3 *4 *5)) (-4 *2 (-558)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-1061 *2 *3 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1231 *3)) (-4 *3 (-1195)))) ((*1 *1 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-33 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-558)) (-5 *2 (-1157 *4)) (-5 *1 (-759 *4))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *3) (|:| |xpnt| (-568))))) (-5 *1 (-420 *3)) (-4 *3 (-558)))) ((*1 *2 *3 *4 *4 *4) (-12 (-5 *4 (-763)) (-4 *3 (-350)) (-4 *5 (-1219 *3)) (-5 *2 (-634 (-1157 *3))) (-5 *1 (-507 *3 *5 *6)) (-4 *6 (-1219 *5))))) 
 (((*1 *2 *3 *3 *4 *5 *3 *6) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-86 FCN)))) (-5 *2 (-1035)) (-5 *1 (-738))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-121)) (-5 *1 (-294))))) 
-(((*1 *1 *1) (-5 *1 (-1059)))) 
-(((*1 *1 *1) (-5 *1 (-215))) ((*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) ((*1 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *1 *1) (-4 *1 (-1124))) ((*1 *1 *1 *1) (-4 *1 (-1124)))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-169 (-568))) (-5 *2 (-121)) (-5 *1 (-447)))) ((*1 *2 *3) (-12 (-5 *3 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568))))) (-14 *4 (-634 (-1161))) (-14 *5 (-763)) (-5 *2 (-121)) (-5 *1 (-515 *4 *5)))) ((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-961 *3)) (-4 *3 (-550)))) ((*1 *2 *1) (-12 (-4 *1 (-1199)) (-5 *2 (-121))))) 
-(((*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-453)) (-5 *2 (-634 (-2 (|:| |eigval| (-3 (-409 (-953 *4)) (-1150 (-1161) (-953 *4)))) (|:| |eigmult| (-763)) (|:| |eigvec| (-634 (-679 (-409 (-953 *4)))))))) (-5 *1 (-286 *4)) (-5 *3 (-679 (-409 (-953 *4))))))) 
-(((*1 *1 *1) (-12 (|has| *1 (-6 -4519)) (-4 *1 (-154 *2)) (-4 *2 (-1195)) (-4 *2 (-1090))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-173 *3)) (-4 *3 (-301))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-52 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-593 *3)) (-4 *3 (-1047)))) ((*1 *2 *1) (-12 (-4 *3 (-558)) (-5 *2 (-121)) (-5 *1 (-615 *3 *4)) (-4 *4 (-1219 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-725 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-716)))) ((*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1249)) (-5 *1 (-1123)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-850))) (-5 *2 (-1249)) (-5 *1 (-1123))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-334 *5 *6 *7 *8)) (-4 *5 (-432 *4)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-4 *8 (-340 *5 *6 *7)) (-4 *4 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-121)) (-5 *1 (-906 *4 *5 *6 *7 *8)))) ((*1 *2 *3) (-12 (-5 *3 (-334 (-409 (-568)) *4 *5 *6)) (-4 *4 (-1219 (-409 (-568)))) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 (-409 (-568)) *4 *5)) (-5 *2 (-121)) (-5 *1 (-907 *4 *5 *6))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-5 *1 (-439))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)) (-5 *2 (-121)))) ((*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-350)) (-5 *2 (-121)) (-5 *1 (-358 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-350)) (-5 *2 (-121)) (-5 *1 (-532 *4))))) 
-(((*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172))))) 
-(((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-27) (-432 *4))) (-4 *4 (-13 (-842) (-558) (-1037 (-568)))) (-4 *7 (-1219 (-409 *6))) (-5 *1 (-553 *4 *5 *6 *7 *2)) (-4 *2 (-340 *5 *6 *7))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-381)) (-5 *1 (-197))))) 
-(((*1 *2 *1 *1 *3 *4) (-12 (-5 *3 (-1 (-121) *5 *5)) (-5 *4 (-1 (-121) *6 *6)) (-4 *5 (-13 (-1090) (-39))) (-4 *6 (-13 (-1090) (-39))) (-5 *2 (-121)) (-5 *1 (-1125 *5 *6))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-320 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-137)) (-4 *3 (-787))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-1047)) (-5 *1 (-702 *3 *4)) (-4 *4 (-1219 *3))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-4 *1 (-898 *3))))) 
+(((*1 *2) (-12 (-4 *3 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *2 (-634 *4)) (-5 *1 (-908 *3 *4 *5 *6)) (-4 *4 (-324 *3 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *2 (-1035)) (-5 *1 (-299))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) ((*1 *2 *3) (-12 (-5 *3 (-972)) (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
+(((*1 *2 *2 *2 *3 *4) (-12 (-5 *3 (-101 *5)) (-5 *4 (-1 *5 *5)) (-4 *5 (-1047)) (-5 *1 (-845 *5 *2)) (-4 *2 (-844 *5))))) 
+(((*1 *1 *1) (-12 (|has| *1 (-6 -4521)) (-4 *1 (-154 *2)) (-4 *2 (-1195)) (-4 *2 (-1090))))) 
+(((*1 *1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-324 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-4 *3 (-172))))) 
+(((*1 *1 *1 *1) (-4 *1 (-296))) ((*1 *1 *1) (-4 *1 (-296)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -2371 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| *7) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 *7))))) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-763)) (-5 *1 (-924 *4 *5 *6 *7))))) 
+(((*1 *2 *2 *1) (|partial| -12 (-5 *2 (-634 *1)) (-4 *1 (-916))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-819))))) 
+(((*1 *2 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-995 *2)) (-4 *2 (-1195)))) ((*1 *2 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-366 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-5 *2 (-1249))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568))))) (-14 *4 (-634 (-1161))) (-14 *5 (-763)) (-5 *2 (-121)) (-5 *1 (-515 *4 *5))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-858)) (-5 *2 (-917))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-497))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465)))) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 *4 (-763) (-763) (-1157 *4))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 *4) (-763)))) (-634 (-465)))) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465)))) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 *6) *6 (-1161))) (|:| A (-1 *5 (-763) (-763) (-1157 *5))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 *6 (-763) (-1161) *6)) (|:| C (-1 (-634 *5) (-763)))) (-634 (-465)))) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-14 *9 (-1 *6 *4)) (-5 *2 (-1 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)))) ((*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465)))) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-1 HPSPEC (-634 (-465)))) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 (-1161))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-365)) (-5 *1 (-758 *2 *3)) (-4 *2 (-698 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
 (((*1 *1) (-5 *1 (-121)))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (|has| *1 (-6 -4520)) (-4 *1 (-1231 *3)) (-4 *3 (-1195))))) 
-(((*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1061 *3 *4 *5))))) 
-(((*1 *1 *1) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-375 *2)) (-4 *2 (-1195)) (-4 *2 (-842)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (|has| *1 (-6 -4520)) (-4 *1 (-375 *3)) (-4 *3 (-1195))))) 
-(((*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-568)) (-4 *6 (-641 *5)) (-4 *5 (-365)) (-5 *2 (-679 *5)) (-5 *1 (-635 *5 *6))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-420 *2)) (-4 *2 (-558))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-663 *3)) (-4 *3 (-842)) (-4 *1 (-376 *3 *4)) (-4 *4 (-172))))) 
-(((*1 *2 *1 *3) (-12 (-4 *1 (-246 *4 *3 *5 *6)) (-4 *4 (-1047)) (-4 *3 (-842)) (-4 *5 (-262 *3)) (-4 *6 (-788)) (-5 *2 (-634 (-763))))) ((*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-634 (-763)))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 (-900 *3))) (-4 *3 (-1090)) (-5 *1 (-899 *3))))) 
-(((*1 *2) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-763)) (-5 *1 (-339 *3 *4 *5 *6)) (-4 *3 (-340 *4 *5 *6)))) ((*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-763))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2850 *4) (|:| -2183 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *2)) (-4 *2 (-172)))) ((*1 *2) (-12 (-4 *2 (-172)) (-5 *1 (-418 *3 *2)) (-4 *3 (-419 *2)))) ((*1 *2) (-12 (-4 *1 (-419 *2)) (-4 *2 (-172))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-365)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-529 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-4 *7 (-993 *4)) (-4 *2 (-677 *7 *8 *9)) (-5 *1 (-530 *4 *5 *6 *3 *7 *8 *9 *2)) (-4 *3 (-677 *4 *5 *6)) (-4 *8 (-375 *7)) (-4 *9 (-375 *7)))) ((*1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (-4 *2 (-301)))) ((*1 *2 *2) (-12 (-4 *3 (-301)) (-4 *3 (-172)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-678 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-679 *3)) (-4 *3 (-301)) (-5 *1 (-689 *3)))) ((*1 *1 *1) (-12 (-4 *1 (-1050 *2 *3 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-230 *3 *4)) (-4 *6 (-230 *2 *4)) (-4 *4 (-301))))) 
+(((*1 *1 *1 *1) (-4 *1 (-753)))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-121)) (-5 *1 (-123)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-296)) (-5 *3 (-1161)) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-296)) (-5 *3 (-123)) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-121)) (-5 *1 (-607 *4)) (-4 *4 (-842)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-123)) (-5 *2 (-121)) (-5 *1 (-607 *4)) (-4 *4 (-842)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-5 *2 (-121)) (-5 *1 (-882 *5 *3 *4)) (-4 *3 (-881 *5)) (-4 *4 (-609 (-887 *5))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-4 *6 (-881 *5)) (-4 *5 (-1090)) (-5 *2 (-121)) (-5 *1 (-882 *5 *6 *4)) (-4 *4 (-609 (-887 *5)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-953 *4)))) (-4 *4 (-453)) (-5 *2 (-634 (-3 (-409 (-953 *4)) (-1150 (-1161) (-953 *4))))) (-5 *1 (-286 *4))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-57))) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-763)) (-4 *4 (-350)) (-5 *1 (-532 *4))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-944 *4)) (-4 *4 (-1047)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917))))) 
+(((*1 *1) (-5 *1 (-439)))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-1035)) (-5 *3 (-1161)) (-5 *1 (-263))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-365)) (-4 *1 (-327 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-1219 *4)) (-4 *4 (-1199)) (-4 *1 (-340 *4 *3 *5)) (-4 *5 (-1219 (-409 *3))))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-1244 *1)) (-4 *4 (-172)) (-4 *1 (-369 *4)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-1244 *1)) (-4 *4 (-172)) (-4 *1 (-372 *4 *5)) (-4 *5 (-1219 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-172)) (-4 *1 (-411 *3 *4)) (-4 *4 (-1219 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-172)) (-4 *1 (-419 *3))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-884 *4 *5)) (-5 *3 (-884 *4 *6)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-658 *5)) (-5 *1 (-880 *4 *5 *6))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-365)) (-5 *2 (-634 *3)))) ((*1 *1 *2) (-12 (-4 *1 (-658 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-634 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-1161))))) 
-(((*1 *2 *3 *3 *3) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1100)) (-5 *3 (-568))))) 
-(((*1 *2 *2 *3) (-12 (-4 *3 (-1047)) (-5 *1 (-445 *3 *2)) (-4 *2 (-1219 *3))))) 
-(((*1 *1 *2 *3 *4) (-12 (-5 *3 (-634 (-2 (|:| |scalar| (-409 (-568))) (|:| |coeff| (-1157 *2)) (|:| |logand| (-1157 *2))))) (-5 *4 (-634 (-2 (|:| |integrand| *2) (|:| |intvar| *2)))) (-4 *2 (-365)) (-5 *1 (-585 *2))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-679 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| |outval| *4) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 *4)))))) (-5 *1 (-773 *4)) (-4 *4 (-13 (-365) (-840)))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-1 (-944 (-215)) (-215) (-215))) (-5 *3 (-1 (-215) (-215) (-215) (-215))) (-5 *1 (-248))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-147))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -2910 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-128 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 *7)) (-5 *5 (-634 (-634 *8))) (-4 *7 (-842)) (-4 *8 (-301)) (-4 *6 (-788)) (-4 *9 (-950 *8 *6 *7)) (-5 *2 (-2 (|:| |unitPart| *9) (|:| |suPart| (-634 (-2 (|:| -3850 (-1157 *9)) (|:| -3483 (-568))))))) (-5 *1 (-732 *6 *7 *8 *9)) (-5 *3 (-1157 *9))))) 
+(((*1 *1 *2 *3) (-12 (-5 *1 (-965 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3145 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *2)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *2 (-117))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-609 (-887 *3))) (-4 *3 (-881 *3)) (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-609 (-887 *3))) (-4 *2 (-881 *3)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *2 *3 *4 *4 *3) (|partial| -12 (-5 *4 (-607 *3)) (-4 *3 (-13 (-432 *5) (-27) (-1181))) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| -4151 *3) (|:| |coeff| *3))) (-5 *1 (-570 *5 *3 *6)) (-4 *6 (-1090))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-1161)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-465))))) 
 (((*1 *1) (-5 *1 (-439)))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-365)) (-5 *2 (-634 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-634 *3))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-2 (|:| |deg| (-763)) (|:| -1853 *5)))) (-5 *1 (-804 *4 *5 *3 *6)) (-4 *3 (-646 *5)) (-4 *6 (-646 (-409 *5)))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-634 (-1216 *5 *4))) (-5 *1 (-1104 *4 *5)) (-5 *3 (-1216 *5 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-1143))))) 
-(((*1 *2 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-230 (-1697 *5) (-763))) (-5 *1 (-119 *4 *5 *2 *6 *3)) (-4 *2 (-324 *4 *6)) (-4 *3 (-117))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-634 *7)) (|:| |badPols| (-634 *7)))) (-5 *1 (-978 *4 *5 *6 *7)) (-5 *3 (-634 *7))))) 
-(((*1 *1 *2) (|partial| -12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-1255 *3 *4 *5 *6)))) ((*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-634 *8)) (-5 *3 (-1 (-121) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1255 *5 *6 *7 *8))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-121))))) 
-(((*1 *1 *1 *1 *1) (-4 *1 (-753)))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-169 (-568)))))) (-5 *2 (-634 (-634 (-288 (-953 (-169 *4)))))) (-5 *1 (-380 *4)) (-4 *4 (-13 (-365) (-840))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-288 (-409 (-953 (-169 (-568))))))) (-5 *2 (-634 (-634 (-288 (-953 (-169 *4)))))) (-5 *1 (-380 *4)) (-4 *4 (-13 (-365) (-840))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 (-169 (-568))))) (-5 *2 (-634 (-288 (-953 (-169 *4))))) (-5 *1 (-380 *4)) (-4 *4 (-13 (-365) (-840))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-288 (-409 (-953 (-169 (-568)))))) (-5 *2 (-634 (-288 (-953 (-169 *4))))) (-5 *1 (-380 *4)) (-4 *4 (-13 (-365) (-840)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-112)))) ((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-208)))) ((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-497)))) ((*1 *1 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)) (-4 *2 (-301)))) ((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568)))) ((*1 *1 *1) (-4 *1 (-1056)))) 
-(((*1 *1) (-5 *1 (-1059)))) 
-(((*1 *2 *1) (-12 (-5 *2 (-173 (-409 (-568)))) (-5 *1 (-126 *3)) (-14 *3 (-568)))) ((*1 *1 *2 *3 *3) (-12 (-5 *3 (-1141 *2)) (-4 *2 (-301)) (-5 *1 (-173 *2)))) ((*1 *1 *2) (-12 (-5 *2 (-409 *3)) (-4 *3 (-301)) (-5 *1 (-173 *3)))) ((*1 *2 *3) (-12 (-5 *2 (-173 (-568))) (-5 *1 (-757 *3)) (-4 *3 (-406)))) ((*1 *2 *1) (-12 (-5 *2 (-173 (-409 (-568)))) (-5 *1 (-865 *3)) (-14 *3 (-568)))) ((*1 *2 *1) (-12 (-14 *3 (-568)) (-5 *2 (-173 (-409 (-568)))) (-5 *1 (-866 *3 *4)) (-4 *4 (-863 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181))))) ((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) ((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-850))))) 
+(((*1 *2 *3 *4 *4) (-12 (-5 *4 (-1161)) (-5 *2 (-1 *7 *5 *6)) (-5 *1 (-691 *3 *5 *6 *7)) (-4 *3 (-609 (-541))) (-4 *5 (-1195)) (-4 *6 (-1195)) (-4 *7 (-1195)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-5 *2 (-1 *6 *5)) (-5 *1 (-696 *3 *5 *6)) (-4 *3 (-609 (-541))) (-4 *5 (-1195)) (-4 *6 (-1195))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-634 *6))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1173 *4 *5)) (-4 *4 (-1090)) (-4 *5 (-1090))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-953 *5)) (-4 *5 (-1047)) (-5 *2 (-242 *4 *5)) (-5 *1 (-945 *4 *5)) (-14 *4 (-634 (-1161)))))) 
+(((*1 *1 *1 *1 *2 *3) (-12 (-5 *2 (-944 *5)) (-5 *3 (-763)) (-4 *5 (-1047)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917))))) 
+(((*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-601 *3 *2)) (-4 *3 (-1090)) (-4 *3 (-842)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-842)))) ((*1 *2 *1) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-663 *3)) (-5 *1 (-888 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1231 *3)) (-4 *3 (-1195)))) ((*1 *2 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *3 *4 *5 *6 *7 *6) (|partial| -12 (-5 *5 (-2 (|:| |contp| *3) (|:| -3276 (-634 (-2 (|:| |irr| *10) (|:| -3959 (-568))))))) (-5 *6 (-634 *3)) (-5 *7 (-634 *8)) (-4 *8 (-842)) (-4 *3 (-301)) (-4 *10 (-950 *3 *9 *8)) (-4 *9 (-788)) (-5 *2 (-2 (|:| |polfac| (-634 *10)) (|:| |correct| *3) (|:| |corrfact| (-634 (-1157 *3))))) (-5 *1 (-617 *8 *9 *3 *10)) (-5 *4 (-634 (-1157 *3)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1143)) (-5 *3 (-766)) (-5 *1 (-123))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-301) (-150))) (-4 *4 (-13 (-842) (-609 (-1161)))) (-4 *5 (-788)) (-5 *1 (-924 *3 *4 *5 *2)) (-4 *2 (-950 *3 *5 *4))))) 
-(((*1 *1) (-5 *1 (-158)))) 
-(((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-169 (-381)))) (-5 *1 (-328)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-381))) (-5 *1 (-328)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-568))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-169 (-381))))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-381)))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-568)))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-169 (-381))))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-381)))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-568)))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-169 (-381)))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-381))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-568))) (-5 *1 (-328)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-683))) (-5 *1 (-328)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-688))) (-5 *1 (-328)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-690))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-683)))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-688)))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-690)))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-683)))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-688)))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-690)))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-683))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-688))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-690))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-683))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-688))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-690))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-683))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-688))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-690))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1143)) (-5 *1 (-328)))) ((*1 *1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *1 *1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1141 *3)) (-4 *3 (-1195)))) ((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1191 *3)) (-4 *3 (-975))))) 
-(((*1 *1 *2 *2) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181)))))) 
+(((*1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1247))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-568)) (-5 *3 (-763)) (-5 *1 (-565))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-568)) (-4 *1 (-62 *4 *3 *5)) (-4 *4 (-1195)) (-4 *3 (-375 *4)) (-4 *5 (-375 *4))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-121))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1244 *5))) (-5 *4 (-568)) (-5 *2 (-1244 *5)) (-5 *1 (-1029 *5)) (-4 *5 (-365)) (-4 *5 (-370)) (-4 *5 (-1047))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-399))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-242 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-1047)) (-5 *2 (-492 *4 *5)) (-5 *1 (-945 *4 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-634 *10)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-917)) (-5 *5 (-634 *9)) (-4 *9 (-971 *6)) (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *4 (-950 *6 *8 (-852 *7))) (-4 *8 (-230 (-1699 *7) (-763))) (-4 *10 (-641 *6)) (-4 *11 (-920 *6 *10)) (-4 *12 (-235 *11)) (-4 *13 (-536 *6 *7 *4 *8 *9 *10 *11 *12 *15)) (-4 *15 (-117)) (-5 *2 (-1249)) (-5 *1 (-556 *6 *7 *4 *8 *9 *10 *11 *12 *13 *14 *15)) (-4 *14 (-258 *13)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-634 (-922 *4))) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-634 (-921 *4))) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-310 *4)) (-5 *1 (-180 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 (-169 *4)))))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3)))))) 
-(((*1 *1 *1 *2) (-12 (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39)))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1168 (-634 *4))) (-4 *4 (-842)) (-5 *2 (-634 (-634 *4))) (-5 *1 (-1167 *4))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1047))))) 
 (((*1 *1 *1) (-4 *1 (-39))) ((*1 *1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) ((*1 *1 *1) (-5 *1 (-123))) ((*1 *1 *1) (-5 *1 (-171))) ((*1 *1 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *1 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) ((*1 *1 *1) (-4 *1 (-550))) ((*1 *1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) ((*1 *1 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) ((*1 *1 *1) (-12 (-4 *1 (-1122 *2)) (-4 *2 (-1047)))) ((*1 *1 *1) (-12 (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) ((*1 *1 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-910 *2)) (-4 *2 (-301))))) 
-(((*1 *2 *1) (|partial| -12 (-5 *2 (-1108)) (-5 *1 (-113)))) ((*1 *2 *1) (|partial| -12 (-5 *1 (-367 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-1143)) (-5 *1 (-1177))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-995 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 *2 *2)) (-5 *1 (-671 *2)) (-4 *2 (-1090)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-634 *5) (-634 *5))) (-5 *4 (-568)) (-5 *2 (-634 *5)) (-5 *1 (-671 *5)) (-4 *5 (-1090))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1 (-215) (-215) (-215) (-215))) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-1 (-215) (-215) (-215))) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *1 (-256))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-150)) (-4 *3 (-301)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-420 (-1157 *1))) (-5 *1 (-310 *4)) (-5 *3 (-1157 *1)) (-4 *4 (-453)) (-4 *4 (-558)) (-4 *4 (-842)))) ((*1 *2 *3) (-12 (-4 *1 (-904)) (-5 *2 (-420 (-1157 *1))) (-5 *3 (-1157 *1))))) 
+(((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-989 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-1097 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7))))) 
+(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1 *7 *7)) (-5 *5 (-634 (-409 *7))) (-4 *7 (-1219 *6)) (-5 *3 (-409 *7)) (-4 *6 (-365)) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-578 *6 *7))))) 
+(((*1 *2 *3 *4) (-12 (-4 *4 (-365)) (-5 *2 (-634 (-1141 *4))) (-5 *1 (-280 *4 *5)) (-5 *3 (-1141 *4)) (-4 *5 (-1234 *4))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-310 *4)) (-5 *1 (-180 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 (-169 *4)))))) ((*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) ((*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3)))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *4)))) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *3)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-978 *4 *5 *6 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) ((*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 (-634 *7) (-634 *7))) (-5 *2 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-978 *4 *5 *6 *7))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-2 (|:| -1374 *5) (|:| -2785 *5)))) (-5 *1 (-802 *4 *5 *3 *6)) (-4 *3 (-646 *5)) (-4 *6 (-646 (-409 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *4 (-1219 *5)) (-5 *2 (-634 (-2 (|:| -1374 *4) (|:| -2785 *4)))) (-5 *1 (-802 *5 *4 *3 *6)) (-4 *3 (-646 *4)) (-4 *6 (-646 (-409 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-2 (|:| -1374 *5) (|:| -2785 *5)))) (-5 *1 (-802 *4 *5 *6 *3)) (-4 *6 (-646 *5)) (-4 *3 (-646 (-409 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *4 (-1219 *5)) (-5 *2 (-634 (-2 (|:| -1374 *4) (|:| -2785 *4)))) (-5 *1 (-802 *5 *4 *6 *3)) (-4 *6 (-646 *4)) (-4 *3 (-646 (-409 *4)))))) 
 (((*1 *1 *2 *1) (-12 (-5 *1 (-634 *2)) (-4 *2 (-1195)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-1141 *2)) (-4 *2 (-1195))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-665 *3)) (-4 *3 (-1195)) (-5 *2 (-121))))) 
-(((*1 *1 *1) (-4 *1 (-550)))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))) (-5 *1 (-444 *4 *3 *2)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-53))) (-5 *2 (-420 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1219 (-53))))) ((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1219 (-53))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-53))) (-4 *5 (-842)) (-4 *6 (-788)) (-5 *2 (-420 *3)) (-5 *1 (-47 *5 *6 *3)) (-4 *3 (-950 (-53) *6 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-53))) (-4 *5 (-842)) (-4 *6 (-788)) (-4 *7 (-950 (-53) *6 *5)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-47 *5 *6 *7)) (-5 *3 (-1157 *7)))) ((*1 *2 *3) (-12 (-4 *4 (-301)) (-5 *2 (-420 *3)) (-5 *1 (-167 *4 *3)) (-4 *3 (-1219 (-169 *4))))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-121)) (-4 *4 (-13 (-365) (-840))) (-5 *2 (-420 *3)) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) ((*1 *2 *3 *4) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-420 *3)) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-420 *3)) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-207 *4 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *3 *4) (-12 (-4 *4 (-854)) (-5 *2 (-420 (-1157 *4))) (-5 *1 (-315 *4)) (-5 *3 (-1157 *4)))) ((*1 *2 *3 *4) (-12 (-4 *4 (-859)) (-5 *2 (-420 (-1157 *4))) (-5 *1 (-317 *4)) (-5 *3 (-1157 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-344 *4 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-763))) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-763))) (-5 *5 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3) (-12 (-5 *2 (-420 (-169 (-568)))) (-5 *1 (-447)) (-5 *3 (-169 (-568))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $)) (-15 -1305 ((-3 $ "failed") (-1161)))))) (-4 *5 (-788)) (-4 *7 (-558)) (-5 *2 (-420 *3)) (-5 *1 (-458 *4 *5 *6 *7 *3)) (-4 *6 (-558)) (-4 *3 (-950 *7 *5 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-301)) (-5 *2 (-420 (-1157 *4))) (-5 *1 (-460 *4)) (-5 *3 (-1157 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-420 *6) *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-4 *7 (-13 (-365) (-150) (-714 *5 *6))) (-5 *2 (-420 *3)) (-5 *1 (-503 *5 *6 *7 *3)) (-4 *3 (-1219 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-420 (-1157 *7)) (-1157 *7))) (-4 *7 (-13 (-301) (-150))) (-4 *5 (-842)) (-4 *6 (-788)) (-5 *2 (-420 *3)) (-5 *1 (-545 *5 *6 *7 *3)) (-4 *3 (-950 *7 *6 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-420 (-1157 *7)) (-1157 *7))) (-4 *7 (-13 (-301) (-150))) (-4 *5 (-842)) (-4 *6 (-788)) (-4 *8 (-950 *7 *6 *5)) (-5 *2 (-420 (-1157 *8))) (-5 *1 (-545 *5 *6 *7 *8)) (-5 *3 (-1157 *8)))) ((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-561 *3)) (-4 *3 (-550)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-643 (-409 *6)))) (-5 *1 (-647 *5 *6)) (-5 *3 (-643 (-409 *6))))) ((*1 *2 *3) (-12 (-4 *4 (-27)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-643 (-409 *5)))) (-5 *1 (-647 *4 *5)) (-5 *3 (-643 (-409 *5))))) ((*1 *2 *3) (-12 (-5 *3 (-814 *4)) (-4 *4 (-842)) (-5 *2 (-634 (-663 *4))) (-5 *1 (-663 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-5 *2 (-634 *3)) (-5 *1 (-685 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-842)) (-4 *5 (-788)) (-4 *6 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-687 *4 *5 *6 *3)) (-4 *3 (-950 *6 *5 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-842)) (-4 *5 (-788)) (-4 *6 (-350)) (-4 *7 (-950 *6 *5 *4)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-687 *4 *5 *6 *7)) (-5 *3 (-1157 *7)))) ((*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $)) (-15 -1305 ((-3 $ "failed") (-1161)))))) (-4 *6 (-301)) (-5 *2 (-420 *3)) (-5 *1 (-720 *4 *5 *6 *3)) (-4 *3 (-950 (-953 *6) *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $))))) (-4 *6 (-558)) (-5 *2 (-420 *3)) (-5 *1 (-722 *4 *5 *6 *3)) (-4 *3 (-950 (-409 (-953 *6)) *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-13 (-301) (-150))) (-5 *2 (-420 *3)) (-5 *1 (-723 *4 *5 *6 *3)) (-4 *3 (-950 (-409 *6) *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-842)) (-4 *5 (-788)) (-4 *6 (-13 (-301) (-150))) (-5 *2 (-420 *3)) (-5 *1 (-731 *4 *5 *6 *3)) (-4 *3 (-950 *6 *5 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-842)) (-4 *5 (-788)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-950 *6 *5 *4)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-731 *4 *5 *6 *7)) (-5 *3 (-1157 *7)))) ((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-1007 *3)) (-4 *3 (-1219 (-409 (-568)))))) ((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-1040 *3)) (-4 *3 (-1219 (-409 (-953 (-568))))))) ((*1 *2 *3) (-12 (-4 *4 (-1219 (-409 (-568)))) (-4 *5 (-13 (-365) (-150) (-714 (-409 (-568)) *4))) (-5 *2 (-420 *3)) (-5 *1 (-1072 *4 *5 *3)) (-4 *3 (-1219 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-1219 (-409 (-953 (-568))))) (-4 *5 (-13 (-365) (-150) (-714 (-409 (-953 (-568))) *4))) (-5 *2 (-420 *3)) (-5 *1 (-1074 *4 *5 *3)) (-4 *3 (-1219 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-453)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-420 (-1157 (-409 *7)))) (-5 *1 (-1156 *4 *5 *6 *7)) (-5 *3 (-1157 (-409 *7))))) ((*1 *2 *1) (-12 (-5 *2 (-420 *1)) (-4 *1 (-1199)))) ((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-1208 *3)) (-4 *3 (-1219 (-568)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1 (-121) *8))) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-2 (|:| |goodPols| (-634 *8)) (|:| |badPols| (-634 *8)))) (-5 *1 (-978 *5 *6 *7 *8)) (-5 *4 (-634 *8))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-5 *2 (-121))))) 
-(((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-239 *2)) (-4 *2 (-1195)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-277 *2)) (-4 *2 (-1195)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-277 *2)) (-4 *2 (-1195)))) ((*1 *1 *1 *2) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) ((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-296)))) ((*1 *1 *1) (-4 *1 (-296))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) ((*1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1047)) (-5 *2 (-1244 *3)) (-5 *1 (-702 *3 *4)) (-4 *4 (-1219 *3))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-634 (-288 *4))) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *2 *2)) (-4 *5 (-365)) (-4 *6 (-1219 (-409 *2))) (-4 *2 (-1219 *5)) (-5 *1 (-206 *5 *2 *6 *3)) (-4 *3 (-340 *5 *2 *6))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-53))) (-5 *2 (-420 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1219 (-53))))) ((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-44 *3)) (-4 *3 (-1219 (-53))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-53))) (-4 *5 (-842)) (-4 *6 (-788)) (-5 *2 (-420 *3)) (-5 *1 (-47 *5 *6 *3)) (-4 *3 (-950 (-53) *6 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-53))) (-4 *5 (-842)) (-4 *6 (-788)) (-4 *7 (-950 (-53) *6 *5)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-47 *5 *6 *7)) (-5 *3 (-1157 *7)))) ((*1 *2 *3) (-12 (-4 *4 (-301)) (-5 *2 (-420 *3)) (-5 *1 (-167 *4 *3)) (-4 *3 (-1219 (-169 *4))))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-121)) (-4 *4 (-13 (-365) (-840))) (-5 *2 (-420 *3)) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) ((*1 *2 *3 *4) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-420 *3)) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-420 *3)) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-207 *4 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *3 *4) (-12 (-4 *4 (-854)) (-5 *2 (-420 (-1157 *4))) (-5 *1 (-315 *4)) (-5 *3 (-1157 *4)))) ((*1 *2 *3 *4) (-12 (-4 *4 (-859)) (-5 *2 (-420 (-1157 *4))) (-5 *1 (-317 *4)) (-5 *3 (-1157 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-344 *4 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-763))) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-763))) (-5 *5 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3) (-12 (-5 *2 (-420 (-169 (-568)))) (-5 *1 (-447)) (-5 *3 (-169 (-568))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $)) (-15 -3325 ((-3 $ "failed") (-1161)))))) (-4 *5 (-788)) (-4 *7 (-558)) (-5 *2 (-420 *3)) (-5 *1 (-458 *4 *5 *6 *7 *3)) (-4 *6 (-558)) (-4 *3 (-950 *7 *5 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-301)) (-5 *2 (-420 (-1157 *4))) (-5 *1 (-460 *4)) (-5 *3 (-1157 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-420 *6) *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-4 *7 (-13 (-365) (-150) (-714 *5 *6))) (-5 *2 (-420 *3)) (-5 *1 (-503 *5 *6 *7 *3)) (-4 *3 (-1219 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-420 (-1157 *7)) (-1157 *7))) (-4 *7 (-13 (-301) (-150))) (-4 *5 (-842)) (-4 *6 (-788)) (-5 *2 (-420 *3)) (-5 *1 (-545 *5 *6 *7 *3)) (-4 *3 (-950 *7 *6 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-420 (-1157 *7)) (-1157 *7))) (-4 *7 (-13 (-301) (-150))) (-4 *5 (-842)) (-4 *6 (-788)) (-4 *8 (-950 *7 *6 *5)) (-5 *2 (-420 (-1157 *8))) (-5 *1 (-545 *5 *6 *7 *8)) (-5 *3 (-1157 *8)))) ((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-561 *3)) (-4 *3 (-550)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-643 (-409 *6)))) (-5 *1 (-647 *5 *6)) (-5 *3 (-643 (-409 *6))))) ((*1 *2 *3) (-12 (-4 *4 (-27)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-643 (-409 *5)))) (-5 *1 (-647 *4 *5)) (-5 *3 (-643 (-409 *5))))) ((*1 *2 *3) (-12 (-5 *3 (-814 *4)) (-4 *4 (-842)) (-5 *2 (-634 (-663 *4))) (-5 *1 (-663 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-5 *2 (-634 *3)) (-5 *1 (-685 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-842)) (-4 *5 (-788)) (-4 *6 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-687 *4 *5 *6 *3)) (-4 *3 (-950 *6 *5 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-842)) (-4 *5 (-788)) (-4 *6 (-350)) (-4 *7 (-950 *6 *5 *4)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-687 *4 *5 *6 *7)) (-5 *3 (-1157 *7)))) ((*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $)) (-15 -3325 ((-3 $ "failed") (-1161)))))) (-4 *6 (-301)) (-5 *2 (-420 *3)) (-5 *1 (-720 *4 *5 *6 *3)) (-4 *3 (-950 (-953 *6) *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $))))) (-4 *6 (-558)) (-5 *2 (-420 *3)) (-5 *1 (-722 *4 *5 *6 *3)) (-4 *3 (-950 (-409 (-953 *6)) *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-13 (-301) (-150))) (-5 *2 (-420 *3)) (-5 *1 (-723 *4 *5 *6 *3)) (-4 *3 (-950 (-409 *6) *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-842)) (-4 *5 (-788)) (-4 *6 (-13 (-301) (-150))) (-5 *2 (-420 *3)) (-5 *1 (-731 *4 *5 *6 *3)) (-4 *3 (-950 *6 *5 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-842)) (-4 *5 (-788)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-950 *6 *5 *4)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-731 *4 *5 *6 *7)) (-5 *3 (-1157 *7)))) ((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-1007 *3)) (-4 *3 (-1219 (-409 (-568)))))) ((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-1040 *3)) (-4 *3 (-1219 (-409 (-953 (-568))))))) ((*1 *2 *3) (-12 (-4 *4 (-1219 (-409 (-568)))) (-4 *5 (-13 (-365) (-150) (-714 (-409 (-568)) *4))) (-5 *2 (-420 *3)) (-5 *1 (-1072 *4 *5 *3)) (-4 *3 (-1219 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-1219 (-409 (-953 (-568))))) (-4 *5 (-13 (-365) (-150) (-714 (-409 (-953 (-568))) *4))) (-5 *2 (-420 *3)) (-5 *1 (-1074 *4 *5 *3)) (-4 *3 (-1219 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-453)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-420 (-1157 (-409 *7)))) (-5 *1 (-1156 *4 *5 *6 *7)) (-5 *3 (-1157 (-409 *7))))) ((*1 *2 *1) (-12 (-5 *2 (-420 *1)) (-4 *1 (-1199)))) ((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-1208 *3)) (-4 *3 (-1219 (-568)))))) 
+(((*1 *2) (-12 (-5 *2 (-2 (|:| -3544 (-634 *3)) (|:| -3043 (-634 *3)))) (-5 *1 (-1196 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-1165))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-634 *3)) (-4 *3 (-950 *4 *6 *5)) (-4 *4 (-453)) (-4 *5 (-842)) (-4 *6 (-788)) (-5 *1 (-988 *4 *5 *6 *3))))) 
 (((*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) ((*1 *1 *1) (-5 *1 (-850))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-4 *1 (-1087 *3)))) ((*1 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1035))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-324 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-4 *4 (-1047)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-230 *5 (-763))) (-14 *5 (-763)) (-5 *1 (-908 *3 *2 *4 *5)) (-4 *2 (-324 *3 *4))))) 
-(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-607 *1)) (-4 *1 (-432 *4)) (-4 *4 (-842)) (-4 *4 (-558)) (-5 *2 (-409 (-1157 *1))))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-607 *3)) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-1157 (-409 (-1157 *3)))) (-5 *1 (-564 *6 *3 *7)) (-5 *5 (-1157 *3)) (-4 *7 (-1090)))) ((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *2 (-1157 *4)) (-5 *1 (-908 *4 *3 *5 *6)) (-4 *3 (-324 *4 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1240 *5)) (-14 *5 (-1161)) (-4 *6 (-1047)) (-5 *2 (-1216 *5 (-953 *6))) (-5 *1 (-948 *5 *6)) (-5 *3 (-953 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-950 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-1157 *3)))) ((*1 *2 *1 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-1157 *1)) (-4 *1 (-950 *4 *5 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-788)) (-4 *4 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *5 *4)) (-5 *2 (-409 (-1157 *3))) (-5 *1 (-951 *5 *4 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2745 ($ *7)) (-15 -2317 (*7 $)) (-15 -2324 (*7 $))))))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-1157 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2745 ($ *7)) (-15 -2317 (*7 $)) (-15 -2324 (*7 $))))) (-4 *7 (-950 *6 *5 *4)) (-4 *5 (-788)) (-4 *4 (-842)) (-4 *6 (-1047)) (-5 *1 (-951 *5 *4 *6 *7 *3)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-558)) (-5 *2 (-409 (-1157 (-409 (-953 *5))))) (-5 *1 (-1042 *5)) (-5 *3 (-409 (-953 *5)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-763))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1082 (-835 *3))) (-4 *3 (-13 (-1181) (-959) (-29 *5))) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 *3)) (|:| |f2| (-634 (-835 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-209 *5 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1082 (-835 *3))) (-5 *5 (-1143)) (-4 *3 (-13 (-1181) (-959) (-29 *6))) (-4 *6 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 *3)) (|:| |f2| (-634 (-835 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-209 *6 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1082 (-835 (-310 *5)))) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 (-310 *5))) (|:| |f2| (-634 (-835 (-310 *5)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-210 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-409 (-953 *6))) (-5 *4 (-1082 (-835 (-310 *6)))) (-5 *5 (-1143)) (-4 *6 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 (-310 *6))) (|:| |f2| (-634 (-835 (-310 *6)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-210 *6)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1082 (-835 (-409 (-953 *5))))) (-5 *3 (-409 (-953 *5))) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 (-310 *5))) (|:| |f2| (-634 (-835 (-310 *5)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-210 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1082 (-835 (-409 (-953 *6))))) (-5 *5 (-1143)) (-5 *3 (-409 (-953 *6))) (-4 *6 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 (-310 *6))) (|:| |f2| (-634 (-835 (-310 *6)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-210 *6)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 *3 (-634 *3))) (-5 *1 (-430 *5 *3)) (-4 *3 (-13 (-1181) (-959) (-29 *5))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-479 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1084 (-835 (-381)))) (-5 *5 (-381)) (-5 *6 (-1059)) (-5 *2 (-1035)) (-5 *1 (-569)))) ((*1 *2 *3) (-12 (-5 *3 (-761)) (-5 *2 (-1035)) (-5 *1 (-569)))) ((*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1084 (-835 (-381)))) (-5 *5 (-381)) (-5 *2 (-1035)) (-5 *1 (-569)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1084 (-835 (-381)))) (-5 *5 (-381)) (-5 *2 (-1035)) (-5 *1 (-569)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1084 (-835 (-381)))) (-5 *2 (-1035)) (-5 *1 (-569)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-634 (-1084 (-835 (-381))))) (-5 *2 (-1035)) (-5 *1 (-569)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-634 (-1084 (-835 (-381))))) (-5 *5 (-381)) (-5 *2 (-1035)) (-5 *1 (-569)))) ((*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-634 (-1084 (-835 (-381))))) (-5 *5 (-381)) (-5 *2 (-1035)) (-5 *1 (-569)))) ((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-634 (-1084 (-835 (-381))))) (-5 *5 (-381)) (-5 *6 (-1059)) (-5 *2 (-1035)) (-5 *1 (-569)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-835 (-381)))) (-5 *5 (-1143)) (-5 *2 (-1035)) (-5 *1 (-569)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-835 (-381)))) (-5 *5 (-1161)) (-5 *2 (-1035)) (-5 *1 (-569)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-568)))) (-4 *5 (-1219 *4)) (-5 *2 (-585 (-409 *5))) (-5 *1 (-572 *4 *5)) (-5 *3 (-409 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-150)) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *2 (-3 (-310 *5) (-634 (-310 *5)))) (-5 *1 (-588 *5)))) ((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-730 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-842)) (-4 *3 (-43 (-409 (-568)))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-953 *3)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)))) ((*1 *1 *1 *2 *3) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-4 *2 (-842)) (-5 *1 (-1114 *3 *2 *4)) (-4 *4 (-950 *3 (-534 *2) *2)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1151 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1158 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1159 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *1 (-1190 *3)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 (QUOTE |x|))) (-5 *1 (-1201 *3)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-2198 (-12 (-5 *2 (-1161)) (-4 *1 (-1203 *3)) (-4 *3 (-1047)) (-12 (-4 *3 (-29 (-568))) (-4 *3 (-959)) (-4 *3 (-1181)) (-4 *3 (-43 (-409 (-568)))))) (-12 (-5 *2 (-1161)) (-4 *1 (-1203 *3)) (-4 *3 (-1047)) (-12 (|has| *3 (-15 -2055 ((-634 *2) *3))) (|has| *3 (-15 -3837 (*3 *3 *2))) (-4 *3 (-43 (-409 (-568)))))))) ((*1 *1 *1) (-12 (-4 *1 (-1203 *2)) (-4 *2 (-1047)) (-4 *2 (-43 (-409 (-568)))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1207 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-43 (-409 (-568)))))) ((*1 *1 *1 *2) (-2198 (-12 (-5 *2 (-1161)) (-4 *1 (-1224 *3)) (-4 *3 (-1047)) (-12 (-4 *3 (-29 (-568))) (-4 *3 (-959)) (-4 *3 (-1181)) (-4 *3 (-43 (-409 (-568)))))) (-12 (-5 *2 (-1161)) (-4 *1 (-1224 *3)) (-4 *3 (-1047)) (-12 (|has| *3 (-15 -2055 ((-634 *2) *3))) (|has| *3 (-15 -3837 (*3 *3 *2))) (-4 *3 (-43 (-409 (-568)))))))) ((*1 *1 *1) (-12 (-4 *1 (-1224 *2)) (-4 *2 (-1047)) (-4 *2 (-43 (-409 (-568)))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1228 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *1 *2) (-2198 (-12 (-5 *2 (-1161)) (-4 *1 (-1234 *3)) (-4 *3 (-1047)) (-12 (-4 *3 (-29 (-568))) (-4 *3 (-959)) (-4 *3 (-1181)) (-4 *3 (-43 (-409 (-568)))))) (-12 (-5 *2 (-1161)) (-4 *1 (-1234 *3)) (-4 *3 (-1047)) (-12 (|has| *3 (-15 -2055 ((-634 *2) *3))) (|has| *3 (-15 -3837 (*3 *3 *2))) (-4 *3 (-43 (-409 (-568)))))))) ((*1 *1 *1) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1047)) (-4 *2 (-43 (-409 (-568)))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-665 *3)) (-4 *3 (-1195)) (-5 *2 (-763))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3)))) ((*1 *2 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-1219 (-409 (-568)))) (-5 *1 (-909 *3 *2)) (-4 *2 (-1219 (-409 *3)))))) 
-(((*1 *1 *1) (-4 *1 (-620))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-334 *5 *6 *7 *8)) (-4 *5 (-432 *4)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-4 *8 (-340 *5 *6 *7)) (-4 *4 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-2 (|:| -1844 (-763)) (|:| -1866 *8))) (-5 *1 (-906 *4 *5 *6 *7 *8)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-334 (-409 (-568)) *4 *5 *6)) (-4 *4 (-1219 (-409 (-568)))) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 (-409 (-568)) *4 *5)) (-5 *2 (-2 (|:| -1844 (-763)) (|:| -1866 *6))) (-5 *1 (-907 *4 *5 *6))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-568)) (-5 *4 (-420 *2)) (-4 *2 (-950 *7 *5 *6)) (-5 *1 (-732 *5 *6 *7 *2)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-301))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-36 *3 *4)) (-4 *4 (-432 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-763)) (-5 *1 (-123)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-123)))) ((*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *4)) (-4 *4 (-432 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-123)) (-5 *1 (-163)))) ((*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *4)) (-4 *4 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-5 *2 (-123)) (-5 *1 (-295 *3)) (-4 *3 (-296)))) ((*1 *2 *2) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) ((*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *4 (-842)) (-5 *1 (-431 *3 *4)) (-4 *3 (-432 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *4)) (-4 *4 (-432 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-123)) (-5 *1 (-607 *3)) (-4 *3 (-842)))) ((*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *4)) (-4 *4 (-13 (-432 *3) (-1002) (-1181)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-607 *1)) (-4 *1 (-432 *4)) (-4 *4 (-842)) (-4 *4 (-558)) (-5 *2 (-409 (-1157 *1))))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-607 *3)) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-1157 (-409 (-1157 *3)))) (-5 *1 (-564 *6 *3 *7)) (-5 *5 (-1157 *3)) (-4 *7 (-1090)))) ((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *2 (-1157 *4)) (-5 *1 (-908 *4 *3 *5 *6)) (-4 *3 (-324 *4 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1240 *5)) (-14 *5 (-1161)) (-4 *6 (-1047)) (-5 *2 (-1216 *5 (-953 *6))) (-5 *1 (-948 *5 *6)) (-5 *3 (-953 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-950 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-1157 *3)))) ((*1 *2 *1 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-1157 *1)) (-4 *1 (-950 *4 *5 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-788)) (-4 *4 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *5 *4)) (-5 *2 (-409 (-1157 *3))) (-5 *1 (-951 *5 *4 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2747 ($ *7)) (-15 -2319 (*7 $)) (-15 -2326 (*7 $))))))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-1157 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2747 ($ *7)) (-15 -2319 (*7 $)) (-15 -2326 (*7 $))))) (-4 *7 (-950 *6 *5 *4)) (-4 *5 (-788)) (-4 *4 (-842)) (-4 *6 (-1047)) (-5 *1 (-951 *5 *4 *6 *7 *3)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-558)) (-5 *2 (-409 (-1157 (-409 (-953 *5))))) (-5 *1 (-1042 *5)) (-5 *3 (-409 (-953 *5)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-4 *3 (-558)) (-5 *2 (-1157 *3))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1108)) (-5 *1 (-328))))) 
+(((*1 *2 *2 *3 *4) (-12 (-5 *2 (-1244 *5)) (-5 *3 (-763)) (-5 *4 (-1108)) (-4 *5 (-350)) (-5 *1 (-532 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-816)) (-5 *2 (-57)) (-5 *1 (-826))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *7)) (|:| |neqzro| (-634 *7)) (|:| |wcond| (-634 (-953 *4))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *4)))) (|:| -2588 (-634 (-1244 (-409 (-953 *4)))))))))) (-5 *1 (-924 *4 *5 *6 *7)) (-4 *7 (-950 *4 *6 *5))))) 
 (((*1 *2 *3 *3 *3 *3 *4 *3 *5 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-742))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-256)))) ((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-953 (-568))))) (-5 *2 (-634 (-679 (-310 (-568))))) (-5 *1 (-1031))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) ((*1 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *1 *1) (-4 *1 (-1124)))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-634 *1)) (|has| *1 (-6 -4520)) (-4 *1 (-1010 *3)) (-4 *3 (-1195))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-953 (-568))))) (-5 *2 (-634 (-310 (-568)))) (-5 *1 (-1031))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-5 *2 (-121))))) 
+(((*1 *2 *1 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1))) (-4 *1 (-301)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2707 *1))) (-4 *1 (-301))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-607 *1))) (-4 *1 (-296))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-763)) (-4 *6 (-1090)) (-4 *3 (-895 *6)) (-5 *2 (-679 *3)) (-5 *1 (-681 *6 *3 *7 *4)) (-4 *7 (-375 *3)) (-4 *4 (-13 (-375 *6) (-10 -7 (-6 -4521))))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-21)) (-4 *2 (-1195))))) 
+(((*1 *2 *3 *3) (-12 (-5 *2 (-634 *3)) (-5 *1 (-961 *3)) (-4 *3 (-550))))) 
 (((*1 *2 *3 *4 *2) (-12 (-5 *4 (-1 *2 *2)) (-4 *2 (-637 *5)) (-4 *5 (-1047)) (-5 *1 (-59 *5 *2 *3)) (-4 *3 (-844 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-679 *3)) (-4 *1 (-419 *3)) (-4 *3 (-172)))) ((*1 *2 *1 *2 *2) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)))) ((*1 *2 *3 *2 *2 *4 *5) (-12 (-5 *4 (-101 *2)) (-5 *5 (-1 *2 *2)) (-4 *2 (-1047)) (-5 *1 (-845 *2 *3)) (-4 *3 (-844 *2))))) 
+(((*1 *2 *2) (|partial| -12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *1 *1 *1) (-4 *1 (-1124)))) 
 (((*1 *2 *3 *3 *3 *3 *4 *4 *4 *5 *4 *6 *7) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-1143)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-87 PDEF)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-88 BNDY)))) (-5 *2 (-1035)) (-5 *1 (-742))))) 
-(((*1 *2 *3 *4 *3 *5 *5 *5 *5 *5) (|partial| -12 (-5 *5 (-121)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *9 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| -1853 (-634 *9)) (|:| -3001 *4) (|:| |ineq| (-634 *9)))) (-5 *1 (-989 *6 *7 *8 *9 *4)) (-5 *3 (-634 *9)) (-4 *4 (-1066 *6 *7 *8 *9)))) ((*1 *2 *3 *4 *3 *5 *5 *5 *5 *5) (|partial| -12 (-5 *5 (-121)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *9 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| -1853 (-634 *9)) (|:| -3001 *4) (|:| |ineq| (-634 *9)))) (-5 *1 (-1097 *6 *7 *8 *9 *4)) (-5 *3 (-634 *9)) (-4 *4 (-1066 *6 *7 *8 *9))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-1023 *3)) (-4 *3 (-13 (-840) (-365) (-1021))))) ((*1 *2 *3 *1 *2) (-12 (-4 *2 (-13 (-840) (-365))) (-5 *1 (-1057 *2 *3)) (-4 *3 (-1219 *2)))) ((*1 *2 *3 *1 *2) (-12 (-4 *1 (-1063 *2 *3)) (-4 *2 (-13 (-840) (-365))) (-4 *3 (-1219 *2))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 *7 *5 *6)) (-5 *1 (-691 *4 *5 *6 *7)) (-4 *4 (-609 (-541))) (-4 *5 (-1195)) (-4 *6 (-1195)) (-4 *7 (-1195))))) 
 (((*1 *2 *3) (-12 (-5 *2 (-169 (-381))) (-5 *1 (-780 *3)) (-4 *3 (-609 (-381))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-5 *2 (-169 (-381))) (-5 *1 (-780 *3)) (-4 *3 (-609 (-381))))) ((*1 *2 *3) (-12 (-5 *3 (-169 *4)) (-4 *4 (-172)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-169 *5)) (-5 *4 (-917)) (-4 *5 (-172)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-953 (-169 *4))) (-4 *4 (-172)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-953 (-169 *5))) (-5 *4 (-917)) (-4 *5 (-172)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-953 *4)) (-4 *4 (-1047)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-953 *5)) (-5 *4 (-917)) (-4 *5 (-1047)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-558)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-409 (-953 (-169 *4)))) (-4 *4 (-558)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 (-169 *5)))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-310 *4)) (-4 *4 (-558)) (-4 *4 (-842)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-310 *5)) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-842)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-310 (-169 *4))) (-4 *4 (-558)) (-4 *4 (-842)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-310 (-169 *5))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-842)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5))))) 
-(((*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-1067 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6)))) ((*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-1098 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 (-1157 (-1157 *4)))) (-5 *1 (-1194 *4)) (-5 *3 (-1157 (-1157 *4)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1111 *3 *4 *2 *5)) (-4 *4 (-1047)) (-4 *5 (-230 *3 *4)) (-4 *2 (-230 *3 *4))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 (-2 (|:| |lcmfij| *4) (|:| |totdeg| (-763)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *4 (-788)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-453)) (-4 *5 (-842)) (-5 *1 (-450 *3 *4 *5 *6))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
+(((*1 *2 *2 *2 *2) (-12 (-5 *2 (-409 (-1157 (-310 *3)))) (-4 *3 (-13 (-558) (-842))) (-5 *1 (-1118 *3))))) 
+(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-798))))) 
+(((*1 *2) (-12 (-4 *3 (-172)) (-5 *2 (-1244 *1)) (-4 *1 (-369 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-665 *3)) (-4 *3 (-1195)) (-5 *2 (-121))))) 
 (((*1 *2 *3 *3 *4 *4 *5 *5 *3 *3 *4 *4 *5 *5 *3 *3 *4 *4 *5 *5 *3 *4 *4 *4 *6 *4) (-12 (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-666 (-215))) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-742))))) 
 (((*1 *2 *3 *2 *3) (-12 (-5 *2 (-439)) (-5 *3 (-1161)) (-5 *1 (-1164)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-439)) (-5 *3 (-1161)) (-5 *1 (-1164)))) ((*1 *2 *3 *2 *4 *1) (-12 (-5 *2 (-439)) (-5 *3 (-634 (-1161))) (-5 *4 (-1161)) (-5 *1 (-1164)))) ((*1 *2 *3 *2 *3 *1) (-12 (-5 *2 (-439)) (-5 *3 (-1161)) (-5 *1 (-1164)))) ((*1 *2 *3 *2 *1) (-12 (-5 *2 (-439)) (-5 *3 (-1161)) (-5 *1 (-1165)))) ((*1 *2 *3 *2 *1) (-12 (-5 *2 (-439)) (-5 *3 (-634 (-1161))) (-5 *1 (-1165))))) 
-(((*1 *1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-970 *3 *2)) (-4 *2 (-1219 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-558))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *5 "failed") *8)) (-5 *4 (-679 (-1157 *8))) (-4 *5 (-1047)) (-4 *8 (-1047)) (-4 *6 (-1219 *5)) (-5 *2 (-679 *6)) (-5 *1 (-510 *5 *6 *7 *8)) (-4 *7 (-1219 *6))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) *2)) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-763))))) 
-(((*1 *2) (-12 (-5 *2 (-1 *3 *3)) (-5 *1 (-533 *3)) (-4 *3 (-13 (-716) (-25)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-607 *1))) (-4 *1 (-296))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-917))) (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-325 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-525 *3 *4)) (-14 *4 (-568))))) 
-(((*1 *2 *1) (|partial| -12 (-5 *2 (-1161)) (-5 *1 (-607 *3)) (-4 *3 (-842))))) 
-(((*1 *2 *1 *1 *3) (-12 (-5 *3 (-1 (-121) *5 *5)) (-4 *5 (-13 (-1090) (-39))) (-5 *2 (-121)) (-5 *1 (-1125 *4 *5)) (-4 *4 (-13 (-1090) (-39)))))) 
-(((*1 *1 *2 *2 *3) (-12 (-5 *2 (-568)) (-5 *3 (-917)) (-5 *1 (-688)))) ((*1 *2 *2 *2 *3 *4) (-12 (-5 *2 (-679 *5)) (-5 *3 (-101 *5)) (-5 *4 (-1 *5 *5)) (-4 *5 (-365)) (-5 *1 (-979 *5))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-950 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-2 (|:| |poly| *3) (|:| |mult| *5))) (-5 *1 (-450 *5 *6 *7 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-4 *7 (-1219 (-409 *6))) (-5 *2 (-2 (|:| |answer| *3) (|:| -2577 *3))) (-5 *1 (-566 *5 *6 *7 *3)) (-4 *3 (-340 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| |answer| (-409 *6)) (|:| -2577 (-409 *6)) (|:| |specpart| (-409 *6)) (|:| |polypart| *6))) (-5 *1 (-567 *5 *6)) (-5 *3 (-409 *6))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-634 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-828 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-835 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *3 *4 *2 *2 *5) (|partial| -12 (-5 *2 (-835 *4)) (-5 *3 (-607 *4)) (-5 *5 (-121)) (-4 *4 (-13 (-1181) (-29 *6))) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-214 *6 *4))))) 
-(((*1 *1 *1 *1) (-5 *1 (-215))) ((*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-381))) (-5 *1 (-1039)))) ((*1 *1 *1 *1) (-4 *1 (-1124)))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-558)) (-4 *4 (-842)) (-5 *1 (-577 *4 *2)) (-4 *2 (-432 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1182 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) ((*1 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |k| (-1161)) (|:| |c| (-1264 *3))))) (-5 *1 (-1264 *3)) (-4 *3 (-1047)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |k| *3) (|:| |c| (-1266 *3 *4))))) (-5 *1 (-1266 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-1195)) (-5 *1 (-179 *3 *2)) (-4 *2 (-665 *3))))) 
-(((*1 *1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |cd| (-1143)) (|:| -3391 (-1143)))) (-5 *1 (-817))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164)))) ((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-1165))))) 
-(((*1 *2 *3 *4 *5 *6) (-12 (-5 *6 (-917)) (-4 *5 (-301)) (-4 *3 (-1219 *5)) (-5 *2 (-2 (|:| |plist| (-634 *3)) (|:| |modulo| *5))) (-5 *1 (-462 *5 *3)) (-5 *4 (-634 *3))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-14 *5 (-634 (-1161))) (-4 *3 (-950 *2 *6 (-852 *5))) (-4 *6 (-230 (-1697 *5) (-763))) (-4 *7 (-971 *2)) (-4 *8 (-641 *2)) (-4 *4 (-920 *2 *8)) (-4 *9 (-235 *4)) (-4 *10 (-536 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) ((*1 *2 *3 *3 *4) (|partial| -12 (-14 *5 (-634 (-1161))) (-4 *3 (-950 *2 *6 (-852 *5))) (-4 *6 (-230 (-1697 *5) (-763))) (-4 *7 (-971 *2)) (-4 *8 (-641 *2)) (-4 *4 (-920 *2 *8)) (-4 *9 (-235 *4)) (-4 *10 (-536 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 *6)) (-4 *6 (-950 *2 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-14 *5 (-634 (-1161))) (-4 *8 (-971 *2)) (-4 *9 (-641 *2)) (-4 *4 (-920 *2 *9)) (-4 *10 (-235 *4)) (-4 *11 (-536 *2 *5 *6 *7 *8 *9 *4 *10 *13)) (-4 *13 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *6 *7 *8 *9 *4 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-242 *5 *2)) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-242 *5 *2)) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 (-242 *5 *2))) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-242 *5 *2)) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-242 *5 *2)) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 (-242 *5 *2))) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117))))) 
-(((*1 *2 *1 *3 *3 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-666 *2)) (-4 *2 (-1090))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-634 *7)) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1699 *6) (-763))) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-5 *2 (-634 (-1244 *5))) (-5 *1 (-562 *5 *6 *7 *8 *9 *10 *11 *3)) (-4 *9 (-971 *5)) (-4 *3 (-235 *11))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-971 *3)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2 *2) (-12 (-5 *2 (-634 (-967 *3))) (-4 *3 (-350)) (-5 *1 (-867 *3 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2 *2) (-12 (-5 *2 (-634 (-966 *3))) (-4 *3 (-365)) (-5 *1 (-868 *3 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6))))) 
 (((*1 *1 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-420 *2)) (-4 *2 (-558))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-381)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-256))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-4 *5 (-365)) (-5 *2 (-634 (-1190 *5))) (-5 *1 (-1252 *5)) (-5 *4 (-1190 *5))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-4 *1 (-730 *4 *5)) (-4 *4 (-1047)) (-4 *5 (-842)) (-5 *2 (-953 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-730 *4 *5)) (-4 *4 (-1047)) (-4 *5 (-842)) (-5 *2 (-953 *4)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-4 *1 (-1234 *4)) (-4 *4 (-1047)) (-5 *2 (-953 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-1234 *4)) (-4 *4 (-1047)) (-5 *2 (-953 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-288 (-953 (-568)))) (-5 *2 (-2 (|:| |varOrder| (-634 (-1161))) (|:| |inhom| (-3 (-634 (-1244 (-763))) "failed")) (|:| |hom| (-634 (-1244 (-763)))))) (-5 *1 (-228))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182))))) 
+(((*1 *1 *1 *2) (|partial| -12 (-5 *2 (-763)) (-4 *1 (-1219 *3)) (-4 *3 (-1047))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-1244 *6)) (-5 *1 (-334 *3 *4 *5 *6)) (-4 *6 (-340 *3 *4 *5))))) 
+(((*1 *1) (-5 *1 (-1246)))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-197)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-634 (-381))) (-5 *2 (-381)) (-5 *1 (-197))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002)))))) 
+(((*1 *2) (-12 (-4 *4 (-365)) (-5 *2 (-763)) (-5 *1 (-326 *3 *4)) (-4 *3 (-327 *4)))) ((*1 *2) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-763))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-409 *6)) (-4 *5 (-1199)) (-4 *6 (-1219 *5)) (-5 *2 (-2 (|:| -3483 (-763)) (|:| -2350 *3) (|:| |radicand| *6))) (-5 *1 (-151 *5 *6 *7)) (-5 *4 (-763)) (-4 *7 (-1219 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 (-763)) (-4 *5 (-172))))) 
+(((*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-763)) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-96 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-212 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-494 *4)) (-4 *4 (-842)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1000 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1132 *4)) (-4 *4 (-1090)))) ((*1 *2 *3 *3) (|partial| -12 (-5 *2 (-121)) (-5 *1 (-1196 *3)) (-4 *3 (-1090)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-1 (-121) *3 *3)) (-4 *3 (-1090)) (-5 *2 (-121)) (-5 *1 (-1196 *3))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-1161)) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-4 *4 (-13 (-29 *6) (-1181) (-959))) (-5 *2 (-2 (|:| |particular| *4) (|:| -2588 (-634 *4)))) (-5 *1 (-796 *6 *4 *3)) (-4 *3 (-646 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-242 *6 *5)) (-5 *4 (-967 *5)) (-4 *5 (-350)) (-14 *6 (-634 (-1161))) (-5 *2 (-242 *6 (-857 *5))) (-5 *1 (-867 *5 *6 *7)) (-4 *7 (-117)))) ((*1 *2 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-365)) (-4 *6 (-230 *7 (-763))) (-14 *7 (-763)) (-5 *1 (-929 *5 *2 *6 *7 *3)) (-4 *2 (-324 *5 *6)) (-4 *3 (-971 *5)))) ((*1 *2 *2 *3) (-12 (-4 *4 (-365)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-929 *4 *2 *5 *6 *3)) (-4 *2 (-324 *4 *5)) (-4 *3 (-971 *4))))) 
+(((*1 *2 *3 *3 *3) (|partial| -12 (-4 *4 (-13 (-365) (-150) (-1037 (-568)))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-409 *5))) (-5 *1 (-1016 *4 *5)) (-5 *3 (-409 *5))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
+(((*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-763)) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-96 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-212 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-494 *4)) (-4 *4 (-842)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1000 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1132 *4)) (-4 *4 (-1090)))) ((*1 *2 *3 *3) (-12 (-5 *2 (-121)) (-5 *1 (-1196 *3)) (-4 *3 (-842)) (-4 *3 (-1090))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-558)) (-5 *2 (-2 (|:| -2908 (-679 *5)) (|:| |vec| (-1244 (-634 (-917)))))) (-5 *1 (-95 *5 *3)) (-5 *4 (-917)) (-4 *3 (-646 *5))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-5 *1 (-60 *4 *5 *2)) (-4 *2 (-13 (-432 *5) (-881 *4) (-609 (-887 *4))))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147))))) 
+(((*1 *1) (-5 *1 (-328)))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1263 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-842)) (-4 *4 (-365)) (-4 *5 (-788)) (-5 *2 (-2 (|:| |mval| (-679 *4)) (|:| |invmval| (-679 *4)) (|:| |genIdeal| (-514 *4 *5 *6 *7)))) (-5 *1 (-514 *4 *5 *6 *7)) (-4 *7 (-950 *4 *5 *6))))) 
+(((*1 *2) (-12 (-4 *2 (-13 (-432 *3) (-1002))) (-5 *1 (-272 *3 *2)) (-4 *3 (-13 (-842) (-558)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-634 (-679 (-568)))) (-5 *1 (-1100))))) 
 (((*1 *2 *3 *4 *4 *5 *3 *3 *3 *3 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-744))))) 
-(((*1 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558) (-609 (-541)))) (-5 *1 (-1024 *3 *2)) (-4 *2 (-13 (-432 *3) (-23) (-1037 (-568)) (-1037 (-1161)) (-895 (-1161)) (-161)))))) 
-(((*1 *2 *3 *1) (|partial| -12 (-5 *3 (-1 (-121) *2)) (-4 *1 (-154 *2)) (-4 *2 (-1195))))) 
-(((*1 *1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-239 *2)) (-4 *2 (-1195))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1219 *3)) (-4 *3 (-1047))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-1141 *4)) (-5 *3 (-1 *4 (-568))) (-4 *4 (-1047)) (-5 *1 (-1145 *4))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-850))))) 
+(((*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 (-679 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *1 (-989 *3 *4 *5 *6 *7)))) ((*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *1 (-1097 *3 *4 *5 *6 *7))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| -2350 *4) (|:| -4409 *3) (|:| -2607 *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-1061 *3 *4 *5)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -2350 *3) (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-1219 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-953 (-568))) (-5 *2 (-328)) (-5 *1 (-330)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-1082 (-953 (-568)))) (-5 *2 (-328)) (-5 *1 (-330)))) ((*1 *1 *2 *2 *2) (-12 (-5 *2 (-763)) (-5 *1 (-666 *3)) (-4 *3 (-1047)) (-4 *3 (-1090))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-634 (-634 *4)))) (-5 *2 (-634 (-634 *4))) (-5 *1 (-1167 *4)) (-4 *4 (-842))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-763)) (-4 *6 (-365)) (-5 *4 (-1190 *6)) (-5 *2 (-1 (-1141 *4) (-1141 *4))) (-5 *1 (-1252 *6)) (-5 *5 (-1141 *4))))) 
 (((*1 *2 *3 *4 *4 *4 *3 *5 *3 *4 *6 *7) (-12 (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT)))) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-741))))) 
 (((*1 *1 *2 *2 *3) (-12 (-5 *2 (-568)) (-5 *3 (-917)) (-4 *1 (-406)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-568)) (-4 *1 (-406)))) ((*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *2 *6)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-1090))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-4 *3 (-895 *5)) (-5 *2 (-679 *3)) (-5 *1 (-681 *5 *3 *6 *4)) (-4 *6 (-375 *3)) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4521))))))) 
 (((*1 *2 *1 *1) (-12 (-4 *1 (-1129)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-568)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-465))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1219 *3)) (-4 *3 (-1047)) (-5 *2 (-1157 *3))))) 
-(((*1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-634 *1)) (-4 *1 (-920 *3 *4))))) 
-(((*1 *2 *2 *3) (-12 (-4 *3 (-365)) (-5 *1 (-280 *3 *2)) (-4 *2 (-1234 *3))))) 
-(((*1 *2 *3 *4 *4 *3 *3 *5 *3 *4 *6 *7) (-12 (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN)))) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-741))))) 
+(((*1 *2 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5))))) 
+(((*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1195)) (-5 *1 (-1120 *4 *2)) (-4 *2 (-13 (-601 (-568) *4) (-10 -7 (-6 -4521) (-6 -4522)))))) ((*1 *2 *2) (-12 (-4 *3 (-842)) (-4 *3 (-1195)) (-5 *1 (-1120 *3 *2)) (-4 *2 (-13 (-601 (-568) *3) (-10 -7 (-6 -4521) (-6 -4522))))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-1061 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1189 *4 *5 *6 *3)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |gen| *3) (|:| -1894 (-568)))) (-5 *1 (-236 *3)) (-4 *3 (-1088)))) ((*1 *1 *1) (-12 (-4 *1 (-239 *2)) (-4 *2 (-1195)))) ((*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842))))) 
 (((*1 *2 *1 *1 *3) (-12 (-4 *1 (-1129)) (-5 *3 (-568)) (-5 *2 (-121))))) 
-(((*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 (-679 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3))))) 
-(((*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2704 *1))) (-4 *1 (-844 *3))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 (-634 *7) *7 (-1157 *7))) (-5 *5 (-1 (-420 *7) *7)) (-4 *7 (-1219 *6)) (-4 *6 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-5 *2 (-634 (-2 (|:| |frac| (-409 *7)) (|:| -1853 *3)))) (-5 *1 (-804 *6 *7 *3 *8)) (-4 *3 (-646 *7)) (-4 *8 (-646 (-409 *7))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-420 *6) *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-634 (-2 (|:| |frac| (-409 *6)) (|:| -1853 (-644 *6 (-409 *6)))))) (-5 *1 (-807 *5 *6)) (-5 *3 (-644 *6 (-409 *6)))))) 
-(((*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) ((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-842) (-1037 (-568)))) (-5 *1 (-180 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 (-169 *3)))))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-310 *4)) (-4 *4 (-13 (-823) (-842) (-1047))) (-5 *2 (-1143)) (-5 *1 (-821 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-310 *5)) (-5 *4 (-121)) (-4 *5 (-13 (-823) (-842) (-1047))) (-5 *2 (-1143)) (-5 *1 (-821 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-817)) (-5 *4 (-310 *5)) (-4 *5 (-13 (-823) (-842) (-1047))) (-5 *2 (-1249)) (-5 *1 (-821 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-817)) (-5 *4 (-310 *6)) (-5 *5 (-121)) (-4 *6 (-13 (-823) (-842) (-1047))) (-5 *2 (-1249)) (-5 *1 (-821 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-823)) (-5 *2 (-1143)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-823)) (-5 *3 (-121)) (-5 *2 (-1143)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-823)) (-5 *3 (-817)) (-5 *2 (-1249)))) ((*1 *2 *3 *1 *4) (-12 (-4 *1 (-823)) (-5 *3 (-817)) (-5 *4 (-121)) (-5 *2 (-1249))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-172)))) ((*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-943)) (-5 *3 (-568))))) 
+(((*1 *2 *3 *4 *4 *3 *3 *5 *3 *4 *6 *7) (-12 (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN)))) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-741))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *4)))) (-5 *1 (-1126 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39)))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-842) (-1037 (-568)))) (-5 *1 (-180 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 (-169 *3)))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-5 *1 (-180 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 (-169 *4)))))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4)))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-677 *4 *5 *6)) (-5 *1 (-108 *4 *3 *2 *5 *6)) (-4 *3 (-1219 *4)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4))))) 
+(((*1 *2 *2) (-12 (-4 *2 (-172)) (-4 *2 (-1047)) (-5 *1 (-704 *2 *3)) (-4 *3 (-637 *2)))) ((*1 *2 *2) (-12 (-5 *1 (-829 *2)) (-4 *2 (-172)) (-4 *2 (-1047))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1244 (-763))) (-5 *1 (-666 *3)) (-4 *3 (-1090))))) 
 (((*1 *2 *3 *4 *4 *3 *5 *3 *6 *4 *7 *8 *9) (-12 (-5 *4 (-568)) (-5 *5 (-1143)) (-5 *6 (-679 (-215))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G)))) (-5 *8 (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN)))) (-5 *9 (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT)))) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-741))))) 
-(((*1 *2 *1 *3) (|partial| -12 (-5 *3 (-1161)) (-4 *4 (-1047)) (-4 *4 (-842)) (-5 *2 (-2 (|:| |var| (-607 *1)) (|:| -3438 (-568)))) (-4 *1 (-432 *4)))) ((*1 *2 *1 *3) (|partial| -12 (-5 *3 (-123)) (-4 *4 (-1047)) (-4 *4 (-842)) (-5 *2 (-2 (|:| |var| (-607 *1)) (|:| -3438 (-568)))) (-4 *1 (-432 *4)))) ((*1 *2 *1) (|partial| -12 (-4 *3 (-1102)) (-4 *3 (-842)) (-5 *2 (-2 (|:| |var| (-607 *1)) (|:| -3438 (-568)))) (-4 *1 (-432 *3)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |val| (-887 *3)) (|:| -3438 (-763)))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-950 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| |var| *5) (|:| -3438 (-763)))))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-2 (|:| |var| *5) (|:| -3438 (-568)))) (-5 *1 (-951 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2745 ($ *7)) (-15 -2317 (*7 $)) (-15 -2324 (*7 $)))))))) 
-(((*1 *2 *3 *3 *3 *3) (-12 (-4 *4 (-453)) (-4 *3 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-450 *4 *3 *5 *6)) (-4 *6 (-950 *4 *3 *5))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *4 (-568))) (-5 *5 (-1 (-1141 *4))) (-4 *4 (-365)) (-4 *4 (-1047)) (-5 *2 (-1141 *4)) (-5 *1 (-1145 *4))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-365)) (-5 *1 (-758 *2 *3)) (-4 *2 (-698 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-917)) (-4 *5 (-842)) (-5 *2 (-64 (-634 (-663 *5)))) (-5 *1 (-663 *5))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1244 *4)) (-4 *4 (-419 *3)) (-4 *3 (-301)) (-4 *3 (-558)) (-5 *1 (-48 *3 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-365)) (-5 *2 (-1244 *1)) (-4 *1 (-327 *4)))) ((*1 *2) (-12 (-4 *3 (-365)) (-5 *2 (-1244 *1)) (-4 *1 (-327 *3)))) ((*1 *2) (-12 (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-1244 *1)) (-4 *1 (-411 *3 *4)))) ((*1 *2 *1) (-12 (-4 *3 (-301)) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-5 *2 (-1244 *6)) (-5 *1 (-415 *3 *4 *5 *6)) (-4 *6 (-13 (-411 *4 *5) (-1037 *4))))) ((*1 *2 *1) (-12 (-4 *3 (-301)) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-5 *2 (-1244 *6)) (-5 *1 (-416 *3 *4 *5 *6 *7)) (-4 *6 (-411 *4 *5)) (-14 *7 *2))) ((*1 *2) (-12 (-4 *3 (-172)) (-5 *2 (-1244 *1)) (-4 *1 (-419 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1244 (-1244 *4))) (-5 *1 (-532 *4)) (-4 *4 (-350))))) 
-(((*1 *2 *3 *3 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-679 (-568))) (-5 *1 (-1100))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *1) (-5 *1 (-158)))) 
+(((*1 *2 *2 *3 *2) (-12 (-5 *3 (-763)) (-4 *4 (-350)) (-5 *1 (-207 *4 *2)) (-4 *2 (-1219 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-2 (|:| |k| *4) (|:| |c| *3)))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
+(((*1 *1) (-5 *1 (-439)))) 
 (((*1 *2 *3 *4 *4 *5 *4 *3 *6 *3 *4 *7 *8 *9 *10) (-12 (-5 *4 (-568)) (-5 *5 (-1143)) (-5 *6 (-679 (-215))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-94 G)))) (-5 *8 (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN)))) (-5 *9 (-3 (|:| |fn| (-390)) (|:| |fp| (-76 PEDERV)))) (-5 *10 (-3 (|:| |fn| (-390)) (|:| |fp| (-93 OUTPUT)))) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-741))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-568)) (-5 *2 (-634 (-634 (-215)))) (-5 *1 (-1192))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-230 *5 (-763))) (-14 *5 (-763)) (-5 *1 (-908 *3 *2 *4 *5)) (-4 *2 (-324 *3 *4))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *1 (-1145 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 *6 *4 *5)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-1 *6 *5 *4)) (-5 *1 (-673 *4 *5 *6))))) 
-(((*1 *1 *2 *2 *2 *2 *2 *2 *2 *2) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-999 *3)) (-4 *3 (-172)) (-5 *1 (-794 *3))))) 
-(((*1 *2 *3) (-12 (-4 *3 (-1219 (-409 (-568)))) (-5 *2 (-2 (|:| |den| (-568)) (|:| |gcdnum| (-568)))) (-5 *1 (-909 *3 *4)) (-4 *4 (-1219 (-409 *3))))) ((*1 *2 *3) (-12 (-4 *4 (-1219 (-409 *2))) (-5 *2 (-568)) (-5 *1 (-909 *4 *3)) (-4 *3 (-1219 (-409 *4)))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *1 *1 *1) (-4 *1 (-1124)))) 
+(((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-763)) (-4 *4 (-13 (-558) (-150))) (-5 *1 (-1213 *4 *2)) (-4 *2 (-1219 *4))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-634 (-953 *4))) (-5 *3 (-634 (-1161))) (-4 *4 (-453)) (-5 *1 (-914 *4))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *1 *1) (-12 (-4 *1 (-995 *2)) (-4 *2 (-1195)))) ((*1 *1 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-57))) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-415 *3 *4 *5 *6)) (-4 *6 (-1037 *4)) (-4 *3 (-301)) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-4 *6 (-411 *4 *5)) (-14 *7 (-1244 *6)) (-5 *1 (-416 *3 *4 *5 *6 *7)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 *6)) (-4 *6 (-411 *4 *5)) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-4 *3 (-301)) (-5 *1 (-416 *3 *4 *5 *6 *7)) (-14 *7 *2)))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-494 *3))))) 
 (((*1 *2 *3 *3 *4 *5 *5 *5 *4 *4 *4 *3 *4 *4 *6) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *5 (-215)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-91 FCN)))) (-5 *2 (-1035)) (-5 *1 (-741))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-491))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-4 *6 (-324 *5 *7)) (-4 *7 (-230 *8 (-763))) (-14 *8 (-763)) (-4 *5 (-365)) (-5 *2 (-121)) (-5 *1 (-929 *5 *6 *7 *8 *4)) (-4 *4 (-971 *5))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -4265 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-977 *3 *4 *2 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *5 (-1061 *3 *4 *2))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-62 *4 *5 *2)) (-4 *4 (-1195)) (-4 *5 (-375 *4)) (-4 *2 (-375 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1050 *4 *5 *6 *7 *2)) (-4 *6 (-1047)) (-4 *7 (-230 *5 *6)) (-4 *2 (-230 *4 *6))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1201 *2)) (-4 *2 (-1047)))) ((*1 *1 *1) (-12 (-5 *1 (-1235 *2 *3 *4)) (-4 *2 (-1047)) (-14 *3 (-1161)) (-14 *4 *2))) ((*1 *1 *1) (-12 (-5 *1 (-1239 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-1161))))) 
+(((*1 *1 *2 *3 *1) (-12 (-5 *2 (-887 *4)) (-4 *4 (-1090)) (-5 *1 (-884 *4 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *3 *1 *4 *4 *4 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1027 *5 *6 *7 *3))) (-5 *1 (-1027 *5 *6 *7 *3)) (-4 *3 (-1061 *5 *6 *7)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-634 *6)) (-4 *1 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-1066 *3 *4 *5 *2)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) ((*1 *2 *3 *1 *4 *4 *4 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1131 *5 *6 *7 *3))) (-5 *1 (-1131 *5 *6 *7 *3)) (-4 *3 (-1061 *5 *6 *7))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-763)) (|:| |poli| *7) (|:| |polj| *7))) (-4 *5 (-788)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-450 *4 *5 *6 *7))))) 
+(((*1 *2 *3 *4 *4 *2 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *3 (-2 (|:| |lcmfij| *6) (|:| |totdeg| (-763)) (|:| |poli| *4) (|:| |polj| *4))) (-4 *6 (-788)) (-4 *4 (-950 *5 *6 *7)) (-4 *5 (-453)) (-4 *7 (-842)) (-5 *1 (-450 *5 *6 *7 *4))))) 
+(((*1 *1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *1 *2 *1) (-12 (-5 *1 (-130 *2)) (-4 *2 (-842))))) 
 (((*1 *2 *3 *3 *4 *3 *4 *4 *4 *5 *5 *5 *5 *4 *4 *6 *7) (-12 (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-89 FCNF)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-90 FCNG)))) (-5 *3 (-215)) (-5 *2 (-1035)) (-5 *1 (-741))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *5)) (-4 *5 (-13 (-27) (-1181) (-432 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-409 (-568))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-288 *3)) (-5 *5 (-409 (-568))) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *6 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 (-568))) (-5 *4 (-288 *6)) (-4 *6 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *6 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *7 (-568))) (-5 *4 (-288 *7)) (-5 *5 (-1210 (-568))) (-4 *7 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *6 *7)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-5 *6 (-1210 (-568))) (-4 *3 (-13 (-27) (-1181) (-432 *7))) (-4 *7 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *7 *3)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *8 (-409 (-568)))) (-5 *4 (-288 *8)) (-5 *5 (-1210 (-409 (-568)))) (-5 *6 (-409 (-568))) (-4 *8 (-13 (-27) (-1181) (-432 *7))) (-4 *7 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *7 *8)))) ((*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-5 *6 (-1210 (-409 (-568)))) (-5 *7 (-409 (-568))) (-4 *3 (-13 (-27) (-1181) (-432 *8))) (-4 *8 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *8 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *3)))) (-4 *3 (-1047)) (-5 *1 (-593 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-594 *3)))) ((*1 *1 *2 *3 *1) (-12 (-5 *2 (-568)) (-4 *1 (-641 *3)) (-4 *3 (-365)))) ((*1 *1 *2) (-12 (-5 *2 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *3)))) (-4 *3 (-1047)) (-4 *1 (-1203 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *3 (-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| *4)))) (-4 *4 (-1047)) (-4 *1 (-1224 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-4 *1 (-1234 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1141 (-2 (|:| |k| (-763)) (|:| |c| *3)))) (-4 *3 (-1047)) (-4 *1 (-1234 *3))))) 
-(((*1 *2 *2 *3 *3) (-12 (-5 *2 (-679 *3)) (-4 *3 (-301)) (-5 *1 (-689 *3))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-634 (-634 *4))) (-5 *3 (-634 *4)) (-4 *4 (-365)) (-5 *1 (-653 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-328))))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-62 *2 *3 *4)) (-4 *2 (-1195)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) ((*1 *1 *1 *2) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-601 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -2850 *4) (|:| -1551 (-568))))) (-4 *4 (-1090)) (-5 *2 (-1 *4)) (-5 *1 (-1017 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-541))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-1090)) (-5 *1 (-900 *3))))) 
+(((*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-568)) (-5 *5 (-3 "left" "center" "right" "vertical" "horizontal")) (-4 *6 (-1047)) (-4 *7 (-230 *8 (-763))) (-14 *8 (-763)) (-5 *2 (-634 (-634 *3))) (-5 *1 (-772 *6 *3 *7 *8)) (-4 *3 (-324 *6 *7))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-568)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-301)) (-4 *9 (-950 *8 *6 *7)) (-5 *2 (-2 (|:| -1416 (-1157 *9)) (|:| |polval| (-1157 *8)))) (-5 *1 (-732 *6 *7 *8 *9)) (-5 *3 (-1157 *9)) (-5 *4 (-1157 *8))))) 
+(((*1 *2 *3 *4 *4 *5) (|partial| -12 (-5 *4 (-607 *3)) (-5 *5 (-634 *3)) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-570 *6 *3 *7)) (-4 *7 (-1090))))) 
 (((*1 *2 *3 *4 *4 *5 *4 *4 *5 *5 *3 *4 *4 *6 *7) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *5 (-215)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-66 COEFFN)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-92 BDYVAL)))) (-5 *2 (-1035)) (-5 *1 (-741)))) ((*1 *2 *3 *4 *4 *5 *4 *4 *5 *5 *3 *4 *4 *6 *7 *8 *8) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *5 (-215)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-66 COEFFN)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-92 BDYVAL)))) (-5 *8 (-390)) (-5 *2 (-1035)) (-5 *1 (-741))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-634 *7)) (|:| |badPols| (-634 *7)))) (-5 *1 (-978 *4 *5 *6 *7)) (-5 *3 (-634 *7))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-565)) (-5 *3 (-568))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-950 *4 *5 *6)) (-5 *2 (-634 (-634 *7))) (-5 *1 (-449 *4 *5 *6 *7)) (-5 *3 (-634 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-950 *5 *6 *7)) (-5 *2 (-634 (-634 *8))) (-5 *1 (-449 *5 *6 *7 *8)) (-5 *3 (-634 *8))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-953 *4)) (-4 *4 (-1047)) (-4 *4 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-953 *5)) (-5 *4 (-917)) (-4 *5 (-1047)) (-4 *5 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-558)) (-4 *4 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-310 *4)) (-4 *4 (-558)) (-4 *4 (-842)) (-4 *4 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-310 *5)) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-842)) (-4 *5 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *5))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-271))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 (-169 (-568))))) (-5 *2 (-634 (-169 *4))) (-5 *1 (-380 *4)) (-4 *4 (-13 (-365) (-840))))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-409 (-953 (-169 (-568)))))) (-5 *4 (-634 (-1161))) (-5 *2 (-634 (-634 (-169 *5)))) (-5 *1 (-380 *5)) (-4 *5 (-13 (-365) (-840)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1244 (-310 (-215)))) (-5 *2 (-1244 (-310 (-381)))) (-5 *1 (-299))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| -2244 (-420 *3)) (|:| |special| (-420 *3)))) (-5 *1 (-717 *5 *3))))) 
+(((*1 *1) (-5 *1 (-142)))) 
+(((*1 *1) (-5 *1 (-818)))) 
 (((*1 *2 *3 *3 *3 *3 *4 *3 *3 *3 *3 *3 *3 *5 *5 *4 *3 *6 *7) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-80 FCN JACOBF JACEPS)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-81 G JACOBG JACGEP)))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-741))))) 
-(((*1 *2 *3) (-12 (-4 *3 (-13 (-301) (-10 -8 (-15 -1678 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *2 (-2 (|:| -3746 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-5 *1 (-351 *3 *4 *5)) (-4 *5 (-411 *3 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1219 *3)) (-5 *2 (-2 (|:| -3746 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-5 *1 (-760 *4 *5)) (-4 *5 (-411 *3 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-350)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 *3)) (-5 *2 (-2 (|:| -3746 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-5 *1 (-986 *4 *3 *5 *6)) (-4 *6 (-714 *3 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-350)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 *3)) (-5 *2 (-2 (|:| -3746 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-5 *1 (-1253 *4 *3 *5 *6)) (-4 *6 (-411 *3 *5))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-634 (-944 *3)))))) ((*1 *1 *2 *3 *3) (-12 (-5 *2 (-634 (-634 (-944 *4)))) (-5 *3 (-121)) (-4 *4 (-1047)) (-4 *1 (-1122 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-634 (-944 *3)))) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) ((*1 *1 *1 *2 *3 *3) (-12 (-5 *2 (-634 (-634 (-634 *4)))) (-5 *3 (-121)) (-4 *1 (-1122 *4)) (-4 *4 (-1047)))) ((*1 *1 *1 *2 *3 *3) (-12 (-5 *2 (-634 (-634 (-944 *4)))) (-5 *3 (-121)) (-4 *1 (-1122 *4)) (-4 *4 (-1047)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-634 (-634 (-634 *5)))) (-5 *3 (-634 (-171))) (-5 *4 (-171)) (-4 *1 (-1122 *5)) (-4 *5 (-1047)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-634 (-634 (-944 *5)))) (-5 *3 (-634 (-171))) (-5 *4 (-171)) (-4 *1 (-1122 *5)) (-4 *5 (-1047))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-2 (|:| -2295 *1) (|:| -4506 *1) (|:| |associate| *1))) (-4 *1 (-558))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-1143)) (-5 *3 (-818)) (-5 *1 (-817))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-568))) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-558)) (-4 *8 (-950 *7 *5 *6)) (-5 *2 (-2 (|:| -3438 (-763)) (|:| -2348 *9) (|:| |radicand| *9))) (-5 *1 (-954 *5 *6 *7 *8 *9)) (-5 *4 (-763)) (-4 *9 (-13 (-365) (-10 -8 (-15 -2317 (*8 $)) (-15 -2324 (*8 $)) (-15 -2745 ($ *8)))))))) 
-(((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1006)))) ((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1006))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-3 (-409 (-953 *5)) (-1150 (-1161) (-953 *5)))) (-4 *5 (-453)) (-5 *2 (-634 (-679 (-409 (-953 *5))))) (-5 *1 (-286 *5)) (-5 *4 (-679 (-409 (-953 *5))))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(((*1 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 (-2 (|:| -1924 *4) (|:| |coeff| *4)) "failed") *4)) (-4 *4 (-365)) (-5 *1 (-578 *4 *2)) (-4 *2 (-1219 *4))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-390)) (-5 *1 (-438)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-390)) (-5 *1 (-438))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1092 *4)) (-4 *4 (-1090)) (-5 *2 (-1 *4)) (-5 *1 (-1017 *4)))) ((*1 *2 *3 *3) (-12 (-5 *2 (-1 (-381))) (-5 *1 (-1039)) (-5 *3 (-381)))) ((*1 *2 *3) (-12 (-5 *3 (-1084 (-568))) (-5 *2 (-1 (-568))) (-5 *1 (-1045))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) ((*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1149 3 *3)) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) ((*1 *1) (-12 (-4 *1 (-1122 *2)) (-4 *2 (-1047))))) 
+(((*1 *2 *1 *2) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) *2)) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-763))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1157 *9)) (-5 *4 (-634 *7)) (-5 *5 (-634 *8)) (-4 *7 (-842)) (-4 *8 (-1047)) (-4 *9 (-950 *8 *6 *7)) (-4 *6 (-788)) (-5 *2 (-1157 *8)) (-5 *1 (-318 *6 *7 *8 *9))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436))))) 
+(((*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-3 (-121) (-634 *1))) (-4 *1 (-1066 *4 *5 *6 *3))))) 
+(((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 *7))) (-5 *3 (-1157 *7)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-904)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-901 *4 *5 *6 *7)))) ((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 *5))) (-5 *3 (-1157 *5)) (-4 *5 (-1219 *4)) (-4 *4 (-904)) (-5 *1 (-902 *4 *5))))) 
+(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-438))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-568))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-1141 (-953 *4)) (-1141 (-953 *4)))) (-5 *1 (-1252 *4)) (-4 *4 (-365))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-184)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-294)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-299))))) 
+(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-869)) (-5 *2 (-1249)) (-5 *1 (-1245)))) ((*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
+(((*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-2 (|:| -4151 *6) (|:| |coeff| *6)) "failed") *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-5 *2 (-3 (-2 (|:| |answer| (-409 *7)) (|:| |a0| *6)) (-2 (|:| -4151 (-409 *7)) (|:| |coeff| (-409 *7))) "failed")) (-5 *1 (-578 *6 *7)) (-5 *3 (-409 *7))))) 
 (((*1 *2 *3 *3 *4 *3 *4 *4 *4 *4 *5) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-69 G)))) (-5 *2 (-1035)) (-5 *1 (-740))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 *2) (-4 *5 (-172)))) ((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-917)) (-5 *1 (-165 *3 *4)) (-4 *3 (-166 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-917)))) ((*1 *2) (-12 (-4 *1 (-372 *3 *4)) (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-917)))) ((*1 *2 *3) (-12 (-4 *4 (-365)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-763)) (-5 *1 (-529 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-679 *5)) (-5 *4 (-1244 *5)) (-4 *5 (-365)) (-5 *2 (-763)) (-5 *1 (-659 *5)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-13 (-375 *5) (-10 -7 (-6 -4520)))) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4520)))) (-5 *2 (-763)) (-5 *1 (-660 *5 *6 *4 *3)) (-4 *3 (-677 *5 *6 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-4 *3 (-558)) (-5 *2 (-763)))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *4 (-172)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-763)) (-5 *1 (-678 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-4 *5 (-558)) (-5 *2 (-763))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-953 *5)) (-4 *5 (-1047)) (-5 *2 (-492 *4 *5)) (-5 *1 (-945 *4 *5)) (-14 *4 (-634 (-1161)))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-169 *4)) (-5 *1 (-178 *4 *3)) (-4 *4 (-13 (-365) (-840))) (-4 *3 (-1219 *2))))) 
-(((*1 *1 *1 *1) (|partial| -12 (-4 *2 (-172)) (-5 *1 (-284 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1219 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-701 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-705 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3))))) 
-(((*1 *1 *1 *1 *2) (|partial| -12 (-5 *2 (-121)) (-5 *1 (-593 *3)) (-4 *3 (-1047))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-5 *2 (-121))))) 
+(((*1 *2 *2) (-12 (-5 *1 (-961 *2)) (-4 *2 (-550))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-172))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-568))) (-4 *3 (-1047)) (-5 *1 (-593 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-568))) (-4 *1 (-1203 *3)) (-4 *3 (-1047)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-568))) (-4 *1 (-1234 *3)) (-4 *3 (-1047))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-953 (-568))) (-5 *2 (-328)) (-5 *1 (-330))))) 
 (((*1 *2 *3 *3 *4 *4 *4 *4) (-12 (-5 *3 (-215)) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-740))))) 
-(((*1 *2 *1) (|partial| -12 (-5 *2 (-607 *1)) (-4 *1 (-296))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1244 *1)) (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4)))))) 
-(((*1 *2 *3 *4 *5 *6 *7 *7 *8) (-12 (-5 *3 (-2 (|:| |det| *12) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568))))) (-5 *4 (-679 *12)) (-5 *5 (-634 (-409 (-953 *9)))) (-5 *6 (-634 (-634 *12))) (-5 *7 (-763)) (-5 *8 (-568)) (-4 *9 (-13 (-301) (-150))) (-4 *12 (-950 *9 *11 *10)) (-4 *10 (-13 (-842) (-609 (-1161)))) (-4 *11 (-788)) (-5 *2 (-2 (|:| |eqzro| (-634 *12)) (|:| |neqzro| (-634 *12)) (|:| |wcond| (-634 (-953 *9))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *9)))) (|:| -3746 (-634 (-1244 (-409 (-953 *9))))))))) (-5 *1 (-924 *9 *10 *11 *12))))) 
-(((*1 *1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *1 (-585 *2)) (-4 *2 (-1037 *3)) (-4 *2 (-365)))) ((*1 *1 *2 *2) (-12 (-5 *1 (-585 *2)) (-4 *2 (-365)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-621 *4 *2)) (-4 *2 (-13 (-432 *4) (-1002) (-1181))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1082 *2)) (-4 *2 (-13 (-432 *4) (-1002) (-1181))) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-621 *4 *2)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-959)) (-5 *2 (-1161)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1082 *1)) (-4 *1 (-959))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1026 (-835 (-568)))) (-5 *1 (-593 *3)) (-4 *3 (-1047))))) 
-(((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-3 (-1 (-215) (-215) (-215) (-215)) "undefined")) (-5 *5 (-1084 (-215))) (-5 *6 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-686))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) ((*1 *2 *1) (-12 (-5 *2 (-2 (|:| -2553 (-634 (-850))) (|:| -1462 (-634 (-850))) (|:| |presup| (-634 (-850))) (|:| -3785 (-634 (-850))) (|:| |args| (-634 (-850))))) (-5 *1 (-1161))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |val| (-634 *7)) (|:| -3001 *8))) (-4 *7 (-1061 *4 *5 *6)) (-4 *8 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *8)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |val| (-634 *7)) (|:| -3001 *8))) (-4 *7 (-1061 *4 *5 *6)) (-4 *8 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *8))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-427 *2)) (-4 *2 (-1090)) (-4 *2 (-370))))) 
+(((*1 *1) (-5 *1 (-473)))) 
+(((*1 *2 *3 *3) (-12 (|has| *2 (-6 (-4523 "*"))) (-4 *5 (-375 *2)) (-4 *6 (-375 *2)) (-4 *2 (-1047)) (-5 *1 (-108 *2 *3 *4 *5 *6)) (-4 *3 (-1219 *2)) (-4 *4 (-677 *2 *5 *6))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-121))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |lm| (-388 *3)) (|:| |mm| (-388 *3)) (|:| |rm| (-388 *3)))) (-5 *1 (-388 *3)) (-4 *3 (-1090)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |lm| (-814 *3)) (|:| |mm| (-814 *3)) (|:| |rm| (-814 *3)))) (-5 *1 (-814 *3)) (-4 *3 (-842))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) ((*1 *2 *1) (-12 (-5 *2 (-2 (|:| -1891 (-634 (-850))) (|:| -2409 (-634 (-850))) (|:| |presup| (-634 (-850))) (|:| -2749 (-634 (-850))) (|:| |args| (-634 (-850))))) (-5 *1 (-1161))))) 
 (((*1 *2 *3 *4 *4 *3 *5 *3 *3 *3 *6) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-83 FUNCTN)))) (-5 *2 (-1035)) (-5 *1 (-740))))) 
-(((*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1161)) (-4 *5 (-13 (-558) (-1037 (-568)) (-150))) (-5 *2 (-2 (|:| -1924 (-409 (-953 *5))) (|:| |coeff| (-409 (-953 *5))))) (-5 *1 (-574 *5)) (-5 *3 (-409 (-953 *5)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-370)) (-5 *2 (-917)))) ((*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-350)) (-5 *2 (-917)) (-5 *1 (-532 *4))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-230 *3 *2)) (-4 *2 (-1195)) (-4 *2 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-850)))) ((*1 *1 *1) (-5 *1 (-850))) ((*1 *2 *3 *3) (-12 (-5 *3 (-944 (-215))) (-5 *2 (-215)) (-5 *1 (-1192)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-1047))))) 
-(((*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1039))))) 
-(((*1 *2 *1 *3 *3 *4) (-12 (-5 *3 (-1 (-850) (-850) (-850))) (-5 *4 (-568)) (-5 *2 (-850)) (-5 *1 (-638 *5 *6 *7)) (-4 *5 (-1090)) (-4 *6 (-23)) (-14 *7 *6))) ((*1 *2 *1 *2) (-12 (-5 *2 (-850)) (-5 *1 (-846 *3 *4 *5)) (-4 *3 (-1047)) (-14 *4 (-101 *3)) (-14 *5 (-1 *3 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-215)) (-5 *1 (-850)))) ((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-850)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-850)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-850)) (-5 *1 (-1157 *3)) (-4 *3 (-1047))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 (-763))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1249)) (-5 *1 (-205 *4)) (-4 *4 (-13 (-842) (-10 -8 (-15 -2781 ((-1143) $ (-1161))) (-15 -4127 (*2 $)) (-15 -3687 (*2 $))))))) ((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-205 *3)) (-4 *3 (-13 (-842) (-10 -8 (-15 -2781 ((-1143) $ (-1161))) (-15 -4127 (*2 $)) (-15 -3687 (*2 $))))))) ((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-511))))) 
+(((*1 *1 *1) (|partial| -12 (-5 *1 (-288 *2)) (-4 *2 (-716)) (-4 *2 (-1195))))) 
+(((*1 *2 *3 *3 *2) (-12 (-5 *2 (-381)) (-5 *3 (-1143)) (-5 *1 (-99)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-381)) (-5 *3 (-1143)) (-5 *1 (-99))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-568)) (-5 *2 (-121)) (-5 *1 (-554))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-679 *5))) (-4 *5 (-301)) (-4 *5 (-1047)) (-5 *2 (-1244 (-1244 *5))) (-5 *1 (-1029 *5)) (-5 *4 (-1244 *5))))) 
+(((*1 *2 *3 *4 *5 *6 *5 *3 *7) (-12 (-5 *4 (-568)) (-5 *6 (-2 (|:| |try| (-381)) (|:| |did| (-381)) (|:| -3652 (-381)))) (-5 *7 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783)))) ((*1 *2 *3 *4 *5 *6 *5 *3 *7 *3 *3 *3 *3 *3 *3 *3) (-12 (-5 *4 (-568)) (-5 *6 (-2 (|:| |try| (-381)) (|:| |did| (-381)) (|:| -3652 (-381)))) (-5 *7 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *2 (-568)) (-5 *1 (-1178 *3)) (-4 *3 (-1047))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) ((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))) (-5 *1 (-444 *4 *3 *2)) (-4 *3 (-1219 *4)))) ((*1 *1 *1) (-4 *1 (-550))) ((*1 *2 *1) (-12 (-5 *2 (-917)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-917)) (-5 *1 (-667 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-814 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-888 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-4 *1 (-995 *3)) (-4 *3 (-1195)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1193 *3)) (-4 *3 (-1195)))) ((*1 *2 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-1002)) (-4 *2 (-1047))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-955)) (-5 *2 (-1084 (-215))))) ((*1 *2 *1) (-12 (-4 *1 (-975)) (-5 *2 (-1084 (-215)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-917)) (-5 *1 (-781))))) 
 (((*1 *2 *3 *3 *4 *4) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-740))))) 
-(((*1 *1 *1 *2 *2 *2 *2) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-33 *3)) (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4520)) (-4 *3 (-1090)) (-5 *1 (-96 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4520)) (-4 *3 (-1090)) (-5 *1 (-212 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4520)) (-4 *3 (-842)) (-5 *1 (-494 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| *1 (-6 -4520)) (-4 *1 (-499 *3)) (-4 *3 (-1195)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4520)) (-4 *3 (-1090)) (-5 *1 (-1000 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4520)) (-4 *3 (-1090)) (-5 *1 (-1132 *3))))) 
+(((*1 *2 *3 *3 *3 *4 *5 *5 *6) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-3 (-1 (-215) (-215) (-215) (-215)) "undefined")) (-5 *5 (-1084 (-215))) (-5 *6 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-686)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-215))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-686)))) ((*1 *2 *2 *3 *4 *4 *5) (-12 (-5 *2 (-1121 (-215))) (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-215))) (-5 *5 (-634 (-256))) (-5 *1 (-686))))) 
 (((*1 *2 *1 *1) (-12 (-4 *1 (-1129)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-958 (-1157 *4))) (-5 *1 (-358 *4)) (-5 *3 (-1157 *4))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-568)) (-5 *1 (-381))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1157 *6)) (-4 *6 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-1157 *7)) (-5 *1 (-318 *4 *5 *6 *7)) (-4 *7 (-950 *6 *4 *5))))) 
-(((*1 *2 *3 *4 *4 *3 *5 *3 *3 *4 *3 *6) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-83 FUNCTN)))) (-5 *2 (-1035)) (-5 *1 (-740))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-57)) (-5 *1 (-56 *2)) (-4 *2 (-1195)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-953 (-381))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-409 (-953 (-381)))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-310 (-381))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-953 (-568))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-409 (-953 (-568)))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-310 (-568))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1161)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 *2)) (-14 *4 (-634 *2)) (-4 *5 (-389)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-310 *5)) (-4 *5 (-389)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-409 (-953 (-568))))) (-4 *1 (-386)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-409 (-953 (-381))))) (-4 *1 (-386)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-953 (-568)))) (-4 *1 (-386)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-953 (-381)))) (-4 *1 (-386)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-310 (-568)))) (-4 *1 (-386)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-310 (-381)))) (-4 *1 (-386)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-409 (-953 (-568)))) (-4 *1 (-398)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-409 (-953 (-381)))) (-4 *1 (-398)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-953 (-568))) (-4 *1 (-398)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-953 (-381))) (-4 *1 (-398)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-310 (-568))) (-4 *1 (-398)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-310 (-381))) (-4 *1 (-398)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-409 (-953 (-568))))) (-4 *1 (-442)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-409 (-953 (-381))))) (-4 *1 (-442)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-953 (-568)))) (-4 *1 (-442)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-953 (-381)))) (-4 *1 (-442)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-310 (-568)))) (-4 *1 (-442)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-310 (-381)))) (-4 *1 (-442)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-350)) (-4 *5 (-327 *4)) (-4 *6 (-1219 *5)) (-5 *2 (-1157 (-1157 *4))) (-5 *1 (-769 *4 *5 *6 *3 *7)) (-4 *3 (-1219 *6)) (-14 *7 (-917)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *1 (-977 *3 *4 *5 *6)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-1037 *2)) (-4 *2 (-1195)))) ((*1 *1 *2) (|partial| -2198 (-12 (-5 *2 (-953 *3)) (-12 (-3044 (-4 *3 (-43 (-409 (-568))))) (-3044 (-4 *3 (-43 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 *3)) (-12 (-3044 (-4 *3 (-550))) (-3044 (-4 *3 (-43 (-409 (-568))))) (-4 *3 (-43 (-568))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 *3)) (-12 (-3044 (-4 *3 (-993 (-568)))) (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))))) ((*1 *1 *2) (|partial| -2198 (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-3044 (-4 *3 (-43 (-409 (-568))))) (-4 *3 (-43 (-568))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-953 (-409 (-568)))) (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-972))))) 
-(((*1 *2 *2) (-12 (-4 *2 (-13 (-365) (-840))) (-5 *1 (-178 *2 *3)) (-4 *3 (-1219 (-169 *2)))))) 
-(((*1 *2 *3 *3 *4) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)))) (-5 *2 (-2 (|:| |a| *6) (|:| |b| (-409 *6)) (|:| |c| (-409 *6)) (|:| -3492 *6))) (-5 *1 (-1015 *5 *6)) (-5 *3 (-409 *6))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-840)) (-5 *2 (-568)))) ((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1063 *4 *3)) (-4 *4 (-13 (-840) (-365))) (-4 *3 (-1219 *4)) (-5 *2 (-568)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-558) (-842) (-1037 *2) (-630 *2) (-453))) (-5 *2 (-568)) (-5 *1 (-1105 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4))))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-835 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-558) (-842) (-1037 *2) (-630 *2) (-453))) (-5 *2 (-568)) (-5 *1 (-1105 *6 *3)))) ((*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-1143)) (-4 *6 (-13 (-558) (-842) (-1037 *2) (-630 *2) (-453))) (-5 *2 (-568)) (-5 *1 (-1105 *6 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *6))))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-453)) (-5 *2 (-568)) (-5 *1 (-1106 *4)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-835 (-409 (-953 *6)))) (-5 *3 (-409 (-953 *6))) (-4 *6 (-453)) (-5 *2 (-568)) (-5 *1 (-1106 *6)))) ((*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *3 (-409 (-953 *6))) (-5 *4 (-1161)) (-5 *5 (-1143)) (-4 *6 (-453)) (-5 *2 (-568)) (-5 *1 (-1106 *6)))) ((*1 *2 *3) (|partial| -12 (-5 *2 (-568)) (-5 *1 (-1178 *3)) (-4 *3 (-1047))))) 
-(((*1 *2) (-12 (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-1244 *1)) (-4 *1 (-340 *3 *4 *5)))) ((*1 *2) (-12 (-4 *3 (-13 (-301) (-10 -8 (-15 -1678 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *2 (-2 (|:| -3746 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-5 *1 (-351 *3 *4 *5)) (-4 *5 (-411 *3 *4)))) ((*1 *2) (-12 (-4 *3 (-1219 (-568))) (-5 *2 (-2 (|:| -3746 (-679 (-568))) (|:| |basisDen| (-568)) (|:| |basisInv| (-679 (-568))))) (-5 *1 (-760 *3 *4)) (-4 *4 (-411 (-568) *3)))) ((*1 *2) (-12 (-4 *3 (-350)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| -3746 (-679 *4)) (|:| |basisDen| *4) (|:| |basisInv| (-679 *4)))) (-5 *1 (-986 *3 *4 *5 *6)) (-4 *6 (-714 *4 *5)))) ((*1 *2) (-12 (-4 *3 (-350)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| -3746 (-679 *4)) (|:| |basisDen| *4) (|:| |basisInv| (-679 *4)))) (-5 *1 (-1253 *3 *4 *5 *6)) (-4 *6 (-411 *4 *5))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-842) (-1037 (-568)) (-630 (-568)) (-453))) (-5 *2 (-2 (|:| |%term| (-2 (|:| |%coef| (-1228 *4 *5 *6)) (|:| |%expon| (-314 *4 *5 *6)) (|:| |%expTerms| (-634 (-2 (|:| |k| (-409 (-568))) (|:| |c| *4)))))) (|:| |%type| (-1143)))) (-5 *1 (-1229 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1181) (-432 *3))) (-14 *5 (-1161)) (-14 *6 *4)))) 
-(((*1 *1) (-5 *1 (-142)))) 
-(((*1 *2 *3 *4 *3) (-12 (-5 *3 (-1108)) (-5 *4 (-958 (-215))) (-5 *2 (-215)) (-5 *1 (-115))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *1 *1 *1) (-4 *1 (-1124)))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *3)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6))))) 
-(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1247))))) 
+(((*1 *2 *3 *3 *3) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1100)) (-5 *3 (-568))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-365)) (-5 *1 (-653 *3))))) 
 (((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121))))) 
-(((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-688)))) ((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-688))))) 
-(((*1 *1 *1) (-4 *1 (-550)))) 
-(((*1 *1 *1) (-12 (-4 *1 (-239 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-473)))) ((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1245)))) ((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1246))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-927)) (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-927)) (-5 *4 (-409 (-568))) (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-607 *5))) (-4 *4 (-842)) (-5 *2 (-607 *5)) (-5 *1 (-577 *4 *5)) (-4 *5 (-432 *4))))) 
-(((*1 *1 *2 *2 *2) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181))))) ((*1 *1 *1 *2) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) ((*1 *1 *2) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) ((*1 *2 *1 *3 *4 *4) (-12 (-5 *3 (-917)) (-5 *4 (-381)) (-5 *2 (-1249)) (-5 *1 (-1245))))) 
-(((*1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247)))) ((*1 *2 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-375 *2)) (-4 *2 (-1195)) (-4 *2 (-842)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (-4 *1 (-375 *3)) (-4 *3 (-1195)))) ((*1 *2 *2) (-12 (-5 *2 (-634 (-900 *3))) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) ((*1 *2 *1 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-4 *6 (-1061 *4 *5 *3)) (-5 *2 (-2 (|:| |under| *1) (|:| -1519 *1) (|:| |upper| *1))) (-4 *1 (-977 *4 *5 *3 *6))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-541)) (-5 *1 (-540 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-5 *2 (-57)) (-5 *1 (-541))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *2 *7 *8 *9 *10)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-641 *3)) (-4 *8 (-920 *3 *7)) (-4 *9 (-235 *8)) (-4 *10 (-117)) (-4 *2 (-971 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1864 *7) (|:| -4477 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *5 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3)))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-242 (-4287 (QUOTE X) (QUOTE -2926)) *5)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *2 (-324 *5 *7)) (-5 *1 (-119 *5 *6 *2 *7 *4)) (-4 *7 (-230 (-1697 *6) (-763))) (-4 *4 (-117))))) 
-(((*1 *2 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5))))) 
-(((*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-763)) (-4 *5 (-365)) (-5 *2 (-173 *6)) (-5 *1 (-861 *5 *4 *6)) (-4 *4 (-1234 *5)) (-4 *6 (-1219 *5))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-366 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090)))) ((*1 *1 *1) (-5 *1 (-623)))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1196 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-2 (|:| -4092 (-634 *6)) (|:| -1798 (-634 *6))))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1244 *4)) (-4 *4 (-630 (-568))) (-5 *2 (-1244 (-409 (-568)))) (-5 *1 (-1269 *4))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))))) ((*1 *2) (|partial| -12 (-4 *4 (-1199)) (-4 *5 (-1219 (-409 *2))) (-4 *2 (-1219 *4)) (-5 *1 (-339 *3 *4 *2 *5)) (-4 *3 (-340 *4 *2 *5)))) ((*1 *2) (|partial| -12 (-4 *1 (-340 *3 *2 *4)) (-4 *3 (-1199)) (-4 *4 (-1219 (-409 *2))) (-4 *2 (-1219 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-184)))) ((*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-294)))) ((*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-299))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) ((*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1058)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1058))))) 
-(((*1 *2) (-12 (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-904)) (-5 *1 (-459 *3 *4 *2 *5)) (-4 *5 (-950 *2 *3 *4)))) ((*1 *2) (-12 (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-904)) (-5 *1 (-901 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) ((*1 *2) (-12 (-4 *2 (-904)) (-5 *1 (-902 *2 *3)) (-4 *3 (-1219 *2))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4))))) ((*1 *1 *1) (-5 *1 (-381))) ((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *4)))) (-5 *1 (-768 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
-(((*1 *2 *2 *3) (-12 (-4 *3 (-301)) (-5 *1 (-457 *3 *2)) (-4 *2 (-1219 *3)))) ((*1 *2 *2 *3) (-12 (-4 *3 (-301)) (-5 *1 (-462 *3 *2)) (-4 *2 (-1219 *3)))) ((*1 *2 *2 *3) (-12 (-4 *3 (-301)) (-14 *4 *3) (-14 *5 (-1 *3 *3 (-763))) (-5 *1 (-544 *3 *2 *4 *5)) (-4 *2 (-1219 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-1157 *3))))) 
-(((*1 *2 *3 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-453)) (-5 *2 (-121)) (-5 *1 (-362 *4 *5)) (-14 *5 (-634 (-1161))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-775 *4 (-852 *5)))) (-4 *4 (-453)) (-14 *5 (-634 (-1161))) (-5 *2 (-121)) (-5 *1 (-619 *4 *5))))) 
-(((*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *4 (-869)) (-5 *5 (-917)) (-5 *6 (-634 (-256))) (-5 *2 (-473)) (-5 *1 (-1248)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *2 (-473)) (-5 *1 (-1248)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *4 (-634 (-256))) (-5 *2 (-473)) (-5 *1 (-1248))))) 
-(((*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2317 ((-1113 *3 (-607 $)) $)) (-15 -2324 ((-1113 *3 (-607 $)) $)) (-15 -2745 ($ (-1113 *3 (-607 $)))))))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -4265 *3) (|:| |coef2| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047))))) 
+(((*1 *2 *3 *4 *4 *3 *5 *3 *3 *4 *3 *6) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-83 FUNCTN)))) (-5 *2 (-1035)) (-5 *1 (-740))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-2 (|:| -2588 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-4 *3 (-13 (-301) (-10 -8 (-15 -3498 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *1 (-508 *3 *4 *5)) (-4 *5 (-411 *3 *4))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-57)) (-5 *1 (-56 *2)) (-4 *2 (-1195)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-953 (-381))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-409 (-953 (-381)))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-310 (-381))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-953 (-568))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-409 (-953 (-568)))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-310 (-568))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1161)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 *2)) (-14 *4 (-634 *2)) (-4 *5 (-389)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-310 *5)) (-4 *5 (-389)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-409 (-953 (-568))))) (-4 *1 (-386)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-409 (-953 (-381))))) (-4 *1 (-386)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-953 (-568)))) (-4 *1 (-386)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-953 (-381)))) (-4 *1 (-386)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-310 (-568)))) (-4 *1 (-386)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-679 (-310 (-381)))) (-4 *1 (-386)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-409 (-953 (-568)))) (-4 *1 (-398)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-409 (-953 (-381)))) (-4 *1 (-398)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-953 (-568))) (-4 *1 (-398)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-953 (-381))) (-4 *1 (-398)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-310 (-568))) (-4 *1 (-398)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-310 (-381))) (-4 *1 (-398)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-409 (-953 (-568))))) (-4 *1 (-442)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-409 (-953 (-381))))) (-4 *1 (-442)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-953 (-568)))) (-4 *1 (-442)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-953 (-381)))) (-4 *1 (-442)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-310 (-568)))) (-4 *1 (-442)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1244 (-310 (-381)))) (-4 *1 (-442)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-350)) (-4 *5 (-327 *4)) (-4 *6 (-1219 *5)) (-5 *2 (-1157 (-1157 *4))) (-5 *1 (-769 *4 *5 *6 *3 *7)) (-4 *3 (-1219 *6)) (-14 *7 (-917)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *1 (-977 *3 *4 *5 *6)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-1037 *2)) (-4 *2 (-1195)))) ((*1 *1 *2) (|partial| -2199 (-12 (-5 *2 (-953 *3)) (-12 (-3046 (-4 *3 (-43 (-409 (-568))))) (-3046 (-4 *3 (-43 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 *3)) (-12 (-3046 (-4 *3 (-550))) (-3046 (-4 *3 (-43 (-409 (-568))))) (-4 *3 (-43 (-568))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 *3)) (-12 (-3046 (-4 *3 (-993 (-568)))) (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))))) ((*1 *1 *2) (|partial| -2199 (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-3046 (-4 *3 (-43 (-409 (-568))))) (-4 *3 (-43 (-568))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-953 (-409 (-568)))) (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))))) 
+(((*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-844 *3)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-558)) (-4 *5 (-1047)) (-5 *2 (-2 (|:| -4409 *3) (|:| -2607 *3))) (-5 *1 (-845 *5 *3)) (-4 *3 (-844 *5))))) 
+(((*1 *2 *3 *3 *2 *4) (-12 (-5 *3 (-679 *2)) (-5 *4 (-568)) (-4 *2 (-13 (-301) (-10 -8 (-15 -3498 ((-420 $) $))))) (-4 *5 (-1219 *2)) (-5 *1 (-508 *2 *5 *6)) (-4 *6 (-411 *2 *5))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-944 *4))) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-634 (-171))))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-840))) (-5 *1 (-178 *3 *2)) (-4 *2 (-1219 (-169 *3)))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-1 (-634 *4) *4)) (-5 *1 (-107 *4)) (-5 *3 (-634 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-57)) (-5 *1 (-1174))))) 
-(((*1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-144)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-145)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-216)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-218))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-858))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1205 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1234 *3))))) 
-(((*1 *2 *3) (-12 (-4 *2 (-1219 *4)) (-5 *1 (-804 *4 *2 *3 *5)) (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *3 (-646 *2)) (-4 *5 (-646 (-409 *2)))))) 
-(((*1 *1) (-5 *1 (-1249)))) 
-(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-96 *3))))) 
-(((*1 *2 *3) (|partial| -12 (-4 *2 (-1090)) (-5 *1 (-1173 *3 *2)) (-4 *3 (-1090))))) 
-(((*1 *2 *2 *3 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-614 *4 *2)) (-4 *2 (-13 (-1181) (-959) (-29 *4)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *3 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-634 (-568)))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-643 *4)) (-4 *4 (-340 *5 *6 *7)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2588 (-634 *4)))) (-5 *1 (-801 *5 *6 *7 *4))))) 
+(((*1 *1 *1) (-4 *1 (-558)))) 
 (((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
-(((*1 *2) (-12 (-5 *2 (-835 (-568))) (-5 *1 (-539)))) ((*1 *1) (-12 (-5 *1 (-835 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *1 *1) (|partial| -12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-5 *2 (-679 *4)) (-5 *1 (-809 *4 *5)) (-4 *5 (-646 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-763)) (-4 *5 (-365)) (-5 *2 (-679 *5)) (-5 *1 (-809 *5 *6)) (-4 *6 (-646 *5))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-288 (-310 *5)))) (-5 *1 (-1117 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-288 (-310 *4)))) (-5 *1 (-1117 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-288 (-409 (-953 *5)))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-288 (-310 *5)))) (-5 *1 (-1117 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-288 (-409 (-953 *4)))) (-4 *4 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-288 (-310 *4)))) (-5 *1 (-1117 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 *5)))) (-5 *4 (-634 (-1161))) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-634 (-288 (-310 *5))))) (-5 *1 (-1117 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 *4)))) (-4 *4 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-634 (-288 (-310 *4))))) (-5 *1 (-1117 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-288 (-409 (-953 *5))))) (-5 *4 (-634 (-1161))) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-634 (-288 (-310 *5))))) (-5 *1 (-1117 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-288 (-409 (-953 *4))))) (-4 *4 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-634 (-288 (-310 *4))))) (-5 *1 (-1117 *4))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-1157 *1)) (-4 *1 (-858)) (-5 *2 (-634 *1)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-365)) (-5 *2 (-2 (|:| |zeros| (-634 *4)) (|:| -2842 (-568)))) (-5 *1 (-1043 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-5 *2 (-634 (-1161))) (-5 *1 (-202)) (-5 *3 (-1161)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-310 (-215))) (-5 *4 (-763)) (-5 *2 (-634 (-1161))) (-5 *1 (-263)))) ((*1 *2 *1) (-12 (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *2 (-634 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917)))) ((*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-667 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-814 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-888 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-634 *3))))) 
-(((*1 *2) (-12 (-5 *2 (-835 (-568))) (-5 *1 (-539)))) ((*1 *1) (-12 (-5 *1 (-835 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-344 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1143)) (-5 *1 (-781))))) 
-(((*1 *2 *3 *2 *2) (-12 (-5 *2 (-634 (-492 *4 *5))) (-5 *3 (-852 *4)) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *1 (-622 *4 *5))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-634 (-634 (-568)))) (-5 *1 (-972)) (-5 *3 (-634 (-568)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-5 *4 (-763)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-634 (-2 (|:| |det| *8) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (-5 *1 (-924 *5 *6 *7 *8))))) 
-(((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 *4))) (-5 *3 (-1157 *4)) (-4 *4 (-904)) (-5 *1 (-655 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *2 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-744))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-453)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6))))) 
-(((*1 *2 *3 *3 *3 *4 *5) (-12 (-5 *5 (-634 (-634 (-215)))) (-5 *4 (-215)) (-5 *2 (-634 (-944 *4))) (-5 *1 (-1192)) (-5 *3 (-944 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181)))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-558))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-1249))))) 
-(((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-1 (-215) (-215) (-215) (-215))) (-5 *2 (-1 (-944 (-215)) (-215) (-215))) (-5 *1 (-686))))) 
-(((*1 *2 *3 *1) (-12 (-4 *1 (-601 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1195)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-869)) (-5 *3 (-634 (-256))) (-5 *1 (-254))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-1170 *2)) (-4 *2 (-365))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-325 *3)) (-4 *3 (-1195)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-525 *3 *4)) (-4 *3 (-1195)) (-14 *4 (-568))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-256))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-554))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-917)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-256))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1 (-121) *8))) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-2 (|:| |goodPols| (-634 *8)) (|:| |badPols| (-634 *8)))) (-5 *1 (-978 *5 *6 *7 *8)) (-5 *4 (-634 *8))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *2)) (-4 *2 (-172)))) ((*1 *2) (-12 (-4 *2 (-172)) (-5 *1 (-418 *3 *2)) (-4 *3 (-419 *2)))) ((*1 *2) (-12 (-4 *1 (-419 *2)) (-4 *2 (-172))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-50 (-1143) (-766))) (-5 *1 (-123))))) 
-(((*1 *1 *1) (-5 *1 (-1059)))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 (-147))) (-5 *1 (-142)))) ((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-142))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-607 *4)) (-4 *4 (-842)) (-4 *2 (-842)) (-5 *1 (-606 *2 *4))))) 
-(((*1 *2 *3 *4) (-12 (-4 *7 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-558)) (-4 *8 (-950 *7 *5 *6)) (-5 *2 (-2 (|:| -3438 (-763)) (|:| -2348 *3) (|:| |radicand| *3))) (-5 *1 (-954 *5 *6 *7 *8 *3)) (-5 *4 (-763)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2317 (*8 $)) (-15 -2324 (*8 $)) (-15 -2745 ($ *8)))))))) 
-(((*1 *2 *2 *1) (|partial| -12 (-5 *2 (-634 *1)) (-4 *1 (-301))))) 
-(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-634 (-409 (-953 *6)))) (-5 *3 (-409 (-953 *6))) (-4 *6 (-13 (-558) (-1037 (-568)) (-150))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-574 *6))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -2217 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-835 (-215)))) (-5 *4 (-215)) (-5 *2 (-634 *4)) (-5 *1 (-263))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
-(((*1 *2) (-12 (-5 *2 (-1244 (-1091 *3 *4))) (-5 *1 (-1091 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917))))) 
-(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1 (-121) *9)) (-5 *5 (-1 (-121) *9 *9)) (-4 *9 (-1061 *6 *7 *8)) (-4 *6 (-558)) (-4 *7 (-788)) (-4 *8 (-842)) (-5 *2 (-2 (|:| |bas| *1) (|:| -2616 (-634 *9)))) (-5 *3 (-634 *9)) (-4 *1 (-1189 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1 (-121) *8 *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-2 (|:| |bas| *1) (|:| -2616 (-634 *8)))) (-5 *3 (-634 *8)) (-4 *1 (-1189 *5 *6 *7 *8))))) 
-(((*1 *2 *3 *4 *4 *5 *6 *7) (-12 (-5 *5 (-1161)) (-5 *6 (-1 (-3 (-2 (|:| |mainpart| *4) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *4) (|:| |logand| *4))))) "failed") *4 (-634 *4))) (-5 *7 (-1 (-3 (-2 (|:| -1924 *4) (|:| |coeff| *4)) "failed") *4 *4)) (-4 *4 (-13 (-1181) (-27) (-432 *8))) (-4 *8 (-13 (-453) (-842) (-150) (-1037 *3) (-630 *3))) (-5 *3 (-568)) (-5 *2 (-2 (|:| |ans| *4) (|:| -3284 *4) (|:| |sol?| (-121)))) (-5 *1 (-1013 *8 *4))))) 
-(((*1 *2 *3 *4 *5 *5 *2) (|partial| -12 (-5 *2 (-121)) (-5 *3 (-953 *6)) (-5 *4 (-1161)) (-5 *5 (-835 *7)) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-4 *7 (-13 (-1181) (-29 *6))) (-5 *1 (-214 *6 *7)))) ((*1 *2 *3 *4 *4 *2) (|partial| -12 (-5 *2 (-121)) (-5 *3 (-1157 *6)) (-5 *4 (-835 *6)) (-4 *6 (-13 (-1181) (-29 *5))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-214 *5 *6))))) 
-(((*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-634 *10)) (-5 *5 (-121)) (-4 *10 (-1066 *6 *7 *8 *9)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *9 (-1061 *6 *7 *8)) (-5 *2 (-634 (-2 (|:| -1853 (-634 *9)) (|:| -3001 *10) (|:| |ineq| (-634 *9))))) (-5 *1 (-989 *6 *7 *8 *9 *10)) (-5 *3 (-634 *9)))) ((*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-634 *10)) (-5 *5 (-121)) (-4 *10 (-1066 *6 *7 *8 *9)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *9 (-1061 *6 *7 *8)) (-5 *2 (-634 (-2 (|:| -1853 (-634 *9)) (|:| -3001 *10) (|:| |ineq| (-634 *9))))) (-5 *1 (-1097 *6 *7 *8 *9 *10)) (-5 *3 (-634 *9))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-665 *3)) (-4 *3 (-1195)) (-5 *2 (-121))))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-710)) (-5 *2 (-917)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-712)) (-5 *2 (-763))))) 
-(((*1 *1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-172)) (-4 *2 (-558)))) ((*1 *1 *1) (|partial| -4 *1 (-712)))) 
-(((*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *3 (-679 *11)) (-5 *4 (-634 (-409 (-953 *8)))) (-5 *5 (-763)) (-5 *6 (-1143)) (-4 *8 (-13 (-301) (-150))) (-4 *11 (-950 *8 *10 *9)) (-4 *9 (-13 (-842) (-609 (-1161)))) (-4 *10 (-788)) (-5 *2 (-2 (|:| |rgl| (-634 (-2 (|:| |eqzro| (-634 *11)) (|:| |neqzro| (-634 *11)) (|:| |wcond| (-634 (-953 *8))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *8)))) (|:| -3746 (-634 (-1244 (-409 (-953 *8)))))))))) (|:| |rgsz| (-568)))) (-5 *1 (-924 *8 *9 *10 *11)) (-5 *7 (-568))))) 
-(((*1 *2 *3 *1) (-12 (-4 *1 (-605 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-5 *2 (-121))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2348 *3) (|:| |gap| (-763)) (|:| -3961 (-777 *3)) (|:| -1500 (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-1047)))) ((*1 *2 *1 *1 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-2 (|:| -2348 *1) (|:| |gap| (-763)) (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-1061 *4 *5 *3)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -2348 *1) (|:| |gap| (-763)) (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-1061 *3 *4 *5))))) 
-(((*1 *1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *2 *3) (-12 (-5 *2 (-420 (-1157 *1))) (-5 *1 (-310 *4)) (-5 *3 (-1157 *1)) (-4 *4 (-453)) (-4 *4 (-558)) (-4 *4 (-842)))) ((*1 *2 *3) (-12 (-4 *1 (-904)) (-5 *2 (-420 (-1157 *1))) (-5 *3 (-1157 *1))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-406)) (-5 *2 (-568)))) ((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-688))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568))))) 
-(((*1 *2) (|partial| -12 (-4 *4 (-1199)) (-4 *5 (-1219 (-409 *2))) (-4 *2 (-1219 *4)) (-5 *1 (-339 *3 *4 *2 *5)) (-4 *3 (-340 *4 *2 *5)))) ((*1 *2) (|partial| -12 (-4 *1 (-340 *3 *2 *4)) (-4 *3 (-1199)) (-4 *4 (-1219 (-409 *2))) (-4 *2 (-1219 *3))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-1012)) (-5 *2 (-850))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-438))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-121)) (-5 *1 (-924 *4 *5 *6 *7)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-121)) (-5 *1 (-924 *4 *5 *6 *7)) (-4 *7 (-950 *4 *6 *5))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1219 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-1221 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-4 *1 (-1224 *3)) (-4 *3 (-1047))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-325 *3)) (-4 *3 (-1195)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-525 *3 *4)) (-4 *3 (-1195)) (-14 *4 (-568))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-857 *4))) (-4 *4 (-350)) (-5 *2 (-967 *4)) (-5 *1 (-867 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-5 *2 (-966 *4)) (-5 *1 (-868 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-4 *1 (-971 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1226 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1203 *3)) (-5 *2 (-409 (-568)))))) 
-(((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-446 *3)) (-4 *3 (-1047))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-1090)) (-5 *1 (-900 *3))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-1000 *3))))) 
-(((*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *3 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *6)))) (-5 *4 (-1026 (-835 (-568)))) (-5 *5 (-1161)) (-5 *7 (-409 (-568))) (-4 *6 (-1047)) (-5 *2 (-850)) (-5 *1 (-593 *6))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(((*1 *1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *2 *3) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-565)) (-5 *3 (-568))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
-(((*1 *2 *1 *2) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *2)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *2 (-117))))) 
-(((*1 *2 *1 *3 *3 *4 *4) (-12 (-5 *3 (-763)) (-5 *4 (-917)) (-5 *2 (-1249)) (-5 *1 (-1245)))) ((*1 *2 *1 *3 *3 *4 *4) (-12 (-5 *3 (-763)) (-5 *4 (-917)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
-(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-568)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-465))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-358 *3)) (-4 *3 (-350))))) 
-(((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-239 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-927))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1090)) (-4 *4 (-1195)) (-5 *2 (-121)) (-5 *1 (-1141 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-679 *4)) (-5 *3 (-917)) (-4 *4 (-1047)) (-5 *1 (-1028 *4)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-634 (-679 *4))) (-5 *3 (-917)) (-4 *4 (-1047)) (-5 *1 (-1028 *4))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-1161))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-123)) (-5 *1 (-1024 *4 *3)) (-4 *3 (-13 (-432 *4) (-23) (-1037 (-568)) (-1037 (-1161)) (-895 (-1161)) (-161)))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4519)) (-4 *1 (-227 *3)) (-4 *3 (-1090)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-277 *3)) (-4 *3 (-1195))))) 
-(((*1 *2 *1) (-12 (-4 *2 (-698 *3)) (-5 *1 (-822 *2 *3)) (-4 *3 (-1047))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-4 *1 (-898 *3))))) 
-(((*1 *1 *1 *1) (-4 *1 (-296))) ((*1 *1 *1) (-4 *1 (-296)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568))))) (-14 *4 (-634 (-1161))) (-14 *5 (-763)) (-5 *2 (-121)) (-5 *1 (-515 *4 *5))))) 
-(((*1 *1 *1 *1) (-4 *1 (-753)))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-57))) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-365)) (-4 *1 (-327 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-1219 *4)) (-4 *4 (-1199)) (-4 *1 (-340 *4 *3 *5)) (-4 *5 (-1219 (-409 *3))))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-1244 *1)) (-4 *4 (-172)) (-4 *1 (-369 *4)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-1244 *1)) (-4 *4 (-172)) (-4 *1 (-372 *4 *5)) (-4 *5 (-1219 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-172)) (-4 *1 (-411 *3 *4)) (-4 *4 (-1219 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-172)) (-4 *1 (-419 *3))))) 
-(((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-128 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *3 *4 *4 *3) (|partial| -12 (-5 *4 (-607 *3)) (-4 *3 (-13 (-432 *5) (-27) (-1181))) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| -1924 *3) (|:| |coeff| *3))) (-5 *1 (-570 *5 *3 *6)) (-4 *6 (-1090))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 *5)) (-4 *5 (-1090)) (-5 *2 (-1 *5 *4)) (-5 *1 (-672 *4 *5)) (-4 *4 (-1090)))) ((*1 *2 *3) (-12 (-4 *4 (-230 *5 (-763))) (-14 *5 (-763)) (-4 *2 (-1047)) (-5 *1 (-908 *2 *3 *4 *5)) (-4 *3 (-324 *2 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-842)) (-5 *1 (-930 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-310 (-568))) (-5 *1 (-931)))) ((*1 *2 *1) (-12 (-4 *1 (-1259 *3 *2)) (-4 *3 (-842)) (-4 *2 (-1047)))) ((*1 *2 *1) (-12 (-4 *2 (-1047)) (-5 *1 (-1265 *2 *3)) (-4 *3 (-838))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-851)))) ((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1249)) (-5 *1 (-851)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-850)) (-5 *2 (-1249)) (-5 *1 (-851)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-1141 *4)) (-4 *4 (-1090)) (-4 *4 (-1195))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-953 *5)) (-4 *5 (-1047)) (-5 *2 (-242 *4 *5)) (-5 *1 (-945 *4 *5)) (-14 *4 (-634 (-1161)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-381))) (-5 *1 (-1039))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-121))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1047))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-36 *3 *4)) (-4 *4 (-432 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-763)) (-5 *1 (-123)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-123)))) ((*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *4)) (-4 *4 (-432 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-123)) (-5 *1 (-163)))) ((*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *4)) (-4 *4 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-5 *2 (-123)) (-5 *1 (-295 *3)) (-4 *3 (-296)))) ((*1 *2 *2) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) ((*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *4 (-842)) (-5 *1 (-431 *3 *4)) (-4 *3 (-432 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *4)) (-4 *4 (-432 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-123)) (-5 *1 (-607 *3)) (-4 *3 (-842)))) ((*1 *2 *2) (-12 (-5 *2 (-123)) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *4)) (-4 *4 (-13 (-432 *3) (-1002) (-1181)))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1108)) (-5 *1 (-328))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-381)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-256))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6))))) 
-(((*1 *1) (-12 (-4 *3 (-1090)) (-5 *1 (-880 *2 *3 *4)) (-4 *2 (-1090)) (-4 *4 (-658 *3)))) ((*1 *1) (-12 (-5 *1 (-884 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090))))) 
-(((*1 *1) (-5 *1 (-1246)))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-242 *6 *5)) (-5 *4 (-967 *5)) (-4 *5 (-350)) (-14 *6 (-634 (-1161))) (-5 *2 (-242 *6 (-857 *5))) (-5 *1 (-867 *5 *6 *7)) (-4 *7 (-117)))) ((*1 *2 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-365)) (-4 *6 (-230 *7 (-763))) (-14 *7 (-763)) (-5 *1 (-929 *5 *2 *6 *7 *3)) (-4 *2 (-324 *5 *6)) (-4 *3 (-971 *5)))) ((*1 *2 *2 *3) (-12 (-4 *4 (-365)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-929 *4 *2 *5 *6 *3)) (-4 *2 (-324 *4 *5)) (-4 *3 (-971 *4))))) 
-(((*1 *1) (-5 *1 (-328)))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1195)) (-5 *1 (-1120 *4 *2)) (-4 *2 (-13 (-601 (-568) *4) (-10 -7 (-6 -4519) (-6 -4520)))))) ((*1 *2 *2) (-12 (-4 *3 (-842)) (-4 *3 (-1195)) (-5 *1 (-1120 *3 *2)) (-4 *2 (-13 (-601 (-568) *3) (-10 -7 (-6 -4519) (-6 -4520))))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *4)))) (-5 *1 (-1126 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39)))))) 
-(((*1 *1) (-5 *1 (-158)))) 
-(((*1 *1 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *1 *1) (-12 (-4 *1 (-995 *2)) (-4 *2 (-1195)))) ((*1 *1 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-234)) (-5 *3 (-1143)))) ((*1 *2 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-234)))) ((*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869))))) 
-(((*1 *2 *3 *1 *4 *4 *4 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1027 *5 *6 *7 *3))) (-5 *1 (-1027 *5 *6 *7 *3)) (-4 *3 (-1061 *5 *6 *7)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-634 *6)) (-4 *1 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-1066 *3 *4 *5 *2)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) ((*1 *2 *3 *1 *4 *4 *4 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1131 *5 *6 *7 *3))) (-5 *1 (-1131 *5 *6 *7 *3)) (-4 *3 (-1061 *5 *6 *7))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-541))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 (-169 (-568))))) (-5 *2 (-634 (-169 *4))) (-5 *1 (-380 *4)) (-4 *4 (-13 (-365) (-840))))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-409 (-953 (-169 (-568)))))) (-5 *4 (-634 (-1161))) (-5 *2 (-634 (-634 (-169 *5)))) (-5 *1 (-380 *5)) (-4 *5 (-13 (-365) (-840)))))) 
-(((*1 *2 *1 *2) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) *2)) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-763))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *2 *3 *3) (-12 (|has| *2 (-6 (-4521 "*"))) (-4 *5 (-375 *2)) (-4 *6 (-375 *2)) (-4 *2 (-1047)) (-5 *1 (-108 *2 *3 *4 *5 *6)) (-4 *3 (-1219 *2)) (-4 *4 (-677 *2 *5 *6))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-568)) (-5 *2 (-121)) (-5 *1 (-554))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-1094)) (-5 *3 (-766)) (-5 *1 (-57))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *2 *3 *3 *2 *4) (-12 (-5 *3 (-679 *2)) (-5 *4 (-568)) (-4 *2 (-13 (-301) (-10 -8 (-15 -1678 ((-420 $) $))))) (-4 *5 (-1219 *2)) (-5 *1 (-508 *2 *5 *6)) (-4 *6 (-411 *2 *5))))) 
+(((*1 *1 *1 *2 *1) (-12 (-5 *1 (-136 *2)) (-4 *2 (-1090)))) ((*1 *1 *2) (-12 (-5 *1 (-136 *2)) (-4 *2 (-1090))))) 
 (((*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-1047)) (-4 *2 (-1219 *5)) (-5 *1 (-1237 *5 *2 *6 *3)) (-4 *6 (-646 *2)) (-4 *3 (-1234 *5))))) 
-(((*1 *2 *3 *3 *3 *4) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)))) (-5 *2 (-2 (|:| |a| *6) (|:| |b| (-409 *6)) (|:| |h| *6) (|:| |c1| (-409 *6)) (|:| |c2| (-409 *6)) (|:| -3492 *6))) (-5 *1 (-1016 *5 *6)) (-5 *3 (-409 *6))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -2534 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3651 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-5 *1 (-563))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3))))) 
+(((*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1161)) (-5 *6 (-634 (-607 *3))) (-5 *5 (-607 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *7))) (-4 *7 (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-2 (|:| -4151 *3) (|:| |coeff| *3))) (-5 *1 (-559 *7 *3))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-372 *4 *5)) (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-679 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-411 *3 *4)) (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-679 *3))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-239 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-473)))) ((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1245)))) ((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1246))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) (-5 *2 (-121)) (-5 *1 (-202))))) 
+(((*1 *2 *3 *3 *3 *4) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)))) (-5 *2 (-2 (|:| |a| *6) (|:| |b| (-409 *6)) (|:| |h| *6) (|:| |c1| (-409 *6)) (|:| |c2| (-409 *6)) (|:| -3494 *6))) (-5 *1 (-1016 *5 *6)) (-5 *3 (-409 *6))))) 
+(((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1 (-1114 *4 *3 *5))) (-4 *4 (-43 (-409 (-568)))) (-4 *4 (-1047)) (-4 *3 (-842)) (-5 *1 (-1114 *4 *3 *5)) (-4 *5 (-950 *4 (-534 *3) *3)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1 (-1190 *4))) (-5 *3 (-1161)) (-5 *1 (-1190 *4)) (-4 *4 (-43 (-409 (-568)))) (-4 *4 (-1047))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-375 *2)) (-4 *2 (-1195)) (-4 *2 (-842)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (-4 *1 (-375 *3)) (-4 *3 (-1195)))) ((*1 *2 *2) (-12 (-5 *2 (-634 (-900 *3))) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) ((*1 *2 *1 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-4 *6 (-1061 *4 *5 *3)) (-5 *2 (-2 (|:| |under| *1) (|:| -4115 *1) (|:| |upper| *1))) (-4 *1 (-977 *4 *5 *3 *6))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 *5 *4 *4)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-5 *2 (-1 *5 *4)) (-5 *1 (-672 *4 *5))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-375 *2)) (-4 *2 (-1195)) (-4 *2 (-842)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (-4 *1 (-375 *3)) (-4 *3 (-1195)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-969 *2)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1122 *2)) (-4 *2 (-1047)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-1149 *3 *4))) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-541)) (-5 *1 (-540 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-5 *2 (-57)) (-5 *1 (-541))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-121)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-465))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-1 (-121) (-123) (-123))) (-5 *1 (-123))))) 
+(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472))))) 
 (((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-381)) (-5 *1 (-184))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-917)) (-5 *2 (-473)) (-5 *1 (-1245))))) 
+(((*1 *2 *2 *3 *3) (-12 (-5 *2 (-1141 *4)) (-5 *3 (-568)) (-4 *4 (-1047)) (-5 *1 (-1145 *4)))) ((*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1201 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3))) ((*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-1161))))) 
+(((*1 *2 *1 *2) (-12 (-4 *1 (-366 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090))))) 
+(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-314 *3 *4 *5)) (-4 *3 (-13 (-365) (-842))) (-14 *4 (-1161)) (-14 *5 *3)))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-2 (|:| |ans| *6) (|:| -3286 *6) (|:| |sol?| (-121))) (-568) *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-5 *2 (-2 (|:| |answer| (-585 (-409 *7))) (|:| |a0| *6))) (-5 *1 (-578 *6 *7)) (-5 *3 (-409 *7))))) 
+(((*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| -4151 (-409 *6)) (|:| |coeff| (-409 *6)))) (-5 *1 (-578 *5 *6)) (-5 *3 (-409 *6))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-381)) (-5 *1 (-184))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-601 *2 *3)) (-4 *3 (-1195)) (-4 *2 (-1090)) (-4 *2 (-842))))) 
+(((*1 *2 *2 *3) (-12 (-4 *3 (-558)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-1186 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -2723 *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3))))) 
+(((*1 *2) (-12 (-4 *2 (-13 (-432 *3) (-1002))) (-5 *1 (-272 *3 *2)) (-4 *3 (-13 (-842) (-558)))))) 
+(((*1 *2 *3 *1 *4) (-12 (-5 *3 (-1125 *5 *6)) (-5 *4 (-1 (-121) *6 *6)) (-4 *5 (-13 (-1090) (-39))) (-4 *6 (-13 (-1090) (-39))) (-5 *2 (-121)) (-5 *1 (-1126 *5 *6))))) 
 (((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-239 *2)) (-4 *2 (-1195)))) ((*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) ((*1 *1 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
+(((*1 *1 *2 *3 *1 *3) (-12 (-5 *2 (-887 *4)) (-4 *4 (-1090)) (-5 *1 (-884 *4 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1249)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-258 *12))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-587 *4)) (-4 *4 (-350))))) 
+(((*1 *2 *3 *4 *5 *6 *7 *8 *9) (|partial| -12 (-5 *4 (-634 *11)) (-5 *5 (-634 (-1157 *9))) (-5 *6 (-634 *9)) (-5 *7 (-634 *12)) (-5 *8 (-634 (-763))) (-4 *11 (-842)) (-4 *9 (-301)) (-4 *12 (-950 *9 *10 *11)) (-4 *10 (-788)) (-5 *2 (-634 (-1157 *12))) (-5 *1 (-697 *10 *11 *9 *12)) (-5 *3 (-1157 *12))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-993 *4)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4))) (-5 *1 (-143 *4 *5 *3)) (-4 *3 (-375 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-993 *4)) (-5 *2 (-2 (|:| |num| *6) (|:| |den| *4))) (-5 *1 (-512 *4 *5 *6 *3)) (-4 *6 (-375 *4)) (-4 *3 (-375 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-679 *5)) (-4 *5 (-993 *4)) (-4 *4 (-558)) (-5 *2 (-2 (|:| |num| (-679 *4)) (|:| |den| *4))) (-5 *1 (-682 *4 *5)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-2 (|:| -2410 *7) (|:| |rh| (-634 (-409 *6))))) (-5 *1 (-802 *5 *6 *7 *3)) (-5 *4 (-634 (-409 *6))) (-4 *7 (-646 *6)) (-4 *3 (-646 (-409 *6))))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-993 *4)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4))) (-5 *1 (-1212 *4 *5 *3)) (-4 *3 (-1219 *5))))) 
 (((*1 *2 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-102)))) ((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-205 (-511))) (-5 *1 (-830))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-350)) (-5 *2 (-420 (-1157 (-1157 *5)))) (-5 *1 (-1194 *5)) (-5 *3 (-1157 (-1157 *5)))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
+(((*1 *1) (-5 *1 (-1249)))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1161)) (-5 *5 (-1084 (-215))) (-5 *2 (-927)) (-5 *1 (-925 *3)) (-4 *3 (-609 (-541))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-5 *2 (-927)) (-5 *1 (-925 *3)) (-4 *3 (-609 (-541))))) ((*1 *1 *2) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *1 (-927)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927))))) 
+(((*1 *1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *3 (-558))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
 (((*1 *2 *1 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
+(((*1 *2 *3 *4 *5) (-12 (-4 *6 (-1219 *9)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *9 (-301)) (-4 *10 (-950 *9 *7 *8)) (-5 *2 (-2 (|:| |deter| (-634 (-1157 *10))) (|:| |dterm| (-634 (-634 (-2 (|:| -2514 (-763)) (|:| |pcoef| *10))))) (|:| |nfacts| (-634 *6)) (|:| |nlead| (-634 *10)))) (-5 *1 (-771 *6 *7 *8 *9 *10)) (-5 *3 (-1157 *10)) (-5 *4 (-634 *6)) (-5 *5 (-634 *10))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-121))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-381)) (-5 *1 (-1059))))) 
+(((*1 *2) (-12 (-5 *2 (-835 (-568))) (-5 *1 (-539)))) ((*1 *1) (-12 (-5 *1 (-835 *2)) (-4 *2 (-1090))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-453)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1157 *6)) (-4 *6 (-950 *5 *3 *4)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-904)) (-5 *1 (-459 *3 *4 *5 *6)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-904))))) 
+(((*1 *2 *3) (-12 (-4 *1 (-795)) (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-1035))))) 
 (((*1 *2 *3 *4 *2 *2 *2 *5) (-12 (-5 *3 (-123)) (-5 *5 (-634 *2)) (-4 *2 (-13 (-432 *6) (-23) (-1037 (-568)) (-1037 *4) (-895 *4) (-161))) (-5 *4 (-1161)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *1 (-1024 *6 *2))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-550)) (-5 *2 (-121))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-121))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *4) (|:| |xpnt| (-568)))) (-4 *4 (-13 (-1219 *3) (-558) (-10 -8 (-15 -2723 ($ $ $))))) (-4 *3 (-558)) (-5 *1 (-1222 *3 *4))))) 
+(((*1 *2 *1) (|partial| -12 (-5 *2 (-1057 (-1023 *3) (-1157 (-1023 *3)))) (-5 *1 (-1023 *3)) (-4 *3 (-13 (-840) (-365) (-1021)))))) 
+(((*1 *2) (-12 (-5 *2 (-835 (-568))) (-5 *1 (-539)))) ((*1 *1) (-12 (-5 *1 (-835 *2)) (-4 *2 (-1090))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-1215 *3 *2)) (-4 *2 (-1219 *3))))) 
+(((*1 *1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1125 *4 *5))) (-5 *3 (-1 (-121) *5 *5)) (-4 *4 (-13 (-1090) (-39))) (-4 *5 (-13 (-1090) (-39))) (-5 *1 (-1126 *4 *5)))) ((*1 *1 *1 *1 *2) (-12 (-5 *2 (-634 (-1125 *3 *4))) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))) (-5 *1 (-1126 *3 *4))))) 
 (((*1 *2 *2 *3 *4) (|partial| -12 (-5 *2 (-634 (-1157 *7))) (-5 *3 (-1157 *7)) (-4 *7 (-950 *5 *6 *4)) (-4 *5 (-904)) (-4 *6 (-788)) (-4 *4 (-842)) (-5 *1 (-901 *5 *6 *4 *7))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1866 *7) (|:| -1844 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *5 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3)))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 (-381))) (-5 *1 (-256)))) ((*1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-558)) (-4 *2 (-172)))) ((*1 *2 *1) (-12 (-5 *1 (-420 *2)) (-4 *2 (-558))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-130 *3))))) 
+(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1141 *3)) (-4 *3 (-1090)) (-4 *3 (-1195))))) 
+(((*1 *2 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-744))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-259 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-2 (|:| |totdeg| (-763)) (|:| -1416 *4))) (-5 *5 (-763)) (-4 *4 (-950 *6 *7 *8)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-5 *2 (-2 (|:| |lcmfij| *7) (|:| |totdeg| *5) (|:| |poli| *4) (|:| |polj| *4))) (-5 *1 (-450 *6 *7 *8 *4))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-409 (-568))) (-5 *2 (-215)) (-5 *1 (-299))))) 
+(((*1 *1 *1 *1) (-4 *1 (-146))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *2 *2 *2) (-12 (-5 *1 (-160 *2)) (-4 *2 (-550)))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *2 *3 *4) (-12 (-5 *4 |RationalNumber|) (-5 *2 (-1 (-568))) (-5 *1 (-1045)) (-5 *3 (-568))))) 
+(((*1 *1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850))))) 
+(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 (-1084 (-409 (-568))))) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-1084 (-381)))) (-5 *1 (-256))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-230 (-1699 *5) (-763))) (-5 *2 (-1157 (-1157 *4))) (-5 *1 (-32 *4 *5 *3 *6 *7)) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *7 (-971 *4))))) 
+(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
 (((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 *4)) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
-(((*1 *2 *3 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-365) (-840))) (-5 *2 (-634 (-2 (|:| -3276 (-634 *3)) (|:| -2183 *5)))) (-5 *1 (-178 *5 *3)) (-4 *3 (-1219 (-169 *5))))) ((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-634 (-2 (|:| -3276 (-634 *3)) (|:| -2183 *4)))) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4)))))) 
-(((*1 *2 *3 *3 *3 *4 *5) (-12 (-5 *5 (-1 *3 *3)) (-4 *3 (-1219 *6)) (-4 *6 (-13 (-365) (-150) (-1037 *4))) (-5 *4 (-568)) (-5 *2 (-3 (|:| |ans| (-2 (|:| |ans| *3) (|:| |nosol| (-121)))) (|:| -1853 (-2 (|:| |b| *3) (|:| |c| *3) (|:| |m| *4) (|:| |alpha| *3) (|:| |beta| *3))))) (-5 *1 (-1015 *6 *3))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-159 *4 *2)) (-4 *2 (-432 *4)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-161)) (-5 *2 (-1161)))) ((*1 *1 *1) (-4 *1 (-161)))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |integrand| *3) (|:| |intvar| *3)))) (-5 *1 (-585 *3)) (-4 *3 (-365))))) 
+(((*1 *2 *2 *2 *3) (-12 (-5 *2 (-1244 (-568))) (-5 *3 (-568)) (-5 *1 (-1100)))) ((*1 *2 *3 *2 *4) (-12 (-5 *2 (-1244 (-568))) (-5 *3 (-634 (-568))) (-5 *4 (-568)) (-5 *1 (-1100))))) 
+(((*1 *2 *2 *3 *4 *5) (-12 (-5 *2 (-634 *9)) (-5 *3 (-1 (-121) *9)) (-5 *4 (-1 (-121) *9 *9)) (-5 *5 (-1 *9 *9 *9)) (-4 *9 (-1061 *6 *7 *8)) (-4 *6 (-558)) (-4 *7 (-788)) (-4 *8 (-842)) (-5 *1 (-978 *6 *7 *8 *9))))) 
+(((*1 *2 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3))))) 
+(((*1 *1 *2 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568))))) 
+(((*1 *2 *3 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-365) (-840))) (-5 *2 (-634 (-2 (|:| -2075 (-634 *3)) (|:| -2185 *5)))) (-5 *1 (-178 *5 *3)) (-4 *3 (-1219 (-169 *5))))) ((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-634 (-2 (|:| -2075 (-634 *3)) (|:| -2185 *4)))) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-568)) (-5 *1 (-196))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1094)) (-5 *2 (-1249)) (-5 *1 (-102))))) 
+(((*1 *2 *3 *2 *4 *5) (-12 (-5 *2 (-634 *3)) (-5 *5 (-917)) (-4 *3 (-1219 *4)) (-4 *4 (-301)) (-5 *1 (-462 *4 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-1219 *4)) (-5 *1 (-544 *4 *2 *5 *6)) (-4 *4 (-301)) (-14 *5 *4) (-14 *6 (-1 *4 *4 (-763)))))) 
+(((*1 *2 *3 *3) (|partial| -12 (-4 *4 (-13 (-365) (-150) (-1037 (-568)))) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| -4151 (-409 *5)) (|:| |coeff| (-409 *5)))) (-5 *1 (-572 *4 *5)) (-5 *3 (-409 *5))))) 
+(((*1 *2 *2 *2 *3) (-12 (-5 *2 (-634 (-568))) (-5 *3 (-121)) (-5 *1 (-1100))))) 
+(((*1 *2 *3 *3 *3 *4 *5) (-12 (-5 *5 (-1 *3 *3)) (-4 *3 (-1219 *6)) (-4 *6 (-13 (-365) (-150) (-1037 *4))) (-5 *4 (-568)) (-5 *2 (-3 (|:| |ans| (-2 (|:| |ans| *3) (|:| |nosol| (-121)))) (|:| -2410 (-2 (|:| |b| *3) (|:| |c| *3) (|:| |m| *4) (|:| |alpha| *3) (|:| |beta| *3))))) (-5 *1 (-1015 *6 *3))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1157 *2)) (-4 *2 (-950 (-409 (-953 *6)) *5 *4)) (-5 *1 (-722 *5 *4 *6 *2)) (-4 *5 (-788)) (-4 *4 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $))))) (-4 *6 (-558))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-634 (-1 *4 (-634 *4)))) (-4 *4 (-1090)) (-5 *1 (-122 *4)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *4 *4)) (-4 *4 (-1090)) (-5 *1 (-122 *4)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-123)) (-5 *2 (-634 (-1 *4 (-634 *4)))) (-5 *1 (-122 *4)) (-4 *4 (-1090))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-121))))) 
+(((*1 *2 *2 *3) (-12 (-4 *3 (-558)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-1186 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1866 *7) (|:| -1844 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *5 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *4))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-139)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-828 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-835 *3)) (-4 *3 (-1090))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047))))) 
+(((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-169 (-215)) (-169 (-215)))) (-5 *4 (-1084 (-215))) (-5 *2 (-1246)) (-5 *1 (-250))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-301)) (-4 *6 (-375 *5)) (-4 *4 (-375 *5)) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2588 (-634 *4)))) (-5 *1 (-1112 *5 *6 *4 *3)) (-4 *3 (-677 *5 *6 *4))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1195)) (-5 *1 (-1120 *4 *2)) (-4 *2 (-13 (-601 (-568) *4) (-10 -7 (-6 -4521) (-6 -4522)))))) ((*1 *2 *2) (-12 (-4 *3 (-842)) (-4 *3 (-1195)) (-5 *1 (-1120 *3 *2)) (-4 *2 (-13 (-601 (-568) *3) (-10 -7 (-6 -4521) (-6 -4522))))))) 
+(((*1 *1) (-12 (-5 *1 (-233 *2)) (-4 *2 (-1047))))) 
+(((*1 *1) (-5 *1 (-439)))) 
 (((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1157 *9)) (-5 *4 (-634 *7)) (-4 *7 (-842)) (-4 *9 (-950 *8 *6 *7)) (-4 *6 (-788)) (-4 *8 (-301)) (-5 *2 (-634 (-763))) (-5 *1 (-732 *6 *7 *8 *9)) (-5 *5 (-763))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-171))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568))))) (-14 *4 (-634 (-1161))) (-14 *5 (-763)) (-5 *2 (-121)) (-5 *1 (-515 *4 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-1244 (-679 *4))))) ((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-1244 (-679 *4))) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4)))) ((*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-1244 (-679 *3))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1161))) (-4 *5 (-365)) (-5 *2 (-1244 (-679 (-409 (-953 *5))))) (-5 *1 (-1077 *5)) (-5 *4 (-679 (-409 (-953 *5)))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1161))) (-4 *5 (-365)) (-5 *2 (-1244 (-679 (-953 *5)))) (-5 *1 (-1077 *5)) (-5 *4 (-679 (-953 *5))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-679 *4))) (-4 *4 (-365)) (-5 *2 (-1244 (-679 *4))) (-5 *1 (-1077 *4))))) 
+(((*1 *2 *3 *1) (-12 (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1157 (-409 (-953 *3)))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-432 *2)) (-4 *2 (-842)) (-4 *2 (-1047)))) ((*1 *1 *1) (-12 (-5 *1 (-733 *2 *3)) (-14 *2 (-1161)) (-4 *3 (-13 (-1047) (-842) (-558))))) ((*1 *1 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *4) (-12 (-5 *2 (-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568))) (-5 *4 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))))) ((*1 *2 *3 *4) (-12 (-5 *2 (-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568))) (-5 *4 (-409 (-568))))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-409 (-568))) (-5 *2 (-634 (-2 (|:| -3030 *5) (|:| -3286 *5)))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568))) (-5 *4 (-2 (|:| -3030 *5) (|:| -3286 *5))))) ((*1 *2 *3) (-12 (-5 *2 (-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 (-409 (-568)))))) ((*1 *2 *3 *4) (-12 (-5 *2 (-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 (-409 (-568)))) (-5 *4 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-409 (-568))) (-5 *2 (-634 (-2 (|:| -3030 *4) (|:| -3286 *4)))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-409 (-568))) (-5 *2 (-634 (-2 (|:| -3030 *5) (|:| -3286 *5)))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 *5)) (-5 *4 (-2 (|:| -3030 *5) (|:| -3286 *5)))))) 
+(((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *4 (-1161)) (-5 *6 (-121)) (-4 *7 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-4 *3 (-13 (-1181) (-959) (-29 *7))) (-5 *2 (-3 (|:| |f1| (-835 *3)) (|:| |f2| (-634 (-835 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-209 *7 *3)) (-5 *5 (-835 *3))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-585 *3)) (-4 *3 (-365))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1231 *3)) (-4 *3 (-1195)) (-5 *2 (-763))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1195)) (-5 *2 (-634 *1)) (-4 *1 (-1010 *3))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-215))) (-5 *4 (-1161)) (-5 *5 (-1084 (-835 (-215)))) (-5 *2 (-634 (-215))) (-5 *1 (-184)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-215))) (-5 *4 (-1161)) (-5 *5 (-1084 (-835 (-215)))) (-5 *2 (-634 (-215))) (-5 *1 (-294))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-173 *2)) (-4 *2 (-301))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-568)) (-4 *6 (-641 *5)) (-4 *5 (-365)) (-5 *2 (-679 *5)) (-5 *1 (-635 *5 *6))))) 
+(((*1 *2 *3 *2 *4) (-12 (-5 *3 (-679 *2)) (-5 *4 (-763)) (-4 *2 (-13 (-301) (-10 -8 (-15 -3498 ((-420 $) $))))) (-4 *5 (-1219 *2)) (-5 *1 (-508 *2 *5 *6)) (-4 *6 (-411 *2 *5))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-230 *6 *2)) (-14 *6 *2) (-5 *2 (-763)) (-5 *1 (-908 *4 *3 *5 *6)) (-4 *3 (-324 *4 *5)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *1 (-950 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-950 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-763))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-350)) (-4 *5 (-327 *4)) (-4 *6 (-1219 *5)) (-5 *2 (-634 *3)) (-5 *1 (-769 *4 *5 *6 *3 *7)) (-4 *3 (-1219 *6)) (-14 *7 (-917))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047))))) 
+(((*1 *2 *3) (-12 (-4 *3 (-1219 *2)) (-4 *2 (-1219 *4)) (-5 *1 (-986 *4 *2 *3 *5)) (-4 *4 (-350)) (-4 *5 (-714 *2 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-324 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787)))) ((*1 *2 *1) (-12 (-4 *1 (-698 *3)) (-4 *3 (-1047)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-844 *3)) (-4 *3 (-1047)) (-5 *2 (-763)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *1 (-950 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 (-763))))) ((*1 *2 *1 *3) (-12 (-4 *1 (-950 *4 *5 *3)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-763))))) 
+(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-927))))) 
 (((*1 *1 *2) (-12 (-5 *2 (-1127 *3 *4)) (-14 *3 (-917)) (-4 *4 (-365)) (-5 *1 (-994 *3 *4))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-634 *1)) (-4 *1 (-296)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-607 *3)) (-4 *3 (-842)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-123)) (-5 *3 (-634 *5)) (-5 *4 (-763)) (-4 *5 (-842)) (-5 *1 (-607 *5))))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-900 *4)) (-4 *4 (-1090)) (-5 *2 (-634 (-763))) (-5 *1 (-899 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)) (-4 *2 (-550)))) ((*1 *1 *1) (-4 *1 (-1056)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-169 *5)) (-4 *5 (-13 (-432 *4) (-1002) (-1181))) (-4 *4 (-13 (-558) (-842))) (-4 *2 (-13 (-432 (-169 *4)) (-1002) (-1181))) (-5 *1 (-597 *4 *5 *2))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-2 (|:| |partsol| (-1244 (-409 (-953 *4)))) (|:| -2588 (-634 (-1244 (-409 (-953 *4))))))) (-5 *3 (-634 *7)) (-4 *4 (-13 (-301) (-150))) (-4 *7 (-950 *4 *6 *5)) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *1 (-924 *4 *5 *6 *7))))) 
+(((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1) (-5 *1 (-850))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *3 (-568)) (-4 *1 (-863 *4))))) 
+(((*1 *1 *2 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3)))) 
 (((*1 *2 *1) (|partial| -12 (-5 *2 (-1157 *1)) (-4 *1 (-1012))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-558)) (-4 *3 (-950 *7 *5 *6)) (-5 *2 (-2 (|:| -3483 (-763)) (|:| -2350 *3) (|:| |radicand| (-634 *3)))) (-5 *1 (-954 *5 *6 *7 *3 *8)) (-5 *4 (-763)) (-4 *8 (-13 (-365) (-10 -8 (-15 -2319 (*3 $)) (-15 -2326 (*3 $)) (-15 -2747 ($ *3)))))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 (-887 *3)))) (-5 *2 (-634 (-1161))) (-5 *1 (-1069 *3 *4 *5)) (-4 *5 (-13 (-432 *4) (-881 *3) (-609 (-887 *3))))))) 
+(((*1 *2 *1 *3) (-12 (-5 *2 (-2 (|:| |k| (-568)) (|:| |c| *4))) (-5 *1 (-774 *4)) (-4 *4 (-365)) (-5 *3 (-568))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-301)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-448 *3 *4 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-1143)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-301)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-448 *4 *5 *6 *7)))) ((*1 *2 *2 *3 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-1143)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-301)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-448 *4 *5 *6 *7))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1157 *5)) (-4 *5 (-453)) (-5 *2 (-634 *6)) (-5 *1 (-543 *5 *6 *4)) (-4 *6 (-365)) (-4 *4 (-13 (-365) (-840))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-953 *5)) (-4 *5 (-453)) (-5 *2 (-634 *6)) (-5 *1 (-543 *5 *6 *4)) (-4 *6 (-365)) (-4 *4 (-13 (-365) (-840)))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1061 *3 *4 *5))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| |stiffnessFactor| (-381)) (|:| |stabilityFactor| (-381)))) (-5 *1 (-197))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-972)) (-5 *1 (-900 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *1 (-989 *3 *4 *5 *6 *7)))) ((*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *1 (-1097 *3 *4 *5 *6 *7))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-1157 *1)) (-5 *3 (-1161)) (-4 *1 (-27)))) ((*1 *1 *2) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-27)))) ((*1 *1 *2) (-12 (-5 *2 (-953 *1)) (-4 *1 (-27)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1161)) (-4 *1 (-29 *3)) (-4 *3 (-13 (-842) (-558))))) ((*1 *1 *1) (-12 (-4 *1 (-29 *2)) (-4 *2 (-13 (-842) (-558)))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-4 *2 (-1219 *4)) (-5 *1 (-918 *4 *2))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-1149 3 *3)))) ((*1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1121 (-215))) (-5 *1 (-1246)))) ((*1 *2 *1) (-12 (-5 *2 (-1121 (-215))) (-5 *1 (-1246))))) 
+(((*1 *2 *1) (-12 (-4 *2 (-1090)) (-5 *1 (-965 *2 *3)) (-4 *3 (-1090))))) 
 (((*1 *1 *2 *3) (-12 (-5 *2 (-1057 (-1023 *4) (-1157 (-1023 *4)))) (-5 *3 (-850)) (-5 *1 (-1023 *4)) (-4 *4 (-13 (-840) (-365) (-1021)))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-634 *2)) (-5 *1 (-177 *2)) (-4 *2 (-301)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-634 (-634 *4))) (-5 *2 (-634 *4)) (-4 *4 (-301)) (-5 *1 (-177 *4)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 (-2 (|:| -2588 (-679 *7)) (|:| |basisDen| *7) (|:| |basisInv| (-679 *7))))) (-5 *5 (-763)) (-4 *8 (-1219 *7)) (-4 *7 (-1219 *6)) (-4 *6 (-350)) (-5 *2 (-2 (|:| -2588 (-679 *7)) (|:| |basisDen| *7) (|:| |basisInv| (-679 *7)))) (-5 *1 (-507 *6 *7 *8)))) ((*1 *2 *2 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *5)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *5)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-1047)) (-5 *1 (-679 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *4)) (-4 *4 (-1047)) (-4 *1 (-1111 *3 *4 *5 *6)) (-4 *5 (-230 *3 *4)) (-4 *6 (-230 *3 *4))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-561 *3)) (-4 *3 (-550)))) ((*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)) (-5 *2 (-420 *3)) (-5 *1 (-732 *4 *5 *6 *3)) (-4 *3 (-950 *6 *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-732 *4 *5 *6 *7)) (-5 *3 (-1157 *7)))) ((*1 *2 *1) (-12 (-4 *3 (-453)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-420 *1)) (-4 *1 (-950 *3 *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-842)) (-4 *5 (-788)) (-4 *6 (-453)) (-5 *2 (-420 *3)) (-5 *1 (-980 *4 *5 *6 *3)) (-4 *3 (-950 *6 *5 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-453)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-420 (-1157 (-409 *7)))) (-5 *1 (-1156 *4 *5 *6 *7)) (-5 *3 (-1157 (-409 *7))))) ((*1 *2 *1) (-12 (-5 *2 (-420 *1)) (-4 *1 (-1199)))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-420 *3)) (-5 *1 (-1222 *4 *3)) (-4 *3 (-13 (-1219 *4) (-558) (-10 -8 (-15 -2723 ($ $ $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1044 *4 *5)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *5 (-634 (-1161))) (-5 *2 (-634 (-1131 *4 (-534 (-852 *6)) (-852 *6) (-775 *4 (-852 *6))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *6 (-634 (-1161)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 *5)) (-4 *5 (-1090)) (-5 *2 (-1 *5 *4)) (-5 *1 (-672 *4 *5)) (-4 *4 (-1090)))) ((*1 *2 *3) (-12 (-4 *4 (-230 *5 (-763))) (-14 *5 (-763)) (-4 *2 (-1047)) (-5 *1 (-908 *2 *3 *4 *5)) (-4 *3 (-324 *2 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-842)) (-5 *1 (-930 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-310 (-568))) (-5 *1 (-931)))) ((*1 *2 *1) (-12 (-4 *1 (-1259 *3 *2)) (-4 *3 (-842)) (-4 *2 (-1047)))) ((*1 *2 *1) (-12 (-4 *2 (-1047)) (-5 *1 (-1265 *2 *3)) (-4 *3 (-838))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-851)))) ((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1249)) (-5 *1 (-851)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-850)) (-5 *2 (-1249)) (-5 *1 (-851)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-1141 *4)) (-4 *4 (-1090)) (-4 *4 (-1195))))) 
+(((*1 *1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-381))) (-5 *1 (-1039))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-926))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465)))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 *4 (-763) (-763) (-1157 *4))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 *4) (-763))))) (-5 *1 (-484 *4)) (-4 *4 (-13 (-350) (-609 (-568)))))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 *4 (-763) (-763) (-1157 *4))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 *4) (-763)))) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465)))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 *6) *6 (-1161))) (|:| A (-1 *5 (-763) (-763) (-1157 *5))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 *6 (-763) (-1161) *6)) (|:| C (-1 (-634 *5) (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 *6) *6 *3)) (|:| A (-1 *5 (-763) (-763) (-1157 *5))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 *6 (-763) *3 *6)) (|:| C (-1 (-634 *5) (-763)))) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465)))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 HPSPEC) (-5 *1 (-488 *4)) (-14 *4 (-1161)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 HPSPEC (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3)))) 
+(((*1 *2 *3 *3 *4 *5 *5) (-12 (-5 *5 (-121)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *4)))) (-5 *1 (-1067 *6 *7 *8 *3 *4)) (-4 *4 (-1066 *6 *7 *8 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-2 (|:| |val| (-634 *8)) (|:| -3145 *9)))) (-5 *5 (-121)) (-4 *8 (-1061 *6 *7 *4)) (-4 *9 (-1066 *6 *7 *4 *8)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *4 (-842)) (-5 *2 (-634 (-2 (|:| |val| *8) (|:| -3145 *9)))) (-5 *1 (-1067 *6 *7 *4 *8 *9))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-568)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-465))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1228 *3 *4 *5)) (-5 *1 (-314 *3 *4 *5)) (-4 *3 (-13 (-365) (-842))) (-14 *4 (-1161)) (-14 *5 *3))) ((*1 *2 *1) (-12 (-4 *1 (-406)) (-5 *2 (-568)))) ((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-420 *3)) (-4 *3 (-558)))) ((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-688)))) ((*1 *2 *1) (-12 (-4 *2 (-1090)) (-5 *1 (-703 *3 *2 *4)) (-4 *3 (-842)) (-14 *4 (-1 (-121) (-2 (|:| -4355 *3) (|:| -3438 *2)) (-2 (|:| -4355 *3) (|:| -3438 *2))))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-121)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1064 *6 *7 *8 *3 *4)) (-4 *4 (-1066 *6 *7 *8 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1130 *5 *6 *7 *3 *4)) (-4 *4 (-1099 *5 *6 *7 *3))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-763)) (-5 *1 (-1091 *4 *5)) (-14 *4 *3) (-14 *5 *3)))) 
+(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-1143)) (-5 *1 (-184)))) ((*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-1143)) (-5 *1 (-294)))) ((*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-1143)) (-5 *1 (-299))))) 
+(((*1 *1) (-12 (-4 *3 (-1090)) (-5 *1 (-880 *2 *3 *4)) (-4 *2 (-1090)) (-4 *4 (-658 *3)))) ((*1 *1) (-12 (-5 *1 (-884 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-420 *3)) (-4 *3 (-558)) (-5 *1 (-421 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1228 *3 *4 *5)) (-5 *1 (-314 *3 *4 *5)) (-4 *3 (-13 (-365) (-842))) (-14 *4 (-1161)) (-14 *5 *3))) ((*1 *2 *1) (-12 (-4 *1 (-406)) (-5 *2 (-568)))) ((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-420 *3)) (-4 *3 (-558)))) ((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-688)))) ((*1 *2 *1) (-12 (-4 *2 (-1090)) (-5 *1 (-703 *3 *2 *4)) (-4 *3 (-842)) (-14 *4 (-1 (-121) (-2 (|:| -4357 *3) (|:| -3483 *2)) (-2 (|:| -4357 *3) (|:| -3483 *2))))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 *4)) (-5 *1 (-1126 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39)))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |polnum| (-777 *3)) (|:| |polden| *3) (|:| -2567 (-763)))) (-5 *1 (-777 *3)) (-4 *3 (-1047)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| |polnum| *1) (|:| |polden| *1) (|:| -2567 (-763)))) (-4 *1 (-1061 *3 *4 *5))))) 
+(((*1 *2 *3 *3 *4 *5 *5) (-12 (-5 *5 (-121)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *4)))) (-5 *1 (-1098 *6 *7 *8 *3 *4)) (-4 *4 (-1066 *6 *7 *8 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-2 (|:| |val| (-634 *8)) (|:| -3145 *9)))) (-5 *5 (-121)) (-4 *8 (-1061 *6 *7 *4)) (-4 *9 (-1066 *6 *7 *4 *8)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *4 (-842)) (-5 *2 (-634 (-2 (|:| |val| *8) (|:| -3145 *9)))) (-5 *1 (-1098 *6 *7 *4 *8 *9))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-236 (-922 *4))) (-4 *4 (-350)) (-5 *2 (-679 *4)) (-5 *1 (-867 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-236 (-922 *5))) (-5 *4 (-634 (-922 *5))) (-4 *5 (-350)) (-5 *2 (-679 *5)) (-5 *1 (-867 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-236 (-921 *4))) (-4 *4 (-365)) (-5 *2 (-679 *4)) (-5 *1 (-868 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-236 (-921 *5))) (-5 *4 (-634 (-921 *5))) (-4 *5 (-365)) (-5 *2 (-679 *5)) (-5 *1 (-868 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-3 (-121) "failed")) (-4 *3 (-453)) (-4 *4 (-842)) (-4 *5 (-788)) (-5 *1 (-988 *3 *4 *5 *6)) (-4 *6 (-950 *3 *5 *4))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-234)) (-5 *3 (-1143)))) ((*1 *2 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-234)))) ((*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
 (((*1 *2 *3 *2) (-12 (-5 *2 (-634 (-1084 (-381)))) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-1084 (-381)))) (-5 *1 (-256)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1084 (-381)))) (-5 *1 (-473)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-1084 (-381)))) (-5 *1 (-473))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 (-634 *2))) (-5 *4 (-634 *5)) (-4 *5 (-43 (-409 (-568)))) (-4 *2 (-1234 *5)) (-5 *1 (-1236 *5 *2))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1244 *5)) (-4 *5 (-630 *4)) (-4 *4 (-558)) (-5 *2 (-121)) (-5 *1 (-629 *4 *5))))) 
+(((*1 *2 *3 *3 *3 *4 *5 *4 *6) (-12 (-5 *3 (-310 (-568))) (-5 *4 (-1 (-215) (-215))) (-5 *5 (-1084 (-215))) (-5 *6 (-568)) (-5 *2 (-1191 (-926))) (-5 *1 (-313)))) ((*1 *2 *3 *3 *3 *4 *5 *4 *6 *7) (-12 (-5 *3 (-310 (-568))) (-5 *4 (-1 (-215) (-215))) (-5 *5 (-1084 (-215))) (-5 *6 (-568)) (-5 *7 (-1143)) (-5 *2 (-1191 (-926))) (-5 *1 (-313)))) ((*1 *2 *3 *3 *3 *4 *5 *6 *7) (-12 (-5 *3 (-310 (-568))) (-5 *4 (-1 (-215) (-215))) (-5 *5 (-1084 (-215))) (-5 *6 (-215)) (-5 *7 (-568)) (-5 *2 (-1191 (-926))) (-5 *1 (-313)))) ((*1 *2 *3 *3 *3 *4 *5 *6 *7 *8) (-12 (-5 *3 (-310 (-568))) (-5 *4 (-1 (-215) (-215))) (-5 *5 (-1084 (-215))) (-5 *6 (-215)) (-5 *7 (-568)) (-5 *8 (-1143)) (-5 *2 (-1191 (-926))) (-5 *1 (-313))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-428 *5 *3)) (-4 *3 (-13 (-1181) (-29 *5)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-121)) (-5 *1 (-263))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-1094)) (-5 *3 (-766)) (-5 *1 (-57))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-1244 *5)) (-4 *5 (-630 *4)) (-4 *4 (-558)) (-5 *2 (-1244 *4)) (-5 *1 (-629 *4 *5))))) 
 (((*1 *1 *2) (-12 (-5 *2 (-679 *4)) (-4 *4 (-1047)) (-5 *1 (-1127 *3 *4)) (-14 *3 (-763))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-288 (-835 *3))) (-4 *3 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (-835 *3) (-2 (|:| |leftHandLimit| (-3 (-835 *3) "failed")) (|:| |rightHandLimit| (-3 (-835 *3) "failed"))) "failed")) (-5 *1 (-627 *5 *3)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-288 *3)) (-5 *5 (-1143)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-835 *3)) (-5 *1 (-627 *6 *3)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-288 (-835 (-953 *5)))) (-4 *5 (-453)) (-5 *2 (-3 (-835 (-409 (-953 *5))) (-2 (|:| |leftHandLimit| (-3 (-835 (-409 (-953 *5))) "failed")) (|:| |rightHandLimit| (-3 (-835 (-409 (-953 *5))) "failed"))) "failed")) (-5 *1 (-628 *5)) (-5 *3 (-409 (-953 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-288 (-409 (-953 *5)))) (-5 *3 (-409 (-953 *5))) (-4 *5 (-453)) (-5 *2 (-3 (-835 *3) (-2 (|:| |leftHandLimit| (-3 (-835 *3) "failed")) (|:| |rightHandLimit| (-3 (-835 *3) "failed"))) "failed")) (-5 *1 (-628 *5)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-288 (-409 (-953 *6)))) (-5 *5 (-1143)) (-5 *3 (-409 (-953 *6))) (-4 *6 (-453)) (-5 *2 (-835 *3)) (-5 *1 (-628 *6))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-121)) (-5 *1 (-445 *4 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-634 *5)) (-4 *5 (-1219 *3)) (-4 *3 (-301)) (-5 *2 (-121)) (-5 *1 (-457 *3 *5))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-150)) (-4 *3 (-301)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1108)) (-5 *2 (-1249)) (-5 *1 (-826))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1160)) (-5 *1 (-328))))) 
 (((*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-852 *5))) (-14 *5 (-634 (-1161))) (-4 *6 (-453)) (-5 *2 (-634 (-634 (-242 *5 *6)))) (-5 *1 (-476 *5 *6 *7)) (-5 *3 (-634 (-242 *5 *6))) (-4 *7 (-453))))) 
+(((*1 *2) (-12 (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-568)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-867 *3 *4 *5)) (-4 (-857 *3) (-370)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-381)))) ((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-381))))) 
+(((*1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247)))) ((*1 *2 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *2)) (-4 *2 (-432 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-634 *8))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-667 *3)) (-4 *3 (-842)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-814 *3)) (-4 *3 (-842))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-173 *3)) (-4 *3 (-301))))) 
+(((*1 *2 *2) (|partial| -12 (-5 *1 (-561 *2)) (-4 *2 (-550))))) 
+(((*1 *1 *2 *3) (-12 (-5 *3 (-363 (-123))) (-4 *2 (-1047)) (-5 *1 (-704 *2 *4)) (-4 *4 (-637 *2)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-363 (-123))) (-5 *1 (-829 *2)) (-4 *2 (-1047))))) 
+(((*1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-634 *1)) (-4 *1 (-296)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-607 *3)) (-4 *3 (-842)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-123)) (-5 *3 (-634 *5)) (-5 *4 (-763)) (-4 *5 (-842)) (-5 *1 (-607 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-763)) (-5 *1 (-589))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-360 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-763)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-568)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-465))))) 
 (((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
+(((*1 *2) (-12 (-4 *2 (-172)) (-5 *1 (-165 *3 *2)) (-4 *3 (-166 *2)))) ((*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-372 *2 *4)) (-4 *4 (-1219 *2)) (-4 *2 (-172)))) ((*1 *2) (-12 (-4 *4 (-1219 *2)) (-4 *2 (-172)) (-5 *1 (-410 *3 *2 *4)) (-4 *3 (-411 *2 *4)))) ((*1 *2) (-12 (-4 *1 (-411 *2 *3)) (-4 *3 (-1219 *2)) (-4 *2 (-172)))) ((*1 *2) (-12 (-4 *3 (-1219 *2)) (-5 *2 (-568)) (-5 *1 (-760 *3 *4)) (-4 *4 (-411 *2 *3)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-950 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *3 (-172)))) ((*1 *2 *3) (-12 (-4 *2 (-558)) (-5 *1 (-970 *2 *3)) (-4 *3 (-1219 *2)))) ((*1 *2 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-172))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 (-679 (-310 (-568))))) (-5 *1 (-1031))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-365)) (-5 *2 (-634 *3)) (-5 *1 (-946 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-96 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-212 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-842)) (-5 *2 (-121)) (-5 *1 (-494 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| *1 (-6 -4521)) (-4 *1 (-499 *4)) (-4 *4 (-1195)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-1000 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4521)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-1132 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-842)) (-5 *2 (-634 (-656 *4 *5))) (-5 *1 (-618 *4 *5 *6)) (-4 *5 (-13 (-172) (-707 (-409 (-568))))) (-14 *6 (-917))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-121))))) 
+(((*1 *2 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5))))) 
 (((*1 *2 *1 *2) (-12 (-5 *1 (-1026 *2)) (-4 *2 (-1195))))) 
+(((*1 *2) (-12 (-5 *2 (-1244 (-634 (-2 (|:| -2852 (-905 *3)) (|:| -4357 (-1108)))))) (-5 *1 (-352 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917)))) ((*1 *2) (-12 (-5 *2 (-1244 (-634 (-2 (|:| -2852 *3) (|:| -4357 (-1108)))))) (-5 *1 (-353 *3 *4)) (-4 *3 (-350)) (-14 *4 (-3 (-1157 *3) *2)))) ((*1 *2) (-12 (-5 *2 (-1244 (-634 (-2 (|:| -2852 *3) (|:| -4357 (-1108)))))) (-5 *1 (-354 *3 *4)) (-4 *3 (-350)) (-14 *4 (-917))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-453)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-1143))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1141 (-409 *3))) (-5 *1 (-173 *3)) (-4 *3 (-301))))) 
+(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-763)) (-5 *1 (-165 *3 *4)) (-4 *3 (-166 *4)))) ((*1 *2) (-12 (-14 *4 *2) (-4 *5 (-1195)) (-5 *2 (-763)) (-5 *1 (-229 *3 *4 *5)) (-4 *3 (-230 *4 *5)))) ((*1 *2) (-12 (-4 *4 (-842)) (-5 *2 (-763)) (-5 *1 (-431 *3 *4)) (-4 *3 (-432 *4)))) ((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-549 *3)) (-4 *3 (-550)))) ((*1 *2) (-12 (-4 *1 (-755)) (-5 *2 (-763)))) ((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-763)) (-5 *1 (-791 *3 *4)) (-4 *3 (-792 *4)))) ((*1 *2) (-12 (-4 *4 (-558)) (-5 *2 (-763)) (-5 *1 (-992 *3 *4)) (-4 *3 (-993 *4)))) ((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-763)) (-5 *1 (-996 *3 *4)) (-4 *3 (-997 *4)))) ((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1011 *3)) (-4 *3 (-1012)))) ((*1 *2) (-12 (-4 *1 (-1047)) (-5 *2 (-763)))) ((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1055 *3)) (-4 *3 (-1056))))) 
 (((*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465)))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 *4 (-763) (-763) (-1157 *4))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 *4) (-763))))) (-5 *1 (-484 *4)) (-4 *4 (-13 (-350) (-609 (-568)))))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 *4 (-763) (-763) (-1157 *4))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 *4) (-763)))) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465)))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 *6) *6 (-1161))) (|:| A (-1 *5 (-763) (-763) (-1157 *5))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 *6 (-763) (-1161) *6)) (|:| C (-1 (-634 *5) (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 *6) *6 *3)) (|:| A (-1 *5 (-763) (-763) (-1157 *5))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 *6 (-763) *3 *6)) (|:| C (-1 (-634 *5) (-763)))) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465)))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 HPSPEC) (-5 *1 (-488 *4)) (-14 *4 (-1161)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 HPSPEC (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3)))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *7 (-230 (-1699 *6) (-763))) (-4 *8 (-971 *5)) (-4 *4 (-920 *5 *2)) (-4 *9 (-235 *4)) (-4 *10 (-536 *5 *6 *3 *7 *8 *2 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-641 *5)) (-5 *1 (-467 *5 *6 *3 *7 *8 *2 *4 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-242 *6 *5)) (-5 *4 (-922 *5)) (-4 *5 (-350)) (-14 *6 (-634 (-1161))) (-5 *2 (-774 (-857 *5))) (-5 *1 (-867 *5 *6 *7)) (-4 *7 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-242 *6 *5)) (-5 *4 (-921 *5)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-5 *2 (-774 *5)) (-5 *1 (-868 *5 *6 *7)) (-4 *7 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 *2)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1699 *6) (-763))) (-4 *2 (-641 *5)) (-5 *1 (-871 *5 *6 *3 *7 *8 *2 *9)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5)) (-4 *9 (-920 *5 *2)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1699 *6) (-763))) (-4 *2 (-641 *5)) (-5 *1 (-871 *5 *6 *3 *7 *8 *2 *4)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5)) (-4 *4 (-920 *5 *2)))) ((*1 *2 *3 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1699 *6) (-763))) (-4 *2 (-641 *5)) (-5 *1 (-871 *5 *6 *3 *7 *8 *2 *4)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5)) (-4 *4 (-920 *5 *2)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-568)) (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *8 (-230 (-1699 *7) (-763))) (-4 *2 (-641 *6)) (-5 *1 (-871 *6 *7 *3 *8 *9 *2 *4)) (-4 *3 (-950 *6 *8 (-852 *7))) (-4 *9 (-971 *6)) (-4 *4 (-920 *6 *2))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1244 (-1244 *4))) (-4 *4 (-1047)) (-5 *2 (-679 *4)) (-5 *1 (-1029 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1263 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-814 *3)))) ((*1 *2 *1) (-12 (-4 *2 (-838)) (-5 *1 (-1265 *3 *2)) (-4 *3 (-1047))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-850)))) ((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1249)) (-5 *1 (-962))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-121)) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-4 *3 (-13 (-27) (-1181) (-432 *6) (-10 -8 (-15 -2747 ($ *7))))) (-4 *7 (-840)) (-4 *8 (-13 (-1221 *3 *7) (-365) (-1181) (-10 -8 (-15 -4191 ($ $)) (-15 -1845 ($ $))))) (-5 *2 (-3 (|:| |%series| *8) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143)))))) (-5 *1 (-424 *6 *3 *7 *8 *9 *10)) (-5 *5 (-1143)) (-4 *9 (-984 *8)) (-14 *10 (-1161))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-123))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465)))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 *4 (-763) (-763) (-1157 *4))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 *4) (-763))))) (-5 *1 (-484 *4)) (-4 *4 (-13 (-350) (-609 (-568)))))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 *4 (-763) (-763) (-1157 *4))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 *4) (-763)))) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465)))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 *6) *6 (-1161))) (|:| A (-1 *5 (-763) (-763) (-1157 *5))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 *6 (-763) (-1161) *6)) (|:| C (-1 (-634 *5) (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 *6) *6 *3)) (|:| A (-1 *5 (-763) (-763) (-1157 *5))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 *6 (-763) *3 *6)) (|:| C (-1 (-634 *5) (-763)))) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) *3)) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) *3 (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465)))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 HPSPEC) (-5 *1 (-488 *4)) (-14 *4 (-1161)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 HPSPEC (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3)))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-763)) (-5 *5 (-634 *3)) (-4 *3 (-301)) (-4 *6 (-842)) (-4 *7 (-788)) (-5 *2 (-121)) (-5 *1 (-617 *6 *7 *3 *8)) (-4 *8 (-950 *3 *7 *6))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-121)) (-5 *1 (-824))))) 
+(((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-350)) (-4 *4 (-327 *3)) (-4 *5 (-1219 *4)) (-5 *1 (-769 *3 *4 *5 *2 *6)) (-4 *2 (-1219 *5)) (-14 *6 (-917)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-4 *3 (-370)))) ((*1 *1 *1) (-12 (-4 *1 (-1261 *2)) (-4 *2 (-365)) (-4 *2 (-370))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-328))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-820))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1201 *2)) (-4 *2 (-1047)))) ((*1 *1 *1) (-12 (-5 *1 (-1235 *2 *3 *4)) (-4 *2 (-1047)) (-14 *3 (-1161)) (-14 *4 *2))) ((*1 *1 *1) (-12 (-5 *1 (-1239 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-1161))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-1226 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1203 *3))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-989 *5 *6 *7 *8 *3)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-1097 *5 *6 *7 *8 *3))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-568)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-568))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-818)) (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-111 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) ((*1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-736 *3)) (-4 *3 (-172))))) 
+(((*1 *1 *2 *3) (-12 (-5 *1 (-429 *3 *2)) (-4 *3 (-13 (-172) (-43 (-409 (-568))))) (-4 *2 (-13 (-842) (-21)))))) 
 (((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-325 *3)) (-4 *3 (-1195)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-525 *3 *4)) (-4 *3 (-1195)) (-14 *4 *2)))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1697 *6) (-763))) (-4 *2 (-920 *5 *8)) (-5 *1 (-654 *5 *6 *4 *7 *3 *8 *2)) (-4 *4 (-950 *5 *7 (-852 *6))) (-4 *3 (-971 *5)) (-4 *8 (-641 *5))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-634 (-2 (|:| |lcmfij| *3) (|:| |totdeg| (-763)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *3 (-788)) (-4 *6 (-950 *4 *3 *5)) (-4 *4 (-453)) (-4 *5 (-842)) (-5 *1 (-450 *4 *3 *5 *6))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-409 *4)) (-4 *4 (-1219 *3)) (-4 *3 (-13 (-365) (-150))) (-5 *1 (-401 *3 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-1143))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-568)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-465))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *5)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *1 *2) (-12 (-4 *2 (-1047)) (-4 *1 (-1111 *3 *2 *4 *5)) (-4 *4 (-230 *3 *2)) (-4 *5 (-230 *3 *2))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *7 (-1219 *5)) (-4 *4 (-714 *5 *7)) (-5 *2 (-2 (|:| -2928 (-679 *6)) (|:| |vec| (-1244 *5)))) (-5 *1 (-806 *5 *6 *7 *4 *3)) (-4 *6 (-646 *5)) (-4 *3 (-646 *4))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-904)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-950 *4 *5 *6)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-901 *4 *5 *6 *7)) (-5 *3 (-1157 *7)))) ((*1 *2 *3) (-12 (-4 *4 (-904)) (-4 *5 (-1219 *4)) (-5 *2 (-420 (-1157 *5))) (-5 *1 (-902 *4 *5)) (-5 *3 (-1157 *5))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-775 *5 (-852 *6)))) (-5 *4 (-121)) (-4 *5 (-453)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-1131 *5 (-534 (-852 *6)) (-852 *6) (-775 *5 (-852 *6))))) (-5 *1 (-619 *5 *6))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *4)))) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-850)))) ((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1249)) (-5 *1 (-962))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-763)) (-5 *1 (-446 *3)) (-4 *3 (-1047)))) ((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-446 *3)) (-4 *3 (-1047))))) 
-(((*1 *1) (-12 (-4 *1 (-427 *2)) (-4 *2 (-370)) (-4 *2 (-1090))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-1047))))) 
-(((*1 *1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1059))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-5 *2 (-1157 *3)) (-5 *1 (-1170 *3)) (-4 *3 (-365))))) 
-(((*1 *2 *2 *2 *3) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-242 (-4287 (QUOTE X) (QUOTE -2926)) *4)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *7 (-230 (-1697 *5) (-763))) (-5 *2 (-634 (-634 (-763)))) (-5 *1 (-119 *4 *5 *6 *7 *8)) (-4 *6 (-324 *4 *7)) (-4 *8 (-117))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-4 *6 (-881 *5)) (-5 *2 (-880 *5 *6 (-634 *6))) (-5 *1 (-882 *5 *6 *4)) (-5 *3 (-634 *6)) (-4 *4 (-609 (-887 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-5 *2 (-634 (-288 *3))) (-5 *1 (-882 *5 *3 *4)) (-4 *3 (-1037 (-1161))) (-4 *3 (-881 *5)) (-4 *4 (-609 (-887 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-5 *2 (-634 (-288 (-953 *3)))) (-5 *1 (-882 *5 *3 *4)) (-4 *3 (-1047)) (-3044 (-4 *3 (-1037 (-1161)))) (-4 *3 (-881 *5)) (-4 *4 (-609 (-887 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-5 *2 (-884 *5 *3)) (-5 *1 (-882 *5 *3 *4)) (-3044 (-4 *3 (-1037 (-1161)))) (-3044 (-4 *3 (-1047))) (-4 *3 (-881 *5)) (-4 *4 (-609 (-887 *5)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-5 *2 (-121)) (-5 *1 (-586 *3)) (-4 *3 (-550))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-3 (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print"))) (-5 *1 (-328))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4519)) (-4 *1 (-227 *3)) (-4 *3 (-1090)))) ((*1 *1 *2 *1) (-12 (|has| *1 (-6 -4519)) (-4 *1 (-227 *2)) (-4 *2 (-1090)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-277 *2)) (-4 *2 (-1195)) (-4 *2 (-1090)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-277 *3)) (-4 *3 (-1195)))) ((*1 *2 *3 *1) (|partial| -12 (-4 *1 (-605 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090)))) ((*1 *1 *2 *1 *3) (-12 (-5 *2 (-1 (-121) *4)) (-5 *3 (-568)) (-4 *4 (-1090)) (-5 *1 (-727 *4)))) ((*1 *1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-727 *2)) (-4 *2 (-1090)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))) (-5 *1 (-1126 *3 *4))))) 
-(((*1 *2 *3 *4 *2 *5 *6) (-12 (-5 *5 (-2 (|:| |done| (-634 *11)) (|:| |todo| (-634 (-2 (|:| |val| *3) (|:| -3001 *11)))))) (-5 *6 (-763)) (-5 *2 (-634 (-2 (|:| |val| (-634 *10)) (|:| -3001 *11)))) (-5 *3 (-634 *10)) (-5 *4 (-634 *11)) (-4 *10 (-1061 *7 *8 *9)) (-4 *11 (-1066 *7 *8 *9 *10)) (-4 *7 (-453)) (-4 *8 (-788)) (-4 *9 (-842)) (-5 *1 (-1064 *7 *8 *9 *10 *11)))) ((*1 *2 *3 *4 *2 *5 *6) (-12 (-5 *5 (-2 (|:| |done| (-634 *11)) (|:| |todo| (-634 (-2 (|:| |val| *3) (|:| -3001 *11)))))) (-5 *6 (-763)) (-5 *2 (-634 (-2 (|:| |val| (-634 *10)) (|:| -3001 *11)))) (-5 *3 (-634 *10)) (-5 *4 (-634 *11)) (-4 *10 (-1061 *7 *8 *9)) (-4 *11 (-1099 *7 *8 *9 *10)) (-4 *7 (-453)) (-4 *8 (-788)) (-4 *9 (-842)) (-5 *1 (-1130 *7 *8 *9 *10 *11))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-978 *4 *5 *6 *2))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2850 *4) (|:| -2183 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568))))) 
-(((*1 *2 *1) (-12 (-14 *3 (-634 (-1161))) (-4 *4 (-172)) (-14 *6 (-1 (-121) (-2 (|:| -4355 *5) (|:| -3438 *2)) (-2 (|:| -4355 *5) (|:| -3438 *2)))) (-4 *2 (-230 (-1697 *3) (-763))) (-5 *1 (-463 *3 *4 *5 *2 *6 *7)) (-4 *5 (-842)) (-4 *7 (-950 *4 *2 (-852 *3)))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-301)) (-5 *1 (-912 *3 *4 *5 *2)) (-4 *2 (-950 *5 *3 *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1157 *6)) (-4 *6 (-950 *5 *3 *4)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-301)) (-5 *1 (-912 *3 *4 *5 *6)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *6 *4 *5)) (-5 *1 (-912 *4 *5 *6 *2)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-4 *1 (-258 *3)))) ((*1 *1 *2) (-12 (-4 *1 (-258 *2)) (-4 *2 (-1090)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-258 *2)) (-4 *2 (-1090)))) ((*1 *1 *2) (-12 (-5 *1 (-1182 *2)) (-4 *2 (-1090)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-1182 *3)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-634 (-1182 *2))) (-5 *1 (-1182 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *3 *4 *2 *3 *2 *3) (-12 (-5 *2 (-958 (-215))) (-5 *3 (-1108)) (-5 *4 (-215)) (-5 *1 (-115))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) ((*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-405 *3)) (-4 *3 (-406)))) ((*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-405 *3)) (-4 *3 (-406)))) ((*1 *2 *2) (-12 (-5 *2 (-917)) (|has| *1 (-6 -4510)) (-4 *1 (-406)))) ((*1 *2) (-12 (-4 *1 (-406)) (-5 *2 (-917)))) ((*1 *2 *1) (-12 (-4 *1 (-863 *3)) (-5 *2 (-1141 (-568)))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 (-1157 (-1157 *4)))) (-5 *1 (-1194 *4)) (-5 *3 (-1157 (-1157 *4)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-439))))) 
+(((*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-1067 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6)))) ((*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-1098 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176))))) 
-(((*1 *2 *1 *2) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) *2)) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-763))))) 
-(((*1 *2 *3 *1) (-12 (-4 *1 (-977 *4 *5 *3 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-4 *6 (-1061 *4 *5 *3)) (-5 *2 (-121))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) *2)) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-763))))) 
+(((*1 *1) (-5 *1 (-158)))) 
+(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-927))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-123)))) ((*1 *2 *1) (-12 (-4 *1 (-366 *2 *3)) (-4 *3 (-1090)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-1143)))) ((*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-440 *3)) (-14 *3 *2))) ((*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-607 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-1068 *3)) (-14 *3 *2))) ((*1 *1 *1) (-5 *1 (-1161)))) 
 (((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1092 (-1092 *3))) (-5 *1 (-899 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1141 *3)) (-4 *3 (-1090)) (-4 *3 (-1195))))) 
-(((*1 *2 *3 *4 *4) (-12 (-5 *4 (-763)) (-4 *5 (-350)) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-2 (|:| -3746 (-679 *6)) (|:| |basisDen| *6) (|:| |basisInv| (-679 *6))))) (-5 *1 (-507 *5 *6 *7)) (-5 *3 (-2 (|:| -3746 (-679 *6)) (|:| |basisDen| *6) (|:| |basisInv| (-679 *6)))) (-4 *7 (-1219 *6))))) 
-(((*1 *2 *2 *2) (|partial| -12 (-4 *3 (-365)) (-5 *1 (-891 *2 *3)) (-4 *2 (-1219 *3))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-43 (-409 (-568)))) (-5 *2 (-2 (|:| -1976 (-1141 *4)) (|:| -1980 (-1141 *4)))) (-5 *1 (-1147 *4)) (-5 *3 (-1141 *4))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1699 *6) (-763))) (-4 *2 (-920 *5 *8)) (-5 *1 (-654 *5 *6 *4 *7 *3 *8 *2)) (-4 *4 (-950 *5 *7 (-852 *6))) (-4 *3 (-971 *5)) (-4 *8 (-641 *5))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
 (((*1 *1 *2) (-12 (-5 *2 (-634 (-1069 *3 *4 *5))) (-4 *3 (-1090)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 (-887 *3)))) (-4 *5 (-13 (-432 *4) (-881 *3) (-609 (-887 *3)))) (-5 *1 (-1070 *3 *4 *5))))) 
-(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
-(((*1 *2 *2) (|partial| -12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1163 (-409 (-568)))) (-5 *2 (-409 (-568))) (-5 *1 (-182))))) 
+(((*1 *1 *1) (|partial| -4 *1 (-148))) ((*1 *1 *1) (-4 *1 (-350))) ((*1 *1 *1) (|partial| -12 (-4 *1 (-148)) (-4 *1 (-904))))) 
 (((*1 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-142)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-147))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-679 (-310 (-215)))) (-5 *2 (-2 (|:| |stiffnessFactor| (-381)) (|:| |stabilityFactor| (-381)))) (-5 *1 (-197))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-603 *2)) (-4 *2 (-1090)))) ((*1 *1 *1) (-5 *1 (-623)))) 
-(((*1 *2 *1 *1 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-2 (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-950 *4 *5 *3)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-1047)) (-5 *2 (-2 (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-1219 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-166 *3)) (-4 *3 (-172)) (-4 *3 (-1056)) (-4 *3 (-1181)) (-5 *2 (-2 (|:| |r| *3) (|:| |phi| *3)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1195)) (-5 *1 (-377 *4 *2)) (-4 *2 (-13 (-375 *4) (-10 -7 (-6 -4520))))))) 
-(((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-129 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *2) (-12 (-5 *2 (-763)) (-5 *1 (-129 *3)) (-4 *3 (-1219 (-568)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))))) ((*1 *2 *3) (-12 (-5 *3 (-57)) (-5 *2 (-121)) (-5 *1 (-56 *4)) (-4 *4 (-1195)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161))))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-667 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-888 *3)) (-4 *3 (-842))))) 
-(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-607 *7)) (-4 *7 (-13 (-432 *6) (-23) (-1037 *2) (-1037 *5) (-895 *5) (-161))) (-5 *5 (-1161)) (-4 *6 (-1047)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-568)) (-5 *1 (-1024 *6 *7))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-121)) (-5 *1 (-123))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-381)) (-5 *2 (-215)) (-5 *1 (-299))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-277 *2)) (-4 *2 (-1195)) (-4 *2 (-1090)))) ((*1 *1 *1) (-12 (-4 *1 (-684 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-215)) (-5 *5 (-568)) (-5 *2 (-1191 *3)) (-5 *1 (-785 *3)) (-4 *3 (-975)))) ((*1 *1 *2 *3 *4) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *4 (-121)) (-5 *1 (-1191 *2)) (-4 *2 (-975))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-324 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047)) (-4 *2 (-453)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1219 (-568))) (-5 *2 (-634 (-568))) (-5 *1 (-496 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-453)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-950 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *3 (-453))))) 
-(((*1 *2 *2 *2 *2 *3) (-12 (-4 *3 (-558)) (-5 *1 (-970 *3 *2)) (-4 *2 (-1219 *3))))) 
-(((*1 *1) (-5 *1 (-563)))) 
-(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-568)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-568))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1265 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-838))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-634 *4))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *6 (-230 (-1699 *5) *2)) (-4 *7 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-763)) (-5 *1 (-260 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-763)) (-5 *1 (-339 *3 *4 *5 *6)) (-4 *3 (-340 *4 *5 *6)))) ((*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-763)))) ((*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) *2)) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-763)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-634 (-2 (|:| |lcmfij| *3) (|:| |totdeg| (-763)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *3 (-788)) (-4 *6 (-950 *4 *3 *5)) (-4 *4 (-453)) (-4 *5 (-842)) (-5 *1 (-450 *4 *3 *5 *6))))) 
+(((*1 *2 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *2 (-558)) (-5 *1 (-970 *2 *4)) (-4 *4 (-1219 *2))))) 
+(((*1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4))))) 
+(((*1 *2 *3 *1) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-1164)) (-5 *3 (-1161))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-819))))) 
+(((*1 *2) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
+(((*1 *2 *3 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-634 (-568))))) ((*1 *2 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-634 (-568)))))) 
+(((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
+(((*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-409 *4)) (-4 *4 (-1219 *3)) (-4 *3 (-13 (-365) (-150))) (-5 *1 (-401 *3 *4))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-981 *2)) (-4 *2 (-1047)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-944 (-215))) (-5 *1 (-1192)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-1047))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| |radval| (-310 (-568))) (|:| |radmult| (-568)) (|:| |radvect| (-634 (-679 (-310 (-568)))))))) (-5 *1 (-1031))))) 
+(((*1 *2 *1 *2) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-1010 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-518 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-842))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-1219 *4)) (-4 *4 (-1199)) (-4 *1 (-340 *4 *3 *5)) (-4 *5 (-1219 (-409 *3)))))) 
+(((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-634 (-2 (|:| |func| *2) (|:| |pole| (-121))))) (-4 *2 (-13 (-432 *4) (-1002))) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-272 *4 *2))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-568)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-465))))) 
+(((*1 *2 *3 *3 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-1 (-634 *4) *4)) (-5 *1 (-107 *4)) (-5 *3 (-634 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-4 *3 (-558)) (-5 *2 (-1157 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-2 (|:| |num| (-1244 *4)) (|:| |den| *4)))))) 
 (((*1 *1 *2 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-5 *1 (-1069 *4 *5 *2)) (-4 *2 (-13 (-432 *5) (-881 *4) (-609 (-887 *4)))))) ((*1 *1 *2 *2) (-12 (-4 *3 (-1090)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 (-887 *3)))) (-5 *1 (-1069 *3 *4 *2)) (-4 *2 (-13 (-432 *4) (-881 *3) (-609 (-887 *3))))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-917)) (|has| *1 (-6 -4510)) (-4 *1 (-406)))) ((*1 *2) (-12 (-4 *1 (-406)) (-5 *2 (-917)))) ((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-688)))) ((*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-688))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-1141 *3))) (-5 *2 (-1141 *3)) (-5 *1 (-1145 *3)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-646 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) ((*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 *4 *4)) (-4 *4 (-365)) (-5 *1 (-649 *4 *2)) (-4 *2 (-646 *4))))) 
-(((*1 *2 *2) (|partial| -12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-1157 *1)) (-5 *3 (-1161)) (-4 *1 (-858)))) ((*1 *1 *2 *1 *3) (-12 (-5 *2 (-1157 *1)) (-5 *3 (-1161)) (-4 *1 (-858)))) ((*1 *1 *2 *2 *3 *1 *4) (-12 (-5 *2 (-1157 (-860))) (-5 *3 (-917)) (-5 *4 (-1161)) (-5 *1 (-860))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-568)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *2 *2 *3) (-12 (-4 *4 (-788)) (-4 *3 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $))))) (-4 *5 (-558)) (-5 *1 (-722 *4 *3 *5 *2)) (-4 *2 (-950 (-409 (-953 *5)) *4 *3)))) ((*1 *2 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $)) (-15 -1305 ((-3 $ "failed") (-1161)))))) (-5 *1 (-985 *4 *5 *3 *2)) (-4 *2 (-950 (-953 *4) *5 *3)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $)) (-15 -1305 ((-3 $ "failed") (-1161)))))) (-4 *4 (-1047)) (-4 *5 (-788)) (-5 *1 (-985 *4 *5 *6 *2)) (-4 *2 (-950 (-953 *4) *5 *6))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-816)) (-5 *4 (-57)) (-5 *2 (-1249)) (-5 *1 (-826))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-277 *2)) (-4 *2 (-1195)) (-4 *2 (-842)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (-4 *1 (-277 *3)) (-4 *3 (-1195)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-969 *2)) (-4 *2 (-842))))) 
-(((*1 *2 *3 *3 *2) (-12 (-5 *2 (-1035)) (-5 *3 (-1161)) (-5 *1 (-184))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-500)))) ((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-700))))) 
-(((*1 *2 *3 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-970 *5 *3)) (-4 *3 (-1219 *5))))) 
-(((*1 *2 *2 *3 *2) (-12 (-5 *3 (-763)) (-4 *4 (-350)) (-5 *1 (-207 *4 *2)) (-4 *2 (-1219 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-492 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-1047)) (-5 *2 (-953 *5)) (-5 *1 (-945 *4 *5))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| -4192 (-123)) (|:| |w| (-215)))) (-5 *1 (-196))))) 
-(((*1 *1 *1 *2 *1) (-12 (-4 *1 (-134 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *4 (-365)) (-5 *2 (-634 *1)) (-4 *1 (-37 *4)))) ((*1 *2 *1) (-12 (-4 *3 (-365)) (-5 *2 (-634 *1)) (-4 *1 (-37 *3)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-898 *3)) (-4 *3 (-1090)) (-5 *2 (-1092 *3)))) ((*1 *2 *1 *3) (-12 (-4 *4 (-1090)) (-5 *2 (-1092 (-634 *4))) (-5 *1 (-899 *4)) (-5 *3 (-634 *4)))) ((*1 *2 *1 *3) (-12 (-4 *4 (-1090)) (-5 *2 (-1092 (-1092 *4))) (-5 *1 (-899 *4)) (-5 *3 (-1092 *4)))) ((*1 *2 *1 *3) (-12 (-5 *2 (-1092 *3)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *4 (-365)) (-5 *2 (-634 *1)) (-4 *1 (-971 *4)))) ((*1 *2 *1) (-12 (-4 *3 (-365)) (-5 *2 (-634 *1)) (-4 *1 (-971 *3))))) 
-(((*1 *1 *1 *1) (-5 *1 (-121))) ((*1 *1 *1 *1) (-4 *1 (-132)))) 
-(((*1 *1 *1) (-12 (-4 *2 (-301)) (-4 *3 (-993 *2)) (-4 *4 (-1219 *3)) (-5 *1 (-415 *2 *3 *4 *5)) (-4 *5 (-13 (-411 *3 *4) (-1037 *3)))))) 
-(((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 (-763) *2)) (-5 *4 (-763)) (-4 *2 (-1090)) (-5 *1 (-668 *2)))) ((*1 *2 *2) (-12 (-5 *2 (-1 *3 (-763) *3)) (-4 *3 (-1090)) (-5 *1 (-671 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-171)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1191 *3)) (-4 *3 (-975))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *2 *2) (-12 (-4 *2 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *1 (-1116 *3 *2)) (-4 *3 (-1219 *2))))) 
-(((*1 *2 *2 *3 *2) (-12 (-5 *3 (-763)) (-4 *4 (-350)) (-5 *1 (-207 *4 *2)) (-4 *2 (-1219 *4)))) ((*1 *2 *2 *3 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-685 *2)) (-4 *2 (-1219 *3))))) 
-(((*1 *2 *3) (|partial| -12 (-4 *5 (-1037 (-53))) (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-4 *5 (-432 *4)) (-5 *2 (-420 (-1157 (-53)))) (-5 *1 (-437 *4 *5 *3)) (-4 *3 (-1219 *5))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1164))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-369 *2)) (-4 *2 (-172))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1044 *4 *5)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *5 (-634 (-1161))) (-5 *2 (-634 (-2 (|:| -3471 (-1157 *4)) (|:| -4073 (-634 (-953 *4)))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *6 (-634 (-1161))))) ((*1 *2 *3 *4 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-2 (|:| -3471 (-1157 *5)) (|:| -4073 (-634 (-953 *5)))))) (-5 *1 (-1268 *5 *6 *7)) (-5 *3 (-634 (-953 *5))) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-2 (|:| -3471 (-1157 *5)) (|:| -4073 (-634 (-953 *5)))))) (-5 *1 (-1268 *5 *6 *7)) (-5 *3 (-634 (-953 *5))) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-2 (|:| -3471 (-1157 *5)) (|:| -4073 (-634 (-953 *5)))))) (-5 *1 (-1268 *5 *6 *7)) (-5 *3 (-634 (-953 *5))) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-2 (|:| -3471 (-1157 *4)) (|:| -4073 (-634 (-953 *4)))))) (-5 *1 (-1268 *4 *5 *6)) (-5 *3 (-634 (-953 *4))) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-366 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090))))) 
-(((*1 *1 *1 *1 *1) (-4 *1 (-550)))) 
-(((*1 *2 *3 *3 *4) (-12 (-5 *3 (-763)) (-4 *2 (-13 (-558) (-453))) (-5 *1 (-346 *2 *4)) (-4 *4 (-52 *2 *3))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *3 (-1102)) (-4 *3 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-432 *3)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (|partial| -12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-950 *3 *4 *5)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-634 *3)) (-5 *1 (-951 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2745 ($ *7)) (-15 -2317 (*7 $)) (-15 -2324 (*7 $)))))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-679 (-953 *4))) (-5 *1 (-1028 *4)) (-4 *4 (-1047))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-438))))) 
-(((*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *4 (-869)) (-5 *5 (-917)) (-5 *6 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-1248)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *4 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-1248))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *5 (-558)) (-5 *2 (-2 (|:| |minor| (-634 (-917))) (|:| -1853 *3) (|:| |minors| (-634 (-634 (-917)))) (|:| |ops| (-634 *3)))) (-5 *1 (-95 *5 *3)) (-5 *4 (-917)) (-4 *3 (-646 *5))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 *4)) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-824)) (-5 *3 (-1143))))) 
-(((*1 *1) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) ((*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| |answer| *3) (|:| |polypart| *3))) (-5 *1 (-578 *5 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-917)) (|has| *1 (-6 -4512)) (-4 *1 (-406)))) ((*1 *2) (-12 (-4 *1 (-406)) (-5 *2 (-917)))) ((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-688)))) ((*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-688))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-13 (-365) (-150))) (-5 *2 (-634 (-2 (|:| -3483 (-763)) (|:| -1374 *4) (|:| |num| *4)))) (-5 *1 (-401 *3 *4)) (-4 *4 (-1219 *3))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *5 *4)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-5 *2 (-1 *5)) (-5 *1 (-672 *4 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *2 (-2 (|:| -2963 (-568)) (|:| -2404 (-568)) (|:| -4409 (-568)) (|:| |reste| (-568)) (|:| -2221 (-3 "left" "center" "right" "vertical" "horizontal")))) (-5 *1 (-772 *4 *3 *5 *6)) (-4 *3 (-324 *4 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *5)) (-4 *5 (-324 *4 *6)) (-4 *6 (-230 *7 (-763))) (-14 *7 (-763)) (-4 *4 (-1047)) (-5 *2 (-2 (|:| -2963 (-568)) (|:| -2404 (-568)) (|:| -4409 (-568)) (|:| |reste| (-568)) (|:| -2221 (-3 "left" "center" "right" "vertical" "horizontal")))) (-5 *1 (-772 *4 *5 *6 *7))))) 
+(((*1 *2) (|partial| -12 (-4 *3 (-558)) (-4 *3 (-172)) (-5 *2 (-2 (|:| |particular| *1) (|:| -2588 (-634 *1)))) (-4 *1 (-369 *3)))) ((*1 *2) (|partial| -12 (-5 *2 (-2 (|:| |particular| (-454 *3 *4 *5 *6)) (|:| -2588 (-634 (-454 *3 *4 *5 *6))))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
+(((*1 *1 *2) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-853 *4 *5 *6 *7)) (-4 *4 (-1047)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 *3)) (-14 *7 *3))) ((*1 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-1047)) (-4 *5 (-842)) (-4 *6 (-788)) (-14 *8 (-634 *5)) (-5 *2 (-1249)) (-5 *1 (-1254 *4 *5 *6 *7 *8 *9 *10)) (-4 *7 (-950 *4 *6 *5)) (-14 *9 (-634 *3)) (-14 *10 *3)))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-634 (-215))) (-5 *1 (-196))))) 
+(((*1 *2 *2) (-12 (-4 *2 (-13 (-365) (-840))) (-5 *1 (-178 *2 *3)) (-4 *3 (-1219 (-169 *2)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1090)) (-5 *2 (-1249)) (-5 *1 (-1196 *4)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1090)) (-5 *2 (-1249)) (-5 *1 (-1196 *4))))) 
+(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-1108)) (-5 *2 (-121)) (-5 *1 (-816))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-541)) (-5 *1 (-540 *4)) (-4 *4 (-1195))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-943)) (-5 *3 (-568)))) ((*1 *2 *2) (-12 (-4 *3 (-301)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-1112 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5))))) 
+(((*1 *2) (-12 (-5 *2 (-634 (-917))) (-5 *1 (-1247)))) ((*1 *2 *2) (-12 (-5 *2 (-634 (-917))) (-5 *1 (-1247))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-365)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-763)) (-5 *1 (-529 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-4 *3 (-558)) (-5 *2 (-763)))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *4 (-172)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-763)) (-5 *1 (-678 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-4 *5 (-558)) (-5 *2 (-763))))) 
+(((*1 *2 *3 *3 *4) (|partial| -12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)))) (-5 *2 (-2 (|:| |a| *6) (|:| |b| (-409 *6)) (|:| |c| (-409 *6)) (|:| -3494 *6))) (-5 *1 (-1015 *5 *6)) (-5 *3 (-409 *6))))) 
+(((*1 *2 *2) (|partial| -12 (-5 *1 (-586 *2)) (-4 *2 (-550))))) 
+(((*1 *2) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-121)) (-5 *1 (-339 *3 *4 *5 *6)) (-4 *3 (-340 *4 *5 *6)))) ((*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-1047)) (-4 *2 (-1219 *4)) (-5 *1 (-445 *4 *2)))) ((*1 *2 *3 *2 *4) (-12 (-5 *2 (-409 (-1157 (-310 *5)))) (-5 *3 (-1244 (-310 *5))) (-5 *4 (-568)) (-4 *5 (-13 (-558) (-842))) (-5 *1 (-1118 *5))))) 
+(((*1 *2 *3 *4 *5 *5 *4 *6) (-12 (-5 *4 (-568)) (-5 *6 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-310 (-215)))) (-5 *2 (-121)) (-5 *1 (-263)))) ((*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-121)) (-5 *1 (-263)))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-840)) (-5 *2 (-568)))) ((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1063 *4 *3)) (-4 *4 (-13 (-840) (-365))) (-4 *3 (-1219 *4)) (-5 *2 (-568)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-558) (-842) (-1037 *2) (-630 *2) (-453))) (-5 *2 (-568)) (-5 *1 (-1105 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4))))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-835 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-558) (-842) (-1037 *2) (-630 *2) (-453))) (-5 *2 (-568)) (-5 *1 (-1105 *6 *3)))) ((*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-1143)) (-4 *6 (-13 (-558) (-842) (-1037 *2) (-630 *2) (-453))) (-5 *2 (-568)) (-5 *1 (-1105 *6 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *6))))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-453)) (-5 *2 (-568)) (-5 *1 (-1106 *4)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-835 (-409 (-953 *6)))) (-5 *3 (-409 (-953 *6))) (-4 *6 (-453)) (-5 *2 (-568)) (-5 *1 (-1106 *6)))) ((*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *3 (-409 (-953 *6))) (-5 *4 (-1161)) (-5 *5 (-1143)) (-4 *6 (-453)) (-5 *2 (-568)) (-5 *1 (-1106 *6)))) ((*1 *2 *3) (|partial| -12 (-5 *2 (-568)) (-5 *1 (-1178 *3)) (-4 *3 (-1047))))) 
+(((*1 *2 *3 *4 *5 *5 *5 *5 *4 *6) (-12 (-5 *4 (-568)) (-5 *6 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1149 3 (-215))) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-306))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
+(((*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-844 *3)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-365)) (-4 *5 (-1047)) (-5 *2 (-2 (|:| -4409 *3) (|:| -2607 *3))) (-5 *1 (-845 *5 *3)) (-4 *3 (-844 *5))))) 
+(((*1 *2 *2) (|partial| -12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3))))) 
+(((*1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-824))))) 
+(((*1 *2) (-12 (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-1244 *1)) (-4 *1 (-340 *3 *4 *5)))) ((*1 *2) (-12 (-4 *3 (-13 (-301) (-10 -8 (-15 -3498 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *2 (-2 (|:| -2588 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-5 *1 (-351 *3 *4 *5)) (-4 *5 (-411 *3 *4)))) ((*1 *2) (-12 (-4 *3 (-1219 (-568))) (-5 *2 (-2 (|:| -2588 (-679 (-568))) (|:| |basisDen| (-568)) (|:| |basisInv| (-679 (-568))))) (-5 *1 (-760 *3 *4)) (-4 *4 (-411 (-568) *3)))) ((*1 *2) (-12 (-4 *3 (-350)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| -2588 (-679 *4)) (|:| |basisDen| *4) (|:| |basisInv| (-679 *4)))) (-5 *1 (-986 *3 *4 *5 *6)) (-4 *6 (-714 *4 *5)))) ((*1 *2) (-12 (-4 *3 (-350)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| -2588 (-679 *4)) (|:| |basisDen| *4) (|:| |basisInv| (-679 *4)))) (-5 *1 (-1253 *3 *4 *5 *6)) (-4 *6 (-411 *4 *5))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-301)) (-5 *2 (-763)) (-5 *1 (-457 *5 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-634 *3))))) 
+(((*1 *2 *2 *2) (|partial| -12 (-4 *3 (-365)) (-5 *1 (-758 *2 *3)) (-4 *2 (-698 *3)))) ((*1 *1 *1 *1) (|partial| -12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) ((*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-262 *2)) (-4 *2 (-842)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1161)) (-5 *1 (-852 *3)) (-14 *3 (-634 *2)))) ((*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-990)))) ((*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-1082 *3)) (-4 *3 (-1195)))) ((*1 *2 *1) (-12 (-4 *1 (-1221 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-1161)))) ((*1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1240 *3)) (-14 *3 *2)))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-842) (-1037 (-568)) (-630 (-568)) (-453))) (-5 *2 (-2 (|:| |%term| (-2 (|:| |%coef| (-1228 *4 *5 *6)) (|:| |%expon| (-314 *4 *5 *6)) (|:| |%expTerms| (-634 (-2 (|:| |k| (-409 (-568))) (|:| |c| *4)))))) (|:| |%type| (-1143)))) (-5 *1 (-1229 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1181) (-432 *3))) (-14 *5 (-1161)) (-14 *6 *4)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-568)) (-5 *1 (-234)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-568)) (-5 *1 (-234))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-634 *5))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-568))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
+(((*1 *2 *3 *2) (-12 (-4 *1 (-782)) (-5 *2 (-1035)) (-5 *3 (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))))) ((*1 *2 *3 *2) (-12 (-4 *1 (-782)) (-5 *2 (-1035)) (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-634 *3)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-634 *3)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-634 *3)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-634 *3)) (-5 *1 (-494 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (|has| *1 (-6 -4521)) (-4 *1 (-499 *3)) (-4 *3 (-1195)) (-5 *2 (-634 *3)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-634 *3)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-634 *3)) (-5 *1 (-1132 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| |deg| (-763)) (|:| -1632 *5)))) (-4 *5 (-1219 *4)) (-4 *4 (-350)) (-5 *2 (-634 *5)) (-5 *1 (-207 *4 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-2 (|:| -3850 *5) (|:| -1836 (-568))))) (-5 *4 (-568)) (-4 *5 (-1219 *4)) (-5 *2 (-634 *5)) (-5 *1 (-685 *5))))) 
+(((*1 *1) (-5 *1 (-142)))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *4 *5)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-1 *6 *5)) (-5 *1 (-673 *4 *5 *6))))) 
+(((*1 *2 *3 *3 *3 *4 *5 *6) (-12 (-5 *3 (-310 (-568))) (-5 *4 (-1 (-215) (-215))) (-5 *5 (-1084 (-215))) (-5 *6 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-686))))) 
 (((*1 *2 *3 *3 *3 *3 *4 *5 *5 *6 *7 *8 *8 *3) (-12 (-5 *6 (-634 (-121))) (-5 *7 (-679 (-215))) (-5 *8 (-679 (-568))) (-5 *3 (-568)) (-5 *4 (-215)) (-5 *5 (-121)) (-5 *2 (-1035)) (-5 *1 (-746))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-568))))) 
-(((*1 *1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *2 *1) (-12 (-4 *1 (-366 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-5 *2 (-1143))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2850 *4) (|:| -2183 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-215)) (-5 *3 (-763)) (-5 *1 (-217)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-169 (-215))) (-5 *3 (-763)) (-5 *1 (-217)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *1 *1 *1) (-4 *1 (-1124)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-310 (-381))) (-5 *1 (-299))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-1141 *3))))) 
+(((*1 *2 *3 *4 *3) (-12 (-5 *3 (-1108)) (-5 *4 (-958 (-215))) (-5 *2 (-215)) (-5 *1 (-115))))) 
+(((*1 *1 *1 *1 *2) (-12 (-5 *2 (-568)) (|has| *1 (-6 -4522)) (-4 *1 (-375 *3)) (-4 *3 (-1195))))) 
 (((*1 *2 *3 *3 *3 *4 *4 *4 *4 *5 *6 *5 *4 *7 *3) (-12 (-5 *4 (-679 (-568))) (-5 *5 (-121)) (-5 *7 (-679 (-215))) (-5 *3 (-568)) (-5 *6 (-215)) (-5 *2 (-1035)) (-5 *1 (-746))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-324 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-634 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-634 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-594 *3)) (-4 *3 (-1047)))) ((*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-725 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-716)))) ((*1 *2 *1) (-12 (-4 *1 (-844 *3)) (-4 *3 (-1047)) (-5 *2 (-634 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-1234 *3)) (-4 *3 (-1047)) (-5 *2 (-1141 *3))))) 
 (((*1 *2) (-12 (-5 *2 (-634 *3)) (-5 *1 (-1076 *3)) (-4 *3 (-138))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1108)) (-5 *1 (-328))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1189 *4 *5 *6 *3)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-900 *3))) (-5 *1 (-899 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-953 (-169 *4))) (-4 *4 (-172)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-953 (-169 *5))) (-5 *4 (-917)) (-4 *5 (-172)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-953 *4)) (-4 *4 (-1047)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-953 *5)) (-5 *4 (-917)) (-4 *5 (-1047)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-558)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-409 (-953 (-169 *4)))) (-4 *4 (-558)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 (-953 (-169 *5)))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-310 *4)) (-4 *4 (-558)) (-4 *4 (-842)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-310 *5)) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-842)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-310 (-169 *4))) (-4 *4 (-558)) (-4 *4 (-842)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-310 (-169 *5))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-842)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-296)) (-5 *2 (-634 (-123)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-634 (-953 *4))))) ((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-634 (-953 *4))) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4)))) ((*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-634 (-953 *3))))) ((*1 *2) (-12 (-5 *2 (-634 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) ((*1 *2 *3) (-12 (-5 *3 (-1244 (-454 *4 *5 *6 *7))) (-5 *2 (-634 (-953 *4))) (-5 *1 (-454 *4 *5 *6 *7)) (-4 *4 (-558)) (-4 *4 (-172)) (-14 *5 (-917)) (-14 *6 (-634 (-1161))) (-14 *7 (-1244 (-679 *4)))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2850 *4) (|:| -2183 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1035))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *1 *1 *1) (-4 *1 (-1124)))) 
+(((*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1 *8 *8)) (-5 *5 (-1 (-2 (|:| |ans| *7) (|:| -3286 *7) (|:| |sol?| (-121))) (-568) *7)) (-5 *6 (-634 (-409 *8))) (-4 *7 (-365)) (-4 *8 (-1219 *7)) (-5 *3 (-409 *8)) (-5 *2 (-2 (|:| |answer| (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (|:| |a0| *7))) (-5 *1 (-578 *7 *8))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-917)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-256))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-634 *3)) (-4 *3 (-301)) (-5 *1 (-177 *3))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-641 *2)) (-4 *2 (-365))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
 (((*1 *1 *1 *1) (-12 (-5 *1 (-509 *2)) (-14 *2 (-568)))) ((*1 *1 *1 *1) (-5 *1 (-1108)))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1 (-121) *7 (-634 *7))) (-4 *1 (-1189 *4 *5 *6 *7)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-230 *6 *2)) (-14 *6 *2) (-5 *2 (-763)) (-5 *1 (-908 *4 *3 *5 *6)) (-4 *3 (-324 *4 *5))))) 
 (((*1 *2 *3 *3 *3 *3 *4 *5 *6 *6 *7 *7 *3) (-12 (-5 *4 (-634 (-121))) (-5 *5 (-679 (-215))) (-5 *6 (-679 (-568))) (-5 *7 (-215)) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-746))))) 
-(((*1 *2 *3 *4 *2 *5 *6 *7 *8 *9 *10) (|partial| -12 (-5 *2 (-634 (-1157 *13))) (-5 *3 (-1157 *13)) (-5 *4 (-634 *12)) (-5 *5 (-634 *10)) (-5 *6 (-634 *13)) (-5 *7 (-634 (-634 (-2 (|:| -1876 (-763)) (|:| |pcoef| *13))))) (-5 *8 (-634 (-763))) (-5 *9 (-1244 (-634 (-1157 *10)))) (-4 *12 (-842)) (-4 *10 (-301)) (-4 *13 (-950 *10 *11 *12)) (-4 *11 (-788)) (-5 *1 (-697 *11 *12 *10 *13))))) 
-(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-763)) (-4 *4 (-301)) (-4 *6 (-1219 *4)) (-5 *2 (-1244 (-634 *6))) (-5 *1 (-457 *4 *6)) (-5 *5 (-634 *6))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *3 *4 *3 *5 *3) (-12 (-5 *4 (-679 (-215))) (-5 *5 (-679 (-568))) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-746))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *3)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6))))) 
+(((*1 *2 *2 *3 *4) (-12 (-5 *3 (-634 (-607 *6))) (-5 *4 (-1161)) (-5 *2 (-607 *6)) (-4 *6 (-432 *5)) (-4 *5 (-842)) (-5 *1 (-577 *5 *6))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-358 *3)) (-4 *3 (-350))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-381)))) (-5 *2 (-1084 (-835 (-215)))) (-5 *1 (-299))))) 
+(((*1 *1 *2) (|partial| -12 (-5 *2 (-1257 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *1 (-656 *3 *4)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-656 *3 *4)) (-5 *1 (-1262 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-1246)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
 (((*1 *1 *1) (-12 (-4 *1 (-128 *2)) (-4 *2 (-1195)))) ((*1 *1 *1) (-12 (-5 *1 (-663 *2)) (-4 *2 (-842)))) ((*1 *1 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-842)))) ((*1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) ((*1 *2 *1) (-12 (-4 *2 (-13 (-840) (-365))) (-5 *1 (-1057 *2 *3)) (-4 *3 (-1219 *2))))) 
-(((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *4 (-568)) (-5 *6 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783)))) ((*1 *2 *3 *4 *5 *5 *6 *3 *3 *3 *3) (-12 (-5 *4 (-568)) (-5 *6 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783))))) 
-(((*1 *2 *2 *3 *4 *5) (-12 (-5 *3 (-123)) (-5 *2 (-568)) (-5 *4 (-1161)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *1 (-1024 *6 *5)) (-4 *5 (-13 (-432 *6) (-23) (-1037 *2) (-1037 *4) (-895 *4) (-161)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-568)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1157 *9)) (-5 *4 (-634 *7)) (-5 *5 (-634 (-634 *8))) (-4 *7 (-842)) (-4 *8 (-301)) (-4 *9 (-950 *8 *6 *7)) (-4 *6 (-788)) (-5 *2 (-2 (|:| |upol| (-1157 *8)) (|:| |Lval| (-634 *8)) (|:| |Lfact| (-634 (-2 (|:| -3848 (-1157 *8)) (|:| -3438 (-568))))) (|:| |ctpol| *8))) (-5 *1 (-732 *6 *7 *8 *9))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1219 (-568))) (-5 *1 (-496 *3))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-453)) (-4 *3 (-842)) (-4 *3 (-1037 (-568))) (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-432 *3)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2317 ((-1113 *3 (-607 $)) $)) (-15 -2324 ((-1113 *3 (-607 $)) $)) (-15 -2745 ($ (-1113 *3 (-607 $)))))))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1037 (-568))) (-4 *1 (-296)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-550)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-900 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1892 (-568))))) (-5 *1 (-363 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1892 (-763))))) (-5 *1 (-388 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| -3848 *3) (|:| -3438 (-568))))) (-5 *1 (-420 *3)) (-4 *3 (-558)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1892 (-763))))) (-5 *1 (-814 *3)) (-4 *3 (-842))))) 
+(((*1 *2 *3 *4 *3 *5 *3) (-12 (-5 *4 (-679 (-215))) (-5 *5 (-679 (-568))) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-746))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7))))) 
+(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1247))))) 
+(((*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-4 *5 (-432 *4)) (-5 *2 (-420 (-1157 (-409 (-568))))) (-5 *1 (-437 *4 *5 *3)) (-4 *3 (-1219 *5))))) 
+(((*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-679 (-409 *4)))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-1143)) (-5 *3 (-568)) (-5 *1 (-234))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-310 *5))) (-5 *1 (-1117 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 *5)))) (-5 *4 (-634 (-1161))) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-634 (-310 *5)))) (-5 *1 (-1117 *5))))) 
 (((*1 *2 *3 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-746))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-953 (-568)))) (-5 *1 (-439)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-679 (-215))) (-5 *2 (-1094)) (-5 *1 (-751)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-679 (-568))) (-5 *2 (-1094)) (-5 *1 (-751))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-159 *4 *2)) (-4 *2 (-432 *4)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1082 *2)) (-4 *2 (-432 *4)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-159 *4 *2)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1082 *1)) (-4 *1 (-161)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-161)) (-5 *2 (-1161)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-470 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) ((*1 *1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1262 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1127 *4 *2)) (-14 *4 (-917)) (-4 *2 (-13 (-1047) (-10 -7 (-6 (-4521 "*"))))) (-5 *1 (-897 *4 *2))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
-(((*1 *1) (-12 (-4 *1 (-406)) (-3044 (|has| *1 (-6 -4510))) (-3044 (|has| *1 (-6 -4502))))) ((*1 *2 *1) (-12 (-4 *1 (-427 *2)) (-4 *2 (-1090)) (-4 *2 (-842)))) ((*1 *2 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-4 *1 (-842))) ((*1 *2 *1) (-12 (-4 *1 (-969 *2)) (-4 *2 (-842)))) ((*1 *1) (-5 *1 (-1108)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-953 *4)) (-4 *4 (-13 (-301) (-150))) (-4 *2 (-950 *4 *6 *5)) (-5 *1 (-924 *4 *5 *6 *2)) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-123))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1191 *3)) (-4 *3 (-975))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-819)) (-5 *3 (-634 (-1161))) (-5 *1 (-820))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-634 (-2 (|:| -3850 (-1157 *6)) (|:| -3483 (-568))))) (-4 *6 (-301)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-732 *4 *5 *6 *7)) (-4 *7 (-950 *6 *4 *5)))) ((*1 *1 *1) (-12 (-4 *1 (-1122 *2)) (-4 *2 (-1047))))) 
+(((*1 *2 *3) (-12 (-5 *3 |RationalNumber|) (-5 *2 (-1 (-568))) (-5 *1 (-1045))))) 
 (((*1 *2 *3 *3 *4 *4 *5 *4 *5 *4 *4 *5 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-746))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| -4265 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *1 *2 *2 *2 *2) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-57)) (-5 *1 (-824))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-422 *3 *2 *4 *5)) (-4 *2 (-13 (-27) (-1181) (-432 *3))) (-14 *4 (-1161)) (-14 *5 *2))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-4 *2 (-13 (-27) (-1181) (-432 *3) (-10 -8 (-15 -2745 ($ *4))))) (-4 *4 (-840)) (-4 *5 (-13 (-1221 *2 *4) (-365) (-1181) (-10 -8 (-15 -4189 ($ $)) (-15 -3837 ($ $))))) (-5 *1 (-424 *3 *2 *4 *5 *6 *7)) (-4 *6 (-984 *5)) (-14 *7 (-1161))))) 
-(((*1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-242 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-1047)) (-5 *2 (-953 *5)) (-5 *1 (-945 *4 *5))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-568)))) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| |ans| (-409 *5)) (|:| |nosol| (-121)))) (-5 *1 (-1015 *4 *5)) (-5 *3 (-409 *5))))) 
+(((*1 *1 *1) (-12 (-4 *2 (-150)) (-4 *2 (-301)) (-4 *2 (-453)) (-4 *3 (-842)) (-4 *4 (-788)) (-5 *1 (-988 *2 *3 *4 *5)) (-4 *5 (-950 *2 *4 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-53)) (-5 *2 (-310 (-568))) (-5 *1 (-1107)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1182 *3)) (-4 *3 (-1090))))) 
+(((*1 *1 *1 *1) (-4 *1 (-550)))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-453)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *4 (-1047)) (-5 *2 (-2 (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-1219 *4))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2723 (-777 *3)) (|:| |coef1| (-777 *3)) (|:| |coef2| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -2723 *1) (|:| |coef1| *1) (|:| |coef2| *1))) (-4 *1 (-1061 *3 *4 *5))))) 
 (((*1 *2 *3 *4 *4 *4 *4 *5 *5 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-746))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| -2721 *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)) (-4 *2 (-1181)))) ((*1 *2 *1) (-12 (-5 *1 (-329 *2)) (-4 *2 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-607 *3)) (-4 *3 (-842))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *3 (-558)) (-4 *3 (-172)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-678 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-256))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-500)))) ((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-700))))) 
-(((*1 *2 *3 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-169 (-215)))) (-5 *2 (-1035)) (-5 *1 (-746))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-634 (-288 (-953 *4))))) (-5 *1 (-382 *4)) (-4 *4 (-13 (-840) (-365))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-288 (-409 (-953 (-568)))))) (-5 *2 (-634 (-634 (-288 (-953 *4))))) (-5 *1 (-382 *4)) (-4 *4 (-13 (-840) (-365))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 (-568)))) (-5 *2 (-634 (-288 (-953 *4)))) (-5 *1 (-382 *4)) (-4 *4 (-13 (-840) (-365))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-288 (-409 (-953 (-568))))) (-5 *2 (-634 (-288 (-953 *4)))) (-5 *1 (-382 *4)) (-4 *4 (-13 (-840) (-365))))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1161)) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-4 *4 (-13 (-29 *6) (-1181) (-959))) (-5 *2 (-2 (|:| |particular| *4) (|:| -2588 (-634 *4)))) (-5 *1 (-642 *6 *4 *3)) (-4 *3 (-646 *4)))) ((*1 *2 *3 *2 *4 *2 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-634 *2)) (-4 *2 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *1 (-642 *6 *2 *3)) (-4 *3 (-646 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-679 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| |particular| (-3 (-1244 *5) "failed")) (|:| -2588 (-634 (-1244 *5))))) (-5 *1 (-659 *5)) (-5 *4 (-1244 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-634 *5))) (-4 *5 (-365)) (-5 *2 (-2 (|:| |particular| (-3 (-1244 *5) "failed")) (|:| -2588 (-634 (-1244 *5))))) (-5 *1 (-659 *5)) (-5 *4 (-1244 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-679 *5)) (-4 *5 (-365)) (-5 *2 (-634 (-2 (|:| |particular| (-3 (-1244 *5) "failed")) (|:| -2588 (-634 (-1244 *5)))))) (-5 *1 (-659 *5)) (-5 *4 (-634 (-1244 *5))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-634 *5))) (-4 *5 (-365)) (-5 *2 (-634 (-2 (|:| |particular| (-3 (-1244 *5) "failed")) (|:| -2588 (-634 (-1244 *5)))))) (-5 *1 (-659 *5)) (-5 *4 (-634 (-1244 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-13 (-375 *5) (-10 -7 (-6 -4522)))) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4522)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2588 (-634 *4)))) (-5 *1 (-660 *5 *6 *4 *3)) (-4 *3 (-677 *5 *6 *4)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-13 (-375 *5) (-10 -7 (-6 -4522)))) (-4 *7 (-13 (-375 *5) (-10 -7 (-6 -4522)))) (-5 *2 (-634 (-2 (|:| |particular| (-3 *7 "failed")) (|:| -2588 (-634 *7))))) (-5 *1 (-660 *5 *6 *7 *3)) (-5 *4 (-634 *7)) (-4 *3 (-677 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-634 (-1161))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *5)))))) (-5 *1 (-762 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *4)))))) (-5 *1 (-762 *4)))) ((*1 *2 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-1161)) (-4 *5 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *1 (-764 *5 *2)) (-4 *2 (-13 (-29 *5) (-1181) (-959))))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-679 *7)) (-5 *5 (-1161)) (-4 *7 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-2 (|:| |particular| (-1244 *7)) (|:| -2588 (-634 (-1244 *7))))) (-5 *1 (-797 *6 *7)) (-5 *4 (-1244 *7)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-679 *6)) (-5 *4 (-1161)) (-4 *6 (-13 (-29 *5) (-1181) (-959))) (-4 *5 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-1244 *6))) (-5 *1 (-797 *5 *6)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-634 (-288 *7))) (-5 *4 (-634 (-123))) (-5 *5 (-1161)) (-4 *7 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-2 (|:| |particular| (-1244 *7)) (|:| -2588 (-634 (-1244 *7))))) (-5 *1 (-797 *6 *7)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-634 *7)) (-5 *4 (-634 (-123))) (-5 *5 (-1161)) (-4 *7 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-2 (|:| |particular| (-1244 *7)) (|:| -2588 (-634 (-1244 *7))))) (-5 *1 (-797 *6 *7)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-288 *7)) (-5 *4 (-123)) (-5 *5 (-1161)) (-4 *7 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-3 (-2 (|:| |particular| *7) (|:| -2588 (-634 *7))) *7 "failed")) (-5 *1 (-797 *6 *7)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-123)) (-5 *5 (-1161)) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-3 (-2 (|:| |particular| *3) (|:| -2588 (-634 *3))) *3 "failed")) (-5 *1 (-797 *6 *3)) (-4 *3 (-13 (-29 *6) (-1181) (-959))))) ((*1 *2 *3 *4 *3 *5) (|partial| -12 (-5 *3 (-288 *2)) (-5 *4 (-123)) (-5 *5 (-634 *2)) (-4 *2 (-13 (-29 *6) (-1181) (-959))) (-5 *1 (-797 *6 *2)) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))))) ((*1 *2 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-288 *2)) (-5 *5 (-634 *2)) (-4 *2 (-13 (-29 *6) (-1181) (-959))) (-4 *6 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *1 (-797 *6 *2)))) ((*1 *2 *3) (-12 (-5 *3 (-803)) (-5 *2 (-1035)) (-5 *1 (-800)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-803)) (-5 *4 (-1059)) (-5 *2 (-1035)) (-5 *1 (-800)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1244 (-310 (-381)))) (-5 *4 (-381)) (-5 *5 (-634 *4)) (-5 *2 (-1035)) (-5 *1 (-800)))) ((*1 *2 *3 *4 *4 *5 *4) (-12 (-5 *3 (-1244 (-310 (-381)))) (-5 *4 (-381)) (-5 *5 (-634 *4)) (-5 *2 (-1035)) (-5 *1 (-800)))) ((*1 *2 *3 *4 *4 *5 *6 *4) (-12 (-5 *3 (-1244 (-310 *4))) (-5 *5 (-634 (-381))) (-5 *6 (-310 (-381))) (-5 *4 (-381)) (-5 *2 (-1035)) (-5 *1 (-800)))) ((*1 *2 *3 *4 *4 *5 *5 *4) (-12 (-5 *3 (-1244 (-310 (-381)))) (-5 *4 (-381)) (-5 *5 (-634 *4)) (-5 *2 (-1035)) (-5 *1 (-800)))) ((*1 *2 *3 *4 *4 *5 *6 *5 *4) (-12 (-5 *3 (-1244 (-310 *4))) (-5 *5 (-634 (-381))) (-5 *6 (-310 (-381))) (-5 *4 (-381)) (-5 *2 (-1035)) (-5 *1 (-800)))) ((*1 *2 *3 *4 *4 *5 *6 *5 *4 *4) (-12 (-5 *3 (-1244 (-310 *4))) (-5 *5 (-634 (-381))) (-5 *6 (-310 (-381))) (-5 *4 (-381)) (-5 *2 (-1035)) (-5 *1 (-800)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1 (-3 (-2 (|:| |particular| *6) (|:| -2588 (-634 *6))) "failed") *7 *6)) (-4 *6 (-365)) (-4 *7 (-646 *6)) (-5 *2 (-2 (|:| |particular| (-1244 *6)) (|:| -2588 (-679 *6)))) (-5 *1 (-808 *6 *7)) (-5 *3 (-679 *6)) (-5 *4 (-1244 *6)))) ((*1 *2 *3) (-12 (-5 *3 (-893)) (-5 *2 (-1035)) (-5 *1 (-892)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-893)) (-5 *4 (-1059)) (-5 *2 (-1035)) (-5 *1 (-892)))) ((*1 *2 *3 *3 *3 *3 *4 *4 *5 *6 *7 *8) (-12 (-5 *4 (-763)) (-5 *6 (-634 (-634 (-310 *3)))) (-5 *7 (-1143)) (-5 *8 (-215)) (-5 *5 (-634 (-310 (-381)))) (-5 *3 (-381)) (-5 *2 (-1035)) (-5 *1 (-892)))) ((*1 *2 *3 *3 *3 *3 *4 *4 *5 *6 *7) (-12 (-5 *4 (-763)) (-5 *6 (-634 (-634 (-310 *3)))) (-5 *7 (-1143)) (-5 *5 (-634 (-310 (-381)))) (-5 *3 (-381)) (-5 *2 (-1035)) (-5 *1 (-892)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-953 (-409 (-568)))) (-5 *2 (-634 (-381))) (-5 *1 (-1022)) (-5 *4 (-381)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-953 (-568))) (-5 *2 (-634 (-381))) (-5 *1 (-1022)) (-5 *4 (-381)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *4)) (-5 *1 (-1116 *3 *4)) (-4 *3 (-1219 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-288 (-310 *4)))) (-5 *1 (-1119 *4)) (-5 *3 (-310 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-288 (-310 *4)))) (-5 *1 (-1119 *4)) (-5 *3 (-288 (-310 *4))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-288 (-310 *5)))) (-5 *1 (-1119 *5)) (-5 *3 (-288 (-310 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-288 (-310 *5)))) (-5 *1 (-1119 *5)) (-5 *3 (-310 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-1161))) (-4 *5 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-634 (-634 (-288 (-310 *5))))) (-5 *1 (-1119 *5)) (-5 *3 (-634 (-288 (-310 *5)))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 *5)))) (-5 *4 (-634 (-1161))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *5)))))) (-5 *1 (-1166 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-1161))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *5)))))) (-5 *1 (-1166 *5)) (-5 *3 (-634 (-288 (-409 (-953 *5))))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 *4)))) (-4 *4 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *4)))))) (-5 *1 (-1166 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *4)))))) (-5 *1 (-1166 *4)) (-5 *3 (-634 (-288 (-409 (-953 *4))))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-558)) (-5 *2 (-634 (-288 (-409 (-953 *5))))) (-5 *1 (-1166 *5)) (-5 *3 (-409 (-953 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-558)) (-5 *2 (-634 (-288 (-409 (-953 *5))))) (-5 *1 (-1166 *5)) (-5 *3 (-288 (-409 (-953 *5)))))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 (-288 (-409 (-953 *4))))) (-5 *1 (-1166 *4)) (-5 *3 (-409 (-953 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 (-288 (-409 (-953 *4))))) (-5 *1 (-1166 *4)) (-5 *3 (-288 (-409 (-953 *4))))))) 
+(((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-688)))) ((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-688))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-1157 *3)) (-4 *3 (-370)) (-4 *1 (-327 *3)) (-4 *3 (-365))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (-5 *1 (-263))))) 
+(((*1 *2 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *1 (-166 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-409 (-568))))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-409 (-568))) (-5 *1 (-420 *3)) (-4 *3 (-550)) (-4 *3 (-558)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-550)) (-5 *2 (-409 (-568))))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-792 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-409 (-568))))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-409 (-568))) (-5 *1 (-828 *3)) (-4 *3 (-550)) (-4 *3 (-1090)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-409 (-568))) (-5 *1 (-835 *3)) (-4 *3 (-550)) (-4 *3 (-1090)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-997 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-409 (-568))))) ((*1 *2 *3) (|partial| -12 (-5 *2 (-409 (-568))) (-5 *1 (-1008 *3)) (-4 *3 (-1037 *2))))) 
 (((*1 *1 *1) (-12 (-5 *1 (-509 *2)) (-14 *2 (-568)))) ((*1 *1 *1) (-5 *1 (-1108)))) 
-(((*1 *1 *1) (-12 (-4 *1 (-324 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)) (-4 *2 (-453)))) ((*1 *1 *1) (-12 (-4 *1 (-340 *2 *3 *4)) (-4 *2 (-1199)) (-4 *3 (-1219 *2)) (-4 *4 (-1219 (-409 *3))))) ((*1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-453)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-950 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *3 (-453)))) ((*1 *1 *1) (-12 (-4 *1 (-950 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453)))) ((*1 *2 *2 *3) (-12 (-4 *3 (-301)) (-4 *3 (-558)) (-5 *1 (-1148 *3 *2)) (-4 *2 (-1219 *3))))) 
-(((*1 *1 *1) (-5 *1 (-1059)))) 
-(((*1 *1) (-4 *1 (-39))) ((*1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) ((*1 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) ((*1 *1) (-5 *1 (-850))) ((*1 *1) (-12 (-4 *2 (-453)) (-4 *3 (-842)) (-4 *4 (-788)) (-5 *1 (-988 *2 *3 *4 *5)) (-4 *5 (-950 *2 *4 *3)))) ((*1 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) ((*1 *1) (-12 (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) ((*1 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) ((*1 *1) (-5 *1 (-1164))) ((*1 *1) (-5 *1 (-1165)))) 
-(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-953 (-215))) (-5 *2 (-310 (-381))) (-5 *1 (-299))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-121)) (-4 *4 (-13 (-365) (-840))) (-5 *2 (-420 *3)) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) ((*1 *2 *3 *4) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-420 *3)) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4)))))) 
+(((*1 *2 *3 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-169 (-215)))) (-5 *2 (-1035)) (-5 *1 (-746))))) 
+(((*1 *2 *3 *3) (|partial| -12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (|partial| -12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *2 (-13 (-432 *4) (-881 *3) (-609 (-887 *3)))) (-5 *1 (-1069 *3 *4 *2)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 (-887 *3)))))) ((*1 *2 *1) (-12 (-4 *2 (-1090)) (-5 *1 (-1150 *3 *2)) (-4 *3 (-1090))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *1 *1) (-4 *1 (-550)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *5 (-1199)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-5 *2 (-634 (-953 *5))) (-5 *1 (-339 *4 *5 *6 *7)) (-4 *4 (-340 *5 *6 *7)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *1 (-340 *4 *5 *6)) (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-4 *4 (-365)) (-5 *2 (-634 (-953 *4)))))) 
+(((*1 *2 *3 *4 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1699 *6) (-763))) (-4 *9 (-971 *5)) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-4 *3 (-235 *11)) (-4 *12 (-536 *5 *6 *7 *8 *9 *10 *11 *3 *14)) (-4 *14 (-117)) (-5 *2 (-2 (|:| -3894 (-568)) (|:| |num| *7) (|:| |den| *7) (|:| |upTo| (-568)))) (-5 *1 (-467 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13 *14)) (-5 *4 (-568)) (-4 *13 (-258 *12)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-236 (-922 *5))) (-4 *5 (-350)) (-5 *2 (-2 (|:| -3894 (-568)) (|:| |num| (-242 *6 *5)) (|:| |den| (-242 *6 *5)) (|:| |upTo| (-568)))) (-5 *1 (-867 *5 *6 *7)) (-5 *4 (-568)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-236 (-921 *5))) (-4 *5 (-365)) (-5 *2 (-2 (|:| -3894 (-568)) (|:| |num| (-242 *6 *5)) (|:| |den| (-242 *6 *5)) (|:| |upTo| (-568)))) (-5 *1 (-868 *5 *6 *7)) (-5 *4 (-568)) (-14 *6 (-634 (-1161))) (-4 *7 (-117))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-2 (|:| |eqzro| (-634 *8)) (|:| |neqzro| (-634 *8)) (|:| |wcond| (-634 (-953 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *5)))) (|:| -2588 (-634 (-1244 (-409 (-953 *5)))))))))) (-5 *4 (-1143)) (-4 *5 (-13 (-301) (-150))) (-4 *8 (-950 *5 *7 *6)) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *5 *6 *7 *8))))) 
 (((*1 *2 *3 *3 *4 *4 *5 *4 *5 *4 *4 *5 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-169 (-215)))) (-5 *2 (-1035)) (-5 *1 (-746))))) 
-(((*1 *1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-172)) (-4 *2 (-558)))) ((*1 *1 *1) (|partial| -4 *1 (-712)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1249)) (-5 *1 (-450 *4 *5 *6 *7))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-679 *2)) (-4 *4 (-1219 *2)) (-4 *2 (-13 (-301) (-10 -8 (-15 -1678 ((-420 $) $))))) (-5 *1 (-508 *2 *4 *5)) (-4 *5 (-411 *2 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-1111 *3 *2 *4 *5)) (-4 *4 (-230 *3 *2)) (-4 *5 (-230 *3 *2)) (-4 *2 (-1047))))) 
-(((*1 *1) (-5 *1 (-1164)))) 
-(((*1 *1 *1) (|partial| -12 (-5 *1 (-1126 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39)))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-763)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4))))) 
+(((*1 *1 *1) (-5 *1 (-1059)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-215)) (-5 *1 (-299))))) 
+(((*1 *2 *3 *1) (-12 (-4 *4 (-365)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *4 *5 *6 *3)) (-4 *3 (-950 *4 *5 *6))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-927)) (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-927)) (-5 *4 (-409 (-568))) (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156))))) 
 (((*1 *2 *3 *4 *4 *4 *4 *5 *5 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-169 (-215)))) (-5 *2 (-1035)) (-5 *1 (-746))))) 
-(((*1 *2 *2 *3 *4) (-12 (-5 *2 (-634 *8)) (-5 *3 (-1 (-121) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-978 *5 *6 *7 *8))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1039))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-365)))) ((*1 *2 *1) (-12 (-4 *1 (-971 *2)) (-4 *2 (-365))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-365)) (-5 *2 (-634 *5)) (-5 *1 (-635 *5 *3)) (-4 *3 (-641 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-679 (-310 (-215)))) (-5 *2 (-381)) (-5 *1 (-197))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *4 *5 *6 *7))))) 
+(((*1 *2 *1 *3) (-12 (-4 *1 (-555 *3)) (-4 *3 (-13 (-406) (-1181))) (-5 *2 (-121))))) 
+(((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *2 (-763) (-763) *7)) (-5 *4 (-1244 *7)) (-5 *5 (-763)) (-5 *6 (-1244 (-1157 *2))) (-4 *7 (-52 *2 *5)) (-4 *2 (-13 (-558) (-453))) (-5 *1 (-346 *2 *7))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-1061 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1189 *4 *5 *6 *3)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-607 *5))) (-4 *4 (-842)) (-5 *2 (-607 *5)) (-5 *1 (-577 *4 *5)) (-4 *5 (-432 *4))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1244 *1)) (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4)))))) 
+(((*1 *1) (-5 *1 (-142)))) 
 (((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-728))))) 
 (((*1 *2 *3 *4 *4 *3 *4 *5 *4 *4 *3 *3 *3 *3 *6 *3 *7) (-12 (-5 *3 (-568)) (-5 *5 (-121)) (-5 *6 (-679 (-215))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-82 OBJFUN)))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-745))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |var| (-634 (-1161))) (|:| |pred| (-57)))) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
-(((*1 *1) (-5 *1 (-158)))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-1177))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-1219 *4)) (-4 *4 (-1199)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-2 (|:| |num| *1) (|:| |den| *5) (|:| |derivden| *5) (|:| |gd| *5))) (-4 *1 (-340 *4 *5 *6))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-57))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-171)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-365)) (-5 *2 (-2 (|:| -4409 *3) (|:| -2607 *3))) (-5 *1 (-758 *3 *4)) (-4 *3 (-698 *4)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-844 *3)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-365)) (-4 *5 (-1047)) (-5 *2 (-2 (|:| -4409 *3) (|:| -2607 *3))) (-5 *1 (-845 *5 *3)) (-4 *3 (-844 *5))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-123))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842))))) 
+(((*1 *1 *2 *2 *2) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181))))) ((*1 *1 *1 *2) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) ((*1 *1 *2) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) ((*1 *2 *1 *3 *4 *4) (-12 (-5 *3 (-917)) (-5 *4 (-381)) (-5 *2 (-1249)) (-5 *1 (-1245))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1244 *1)) (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4)))))) 
+(((*1 *2) (-12 (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-1157 (-568))) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-1157 (-568))) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) ((*1 *2) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-867 *3 *4 *5)) (-4 (-857 *3) (-370)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 (-568))) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 (-568))) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117))))) 
 (((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-436)) (-4 *5 (-842)) (-5 *1 (-1096 *5 *4)) (-4 *4 (-432 *5))))) 
 (((*1 *2 *3 *3 *3 *3 *4 *3 *5) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-84 LSFUN1)))) (-5 *2 (-1035)) (-5 *1 (-745))))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-404)) (-5 *2 (-763)))) ((*1 *1 *1) (-4 *1 (-404)))) 
-(((*1 *2 *3 *4 *4 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *3 (-2 (|:| |lcmfij| *6) (|:| |totdeg| (-763)) (|:| |poli| *4) (|:| |polj| *4))) (-4 *6 (-788)) (-4 *4 (-950 *5 *6 *7)) (-4 *5 (-453)) (-4 *7 (-842)) (-5 *1 (-450 *5 *6 *7 *4))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-121) *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-2 (|:| |goodPols| (-634 *8)) (|:| |badPols| (-634 *8)))) (-5 *1 (-978 *5 *6 *7 *8)) (-5 *4 (-634 *8))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1157 *1)) (-5 *4 (-1161)) (-4 *1 (-27)) (-5 *2 (-634 *1)))) ((*1 *2 *3) (-12 (-5 *3 (-1157 *1)) (-4 *1 (-27)) (-5 *2 (-634 *1)))) ((*1 *2 *3) (-12 (-5 *3 (-953 *1)) (-4 *1 (-27)) (-5 *2 (-634 *1)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-634 *1)) (-4 *1 (-29 *4)))) ((*1 *2 *1) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *2 (-634 *1)) (-4 *1 (-29 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-944 *4)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
+(((*1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247)))) ((*1 *2 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1084 (-835 (-215)))) (-5 *1 (-299))))) 
+(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1161))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565)))) ((*1 *2 *3) (-12 (-5 *2 (-1157 (-409 (-568)))) (-5 *1 (-943)) (-5 *3 (-568))))) 
 (((*1 *2 *3 *3 *3 *3 *4 *3 *5) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-68 LSFUN2)))) (-5 *2 (-1035)) (-5 *1 (-745))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 (-514 *3 *4 *5 *6))) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-5 *3 (-634 *7)) (-4 *1 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *3) (-12 (-4 *1 (-350)) (-5 *3 (-568)) (-5 *2 (-1169 (-917) (-763)))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-301)))) ((*1 *2 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |lm| (-388 *3)) (|:| |rm| (-388 *3)))) (-5 *1 (-388 *3)) (-4 *3 (-1090)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -3961 (-763)) (|:| -1500 (-763)))) (-5 *1 (-763)))) ((*1 *2 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |lm| (-3 (-814 *3) "failed")) (|:| |rm| (-3 (-814 *3) "failed")))) (-5 *1 (-814 *3)) (-4 *3 (-842)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| -3961 *3) (|:| -1500 *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *1 (-1191 *3)) (-4 *3 (-975))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-634 (-634 *3))))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-634 (-634 *5))))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-634 *3))) (-5 *1 (-1168 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-1157 *2)) (-4 *2 (-432 *4)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-36 *4 *2))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-52 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))))) ((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161))))) ((*1 *2 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-568)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-246 *4 *3 *5 *6)) (-4 *4 (-1047)) (-4 *3 (-842)) (-4 *5 (-262 *3)) (-4 *6 (-788)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-271)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1157 *8)) (-5 *4 (-634 *6)) (-4 *6 (-842)) (-4 *8 (-950 *7 *5 *6)) (-4 *5 (-788)) (-4 *7 (-1047)) (-5 *2 (-634 (-763))) (-5 *1 (-318 *5 *6 *7 *8)))) ((*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-5 *2 (-917)))) ((*1 *2 *1) (-12 (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-475 *3 *2)) (-4 *3 (-172)) (-4 *2 (-23)))) ((*1 *2 *1) (-12 (-4 *3 (-558)) (-5 *2 (-568)) (-5 *1 (-615 *3 *4)) (-4 *4 (-1219 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-698 *3)) (-4 *3 (-1047)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-844 *3)) (-4 *3 (-1047)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-1047)) (-4 *6 (-230 *7 *2)) (-14 *7 *2) (-5 *2 (-763)) (-5 *1 (-908 *5 *3 *6 *7)) (-4 *3 (-324 *5 *6)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *1 (-950 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 (-763))))) ((*1 *2 *1 *3) (-12 (-4 *1 (-950 *4 *5 *3)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-974 *3 *2 *4)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *2 (-787)))) ((*1 *2 *1) (-12 (-4 *1 (-1088)) (-5 *2 (-917)))) ((*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-1205 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1234 *3)) (-5 *2 (-568)))) ((*1 *2 *1) (-12 (-4 *1 (-1226 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1203 *3)) (-5 *2 (-409 (-568))))) ((*1 *2 *1) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-828 (-917))))) ((*1 *2 *1) (-12 (-4 *1 (-1263 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-763))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-150))) (-5 *2 (-634 *3)) (-5 *1 (-1213 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-432 *2)) (-4 *2 (-842)) (-4 *2 (-558)))) ((*1 *1 *1) (-12 (-5 *1 (-733 *2 *3)) (-14 *2 (-1161)) (-4 *3 (-13 (-1047) (-842) (-558))))) ((*1 *1 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *2 *7 *8 *9 *10)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-641 *3)) (-4 *8 (-920 *3 *7)) (-4 *9 (-235 *8)) (-4 *10 (-117)) (-4 *2 (-971 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-634 (-3 (|:| -3393 (-1161)) (|:| |bounds| (-634 (-3 (|:| S (-1161)) (|:| P (-953 (-568)))))))))) (-5 *1 (-1165))))) 
 (((*1 *1 *2 *2) (-12 (-5 *2 (-763)) (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *5)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1242 *3)) (-4 *3 (-23)) (-4 *3 (-1195))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-977 *3 *4 *2 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *5 (-1061 *3 *4 *2))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *1 (-873 *2)) (-4 *2 (-1195)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *1 (-875 *2)) (-4 *2 (-1195)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *1 (-877 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
 (((*1 *2 *3 *3 *3 *3 *4 *4 *4 *3 *5) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-3 (|:| |fn| (-390)) (|:| |fp| (-71 FUNCT1)))) (-5 *2 (-1035)) (-5 *1 (-745))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2721 (-777 *3)) (|:| |coef1| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -2721 *1) (|:| |coef1| *1))) (-4 *1 (-1061 *3 *4 *5))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-473)) (-5 *3 (-634 (-256))) (-5 *1 (-1245)))) ((*1 *1 *1) (-5 *1 (-1245)))) 
-(((*1 *2 *2 *3 *4) (-12 (-5 *3 (-634 (-607 *2))) (-5 *4 (-634 (-1161))) (-4 *2 (-13 (-432 (-169 *5)) (-1002) (-1181))) (-4 *5 (-13 (-558) (-842))) (-5 *1 (-597 *5 *6 *2)) (-4 *6 (-13 (-432 *5) (-1002) (-1181)))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-568)) (-5 *1 (-444 *4 *3 *5)) (-4 *3 (-1219 *4)) (-4 *5 (-13 (-406) (-1037 *4) (-365) (-1181) (-279)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1157 *3)) (-4 *3 (-1047)) (-4 *1 (-1219 *3))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1216 *5 *4)) (-5 *1 (-1159 *4 *5 *6)) (-4 *4 (-1047)) (-14 *5 (-1161)) (-14 *6 *4))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1216 (QUOTE |x|) *4)) (-5 *1 (-1201 *4)) (-4 *4 (-1047)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1216 *5 *4)) (-5 *1 (-1235 *4 *5 *6)) (-4 *4 (-1047)) (-14 *5 (-1161)) (-14 *6 *4))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1216 *5 *4)) (-5 *1 (-1239 *4 *5)) (-4 *4 (-1047)) (-14 *5 (-1161))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) ((*1 *1 *1) (-12 (-5 *1 (-1265 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-838))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1866 *7) (|:| -1844 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *5 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3)))) 
+(((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -3440 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1244 *6)) (-5 *4 (-1244 (-568))) (-5 *5 (-568)) (-4 *6 (-1090)) (-5 *2 (-1 *6)) (-5 *1 (-1017 *6))))) 
 (((*1 *2 *3 *3 *3 *3 *3 *3 *4 *4 *4 *4 *5 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-121)) (-5 *2 (-1035)) (-5 *1 (-745))))) 
-(((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-1067 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-1098 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1092 *3)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-1092 *3)) (-5 *1 (-900 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1161)) (-4 *5 (-609 (-887 (-568)))) (-4 *5 (-881 (-568))) (-4 *5 (-13 (-842) (-1037 (-568)) (-453) (-630 (-568)))) (-5 *2 (-2 (|:| |special| *3) (|:| |integrand| *3))) (-5 *1 (-571 *5 *3)) (-4 *3 (-620)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) ((*1 *2 *2 *3 *4 *4) (|partial| -12 (-5 *3 (-1161)) (-5 *4 (-835 *2)) (-4 *2 (-1124)) (-4 *2 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-609 (-887 (-568)))) (-4 *5 (-881 (-568))) (-4 *5 (-13 (-842) (-1037 (-568)) (-453) (-630 (-568)))) (-5 *1 (-571 *5 *2))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1 *4 *4)) (-5 *3 (-763)) (-4 *1 (-223 *4)) (-4 *4 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-223 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-225)) (-5 *2 (-763)))) ((*1 *1 *1) (-4 *1 (-225))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *3 (-13 (-365) (-150))) (-5 *1 (-401 *3 *4)) (-4 *4 (-1219 *3)))) ((*1 *1 *1) (-12 (-4 *2 (-13 (-365) (-150))) (-5 *1 (-401 *2 *3)) (-4 *3 (-1219 *2)))) ((*1 *1) (-12 (-4 *1 (-646 *2)) (-4 *2 (-1047)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *4)) (-5 *3 (-634 (-763))) (-4 *1 (-895 *4)) (-4 *4 (-1090)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-895 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *1 (-895 *3)) (-4 *3 (-1090)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-895 *2)) (-4 *2 (-1090))))) 
+(((*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1027 *5 *6 *7 *8))) (-5 *1 (-1027 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1131 *5 *6 *7 *8))) (-5 *1 (-1131 *5 *6 *7 *8))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-702 *3 *2)) (-4 *2 (-1219 *3))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-121)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-465))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1 *4 *4)) (-5 *3 (-763)) (-4 *1 (-223 *4)) (-4 *4 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-223 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-225)) (-5 *2 (-763)))) ((*1 *1 *1) (-4 *1 (-225))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *3 (-13 (-365) (-150))) (-5 *1 (-401 *3 *4)) (-4 *4 (-1219 *3)))) ((*1 *1 *1) (-12 (-4 *2 (-13 (-365) (-150))) (-5 *1 (-401 *2 *3)) (-4 *3 (-1219 *2)))) ((*1 *1) (-12 (-4 *1 (-646 *2)) (-4 *2 (-1047)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *4)) (-5 *3 (-634 (-763))) (-4 *1 (-895 *4)) (-4 *4 (-1090)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-895 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *1 (-895 *3)) (-4 *3 (-1090)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-895 *2)) (-4 *2 (-1090))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-242 (-4289 (QUOTE X) (QUOTE -2928)) *5)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *2 (-324 *5 *7)) (-5 *1 (-119 *5 *6 *2 *7 *4)) (-4 *7 (-230 (-1699 *6) (-763))) (-4 *4 (-117))))) 
 (((*1 *2 *3 *3 *3 *3 *3 *3 *3 *3 *4 *5 *5 *5 *5 *5 *5 *6 *6 *6 *3 *3 *5 *7 *3 *8) (-12 (-5 *5 (-679 (-215))) (-5 *6 (-121)) (-5 *7 (-679 (-568))) (-5 *8 (-3 (|:| |fn| (-390)) (|:| |fp| (-70 QPHESS)))) (-5 *3 (-568)) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-745))))) 
-(((*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1 *8 *8)) (-5 *5 (-1 (-3 (-2 (|:| -1924 *7) (|:| |coeff| *7)) "failed") *7)) (-5 *6 (-634 (-409 *8))) (-4 *7 (-365)) (-4 *8 (-1219 *7)) (-5 *3 (-409 *8)) (-5 *2 (-2 (|:| |answer| (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (|:| |a0| *7))) (-5 *1 (-578 *7 *8))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-819))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-310 *3)) (-4 *3 (-558)) (-4 *3 (-842))))) 
-(((*1 *2 *2 *3 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-21)) (-4 *2 (-1195))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-927)) (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-927)) (-5 *4 (-409 (-568))) (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156)))) ((*1 *2 *3) (-12 (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156)) (-5 *3 (-634 (-944 (-215)))))) ((*1 *2 *3) (-12 (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156)) (-5 *3 (-634 (-634 (-944 (-215))))))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-1084 (-381)))) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-256))))) 
+(((*1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-634 *1)) (-4 *1 (-920 *3 *4))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *2 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-751))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
 (((*1 *2 *3 *3 *3 *3 *3 *3 *4 *4 *4 *3 *3 *5 *6 *3 *6 *6 *5 *6 *6 *6 *6 *5 *3 *3 *3 *3 *3 *6 *6 *6 *3 *3 *3 *3 *3 *7 *4 *4 *4 *4 *3 *8 *9) (-12 (-5 *4 (-679 (-215))) (-5 *5 (-121)) (-5 *6 (-215)) (-5 *7 (-679 (-568))) (-5 *8 (-3 (|:| |fn| (-390)) (|:| |fp| (-85 CONFUN)))) (-5 *9 (-3 (|:| |fn| (-390)) (|:| |fp| (-82 OBJFUN)))) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-745))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-1093 *3 *2 *4 *5 *6)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-1090))))) 
-(((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-1067 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-1098 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1216 *5 *4)) (-4 *4 (-453)) (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-568)) (-5 *1 (-1104 *4 *5))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-350)) (-5 *2 (-2 (|:| |cont| *5) (|:| -3276 (-634 (-2 (|:| |irr| *3) (|:| -3959 (-568))))))) (-5 *1 (-207 *5 *3)) (-4 *3 (-1219 *5))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-310 (-215))) (-5 *1 (-202))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-381)) (-5 *1 (-197))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-2 (|:| -2553 (-634 (-850))) (|:| -1462 (-634 (-850))) (|:| |presup| (-634 (-850))) (|:| -3785 (-634 (-850))) (|:| |args| (-634 (-850))))) (-5 *1 (-1161)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-634 (-850)))) (-5 *1 (-1161))))) 
+(((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *2)) (-5 *4 (-763)) (-4 *2 (-1090)) (-5 *1 (-668 *2))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1195)) (-5 *2 (-634 *1)) (-4 *1 (-1010 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-1149 *3 *4))) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
+(((*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-763)) (-4 *5 (-365)) (-5 *2 (-173 *6)) (-5 *1 (-861 *5 *4 *6)) (-4 *4 (-1234 *5)) (-4 *6 (-1219 *5))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-320 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-137)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-363 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-388 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-638 *3 *4 *5)) (-4 *4 (-23)) (-14 *5 *4)))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-2 (|:| -1891 (-634 (-850))) (|:| -2409 (-634 (-850))) (|:| |presup| (-634 (-850))) (|:| -2749 (-634 (-850))) (|:| |args| (-634 (-850))))) (-5 *1 (-1161)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-634 (-850)))) (-5 *1 (-1161))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) ((*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
 (((*1 *2 *3 *3 *3 *4 *5 *3 *5 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-745))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1697 *6) (-763))) (-5 *2 (-242 (-4287 (QUOTE X) (QUOTE -2926)) *5)) (-5 *1 (-119 *5 *6 *3 *7 *4)) (-4 *3 (-324 *5 *7)) (-4 *4 (-117))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-39)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-494 *3)) (-4 *3 (-842)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1132 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-679 (-310 (-568)))) (-5 *1 (-1031))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-2 (|:| |k| (-814 *3)) (|:| |c| *4)))))) 
-(((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-615 *4 *5)) (-5 *3 (-1 (-2 (|:| |ans| *4) (|:| -3284 *4) (|:| |sol?| (-121))) (-568) *4)) (-4 *4 (-365)) (-4 *5 (-1219 *4)) (-5 *1 (-578 *4 *5))))) 
+(((*1 *1) (-5 *1 (-818)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-643 (-409 *2))) (-4 *2 (-1219 *4)) (-5 *1 (-805 *4 *2)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))))) ((*1 *2 *3) (-12 (-5 *3 (-644 *2 (-409 *2))) (-4 *2 (-1219 *4)) (-5 *1 (-805 *4 *2)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568)))))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-366 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090)))) ((*1 *1 *1) (-5 *1 (-623)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-607 *5)) (-4 *5 (-432 *4)) (-4 *4 (-1037 (-568))) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-1157 *5)) (-5 *1 (-36 *4 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-607 *1)) (-4 *1 (-1047)) (-4 *1 (-296)) (-5 *2 (-1157 *1))))) 
 (((*1 *2 *3 *4 *4 *5 *3 *3 *4 *3 *3 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-744))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-1125 *4 *5)) (-4 *4 (-13 (-1090) (-39))) (-4 *5 (-13 (-1090) (-39))) (-5 *2 (-121)) (-5 *1 (-1126 *4 *5))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-679 *1)) (-5 *4 (-1244 *1)) (-4 *1 (-630 *5)) (-4 *5 (-1047)) (-5 *2 (-2 (|:| -2928 (-679 *5)) (|:| |vec| (-1244 *5)))))) ((*1 *2 *3) (-12 (-5 *3 (-679 *1)) (-4 *1 (-630 *4)) (-4 *4 (-1047)) (-5 *2 (-679 *4))))) 
-(((*1 *2 *1) (|partial| -12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-350)) (-5 *2 (-634 *3)) (-5 *1 (-344 *5 *3)) (-4 *3 (-1219 *5))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-858)) (-5 *2 (-1249))))) 
+(((*1 *1 *1 *2 *2) (|partial| -12 (-5 *2 (-917)) (-5 *1 (-1091 *3 *4)) (-14 *3 *2) (-14 *4 *2)))) 
+(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1196 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| -4194 (-123)) (|:| |arg| (-634 (-887 *3))))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) ((*1 *2 *1 *3) (|partial| -12 (-5 *3 (-123)) (-5 *2 (-634 (-887 *4))) (-5 *1 (-887 *4)) (-4 *4 (-1090))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3145 *4)))) (-5 *1 (-768 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *4)) (-5 *1 (-1116 *3 *4)) (-4 *3 (-1219 *4)))) ((*1 *2 *3 *3) (-12 (-4 *3 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *3)) (-5 *1 (-1116 *4 *3)) (-4 *4 (-1219 *3))))) 
 (((*1 *2 *3 *4 *4 *5 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-744))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-310 (-215))) (-5 *1 (-263))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-634 (-242 *4 *5))) (-5 *2 (-242 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *1 (-622 *4 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-420 *3)) (-4 *3 (-558)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3848 *4) (|:| -3206 (-568))))) (-4 *4 (-1219 (-568))) (-5 *2 (-763)) (-5 *1 (-443 *4))))) 
-(((*1 *2 *3 *3 *3) (|partial| -12 (-4 *4 (-13 (-150) (-27) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-1157 (-409 *5))) (-5 *1 (-610 *4 *5)) (-5 *3 (-409 *5)))) ((*1 *2 *3 *3 *3 *4) (|partial| -12 (-5 *4 (-1 (-420 *6) *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-150) (-27) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-1157 (-409 *6))) (-5 *1 (-610 *5 *6)) (-5 *3 (-409 *6))))) 
-(((*1 *2 *3 *3 *4) (-12 (-5 *3 (-763)) (-4 *2 (-13 (-558) (-453))) (-5 *1 (-346 *2 *4)) (-4 *4 (-52 *2 *3))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-230 *5 (-763))) (-5 *1 (-908 *4 *3 *2 *5)) (-4 *3 (-324 *4 *2)) (-14 *5 (-763))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-296)))) ((*1 *1 *1) (-4 *1 (-296))) ((*1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-2 (|:| -4094 (-634 *6)) (|:| -2133 (-634 *6))))))) 
+(((*1 *2 *2 *2 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-607 *2)) (-5 *4 (-1 (-3 *2 "failed") *2 *2 (-1161))) (-4 *2 (-13 (-432 *5) (-27) (-1181))) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *1 (-570 *5 *2 *6)) (-4 *6 (-1090))))) 
 (((*1 *2 *3 *3 *4 *4 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-744))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-842)) (-5 *1 (-1167 *3))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1219 *3)) (-4 *3 (-1047))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1244 (-2 (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)) (|:| -1526 (-568)) (|:| -4257 (-568)) (|:| |spline| (-568)) (|:| -1718 (-568)) (|:| |axesColor| (-869)) (|:| -2832 (-568)) (|:| |unitsColor| (-869)) (|:| |showing| (-568))))) (-5 *1 (-1245))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-409 (-568))) (-5 *1 (-299))))) 
+(((*1 *1 *1 *1) (-4 *1 (-550)))) 
+(((*1 *1 *1) (-12 (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39)))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1216 *5 *4)) (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-568)) (-5 *1 (-1104 *4 *5))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1244 *4)) (-4 *4 (-630 (-568))) (-5 *2 (-1244 (-409 (-568)))) (-5 *1 (-1269 *4))))) 
 (((*1 *2 *3 *4 *4 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *2 (-1035)) (-5 *1 (-744))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1244 (-310 (-215)))) (-5 *4 (-634 (-1161))) (-5 *2 (-679 (-310 (-215)))) (-5 *1 (-197)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-4 *6 (-895 *5)) (-5 *2 (-679 *6)) (-5 *1 (-681 *5 *6 *3 *4)) (-4 *3 (-375 *6)) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4519))))))) 
-(((*1 *1 *1) (-12 (-4 *2 (-350)) (-4 *2 (-1047)) (-5 *1 (-702 *2 *3)) (-4 *3 (-1219 *2))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-169 (-310 *4))) (-5 *1 (-180 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 (-169 *4)))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-169 *3)) (-5 *1 (-1185 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4)))))) 
-(((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) ((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) ((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-350)) (-5 *2 (-763)))) ((*1 *2 *1 *1) (|partial| -12 (-4 *1 (-404)) (-5 *2 (-763))))) 
-(((*1 *2 *3 *4 *4 *5 *3 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *2 (-1035)) (-5 *1 (-744))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *3 (-365)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-529 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-558)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-4 *7 (-993 *4)) (-4 *2 (-677 *7 *8 *9)) (-5 *1 (-530 *4 *5 *6 *3 *7 *8 *9 *2)) (-4 *3 (-677 *4 *5 *6)) (-4 *8 (-375 *7)) (-4 *9 (-375 *7)))) ((*1 *1 *1) (|partial| -12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (-4 *2 (-365)))) ((*1 *2 *2) (|partial| -12 (-4 *3 (-365)) (-4 *3 (-172)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-678 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) ((*1 *1 *1) (|partial| -12 (-5 *1 (-679 *2)) (-4 *2 (-365)) (-4 *2 (-1047)))) ((*1 *1 *1) (|partial| -12 (-4 *1 (-1111 *2 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-230 *2 *3)) (-4 *5 (-230 *2 *3)) (-4 *3 (-365)))) ((*1 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-1167 *3))))) 
-(((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-239 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *1 *3) (-12 (-4 *1 (-138)) (-5 *3 (-763)) (-5 *2 (-1249))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-301)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-2 (|:| |Hermite| *3) (|:| |eqMat| *3))) (-5 *1 (-1112 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-150)) (-4 *3 (-301)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6))))) 
-(((*1 *1) (-5 *1 (-142)))) 
-(((*1 *1 *1 *1) (|partial| -4 *1 (-137)))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381)))) (-5 *2 (-1035)) (-5 *1 (-299))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1092 *3)) (-5 *1 (-900 *3)) (-4 *3 (-370)) (-4 *3 (-1090))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
-(((*1 *2 *3 *3 *2) (-12 (-5 *2 (-679 (-568))) (-5 *3 (-634 (-568))) (-5 *1 (-1100))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1244 *5)) (-4 *5 (-787)) (-5 *2 (-121)) (-5 *1 (-837 *4 *5)) (-14 *4 (-763))))) 
-(((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-666 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-250))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-900 (-568))) (-5 *4 (-568)) (-5 *2 (-679 *4)) (-5 *1 (-1028 *5)) (-4 *5 (-1047)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-679 (-568))) (-5 *1 (-1028 *4)) (-4 *4 (-1047)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-900 (-568)))) (-5 *4 (-568)) (-5 *2 (-634 (-679 *4))) (-5 *1 (-1028 *5)) (-4 *5 (-1047)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-634 (-568)))) (-5 *2 (-634 (-679 (-568)))) (-5 *1 (-1028 *4)) (-4 *4 (-1047))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-554))))) 
-(((*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-3 (-409 (-953 *6)) (-1150 (-1161) (-953 *6)))) (-5 *5 (-763)) (-4 *6 (-453)) (-5 *2 (-634 (-679 (-409 (-953 *6))))) (-5 *1 (-286 *6)) (-5 *4 (-679 (-409 (-953 *6)))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-2 (|:| |eigval| (-3 (-409 (-953 *5)) (-1150 (-1161) (-953 *5)))) (|:| |eigmult| (-763)) (|:| |eigvec| (-634 *4)))) (-4 *5 (-453)) (-5 *2 (-634 (-679 (-409 (-953 *5))))) (-5 *1 (-286 *5)) (-5 *4 (-679 (-409 (-953 *5))))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *2)) (-4 *2 (-138)) (-5 *1 (-1076 *2)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-568) *2 *2)) (-4 *2 (-138)) (-5 *1 (-1076 *2))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 *5 (-634 *5))) (-4 *5 (-1234 *4)) (-4 *4 (-43 (-409 (-568)))) (-5 *2 (-1 (-1141 *4) (-634 (-1141 *4)))) (-5 *1 (-1236 *4 *5))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172))))) 
-(((*1 *2) (|partial| -12 (-4 *3 (-558)) (-4 *3 (-172)) (-5 *2 (-2 (|:| |particular| *1) (|:| -3746 (-634 *1)))) (-4 *1 (-369 *3)))) ((*1 *2) (|partial| -12 (-5 *2 (-2 (|:| |particular| (-454 *3 *4 *5 *6)) (|:| -3746 (-634 (-454 *3 *4 *5 *6))))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-123)) (-5 *4 (-1161)) (-4 *6 (-1047)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-2 (|:| -3268 (-3 (-568) "failed")) (|:| -1379 (-3 (-568) "failed")) (|:| |ker| (-607 *5)))) (-5 *1 (-1024 *6 *5)) (-4 *5 (-13 (-432 *6) (-23) (-1037 (-568)) (-1037 *4) (-895 *4) (-161)))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-568)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) (-5 *2 (-634 (-409 (-568)))) (-5 *1 (-1019 *4)) (-4 *4 (-1219 (-568)))))) 
-(((*1 *2 *3 *2 *4) (|partial| -12 (-5 *4 (-1 (-3 (-568) "failed") *5)) (-4 *5 (-1047)) (-5 *2 (-568)) (-5 *1 (-548 *5 *3)) (-4 *3 (-1219 *5)))) ((*1 *2 *3 *4 *2 *5) (|partial| -12 (-5 *5 (-1 (-3 (-568) "failed") *4)) (-4 *4 (-1047)) (-5 *2 (-568)) (-5 *1 (-548 *4 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1 (-3 (-568) "failed") *4)) (-4 *4 (-1047)) (-5 *2 (-568)) (-5 *1 (-548 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *1 *2 *3 *3 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-121)) (-5 *1 (-887 *4)) (-4 *4 (-1090))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 (-310 (-215)))) (-5 *1 (-263))))) 
-(((*1 *2 *3 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-121)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-121)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) ((*1 *2 *3 *1) (-12 (|has| *1 (-6 -4519)) (-4 *1 (-499 *3)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-900 *4)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-899 *4)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-121)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-917)) (-5 *2 (-121)) (-5 *1 (-1091 *4 *5)) (-14 *4 *3) (-14 *5 *3))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-121)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090))))) 
-(((*1 *2 *2 *2 *3) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-5 *1 (-653 *3))))) 
-(((*1 *2 *3 *4 *5 *6) (-12 (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *9 (-230 (-1697 *7) (-763))) (-5 *2 (-2 (|:| |mult| (-763)) (|:| |subMult| (-763)) (|:| |blUpRec| (-634 (-2 (|:| |recTransStr| (-242 (-4287 (QUOTE X) (QUOTE -2926)) *6)) (|:| |recPoint| (-33 *6)) (|:| |recChart| *5) (|:| |definingExtension| *6)))))) (-5 *1 (-119 *6 *7 *8 *9 *5)) (-5 *3 (-242 (-4287 (QUOTE X) (QUOTE -2926)) *6)) (-5 *4 (-33 *6)) (-4 *8 (-324 *6 *9)) (-4 *5 (-117))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-634 (-1161))) (-5 *2 (-634 (-634 (-381)))) (-5 *1 (-1022)) (-5 *5 (-381)))) ((*1 *2 *3) (-12 (-5 *3 (-1044 *4 *5)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *5 (-634 (-1161))) (-5 *2 (-634 (-634 (-1023 (-409 *4))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *6 (-634 (-1161))))) ((*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *5))))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *5))))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *5))))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *4))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161)))))) 
-(((*1 *1 *1 *1) (-5 *1 (-121))) ((*1 *1 *1 *1) (-4 *1 (-132))) ((*1 *1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *2 *2 *3 *4) (|partial| -12 (-5 *4 (-1 *3)) (-4 *3 (-842)) (-4 *5 (-788)) (-4 *6 (-558)) (-4 *7 (-950 *6 *5 *3)) (-5 *1 (-466 *5 *3 *6 *7 *2)) (-4 *2 (-13 (-1037 (-409 (-568))) (-365) (-10 -8 (-15 -2745 ($ *7)) (-15 -2317 (*7 $)) (-15 -2324 (*7 $)))))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
-(((*1 *1 *2) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181)))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1141 (-1141 *4))) (-5 *2 (-1141 *4)) (-5 *1 (-1145 *4)) (-4 *4 (-1047))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-13 (-558) (-453))) (-5 *2 (-634 *4)) (-5 *1 (-346 *4 *5)) (-4 *5 (-52 *4 *3))))) 
-(((*1 *2) (-12 (-5 *2 (-634 (-763))) (-5 *1 (-1247)))) ((*1 *2 *2) (-12 (-5 *2 (-634 (-763))) (-5 *1 (-1247))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *1 (-1145 *3))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-172)) (-4 *2 (-23)) (-5 *1 (-284 *3 *4 *2 *5 *6 *7)) (-4 *4 (-1219 *3)) (-14 *5 (-1 *4 *4 *2)) (-14 *6 (-1 (-3 *2 "failed") *2 *2)) (-14 *7 (-1 (-3 *4 "failed") *4 *4 *2)))) ((*1 *2 *1) (-12 (-4 *2 (-23)) (-5 *1 (-701 *3 *2 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-1 *3 *3 *2)) (-14 *5 (-1 (-3 *2 "failed") *2 *2)) (-14 *6 (-1 (-3 *3 "failed") *3 *3 *2)))) ((*1 *2) (-12 (-4 *2 (-1219 *3)) (-5 *1 (-702 *3 *2)) (-4 *3 (-1047)))) ((*1 *2 *1) (-12 (-4 *2 (-23)) (-5 *1 (-705 *3 *2 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-1 *3 *3 *2)) (-14 *5 (-1 (-3 *2 "failed") *2 *2)) (-14 *6 (-1 (-3 *3 "failed") *3 *3 *2)))) ((*1 *2) (-12 (-4 *1 (-863 *3)) (-5 *2 (-568))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-993 *2)) (-4 *2 (-558)) (-5 *1 (-143 *2 *4 *3)) (-4 *3 (-375 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-993 *2)) (-4 *2 (-558)) (-5 *1 (-512 *2 *4 *5 *3)) (-4 *5 (-375 *2)) (-4 *3 (-375 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-679 *4)) (-4 *4 (-993 *2)) (-4 *2 (-558)) (-5 *1 (-682 *2 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-993 *2)) (-4 *2 (-558)) (-5 *1 (-1212 *2 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *1 *1) (-5 *1 (-53))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-64 *5)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-63 *5 *2)))) ((*1 *2 *3 *1 *2 *2) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1090)) (|has| *1 (-6 -4519)) (-4 *1 (-154 *2)) (-4 *2 (-1195)))) ((*1 *2 *3 *1 *2) (-12 (-5 *3 (-1 *2 *2 *2)) (|has| *1 (-6 -4519)) (-4 *1 (-154 *2)) (-4 *2 (-1195)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 *2 *2 *2)) (|has| *1 (-6 -4519)) (-4 *1 (-154 *2)) (-4 *2 (-1195)))) ((*1 *2 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-2 (|:| -2700 (-1157 *4)) (|:| |deg| (-917)))) (-5 *1 (-211 *4 *5)) (-5 *3 (-1157 *4)) (-4 *5 (-13 (-558) (-842))))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *6 *2)) (-5 *4 (-232 *5 *6)) (-14 *5 (-763)) (-4 *6 (-1195)) (-4 *2 (-1195)) (-5 *1 (-231 *5 *6 *2)))) ((*1 *1 *2 *3) (-12 (-4 *4 (-172)) (-5 *1 (-284 *4 *2 *3 *5 *6 *7)) (-4 *2 (-1219 *4)) (-4 *3 (-23)) (-14 *5 (-1 *2 *2 *3)) (-14 *6 (-1 (-3 *3 "failed") *3 *3)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-310 *2)) (-4 *2 (-558)) (-4 *2 (-842)))) ((*1 *1 *1) (-12 (-4 *1 (-333 *2 *3 *4 *5)) (-4 *2 (-365)) (-4 *3 (-1219 *2)) (-4 *4 (-1219 (-409 *3))) (-4 *5 (-340 *2 *3 *4)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-373 *5 *4 *2 *6)) (-4 *4 (-375 *5)) (-4 *6 (-375 *2)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1090)) (-4 *2 (-1090)) (-5 *1 (-425 *5 *4 *2 *6)) (-4 *4 (-427 *5)) (-4 *6 (-427 *2)))) ((*1 *1 *1) (-5 *1 (-504))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-634 *5)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-632 *5 *2)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1047)) (-4 *2 (-1047)) (-4 *6 (-375 *5)) (-4 *7 (-375 *5)) (-4 *8 (-375 *2)) (-4 *9 (-375 *2)) (-5 *1 (-675 *5 *6 *7 *4 *2 *8 *9 *10)) (-4 *4 (-677 *5 *6 *7)) (-4 *10 (-677 *2 *8 *9)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-701 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-702 *3 *2)) (-4 *2 (-1219 *3)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-705 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-409 *4)) (-4 *4 (-1219 *3)) (-4 *3 (-365)) (-4 *3 (-172)) (-4 *1 (-714 *3 *4)))) ((*1 *1 *2) (-12 (-4 *3 (-172)) (-4 *1 (-714 *3 *2)) (-4 *2 (-1219 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-858)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-920 *4 *5)) (-4 *4 (-365)) (-4 *5 (-641 *4)) (-5 *2 (-236 *1)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-958 *5)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-957 *5 *2)))) ((*1 *1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-1034 *3 *4 *5 *2 *6)) (-4 *2 (-950 *3 *4 *5)) (-14 *6 (-634 *2)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *7 *2)) (-4 *7 (-1047)) (-4 *2 (-1047)) (-14 *5 (-763)) (-14 *6 (-763)) (-4 *8 (-230 *6 *7)) (-4 *9 (-230 *5 *7)) (-4 *10 (-230 *6 *2)) (-4 *11 (-230 *5 *2)) (-5 *1 (-1052 *5 *6 *7 *8 *9 *4 *2 *10 *11 *12)) (-4 *4 (-1050 *5 *6 *7 *8 *9)) (-4 *12 (-1050 *5 *6 *2 *10 *11)))) ((*1 *2 *2 *3 *4) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-1141 *5)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-1139 *5 *2)))) ((*1 *2 *2 *1 *3 *4) (-12 (-5 *3 (-1 *2 *2 *2)) (-5 *4 (-1 (-121) *2 *2)) (-4 *1 (-1189 *5 *6 *7 *2)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *2 (-1061 *5 *6 *7)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-1244 *5)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-1243 *5 *2))))) 
-(((*1 *1 *1 *1) (-5 *1 (-121))) ((*1 *1 *1 *1) (-4 *1 (-132))) ((*1 *1 *1 *1) (-5 *1 (-1108)))) 
-(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-139))))) 
-(((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-128 *2)) (-4 *2 (-1195))))) 
-(((*1 *1 *1 *2 *3 *1) (-12 (-4 *1 (-324 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) ((*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-607 *6)) (-4 *6 (-13 (-432 *5) (-27) (-1181))) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-1157 (-409 (-1157 *6)))) (-5 *1 (-564 *5 *6 *7)) (-5 *3 (-1157 *6)) (-4 *7 (-1090)))) ((*1 *2 *1) (-12 (-4 *2 (-1219 *3)) (-5 *1 (-702 *3 *2)) (-4 *3 (-1047)))) ((*1 *2 *1) (-12 (-4 *1 (-714 *3 *2)) (-4 *3 (-172)) (-4 *2 (-1219 *3)))) ((*1 *2 *3 *4 *4 *5 *6 *7 *8) (|partial| -12 (-5 *4 (-1157 *11)) (-5 *6 (-634 *10)) (-5 *7 (-634 (-763))) (-5 *8 (-634 *11)) (-4 *10 (-842)) (-4 *11 (-301)) (-4 *9 (-788)) (-4 *5 (-950 *11 *9 *10)) (-5 *2 (-634 (-1157 *5))) (-5 *1 (-732 *9 *10 *11 *5)) (-5 *3 (-1157 *5)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-858)))) ((*1 *2 *1) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-858)))) ((*1 *2 *1) (-12 (-4 *2 (-950 *3 *4 *5)) (-5 *1 (-1034 *3 *4 *5 *2 *6)) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-14 *6 (-634 *2))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-39)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-494 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-4 *3 (-453)) (-4 *4 (-842)) (-4 *5 (-788)) (-5 *2 (-121)) (-5 *1 (-988 *3 *4 *5 *6)) (-4 *6 (-950 *3 *5 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1132 *3)) (-4 *3 (-1090))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-256))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (|has| *2 (-6 (-4521 "*"))) (-4 *2 (-1047)))) ((*1 *2 *3) (-12 (-4 *4 (-375 *2)) (-4 *5 (-375 *2)) (-4 *2 (-172)) (-5 *1 (-678 *2 *4 *5 *3)) (-4 *3 (-677 *2 *4 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-1111 *3 *2 *4 *5)) (-4 *4 (-230 *3 *2)) (-4 *5 (-230 *3 *2)) (|has| *2 (-6 (-4521 "*"))) (-4 *2 (-1047))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 (-634 (-568)))) (-5 *1 (-924 *4 *5 *6 *7)) (-5 *3 (-568)) (-4 *7 (-950 *4 *6 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-835 (-381))) (-5 *2 (-835 (-215))) (-5 *1 (-299))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-593 *3)) (-4 *3 (-43 *2)) (-4 *3 (-1047))))) 
-(((*1 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-763)) (-4 *4 (-13 (-558) (-150))) (-5 *1 (-1213 *4 *2)) (-4 *2 (-1219 *4))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-213 *2 *3)) (-4 *2 (-13 (-1047) (-842))) (-14 *3 (-634 (-1161)))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *1 (-1226 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1203 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1249)) (-5 *1 (-1123)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-850))) (-5 *2 (-1249)) (-5 *1 (-1123))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1249)) (-5 *1 (-450 *4 *5 *6 *7)) (-4 *7 (-950 *4 *5 *6))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-1219 *4)) (-5 *2 (-1 *6 (-634 *6))) (-5 *1 (-1237 *4 *5 *3 *6)) (-4 *3 (-646 *5)) (-4 *6 (-1234 *4))))) 
-(((*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-158))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-926))))) 
-(((*1 *1) (-4 *1 (-350)))) 
-(((*1 *2 *3) (-12 (-5 *3 |RationalNumber|) (-5 *2 (-1 (-568))) (-5 *1 (-1045))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-917)) (-5 *1 (-1030 *2)) (-4 *2 (-13 (-1090) (-10 -8 (-15 -1767 ($ $ $)))))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-1047)) (-4 *6 (-230 *7 *3)) (-14 *7 *3) (-5 *2 (-634 *5)) (-5 *1 (-908 *4 *5 *6 *7)) (-4 *5 (-324 *4 *6))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-310 (-381))) (-5 *1 (-299))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
-(((*1 *2) (-12 (-5 *2 (-828 (-568))) (-5 *1 (-539)))) ((*1 *1) (-12 (-5 *1 (-828 *2)) (-4 *2 (-1090))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-634 *1)) (-4 *1 (-432 *4)) (-4 *4 (-842)))) ((*1 *1 *2 *1 *1 *1 *1) (-12 (-5 *2 (-1161)) (-4 *1 (-432 *3)) (-4 *3 (-842)))) ((*1 *1 *2 *1 *1 *1) (-12 (-5 *2 (-1161)) (-4 *1 (-432 *3)) (-4 *3 (-842)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1161)) (-4 *1 (-432 *3)) (-4 *3 (-842)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1161)) (-4 *1 (-432 *3)) (-4 *3 (-842))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-13 (-301) (-10 -8 (-15 -1678 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *1 (-508 *3 *4 *5)) (-4 *5 (-411 *3 *4)))) ((*1 *2 *2 *2 *3) (-12 (-5 *2 (-679 *3)) (-4 *3 (-13 (-301) (-10 -8 (-15 -1678 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *1 (-508 *3 *4 *5)) (-4 *5 (-411 *3 *4))))) 
-(((*1 *1) (-4 *1 (-23))) ((*1 *1) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) ((*1 *1) (-5 *1 (-541))) ((*1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-944 (-215))) (-5 *2 (-1249)) (-5 *1 (-473))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-121)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-465))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1157 *4))) (-4 *4 (-365)) (-5 *2 (-2 (|:| |zeros| (-634 *4)) (|:| -2842 (-568)))) (-5 *1 (-1043 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |preimage| (-634 *3)) (|:| |image| (-634 *3)))) (-5 *1 (-900 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-171)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-1219 *4)) (-5 *1 (-544 *4 *2 *5 *6)) (-4 *4 (-301)) (-14 *5 *4) (-14 *6 (-1 *4 *4 (-763)))))) 
-(((*1 *1 *1) (-4 *1 (-1056)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-1161)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-465))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-817))))) 
-(((*1 *1 *1) (-5 *1 (-121))) ((*1 *1 *1) (-4 *1 (-132))) ((*1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1) (-5 *1 (-1108)))) 
-(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-763))))) 
 (((*1 *2 *1 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-679 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-679 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1157 (-568))) (-5 *2 (-568)) (-5 *1 (-943))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *4)) (-5 *1 (-1116 *3 *4)) (-4 *3 (-1219 *4)))) ((*1 *2 *3 *3 *3 *3 *3) (-12 (-4 *3 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *3)) (-5 *1 (-1116 *4 *3)) (-4 *4 (-1219 *3))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *2 (-950 *4 *6 (-852 *5))) (-4 *6 (-230 (-1697 *5) (-763))) (-4 *7 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *4 *5 *2 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *1 (-467 *4 *5 *2 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-242 *5 *4)) (-5 *3 (-568)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-5 *1 (-867 *4 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-242 *5 *4)) (-5 *3 (-568)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *1 (-868 *4 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5)))) ((*1 *1 *1) (-12 (-4 *1 (-971 *2)) (-4 *2 (-365)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-971 *3)) (-4 *3 (-365))))) 
-(((*1 *1 *1) (|partial| -4 *1 (-1136)))) 
-(((*1 *2 *2) (-12 (-4 *3 (-842)) (-5 *1 (-930 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-310 (-568))) (-5 *1 (-931))))) 
-(((*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-679 (-409 *4)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-688)) (-5 *1 (-299))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-814 *3)) (-4 *3 (-842)) (-5 *1 (-663 *3))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-842)) (-5 *1 (-930 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-310 (-568))) (-5 *1 (-931))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-917)) (-4 *5 (-558)) (-5 *2 (-679 *5)) (-5 *1 (-956 *5 *3)) (-4 *3 (-646 *5))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4)))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-634 (-607 *5))) (-5 *3 (-1161)) (-4 *5 (-432 *4)) (-4 *4 (-842)) (-5 *1 (-577 *4 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-761)) (-5 *2 (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035)))) (-5 *1 (-569)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-761)) (-5 *4 (-1059)) (-5 *2 (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035)))) (-5 *1 (-569)))) ((*1 *2 *3 *4) (-12 (-4 *1 (-782)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035)))))) ((*1 *2 *3 *4) (-12 (-4 *1 (-782)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035)))))) ((*1 *2 *3 *4) (-12 (-4 *1 (-795)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)))))) ((*1 *2 *3) (-12 (-5 *3 (-803)) (-5 *2 (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-800)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-803)) (-5 *4 (-1059)) (-5 *2 (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-800)))) ((*1 *2 *3 *4) (-12 (-4 *1 (-831)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) (-5 *2 (-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)))))) ((*1 *2 *3 *4) (-12 (-4 *1 (-831)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (-5 *2 (-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)))))) ((*1 *2 *3) (-12 (-5 *3 (-833)) (-5 *2 (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-832)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-833)) (-5 *4 (-1059)) (-5 *2 (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-832)))) ((*1 *2 *3 *4) (-12 (-4 *1 (-890)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) (-5 *2 (-2 (|:| -3029 (-381)) (|:| |explanations| (-1143)))))) ((*1 *2 *3) (-12 (-5 *3 (-893)) (-5 *2 (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-892)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-893)) (-5 *4 (-1059)) (-5 *2 (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-892))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-128 *2)) (-4 *2 (-1195)))) ((*1 *1 *1) (-12 (-5 *1 (-663 *2)) (-4 *2 (-842)))) ((*1 *1 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-842)))) ((*1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) ((*1 *2 *1) (-12 (-4 *2 (-13 (-840) (-365))) (-5 *1 (-1057 *2 *3)) (-4 *3 (-1219 *2))))) 
-(((*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1 *8 *8)) (-5 *5 (-1 (-2 (|:| |ans| *7) (|:| -3284 *7) (|:| |sol?| (-121))) (-568) *7)) (-5 *6 (-634 (-409 *8))) (-4 *7 (-365)) (-4 *8 (-1219 *7)) (-5 *3 (-409 *8)) (-5 *2 (-2 (|:| |answer| (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (|:| |a0| *7))) (-5 *1 (-578 *7 *8))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-381)))) (-5 *2 (-1084 (-835 (-215)))) (-5 *1 (-299))))) 
-(((*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-4 *5 (-432 *4)) (-5 *2 (-420 (-1157 (-409 (-568))))) (-5 *1 (-437 *4 *5 *3)) (-4 *3 (-1219 *5))))) 
-(((*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-819)) (-5 *3 (-634 (-1161))) (-5 *1 (-820))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1182 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (-5 *1 (-263))))) 
-(((*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-747))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(((*1 *2 *3 *1) (-12 (-4 *4 (-365)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *4 *5 *6 *3)) (-4 *3 (-950 *4 *5 *6))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1244 *1)) (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1244 *1)) (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4)))))) 
-(((*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1084 (-835 (-215)))) (-5 *1 (-299))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-432 *2)) (-4 *2 (-842)) (-4 *2 (-558)))) ((*1 *1 *1) (-12 (-5 *1 (-733 *2 *3)) (-14 *2 (-1161)) (-4 *3 (-13 (-1047) (-842) (-558))))) ((*1 *1 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-702 *3 *2)) (-4 *2 (-1219 *3))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-751))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-607 *5)) (-4 *5 (-432 *4)) (-4 *4 (-1037 (-568))) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-1157 *5)) (-5 *1 (-36 *4 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-607 *1)) (-4 *1 (-1047)) (-4 *1 (-296)) (-5 *2 (-1157 *1))))) 
-(((*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-509 *2)) (-14 *2 (-568)))) ((*1 *1 *1 *1) (-5 *1 (-1108)))) 
-(((*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| -4192 (-123)) (|:| |arg| (-634 (-887 *3))))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) ((*1 *2 *1 *3) (|partial| -12 (-5 *3 (-123)) (-5 *2 (-634 (-887 *4))) (-5 *1 (-887 *4)) (-4 *4 (-1090))))) 
-(((*1 *2 *2 *2 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-607 *2)) (-5 *4 (-1 (-3 *2 "failed") *2 *2 (-1161))) (-4 *2 (-13 (-432 *5) (-27) (-1181))) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *1 (-570 *5 *2 *6)) (-4 *6 (-1090))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))))) ((*1 *2) (|partial| -12 (-4 *4 (-1199)) (-4 *5 (-1219 (-409 *2))) (-4 *2 (-1219 *4)) (-5 *1 (-339 *3 *4 *2 *5)) (-4 *3 (-340 *4 *2 *5)))) ((*1 *2) (|partial| -12 (-4 *1 (-340 *3 *2 *4)) (-4 *3 (-1199)) (-4 *4 (-1219 (-409 *2))) (-4 *2 (-1219 *3))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-634 (-607 *1))) (-4 *1 (-296))))) 
+(((*1 *2 *3 *4 *4 *5 *3 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *2 (-1035)) (-5 *1 (-744))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1094)) (-5 *1 (-1165))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |k| (-663 *3)) (|:| |c| *4)))) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-184)))) ((*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-294)))) ((*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-299))))) 
 (((*1 *1 *1 *1) (-5 *1 (-162))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-162))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-568)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-568))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) ((*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-777 *2)) (-4 *2 (-558)) (-4 *2 (-1047)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-970 *3 *2)) (-4 *2 (-1219 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) ((*1 *2 *3 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *1)))) (-4 *1 (-1066 *4 *5 *6 *3))))) 
 (((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1866 *7) (|:| -1844 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *5 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3)))) 
+(((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1058)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1058))))) 
 (((*1 *2 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-4 *1 (-227 *3)))) ((*1 *1) (-12 (-4 *1 (-227 *2)) (-4 *2 (-1090))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-817))))) 
+(((*1 *2) (-12 (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-904)) (-5 *1 (-459 *3 *4 *2 *5)) (-4 *5 (-950 *2 *3 *4)))) ((*1 *2) (-12 (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-904)) (-5 *1 (-901 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) ((*1 *2) (-12 (-4 *2 (-904)) (-5 *1 (-902 *2 *3)) (-4 *3 (-1219 *2))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1228 *3 *4 *5)) (-4 *3 (-13 (-365) (-842))) (-14 *4 (-1161)) (-14 *5 *3) (-5 *1 (-314 *3 *4 *5)))) ((*1 *2 *3) (-12 (-5 *2 (-1 (-381))) (-5 *1 (-1039)) (-5 *3 (-381))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4))))) ((*1 *1 *1) (-5 *1 (-381))) ((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *4)))) (-5 *1 (-768 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
 (((*1 *1 *1) (-5 *1 (-1059)))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *6)) (-5 *5 (-1 (-420 (-1157 *6)) (-1157 *6))) (-4 *6 (-365)) (-5 *2 (-634 (-2 (|:| |outval| *7) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 *7)))))) (-5 *1 (-535 *6 *7 *4)) (-4 *7 (-365)) (-4 *4 (-13 (-365) (-840)))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *1 (-106 *3)) (-4 *3 (-1090))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-637 *3)) (-4 *3 (-1047)) (-5 *1 (-704 *3 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-829 *3))))) 
+(((*1 *2 *2 *3) (-12 (-4 *3 (-301)) (-5 *1 (-457 *3 *2)) (-4 *2 (-1219 *3)))) ((*1 *2 *2 *3) (-12 (-4 *3 (-301)) (-5 *1 (-462 *3 *2)) (-4 *2 (-1219 *3)))) ((*1 *2 *2 *3) (-12 (-4 *3 (-301)) (-14 *4 *3) (-14 *5 (-1 *3 *3 (-763))) (-5 *1 (-544 *3 *2 *4 *5)) (-4 *2 (-1219 *3))))) 
 (((*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-607 *3)) (-5 *5 (-1 (-1157 *3) (-1157 *3))) (-4 *3 (-13 (-27) (-432 *6))) (-4 *6 (-13 (-842) (-558))) (-5 *2 (-585 *3)) (-5 *1 (-552 *6 *3))))) 
-(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160))))) 
-(((*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-310 (-568))) (-5 *1 (-483 *3)) (-4 *3 (-13 (-350) (-609 (-568))))))) 
+(((*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3))))) 
+(((*1 *2) (-12 (-5 *2 (-1121 (-215))) (-5 *1 (-1179))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-5 *1 (-496 *2)) (-4 *2 (-1219 (-568)))))) 
 (((*1 *2 *1) (-12 (-4 *2 (-950 *3 *5 *4)) (-5 *1 (-988 *3 *4 *5 *2)) (-4 *3 (-453)) (-4 *4 (-842)) (-4 *5 (-788))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-1157 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-900 *4)) (-4 *4 (-1090)) (-5 *2 (-634 (-763))) (-5 *1 (-899 *4))))) 
+(((*1 *1) (-5 *1 (-215))) ((*1 *1) (-5 *1 (-381)))) 
 (((*1 *2 *3 *3 *4) (-12 (-5 *3 (-634 (-492 *5 *6))) (-5 *4 (-852 *5)) (-14 *5 (-634 (-1161))) (-5 *2 (-492 *5 *6)) (-5 *1 (-622 *5 *6)) (-4 *6 (-453)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-492 *5 *6))) (-5 *4 (-852 *5)) (-14 *5 (-634 (-1161))) (-5 *2 (-492 *5 *6)) (-5 *1 (-622 *5 *6)) (-4 *6 (-453))))) 
+(((*1 *2 *3 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002)))))) 
+(((*1 *2) (-12 (-14 *4 (-763)) (-4 *5 (-1195)) (-5 *2 (-139)) (-5 *1 (-229 *3 *4 *5)) (-4 *3 (-230 *4 *5)))) ((*1 *2) (-12 (-4 *4 (-365)) (-5 *2 (-139)) (-5 *1 (-326 *3 *4)) (-4 *3 (-327 *4)))) ((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-392 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-172)))) ((*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-568)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-842)) (-4 *4 (-365)) (-4 *5 (-788)) (-5 *2 (-568)) (-5 *1 (-514 *4 *5 *6 *7)) (-4 *7 (-950 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-981 *3)) (-4 *3 (-1047)) (-5 *2 (-917)))) ((*1 *2) (-12 (-4 *1 (-1251 *3)) (-4 *3 (-365)) (-5 *2 (-139))))) 
+(((*1 *1 *1 *1) (-5 *1 (-121))) ((*1 *1 *1 *1) (-4 *1 (-132))) ((*1 *1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-453)) (-5 *2 (-121)) (-5 *1 (-362 *4 *5)) (-14 *5 (-634 (-1161))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-775 *4 (-852 *5)))) (-4 *4 (-453)) (-14 *5 (-634 (-1161))) (-5 *2 (-121)) (-5 *1 (-619 *4 *5))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-1157 *3))))) 
+(((*1 *2 *3 *3 *2) (|partial| -12 (-5 *2 (-763)) (-4 *3 (-13 (-716) (-370) (-10 -7 (-15 ** (*3 *3 (-568)))))) (-5 *1 (-241 *3))))) 
+(((*1 *2 *2 *2) (-12 (-5 *1 (-160 *2)) (-4 *2 (-550))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (-4 *2 (-1047)) (-4 *2 (-172))))) 
+(((*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *4 (-869)) (-5 *5 (-917)) (-5 *6 (-634 (-256))) (-5 *2 (-473)) (-5 *1 (-1248)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *2 (-473)) (-5 *1 (-1248)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *4 (-634 (-256))) (-5 *2 (-473)) (-5 *1 (-1248))))) 
 (((*1 *2 *3 *4 *2 *2 *2 *5) (-12 (-5 *3 (-123)) (-5 *5 (-634 *2)) (-4 *2 (-13 (-432 *6) (-23) (-1037 (-568)) (-1037 *4) (-895 *4) (-161))) (-5 *4 (-1161)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *1 (-1024 *6 *2))))) 
-(((*1 *2 *3 *3 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3649 *3) (|:| -4083 *4)))) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *1 (-1172 *3 *4)))) ((*1 *1) (-12 (-4 *1 (-1172 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090))))) 
+(((*1 *2 *2 *3 *3 *4) (-12 (-5 *3 (-763)) (-4 *2 (-13 (-558) (-453))) (-5 *1 (-346 *2 *4)) (-4 *4 (-52 *2 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-1143)) (-5 *1 (-184)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1100))))) 
+(((*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-852 *5))) (-14 *5 (-634 (-1161))) (-4 *6 (-453)) (-5 *2 (-2 (|:| |dpolys| (-634 (-242 *5 *6))) (|:| |coords| (-634 (-568))))) (-5 *1 (-476 *5 *6 *7)) (-5 *3 (-634 (-242 *5 *6))) (-4 *7 (-453))))) 
+(((*1 *1 *1) (-5 *1 (-53))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-64 *5)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-63 *5 *2)))) ((*1 *2 *3 *1 *2 *2) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1090)) (|has| *1 (-6 -4521)) (-4 *1 (-154 *2)) (-4 *2 (-1195)))) ((*1 *2 *3 *1 *2) (-12 (-5 *3 (-1 *2 *2 *2)) (|has| *1 (-6 -4521)) (-4 *1 (-154 *2)) (-4 *2 (-1195)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 *2 *2 *2)) (|has| *1 (-6 -4521)) (-4 *1 (-154 *2)) (-4 *2 (-1195)))) ((*1 *2 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-2 (|:| -1416 (-1157 *4)) (|:| |deg| (-917)))) (-5 *1 (-211 *4 *5)) (-5 *3 (-1157 *4)) (-4 *5 (-13 (-558) (-842))))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *6 *2)) (-5 *4 (-232 *5 *6)) (-14 *5 (-763)) (-4 *6 (-1195)) (-4 *2 (-1195)) (-5 *1 (-231 *5 *6 *2)))) ((*1 *1 *2 *3) (-12 (-4 *4 (-172)) (-5 *1 (-284 *4 *2 *3 *5 *6 *7)) (-4 *2 (-1219 *4)) (-4 *3 (-23)) (-14 *5 (-1 *2 *2 *3)) (-14 *6 (-1 (-3 *3 "failed") *3 *3)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-310 *2)) (-4 *2 (-558)) (-4 *2 (-842)))) ((*1 *1 *1) (-12 (-4 *1 (-333 *2 *3 *4 *5)) (-4 *2 (-365)) (-4 *3 (-1219 *2)) (-4 *4 (-1219 (-409 *3))) (-4 *5 (-340 *2 *3 *4)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-373 *5 *4 *2 *6)) (-4 *4 (-375 *5)) (-4 *6 (-375 *2)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1090)) (-4 *2 (-1090)) (-5 *1 (-425 *5 *4 *2 *6)) (-4 *4 (-427 *5)) (-4 *6 (-427 *2)))) ((*1 *1 *1) (-5 *1 (-504))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-634 *5)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-632 *5 *2)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-4 *5 (-1047)) (-4 *2 (-1047)) (-4 *6 (-375 *5)) (-4 *7 (-375 *5)) (-4 *8 (-375 *2)) (-4 *9 (-375 *2)) (-5 *1 (-675 *5 *6 *7 *4 *2 *8 *9 *10)) (-4 *4 (-677 *5 *6 *7)) (-4 *10 (-677 *2 *8 *9)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-701 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-702 *3 *2)) (-4 *2 (-1219 *3)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-705 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-409 *4)) (-4 *4 (-1219 *3)) (-4 *3 (-365)) (-4 *3 (-172)) (-4 *1 (-714 *3 *4)))) ((*1 *1 *2) (-12 (-4 *3 (-172)) (-4 *1 (-714 *3 *2)) (-4 *2 (-1219 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-858)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-920 *4 *5)) (-4 *4 (-365)) (-4 *5 (-641 *4)) (-5 *2 (-236 *1)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-958 *5)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-957 *5 *2)))) ((*1 *1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-1034 *3 *4 *5 *2 *6)) (-4 *2 (-950 *3 *4 *5)) (-14 *6 (-634 *2)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *7 *2)) (-4 *7 (-1047)) (-4 *2 (-1047)) (-14 *5 (-763)) (-14 *6 (-763)) (-4 *8 (-230 *6 *7)) (-4 *9 (-230 *5 *7)) (-4 *10 (-230 *6 *2)) (-4 *11 (-230 *5 *2)) (-5 *1 (-1052 *5 *6 *7 *8 *9 *4 *2 *10 *11 *12)) (-4 *4 (-1050 *5 *6 *7 *8 *9)) (-4 *12 (-1050 *5 *6 *2 *10 *11)))) ((*1 *2 *2 *3 *4) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-1141 *5)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-1139 *5 *2)))) ((*1 *2 *2 *1 *3 *4) (-12 (-5 *3 (-1 *2 *2 *2)) (-5 *4 (-1 (-121) *2 *2)) (-4 *1 (-1189 *5 *6 *7 *2)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *2 (-1061 *5 *6 *7)))) ((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *5 *2)) (-5 *4 (-1244 *5)) (-4 *5 (-1195)) (-4 *2 (-1195)) (-5 *1 (-1243 *5 *2))))) 
+(((*1 *1 *1 *1) (-5 *1 (-121))) ((*1 *1 *1 *1) (-4 *1 (-132))) ((*1 *1 *1 *1) (-5 *1 (-1108)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-492 *4 *5))) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *2 (-634 (-242 *4 *5))) (-5 *1 (-622 *4 *5))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-953 (-215))) (-5 *2 (-215)) (-5 *1 (-299))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-778 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-172))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
 (((*1 *2 *3 *2) (-12 (-5 *2 (-869)) (-5 *3 (-634 (-256))) (-5 *1 (-254))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-607 *6)) (-4 *6 (-13 (-432 *5) (-27) (-1181))) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-1157 (-409 (-1157 *6)))) (-5 *1 (-564 *5 *6 *7)) (-5 *3 (-1157 *6)) (-4 *7 (-1090)))) ((*1 *2 *1) (-12 (-4 *2 (-1219 *3)) (-5 *1 (-702 *3 *2)) (-4 *3 (-1047)))) ((*1 *2 *1) (-12 (-4 *1 (-714 *3 *2)) (-4 *3 (-172)) (-4 *2 (-1219 *3)))) ((*1 *2 *3 *4 *4 *5 *6 *7 *8) (|partial| -12 (-5 *4 (-1157 *11)) (-5 *6 (-634 *10)) (-5 *7 (-634 (-763))) (-5 *8 (-634 *11)) (-4 *10 (-842)) (-4 *11 (-301)) (-4 *9 (-788)) (-4 *5 (-950 *11 *9 *10)) (-5 *2 (-634 (-1157 *5))) (-5 *1 (-732 *9 *10 *11 *5)) (-5 *3 (-1157 *5)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-858)))) ((*1 *2 *1) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-858)))) ((*1 *2 *1) (-12 (-4 *2 (-950 *3 *4 *5)) (-5 *1 (-1034 *3 *4 *5 *2 *6)) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-14 *6 (-634 *2))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-5 *2 (-1249)) (-5 *1 (-1164)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-5 *2 (-1249)) (-5 *1 (-1164)))) ((*1 *2 *3 *4 *1) (-12 (-5 *3 (-1161)) (-5 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-5 *2 (-1249)) (-5 *1 (-1164))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2319 ((-1113 *3 (-607 $)) $)) (-15 -2326 ((-1113 *3 (-607 $)) $)) (-15 -2747 ($ (-1113 *3 (-607 $)))))))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *1) (-5 *1 (-142))) ((*1 *1 *1) (-5 *1 (-147))) ((*1 *1 *1) (-4 *1 (-1129)))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2910 *3) (|:| |coef2| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047))))) 
 (((*1 *1 *2 *3) (-12 (-5 *3 (-1141 *2)) (-4 *2 (-301)) (-5 *1 (-173 *2))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-4 *2 (-895 *5)) (-5 *1 (-681 *5 *2 *3 *4)) (-4 *3 (-375 *2)) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4519))))))) 
-(((*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1 *3)) (-5 *1 (-671 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-4 *2 (-895 *5)) (-5 *1 (-681 *5 *2 *3 *4)) (-4 *3 (-375 *2)) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4521))))))) 
+(((*1 *2 *3 *4 *5 *5 *4 *6) (-12 (-5 *5 (-607 *4)) (-5 *6 (-1157 *4)) (-4 *4 (-13 (-432 *7) (-27) (-1181))) (-4 *7 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2588 (-634 *4)))) (-5 *1 (-564 *7 *4 *3)) (-4 *3 (-646 *4)) (-4 *3 (-1090)))) ((*1 *2 *3 *4 *5 *5 *5 *4 *6) (-12 (-5 *5 (-607 *4)) (-5 *6 (-409 (-1157 *4))) (-4 *4 (-13 (-432 *7) (-27) (-1181))) (-4 *7 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2588 (-634 *4)))) (-5 *1 (-564 *7 *4 *3)) (-4 *3 (-646 *4)) (-4 *3 (-1090))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-541))))) 
+(((*1 *2 *3 *2) (|partial| -12 (-5 *2 (-1244 *4)) (-5 *3 (-679 *4)) (-4 *4 (-365)) (-5 *1 (-659 *4)))) ((*1 *2 *3 *2) (|partial| -12 (-4 *4 (-365)) (-4 *5 (-13 (-375 *4) (-10 -7 (-6 -4522)))) (-4 *2 (-13 (-375 *4) (-10 -7 (-6 -4522)))) (-5 *1 (-660 *4 *5 *2 *3)) (-4 *3 (-677 *4 *5 *2)))) ((*1 *2 *3 *2 *4 *5) (|partial| -12 (-5 *4 (-634 *2)) (-5 *5 (-1 *2 *2)) (-4 *2 (-365)) (-5 *1 (-809 *2 *3)) (-4 *3 (-646 *2)))) ((*1 *2 *3) (-12 (-4 *2 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *1 (-1116 *3 *2)) (-4 *3 (-1219 *2))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-840))) (-5 *1 (-178 *3 *2)) (-4 *2 (-1219 (-169 *3)))))) 
 (((*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842))) (-4 *2 (-13 (-432 *4) (-1002) (-1181))) (-5 *1 (-597 *4 *2 *3)) (-4 *3 (-13 (-432 (-169 *4)) (-1002) (-1181)))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-634 *5)) (-4 *1 (-920 *4 *5)) (-4 *4 (-365)) (-4 *5 (-641 *4)) (-5 *2 (-1249))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-1 (-634 *4) *4)) (-5 *1 (-107 *4)) (-5 *3 (-634 *4))))) 
 (((*1 *2 *3) (|partial| -12 (-5 *3 (-679 *1)) (-4 *1 (-350)) (-5 *2 (-1244 *1)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-679 *1)) (-4 *1 (-148)) (-4 *1 (-904)) (-5 *2 (-1244 *1))))) 
+(((*1 *2 *3 *4 *4 *3 *5) (-12 (-5 *4 (-607 *3)) (-5 *5 (-1157 *3)) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-564 *6 *3 *7)) (-4 *7 (-1090)))) ((*1 *2 *3 *4 *4 *4 *3 *5) (-12 (-5 *4 (-607 *3)) (-5 *5 (-409 (-1157 *3))) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-564 *6 *3 *7)) (-4 *7 (-1090))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-57)) (-5 *1 (-1174))))) 
 (((*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568)))) ((*1 *2 *1) (-12 (-5 *2 (-1244 (-3 (-473) "undefined"))) (-5 *1 (-1245))))) 
-(((*1 *2 *3 *4 *3 *4 *4 *4 *4 *4) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-917)) (-5 *1 (-1030 *2)) (-4 *2 (-13 (-1090) (-10 -8 (-15 -1769 ($ $ $)))))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-1182 *2)) (-4 *2 (-1090))))) 
+(((*1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-144)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-145)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-216)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-218))))) 
 (((*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-634 *1)) (-4 *1 (-384 *3 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-725 *3 *4))) (-5 *1 (-725 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-716)))) ((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *2 (-634 *3)) (-5 *1 (-908 *4 *3 *5 *6)) (-4 *3 (-324 *4 *5)))) ((*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-950 *3 *4 *5))))) 
+(((*1 *2) (-12 (-5 *2 (-828 (-568))) (-5 *1 (-539)))) ((*1 *1) (-12 (-5 *1 (-828 *2)) (-4 *2 (-1090))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-634 *1)) (-4 *1 (-432 *4)) (-4 *4 (-842)))) ((*1 *1 *2 *1 *1 *1 *1) (-12 (-5 *2 (-1161)) (-4 *1 (-432 *3)) (-4 *3 (-842)))) ((*1 *1 *2 *1 *1 *1) (-12 (-5 *2 (-1161)) (-4 *1 (-432 *3)) (-4 *3 (-842)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1161)) (-4 *1 (-432 *3)) (-4 *3 (-842)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1161)) (-4 *1 (-432 *3)) (-4 *3 (-842))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-953 (-568))) (-5 *2 (-634 *1)) (-4 *1 (-1012)))) ((*1 *2 *3) (-12 (-5 *3 (-953 (-409 (-568)))) (-5 *2 (-634 *1)) (-4 *1 (-1012)))) ((*1 *2 *3) (-12 (-5 *3 (-953 *1)) (-4 *1 (-1012)) (-5 *2 (-634 *1)))) ((*1 *2 *3) (-12 (-5 *3 (-1157 (-568))) (-5 *2 (-634 *1)) (-4 *1 (-1012)))) ((*1 *2 *3) (-12 (-5 *3 (-1157 (-409 (-568)))) (-5 *2 (-634 *1)) (-4 *1 (-1012)))) ((*1 *2 *3) (-12 (-5 *3 (-1157 *1)) (-4 *1 (-1012)) (-5 *2 (-634 *1)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-840) (-365))) (-4 *3 (-1219 *4)) (-5 *2 (-634 *1)) (-4 *1 (-1063 *4 *3))))) 
+(((*1 *1) (-4 *1 (-23))) ((*1 *1) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) ((*1 *1) (-5 *1 (-541))) ((*1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-858))))) 
 (((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *4)) (-5 *1 (-1116 *3 *4)) (-4 *3 (-1219 *4)))) ((*1 *2 *3 *3 *3) (-12 (-4 *3 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *3)) (-5 *1 (-1116 *4 *3)) (-4 *4 (-1219 *3))))) 
+(((*1 *2 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1205 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1234 *3))))) 
 (((*1 *2 *2 *2 *2) (-12 (-4 *2 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *1 (-1116 *3 *2)) (-4 *3 (-1219 *2))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) ((*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
+(((*1 *2 *3) (-12 (-4 *2 (-1219 *4)) (-5 *1 (-804 *4 *2 *3 *5)) (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *3 (-646 *2)) (-4 *5 (-646 (-409 *2)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-1161)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-465))))) 
 (((*1 *2 *3 *3 *3 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-1 (-634 *4) *4)) (-5 *1 (-107 *4)) (-5 *3 (-634 *4))))) 
-(((*1 *2 *3 *3 *4 *4 *3 *3 *5 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-814 *4)) (-4 *4 (-842)) (-5 *2 (-121)) (-5 *1 (-663 *4))))) 
+(((*1 *1 *1) (-5 *1 (-121))) ((*1 *1 *1) (-4 *1 (-132))) ((*1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1) (-5 *1 (-1108)))) 
+(((*1 *1 *1) (-12 (-4 *1 (-950 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453)))) ((*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *1)))) (-4 *1 (-1066 *4 *5 *6 *3)))) ((*1 *1 *1) (-4 *1 (-1199))) ((*1 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-1222 *3 *2)) (-4 *2 (-13 (-1219 *3) (-558) (-10 -8 (-15 -2723 ($ $ $)))))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-763)) (-5 *1 (-586 *2)) (-4 *2 (-550))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-96 *3))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-630 (-568))) (-5 *2 (-121)) (-5 *1 (-1269 *4))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-842)) (-5 *1 (-930 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-310 (-568))) (-5 *1 (-931))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-365)) (-5 *1 (-891 *2 *4)) (-4 *2 (-1219 *4))))) 
+(((*1 *2 *3) (|partial| -12 (-4 *2 (-1090)) (-5 *1 (-1173 *3 *2)) (-4 *3 (-1090))))) 
 (((*1 *2 *3 *4) (-12 (-4 *2 (-1219 *4)) (-5 *1 (-802 *4 *2 *3 *5)) (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *3 (-646 *2)) (-4 *5 (-646 (-409 *2))))) ((*1 *2 *3 *4) (-12 (-4 *2 (-1219 *4)) (-5 *1 (-802 *4 *2 *5 *3)) (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *5 (-646 *2)) (-4 *3 (-646 (-409 *2)))))) 
-(((*1 *2 *3 *4 *4 *3 *3 *5) (|partial| -12 (-5 *4 (-607 *3)) (-5 *5 (-1157 *3)) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| -1924 *3) (|:| |coeff| *3))) (-5 *1 (-564 *6 *3 *7)) (-4 *7 (-1090)))) ((*1 *2 *3 *4 *4 *3 *4 *3 *5) (|partial| -12 (-5 *4 (-607 *3)) (-5 *5 (-409 (-1157 *3))) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| -1924 *3) (|:| |coeff| *3))) (-5 *1 (-564 *6 *3 *7)) (-4 *7 (-1090))))) 
-(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-473)) (-5 *4 (-917)) (-5 *2 (-1249)) (-5 *1 (-1245))))) 
-(((*1 *2 *3 *3 *3 *4 *5 *3 *6 *6 *3) (-12 (-5 *3 (-568)) (-5 *5 (-121)) (-5 *6 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-842)) (-5 *1 (-930 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-310 (-568))) (-5 *1 (-931))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7))))) 
+(((*1 *2 *2 *3 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-614 *4 *2)) (-4 *2 (-13 (-1181) (-959) (-29 *4)))))) 
+(((*1 *2 *3 *4 *4 *3 *3 *5) (|partial| -12 (-5 *4 (-607 *3)) (-5 *5 (-1157 *3)) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| -4151 *3) (|:| |coeff| *3))) (-5 *1 (-564 *6 *3 *7)) (-4 *7 (-1090)))) ((*1 *2 *3 *4 *4 *3 *4 *3 *5) (|partial| -12 (-5 *4 (-607 *3)) (-5 *5 (-409 (-1157 *3))) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| -4151 *3) (|:| |coeff| *3))) (-5 *1 (-564 *6 *3 *7)) (-4 *7 (-1090))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-761)) (-5 *2 (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035)))) (-5 *1 (-569)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-761)) (-5 *4 (-1059)) (-5 *2 (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035)))) (-5 *1 (-569)))) ((*1 *2 *3 *4) (-12 (-4 *1 (-782)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035)))))) ((*1 *2 *3 *4) (-12 (-4 *1 (-782)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)) (|:| |extra| (-1035)))))) ((*1 *2 *3 *4) (-12 (-4 *1 (-795)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)))))) ((*1 *2 *3) (-12 (-5 *3 (-803)) (-5 *2 (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-800)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-803)) (-5 *4 (-1059)) (-5 *2 (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-800)))) ((*1 *2 *3 *4) (-12 (-4 *1 (-831)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) (-5 *2 (-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)))))) ((*1 *2 *3 *4) (-12 (-4 *1 (-831)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (-5 *2 (-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)))))) ((*1 *2 *3) (-12 (-5 *3 (-833)) (-5 *2 (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-832)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-833)) (-5 *4 (-1059)) (-5 *2 (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-832)))) ((*1 *2 *3 *4) (-12 (-4 *1 (-890)) (-5 *3 (-1059)) (-5 *4 (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) (-5 *2 (-2 (|:| -3031 (-381)) (|:| |explanations| (-1143)))))) ((*1 *2 *3) (-12 (-5 *3 (-893)) (-5 *2 (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-892)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-893)) (-5 *4 (-1059)) (-5 *2 (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *1 (-892))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-128 *2)) (-4 *2 (-1195)))) ((*1 *1 *1) (-12 (-5 *1 (-663 *2)) (-4 *2 (-842)))) ((*1 *1 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-842)))) ((*1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) ((*1 *2 *1) (-12 (-4 *2 (-13 (-840) (-365))) (-5 *1 (-1057 *2 *3)) (-4 *3 (-1219 *2))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-225)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-1 *1 (-763))) (-4 *1 (-246 *3 *4 *5 *6)))) ((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *3 (-842)) (-4 *5 (-262 *3)) (-4 *6 (-788)) (-5 *2 (-1 *1 (-763))) (-4 *1 (-246 *4 *3 *5 *6)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-262 *2)) (-4 *2 (-842))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
 (((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-900 *3))))) 
+(((*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *1 *1) (-5 *1 (-215))) ((*1 *1 *1) (-5 *1 (-381))) ((*1 *1) (-5 *1 (-381)))) 
+(((*1 *2 *3 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-634 (-568)))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-817))))) 
+(((*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-917)) (-5 *2 (-1244 (-634 (-2 (|:| -2852 *4) (|:| -4357 (-1108)))))) (-5 *1 (-347 *4)) (-4 *4 (-350))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
 (((*1 *2 *3 *3) (-12 (-4 *2 (-558)) (-5 *1 (-970 *2 *3)) (-4 *3 (-1219 *2))))) 
-(((*1 *2 *3 *3 *4 *3 *3 *3 *3 *3 *3 *3 *5 *3 *6 *7) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-72 DOT)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-73 IMAGE)))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-747)))) ((*1 *2 *3 *3 *4 *3 *3 *3 *3 *3 *3 *3 *5 *3 *6 *7 *8) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-72 DOT)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-73 IMAGE)))) (-5 *8 (-390)) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-747))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-247 *3)) (-4 *3 (-1195)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-296)) (-5 *2 (-763)))) ((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))) (-5 *1 (-444 *4 *3 *2)) (-4 *3 (-1219 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-607 *3)) (-4 *3 (-842)))) ((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) ((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-850))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-634 (-256))) (-5 *4 (-1161)) (-5 *1 (-255 *2)) (-4 *2 (-1195)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-634 (-256))) (-5 *4 (-1161)) (-5 *2 (-57)) (-5 *1 (-256)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-634 (-465))) (-5 *4 (-1161)) (-5 *2 (-57)) (-5 *1 (-465))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-409 *2)) (-5 *4 (-1 *2 *2)) (-4 *2 (-1219 *5)) (-5 *1 (-717 *5 *2)) (-4 *5 (-365))))) 
+(((*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-634 (-2 (|:| |k| *4) (|:| |c| *3)))))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |k| (-888 *3)) (|:| |c| *4)))) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-663 *3))) (-5 *1 (-888 *3)) (-4 *3 (-842))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
 (((*1 *2 *3 *4 *4 *5 *3 *6) (|partial| -12 (-5 *4 (-607 *3)) (-5 *5 (-634 *3)) (-5 *6 (-1157 *3)) (-4 *3 (-13 (-432 *7) (-27) (-1181))) (-4 *7 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-564 *7 *3 *8)) (-4 *8 (-1090)))) ((*1 *2 *3 *4 *4 *5 *4 *3 *6) (|partial| -12 (-5 *4 (-607 *3)) (-5 *5 (-634 *3)) (-5 *6 (-409 (-1157 *3))) (-4 *3 (-13 (-432 *7) (-27) (-1181))) (-4 *7 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-564 *7 *3 *8)) (-4 *8 (-1090))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *6 (-230 (-1699 *5) (-763))) (-4 *7 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *12)) (-5 *1 (-260 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *12)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2) (-12 (-5 *2 (-634 (-259 (-537 *3 *4 *5)))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-634 (-259 (-513 *3 *4 *5)))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
+(((*1 *2 *1 *1) (|partial| -12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5 *4)) (-4 *5 (-1090)) (-4 *4 (-1090)) (-4 *6 (-1090)) (-5 *2 (-1 *6 *5)) (-5 *1 (-673 *5 *4 *6))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396))))) 
+(((*1 *2 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-509 *2)) (-14 *2 (-568)))) ((*1 *1 *1 *1) (-5 *1 (-1108)))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 *9)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-763)) (-5 *1 (-1064 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 *9)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1099 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-763)) (-5 *1 (-1130 *5 *6 *7 *8 *9))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-5 *2 (-679 *4)) (-5 *1 (-809 *4 *5)) (-4 *5 (-646 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-763)) (-4 *5 (-365)) (-5 *2 (-679 *5)) (-5 *1 (-809 *5 *6)) (-4 *6 (-646 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 *6 *5)) (-5 *1 (-696 *4 *5 *6)) (-4 *4 (-609 (-541))) (-4 *5 (-1195)) (-4 *6 (-1195))))) 
 (((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *2 *3 *3 *3 *3 *3 *4 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-121)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-288 (-310 *5)))) (-5 *1 (-1117 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-288 (-310 *4)))) (-5 *1 (-1117 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-288 (-409 (-953 *5)))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-288 (-310 *5)))) (-5 *1 (-1117 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-288 (-409 (-953 *4)))) (-4 *4 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-288 (-310 *4)))) (-5 *1 (-1117 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 *5)))) (-5 *4 (-634 (-1161))) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-634 (-288 (-310 *5))))) (-5 *1 (-1117 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 *4)))) (-4 *4 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-634 (-288 (-310 *4))))) (-5 *1 (-1117 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-288 (-409 (-953 *5))))) (-5 *4 (-634 (-1161))) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-634 (-288 (-310 *5))))) (-5 *1 (-1117 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-288 (-409 (-953 *4))))) (-4 *4 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-634 (-288 (-310 *4))))) (-5 *1 (-1117 *4))))) 
 (((*1 *1 *2 *3) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3)))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-5 *2 (-2 (|:| |contp| (-568)) (|:| -3276 (-634 (-2 (|:| |irr| *3) (|:| -3959 (-568))))))) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-5 *2 (-2 (|:| |contp| (-568)) (|:| -3276 (-634 (-2 (|:| |irr| *3) (|:| -3959 (-568))))))) (-5 *1 (-1208 *3)) (-4 *3 (-1219 (-568)))))) 
-(((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-121)) (-5 *5 (-1092 (-763))) (-5 *6 (-763)) (-5 *2 (-2 (|:| |contp| (-568)) (|:| -3276 (-634 (-2 (|:| |irr| *3) (|:| -3959 (-568))))))) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568)))))) 
-(((*1 *2 *3 *3 *3 *3 *3 *4 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-121)) (-5 *5 (-679 (-169 (-215)))) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-917)) (-5 *2 (-121)) (-5 *1 (-233 *4)) (-4 *4 (-1047))))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-1157 *1)) (-4 *1 (-858)) (-5 *2 (-634 *1)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-365)) (-5 *2 (-2 (|:| |zeros| (-634 *4)) (|:| -3917 (-568)))) (-5 *1 (-1043 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-5 *2 (-2 (|:| |contp| (-568)) (|:| -2075 (-634 (-2 (|:| |irr| *3) (|:| -4402 (-568))))))) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-5 *2 (-2 (|:| |contp| (-568)) (|:| -2075 (-634 (-2 (|:| |irr| *3) (|:| -4402 (-568))))))) (-5 *1 (-1208 *3)) (-4 *3 (-1219 (-568)))))) 
+(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160))))) 
+(((*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436))))) 
+(((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-121)) (-5 *5 (-1092 (-763))) (-5 *6 (-763)) (-5 *2 (-2 (|:| |contp| (-568)) (|:| -2075 (-634 (-2 (|:| |irr| *3) (|:| -4402 (-568))))))) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568)))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1249)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-258 *12)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 *7)) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1699 *6) (-763))) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *9 (-971 *5)) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-4 *12 (-235 *11)) (-4 *13 (-536 *5 *6 *7 *8 *9 *10 *11 *12 *14)) (-4 *14 (-117)) (-5 *2 (-1249)) (-5 *1 (-260 *5 *6 *7 *8 *9 *10 *11 *12 *13 *3 *14)) (-4 *3 (-258 *13))))) 
+(((*1 *2 *3 *3 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3651 *3) (|:| -4085 *4)))) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *1 (-1172 *3 *4)))) ((*1 *1) (-12 (-4 *1 (-1172 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-121))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) (-5 *2 (-634 (-215))) (-5 *1 (-299))))) 
+(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
+(((*1 *2 *3 *3 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-121))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-5 *2 (-634 (-1161))) (-5 *1 (-202)) (-5 *3 (-1161)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-310 (-215))) (-5 *4 (-763)) (-5 *2 (-634 (-1161))) (-5 *1 (-263)))) ((*1 *2 *1) (-12 (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *2 (-634 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917)))) ((*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-667 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-814 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-888 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-634 *3))))) 
 (((*1 *2 *2) (-12 (-5 *2 (-988 (-409 (-568)) (-852 *3) (-232 *4 (-763)) (-242 *3 (-409 (-568))))) (-14 *3 (-634 (-1161))) (-14 *4 (-763)) (-5 *1 (-987 *3 *4))))) 
+(((*1 *2 *3 *4 *3 *4 *4 *4 *4 *4) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *2 *3 *1) (-12 (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-344 *4 *3)) (-4 *3 (-1219 *4))))) 
 (((*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-634 (-634 (-3 (|:| |array| *6) (|:| |scalar| *3))))) (-5 *4 (-634 (-3 (|:| |array| (-634 *3)) (|:| |scalar| (-1161))))) (-5 *6 (-634 (-1161))) (-5 *3 (-1161)) (-5 *2 (-1094)) (-5 *1 (-399)))) ((*1 *2 *3 *4 *5 *6 *3) (-12 (-5 *5 (-634 (-634 (-3 (|:| |array| *6) (|:| |scalar| *3))))) (-5 *4 (-634 (-3 (|:| |array| (-634 *3)) (|:| |scalar| (-1161))))) (-5 *6 (-634 (-1161))) (-5 *3 (-1161)) (-5 *2 (-1094)) (-5 *1 (-399)))) ((*1 *2 *3 *4 *5 *4) (-12 (-5 *4 (-634 (-1161))) (-5 *5 (-1164)) (-5 *3 (-1161)) (-5 *2 (-1094)) (-5 *1 (-399))))) 
-(((*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-1143)) (-5 *4 (-169 (-215))) (-5 *5 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1244 *4)) (-4 *4 (-630 *5)) (-4 *5 (-365)) (-4 *5 (-558)) (-5 *2 (-1244 *5)) (-5 *1 (-629 *5 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1244 *4)) (-4 *4 (-630 *5)) (-3044 (-4 *5 (-365))) (-4 *5 (-558)) (-5 *2 (-1244 (-409 *5))) (-5 *1 (-629 *5 *4))))) 
-(((*1 *2 *3) (|partial| -12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-2 (|:| |bas| (-481 *4 *5 *6 *7)) (|:| -2616 (-634 *7)))) (-5 *1 (-978 *4 *5 *6 *7)) (-5 *3 (-634 *7))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
+(((*1 *2 *3 *3 *4 *4 *3 *3 *5 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-763)) (-5 *1 (-734 *4 *3)) (-14 *4 (-1161)) (-4 *3 (-1047)))) ((*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-763)) (-5 *1 (-777 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2 *3 *1) (-12 (-5 *1 (-964 *3 *2)) (-4 *2 (-137)) (-4 *3 (-558)) (-4 *3 (-1047)) (-4 *2 (-787)))) ((*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1157 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-972)) (-4 *2 (-137)) (-5 *1 (-1163 *3)) (-4 *3 (-558)) (-4 *3 (-1047)))) ((*1 *1 *1 *2 *3 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1216 *4 *3)) (-14 *4 (-1161)) (-4 *3 (-1047))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1143)) (-5 *1 (-781))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1244 *4)) (-4 *4 (-630 *5)) (-4 *5 (-365)) (-4 *5 (-558)) (-5 *2 (-1244 *5)) (-5 *1 (-629 *5 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1244 *4)) (-4 *4 (-630 *5)) (-3046 (-4 *5 (-365))) (-4 *5 (-558)) (-5 *2 (-1244 (-409 *5))) (-5 *1 (-629 *5 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-568))) (-5 *4 (-900 (-568))) (-5 *2 (-679 (-568))) (-5 *1 (-589)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-634 (-679 (-568)))) (-5 *1 (-589)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-568))) (-5 *4 (-634 (-900 (-568)))) (-5 *2 (-634 (-679 (-568)))) (-5 *1 (-589))))) 
+(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-473)) (-5 *4 (-917)) (-5 *2 (-1249)) (-5 *1 (-1245))))) 
+(((*1 *2 *3 *3 *3 *4 *5 *3 *6 *6 *3) (-12 (-5 *3 (-568)) (-5 *5 (-121)) (-5 *6 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1164)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164))))) 
+(((*1 *2 *3 *2 *2) (-12 (-5 *2 (-634 (-492 *4 *5))) (-5 *3 (-852 *4)) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *1 (-622 *4 *5))))) 
+(((*1 *2 *3) (|partial| -12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-2 (|:| |bas| (-481 *4 *5 *6 *7)) (|:| -2618 (-634 *7)))) (-5 *1 (-978 *4 *5 *6 *7)) (-5 *3 (-634 *7))))) 
+(((*1 *2 *3 *3 *4 *3 *3 *3 *3 *3 *3 *3 *5 *3 *6 *7) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-72 DOT)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-73 IMAGE)))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-747)))) ((*1 *2 *3 *3 *4 *3 *3 *3 *3 *3 *3 *3 *5 *3 *6 *7 *8) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-72 DOT)))) (-5 *7 (-3 (|:| |fn| (-390)) (|:| |fp| (-73 IMAGE)))) (-5 *8 (-390)) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-247 *3)) (-4 *3 (-1195)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-296)) (-5 *2 (-763)))) ((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))) (-5 *1 (-444 *4 *3 *2)) (-4 *3 (-1219 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-607 *3)) (-4 *3 (-842)))) ((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) ((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-850))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-634 (-256))) (-5 *4 (-1161)) (-5 *1 (-255 *2)) (-4 *2 (-1195)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-634 (-256))) (-5 *4 (-1161)) (-5 *2 (-57)) (-5 *1 (-256)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-634 (-465))) (-5 *4 (-1161)) (-5 *2 (-57)) (-5 *1 (-465))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1244 (-310 (-215)))) (-5 *2 (-2 (|:| |additions| (-568)) (|:| |multiplications| (-568)) (|:| |exponentiations| (-568)) (|:| |functionCalls| (-568)))) (-5 *1 (-299))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-634 (-634 (-568)))) (-5 *1 (-972)) (-5 *3 (-634 (-568)))))) 
 (((*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3))))) 
-(((*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-1143)) (-5 *4 (-169 (-215))) (-5 *5 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
+(((*1 *2 *3 *3 *3 *3 *3 *4 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-121)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *3 (-1 (-634 *2) *2 *2 *2)) (-4 *2 (-1090)) (-5 *1 (-106 *2)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1090)) (-5 *1 (-106 *2))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-5 *4 (-763)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-634 (-2 (|:| |det| *8) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (-5 *1 (-924 *5 *6 *7 *8))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1047)) (-4 *6 (-230 *7 (-763))) (-14 *7 (-763)) (-5 *2 (-634 *6)) (-5 *1 (-908 *4 *5 *6 *7)) (-4 *5 (-324 *4 *6))))) 
+(((*1 *2 *3 *3 *3 *3 *3 *4 *3 *4 *3 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-121)) (-5 *5 (-679 (-169 (-215)))) (-5 *2 (-1035)) (-5 *1 (-747))))) 
+(((*1 *2 *1) (-12 (-4 *2 (-13 (-840) (-365))) (-5 *1 (-1057 *2 *3)) (-4 *3 (-1219 *2))))) 
+(((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 *4))) (-5 *3 (-1157 *4)) (-4 *4 (-904)) (-5 *1 (-655 *4))))) 
 (((*1 *2 *3) (-12 (-5 *2 (-381)) (-5 *1 (-780 *3)) (-4 *3 (-609 *2)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-5 *2 (-381)) (-5 *1 (-780 *3)) (-4 *3 (-609 *2)))) ((*1 *2 *3) (-12 (-5 *3 (-953 *4)) (-4 *4 (-1047)) (-4 *4 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-953 *5)) (-5 *4 (-917)) (-4 *5 (-1047)) (-4 *5 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-558)) (-4 *4 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-310 *4)) (-4 *4 (-558)) (-4 *4 (-842)) (-4 *4 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-310 *5)) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-842)) (-4 *5 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *5))))) 
+(((*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-1143)) (-5 *4 (-169 (-215))) (-5 *5 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
+(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
 (((*1 *1 *2) (-12 (-5 *2 (-1108)) (-5 *1 (-816))))) 
-(((*1 *2 *3 *4 *5 *3 *6 *3) (-12 (-5 *3 (-568)) (-5 *5 (-169 (-215))) (-5 *6 (-1143)) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
+(((*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-1143)) (-5 *4 (-169 (-215))) (-5 *5 (-568)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *2 (-950 *3 *5 (-852 *4))) (-4 *5 (-230 (-1699 *4) (-763))) (-4 *6 (-971 *3)) (-4 *7 (-641 *3)) (-4 *8 (-920 *3 *7)) (-4 *9 (-235 *8)) (-4 *10 (-536 *3 *4 *2 *5 *6 *7 *8 *9 *12)) (-4 *12 (-117)) (-5 *1 (-467 *3 *4 *2 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) ((*1 *2 *2) (-12 (-5 *2 (-242 *4 *3)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-5 *1 (-867 *3 *4 *5)) (-4 *5 (-117)))) ((*1 *2 *2) (-12 (-5 *2 (-242 *4 *3)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-5 *1 (-868 *3 *4 *5)) (-4 *5 (-117))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-1165))))) 
+(((*1 *2 *3 *4 *5 *3 *6 *3) (-12 (-5 *3 (-568)) (-5 *5 (-169 (-215))) (-5 *6 (-1143)) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-750))))) 
+(((*1 *2 *2 *1 *3 *4) (-12 (-5 *2 (-634 *8)) (-5 *3 (-1 *8 *8 *8)) (-5 *4 (-1 (-121) *8 *8)) (-4 *1 (-1189 *5 *6 *7 *8)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-453)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6))))) 
 (((*1 *2 *3 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-970 *5 *3)) (-4 *3 (-1219 *5))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-641 *3)) (-4 *3 (-365))))) 
+(((*1 *2 *3 *3 *3 *4 *5) (-12 (-5 *5 (-634 (-634 (-215)))) (-5 *4 (-215)) (-5 *2 (-634 (-944 *4))) (-5 *1 (-1192)) (-5 *3 (-944 *4))))) 
 (((*1 *1 *1 *2) (-12 (-4 *1 (-1012)) (-5 *2 (-850))))) 
-(((*1 *1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *2) (|:| |xpnt| (-568))))) (-4 *2 (-558)) (-5 *1 (-420 *2)))) ((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |contp| (-568)) (|:| -3276 (-634 (-2 (|:| |irr| *4) (|:| -3959 (-568))))))) (-4 *4 (-1219 (-568))) (-5 *2 (-420 *4)) (-5 *1 (-443 *4))))) 
+(((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-749))))) 
+(((*1 *2 *3) (-12 (|has| *6 (-6 -4522)) (-4 *4 (-365)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-634 *6)) (-5 *1 (-529 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) ((*1 *2 *3) (-12 (|has| *9 (-6 -4522)) (-4 *4 (-558)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-4 *7 (-993 *4)) (-4 *8 (-375 *7)) (-4 *9 (-375 *7)) (-5 *2 (-634 *6)) (-5 *1 (-530 *4 *5 *6 *3 *7 *8 *9 *10)) (-4 *3 (-677 *4 *5 *6)) (-4 *10 (-677 *7 *8 *9)))) ((*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-4 *3 (-558)) (-5 *2 (-634 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *4 (-172)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-634 *6)) (-5 *1 (-678 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-4 *5 (-558)) (-5 *2 (-634 *7))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181)))))) 
+(((*1 *1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *2) (|:| |xpnt| (-568))))) (-4 *2 (-558)) (-5 *1 (-420 *2)))) ((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |contp| (-568)) (|:| -2075 (-634 (-2 (|:| |irr| *4) (|:| -4402 (-568))))))) (-4 *4 (-1219 (-568))) (-5 *2 (-420 *4)) (-5 *1 (-443 *4))))) 
+(((*1 *2 *3 *4 *4 *5 *4 *6 *4 *5) (-12 (-5 *3 (-1143)) (-5 *5 (-679 (-215))) (-5 *6 (-679 (-568))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-749))))) 
+(((*1 *2 *2 *3 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-1108)) (-4 *4 (-350)) (-5 *1 (-532 *4))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-558))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 (-1141 *4) (-1141 *4))) (-5 *2 (-1141 *4)) (-5 *1 (-1267 *4)) (-4 *4 (-1195)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-634 (-1141 *5)) (-634 (-1141 *5)))) (-5 *4 (-568)) (-5 *2 (-634 (-1141 *5))) (-5 *1 (-1267 *5)) (-4 *5 (-1195))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-634 (-944 (-215)))) (-5 *1 (-1245))))) 
+(((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-749))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-1249))))) 
 (((*1 *2 *1) (-12 (-4 *4 (-1090)) (-5 *2 (-884 *3 *4)) (-5 *1 (-880 *3 *4 *5)) (-4 *3 (-1090)) (-4 *5 (-658 *4))))) 
-(((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-749))))) 
+(((*1 *2 *3 *4 *4 *5 *4 *4 *5) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-749))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-301)) (-5 *2 (-409 (-420 (-953 *4)))) (-5 *1 (-1041 *4))))) 
+(((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-1 (-215) (-215) (-215) (-215))) (-5 *2 (-1 (-944 (-215)) (-215) (-215))) (-5 *1 (-686))))) 
 (((*1 *1 *2 *3) (-12 (-5 *2 (-1157 *1)) (-5 *3 (-1161)) (-4 *1 (-27)))) ((*1 *1 *2) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-27)))) ((*1 *1 *2) (-12 (-5 *2 (-953 *1)) (-4 *1 (-27)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1161)) (-4 *1 (-29 *3)) (-4 *3 (-13 (-842) (-558))))) ((*1 *1 *1) (-12 (-4 *1 (-29 *2)) (-4 *2 (-13 (-842) (-558))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1157 *2)) (-5 *4 (-1161)) (-4 *2 (-432 *5)) (-5 *1 (-36 *5 *2)) (-4 *5 (-13 (-842) (-558))))) ((*1 *1 *2 *3) (|partial| -12 (-5 *2 (-1157 *1)) (-5 *3 (-917)) (-4 *1 (-1012)))) ((*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-1157 *1)) (-5 *3 (-917)) (-5 *4 (-850)) (-4 *1 (-1012)))) ((*1 *1 *2 *3) (|partial| -12 (-5 *3 (-917)) (-4 *4 (-13 (-840) (-365))) (-4 *1 (-1063 *4 *2)) (-4 *2 (-1219 *4))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-147)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-147))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-409 (-568))) (-5 *1 (-435 *4 *3)) (-4 *3 (-432 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-607 *3)) (-4 *3 (-432 *5)) (-4 *5 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-1157 (-409 (-568)))) (-5 *1 (-435 *5 *3))))) 
+(((*1 *2 *3 *1) (-12 (-4 *1 (-601 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1195)) (-5 *2 (-121))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-301)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-1112 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5))))) 
-(((*1 *2 *3 *1) (-12 (-5 *2 (-2 (|:| |cycle?| (-121)) (|:| -3390 (-763)) (|:| |period| (-763)))) (-5 *1 (-1141 *4)) (-4 *4 (-1195)) (-5 *3 (-763))))) 
-(((*1 *2 *3 *4 *4 *5 *4 *6 *4 *5) (-12 (-5 *3 (-1143)) (-5 *5 (-679 (-215))) (-5 *6 (-679 (-568))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-749))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-840)) (-5 *1 (-297 *3))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-869)) (-5 *3 (-634 (-256))) (-5 *1 (-254))))) 
+(((*1 *2 *3 *1) (-12 (-5 *2 (-2 (|:| |cycle?| (-121)) (|:| -3392 (-763)) (|:| |period| (-763)))) (-5 *1 (-1141 *4)) (-4 *4 (-1195)) (-5 *3 (-763))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1108)) (-5 *1 (-328))))) 
+(((*1 *1 *1 *1 *2) (-12 (-4 *1 (-950 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *3 (-172)))) ((*1 *2 *3 *3) (-12 (-4 *2 (-558)) (-5 *1 (-970 *2 *3)) (-4 *3 (-1219 *2)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-172))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-1170 *2)) (-4 *2 (-365))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-215))) (-5 *4 (-763)) (-5 *2 (-679 (-215))) (-5 *1 (-299))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-57))) (-5 *2 (-1249)) (-5 *1 (-851))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-325 *3)) (-4 *3 (-1195)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-525 *3 *4)) (-4 *3 (-1195)) (-14 *4 (-568))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 (-1141 *4) (-1141 *4))) (-5 *2 (-1141 *4)) (-5 *1 (-1267 *4)) (-4 *4 (-1195)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-634 (-1141 *5)) (-634 (-1141 *5)))) (-5 *4 (-568)) (-5 *2 (-634 (-1141 *5))) (-5 *1 (-1267 *5)) (-4 *5 (-1195))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-817)) (-5 *2 (-57)) (-5 *1 (-824))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-256))))) 
 (((*1 *1 *1) (|partial| -12 (-5 *1 (-155 *2 *3 *4)) (-14 *2 (-917)) (-4 *3 (-365)) (-14 *4 (-994 *2 *3)))) ((*1 *1 *1) (|partial| -12 (-4 *2 (-172)) (-5 *1 (-284 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1219 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) ((*1 *1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-172)) (-4 *2 (-558)))) ((*1 *1 *1) (|partial| -12 (-5 *1 (-705 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) ((*1 *1) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) ((*1 *1 *1) (|partial| -4 *1 (-712))) ((*1 *1 *1) (|partial| -4 *1 (-716))) ((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *3))) (-5 *1 (-768 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) ((*1 *2 *2 *1) (|partial| -12 (-4 *1 (-1063 *3 *2)) (-4 *3 (-13 (-840) (-365))) (-4 *2 (-1219 *3)))) ((*1 *2 *2) (|partial| -12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3))))) 
-(((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-749))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-568)) (-5 *1 (-1178 *4)) (-4 *4 (-1047))))) 
+(((*1 *2 *3 *4 *3 *3 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-169 (-215)))) (-5 *2 (-1035)) (-5 *1 (-748))))) 
+(((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-554))))) 
 (((*1 *2 *3 *4 *5) (-12 (-5 *3 (-953 (-409 (-568)))) (-5 *4 (-1161)) (-5 *5 (-1084 (-835 (-215)))) (-5 *2 (-634 (-215))) (-5 *1 (-294))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-1157 (-953 *4)) (-953 *4))) (-5 *1 (-1252 *4)) (-4 *4 (-365))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-917)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-256))))) 
 (((*1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-1090)) (-4 *1 (-898 *3))))) 
-(((*1 *2 *3 *4 *4 *5 *4 *4 *5) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-749))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-763)) (-5 *1 (-450 *4 *5 *6 *3)) (-4 *3 (-950 *4 *5 *6))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1 (-121) *8))) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-2 (|:| |goodPols| (-634 *8)) (|:| |badPols| (-634 *8)))) (-5 *1 (-978 *5 *6 *7 *8)) (-5 *4 (-634 *8))))) 
 (((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-634 (-777 *3))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047))))) 
+(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *2)) (-4 *2 (-172)))) ((*1 *2) (-12 (-4 *2 (-172)) (-5 *1 (-418 *3 *2)) (-4 *3 (-419 *2)))) ((*1 *2) (-12 (-4 *1 (-419 *2)) (-4 *2 (-172))))) 
 (((*1 *2 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) ((*1 *2 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-1109 *2)) (-4 *2 (-1195)))) ((*1 *2 *2 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *2 *3) (-12 (-4 *4 (-788)) (-4 *3 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $))))) (-4 *5 (-558)) (-5 *1 (-722 *4 *3 *5 *2)) (-4 *2 (-950 (-409 (-953 *5)) *4 *3)))) ((*1 *2 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $)) (-15 -1305 ((-3 $ "failed") (-1161)))))) (-5 *1 (-985 *4 *5 *3 *2)) (-4 *2 (-950 (-953 *4) *5 *3)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $)) (-15 -1305 ((-3 $ "failed") (-1161)))))) (-4 *4 (-1047)) (-4 *5 (-788)) (-5 *1 (-985 *4 *5 *6 *2)) (-4 *2 (-950 (-953 *4) *5 *6))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-147)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-147))))) 
+(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-372 *4 *5)) (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-679 *4)))) ((*1 *2) (-12 (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-679 *4)) (-5 *1 (-410 *3 *4 *5)) (-4 *3 (-411 *4 *5)))) ((*1 *2) (-12 (-4 *1 (-411 *3 *4)) (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-679 *3))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-50 (-1143) (-766))) (-5 *1 (-123))))) 
+(((*1 *2 *2 *3) (-12 (-4 *4 (-788)) (-4 *3 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $))))) (-4 *5 (-558)) (-5 *1 (-722 *4 *3 *5 *2)) (-4 *2 (-950 (-409 (-953 *5)) *4 *3)))) ((*1 *2 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $)) (-15 -3325 ((-3 $ "failed") (-1161)))))) (-5 *1 (-985 *4 *5 *3 *2)) (-4 *2 (-950 (-953 *4) *5 *3)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $)) (-15 -3325 ((-3 $ "failed") (-1161)))))) (-4 *4 (-1047)) (-4 *5 (-788)) (-5 *1 (-985 *4 *5 *6 *2)) (-4 *2 (-950 (-953 *4) *5 *6))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *1 *1) (-5 *1 (-1059)))) 
 (((*1 *2 *1) (-12 (-5 *1 (-1026 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-568)) (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *8 (-230 (-1699 *7) (-763))) (-4 *9 (-641 *6)) (-5 *2 (-634 *9)) (-5 *1 (-654 *6 *7 *4 *8 *3 *9 *10)) (-4 *4 (-950 *6 *8 (-852 *7))) (-4 *3 (-971 *6)) (-4 *10 (-920 *6 *9))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568))))) 
 (((*1 *2 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-729 *3))))) 
+(((*1 *1 *1 *1) (-5 *1 (-121)))) 
+(((*1 *2 *3 *4 *3 *3) (-12 (-5 *3 (-288 *6)) (-5 *4 (-123)) (-4 *6 (-432 *5)) (-4 *5 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *5 *6)))) ((*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-288 *7)) (-5 *4 (-123)) (-5 *5 (-634 *7)) (-4 *7 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *7)))) ((*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-634 (-288 *7))) (-5 *4 (-634 (-123))) (-5 *5 (-288 *7)) (-4 *7 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *7)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-634 (-288 *8))) (-5 *4 (-634 (-123))) (-5 *5 (-288 *8)) (-5 *6 (-634 *8)) (-4 *8 (-432 *7)) (-4 *7 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *7 *8)))) ((*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-634 *7)) (-5 *4 (-634 (-123))) (-5 *5 (-288 *7)) (-4 *7 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *7)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 (-123))) (-5 *6 (-634 (-288 *8))) (-4 *8 (-432 *7)) (-5 *5 (-288 *8)) (-4 *7 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *7 *8)))) ((*1 *2 *3 *4 *3 *5) (-12 (-5 *3 (-288 *5)) (-5 *4 (-123)) (-4 *5 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *5)))) ((*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-123)) (-5 *5 (-288 *3)) (-4 *3 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *3)))) ((*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-123)) (-5 *5 (-288 *3)) (-4 *3 (-432 *6)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *6 *3)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-123)) (-5 *5 (-288 *3)) (-5 *6 (-634 *3)) (-4 *3 (-432 *7)) (-4 *7 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-57)) (-5 *1 (-311 *7 *3)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-123)) (-5 *5 (-1161)) (-5 *6 (-634 *3)) (-4 *3 (-432 *7)) (-4 *7 (-13 (-842) (-558) (-609 (-541)))) (-4 *2 (-1234 *3)) (-5 *1 (-312 *7 *3 *2 *8)) (-4 *8 (-1234 (-1155 *3))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *6)) (-5 *4 (-634 *5)) (-4 *5 (-365)) (-4 *6 (-1234 (-1155 *5))) (-4 *2 (-1234 *5)) (-5 *1 (-1238 *5 *2 *6))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 (-147))) (-5 *1 (-142)))) ((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-142))))) 
 (((*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-305)) (-5 *1 (-824))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-634 *8)) (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-953 (-568))) (-5 *2 (-328)) (-5 *1 (-330))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-607 *4)) (-4 *4 (-842)) (-4 *2 (-842)) (-5 *1 (-606 *2 *4))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1141 (-568))) (-5 *1 (-1145 *4)) (-4 *4 (-1047)) (-5 *3 (-568))))) 
 (((*1 *2 *3) (|partial| -12 (-5 *3 (-679 (-409 (-953 (-568))))) (-5 *2 (-679 (-310 (-568)))) (-5 *1 (-1031))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *3 (-235 *10)) (-4 *11 (-536 *4 *5 *6 *7 *8 *9 *10 *3 *13)) (-4 *13 (-117)) (-5 *2 (-2 (|:| |num| (-634 *6)) (|:| |den| *6))) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *3 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-236 (-922 *5))) (-5 *4 (-763)) (-4 *5 (-350)) (-5 *2 (-634 (-409 (-242 *6 *5)))) (-5 *1 (-867 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-236 (-922 *4))) (-4 *4 (-350)) (-5 *2 (-2 (|:| |num| (-634 (-242 *5 *4))) (|:| |den| (-242 *5 *4)))) (-5 *1 (-867 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-236 (-921 *5))) (-5 *4 (-763)) (-4 *5 (-365)) (-5 *2 (-634 (-409 (-242 *6 *5)))) (-5 *1 (-868 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-236 (-921 *4))) (-4 *4 (-365)) (-5 *2 (-2 (|:| |num| (-634 (-242 *5 *4))) (|:| |den| (-242 *5 *4)))) (-5 *1 (-868 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-50 (-1143) (-766))) (-5 *1 (-123))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-536 *2 *3 *4 *5 *6 *7 *8 *9 *10)) (-4 *4 (-950 *2 *5 (-852 *3))) (-4 *5 (-230 (-1699 *3) (-763))) (-4 *6 (-971 *2)) (-4 *7 (-641 *2)) (-4 *8 (-920 *2 *7)) (-4 *9 (-235 *8)) (-4 *10 (-117)) (-4 *2 (-365))))) 
+(((*1 *2 *3 *4) (-12 (-4 *7 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-558)) (-4 *8 (-950 *7 *5 *6)) (-5 *2 (-2 (|:| -3483 (-763)) (|:| -2350 *3) (|:| |radicand| *3))) (-5 *1 (-954 *5 *6 *7 *8 *3)) (-5 *4 (-763)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2319 (*8 $)) (-15 -2326 (*8 $)) (-15 -2747 ($ *8)))))))) 
 (((*1 *2 *1) (-12 (-4 *2 (-1090)) (-5 *1 (-965 *3 *2)) (-4 *3 (-1090))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-259 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-513 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-537 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2 *1) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-5 *2 (-850)) (-5 *1 (-538 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *7 (-971 *3)) (-4 *10 (-235 *9)) (-4 *11 (-117))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-555 *3)) (-4 *3 (-13 (-406) (-1181))) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-840)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1063 *4 *3)) (-4 *4 (-13 (-840) (-365))) (-4 *3 (-1219 *4)) (-5 *2 (-121))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-57)) (-5 *1 (-56 *2)) (-4 *2 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-953 (-381))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (-12 (-5 *2 (-409 (-953 (-381)))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-381))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (-12 (-5 *2 (-953 (-568))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (-12 (-5 *2 (-409 (-953 (-568)))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-568))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 *2)) (-14 *4 (-634 *2)) (-4 *5 (-389)))) ((*1 *1 *2) (-12 (-5 *2 (-310 *5)) (-4 *5 (-389)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))))) ((*1 *1 *2) (-12 (-5 *2 (-679 (-409 (-953 (-568))))) (-4 *1 (-386)))) ((*1 *1 *2) (-12 (-5 *2 (-679 (-409 (-953 (-381))))) (-4 *1 (-386)))) ((*1 *1 *2) (-12 (-5 *2 (-679 (-953 (-568)))) (-4 *1 (-386)))) ((*1 *1 *2) (-12 (-5 *2 (-679 (-953 (-381)))) (-4 *1 (-386)))) ((*1 *1 *2) (-12 (-5 *2 (-679 (-310 (-568)))) (-4 *1 (-386)))) ((*1 *1 *2) (-12 (-5 *2 (-679 (-310 (-381)))) (-4 *1 (-386)))) ((*1 *1 *2) (-12 (-5 *2 (-409 (-953 (-568)))) (-4 *1 (-398)))) ((*1 *1 *2) (-12 (-5 *2 (-409 (-953 (-381)))) (-4 *1 (-398)))) ((*1 *1 *2) (-12 (-5 *2 (-953 (-568))) (-4 *1 (-398)))) ((*1 *1 *2) (-12 (-5 *2 (-953 (-381))) (-4 *1 (-398)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-568))) (-4 *1 (-398)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-381))) (-4 *1 (-398)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-409 (-953 (-568))))) (-4 *1 (-442)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-409 (-953 (-381))))) (-4 *1 (-442)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-953 (-568)))) (-4 *1 (-442)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-953 (-381)))) (-4 *1 (-442)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-310 (-568)))) (-4 *1 (-442)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-310 (-381)))) (-4 *1 (-442)))) ((*1 *2 *1) (-12 (-5 *2 (-409 (-734 *3 *4))) (-5 *1 (-733 *3 *4)) (-14 *3 (-1161)) (-4 *4 (-13 (-1047) (-842) (-558))))) ((*1 *2 *1) (-12 (-5 *2 (-3 (|:| |nia| (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| |mdnia| (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))))) (-5 *1 (-761)))) ((*1 *1 *2) (-12 (-5 *2 (-1201 *3)) (-4 *3 (-350)) (-5 *1 (-770 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *1 (-803)))) ((*1 *2 *1) (-12 (-5 *2 (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))))) (-5 *1 (-833)))) ((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) (-5 *1 (-893)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *1 (-977 *3 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-1037 *2)) (-4 *2 (-1195)))) ((*1 *1 *2) (-2199 (-12 (-5 *2 (-953 *3)) (-12 (-3046 (-4 *3 (-43 (-409 (-568))))) (-3046 (-4 *3 (-43 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 *3)) (-12 (-3046 (-4 *3 (-550))) (-3046 (-4 *3 (-43 (-409 (-568))))) (-4 *3 (-43 (-568))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 *3)) (-12 (-3046 (-4 *3 (-993 (-568)))) (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))))) ((*1 *1 *2) (-2199 (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-3046 (-4 *3 (-43 (-409 (-568))))) (-4 *3 (-43 (-568))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))))) ((*1 *1 *2) (-12 (-5 *2 (-953 (-409 (-568)))) (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))))) 
 (((*1 *2 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-365)) (-5 *1 (-653 *3))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1108)) (-5 *1 (-328))))) 
+(((*1 *2 *2 *1) (|partial| -12 (-5 *2 (-634 *1)) (-4 *1 (-301))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-638 *3 *4 *5)) (-4 *3 (-1090)) (-4 *4 (-23)) (-14 *5 *4)))) 
+(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-634 (-409 (-953 *6)))) (-5 *3 (-409 (-953 *6))) (-4 *6 (-13 (-558) (-1037 (-568)) (-150))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-574 *6))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-849)))) ((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-990)))) ((*1 *2 *1) (-12 (-4 *1 (-1010 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-4 *2 (-13 (-1090) (-39))) (-5 *1 (-1125 *2 *3)) (-4 *3 (-13 (-1090) (-39)))))) 
 (((*1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-751))))) 
+(((*1 *2 *3 *4 *5 *6 *2 *7 *8) (|partial| -12 (-5 *2 (-634 (-1157 *11))) (-5 *3 (-1157 *11)) (-5 *4 (-634 *10)) (-5 *5 (-634 *8)) (-5 *6 (-634 (-763))) (-5 *7 (-1244 (-634 (-1157 *8)))) (-4 *10 (-842)) (-4 *8 (-301)) (-4 *11 (-950 *8 *9 *10)) (-4 *9 (-788)) (-5 *1 (-697 *9 *10 *8 *11))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -3440 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-3 (|:| |nullBranch| "null") (|:| |assignmentBranch| (-2 (|:| |var| (-1161)) (|:| |arrayIndex| (-634 (-953 (-568)))) (|:| |rand| (-2 (|:| |ints2Floats?| (-121)) (|:| -4153 (-850)))))) (|:| |arrayAssignmentBranch| (-2 (|:| |var| (-1161)) (|:| |rand| (-850)) (|:| |ints2Floats?| (-121)))) (|:| |conditionalBranch| (-2 (|:| |switch| (-1160)) (|:| |thenClause| (-328)) (|:| |elseClause| (-328)))) (|:| |returnBranch| (-2 (|:| -2436 (-121)) (|:| -2852 (-2 (|:| |ints2Floats?| (-121)) (|:| -4153 (-850)))))) (|:| |blockBranch| (-634 (-328))) (|:| |commentBranch| (-634 (-1143))) (|:| |callBranch| (-1143)) (|:| |forBranch| (-2 (|:| -3581 (-1082 (-953 (-568)))) (|:| |span| (-953 (-568))) (|:| |body| (-328)))) (|:| |labelBranch| (-1108)) (|:| |loopBranch| (-2 (|:| |switch| (-1160)) (|:| |body| (-328)))) (|:| |commonBranch| (-2 (|:| -3393 (-1161)) (|:| |contents| (-634 (-1161))))) (|:| |printBranch| (-634 (-850))))) (-5 *1 (-328))))) 
 (((*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-320 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-137))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-950 *4 *5 *6)) (-4 *6 (-609 (-1161))) (-4 *4 (-365)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1150 (-634 (-953 *4)) (-634 (-288 (-953 *4))))) (-5 *1 (-514 *4 *5 *6 *7))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-835 (-215)))) (-5 *4 (-215)) (-5 *2 (-634 *4)) (-5 *1 (-263))))) 
 (((*1 *1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-917)) (-4 *5 (-842)) (-5 *2 (-634 (-663 *5))) (-5 *1 (-663 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
 (((*1 *2 *3) (-12 (-4 *1 (-904)) (-5 *2 (-420 (-1157 *1))) (-5 *3 (-1157 *1))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-155 *3 *4 *5)) (-14 *3 *2) (-4 *4 (-365)) (-14 *5 (-994 *3 *4))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-917)) (-5 *2 (-121)) (-5 *1 (-233 *4)) (-4 *4 (-1047))))) 
+(((*1 *2) (-12 (-5 *2 (-1244 (-1091 *3 *4))) (-5 *1 (-1091 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917))))) 
 (((*1 *2 *3 *2) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *3 (-634 (-568))) (-5 *1 (-878))))) 
+(((*1 *1 *1 *2) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
+(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1 (-121) *9)) (-5 *5 (-1 (-121) *9 *9)) (-4 *9 (-1061 *6 *7 *8)) (-4 *6 (-558)) (-4 *7 (-788)) (-4 *8 (-842)) (-5 *2 (-2 (|:| |bas| *1) (|:| -2618 (-634 *9)))) (-5 *3 (-634 *9)) (-4 *1 (-1189 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1 (-121) *8 *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-2 (|:| |bas| *1) (|:| -2618 (-634 *8)))) (-5 *3 (-634 *8)) (-4 *1 (-1189 *5 *6 *7 *8))))) 
 (((*1 *2 *3 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-679 (-568))) (-5 *1 (-1100))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-634 (-381))) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-634 (-381))) (-5 *1 (-473)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-381))) (-5 *1 (-473)))) ((*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-869)) (-5 *2 (-1249)) (-5 *1 (-1245)))) ((*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-57))) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *3 *4 *4 *5 *6 *7) (-12 (-5 *5 (-1161)) (-5 *6 (-1 (-3 (-2 (|:| |mainpart| *4) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *4) (|:| |logand| *4))))) "failed") *4 (-634 *4))) (-5 *7 (-1 (-3 (-2 (|:| -4151 *4) (|:| |coeff| *4)) "failed") *4 *4)) (-4 *4 (-13 (-1181) (-27) (-432 *8))) (-4 *8 (-13 (-453) (-842) (-150) (-1037 *3) (-630 *3))) (-5 *3 (-568)) (-5 *2 (-2 (|:| |ans| *4) (|:| -3286 *4) (|:| |sol?| (-121)))) (-5 *1 (-1013 *8 *4))))) 
 (((*1 *1 *1) (-4 *1 (-620))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 *7)) (-4 *7 (-842)) (-4 *8 (-950 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-5 *2 (-2 (|:| |particular| (-3 (-1244 (-409 *8)) "failed")) (|:| -3746 (-634 (-1244 (-409 *8)))))) (-5 *1 (-661 *5 *6 *7 *8))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-310 *3)) (-4 *3 (-13 (-1047) (-842))) (-5 *1 (-213 *3 *4)) (-14 *4 (-634 (-1161)))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-1210 (-568))) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-640 *3)) (-4 *3 (-1195))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 *7)) (-4 *7 (-842)) (-4 *8 (-950 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-5 *2 (-2 (|:| |particular| (-3 (-1244 (-409 *8)) "failed")) (|:| -2588 (-634 (-1244 (-409 *8)))))) (-5 *1 (-661 *5 *6 *7 *8))))) 
+(((*1 *2 *3 *4 *5 *5 *2) (|partial| -12 (-5 *2 (-121)) (-5 *3 (-953 *6)) (-5 *4 (-1161)) (-5 *5 (-835 *7)) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-4 *7 (-13 (-1181) (-29 *6))) (-5 *1 (-214 *6 *7)))) ((*1 *2 *3 *4 *4 *2) (|partial| -12 (-5 *2 (-121)) (-5 *3 (-1157 *6)) (-5 *4 (-835 *6)) (-4 *6 (-13 (-1181) (-29 *5))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-214 *5 *6))))) 
+(((*1 *2 *1 *3) (|partial| -12 (-5 *3 (-1143)) (-5 *2 (-766)) (-5 *1 (-123))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2852 *4) (|:| -2185 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568))))) 
+(((*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-634 *10)) (-5 *5 (-121)) (-4 *10 (-1066 *6 *7 *8 *9)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *9 (-1061 *6 *7 *8)) (-5 *2 (-634 (-2 (|:| -2410 (-634 *9)) (|:| -3145 *10) (|:| |ineq| (-634 *9))))) (-5 *1 (-989 *6 *7 *8 *9 *10)) (-5 *3 (-634 *9)))) ((*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-634 *10)) (-5 *5 (-121)) (-4 *10 (-1066 *6 *7 *8 *9)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *9 (-1061 *6 *7 *8)) (-5 *2 (-634 (-2 (|:| -2410 (-634 *9)) (|:| -3145 *10) (|:| |ineq| (-634 *9))))) (-5 *1 (-1097 *6 *7 *8 *9 *10)) (-5 *3 (-634 *9))))) 
 (((*1 *2 *3) (|partial| -12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-781))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1177))))) 
+(((*1 *2 *3 *4) (-12 (-5 *2 (-2 (|:| |part1| *3) (|:| |part2| *4))) (-5 *1 (-695 *3 *4)) (-4 *3 (-1195)) (-4 *4 (-1195))))) 
 (((*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-1109 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-665 *3)) (-4 *3 (-1195)) (-5 *2 (-121))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *1 (-950 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-788)) (-4 *5 (-1047)) (-4 *6 (-950 *5 *4 *2)) (-4 *2 (-842)) (-5 *1 (-951 *4 *2 *5 *6 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2747 ($ *6)) (-15 -2319 (*6 $)) (-15 -2326 (*6 $))))))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-558)) (-5 *2 (-1161)) (-5 *1 (-1042 *4))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39)))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-710)) (-5 *2 (-917)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-712)) (-5 *2 (-763))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *3 (-453)) (-4 *4 (-842)) (-4 *5 (-788)) (-5 *2 (-121)) (-5 *1 (-988 *3 *4 *5 *6)) (-4 *6 (-950 *3 *5 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39)))))) 
 (((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-763)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4))))) 
+(((*1 *1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-172)) (-4 *2 (-558)))) ((*1 *1 *1) (|partial| -4 *1 (-712)))) 
 (((*1 *1 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)) (-4 *2 (-1056)))) ((*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)) (-4 *2 (-1056)))) ((*1 *1 *1) (-4 *1 (-840))) ((*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172)) (-4 *2 (-1056)))) ((*1 *1 *1) (-4 *1 (-1056))) ((*1 *1 *1) (-4 *1 (-1124)))) 
-(((*1 *2 *3 *4 *3 *3 *3 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-169 (-215)))) (-5 *2 (-1035)) (-5 *1 (-748))))) 
+(((*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *3 (-679 *11)) (-5 *4 (-634 (-409 (-953 *8)))) (-5 *5 (-763)) (-5 *6 (-1143)) (-4 *8 (-13 (-301) (-150))) (-4 *11 (-950 *8 *10 *9)) (-4 *9 (-13 (-842) (-609 (-1161)))) (-4 *10 (-788)) (-5 *2 (-2 (|:| |rgl| (-634 (-2 (|:| |eqzro| (-634 *11)) (|:| |neqzro| (-634 *11)) (|:| |wcond| (-634 (-953 *8))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *8)))) (|:| -2588 (-634 (-1244 (-409 (-953 *8)))))))))) (|:| |rgsz| (-568)))) (-5 *1 (-924 *8 *9 *10 *11)) (-5 *7 (-568))))) 
 (((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-763)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7))))) 
+(((*1 *2 *3 *1) (-12 (-4 *1 (-605 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-5 *2 (-121))))) 
 (((*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1244 (-634 *3))) (-4 *4 (-301)) (-5 *2 (-634 *3)) (-5 *1 (-457 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-634 *3)) (-5 *1 (-590 *5 *6 *7 *8 *3)) (-4 *3 (-1099 *5 *6 *7 *8)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-5 *2 (-634 (-2 (|:| -3722 (-1157 *5)) (|:| -1656 (-634 (-953 *5)))))) (-5 *1 (-1071 *5 *6)) (-5 *3 (-634 (-953 *5))) (-14 *6 (-634 (-1161))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-5 *2 (-634 (-2 (|:| -3722 (-1157 *4)) (|:| -1656 (-634 (-953 *4)))))) (-5 *1 (-1071 *4 *5)) (-5 *3 (-634 (-953 *4))) (-14 *5 (-634 (-1161))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-5 *2 (-634 (-2 (|:| -3722 (-1157 *5)) (|:| -1656 (-634 (-953 *5)))))) (-5 *1 (-1071 *5 *6)) (-5 *3 (-634 (-953 *5))) (-14 *6 (-634 (-1161)))))) 
+(((*1 *2 *3 *1) (|partial| -12 (-4 *1 (-41 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-5 *2 (-2 (|:| -3651 *3) (|:| -4085 *4)))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4521)) (-4 *1 (-154 *3)) (-4 *3 (-1195)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1195)) (-5 *1 (-598 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-665 *3)) (-4 *3 (-1195)))) ((*1 *2 *1 *3) (|partial| -12 (-4 *1 (-1189 *4 *5 *3 *2)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *3 (-842)) (-4 *2 (-1061 *4 *5 *3)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *1 (-1193 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2350 *3) (|:| |gap| (-763)) (|:| -4409 (-777 *3)) (|:| -2607 (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-1047)))) ((*1 *2 *1 *1 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-2 (|:| -2350 *1) (|:| |gap| (-763)) (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-1061 *4 *5 *3)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -2350 *1) (|:| |gap| (-763)) (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-1061 *3 *4 *5))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-568)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-568))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-568))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-428 *4 *2)) (-4 *2 (-13 (-1181) (-29 *4))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-150)) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *2 (-310 *5)) (-5 *1 (-588 *5))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-369 *2)) (-4 *2 (-172))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1141 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-36 *4 *5)) (-4 *5 (-432 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-159 *4 *5)) (-4 *5 (-432 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-272 *4 *5)) (-4 *5 (-13 (-432 *4) (-1002))))) ((*1 *2 *3) (-12 (-5 *3 (-123)) (-5 *2 (-121)) (-5 *1 (-295 *4)) (-4 *4 (-296)))) ((*1 *2 *3) (-12 (-4 *1 (-296)) (-5 *3 (-123)) (-5 *2 (-121)))) ((*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-431 *4 *5)) (-4 *4 (-432 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-433 *4 *5)) (-4 *5 (-432 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-621 *4 *5)) (-4 *5 (-13 (-432 *4) (-1002) (-1181)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-333 *3 *4 *5 *6)) (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 *3 *4 *5)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-816))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-121)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-465))))) 
-(((*1 *1) (-12 (-4 *1 (-327 *2)) (-4 *2 (-370)) (-4 *2 (-365)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1244 *4)) (-5 *1 (-532 *4)) (-4 *4 (-350))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-320 *2 *4)) (-4 *4 (-137)) (-4 *2 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-363 *2)) (-4 *2 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-388 *2)) (-4 *2 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-420 *2)) (-4 *2 (-558)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *2 (-1090)) (-5 *1 (-638 *2 *4 *5)) (-4 *4 (-23)) (-14 *5 *4))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-814 *2)) (-4 *2 (-842))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182))))) 
-(((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-559 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4)))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2721 (-777 *3)) (|:| |coef2| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -2721 *1) (|:| |coef2| *1))) (-4 *1 (-1061 *3 *4 *5))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-1037 (-409 *2)))) (-5 *2 (-568)) (-5 *1 (-124 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-121)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)) (-4 *5 (-1047))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3001 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
-(((*1 *1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-173 *3)) (-4 *3 (-301))))) 
-(((*1 *1 *2 *2 *2 *2) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172))))) 
-(((*1 *1 *1 *1) (-5 *1 (-121)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-679 *4)) (-4 *4 (-365)) (-5 *2 (-1157 *4)) (-5 *1 (-535 *4 *5 *6)) (-4 *5 (-365)) (-4 *6 (-13 (-365) (-840)))))) 
-(((*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-763)) (-4 *5 (-172)))) ((*1 *1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172)))) ((*1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) ((*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *1 (-677 *3 *2 *4)) (-4 *2 (-375 *3)) (-4 *4 (-375 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1127 *2 *3)) (-14 *2 (-763)) (-4 *3 (-1047))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-5 *2 (-634 *3))))) 
-(((*1 *1 *1 *2 *2 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-926)))) ((*1 *1 *1 *2 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-927)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-927)))) ((*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-1026 (-835 (-568)))) (-5 *3 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *4)))) (-4 *4 (-1047)) (-5 *1 (-593 *4))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *6)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-900 *3))) (-5 *1 (-899 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-50 (-1143) (-766))) (-5 *1 (-123))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-450 *3 *4 *5 *6))))) 
-(((*1 *2 *3 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-970 *5 *3)) (-4 *3 (-1219 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-500)))) ((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-700))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-1182 *3))) (-5 *1 (-1182 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *3) (-12 (-4 *1 (-831)) (-5 *3 (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (-5 *2 (-1035)))) ((*1 *2 *3) (-12 (-4 *1 (-831)) (-5 *3 (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) (-5 *2 (-1035))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-57)) (-5 *1 (-56 *2)) (-4 *2 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-953 (-381))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (-12 (-5 *2 (-409 (-953 (-381)))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-381))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-381))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (-12 (-5 *2 (-953 (-568))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (-12 (-5 *2 (-409 (-953 (-568)))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-568))) (-5 *1 (-337 *3 *4 *5)) (-4 *5 (-1037 (-568))) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 *2)) (-14 *4 (-634 *2)) (-4 *5 (-389)))) ((*1 *1 *2) (-12 (-5 *2 (-310 *5)) (-4 *5 (-389)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))))) ((*1 *1 *2) (-12 (-5 *2 (-679 (-409 (-953 (-568))))) (-4 *1 (-386)))) ((*1 *1 *2) (-12 (-5 *2 (-679 (-409 (-953 (-381))))) (-4 *1 (-386)))) ((*1 *1 *2) (-12 (-5 *2 (-679 (-953 (-568)))) (-4 *1 (-386)))) ((*1 *1 *2) (-12 (-5 *2 (-679 (-953 (-381)))) (-4 *1 (-386)))) ((*1 *1 *2) (-12 (-5 *2 (-679 (-310 (-568)))) (-4 *1 (-386)))) ((*1 *1 *2) (-12 (-5 *2 (-679 (-310 (-381)))) (-4 *1 (-386)))) ((*1 *1 *2) (-12 (-5 *2 (-409 (-953 (-568)))) (-4 *1 (-398)))) ((*1 *1 *2) (-12 (-5 *2 (-409 (-953 (-381)))) (-4 *1 (-398)))) ((*1 *1 *2) (-12 (-5 *2 (-953 (-568))) (-4 *1 (-398)))) ((*1 *1 *2) (-12 (-5 *2 (-953 (-381))) (-4 *1 (-398)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-568))) (-4 *1 (-398)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-381))) (-4 *1 (-398)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-409 (-953 (-568))))) (-4 *1 (-442)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-409 (-953 (-381))))) (-4 *1 (-442)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-953 (-568)))) (-4 *1 (-442)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-953 (-381)))) (-4 *1 (-442)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-310 (-568)))) (-4 *1 (-442)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-310 (-381)))) (-4 *1 (-442)))) ((*1 *2 *1) (-12 (-5 *2 (-409 (-734 *3 *4))) (-5 *1 (-733 *3 *4)) (-14 *3 (-1161)) (-4 *4 (-13 (-1047) (-842) (-558))))) ((*1 *2 *1) (-12 (-5 *2 (-3 (|:| |nia| (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| |mdnia| (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))))) (-5 *1 (-761)))) ((*1 *1 *2) (-12 (-5 *2 (-1201 *3)) (-4 *3 (-350)) (-5 *1 (-770 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *1 (-803)))) ((*1 *2 *1) (-12 (-5 *2 (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))))) (-5 *1 (-833)))) ((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) (-5 *1 (-893)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *1 (-977 *3 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-1037 *2)) (-4 *2 (-1195)))) ((*1 *1 *2) (-2198 (-12 (-5 *2 (-953 *3)) (-12 (-3044 (-4 *3 (-43 (-409 (-568))))) (-3044 (-4 *3 (-43 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 *3)) (-12 (-3044 (-4 *3 (-550))) (-3044 (-4 *3 (-43 (-409 (-568))))) (-4 *3 (-43 (-568))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 *3)) (-12 (-3044 (-4 *3 (-993 (-568)))) (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *1 (-1061 *3 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842))))) ((*1 *1 *2) (-2198 (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-3044 (-4 *3 (-43 (-409 (-568))))) (-4 *3 (-43 (-568))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))) (-12 (-5 *2 (-953 (-568))) (-4 *1 (-1061 *3 *4 *5)) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161)))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))))) ((*1 *1 *2) (-12 (-5 *2 (-953 (-409 (-568)))) (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *5 (-609 (-1161))) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842))))) 
-(((*1 *2 *3 *2 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-634 (-242 *5 *6))) (-4 *6 (-453)) (-5 *2 (-242 *5 *6)) (-14 *5 (-634 (-1161))) (-5 *1 (-622 *5 *6))))) 
-(((*1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247)))) ((*1 *2 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247))))) 
-(((*1 *1) (-5 *1 (-439)))) 
-(((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-849)))) ((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-990)))) ((*1 *2 *1) (-12 (-4 *1 (-1010 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-4 *2 (-13 (-1090) (-39))) (-5 *1 (-1125 *2 *3)) (-4 *3 (-13 (-1090) (-39)))))) 
-(((*1 *1 *2 *3 *3 *3 *4) (-12 (-4 *4 (-365)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 (-409 *3))) (-4 *1 (-333 *4 *3 *5 *2)) (-4 *2 (-340 *4 *3 *5)))) ((*1 *1 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *2 (-365)) (-4 *4 (-1219 *2)) (-4 *5 (-1219 (-409 *4))) (-4 *1 (-333 *2 *4 *5 *6)) (-4 *6 (-340 *2 *4 *5)))) ((*1 *1 *2 *2) (-12 (-4 *2 (-365)) (-4 *3 (-1219 *2)) (-4 *4 (-1219 (-409 *3))) (-4 *1 (-333 *2 *3 *4 *5)) (-4 *5 (-340 *2 *3 *4)))) ((*1 *1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *1 (-333 *3 *4 *5 *2)) (-4 *2 (-340 *3 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-415 *4 (-409 *4) *5 *6)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 *3 *4 *5)) (-4 *3 (-365)) (-4 *1 (-333 *3 *4 *5 *6))))) 
-(((*1 *2 *1) (-12 (-4 *2 (-1219 *3)) (-5 *1 (-401 *3 *2)) (-4 *3 (-13 (-365) (-150)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-333 *3 *4 *5 *6)) (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 *3 *4 *5)) (-5 *2 (-2 (|:| -1713 (-415 *4 (-409 *4) *5 *6)) (|:| |principalPart| *6))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| |poly| *6) (|:| -2242 (-409 *6)) (|:| |special| (-409 *6)))) (-5 *1 (-717 *5 *6)) (-5 *3 (-409 *6)))) ((*1 *2 *3) (-12 (-4 *4 (-365)) (-5 *2 (-634 *3)) (-5 *1 (-891 *3 *4)) (-4 *3 (-1219 *4)))) ((*1 *2 *3 *4 *4) (|partial| -12 (-5 *4 (-763)) (-4 *5 (-365)) (-5 *2 (-2 (|:| -3028 *3) (|:| -3284 *3))) (-5 *1 (-891 *3 *5)) (-4 *3 (-1219 *5)))) ((*1 *2 *3 *2 *4 *4) (-12 (-5 *2 (-634 *9)) (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1064 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *2 *4 *4 *4 *4 *4) (-12 (-5 *2 (-634 *9)) (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1064 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *2 *4 *4) (-12 (-5 *2 (-634 *9)) (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1099 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1130 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *2 *4 *4 *4 *4 *4) (-12 (-5 *2 (-634 *9)) (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1099 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1130 *5 *6 *7 *8 *9))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-679 *5)) (-4 *5 (-1047)) (-5 *1 (-1051 *3 *4 *5)) (-14 *3 (-763)) (-14 *4 (-763))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-3 (|:| |nullBranch| "null") (|:| |assignmentBranch| (-2 (|:| |var| (-1161)) (|:| |arrayIndex| (-634 (-953 (-568)))) (|:| |rand| (-2 (|:| |ints2Floats?| (-121)) (|:| -4151 (-850)))))) (|:| |arrayAssignmentBranch| (-2 (|:| |var| (-1161)) (|:| |rand| (-850)) (|:| |ints2Floats?| (-121)))) (|:| |conditionalBranch| (-2 (|:| |switch| (-1160)) (|:| |thenClause| (-328)) (|:| |elseClause| (-328)))) (|:| |returnBranch| (-2 (|:| -3084 (-121)) (|:| -2850 (-2 (|:| |ints2Floats?| (-121)) (|:| -4151 (-850)))))) (|:| |blockBranch| (-634 (-328))) (|:| |commentBranch| (-634 (-1143))) (|:| |callBranch| (-1143)) (|:| |forBranch| (-2 (|:| -1338 (-1082 (-953 (-568)))) (|:| |span| (-953 (-568))) (|:| |body| (-328)))) (|:| |labelBranch| (-1108)) (|:| |loopBranch| (-2 (|:| |switch| (-1160)) (|:| |body| (-328)))) (|:| |commonBranch| (-2 (|:| -3391 (-1161)) (|:| |contents| (-634 (-1161))))) (|:| |printBranch| (-634 (-850))))) (-5 *1 (-328))))) 
-(((*1 *2) (-12 (-4 *3 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *2 (-634 *4)) (-5 *1 (-908 *3 *4 *5 *6)) (-4 *4 (-324 *3 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3700 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| *7) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 *7))))) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-763)) (-5 *1 (-924 *4 *5 *6 *7))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-858)) (-5 *2 (-917))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-121)) (-5 *1 (-123)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-296)) (-5 *3 (-1161)) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-296)) (-5 *3 (-123)) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-121)) (-5 *1 (-607 *4)) (-4 *4 (-842)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-123)) (-5 *2 (-121)) (-5 *1 (-607 *4)) (-4 *4 (-842)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-5 *2 (-121)) (-5 *1 (-882 *5 *3 *4)) (-4 *3 (-881 *5)) (-4 *4 (-609 (-887 *5))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-4 *6 (-881 *5)) (-4 *5 (-1090)) (-5 *2 (-121)) (-5 *1 (-882 *5 *6 *4)) (-4 *4 (-609 (-887 *5)))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-763)) (-4 *4 (-350)) (-5 *1 (-532 *4))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-884 *4 *5)) (-5 *3 (-884 *4 *6)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-658 *5)) (-5 *1 (-880 *4 *5 *6))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-155 *3 *4 *5)) (-14 *3 *2) (-4 *4 (-365)) (-14 *5 (-994 *3 *4))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 *7)) (-5 *5 (-634 (-634 *8))) (-4 *7 (-842)) (-4 *8 (-301)) (-4 *6 (-788)) (-4 *9 (-950 *8 *6 *7)) (-5 *2 (-2 (|:| |unitPart| *9) (|:| |suPart| (-634 (-2 (|:| -3848 (-1157 *9)) (|:| -3438 (-568))))))) (-5 *1 (-732 *6 *7 *8 *9)) (-5 *3 (-1157 *9))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-1161)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-465))))) 
-(((*1 *1 *1 *1 *2 *3) (-12 (-5 *2 (-944 *5)) (-5 *3 (-763)) (-4 *5 (-1047)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1244 *5))) (-5 *4 (-568)) (-5 *2 (-1244 *5)) (-5 *1 (-1029 *5)) (-4 *5 (-365)) (-4 *5 (-370)) (-4 *5 (-1047))))) 
-(((*1 *2 *3 *4) (-12 (-4 *4 (-365)) (-5 *2 (-634 (-1141 *4))) (-5 *1 (-280 *4 *5)) (-5 *3 (-1141 *4)) (-4 *5 (-1234 *4))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-634 (-381))) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-634 (-381))) (-5 *1 (-473)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-381))) (-5 *1 (-473)))) ((*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-869)) (-5 *2 (-1249)) (-5 *1 (-1245)))) ((*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-634 (-288 *4))) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-634 *3)) (-4 *3 (-950 *4 *6 *5)) (-4 *4 (-453)) (-4 *5 (-842)) (-4 *6 (-788)) (-5 *1 (-988 *4 *5 *6 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-288 (-953 (-568)))) (-5 *2 (-2 (|:| |varOrder| (-634 (-1161))) (|:| |inhom| (-3 (-634 (-1244 (-763))) "failed")) (|:| |hom| (-634 (-1244 (-763)))))) (-5 *1 (-228))))) 
-(((*1 *2 *3 *3) (-12 (-5 *2 (-634 *3)) (-5 *1 (-961 *3)) (-4 *3 (-550))))) 
-(((*1 *2 *2 *2 *2) (-12 (-5 *2 (-409 (-1157 (-310 *3)))) (-4 *3 (-13 (-558) (-842))) (-5 *1 (-1118 *3))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-1210 (-568))) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-640 *3)) (-4 *3 (-1195))))) 
-(((*1 *1 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-420 *2)) (-4 *2 (-558))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-197)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-634 (-381))) (-5 *2 (-381)) (-5 *1 (-197))))) 
-(((*1 *2 *1 *3) (|partial| -12 (-5 *3 (-1143)) (-5 *2 (-766)) (-5 *1 (-123))))) 
-(((*1 *2 *3 *3 *3) (|partial| -12 (-4 *4 (-13 (-365) (-150) (-1037 (-568)))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-409 *5))) (-5 *1 (-1016 *4 *5)) (-5 *3 (-409 *5))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1263 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047))))) 
-(((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-953 (-568))) (-5 *2 (-328)) (-5 *1 (-330)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-1082 (-953 (-568)))) (-5 *2 (-328)) (-5 *1 (-330)))) ((*1 *1 *2 *2 *2) (-12 (-5 *2 (-763)) (-5 *1 (-666 *3)) (-4 *3 (-1047)) (-4 *3 (-1090))))) 
-(((*1 *2 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-842) (-1037 (-568)))) (-5 *1 (-180 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 (-169 *3)))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-5 *1 (-180 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 (-169 *4)))))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *2 (-2 (|:| |part1| *3) (|:| |part2| *4))) (-5 *1 (-695 *3 *4)) (-4 *3 (-1195)) (-4 *4 (-1195))))) 
-(((*1 *2 *2 *3 *2) (-12 (-5 *3 (-763)) (-4 *4 (-350)) (-5 *1 (-207 *4 *2)) (-4 *2 (-1219 *4))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-763)) (|:| |poli| *7) (|:| |polj| *7))) (-4 *5 (-788)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-450 *4 *5 *6 *7))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-1090)) (-5 *1 (-900 *3))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *3 (-453)) (-4 *4 (-842)) (-4 *5 (-788)) (-5 *2 (-121)) (-5 *1 (-988 *3 *4 *5 *6)) (-4 *6 (-950 *3 *5 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1244 (-310 (-215)))) (-5 *2 (-1244 (-310 (-381)))) (-5 *1 (-299))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1157 *9)) (-5 *4 (-634 *7)) (-5 *5 (-634 *8)) (-4 *7 (-842)) (-4 *8 (-1047)) (-4 *9 (-950 *8 *6 *7)) (-4 *6 (-788)) (-5 *2 (-1157 *8)) (-5 *1 (-318 *6 *7 *8 *9))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-1141 (-953 *4)) (-1141 (-953 *4)))) (-5 *1 (-1252 *4)) (-4 *4 (-365))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-172))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869))))) 
-(((*1 *2 *3 *4 *5 *6 *5 *3 *7) (-12 (-5 *4 (-568)) (-5 *6 (-2 (|:| |try| (-381)) (|:| |did| (-381)) (|:| -3650 (-381)))) (-5 *7 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783)))) ((*1 *2 *3 *4 *5 *6 *5 *3 *7 *3 *3 *3 *3 *3 *3 *3) (-12 (-5 *4 (-568)) (-5 *6 (-2 (|:| |try| (-381)) (|:| |did| (-381)) (|:| -3650 (-381)))) (-5 *7 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783))))) 
-(((*1 *2 *3 *3 *3) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1100)) (-5 *3 (-568))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-944 *4))) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -3649 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-5 *1 (-563))))) 
-(((*1 *2 *3 *1) (|partial| -12 (-4 *1 (-41 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-5 *2 (-2 (|:| -3649 *3) (|:| -4083 *4)))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4519)) (-4 *1 (-154 *3)) (-4 *3 (-1195)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1195)) (-5 *1 (-598 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-665 *3)) (-4 *3 (-1195)))) ((*1 *2 *1 *3) (|partial| -12 (-4 *1 (-1189 *4 *5 *3 *2)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *3 (-842)) (-4 *2 (-1061 *4 *5 *3)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *1 (-1193 *2)) (-4 *2 (-1195))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-1 (-121) (-123) (-123))) (-5 *1 (-123))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-917)) (-5 *2 (-473)) (-5 *1 (-1245))))) 
 (((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1195)) (-5 *1 (-598 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1195)) (-5 *1 (-1141 *3))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-239 *2)) (-4 *2 (-1195)))) ((*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) ((*1 *1 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-52 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-55 *3 *4)) (-14 *4 (-634 (-1161))))) ((*1 *1 *2 *1 *1 *3) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-64 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-64 *6)) (-5 *1 (-63 *5 *6)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-96 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *7)) (-5 *4 (-141 *5 *6 *7)) (-14 *5 (-568)) (-14 *6 (-763)) (-4 *7 (-172)) (-4 *8 (-172)) (-5 *2 (-141 *5 *6 *8)) (-5 *1 (-140 *5 *6 *7 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-169 *5)) (-4 *5 (-172)) (-4 *6 (-172)) (-5 *2 (-169 *6)) (-5 *1 (-168 *5 *6)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-212 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-310 *3) (-310 *3))) (-4 *3 (-13 (-1047) (-842))) (-5 *1 (-213 *3 *4)) (-14 *4 (-634 (-1161))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-232 *5 *6)) (-14 *5 (-763)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-5 *2 (-232 *5 *7)) (-5 *1 (-231 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-288 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-288 *6)) (-5 *1 (-287 *5 *6)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1195)) (-5 *1 (-288 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *6)) (-5 *4 (-1143)) (-5 *5 (-607 *6)) (-4 *6 (-296)) (-4 *2 (-1195)) (-5 *1 (-291 *6 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 *5)) (-5 *4 (-607 *5)) (-4 *5 (-296)) (-4 *2 (-296)) (-5 *1 (-292 *5 *2)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 *1 *1)) (-5 *3 (-607 *1)) (-4 *1 (-296)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-679 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-5 *2 (-679 *6)) (-5 *1 (-298 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-310 *5)) (-4 *5 (-842)) (-4 *6 (-842)) (-5 *2 (-310 *6)) (-5 *1 (-308 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-4 *6 (-1047)) (-4 *7 (-1047)) (-4 *5 (-787)) (-4 *2 (-324 *7 *5)) (-5 *1 (-322 *5 *6 *4 *7 *2)) (-4 *4 (-324 *6 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *5)) (-5 *4 (-334 *5 *6 *7 *8)) (-4 *5 (-365)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-4 *8 (-340 *5 *6 *7)) (-4 *9 (-365)) (-4 *10 (-1219 *9)) (-4 *11 (-1219 (-409 *10))) (-5 *2 (-334 *9 *10 *11 *12)) (-5 *1 (-331 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *12 (-340 *9 *10 *11)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-336 *3)) (-4 *3 (-1090)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *5)) (-4 *5 (-1199)) (-4 *8 (-1199)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-4 *9 (-1219 *8)) (-4 *2 (-340 *8 *9 *10)) (-5 *1 (-338 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-340 *5 *6 *7)) (-4 *10 (-1219 (-409 *9))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-4 *2 (-375 *6)) (-5 *1 (-373 *5 *4 *6 *2)) (-4 *4 (-375 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-420 *5)) (-4 *5 (-558)) (-4 *6 (-558)) (-5 *2 (-420 *6)) (-5 *1 (-407 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-409 *5)) (-4 *5 (-558)) (-4 *6 (-558)) (-5 *2 (-409 *6)) (-5 *1 (-408 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *5)) (-5 *4 (-415 *5 *6 *7 *8)) (-4 *5 (-301)) (-4 *6 (-993 *5)) (-4 *7 (-1219 *6)) (-4 *8 (-13 (-411 *6 *7) (-1037 *6))) (-4 *9 (-301)) (-4 *10 (-993 *9)) (-4 *11 (-1219 *10)) (-5 *2 (-415 *9 *10 *11 *12)) (-5 *1 (-414 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *12 (-13 (-411 *10 *11) (-1037 *10))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-172)) (-4 *6 (-172)) (-4 *2 (-419 *6)) (-5 *1 (-417 *4 *5 *2 *6)) (-4 *4 (-419 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-558)) (-5 *1 (-420 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-13 (-1047) (-842))) (-4 *6 (-13 (-1047) (-842))) (-4 *2 (-432 *6)) (-5 *1 (-423 *5 *4 *6 *2)) (-4 *4 (-432 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-427 *6)) (-5 *1 (-425 *5 *4 *6 *2)) (-4 *4 (-427 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-842)) (-5 *1 (-494 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-499 *3)) (-4 *3 (-1195)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-518 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-842)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-585 *5)) (-4 *5 (-365)) (-4 *6 (-365)) (-5 *2 (-585 *6)) (-5 *1 (-584 *5 *6)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *6 *5)) (-5 *4 (-3 (-2 (|:| -1924 *5) (|:| |coeff| *5)) "failed")) (-4 *5 (-365)) (-4 *6 (-365)) (-5 *2 (-2 (|:| -1924 *6) (|:| |coeff| *6))) (-5 *1 (-584 *5 *6)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *2 *5)) (-5 *4 (-3 *5 "failed")) (-4 *5 (-365)) (-4 *2 (-365)) (-5 *1 (-584 *5 *2)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *6 *5)) (-5 *4 (-3 (-2 (|:| |mainpart| *5) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *5) (|:| |logand| *5))))) "failed")) (-4 *5 (-365)) (-4 *6 (-365)) (-5 *2 (-2 (|:| |mainpart| *6) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *6) (|:| |logand| *6)))))) (-5 *1 (-584 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-598 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-598 *6)) (-5 *1 (-595 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-598 *6)) (-5 *5 (-598 *7)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-4 *8 (-1195)) (-5 *2 (-598 *8)) (-5 *1 (-596 *6 *7 *8)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-1141 *6)) (-5 *5 (-598 *7)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-4 *8 (-1195)) (-5 *2 (-1141 *8)) (-5 *1 (-596 *6 *7 *8)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-598 *6)) (-5 *5 (-1141 *7)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-4 *8 (-1195)) (-5 *2 (-1141 *8)) (-5 *1 (-596 *6 *7 *8)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1195)) (-5 *1 (-598 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-634 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-634 *6)) (-5 *1 (-632 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-634 *6)) (-5 *5 (-634 *7)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-4 *8 (-1195)) (-5 *2 (-634 *8)) (-5 *1 (-633 *6 *7 *8)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *5)) (-4 *5 (-1047)) (-4 *8 (-1047)) (-4 *6 (-375 *5)) (-4 *7 (-375 *5)) (-4 *2 (-677 *8 *9 *10)) (-5 *1 (-675 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-677 *5 *6 *7)) (-4 *9 (-375 *8)) (-4 *10 (-375 *8)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *8 "failed") *5)) (-4 *5 (-1047)) (-4 *8 (-1047)) (-4 *6 (-375 *5)) (-4 *7 (-375 *5)) (-4 *2 (-677 *8 *9 *10)) (-5 *1 (-675 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-677 *5 *6 *7)) (-4 *9 (-375 *8)) (-4 *10 (-375 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-558)) (-4 *7 (-558)) (-4 *6 (-1219 *5)) (-4 *2 (-1219 (-409 *8))) (-5 *1 (-699 *5 *6 *4 *7 *8 *2)) (-4 *4 (-1219 (-409 *6))) (-4 *8 (-1219 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *8)) (-4 *8 (-1047)) (-4 *9 (-1047)) (-4 *5 (-842)) (-4 *6 (-788)) (-4 *2 (-950 *9 *7 *5)) (-5 *1 (-718 *5 *6 *7 *8 *9 *4 *2)) (-4 *7 (-788)) (-4 *4 (-950 *8 *6 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-842)) (-4 *6 (-842)) (-4 *7 (-788)) (-4 *9 (-1047)) (-4 *2 (-950 *9 *8 *6)) (-5 *1 (-719 *5 *6 *7 *8 *9 *4 *2)) (-4 *8 (-788)) (-4 *4 (-950 *9 *7 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-725 *5 *7)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-4 *7 (-716)) (-5 *2 (-725 *6 *7)) (-5 *1 (-724 *5 *6 *7)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-725 *3 *4)) (-4 *4 (-716)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-777 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-5 *2 (-777 *6)) (-5 *1 (-776 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-172)) (-4 *6 (-172)) (-4 *2 (-792 *6)) (-5 *1 (-793 *4 *5 *2 *6)) (-4 *4 (-792 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-828 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-828 *6)) (-5 *1 (-827 *5 *6)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-828 *6)) (-5 *3 (-1 *6 *5)) (-5 *4 (-828 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *1 (-827 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-835 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-835 *6)) (-5 *1 (-834 *5 *6)))) ((*1 *2 *3 *4 *2 *2) (-12 (-5 *2 (-835 *6)) (-5 *3 (-1 *6 *5)) (-5 *4 (-835 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *1 (-834 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-873 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-873 *6)) (-5 *1 (-872 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-875 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-875 *6)) (-5 *1 (-874 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-877 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-877 *6)) (-5 *1 (-876 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-884 *5 *6)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-884 *5 *7)) (-5 *1 (-883 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-887 *6)) (-5 *1 (-886 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-953 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-5 *2 (-953 *6)) (-5 *1 (-947 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *7)) (-5 *4 (-1 *2 *8)) (-4 *7 (-842)) (-4 *8 (-1047)) (-4 *6 (-788)) (-4 *2 (-13 (-1090) (-10 -8 (-15 -1767 ($ $ $)) (-15 * ($ $ $)) (-15 ** ($ $ (-763)))))) (-5 *1 (-952 *6 *7 *8 *5 *2)) (-4 *5 (-950 *8 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-958 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-958 *6)) (-5 *1 (-957 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-944 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-5 *2 (-944 *6)) (-5 *1 (-982 *5 *6)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-1 *2 (-953 *4))) (-4 *4 (-1047)) (-4 *2 (-950 (-953 *4) *5 *6)) (-4 *5 (-788)) (-4 *6 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $)) (-15 -1305 ((-3 $ "failed") (-1161)))))) (-5 *1 (-985 *4 *5 *6 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-558)) (-4 *6 (-558)) (-4 *2 (-993 *6)) (-5 *1 (-991 *5 *6 *4 *2)) (-4 *4 (-993 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-172)) (-4 *6 (-172)) (-4 *2 (-997 *6)) (-5 *1 (-998 *4 *5 *2 *6)) (-4 *4 (-997 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-1000 *3)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *5 *5 *5)) (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *5 *5)) (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *10 *7)) (-4 *7 (-1047)) (-4 *10 (-1047)) (-14 *5 (-763)) (-14 *6 (-763)) (-4 *8 (-230 *6 *7)) (-4 *9 (-230 *5 *7)) (-4 *2 (-1050 *5 *6 *10 *11 *12)) (-5 *1 (-1052 *5 *6 *7 *8 *9 *4 *10 *11 *12 *2)) (-4 *4 (-1050 *5 *6 *7 *8 *9)) (-4 *11 (-230 *6 *10)) (-4 *12 (-230 *5 *10)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1084 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1084 *6)) (-5 *1 (-1080 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1084 *5)) (-4 *5 (-840)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-634 *6)) (-5 *1 (-1080 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1082 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1082 *6)) (-5 *1 (-1081 *5 *6)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 *4 *4)) (-4 *1 (-1085 *4 *2)) (-4 *4 (-840)) (-4 *2 (-1134 *4)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-1132 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1141 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1141 *6)) (-5 *1 (-1139 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-1141 *6)) (-5 *5 (-1141 *7)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-4 *8 (-1195)) (-5 *2 (-1141 *8)) (-5 *1 (-1140 *6 *7 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1157 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-5 *2 (-1157 *6)) (-5 *1 (-1154 *5 *6)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *4 *4 *4)) (-4 *1 (-1172 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1207 *5 *7 *9)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-14 *7 (-1161)) (-14 *9 *5) (-14 *10 *6) (-5 *2 (-1207 *6 *8 *10)) (-5 *1 (-1202 *5 *6 *7 *8 *9 *10)) (-14 *8 (-1161)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1210 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1210 *6)) (-5 *1 (-1209 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1210 *5)) (-4 *5 (-840)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1141 *6)) (-5 *1 (-1209 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *6)) (-5 *4 (-1216 *5 *6)) (-14 *5 (-1161)) (-4 *6 (-1047)) (-4 *8 (-1047)) (-5 *2 (-1216 *7 *8)) (-5 *1 (-1211 *5 *6 *7 *8)) (-14 *7 (-1161)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-4 *2 (-1219 *6)) (-5 *1 (-1217 *5 *4 *6 *2)) (-4 *4 (-1219 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1228 *5 *7 *9)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-14 *7 (-1161)) (-14 *9 *5) (-14 *10 *6) (-5 *2 (-1228 *6 *8 *10)) (-5 *1 (-1223 *5 *6 *7 *8 *9 *10)) (-14 *8 (-1161)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-4 *2 (-1234 *6)) (-5 *1 (-1232 *5 *6 *4 *2)) (-4 *4 (-1234 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1244 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1244 *6)) (-5 *1 (-1243 *5 *6)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *6 "failed") *5)) (-5 *4 (-1244 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1244 *6)) (-5 *1 (-1243 *5 *6)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-1265 *3 *4)) (-4 *4 (-838))))) 
+(((*1 *1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *1 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-1195))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-52 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-55 *3 *4)) (-14 *4 (-634 (-1161))))) ((*1 *1 *2 *1 *1 *3) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-64 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-64 *6)) (-5 *1 (-63 *5 *6)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-96 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *7)) (-5 *4 (-141 *5 *6 *7)) (-14 *5 (-568)) (-14 *6 (-763)) (-4 *7 (-172)) (-4 *8 (-172)) (-5 *2 (-141 *5 *6 *8)) (-5 *1 (-140 *5 *6 *7 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-169 *5)) (-4 *5 (-172)) (-4 *6 (-172)) (-5 *2 (-169 *6)) (-5 *1 (-168 *5 *6)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-212 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-310 *3) (-310 *3))) (-4 *3 (-13 (-1047) (-842))) (-5 *1 (-213 *3 *4)) (-14 *4 (-634 (-1161))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-232 *5 *6)) (-14 *5 (-763)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-5 *2 (-232 *5 *7)) (-5 *1 (-231 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-288 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-288 *6)) (-5 *1 (-287 *5 *6)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1195)) (-5 *1 (-288 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *6)) (-5 *4 (-1143)) (-5 *5 (-607 *6)) (-4 *6 (-296)) (-4 *2 (-1195)) (-5 *1 (-291 *6 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 *5)) (-5 *4 (-607 *5)) (-4 *5 (-296)) (-4 *2 (-296)) (-5 *1 (-292 *5 *2)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 *1 *1)) (-5 *3 (-607 *1)) (-4 *1 (-296)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-679 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-5 *2 (-679 *6)) (-5 *1 (-298 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-310 *5)) (-4 *5 (-842)) (-4 *6 (-842)) (-5 *2 (-310 *6)) (-5 *1 (-308 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-4 *6 (-1047)) (-4 *7 (-1047)) (-4 *5 (-787)) (-4 *2 (-324 *7 *5)) (-5 *1 (-322 *5 *6 *4 *7 *2)) (-4 *4 (-324 *6 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *5)) (-5 *4 (-334 *5 *6 *7 *8)) (-4 *5 (-365)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-4 *8 (-340 *5 *6 *7)) (-4 *9 (-365)) (-4 *10 (-1219 *9)) (-4 *11 (-1219 (-409 *10))) (-5 *2 (-334 *9 *10 *11 *12)) (-5 *1 (-331 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *12 (-340 *9 *10 *11)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-336 *3)) (-4 *3 (-1090)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *5)) (-4 *5 (-1199)) (-4 *8 (-1199)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-4 *9 (-1219 *8)) (-4 *2 (-340 *8 *9 *10)) (-5 *1 (-338 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-340 *5 *6 *7)) (-4 *10 (-1219 (-409 *9))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-4 *2 (-375 *6)) (-5 *1 (-373 *5 *4 *6 *2)) (-4 *4 (-375 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-420 *5)) (-4 *5 (-558)) (-4 *6 (-558)) (-5 *2 (-420 *6)) (-5 *1 (-407 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-409 *5)) (-4 *5 (-558)) (-4 *6 (-558)) (-5 *2 (-409 *6)) (-5 *1 (-408 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *5)) (-5 *4 (-415 *5 *6 *7 *8)) (-4 *5 (-301)) (-4 *6 (-993 *5)) (-4 *7 (-1219 *6)) (-4 *8 (-13 (-411 *6 *7) (-1037 *6))) (-4 *9 (-301)) (-4 *10 (-993 *9)) (-4 *11 (-1219 *10)) (-5 *2 (-415 *9 *10 *11 *12)) (-5 *1 (-414 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *12 (-13 (-411 *10 *11) (-1037 *10))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-172)) (-4 *6 (-172)) (-4 *2 (-419 *6)) (-5 *1 (-417 *4 *5 *2 *6)) (-4 *4 (-419 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-558)) (-5 *1 (-420 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-13 (-1047) (-842))) (-4 *6 (-13 (-1047) (-842))) (-4 *2 (-432 *6)) (-5 *1 (-423 *5 *4 *6 *2)) (-4 *4 (-432 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-427 *6)) (-5 *1 (-425 *5 *4 *6 *2)) (-4 *4 (-427 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-842)) (-5 *1 (-494 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-499 *3)) (-4 *3 (-1195)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-518 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-842)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-585 *5)) (-4 *5 (-365)) (-4 *6 (-365)) (-5 *2 (-585 *6)) (-5 *1 (-584 *5 *6)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *6 *5)) (-5 *4 (-3 (-2 (|:| -4151 *5) (|:| |coeff| *5)) "failed")) (-4 *5 (-365)) (-4 *6 (-365)) (-5 *2 (-2 (|:| -4151 *6) (|:| |coeff| *6))) (-5 *1 (-584 *5 *6)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *2 *5)) (-5 *4 (-3 *5 "failed")) (-4 *5 (-365)) (-4 *2 (-365)) (-5 *1 (-584 *5 *2)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 *6 *5)) (-5 *4 (-3 (-2 (|:| |mainpart| *5) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *5) (|:| |logand| *5))))) "failed")) (-4 *5 (-365)) (-4 *6 (-365)) (-5 *2 (-2 (|:| |mainpart| *6) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *6) (|:| |logand| *6)))))) (-5 *1 (-584 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-598 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-598 *6)) (-5 *1 (-595 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-598 *6)) (-5 *5 (-598 *7)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-4 *8 (-1195)) (-5 *2 (-598 *8)) (-5 *1 (-596 *6 *7 *8)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-1141 *6)) (-5 *5 (-598 *7)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-4 *8 (-1195)) (-5 *2 (-1141 *8)) (-5 *1 (-596 *6 *7 *8)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-598 *6)) (-5 *5 (-1141 *7)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-4 *8 (-1195)) (-5 *2 (-1141 *8)) (-5 *1 (-596 *6 *7 *8)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1195)) (-5 *1 (-598 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-634 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-634 *6)) (-5 *1 (-632 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-634 *6)) (-5 *5 (-634 *7)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-4 *8 (-1195)) (-5 *2 (-634 *8)) (-5 *1 (-633 *6 *7 *8)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *3 *3 *3)) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *5)) (-4 *5 (-1047)) (-4 *8 (-1047)) (-4 *6 (-375 *5)) (-4 *7 (-375 *5)) (-4 *2 (-677 *8 *9 *10)) (-5 *1 (-675 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-677 *5 *6 *7)) (-4 *9 (-375 *8)) (-4 *10 (-375 *8)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *8 "failed") *5)) (-4 *5 (-1047)) (-4 *8 (-1047)) (-4 *6 (-375 *5)) (-4 *7 (-375 *5)) (-4 *2 (-677 *8 *9 *10)) (-5 *1 (-675 *5 *6 *7 *4 *8 *9 *10 *2)) (-4 *4 (-677 *5 *6 *7)) (-4 *9 (-375 *8)) (-4 *10 (-375 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-558)) (-4 *7 (-558)) (-4 *6 (-1219 *5)) (-4 *2 (-1219 (-409 *8))) (-5 *1 (-699 *5 *6 *4 *7 *8 *2)) (-4 *4 (-1219 (-409 *6))) (-4 *8 (-1219 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *9 *8)) (-4 *8 (-1047)) (-4 *9 (-1047)) (-4 *5 (-842)) (-4 *6 (-788)) (-4 *2 (-950 *9 *7 *5)) (-5 *1 (-718 *5 *6 *7 *8 *9 *4 *2)) (-4 *7 (-788)) (-4 *4 (-950 *8 *6 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-842)) (-4 *6 (-842)) (-4 *7 (-788)) (-4 *9 (-1047)) (-4 *2 (-950 *9 *8 *6)) (-5 *1 (-719 *5 *6 *7 *8 *9 *4 *2)) (-4 *8 (-788)) (-4 *4 (-950 *9 *7 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-725 *5 *7)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-4 *7 (-716)) (-5 *2 (-725 *6 *7)) (-5 *1 (-724 *5 *6 *7)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-725 *3 *4)) (-4 *4 (-716)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-777 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-5 *2 (-777 *6)) (-5 *1 (-776 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-172)) (-4 *6 (-172)) (-4 *2 (-792 *6)) (-5 *1 (-793 *4 *5 *2 *6)) (-4 *4 (-792 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-828 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-828 *6)) (-5 *1 (-827 *5 *6)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-828 *6)) (-5 *3 (-1 *6 *5)) (-5 *4 (-828 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *1 (-827 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-835 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-835 *6)) (-5 *1 (-834 *5 *6)))) ((*1 *2 *3 *4 *2 *2) (-12 (-5 *2 (-835 *6)) (-5 *3 (-1 *6 *5)) (-5 *4 (-835 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *1 (-834 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-873 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-873 *6)) (-5 *1 (-872 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-875 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-875 *6)) (-5 *1 (-874 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-877 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-877 *6)) (-5 *1 (-876 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-884 *5 *6)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-884 *5 *7)) (-5 *1 (-883 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-887 *6)) (-5 *1 (-886 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-953 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-5 *2 (-953 *6)) (-5 *1 (-947 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *7)) (-5 *4 (-1 *2 *8)) (-4 *7 (-842)) (-4 *8 (-1047)) (-4 *6 (-788)) (-4 *2 (-13 (-1090) (-10 -8 (-15 -1769 ($ $ $)) (-15 * ($ $ $)) (-15 ** ($ $ (-763)))))) (-5 *1 (-952 *6 *7 *8 *5 *2)) (-4 *5 (-950 *8 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-958 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-958 *6)) (-5 *1 (-957 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-944 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-5 *2 (-944 *6)) (-5 *1 (-982 *5 *6)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-1 *2 (-953 *4))) (-4 *4 (-1047)) (-4 *2 (-950 (-953 *4) *5 *6)) (-4 *5 (-788)) (-4 *6 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $)) (-15 -3325 ((-3 $ "failed") (-1161)))))) (-5 *1 (-985 *4 *5 *6 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-558)) (-4 *6 (-558)) (-4 *2 (-993 *6)) (-5 *1 (-991 *5 *6 *4 *2)) (-4 *4 (-993 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-172)) (-4 *6 (-172)) (-4 *2 (-997 *6)) (-5 *1 (-998 *4 *5 *2 *6)) (-4 *4 (-997 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-1000 *3)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *5 *5 *5)) (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *5 *5)) (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *10 *7)) (-4 *7 (-1047)) (-4 *10 (-1047)) (-14 *5 (-763)) (-14 *6 (-763)) (-4 *8 (-230 *6 *7)) (-4 *9 (-230 *5 *7)) (-4 *2 (-1050 *5 *6 *10 *11 *12)) (-5 *1 (-1052 *5 *6 *7 *8 *9 *4 *10 *11 *12 *2)) (-4 *4 (-1050 *5 *6 *7 *8 *9)) (-4 *11 (-230 *6 *10)) (-4 *12 (-230 *5 *10)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1084 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1084 *6)) (-5 *1 (-1080 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1084 *5)) (-4 *5 (-840)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-634 *6)) (-5 *1 (-1080 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1082 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1082 *6)) (-5 *1 (-1081 *5 *6)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 *4 *4)) (-4 *1 (-1085 *4 *2)) (-4 *4 (-840)) (-4 *2 (-1134 *4)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-1132 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1141 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1141 *6)) (-5 *1 (-1139 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *8 *6 *7)) (-5 *4 (-1141 *6)) (-5 *5 (-1141 *7)) (-4 *6 (-1195)) (-4 *7 (-1195)) (-4 *8 (-1195)) (-5 *2 (-1141 *8)) (-5 *1 (-1140 *6 *7 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1157 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-5 *2 (-1157 *6)) (-5 *1 (-1154 *5 *6)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 *4 *4 *4)) (-4 *1 (-1172 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1207 *5 *7 *9)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-14 *7 (-1161)) (-14 *9 *5) (-14 *10 *6) (-5 *2 (-1207 *6 *8 *10)) (-5 *1 (-1202 *5 *6 *7 *8 *9 *10)) (-14 *8 (-1161)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1210 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1210 *6)) (-5 *1 (-1209 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1210 *5)) (-4 *5 (-840)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1141 *6)) (-5 *1 (-1209 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *8 *6)) (-5 *4 (-1216 *5 *6)) (-14 *5 (-1161)) (-4 *6 (-1047)) (-4 *8 (-1047)) (-5 *2 (-1216 *7 *8)) (-5 *1 (-1211 *5 *6 *7 *8)) (-14 *7 (-1161)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-4 *2 (-1219 *6)) (-5 *1 (-1217 *5 *4 *6 *2)) (-4 *4 (-1219 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1228 *5 *7 *9)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-14 *7 (-1161)) (-14 *9 *5) (-14 *10 *6) (-5 *2 (-1228 *6 *8 *10)) (-5 *1 (-1223 *5 *6 *7 *8 *9 *10)) (-14 *8 (-1161)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1047)) (-4 *6 (-1047)) (-4 *2 (-1234 *6)) (-5 *1 (-1232 *5 *6 *4 *2)) (-4 *4 (-1234 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *5)) (-5 *4 (-1244 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1244 *6)) (-5 *1 (-1243 *5 *6)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *6 "failed") *5)) (-5 *4 (-1244 *5)) (-4 *5 (-1195)) (-4 *6 (-1195)) (-5 *2 (-1244 *6)) (-5 *1 (-1243 *5 *6)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-1265 *3 *4)) (-4 *4 (-838))))) 
 (((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1195)) (-5 *1 (-598 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *3 (-1195)) (-5 *1 (-1141 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
-(((*1 *2 *3 *4 *5) (-12 (-4 *6 (-1219 *9)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *9 (-301)) (-4 *10 (-950 *9 *7 *8)) (-5 *2 (-2 (|:| |deter| (-634 (-1157 *10))) (|:| |dterm| (-634 (-634 (-2 (|:| -1876 (-763)) (|:| |pcoef| *10))))) (|:| |nfacts| (-634 *6)) (|:| |nlead| (-634 *10)))) (-5 *1 (-771 *6 *7 *8 *9 *10)) (-5 *3 (-1157 *10)) (-5 *4 (-634 *6)) (-5 *5 (-634 *10))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-550)) (-5 *2 (-121))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-420 (-1157 *1))) (-5 *1 (-310 *4)) (-5 *3 (-1157 *1)) (-4 *4 (-453)) (-4 *4 (-558)) (-4 *4 (-842)))) ((*1 *2 *3) (-12 (-4 *1 (-904)) (-5 *2 (-420 (-1157 *1))) (-5 *3 (-1157 *1))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-568))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-184)))) ((*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-294)))) ((*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-299))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *1 *2) (-12 (-5 *1 (-329 *2)) (-4 *2 (-842)))) ((*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) ((*1 *1 *1) (-4 *1 (-1184)))) 
 (((*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *6 (-13 (-558) (-842))) (-5 *2 (-634 (-310 *6))) (-5 *1 (-211 *5 *6)) (-5 *3 (-310 *6)) (-4 *5 (-1047)))) ((*1 *2 *1) (-12 (-5 *1 (-420 *2)) (-4 *2 (-558)))) ((*1 *2 *3) (-12 (-5 *3 (-585 *5)) (-4 *5 (-13 (-29 *4) (-1181))) (-4 *4 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *2 (-634 *5)) (-5 *1 (-583 *4 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-585 (-409 (-953 *4)))) (-4 *4 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *2 (-634 (-310 *4))) (-5 *1 (-588 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-1085 *3 *2)) (-4 *3 (-840)) (-4 *2 (-1134 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-1085 *4 *2)) (-4 *4 (-840)) (-4 *2 (-1134 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181))))) ((*1 *2 *1) (-12 (-5 *2 (-1257 (-1161) *3)) (-5 *1 (-1264 *3)) (-4 *3 (-1047)))) ((*1 *2 *1) (-12 (-5 *2 (-1257 *3 *4)) (-5 *1 (-1266 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1864 *7) (|:| -4477 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *5 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3)))) 
-(((*1 *1 *1 *1) (-4 *1 (-146))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *2 *2 *2) (-12 (-5 *1 (-160 *2)) (-4 *2 (-550)))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *2 *3 *4) (-12 (-5 *4 |RationalNumber|) (-5 *2 (-1 (-568))) (-5 *1 (-1045)) (-5 *3 (-568))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-406)) (-5 *2 (-568)))) ((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-688))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-428 *4 *2)) (-4 *2 (-13 (-1181) (-29 *4))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-150)) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *2 (-310 *5)) (-5 *1 (-588 *5))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *1 *2) (-12 (-5 *1 (-329 *2)) (-4 *2 (-842)))) ((*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) ((*1 *1 *1) (-4 *1 (-1184)))) 
 (((*1 *2 *3) (-12 (-5 *2 (-1 *3 *3)) (-5 *1 (-533 *3)) (-4 *3 (-13 (-716) (-25)))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-159 *4 *2)) (-4 *2 (-432 *4)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-161)) (-5 *2 (-1161)))) ((*1 *1 *1) (-4 *1 (-161)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-369 *2)) (-4 *2 (-172))))) 
 (((*1 *1 *2 *2) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1195)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1143)) (-5 *1 (-990)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1084 *4)) (-4 *4 (-1195)) (-5 *1 (-1082 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-568)) (-5 *1 (-196))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-950 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-2 (|:| |poly| *3) (|:| |mult| *5))) (-5 *1 (-450 *5 *6 *7 *3))))) 
 (((*1 *2 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1244 (-634 (-568)))) (-5 *1 (-491)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1195)) (-5 *1 (-598 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1195)) (-5 *1 (-1141 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1 *3)) (-4 *3 (-1195)) (-5 *1 (-1141 *3))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-37 *2)) (-4 *2 (-365)))) ((*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1195)) (-4 *4 (-375 *2)) (-4 *5 (-375 *2)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *1 (-62 *2 *4 *5)) (-4 *4 (-375 *2)) (-4 *5 (-375 *2)) (-4 *2 (-1195)))) ((*1 *1 *1 *2) (-12 (-5 *2 "right") (-4 *1 (-128 *3)) (-4 *3 (-1195)))) ((*1 *1 *1 *2) (-12 (-5 *2 "left") (-4 *1 (-128 *3)) (-4 *3 (-1195)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-634 (-568))) (-4 *2 (-172)) (-5 *1 (-141 *4 *5 *2)) (-14 *4 (-568)) (-14 *5 (-763)))) ((*1 *2 *1 *3 *3 *3 *3) (-12 (-5 *3 (-568)) (-4 *2 (-172)) (-5 *1 (-141 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-763)))) ((*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-568)) (-4 *2 (-172)) (-5 *1 (-141 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-763)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *2 (-172)) (-5 *1 (-141 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-763)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *2 (-172)) (-5 *1 (-141 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-763)))) ((*1 *2 *1) (-12 (-4 *2 (-172)) (-5 *1 (-141 *3 *4 *2)) (-14 *3 (-568)) (-14 *4 (-763)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-240 (-1143))) (-5 *1 (-205 *4)) (-4 *4 (-13 (-842) (-10 -8 (-15 -2779 ((-1143) $ *3)) (-15 -4125 ((-1249) $)) (-15 -1352 ((-1249) $))))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-990)) (-5 *1 (-205 *3)) (-4 *3 (-13 (-842) (-10 -8 (-15 -2779 ((-1143) $ (-1161))) (-15 -4125 ((-1249) $)) (-15 -1352 ((-1249) $))))))) ((*1 *2 *1 *3) (-12 (-5 *3 "count") (-5 *2 (-763)) (-5 *1 (-240 *4)) (-4 *4 (-842)))) ((*1 *1 *1 *2) (-12 (-5 *2 "sort") (-5 *1 (-240 *3)) (-4 *3 (-842)))) ((*1 *1 *1 *2) (-12 (-5 *2 "unique") (-5 *1 (-240 *3)) (-4 *3 (-842)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-281 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195)))) ((*1 *2 *1 *3 *2) (-12 (-4 *1 (-283 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195)))) ((*1 *2 *1 *2) (-12 (-4 *3 (-172)) (-5 *1 (-284 *3 *2 *4 *5 *6 *7)) (-4 *2 (-1219 *3)) (-4 *4 (-23)) (-14 *5 (-1 *2 *2 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *4)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-634 *1)) (-4 *1 (-296)))) ((*1 *1 *2 *1 *1 *1 *1) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) ((*1 *1 *2 *1 *1 *1) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) ((*1 *1 *2 *1 *1) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) ((*1 *2 *1 *2 *2) (-12 (-4 *1 (-340 *2 *3 *4)) (-4 *2 (-1199)) (-4 *3 (-1219 *2)) (-4 *4 (-1219 (-409 *3))))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-419 *2)) (-4 *2 (-172)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1143)) (-5 *1 (-511)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-57)) (-5 *1 (-623)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1210 (-568))) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) ((*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-763)) (-5 *1 (-666 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *2 *2) (-12 (-5 *2 (-634 (-568))) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-634 (-887 *4))) (-5 *1 (-887 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-898 *2)) (-4 *2 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-900 *4)) (-5 *1 (-899 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-920 *2 *4)) (-4 *4 (-641 *2)) (-4 *2 (-365)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-971 *2)) (-4 *2 (-365)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-232 *4 *2)) (-14 *4 (-917)) (-4 *2 (-365)) (-5 *1 (-994 *4 *2)))) ((*1 *2 *1 *3) (-12 (-5 *3 "value") (-4 *1 (-1010 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-5 *1 (-1026 *2)) (-4 *2 (-1195)))) ((*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-1050 *4 *5 *2 *6 *7)) (-4 *2 (-1047)) (-4 *6 (-230 *5 *2)) (-4 *7 (-230 *4 *2)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1050 *4 *5 *2 *6 *7)) (-4 *6 (-230 *5 *2)) (-4 *7 (-230 *4 *2)) (-4 *2 (-1047)))) ((*1 *2 *1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-5 *1 (-1069 *4 *5 *2)) (-4 *2 (-13 (-432 *5) (-881 *4) (-609 (-887 *4)))))) ((*1 *2 *1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-5 *1 (-1070 *4 *5 *2)) (-4 *2 (-13 (-432 *5) (-881 *4) (-609 (-887 *4)))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)))) ((*1 *1 *1 *1) (-4 *1 (-1129))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-1161)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-409 *1)) (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-409 *1)) (-4 *1 (-1219 *3)) (-4 *3 (-1047)) (-4 *3 (-558)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-1221 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047)))) ((*1 *2 *1 *3) (-12 (-5 *3 "last") (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) ((*1 *1 *1 *2) (-12 (-5 *2 "rest") (-4 *1 (-1231 *3)) (-4 *3 (-1195)))) ((*1 *2 *1 *3) (-12 (-5 *3 "first") (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1141 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-37 *2)) (-4 *2 (-365)))) ((*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1195)) (-4 *4 (-375 *2)) (-4 *5 (-375 *2)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *1 (-62 *2 *4 *5)) (-4 *4 (-375 *2)) (-4 *5 (-375 *2)) (-4 *2 (-1195)))) ((*1 *1 *1 *2) (-12 (-5 *2 "right") (-4 *1 (-128 *3)) (-4 *3 (-1195)))) ((*1 *1 *1 *2) (-12 (-5 *2 "left") (-4 *1 (-128 *3)) (-4 *3 (-1195)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-634 (-568))) (-4 *2 (-172)) (-5 *1 (-141 *4 *5 *2)) (-14 *4 (-568)) (-14 *5 (-763)))) ((*1 *2 *1 *3 *3 *3 *3) (-12 (-5 *3 (-568)) (-4 *2 (-172)) (-5 *1 (-141 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-763)))) ((*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-568)) (-4 *2 (-172)) (-5 *1 (-141 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-763)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *2 (-172)) (-5 *1 (-141 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-763)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *2 (-172)) (-5 *1 (-141 *4 *5 *2)) (-14 *4 *3) (-14 *5 (-763)))) ((*1 *2 *1) (-12 (-4 *2 (-172)) (-5 *1 (-141 *3 *4 *2)) (-14 *3 (-568)) (-14 *4 (-763)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-240 (-1143))) (-5 *1 (-205 *4)) (-4 *4 (-13 (-842) (-10 -8 (-15 -2781 ((-1143) $ *3)) (-15 -4127 ((-1249) $)) (-15 -3687 ((-1249) $))))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-990)) (-5 *1 (-205 *3)) (-4 *3 (-13 (-842) (-10 -8 (-15 -2781 ((-1143) $ (-1161))) (-15 -4127 ((-1249) $)) (-15 -3687 ((-1249) $))))))) ((*1 *2 *1 *3) (-12 (-5 *3 "count") (-5 *2 (-763)) (-5 *1 (-240 *4)) (-4 *4 (-842)))) ((*1 *1 *1 *2) (-12 (-5 *2 "sort") (-5 *1 (-240 *3)) (-4 *3 (-842)))) ((*1 *1 *1 *2) (-12 (-5 *2 "unique") (-5 *1 (-240 *3)) (-4 *3 (-842)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-281 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195)))) ((*1 *2 *1 *3 *2) (-12 (-4 *1 (-283 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195)))) ((*1 *2 *1 *2) (-12 (-4 *3 (-172)) (-5 *1 (-284 *3 *2 *4 *5 *6 *7)) (-4 *2 (-1219 *3)) (-4 *4 (-23)) (-14 *5 (-1 *2 *2 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *4)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-634 *1)) (-4 *1 (-296)))) ((*1 *1 *2 *1 *1 *1 *1) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) ((*1 *1 *2 *1 *1 *1) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) ((*1 *1 *2 *1 *1) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-296)) (-5 *2 (-123)))) ((*1 *2 *1 *2 *2) (-12 (-4 *1 (-340 *2 *3 *4)) (-4 *2 (-1199)) (-4 *3 (-1219 *2)) (-4 *4 (-1219 (-409 *3))))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-419 *2)) (-4 *2 (-172)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1143)) (-5 *1 (-511)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-57)) (-5 *1 (-623)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1210 (-568))) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) ((*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-763)) (-5 *1 (-666 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *2 *2) (-12 (-5 *2 (-634 (-568))) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-634 (-887 *4))) (-5 *1 (-887 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-898 *2)) (-4 *2 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-900 *4)) (-5 *1 (-899 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-920 *2 *4)) (-4 *4 (-641 *2)) (-4 *2 (-365)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-971 *2)) (-4 *2 (-365)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-232 *4 *2)) (-14 *4 (-917)) (-4 *2 (-365)) (-5 *1 (-994 *4 *2)))) ((*1 *2 *1 *3) (-12 (-5 *3 "value") (-4 *1 (-1010 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-5 *1 (-1026 *2)) (-4 *2 (-1195)))) ((*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-1050 *4 *5 *2 *6 *7)) (-4 *2 (-1047)) (-4 *6 (-230 *5 *2)) (-4 *7 (-230 *4 *2)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1050 *4 *5 *2 *6 *7)) (-4 *6 (-230 *5 *2)) (-4 *7 (-230 *4 *2)) (-4 *2 (-1047)))) ((*1 *2 *1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-5 *1 (-1069 *4 *5 *2)) (-4 *2 (-13 (-432 *5) (-881 *4) (-609 (-887 *4)))))) ((*1 *2 *1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-5 *1 (-1070 *4 *5 *2)) (-4 *2 (-13 (-432 *5) (-881 *4) (-609 (-887 *4)))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)))) ((*1 *1 *1 *1) (-4 *1 (-1129))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-1161)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-409 *1)) (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-409 *1)) (-4 *1 (-1219 *3)) (-4 *3 (-1047)) (-4 *3 (-558)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-1221 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047)))) ((*1 *2 *1 *3) (-12 (-5 *3 "last") (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) ((*1 *1 *1 *2) (-12 (-5 *2 "rest") (-4 *1 (-1231 *3)) (-4 *3 (-1195)))) ((*1 *2 *1 *3) (-12 (-5 *3 "first") (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-4 *7 (-1219 (-409 *6))) (-5 *2 (-2 (|:| |answer| *3) (|:| -1989 *3))) (-5 *1 (-566 *5 *6 *7 *3)) (-4 *3 (-340 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| |answer| (-409 *6)) (|:| -1989 (-409 *6)) (|:| |specpart| (-409 *6)) (|:| |polypart| *6))) (-5 *1 (-567 *5 *6)) (-5 *3 (-409 *6))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-36 *4 *5)) (-4 *5 (-432 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-159 *4 *5)) (-4 *5 (-432 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-272 *4 *5)) (-4 *5 (-13 (-432 *4) (-1002))))) ((*1 *2 *3) (-12 (-5 *3 (-123)) (-5 *2 (-121)) (-5 *1 (-295 *4)) (-4 *4 (-296)))) ((*1 *2 *3) (-12 (-4 *1 (-296)) (-5 *3 (-123)) (-5 *2 (-121)))) ((*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-431 *4 *5)) (-4 *4 (-432 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-433 *4 *5)) (-4 *5 (-432 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-123)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-621 *4 *5)) (-4 *5 (-13 (-432 *4) (-1002) (-1181)))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-1244 (-679 *4))))) ((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-1244 (-679 *4))) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4)))) ((*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-1244 (-679 *3))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1161))) (-4 *5 (-365)) (-5 *2 (-1244 (-679 (-409 (-953 *5))))) (-5 *1 (-1077 *5)) (-5 *4 (-679 (-409 (-953 *5)))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1161))) (-4 *5 (-365)) (-5 *2 (-1244 (-679 (-953 *5)))) (-5 *1 (-1077 *5)) (-5 *4 (-679 (-953 *5))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-679 *4))) (-4 *4 (-365)) (-5 *2 (-1244 (-679 *4))) (-5 *1 (-1077 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1231 *3)) (-4 *3 (-1195)) (-5 *2 (-763))))) 
 (((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-230 *6 *2)) (-14 *6 *2) (-5 *2 (-763)) (-5 *1 (-908 *4 *3 *5 *6)) (-4 *3 (-324 *4 *5)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *1 (-950 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-950 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-763))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-900 *4)) (-4 *4 (-1090)) (-5 *2 (-634 (-763))) (-5 *1 (-899 *4))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-558)) (-4 *3 (-950 *7 *5 *6)) (-5 *2 (-2 (|:| -3438 (-763)) (|:| -2348 *3) (|:| |radicand| (-634 *3)))) (-5 *1 (-954 *5 *6 *7 *3 *8)) (-5 *4 (-763)) (-4 *8 (-13 (-365) (-10 -8 (-15 -2317 (*3 $)) (-15 -2324 (*3 $)) (-15 -2745 ($ *3)))))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-972)) (-5 *1 (-900 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-634 *2)) (-5 *1 (-177 *2)) (-4 *2 (-301)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-634 (-634 *4))) (-5 *2 (-634 *4)) (-4 *4 (-301)) (-5 *1 (-177 *4)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 (-2 (|:| -3746 (-679 *7)) (|:| |basisDen| *7) (|:| |basisInv| (-679 *7))))) (-5 *5 (-763)) (-4 *8 (-1219 *7)) (-4 *7 (-1219 *6)) (-4 *6 (-350)) (-5 *2 (-2 (|:| -3746 (-679 *7)) (|:| |basisDen| *7) (|:| |basisInv| (-679 *7)))) (-5 *1 (-507 *6 *7 *8)))) ((*1 *2 *2 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-333 *3 *4 *5 *6)) (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 *3 *4 *5)) (-5 *2 (-121))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-634 *4))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-816))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-828 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-835 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-121)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-465))))) 
+(((*1 *2 *3 *4 *2 *2 *5) (|partial| -12 (-5 *2 (-835 *4)) (-5 *3 (-607 *4)) (-5 *5 (-121)) (-4 *4 (-13 (-1181) (-29 *6))) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-214 *6 *4))))) 
 (((*1 *1 *1 *1) (-12 (-4 *1 (-235 *2)) (-4 *2 (-1090)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1035)) (-5 *1 (-299)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-1035))) (-5 *2 (-1035)) (-5 *1 (-299)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-640 *2)) (-4 *2 (-1195)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-640 *2)) (-4 *2 (-1195)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-640 *2)) (-4 *2 (-1195)))) ((*1 *1 *1 *1) (-5 *1 (-1059))) ((*1 *2 *3) (-12 (-5 *3 (-1141 (-1141 *4))) (-5 *2 (-1141 *4)) (-5 *1 (-1138 *4)) (-4 *4 (-1195)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
-(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-236 (-922 *4))) (-4 *4 (-350)) (-5 *2 (-679 *4)) (-5 *1 (-867 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-236 (-922 *5))) (-5 *4 (-634 (-922 *5))) (-4 *5 (-350)) (-5 *2 (-679 *5)) (-5 *1 (-867 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-236 (-921 *4))) (-4 *4 (-365)) (-5 *2 (-679 *4)) (-5 *1 (-868 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-236 (-921 *5))) (-5 *4 (-634 (-921 *5))) (-4 *5 (-365)) (-5 *2 (-679 *5)) (-5 *1 (-868 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 (-634 *2))) (-5 *4 (-634 *5)) (-4 *5 (-43 (-409 (-568)))) (-4 *2 (-1234 *5)) (-5 *1 (-1236 *5 *2))))) 
+(((*1 *1) (-12 (-4 *1 (-327 *2)) (-4 *2 (-370)) (-4 *2 (-365)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1244 *4)) (-5 *1 (-532 *4)) (-4 *4 (-350))))) 
+(((*1 *1 *1 *1) (-5 *1 (-215))) ((*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-381))) (-5 *1 (-1039)))) ((*1 *1 *1 *1) (-4 *1 (-1124)))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-558)) (-4 *4 (-842)) (-5 *1 (-577 *4 *2)) (-4 *2 (-432 *4))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-1108)) (-5 *1 (-113)))) ((*1 *2 *1) (-12 (-4 *1 (-138)) (-5 *2 (-763)))) ((*1 *2 *3 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-375 *3)) (-4 *3 (-1195)) (-4 *3 (-1090)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-375 *3)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-568)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (-4 *1 (-375 *4)) (-4 *4 (-1195)) (-5 *2 (-568)))) ((*1 *2 *3 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-568)) (-5 *3 (-142)))) ((*1 *2 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-568))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-288 (-835 *3))) (-4 *3 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (-835 *3) (-2 (|:| |leftHandLimit| (-3 (-835 *3) "failed")) (|:| |rightHandLimit| (-3 (-835 *3) "failed"))) "failed")) (-5 *1 (-627 *5 *3)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-288 *3)) (-5 *5 (-1143)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-835 *3)) (-5 *1 (-627 *6 *3)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-288 (-835 (-953 *5)))) (-4 *5 (-453)) (-5 *2 (-3 (-835 (-409 (-953 *5))) (-2 (|:| |leftHandLimit| (-3 (-835 (-409 (-953 *5))) "failed")) (|:| |rightHandLimit| (-3 (-835 (-409 (-953 *5))) "failed"))) "failed")) (-5 *1 (-628 *5)) (-5 *3 (-409 (-953 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-288 (-409 (-953 *5)))) (-5 *3 (-409 (-953 *5))) (-4 *5 (-453)) (-5 *2 (-3 (-835 *3) (-2 (|:| |leftHandLimit| (-3 (-835 *3) "failed")) (|:| |rightHandLimit| (-3 (-835 *3) "failed"))) "failed")) (-5 *1 (-628 *5)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-288 (-409 (-953 *6)))) (-5 *5 (-1143)) (-5 *3 (-409 (-953 *6))) (-4 *6 (-453)) (-5 *2 (-835 *3)) (-5 *1 (-628 *6))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-634 (-541))) (-5 *2 (-1161)) (-5 *1 (-541))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-381)))) ((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-381))))) 
-(((*1 *2 *2) (|partial| -12 (-5 *1 (-561 *2)) (-4 *2 (-550))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-842)) (-5 *2 (-634 (-656 *4 *5))) (-5 *1 (-618 *4 *5 *6)) (-4 *5 (-13 (-172) (-707 (-409 (-568))))) (-14 *6 (-917))))) 
-(((*1 *2) (-12 (-5 *2 (-1244 (-634 (-2 (|:| -2850 (-905 *3)) (|:| -4355 (-1108)))))) (-5 *1 (-352 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917)))) ((*1 *2) (-12 (-5 *2 (-1244 (-634 (-2 (|:| -2850 *3) (|:| -4355 (-1108)))))) (-5 *1 (-353 *3 *4)) (-4 *3 (-350)) (-14 *4 (-3 (-1157 *3) *2)))) ((*1 *2) (-12 (-5 *2 (-1244 (-634 (-2 (|:| -2850 *3) (|:| -4355 (-1108)))))) (-5 *1 (-354 *3 *4)) (-4 *3 (-350)) (-14 *4 (-917))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-121)) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-4 *3 (-13 (-27) (-1181) (-432 *6) (-10 -8 (-15 -2745 ($ *7))))) (-4 *7 (-840)) (-4 *8 (-13 (-1221 *3 *7) (-365) (-1181) (-10 -8 (-15 -4189 ($ $)) (-15 -3837 ($ $))))) (-5 *2 (-3 (|:| |%series| *8) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143)))))) (-5 *1 (-424 *6 *3 *7 *8 *9 *10)) (-5 *5 (-1143)) (-4 *9 (-984 *8)) (-14 *10 (-1161))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-763)) (-5 *5 (-634 *3)) (-4 *3 (-301)) (-4 *6 (-842)) (-4 *7 (-788)) (-5 *2 (-121)) (-5 *1 (-617 *6 *7 *3 *8)) (-4 *8 (-950 *3 *7 *6))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-818)) (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-420 *3)) (-4 *3 (-558)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3850 *4) (|:| -1836 (-568))))) (-4 *4 (-1219 (-568))) (-5 *2 (-763)) (-5 *1 (-443 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1182 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *3 *3 *3) (|partial| -12 (-4 *4 (-13 (-150) (-27) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-1157 (-409 *5))) (-5 *1 (-610 *4 *5)) (-5 *3 (-409 *5)))) ((*1 *2 *3 *3 *3 *4) (|partial| -12 (-5 *4 (-1 (-420 *6) *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-150) (-27) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-1157 (-409 *6))) (-5 *1 (-610 *5 *6)) (-5 *3 (-409 *6))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) ((*1 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217))))) 
+(((*1 *2 *3 *3 *4) (-12 (-5 *3 (-763)) (-4 *2 (-13 (-558) (-453))) (-5 *1 (-346 *2 *4)) (-4 *4 (-52 *2 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |k| (-1161)) (|:| |c| (-1264 *3))))) (-5 *1 (-1264 *3)) (-4 *3 (-1047)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |k| *3) (|:| |c| (-1266 *3 *4))))) (-5 *1 (-1266 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-439))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1163 (-409 (-568)))) (-5 *2 (-409 (-568))) (-5 *1 (-182))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-842)) (-5 *1 (-1167 *3))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-1195)) (-5 *1 (-179 *3 *2)) (-4 *2 (-665 *3))))) 
 (((*1 *1 *1) (-12 (-4 *1 (-235 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-1083 *3)) (-4 *3 (-1195)) (-5 *2 (-568))))) 
-(((*1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1219 *3)) (-4 *3 (-1047))))) 
 (((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-4 *1 (-1087 *3)))) ((*1 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-981 *2)) (-4 *2 (-1047)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-944 (-215))) (-5 *1 (-1192)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-1047))))) 
-(((*1 *2 *3 *3 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-1 (-634 *4) *4)) (-5 *1 (-107 *4)) (-5 *3 (-634 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-4 *1 (-37 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-365)) (-5 *2 (-634 *3)))) ((*1 *1 *2) (-12 (-4 *1 (-43 *2)) (-4 *2 (-172)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-365)) (-14 *6 (-1244 (-679 *3))) (-5 *1 (-49 *3 *4 *5 *6)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))))) ((*1 *1 *2) (-12 (-5 *2 (-1113 (-568) (-607 (-53)))) (-5 *1 (-53)))) ((*1 *2 *3) (-12 (-5 *2 (-57)) (-5 *1 (-56 *3)) (-4 *3 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287 (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (-4287) (-688)))) (-5 *1 (-66 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287) (-4287 (QUOTE XC)) (-688)))) (-5 *1 (-68 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-337 (-4287 (QUOTE X)) (-4287) (-688))) (-5 *1 (-69 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-679 (-337 (-4287) (-4287 (QUOTE X) (QUOTE HESS)) (-688)))) (-5 *1 (-70 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-337 (-4287) (-4287 (QUOTE XC)) (-688))) (-5 *1 (-71 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287 (QUOTE X)) (-4287 (QUOTE -2926)) (-688)))) (-5 *1 (-76 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287) (-4287 (QUOTE X)) (-688)))) (-5 *1 (-79 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287 (QUOTE X) (QUOTE EPS)) (-4287 (QUOTE -2926)) (-688)))) (-5 *1 (-80 *3 *4 *5)) (-14 *3 (-1161)) (-14 *4 (-1161)) (-14 *5 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287 (QUOTE EPS)) (-4287 (QUOTE YA) (QUOTE YB)) (-688)))) (-5 *1 (-81 *3 *4 *5)) (-14 *3 (-1161)) (-14 *4 (-1161)) (-14 *5 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-337 (-4287) (-4287 (QUOTE X)) (-688))) (-5 *1 (-82 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-337 (-4287) (-4287 (QUOTE X)) (-688))) (-5 *1 (-83 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287) (-4287 (QUOTE XC)) (-688)))) (-5 *1 (-84 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287) (-4287 (QUOTE X)) (-688)))) (-5 *1 (-85 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287) (-4287 (QUOTE X)) (-688)))) (-5 *1 (-86 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287 (QUOTE X) (QUOTE -2926)) (-4287) (-688)))) (-5 *1 (-87 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-679 (-337 (-4287 (QUOTE X) (QUOTE -2926)) (-4287) (-688)))) (-5 *1 (-88 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-679 (-337 (-4287 (QUOTE X)) (-4287) (-688)))) (-5 *1 (-89 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287 (QUOTE X)) (-4287) (-688)))) (-5 *1 (-90 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4287 (QUOTE X)) (-4287 (QUOTE -2926)) (-688)))) (-5 *1 (-91 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-679 (-337 (-4287 (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (-4287) (-688)))) (-5 *1 (-92 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-337 (-4287 (QUOTE X)) (-4287 (QUOTE -2926)) (-688))) (-5 *1 (-94 *3)) (-14 *3 (-1161)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-1004 2)) (-5 *1 (-112)))) ((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-112)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-4 *1 (-117)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-141 *3 *4 *5))) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 (-763)) (-4 *5 (-172)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *5)) (-4 *5 (-172)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 (-763)))) ((*1 *1 *2) (-12 (-5 *2 (-1127 *4 *5)) (-14 *4 (-763)) (-4 *5 (-172)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)))) ((*1 *1 *2) (-12 (-5 *2 (-232 *4 *5)) (-14 *4 (-763)) (-4 *5 (-172)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)))) ((*1 *2 *3) (-12 (-5 *3 (-1244 (-679 *4))) (-4 *4 (-172)) (-5 *2 (-1244 (-679 (-409 (-953 *4))))) (-5 *1 (-181 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-13 (-842) (-10 -8 (-15 -2779 ((-1143) $ (-1161))) (-15 -4125 ((-1249) $)) (-15 -1352 ((-1249) $))))) (-5 *1 (-205 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1004 10)) (-5 *1 (-208)))) ((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-208)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-233 *3)) (-4 *3 (-1047)))) ((*1 *1 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-233 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1 *3 (-917))) (-5 *1 (-233 *3)) (-4 *3 (-1047)))) ((*1 *1 *2) (-12 (-5 *2 (-1 *3 (-917))) (-4 *3 (-1047)) (-5 *1 (-233 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-240 *3)) (-4 *3 (-842)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-240 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1082 (-310 *4))) (-4 *4 (-13 (-842) (-558) (-609 (-381)))) (-5 *2 (-1082 (-381))) (-5 *1 (-251 *4)))) ((*1 *1 *2) (-12 (-4 *1 (-262 *2)) (-4 *2 (-842)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-271)))) ((*1 *2 *1) (-12 (-4 *2 (-1219 *3)) (-5 *1 (-284 *3 *2 *4 *5 *6 *7)) (-4 *3 (-172)) (-4 *4 (-23)) (-14 *5 (-1 *2 *2 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-1228 *4 *5 *6)) (-4 *4 (-13 (-27) (-1181) (-432 *3))) (-14 *5 (-1161)) (-14 *6 *4) (-4 *3 (-13 (-842) (-1037 (-568)) (-630 (-568)) (-453))) (-5 *1 (-307 *3 *4 *5 *6)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-328)))) ((*1 *2 *1) (-12 (-5 *2 (-310 *5)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *2 *3) (-12 (-4 *4 (-350)) (-4 *2 (-327 *4)) (-5 *1 (-348 *3 *4 *2)) (-4 *3 (-327 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-350)) (-4 *2 (-327 *4)) (-5 *1 (-348 *2 *4 *3)) (-4 *3 (-327 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *2 (-1266 *3 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *2 (-1257 *3 *4)))) ((*1 *1 *2) (-12 (-4 *1 (-376 *2 *3)) (-4 *2 (-842)) (-4 *3 (-172)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) (-4 *1 (-385)))) ((*1 *1 *2) (-12 (-5 *2 (-328)) (-4 *1 (-385)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-4 *1 (-385)))) ((*1 *1 *2) (-12 (-5 *2 (-679 (-688))) (-4 *1 (-385)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) (-4 *1 (-386)))) ((*1 *1 *2) (-12 (-5 *2 (-328)) (-4 *1 (-386)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-4 *1 (-386)))) ((*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-1143)))) ((*1 *1 *2) (-12 (-5 *2 (-1143)) (-4 *1 (-391)))) ((*1 *2 *3) (-12 (-5 *2 (-396)) (-5 *1 (-395 *3)) (-4 *3 (-1090)))) ((*1 *1 *2) (-12 (-5 *2 (-850)) (-5 *1 (-396)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) (-4 *1 (-398)))) ((*1 *1 *2) (-12 (-5 *2 (-328)) (-4 *1 (-398)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-4 *1 (-398)))) ((*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-169 (-381))))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-381)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-568)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-169 (-381)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-381))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-568))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-683)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-688)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-690)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-683))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-688))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-690))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-328)) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-329 *4)) (-4 *4 (-13 (-842) (-21))) (-5 *1 (-429 *3 *4)) (-4 *3 (-13 (-172) (-43 (-409 (-568))))))) ((*1 *1 *2) (-12 (-5 *1 (-429 *2 *3)) (-4 *2 (-13 (-172) (-43 (-409 (-568))))) (-4 *3 (-13 (-842) (-21))))) ((*1 *1 *2) (-12 (-5 *2 (-409 (-953 (-409 *3)))) (-4 *3 (-558)) (-4 *3 (-842)) (-4 *1 (-432 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-953 (-409 *3))) (-4 *3 (-558)) (-4 *3 (-842)) (-4 *1 (-432 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-409 *3)) (-4 *3 (-558)) (-4 *3 (-842)) (-4 *1 (-432 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1113 *3 (-607 *1))) (-4 *3 (-1047)) (-4 *3 (-842)) (-4 *1 (-432 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1094)) (-5 *1 (-436)))) ((*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-436)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-436)))) ((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-436)))) ((*1 *1 *2) (-12 (-5 *2 (-436)) (-5 *1 (-439)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-439)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) (-4 *1 (-441)))) ((*1 *1 *2) (-12 (-5 *2 (-328)) (-4 *1 (-441)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-4 *1 (-441)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-688))) (-4 *1 (-441)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2845 (-634 (-328))))) (-4 *1 (-442)))) ((*1 *1 *2) (-12 (-5 *2 (-328)) (-4 *1 (-442)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-4 *1 (-442)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-409 (-953 *3)))) (-4 *3 (-172)) (-14 *6 (-1244 (-679 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *1 (-473)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-473)))) ((*1 *1 *2) (-12 (-5 *2 (-1228 *3 *4 *5)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3) (-5 *1 (-479 *3 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-479 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-1004 16)) (-5 *1 (-497)))) ((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-497)))) ((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-500)))) ((*1 *1 *2) (-12 (-5 *2 (-1113 (-568) (-607 (-504)))) (-5 *1 (-504)))) ((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-511)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6)))) ((*1 *1 *2) (-12 (-4 *3 (-172)) (-5 *1 (-602 *3 *2)) (-4 *2 (-736 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-608 *2)) (-4 *2 (-1195)))) ((*1 *1 *2) (-12 (-4 *1 (-612 *2)) (-4 *2 (-1047)))) ((*1 *2 *1) (-12 (-5 *2 (-1262 *3 *4)) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917)))) ((*1 *2 *1) (-12 (-5 *2 (-1257 *3 *4)) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917)))) ((*1 *1 *2) (-12 (-4 *3 (-172)) (-5 *1 (-626 *3 *2)) (-4 *2 (-736 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-641 *3)) (-4 *3 (-365)) (-5 *2 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *3)))))) ((*1 *1 *2) (-12 (-5 *2 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *3)))) (-4 *3 (-365)) (-4 *1 (-641 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-667 *3)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-814 *3)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-958 (-958 (-958 *3)))) (-5 *1 (-666 *3)) (-4 *3 (-1090)))) ((*1 *1 *2) (-12 (-5 *2 (-958 (-958 (-958 *3)))) (-4 *3 (-1090)) (-5 *1 (-666 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-814 *3)) (-5 *1 (-667 *3)) (-4 *3 (-842)))) ((*1 *2 *3) (-12 (-5 *2 (-1 *3)) (-5 *1 (-671 *3)) (-4 *3 (-1090)))) ((*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *2)) (-4 *4 (-375 *3)) (-4 *2 (-375 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-169 (-381))) (-5 *1 (-683)))) ((*1 *1 *2) (-12 (-5 *2 (-169 (-690))) (-5 *1 (-683)))) ((*1 *1 *2) (-12 (-5 *2 (-169 (-688))) (-5 *1 (-683)))) ((*1 *1 *2) (-12 (-5 *2 (-169 (-568))) (-5 *1 (-683)))) ((*1 *1 *2) (-12 (-5 *2 (-169 (-381))) (-5 *1 (-683)))) ((*1 *1 *2) (-12 (-5 *2 (-690)) (-5 *1 (-688)))) ((*1 *2 *1) (-12 (-5 *2 (-381)) (-5 *1 (-688)))) ((*1 *2 *3) (-12 (-5 *3 (-310 (-568))) (-5 *2 (-310 (-690))) (-5 *1 (-690)))) ((*1 *1 *2) (-12 (-5 *1 (-692 *2)) (-4 *2 (-1090)))) ((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-700)))) ((*1 *2 *1) (-12 (-4 *2 (-172)) (-5 *1 (-701 *2 *3 *4 *5 *6)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-702 *3 *2)) (-4 *2 (-1219 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-2 (|:| -4355 *3) (|:| -3438 *4))) (-5 *1 (-703 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-1090)) (-14 *5 (-1 (-121) *2 *2)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| -4355 *3) (|:| -3438 *4))) (-4 *3 (-842)) (-4 *4 (-1090)) (-5 *1 (-703 *3 *4 *5)) (-14 *5 (-1 (-121) *2 *2)))) ((*1 *2 *1) (-12 (-4 *2 (-172)) (-5 *1 (-705 *2 *3 *4 *5 *6)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -2348 *3) (|:| -2354 *4)))) (-4 *3 (-1047)) (-4 *4 (-716)) (-5 *1 (-725 *3 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-409 (-734 *3 *4))) (-14 *3 (-1161)) (-4 *4 (-13 (-1047) (-842) (-558))) (-5 *1 (-733 *3 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-953 *4)) (-4 *4 (-1047)) (-5 *1 (-734 *3 *4)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1240 *3)) (-14 *3 (-1161)) (-5 *1 (-734 *3 *4)) (-4 *4 (-1047)))) ((*1 *1 *2) (-12 (-5 *1 (-734 *3 *2)) (-14 *3 (-1161)) (-4 *2 (-1047)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-755)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (|:| |nia| (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| |mdnia| (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))))) (-5 *1 (-761)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *1 (-761)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *1 (-761)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-761)))) ((*1 *2 *3) (-12 (-5 *2 (-766)) (-5 *1 (-765 *3)) (-4 *3 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *1 (-803)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-803)))) ((*1 *2 *1) (-12 (-4 *2 (-895 *3)) (-5 *1 (-812 *3 *2 *4)) (-4 *3 (-1090)) (-14 *4 *3))) ((*1 *1 *2) (-12 (-4 *3 (-1090)) (-14 *4 *3) (-5 *1 (-812 *3 *2 *4)) (-4 *2 (-895 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-819)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))))) (-5 *1 (-833)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) (-5 *1 (-833)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (-5 *1 (-833)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-833)))) ((*1 *1 *2) (-12 (-5 *2 (-1240 *3)) (-14 *3 (-1161)) (-5 *1 (-847 *3 *4 *5 *6)) (-4 *4 (-1047)) (-14 *5 (-101 *4)) (-14 *6 (-1 *4 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-849)))) ((*1 *1 *2) (-12 (-5 *2 (-953 *3)) (-4 *3 (-1047)) (-5 *1 (-853 *3 *4 *5 *6)) (-14 *4 (-634 (-1161))) (-14 *5 (-634 (-763))) (-14 *6 (-763)))) ((*1 *2 *1) (-12 (-5 *2 (-953 *3)) (-5 *1 (-853 *3 *4 *5 *6)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))) (-14 *5 (-634 (-763))) (-14 *6 (-763)))) ((*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869)))) ((*1 *2 *3) (-12 (-5 *3 (-953 (-53))) (-5 *2 (-310 (-568))) (-5 *1 (-870)))) ((*1 *2 *3) (-12 (-5 *3 (-409 (-953 (-53)))) (-5 *2 (-310 (-568))) (-5 *1 (-870)))) ((*1 *1 *2) (-12 (-5 *1 (-888 *2)) (-4 *2 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-814 *3)) (-5 *1 (-888 *3)) (-4 *3 (-842)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) (-5 *1 (-893)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-893)))) ((*1 *2 *1) (-12 (-5 *2 (-1182 *3)) (-5 *1 (-896 *3)) (-4 *3 (-1090)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-900 *3))) (-4 *3 (-1090)) (-5 *1 (-899 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-900 *3))) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-900 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-1090)) (-5 *1 (-900 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-409 (-420 *3))) (-4 *3 (-301)) (-5 *1 (-910 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-409 *3)) (-5 *1 (-910 *3)) (-4 *3 (-301)))) ((*1 *2 *3) (-12 (-5 *3 (-489)) (-5 *2 (-310 *4)) (-5 *1 (-915 *4)) (-4 *4 (-13 (-842) (-558))))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-4 *1 (-971 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-634 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-972)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568)))) ((*1 *2 *3) (-12 (-5 *2 (-1249)) (-5 *1 (-1033 *3)) (-4 *3 (-1195)))) ((*1 *2 *3) (-12 (-5 *3 (-305)) (-5 *1 (-1033 *2)) (-4 *2 (-1195)))) ((*1 *1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-1034 *3 *4 *5 *2 *6)) (-4 *2 (-950 *3 *4 *5)) (-14 *6 (-634 *2)))) ((*1 *1 *2) (-12 (-4 *1 (-1037 *2)) (-4 *2 (-1195)))) ((*1 *2 *3) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-1042 *3)) (-4 *3 (-558)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-1047)))) ((*1 *2 *1) (-12 (-5 *2 (-679 *5)) (-5 *1 (-1051 *3 *4 *5)) (-14 *3 (-763)) (-14 *4 (-763)) (-4 *5 (-1047)))) ((*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-842)) (-5 *1 (-1114 *3 *4 *2)) (-4 *2 (-950 *3 (-534 *4) *4)))) ((*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *2 (-842)) (-5 *1 (-1114 *3 *2 *4)) (-4 *4 (-950 *3 (-534 *2) *2)))) ((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-850)))) ((*1 *2 *1) (-12 (-5 *2 (-679 *4)) (-5 *1 (-1127 *3 *4)) (-14 *3 (-763)) (-4 *4 (-1047)))) ((*1 *1 *2) (-12 (-5 *2 (-147)) (-4 *1 (-1129)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-1141 *3)))) ((*1 *2 *3) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-1145 *3)) (-4 *3 (-1047)))) ((*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1151 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1158 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1159 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1216 *4 *3)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3) (-5 *1 (-1159 *3 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1160)))) ((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1161)))) ((*1 *2 *1) (-12 (-5 *2 (-1169 (-1161) (-439))) (-5 *1 (-1165)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1168 *3)) (-4 *3 (-1090)))) ((*1 *2 *3) (-12 (-5 *2 (-1176)) (-5 *1 (-1175 *3)) (-4 *3 (-1090)))) ((*1 *1 *2) (-12 (-5 *2 (-850)) (-5 *1 (-1176)))) ((*1 *1 *2) (-12 (-5 *2 (-953 *3)) (-4 *3 (-1047)) (-5 *1 (-1190 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1190 *3)) (-4 *3 (-1047)))) ((*1 *1 *2) (-12 (-5 *2 (-958 *3)) (-4 *3 (-1195)) (-5 *1 (-1193 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1240 (QUOTE |x|))) (-5 *1 (-1201 *3)) (-4 *3 (-1047)))) ((*1 *1 *2) (-12 (-5 *2 (-1216 (QUOTE |x|) *3)) (-4 *3 (-1047)) (-5 *1 (-1201 *3)))) ((*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *1 (-1205 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1207 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1084 *3)) (-4 *3 (-1195)) (-5 *1 (-1210 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1240 *3)) (-14 *3 (-1161)) (-5 *1 (-1216 *3 *4)) (-4 *4 (-1047)))) ((*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *1 (-1226 *3 *2)) (-4 *2 (-1203 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1228 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1216 *4 *3)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3) (-5 *1 (-1235 *3 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-1047)))) ((*1 *1 *2) (-12 (-5 *2 (-1216 *4 *3)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-5 *1 (-1239 *3 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-1240 *3)) (-14 *3 *2))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1245)))) ((*1 *2 *3) (-12 (-5 *3 (-473)) (-5 *2 (-1245)) (-5 *1 (-1248)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1249)))) ((*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-788)) (-14 *6 (-634 *4)) (-5 *1 (-1254 *3 *4 *5 *2 *6 *7 *8)) (-4 *2 (-950 *3 *5 *4)) (-14 *7 (-634 (-763))) (-14 *8 (-763)))) ((*1 *2 *1) (-12 (-4 *2 (-950 *3 *5 *4)) (-5 *1 (-1254 *3 *4 *5 *2 *6 *7 *8)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-788)) (-14 *6 (-634 *4)) (-14 *7 (-634 (-763))) (-14 *8 (-763)))) ((*1 *1 *2) (-12 (-4 *1 (-1256 *2)) (-4 *2 (-1047)))) ((*1 *1 *2) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) ((*1 *2 *1) (-12 (-5 *2 (-1266 *3 *4)) (-5 *1 (-1262 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) ((*1 *2 *1) (-12 (-5 *2 (-1257 *3 *4)) (-5 *1 (-1262 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) ((*1 *1 *2) (-12 (-5 *2 (-656 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *1 (-1262 *3 *4)))) ((*1 *1 *2) (-12 (-5 *1 (-1265 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-838))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1090)) (-5 *2 (-1249)) (-5 *1 (-1196 *4)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1090)) (-5 *2 (-1249)) (-5 *1 (-1196 *4))))) 
-(((*1 *2 *2) (|partial| -12 (-5 *1 (-586 *2)) (-4 *2 (-550))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1149 3 (-215))) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-306))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-634 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-634 *5))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 *4 *5)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-1 *6 *5)) (-5 *1 (-673 *4 *5 *6))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-685 *2)) (-4 *2 (-1219 *3))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 (-2 (|:| |val| (-634 *6)) (|:| -3001 *7)))) (-4 *6 (-1061 *3 *4 *5)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-989 *3 *4 *5 *6 *7)))) ((*1 *2 *2) (-12 (-5 *2 (-634 (-2 (|:| |val| (-634 *6)) (|:| -3001 *7)))) (-4 *6 (-1061 *3 *4 *5)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-1097 *3 *4 *5 *6 *7))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-712)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-716)) (-5 *2 (-121))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 *5)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 (-763)) (-4 *5 (-172))))) 
-(((*1 *2 *3) (-12 (|has| *2 (-6 (-4521 "*"))) (-4 *5 (-375 *2)) (-4 *6 (-375 *2)) (-4 *2 (-1047)) (-5 *1 (-108 *2 *3 *4 *5 *6)) (-4 *3 (-1219 *2)) (-4 *4 (-677 *2 *5 *6))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-634 (-2 (|:| -3700 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| *8) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 *8))))) (-5 *1 (-924 *5 *6 *7 *8)) (-5 *4 (-763))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1161)) (-4 *5 (-609 (-887 (-568)))) (-4 *5 (-881 (-568))) (-4 *5 (-13 (-842) (-1037 (-568)) (-453) (-630 (-568)))) (-5 *2 (-2 (|:| |special| *3) (|:| |integrand| *3))) (-5 *1 (-571 *5 *3)) (-4 *3 (-620)) (-4 *3 (-13 (-27) (-1181) (-432 *5)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-817)) (-5 *1 (-816))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381)))) (-5 *1 (-798))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1157 (-409 (-953 *3)))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *7 (-230 (-1697 *6) (-763))) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 *8)) (-5 *1 (-963 *5 *6 *3 *7 *8)) (-4 *8 (-971 *5))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-950 *4 *5 *6)) (-5 *2 (-634 (-634 *7))) (-5 *1 (-449 *4 *5 *6 *7)) (-5 *3 (-634 *7)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-950 *5 *6 *7)) (-5 *2 (-634 (-634 *8))) (-5 *1 (-449 *5 *6 *7 *8)) (-5 *3 (-634 *8)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-950 *4 *5 *6)) (-5 *2 (-634 (-634 *7))) (-5 *1 (-449 *4 *5 *6 *7)) (-5 *3 (-634 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-950 *5 *6 *7)) (-5 *2 (-634 (-634 *8))) (-5 *1 (-449 *5 *6 *7 *8)) (-5 *3 (-634 *8))))) 
-(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160))))) 
-(((*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-763)) (-4 *5 (-172)))) ((*1 *1 *1 *2 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-763)) (-4 *5 (-172)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568))))) (-5 *3 (-634 (-852 *4))) (-14 *4 (-634 (-1161))) (-14 *5 (-763)) (-5 *1 (-515 *4 *5))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-453)))) ((*1 *1 *1 *1) (-4 *1 (-453))) ((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-5 *1 (-496 *2)) (-4 *2 (-1219 (-568))))) ((*1 *2 *2 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-685 *2)) (-4 *2 (-1219 *3)))) ((*1 *1 *1 *1) (-5 *1 (-763))) ((*1 *2 *2 *2) (-12 (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-301)) (-5 *1 (-912 *3 *4 *5 *2)) (-4 *2 (-950 *5 *3 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *6 *4 *5)) (-5 *1 (-912 *4 *5 *6 *2)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1157 *6)) (-4 *6 (-950 *5 *3 *4)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-301)) (-5 *1 (-912 *3 *4 *5 *6)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-1157 *7))) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)) (-5 *2 (-1157 *7)) (-5 *1 (-912 *4 *5 *6 *7)) (-4 *7 (-950 *6 *4 *5)))) ((*1 *1 *1 *1) (-5 *1 (-917))) ((*1 *2 *2 *2) (-12 (-4 *3 (-453)) (-4 *3 (-558)) (-5 *1 (-970 *3 *2)) (-4 *2 (-1219 *3)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-910 *2)) (-4 *2 (-301))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-568)) (|has| *1 (-6 -4510)) (-4 *1 (-406)) (-5 *2 (-917))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-99)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-99))))) 
-(((*1 *2 *3 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-3 *3 (-634 *1))) (-4 *1 (-1066 *4 *5 *6 *3))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 (-953 *3))) (-4 *3 (-453)) (-5 *1 (-362 *3 *4)) (-14 *4 (-634 (-1161))))) ((*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-451 *3 *4 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-1143)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-451 *4 *5 *6 *7)))) ((*1 *2 *2 *3 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-1143)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-451 *4 *5 *6 *7)))) ((*1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-950 *3 *5 *6)) (-4 *3 (-365)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-560 *3 *4 *5 *6 *7)) (-14 *4 (-634 (-1161))))) ((*1 *2 *2) (-12 (-5 *2 (-634 (-775 *3 (-852 *4)))) (-4 *3 (-453)) (-14 *4 (-634 (-1161))) (-5 *1 (-619 *3 *4))))) 
-(((*1 *1 *1) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-860)) (-5 *1 (-855 *3)) (-14 *3 *2)))) 
-(((*1 *2 *3) (-12 (-4 *1 (-340 *4 *3 *5)) (-4 *4 (-1199)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 (-409 *3))) (-5 *2 (-121)))) ((*1 *2 *3) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-607 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4))) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *4 *2))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-150))) (-5 *1 (-542 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-4 *4 (-1219 *3)) (-4 *5 (-714 *3 *4)) (-5 *1 (-546 *3 *4 *5 *2)) (-4 *2 (-1234 *5)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-5 *1 (-547 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-13 (-558) (-150))) (-5 *1 (-1137 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-301)) (-5 *2 (-763))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-1157 *7)) (-5 *3 (-568)) (-4 *7 (-950 *6 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-5 *1 (-318 *4 *5 *6 *7))))) 
-(((*1 *2 *3 *1) (-12 (-4 *4 (-13 (-840) (-365))) (-5 *2 (-121)) (-5 *1 (-1057 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *2) (|partial| -12 (-5 *2 (-409 *4)) (-4 *4 (-1219 *3)) (-4 *3 (-13 (-365) (-150) (-1037 (-568)))) (-5 *1 (-572 *3 *4))))) 
-(((*1 *2 *3 *1) (-12 (-4 *1 (-977 *4 *5 *6 *3)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4)))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))))) ((*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161))))) ((*1 *1) (-12 (-4 *1 (-327 *2)) (-4 *2 (-370)) (-4 *2 (-365)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-333 *3 *4 *5 *2)) (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *2 (-340 *3 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-392 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-172)))) ((*1 *1) (-12 (-4 *2 (-172)) (-4 *1 (-714 *2 *3)) (-4 *3 (-1219 *2))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1257 (-1161) *3)) (-4 *3 (-1047)) (-5 *1 (-1264 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1257 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *1 (-1266 *3 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-121)) (-5 *2 (-1143)) (-5 *1 (-57))))) 
-(((*1 *2 *3 *3 *3 *3) (-12 (-5 *3 (-568)) (-5 *2 (-121)) (-5 *1 (-491))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-350)) (-5 *2 (-1157 *4)) (-5 *1 (-532 *4))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-646 *3)) (-4 *3 (-1047)) (-4 *3 (-365)))) ((*1 *2 *2 *3 *4) (-12 (-5 *3 (-763)) (-5 *4 (-1 *5 *5)) (-4 *5 (-365)) (-5 *1 (-649 *5 *2)) (-4 *2 (-646 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1108)) (-5 *1 (-835 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1047)) (-5 *2 (-634 *1)) (-4 *1 (-1122 *3))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1216 *5 *4)) (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-634 *4)) (-5 *1 (-1104 *4 *5))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *7)) (-4 *7 (-842)) (-4 *5 (-904)) (-4 *6 (-788)) (-4 *8 (-950 *5 *6 *7)) (-5 *2 (-420 (-1157 *8))) (-5 *1 (-901 *5 *6 *7 *8)) (-5 *4 (-1157 *8)))) ((*1 *2 *3) (-12 (-4 *4 (-904)) (-4 *5 (-1219 *4)) (-5 *2 (-420 (-1157 *5))) (-5 *1 (-902 *4 *5)) (-5 *3 (-1157 *5))))) 
-(((*1 *2 *2 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1045))))) 
-(((*1 *2 *3 *4 *2 *5) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 (-887 *6))) (-5 *5 (-1 (-884 *6 *8) *8 (-887 *6) (-884 *6 *8))) (-4 *6 (-1090)) (-4 *8 (-13 (-1047) (-609 (-887 *6)) (-1037 *7))) (-5 *2 (-884 *6 *8)) (-4 *7 (-13 (-1047) (-842))) (-5 *1 (-942 *6 *7 *8))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-381))) (-5 *1 (-1039))))) 
-(((*1 *2 *2 *2) (-12 (-5 *1 (-160 *2)) (-4 *2 (-550))))) 
-(((*1 *1 *1 *1 *1) (-4 *1 (-550)))) 
-(((*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-365)) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-37 *4)) (-4 *4 (-365)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-166 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-420 *3)) (-4 *3 (-550)) (-4 *3 (-558)))) ((*1 *2 *1) (-12 (-4 *1 (-550)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-792 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-828 *3)) (-4 *3 (-550)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-835 *3)) (-4 *3 (-550)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-971 *4)) (-4 *4 (-365)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-997 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-121)))) ((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-1008 *3)) (-4 *3 (-1037 (-409 (-568))))))) 
-(((*1 *1) (-5 *1 (-147)))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 *4)) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1047)) (-5 *2 (-1244 *4)) (-5 *1 (-1162 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-5 *2 (-1244 *3)) (-5 *1 (-1162 *3)) (-4 *3 (-1047))))) 
-(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-328))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
-(((*1 *2 *1 *3) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1059)) (-5 *3 (-1143))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-679 *2)) (-4 *2 (-172)) (-5 *1 (-149 *2)))) ((*1 *2 *3) (-12 (-4 *4 (-172)) (-4 *2 (-1219 *4)) (-5 *1 (-175 *4 *2 *3)) (-4 *3 (-714 *4 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-679 (-409 (-953 *5)))) (-5 *4 (-1161)) (-5 *2 (-953 *5)) (-5 *1 (-286 *5)) (-4 *5 (-453)))) ((*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-953 *4)))) (-5 *2 (-953 *4)) (-5 *1 (-286 *4)) (-4 *4 (-453)))) ((*1 *2 *1) (-12 (-4 *1 (-372 *3 *2)) (-4 *3 (-172)) (-4 *2 (-1219 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-679 (-169 (-409 (-568))))) (-5 *2 (-953 (-169 (-409 (-568))))) (-5 *1 (-756 *4)) (-4 *4 (-13 (-365) (-840))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-679 (-169 (-409 (-568))))) (-5 *4 (-1161)) (-5 *2 (-953 (-169 (-409 (-568))))) (-5 *1 (-756 *5)) (-4 *5 (-13 (-365) (-840))))) ((*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-568)))) (-5 *2 (-953 (-409 (-568)))) (-5 *1 (-773 *4)) (-4 *4 (-13 (-365) (-840))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-679 (-409 (-568)))) (-5 *4 (-1161)) (-5 *2 (-953 (-409 (-568)))) (-5 *1 (-773 *5)) (-4 *5 (-13 (-365) (-840)))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-121) *6 *6)) (-4 *6 (-842)) (-5 *4 (-634 *6)) (-5 *2 (-2 (|:| |fs| (-121)) (|:| |sd| *4) (|:| |td| (-634 *4)))) (-5 *1 (-1167 *6)) (-5 *5 (-634 *4))))) 
-(((*1 *1 *1 *2) (|partial| -12 (-5 *2 (-917)) (-5 *1 (-1091 *3 *4)) (-14 *3 *2) (-14 *4 *2)))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *1 (-799 *4 *2)) (-4 *2 (-13 (-29 *4) (-1181) (-959)))))) 
-(((*1 *2 *3 *1) (|partial| -12 (-4 *1 (-605 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-392 *3 *4 *5)) (-14 *3 (-763)) (-14 *4 (-763)) (-4 *5 (-172))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *3 (-1047)) (-4 *3 (-842)) (-5 *2 (-2 (|:| |val| *1) (|:| -3438 (-568)))) (-4 *1 (-432 *3)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |val| (-887 *3)) (|:| -3438 (-887 *3)))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-2 (|:| |val| *3) (|:| -3438 (-568)))) (-5 *1 (-951 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2745 ($ *7)) (-15 -2317 (*7 $)) (-15 -2324 (*7 $)))))))) 
-(((*1 *1) (-4 *1 (-23))) ((*1 *1) (-4 *1 (-39))) ((*1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) ((*1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172)))) ((*1 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) ((*1 *1) (-4 *1 (-716))) ((*1 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) ((*1 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) ((*1 *1) (-5 *1 (-1161)))) 
-(((*1 *2 *2) (-12 (-4 *3 (-453)) (-4 *3 (-842)) (-4 *3 (-1037 (-568))) (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-432 *3)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2317 ((-1113 *3 (-607 $)) $)) (-15 -2324 ((-1113 *3 (-607 $)) $)) (-15 -2745 ($ (-1113 *3 (-607 $)))))))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-453)) (-4 *3 (-842)) (-4 *3 (-1037 (-568))) (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-432 *3)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2317 ((-1113 *3 (-607 $)) $)) (-15 -2324 ((-1113 *3 (-607 $)) $)) (-15 -2745 ($ (-1113 *3 (-607 $)))))))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-4 *1 (-555 *3)) (-4 *3 (-13 (-406) (-1181))))) ((*1 *1 *2) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181))))) ((*1 *1 *2 *2) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1697 *6) (-763))) (-5 *2 (-634 *8)) (-5 *1 (-31 *5 *6 *3 *7 *8)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1697 *6) (-763))) (-5 *2 (-3 (-634 *8) "failed" "Infinite" (-568))) (-5 *1 (-32 *5 *6 *3 *7 *8)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-57)) (-5 *1 (-824))))) 
-(((*1 *2 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-13 (-1047) (-707 (-409 (-568))))) (-4 *5 (-842)) (-5 *1 (-1258 *4 *5 *2)) (-4 *2 (-1263 *5 *4))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1697 *6) *4)) (-4 *9 (-971 *5)) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-4 *3 (-235 *11)) (-4 *12 (-536 *5 *6 *7 *8 *9 *10 *11 *3 *14)) (-4 *14 (-117)) (-5 *2 (-634 *7)) (-5 *1 (-467 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13 *14)) (-4 *13 (-258 *12)))) ((*1 *2 *3 *4 *5 *2) (-12 (-5 *2 (-634 *5)) (-4 *5 (-950 *6 *8 (-852 *7))) (-4 *8 (-230 (-1697 *7) *4)) (-5 *4 (-763)) (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *10 (-641 *6)) (-4 *11 (-920 *6 *10)) (-5 *1 (-562 *6 *7 *5 *8 *9 *10 *11 *3)) (-4 *9 (-971 *6)) (-4 *3 (-235 *11)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-236 (-922 *5))) (-5 *4 (-763)) (-4 *5 (-350)) (-5 *2 (-634 (-242 *6 *5))) (-5 *1 (-867 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-236 (-921 *5))) (-5 *4 (-763)) (-4 *5 (-365)) (-5 *2 (-634 (-242 *6 *5))) (-5 *1 (-868 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-129 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *1 (-129 *3)) (-4 *3 (-1219 (-568)))))) 
-(((*1 *1 *2 *3 *4) (-12 (-5 *2 (-634 *1)) (-5 *3 (-634 (-763))) (-5 *4 (-568)) (-4 *1 (-641 *5)) (-4 *5 (-365))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 *6)) (-4 *5 (-1090)) (-4 *6 (-1195)) (-5 *2 (-1 *6 *5)) (-5 *1 (-631 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 *2)) (-4 *5 (-1090)) (-4 *2 (-1195)) (-5 *1 (-631 *5 *2)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 *6)) (-5 *4 (-634 *5)) (-4 *6 (-1090)) (-4 *5 (-1195)) (-5 *2 (-1 *5 *6)) (-5 *1 (-631 *6 *5)))) ((*1 *2 *3 *4 *5 *2) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 *2)) (-4 *5 (-1090)) (-4 *2 (-1195)) (-5 *1 (-631 *5 *2)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-1 *6 *5)) (-5 *3 (-634 *5)) (-5 *4 (-634 *6)) (-4 *5 (-1090)) (-4 *6 (-1195)) (-5 *1 (-631 *5 *6)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 *2)) (-5 *6 (-1 *2 *5)) (-4 *5 (-1090)) (-4 *2 (-1195)) (-5 *1 (-631 *5 *2)))) ((*1 *2 *1 *1 *3) (-12 (-4 *1 (-1129)) (-5 *3 (-147)) (-5 *2 (-763))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-420 *3)) (-4 *3 (-558))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1864 *7) (|:| -4477 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *5 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *5))))) 
-(((*1 *2 *3 *3 *4) (-12 (-5 *4 (-634 (-310 (-215)))) (-5 *3 (-215)) (-5 *2 (-121)) (-5 *1 (-202))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-607 (-53)))) (-5 *1 (-53)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-607 (-53))) (-5 *1 (-53)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1157 (-53))) (-5 *3 (-634 (-607 (-53)))) (-5 *1 (-53)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1157 (-53))) (-5 *3 (-607 (-53))) (-5 *1 (-53)))) ((*1 *2 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)))) ((*1 *2 *3) (-12 (-4 *2 (-13 (-365) (-840))) (-5 *1 (-178 *2 *3)) (-4 *3 (-1219 (-169 *2))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)))) ((*1 *2 *1) (-12 (-4 *1 (-327 *2)) (-4 *2 (-365)))) ((*1 *2 *1) (-12 (-4 *1 (-372 *2 *3)) (-4 *3 (-1219 *2)) (-4 *2 (-172)))) ((*1 *2 *1) (-12 (-4 *4 (-1219 *2)) (-4 *2 (-993 *3)) (-5 *1 (-415 *3 *2 *4 *5)) (-4 *3 (-301)) (-4 *5 (-13 (-411 *2 *4) (-1037 *2))))) ((*1 *2 *1) (-12 (-4 *4 (-1219 *2)) (-4 *2 (-993 *3)) (-5 *1 (-416 *3 *2 *4 *5 *6)) (-4 *3 (-301)) (-4 *5 (-411 *2 *4)) (-14 *6 (-1244 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-1047)) (-4 *2 (-13 (-406) (-1037 *5) (-365) (-1181) (-279))) (-5 *1 (-444 *5 *3 *2)) (-4 *3 (-1219 *5)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-607 (-504)))) (-5 *1 (-504)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-607 (-504))) (-5 *1 (-504)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1157 (-504))) (-5 *3 (-634 (-607 (-504)))) (-5 *1 (-504)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1157 (-504))) (-5 *3 (-607 (-504))) (-5 *1 (-504)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-917)) (-4 *4 (-350)) (-5 *1 (-532 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-453)) (-4 *5 (-714 *4 *2)) (-4 *2 (-1219 *4)) (-5 *1 (-767 *4 *2 *5 *3)) (-4 *3 (-1219 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) ((*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172)))) ((*1 *1 *1) (-4 *1 (-1056)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-1244 (-688))) (-5 *1 (-299))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-568))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-568)) (-5 *1 (-450 *4 *5 *6 *3)) (-4 *3 (-950 *4 *5 *6))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-904)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-950 *4 *5 *6)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-901 *4 *5 *6 *7)) (-5 *3 (-1157 *7)))) ((*1 *2 *3) (-12 (-4 *4 (-904)) (-4 *5 (-1219 *4)) (-5 *2 (-420 (-1157 *5))) (-5 *1 (-902 *4 *5)) (-5 *3 (-1157 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568))))) 
-(((*1 *2 *3 *3 *2) (-12 (-5 *2 (-1141 *4)) (-5 *3 (-568)) (-4 *4 (-1047)) (-5 *1 (-1145 *4)))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1201 *3)) (-4 *3 (-1047)))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-1161))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-1219 *2)) (-4 *2 (-1199)) (-5 *1 (-151 *2 *4 *3)) (-4 *3 (-1219 (-409 *4)))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568))))) 
-(((*1 *1 *2 *3 *1) (-12 (-5 *2 (-887 *4)) (-4 *4 (-1090)) (-5 *1 (-884 *4 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-2 (|:| |num| (-1244 *4)) (|:| |den| *4)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4) (-12 (-4 *4 (-854)) (-5 *2 (-420 (-1157 *4))) (-5 *1 (-315 *4)) (-5 *3 (-1157 *4)))) ((*1 *2 *3 *4) (-12 (-4 *4 (-859)) (-5 *2 (-420 (-1157 *4))) (-5 *1 (-317 *4)) (-5 *3 (-1157 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-833)) (-5 *2 (-1035)) (-5 *1 (-832)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-310 (-381)))) (-5 *4 (-634 (-381))) (-5 *2 (-1035)) (-5 *1 (-832))))) 
-(((*1 *1) (-5 *1 (-798)))) 
-(((*1 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3)))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-634 (-763)))) (-5 *1 (-899 *3)) (-4 *3 (-1090))))) 
-(((*1 *1) (-5 *1 (-1245)))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-4 *1 (-37 *3))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-121)) (-5 *1 (-180 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 (-169 *4)))))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-121)) (-5 *1 (-1185 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-365)) (-5 *2 (-634 *3)) (-5 *1 (-946 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *4 *5 *6)) (-4 *4 (-365)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-451 *4 *5 *6 *2)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-101 *6)) (-5 *5 (-1 *6 *6)) (-4 *6 (-365)) (-5 *2 (-2 (|:| R (-679 *6)) (|:| A (-679 *6)) (|:| |Ainv| (-679 *6)))) (-5 *1 (-979 *6)) (-5 *3 (-679 *6))))) 
-(((*1 *2 *3 *1) (-12 (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3001 *1)))) (-4 *1 (-1066 *4 *5 *6 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-207 *4 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-634 *3)) (-5 *1 (-344 *4 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-763))) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-763))) (-5 *5 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-763)) (-5 *2 (-420 *3)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-1007 *3)) (-4 *3 (-1219 (-409 (-568)))))) ((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-1208 *3)) (-4 *3 (-1219 (-568)))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-926))))) 
-(((*1 *2 *2 *1) (-12 (-5 *2 (-1266 *3 *4)) (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *2) (|partial| -12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-814 *3)) (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-1084 *3)) (-4 *3 (-950 *7 *6 *4)) (-4 *6 (-788)) (-4 *4 (-842)) (-4 *7 (-558)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| (-568)))) (-5 *1 (-592 *6 *4 *7 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-788)) (-4 *4 (-842)) (-4 *6 (-558)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| (-568)))) (-5 *1 (-592 *5 *4 *6 *3)) (-4 *3 (-950 *6 *5 *4)))) ((*1 *1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1) (-5 *1 (-850))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1152 *4 *2)) (-4 *2 (-13 (-432 *4) (-161) (-27) (-1181))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1082 *2)) (-4 *2 (-13 (-432 *4) (-161) (-27) (-1181))) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1152 *4 *2)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-409 (-953 *5))) (-5 *1 (-1153 *5)) (-5 *3 (-953 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-3 (-409 (-953 *5)) (-310 *5))) (-5 *1 (-1153 *5)) (-5 *3 (-409 (-953 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1082 (-953 *5))) (-5 *3 (-953 *5)) (-4 *5 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-409 *3)) (-5 *1 (-1153 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1082 (-409 (-953 *5)))) (-5 *3 (-409 (-953 *5))) (-4 *5 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-3 *3 (-310 *5))) (-5 *1 (-1153 *5))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-634 (-634 (-944 *3)))))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *4 (-950 *5 *7 (-852 *6))) (-4 *7 (-230 (-1697 *6) (-763))) (-4 *3 (-971 *5)) (-4 *8 (-641 *5)) (-4 *9 (-920 *5 *8)) (-4 *10 (-235 *9)) (-4 *12 (-117)) (-4 *2 (-258 *11)) (-5 *1 (-260 *5 *6 *4 *7 *3 *8 *9 *10 *11 *2 *12)) (-4 *11 (-536 *5 *6 *4 *7 *3 *8 *9 *10 *12))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-57)) (-5 *1 (-887 *4)) (-4 *4 (-1090))))) 
-(((*1 *2 *2 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *2 (-1061 *4 *5 *6)) (-5 *1 (-768 *4 *5 *6 *2 *3)) (-4 *3 (-1066 *4 *5 *6 *2))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-840))) (-5 *1 (-178 *3 *2)) (-4 *2 (-1219 (-169 *3)))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-123)) (-4 *2 (-1090)) (-4 *2 (-842)) (-5 *1 (-122 *2))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-842) (-1037 (-568)) (-630 (-568)) (-453))) (-5 *2 (-835 *4)) (-5 *1 (-307 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1181) (-432 *3))) (-14 *5 (-1161)) (-14 *6 *4))) ((*1 *2 *1) (|partial| -12 (-4 *3 (-13 (-842) (-1037 (-568)) (-630 (-568)) (-453))) (-5 *2 (-835 *4)) (-5 *1 (-1229 *3 *4 *5 *6)) (-4 *4 (-13 (-27) (-1181) (-432 *3))) (-14 *5 (-1161)) (-14 *6 *4)))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-4 *5 (-365)) (-5 *2 (-1141 (-1141 (-953 *5)))) (-5 *1 (-1252 *5)) (-5 *4 (-1141 (-953 *5)))))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-1245)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
-(((*1 *1 *1) (-4 *1 (-1056))) ((*1 *1 *1 *2 *2) (-12 (-4 *1 (-1221 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1221 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-1109 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-121)) (-5 *1 (-824))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-558)) (-4 *7 (-950 *3 *5 *6)) (-5 *2 (-2 (|:| -3438 (-763)) (|:| -2348 *8) (|:| |radicand| *8))) (-5 *1 (-954 *5 *6 *3 *7 *8)) (-5 *4 (-763)) (-4 *8 (-13 (-365) (-10 -8 (-15 -2317 (*7 $)) (-15 -2324 (*7 $)) (-15 -2745 ($ *7)))))))) 
-(((*1 *1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-634 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-559 *6 *3))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-121)) (-5 *5 (-568)) (-4 *6 (-365)) (-4 *6 (-370)) (-4 *6 (-1047)) (-5 *2 (-634 (-634 (-679 *6)))) (-5 *1 (-1029 *6)) (-5 *3 (-634 (-679 *6))))) ((*1 *2 *3) (-12 (-4 *4 (-365)) (-4 *4 (-370)) (-4 *4 (-1047)) (-5 *2 (-634 (-634 (-679 *4)))) (-5 *1 (-1029 *4)) (-5 *3 (-634 (-679 *4))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-365)) (-4 *5 (-370)) (-4 *5 (-1047)) (-5 *2 (-634 (-634 (-679 *5)))) (-5 *1 (-1029 *5)) (-5 *3 (-634 (-679 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-365)) (-4 *5 (-370)) (-4 *5 (-1047)) (-5 *2 (-634 (-634 (-679 *5)))) (-5 *1 (-1029 *5)) (-5 *3 (-634 (-679 *5)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1201 *2)) (-4 *2 (-1047)))) ((*1 *1 *1) (-12 (-5 *1 (-1235 *2 *3 *4)) (-4 *2 (-1047)) (-14 *3 (-1161)) (-14 *4 *2))) ((*1 *1 *1) (-12 (-5 *1 (-1239 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-1161))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
-(((*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-230 (-1697 *4) (-763))) (-4 *6 (-971 *3)) (-4 *7 (-641 *3)) (-4 *8 (-920 *3 *7)) (-4 *9 (-235 *8)) (-4 *10 (-536 *3 *4 *2 *5 *6 *7 *8 *9 *12)) (-4 *12 (-117)) (-4 *2 (-950 *3 *5 (-852 *4))) (-5 *1 (-467 *3 *4 *2 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) ((*1 *2) (-12 (-5 *2 (-242 *4 *3)) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-242 *4 *3)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-215))))) 
-(((*1 *2 *1 *3) (-12 (-4 *1 (-52 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047)))) ((*1 *2 *1 *1) (-12 (-4 *2 (-1047)) (-5 *1 (-55 *2 *3)) (-14 *3 (-634 (-1161))))) ((*1 *2 *1 *3) (-12 (-5 *3 (-634 (-917))) (-4 *2 (-365)) (-5 *1 (-155 *4 *2 *5)) (-14 *4 (-917)) (-14 *5 (-994 *4 *2)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-310 *3)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161))))) ((*1 *2 *3 *1) (-12 (-4 *1 (-320 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-137)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-384 *2 *3)) (-4 *3 (-1090)) (-4 *2 (-1047)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *2 (-558)) (-5 *1 (-615 *2 *4)) (-4 *4 (-1219 *2)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-698 *2)) (-4 *2 (-1047)))) ((*1 *2 *1 *3) (-12 (-4 *2 (-1047)) (-5 *1 (-725 *2 *3)) (-4 *3 (-716)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *5)) (-5 *3 (-634 (-763))) (-4 *1 (-730 *4 *5)) (-4 *4 (-1047)) (-4 *5 (-842)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-730 *4 *2)) (-4 *4 (-1047)) (-4 *2 (-842)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-844 *2)) (-4 *2 (-1047)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *6)) (-5 *3 (-634 (-763))) (-4 *1 (-950 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-950 *4 *5 *2)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *2 (-842)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *2 (-950 *4 (-534 *5) *5)) (-5 *1 (-1114 *4 *5 *2)) (-4 *4 (-1047)) (-4 *5 (-842)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-953 *4)) (-5 *1 (-1190 *4)) (-4 *4 (-1047))))) 
-(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-751))))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *1 (-62 *2 *4 *5)) (-4 *4 (-375 *2)) (-4 *5 (-375 *2)) (-4 *2 (-1195)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-283 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1050 *4 *5 *2 *6 *7)) (-4 *6 (-230 *5 *2)) (-4 *7 (-230 *4 *2)) (-4 *2 (-1047))))) 
-(((*1 *1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-634 (-2 (|:| |lcmfij| *4) (|:| |totdeg| (-763)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *4 (-788)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-453)) (-4 *5 (-842)) (-5 *1 (-450 *3 *4 *5 *6))))) 
-(((*1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-558)) (-4 *2 (-172))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 (-1255 *4 *5 *6 *7))) (-5 *1 (-1255 *4 *5 *6 *7)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 *9)) (-5 *4 (-1 (-121) *9 *9)) (-5 *5 (-1 *9 *9 *9)) (-4 *9 (-1061 *6 *7 *8)) (-4 *6 (-558)) (-4 *7 (-788)) (-4 *8 (-842)) (-5 *2 (-634 (-1255 *6 *7 *8 *9))) (-5 *1 (-1255 *6 *7 *8 *9))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-634 *3)) (-4 *3 (-1195))))) 
-(((*1 *2) (-12 (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-1239 (-568) -3492)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-1239 (-568) -3492)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) ((*1 *2) (-12 (-5 *2 (-1239 (-568) -3492)) (-5 *1 (-867 *3 *4 *5)) (-4 (-857 *3) (-370)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1239 (-568) -3492)) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2) (-12 (-5 *2 (-1239 (-568) -3492)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1239 (-568) -3492)) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117))))) 
-(((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-166 *2)) (-4 *2 (-172)) (-4 *2 (-558)))) ((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-324 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)) (-4 *2 (-558)))) ((*1 *1 *1 *1) (|partial| -4 *1 (-558))) ((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (-4 *2 (-558)))) ((*1 *1 *1 *1) (|partial| -5 *1 (-763))) ((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-558)))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1244 *4)) (-4 *4 (-1219 *3)) (-4 *3 (-558)) (-5 *1 (-970 *3 *4)))) ((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-1050 *3 *4 *2 *5 *6)) (-4 *2 (-1047)) (-4 *5 (-230 *4 *2)) (-4 *6 (-230 *3 *2)) (-4 *2 (-558)))) ((*1 *2 *2 *2) (|partial| -12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(((*1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-558)) (-4 *2 (-172))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-310 (-169 (-381)))) (-5 *1 (-328)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-568))) (-5 *1 (-328)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-381))) (-5 *1 (-328)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-683))) (-5 *1 (-328)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-690))) (-5 *1 (-328)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-688))) (-5 *1 (-328)))) ((*1 *1) (-5 *1 (-328)))) 
-(((*1 *1) (-5 *1 (-1059)))) 
-(((*1 *1 *2) (|partial| -12 (-5 *2 (-814 *3)) (-4 *3 (-842)) (-5 *1 (-663 *3))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-1219 *3)) (-5 *1 (-164 *3 *4 *2)) (-4 *2 (-1219 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-536 *4 *5 *6 *7 *8 *9 *10 *2 *12)) (-4 *12 (-117)) (-4 *2 (-235 *10)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *2 *11 *3 *12)) (-4 *3 (-258 *11))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -1880 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *2 *2 *3 *4 *4) (-12 (-5 *4 (-568)) (-4 *3 (-172)) (-4 *5 (-375 *3)) (-4 *6 (-375 *3)) (-5 *1 (-678 *3 *5 *6 *2)) (-4 *2 (-677 *3 *5 *6))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-320 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-137)) (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1892 *4)))))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| -2348 *3) (|:| -2354 *4)))) (-5 *1 (-725 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-716)))) ((*1 *2 *1) (-12 (-4 *1 (-1221 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-1141 (-2 (|:| |k| *4) (|:| |c| *3))))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-842) (-1037 (-568)))) (-5 *1 (-180 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 (-169 *3)))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-5 *1 (-180 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 (-169 *4)))))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4)))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1157 *5)) (-4 *5 (-365)) (-5 *2 (-634 *6)) (-5 *1 (-535 *5 *6 *4)) (-4 *6 (-365)) (-4 *4 (-13 (-365) (-840)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-634 (-1161))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *5)))))) (-5 *1 (-762 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *4)))))) (-5 *1 (-762 *4)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *7)) (-5 *5 (-1 (-2 (|:| |particular| (-3 *6 "failed")) (|:| -3746 (-634 *6))) *7 *6)) (-4 *6 (-365)) (-4 *7 (-646 *6)) (-5 *2 (-2 (|:| |particular| (-3 (-1244 *6) "failed")) (|:| -3746 (-634 (-1244 *6))))) (-5 *1 (-808 *6 *7)) (-5 *4 (-1244 *6))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |scalar| (-409 (-568))) (|:| |coeff| (-1157 *3)) (|:| |logand| (-1157 *3))))) (-5 *1 (-585 *3)) (-4 *3 (-365))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-392 *3 *4 *5)) (-14 *3 (-763)) (-14 *4 (-763)) (-4 *5 (-172))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-817))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-5 *3 (-634 *7)) (-4 *1 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)))) ((*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-568)) (|has| *1 (-6 -4510)) (-4 *1 (-406)) (-5 *2 (-917))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-1244 *1)) (-4 *1 (-858)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-1219 *4)) (-4 *4 (-1047)) (-5 *2 (-1244 *4))))) 
-(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-1047)) (-4 *7 (-1047)) (-4 *6 (-1219 *5)) (-5 *2 (-1157 (-1157 *7))) (-5 *1 (-510 *5 *6 *4 *7)) (-4 *4 (-1219 *6))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) ((*1 *2 *2 *2 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-121)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-978 *4 *5 *6 *7))))) 
-(((*1 *2 *2 *2 *2 *2 *2) (-12 (-4 *2 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *1 (-1116 *3 *2)) (-4 *3 (-1219 *2))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-172)))) ((*1 *2 *3 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-172))))) 
-(((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1234 *4)) (-5 *1 (-1236 *4 *2)) (-4 *4 (-43 (-409 (-568))))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-850))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-230 *5 (-763))) (-14 *5 (-763)) (-5 *1 (-908 *3 *2 *4 *5)) (-4 *2 (-324 *3 *4)))) ((*1 *2 *2 *3) (-12 (-4 *4 (-365)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-929 *4 *2 *5 *6 *3)) (-4 *2 (-324 *4 *5)) (-4 *3 (-971 *4)))) ((*1 *2 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-365)) (-4 *6 (-230 *7 (-763))) (-14 *7 (-763)) (-5 *1 (-929 *5 *2 *6 *7 *3)) (-4 *2 (-324 *5 *6)) (-4 *3 (-971 *5))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-926)))) ((*1 *2 *1) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-927))))) 
-(((*1 *2 *2 *2 *3) (-12 (-5 *2 (-634 (-568))) (-5 *3 (-679 (-568))) (-5 *1 (-1100))))) 
-(((*1 *2 *2) (-12 (-5 *1 (-586 *2)) (-4 *2 (-550))))) 
-(((*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-763))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-850))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-106 *3))))) 
 (((*1 *1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1892 *4)))) (-4 *3 (-1090)) (-4 *4 (-23)) (-14 *5 *4) (-5 *1 (-638 *3 *4 *5))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *5 *5)) (-4 *5 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-2 (|:| |solns| (-634 *5)) (|:| |maps| (-634 (-2 (|:| |arg| *5) (|:| |res| *5)))))) (-5 *1 (-1116 *3 *5)) (-4 *3 (-1219 *5))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-955)) (-5 *2 (-634 (-634 (-944 (-215))))))) ((*1 *2 *1) (-12 (-4 *1 (-975)) (-5 *2 (-634 (-634 (-944 (-215)))))))) 
-(((*1 *2 *1 *3 *4 *4 *4 *4 *5 *5 *5 *5 *6 *5 *6 *5) (-12 (-5 *3 (-917)) (-5 *4 (-215)) (-5 *5 (-568)) (-5 *6 (-869)) (-5 *2 (-1249)) (-5 *1 (-1245))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-230 (-1697 *5) (-763))) (-5 *2 (-3 (-634 *7) "failed" "Infinite" (-568))) (-5 *1 (-31 *4 *5 *3 *6 *7)) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *7 (-971 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-230 (-1697 *5) (-763))) (-5 *2 (-3 (-634 *7) "failed" "Infinite" (-568))) (-5 *1 (-32 *4 *5 *3 *6 *7)) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *7 (-971 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1157 (-1157 *4))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *7 (-230 (-1697 *5) (-763))) (-5 *2 (-3 (-634 *8) "failed" "Infinite" (-568))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *8 (-971 *4))))) 
-(((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-634 (-634 (-634 *4)))) (-5 *2 (-634 (-634 *4))) (-4 *4 (-842)) (-5 *1 (-1167 *4))))) 
-(((*1 *1 *1 *2) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3)))) 
-(((*1 *2 *3) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-565)) (-5 *3 (-568)))) ((*1 *2 *3) (-12 (-5 *2 (-1157 (-409 (-568)))) (-5 *1 (-943)) (-5 *3 (-568))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-778 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-172))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-1161)) (-5 *2 (-439)) (-5 *1 (-1165))))) 
-(((*1 *1) (-5 *1 (-147))) ((*1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -2721 *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-23)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1063 *4 *3)) (-4 *4 (-13 (-840) (-365))) (-4 *3 (-1219 *4)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (|partial| -12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| |radicand| (-409 *5)) (|:| |deg| (-763)))) (-5 *1 (-151 *4 *5 *3)) (-4 *3 (-1219 (-409 *5)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-634 *8))) (-5 *3 (-634 *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *5 *6 *7 *8))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-420 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-1047)) (-5 *2 (-634 *6)) (-5 *1 (-445 *5 *6))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-634 *3))))) 
-(((*1 *2 *2 *1) (-12 (-5 *2 (-1266 *3 *4)) (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *2) (|partial| -12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-814 *3)) (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047))))) 
-(((*1 *1 *2) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181)))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2850 *4) (|:| -2183 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-1143)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-256))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-842)) (-4 *4 (-365)) (-4 *5 (-788)) (-5 *1 (-514 *4 *5 *6 *2)) (-4 *2 (-950 *4 *5 *6)))) ((*1 *1 *1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *2)) (-4 *2 (-950 *3 *4 *5))))) 
-(((*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-568)) (-4 *5 (-840)) (-4 *5 (-365)) (-5 *2 (-763)) (-5 *1 (-946 *5 *6)) (-4 *6 (-1219 *5))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-887 *4)) (-4 *4 (-1090)) (-5 *1 (-885 *4 *3)) (-4 *3 (-1195)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-57)) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *3 (-235 *10)) (-4 *11 (-536 *4 *5 *6 *7 *8 *9 *10 *3 *13)) (-4 *13 (-117)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *3 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-5 *1 (-562 *4 *5 *6 *7 *8 *9 *10 *3)) (-4 *8 (-971 *4)) (-4 *3 (-235 *10)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-236 (-922 *5))) (-5 *4 (-634 (-242 *6 *5))) (-4 *5 (-350)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-242 *6 (-857 *5)))) (-5 *1 (-867 *5 *6 *7)) (-4 *7 (-117)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-634 (-242 *5 *4))) (-5 *3 (-236 (-921 *4))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *1 (-868 *4 *5 *6)) (-4 *6 (-117))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-1028 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-634 (-679 *3))) (-4 *3 (-1047)) (-5 *1 (-1028 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-1028 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-634 (-679 *3))) (-4 *3 (-1047)) (-5 *1 (-1028 *3))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-409 *2)) (-4 *2 (-1219 *5)) (-5 *1 (-802 *5 *2 *3 *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *3 (-646 *2)) (-4 *6 (-646 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-409 *2))) (-4 *2 (-1219 *5)) (-5 *1 (-802 *5 *2 *3 *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *3 (-646 *2)) (-4 *6 (-646 (-409 *2)))))) 
-(((*1 *1) (-12 (-4 *1 (-406)) (-3044 (|has| *1 (-6 -4510))) (-3044 (|has| *1 (-6 -4502))))) ((*1 *2 *1) (-12 (-4 *1 (-427 *2)) (-4 *2 (-1090)) (-4 *2 (-842)))) ((*1 *2 *1) (-12 (-4 *1 (-825 *2)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-4 *1 (-842))) ((*1 *1) (-5 *1 (-1108)))) 
-(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1197))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-27)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-643 (-409 *5)))) (-5 *1 (-647 *4 *5)) (-5 *3 (-643 (-409 *5)))))) 
-(((*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-558) (-150))) (-5 *2 (-2 (|:| -3028 *3) (|:| -3284 *3))) (-5 *1 (-1213 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *1 *2) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *3 *4 *2) (-12 (-5 *2 (-634 (-634 (-634 *5)))) (-5 *3 (-1 (-121) *5 *5)) (-5 *4 (-634 *5)) (-4 *5 (-842)) (-5 *1 (-1167 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1219 (-409 *3))) (-5 *2 (-917)) (-5 *1 (-909 *4 *5)) (-4 *5 (-1219 (-409 *4)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-975)) (-5 *2 (-1084 (-215)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1892 *4)))) (-5 *1 (-638 *3 *4 *5)) (-4 *3 (-1090)) (-4 *4 (-23)) (-14 *5 *4)))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-64 *6)) (-4 *6 (-1195)) (-4 *5 (-1195)) (-5 *2 (-64 *5)) (-5 *1 (-63 *6 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *7 *5)) (-5 *4 (-232 *6 *7)) (-14 *6 (-763)) (-4 *7 (-1195)) (-4 *5 (-1195)) (-5 *2 (-232 *6 *5)) (-5 *1 (-231 *6 *7 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-4 *6 (-1195)) (-4 *5 (-1195)) (-4 *2 (-375 *5)) (-5 *1 (-373 *6 *4 *5 *2)) (-4 *4 (-375 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-4 *6 (-1090)) (-4 *5 (-1090)) (-4 *2 (-427 *5)) (-5 *1 (-425 *6 *4 *5 *2)) (-4 *4 (-427 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-634 *6)) (-4 *6 (-1195)) (-4 *5 (-1195)) (-5 *2 (-634 *5)) (-5 *1 (-632 *6 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-958 *6)) (-4 *6 (-1195)) (-4 *5 (-1195)) (-5 *2 (-958 *5)) (-5 *1 (-957 *6 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *3 *6 *3)) (-5 *5 (-1141 *6)) (-4 *6 (-1195)) (-4 *3 (-1195)) (-5 *2 (-1141 *3)) (-5 *1 (-1139 *6 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-1244 *6)) (-4 *6 (-1195)) (-4 *5 (-1195)) (-5 *2 (-1244 *5)) (-5 *1 (-1243 *6 *5))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-1143)) (-4 *1 (-366 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090))))) 
-(((*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-763)) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-96 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-212 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-494 *4)) (-4 *4 (-842)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1000 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1132 *4)) (-4 *4 (-1090))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1141 (-568))) (-5 *1 (-1145 *4)) (-4 *4 (-1047)) (-5 *3 (-568))))) 
-(((*1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1164))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-777 *2)) (-4 *2 (-1047)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-2 (|:| |start| *3) (|:| -3276 (-420 *3)))) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4)))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-568) (-568))) (-5 *1 (-363 *3)) (-4 *3 (-1090)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-763) (-763))) (-5 *1 (-388 *3)) (-4 *3 (-1090)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-23)) (-14 *5 *4) (-5 *1 (-638 *3 *4 *5)) (-4 *3 (-1090))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-301)) (-5 *1 (-177 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-288 *3))) (-5 *1 (-288 *3)) (-4 *3 (-558)) (-4 *3 (-1195))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1161))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)))) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)))) (-5 *1 (-256)))) ((*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) ((*1 *2 *1 *3 *3 *4 *4 *4) (-12 (-5 *3 (-568)) (-5 *4 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)))) (-5 *2 (-1249)) (-5 *1 (-1246)))) ((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3646 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)))) (-5 *1 (-1246)))) ((*1 *2 *1 *3 *3 *3 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-4 *5 (-432 *4)) (-5 *2 (-3 (|:| |overq| (-1157 (-409 (-568)))) (|:| |overan| (-1157 (-53))) (|:| -3483 (-121)))) (-5 *1 (-437 *4 *5 *3)) (-4 *3 (-1219 *5))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-568)) (-5 *4 (-1 (-1249) (-1094))) (-5 *2 (-1249)) (-5 *1 (-102))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-763)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1064 *6 *7 *8 *3 *4)) (-4 *4 (-1066 *6 *7 *8 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1064 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-763)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1130 *6 *7 *8 *3 *4)) (-4 *4 (-1099 *6 *7 *8 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1130 *5 *6 *7 *3 *4)) (-4 *4 (-1099 *5 *6 *7 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-4 *1 (-37 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-365)) (-5 *2 (-634 *3)))) ((*1 *1 *2) (-12 (-4 *1 (-43 *2)) (-4 *2 (-172)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-365)) (-14 *6 (-1244 (-679 *3))) (-5 *1 (-49 *3 *4 *5 *6)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))))) ((*1 *1 *2) (-12 (-5 *2 (-1113 (-568) (-607 (-53)))) (-5 *1 (-53)))) ((*1 *2 *3) (-12 (-5 *2 (-57)) (-5 *1 (-56 *3)) (-4 *3 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289 (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (-4289) (-688)))) (-5 *1 (-66 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289) (-4289 (QUOTE XC)) (-688)))) (-5 *1 (-68 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-337 (-4289 (QUOTE X)) (-4289) (-688))) (-5 *1 (-69 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-679 (-337 (-4289) (-4289 (QUOTE X) (QUOTE HESS)) (-688)))) (-5 *1 (-70 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-337 (-4289) (-4289 (QUOTE XC)) (-688))) (-5 *1 (-71 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289 (QUOTE X)) (-4289 (QUOTE -2928)) (-688)))) (-5 *1 (-76 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289) (-4289 (QUOTE X)) (-688)))) (-5 *1 (-79 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289 (QUOTE X) (QUOTE EPS)) (-4289 (QUOTE -2928)) (-688)))) (-5 *1 (-80 *3 *4 *5)) (-14 *3 (-1161)) (-14 *4 (-1161)) (-14 *5 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289 (QUOTE EPS)) (-4289 (QUOTE YA) (QUOTE YB)) (-688)))) (-5 *1 (-81 *3 *4 *5)) (-14 *3 (-1161)) (-14 *4 (-1161)) (-14 *5 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-337 (-4289) (-4289 (QUOTE X)) (-688))) (-5 *1 (-82 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-337 (-4289) (-4289 (QUOTE X)) (-688))) (-5 *1 (-83 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289) (-4289 (QUOTE XC)) (-688)))) (-5 *1 (-84 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289) (-4289 (QUOTE X)) (-688)))) (-5 *1 (-85 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289) (-4289 (QUOTE X)) (-688)))) (-5 *1 (-86 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289 (QUOTE X) (QUOTE -2928)) (-4289) (-688)))) (-5 *1 (-87 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-679 (-337 (-4289 (QUOTE X) (QUOTE -2928)) (-4289) (-688)))) (-5 *1 (-88 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-679 (-337 (-4289 (QUOTE X)) (-4289) (-688)))) (-5 *1 (-89 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289 (QUOTE X)) (-4289) (-688)))) (-5 *1 (-90 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-337 (-4289 (QUOTE X)) (-4289 (QUOTE -2928)) (-688)))) (-5 *1 (-91 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-679 (-337 (-4289 (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (-4289) (-688)))) (-5 *1 (-92 *3)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-337 (-4289 (QUOTE X)) (-4289 (QUOTE -2928)) (-688))) (-5 *1 (-94 *3)) (-14 *3 (-1161)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-1004 2)) (-5 *1 (-112)))) ((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-112)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-4 *1 (-117)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-141 *3 *4 *5))) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 (-763)) (-4 *5 (-172)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *5)) (-4 *5 (-172)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 (-763)))) ((*1 *1 *2) (-12 (-5 *2 (-1127 *4 *5)) (-14 *4 (-763)) (-4 *5 (-172)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)))) ((*1 *1 *2) (-12 (-5 *2 (-232 *4 *5)) (-14 *4 (-763)) (-4 *5 (-172)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)))) ((*1 *2 *3) (-12 (-5 *3 (-1244 (-679 *4))) (-4 *4 (-172)) (-5 *2 (-1244 (-679 (-409 (-953 *4))))) (-5 *1 (-181 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-13 (-842) (-10 -8 (-15 -2781 ((-1143) $ (-1161))) (-15 -4127 ((-1249) $)) (-15 -3687 ((-1249) $))))) (-5 *1 (-205 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1004 10)) (-5 *1 (-208)))) ((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-208)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-233 *3)) (-4 *3 (-1047)))) ((*1 *1 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-233 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1 *3 (-917))) (-5 *1 (-233 *3)) (-4 *3 (-1047)))) ((*1 *1 *2) (-12 (-5 *2 (-1 *3 (-917))) (-4 *3 (-1047)) (-5 *1 (-233 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-240 *3)) (-4 *3 (-842)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-240 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1082 (-310 *4))) (-4 *4 (-13 (-842) (-558) (-609 (-381)))) (-5 *2 (-1082 (-381))) (-5 *1 (-251 *4)))) ((*1 *1 *2) (-12 (-4 *1 (-262 *2)) (-4 *2 (-842)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-271)))) ((*1 *2 *1) (-12 (-4 *2 (-1219 *3)) (-5 *1 (-284 *3 *2 *4 *5 *6 *7)) (-4 *3 (-172)) (-4 *4 (-23)) (-14 *5 (-1 *2 *2 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *2 "failed") *2 *2 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-1228 *4 *5 *6)) (-4 *4 (-13 (-27) (-1181) (-432 *3))) (-14 *5 (-1161)) (-14 *6 *4) (-4 *3 (-13 (-842) (-1037 (-568)) (-630 (-568)) (-453))) (-5 *1 (-307 *3 *4 *5 *6)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-328)))) ((*1 *2 *1) (-12 (-5 *2 (-310 *5)) (-5 *1 (-337 *3 *4 *5)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-1161))) (-4 *5 (-389)))) ((*1 *2 *3) (-12 (-4 *4 (-350)) (-4 *2 (-327 *4)) (-5 *1 (-348 *3 *4 *2)) (-4 *3 (-327 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-350)) (-4 *2 (-327 *4)) (-5 *1 (-348 *2 *4 *3)) (-4 *3 (-327 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *2 (-1266 *3 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *2 (-1257 *3 *4)))) ((*1 *1 *2) (-12 (-4 *1 (-376 *2 *3)) (-4 *2 (-842)) (-4 *3 (-172)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) (-4 *1 (-385)))) ((*1 *1 *2) (-12 (-5 *2 (-328)) (-4 *1 (-385)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-4 *1 (-385)))) ((*1 *1 *2) (-12 (-5 *2 (-679 (-688))) (-4 *1 (-385)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) (-4 *1 (-386)))) ((*1 *1 *2) (-12 (-5 *2 (-328)) (-4 *1 (-386)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-4 *1 (-386)))) ((*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-1143)))) ((*1 *1 *2) (-12 (-5 *2 (-1143)) (-4 *1 (-391)))) ((*1 *2 *3) (-12 (-5 *2 (-396)) (-5 *1 (-395 *3)) (-4 *3 (-1090)))) ((*1 *1 *2) (-12 (-5 *2 (-850)) (-5 *1 (-396)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) (-4 *1 (-398)))) ((*1 *1 *2) (-12 (-5 *2 (-328)) (-4 *1 (-398)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-4 *1 (-398)))) ((*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-169 (-381))))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-381)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-568)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-169 (-381)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-381))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-568))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-683)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-688)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-288 (-310 (-690)))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-683))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-688))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-690))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-328)) (-5 *1 (-400 *3 *4 *5 *6)) (-14 *3 (-1161)) (-14 *4 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-14 *5 (-634 (-1161))) (-14 *6 (-1165)))) ((*1 *1 *2) (-12 (-5 *2 (-329 *4)) (-4 *4 (-13 (-842) (-21))) (-5 *1 (-429 *3 *4)) (-4 *3 (-13 (-172) (-43 (-409 (-568))))))) ((*1 *1 *2) (-12 (-5 *1 (-429 *2 *3)) (-4 *2 (-13 (-172) (-43 (-409 (-568))))) (-4 *3 (-13 (-842) (-21))))) ((*1 *1 *2) (-12 (-5 *2 (-409 (-953 (-409 *3)))) (-4 *3 (-558)) (-4 *3 (-842)) (-4 *1 (-432 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-953 (-409 *3))) (-4 *3 (-558)) (-4 *3 (-842)) (-4 *1 (-432 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-409 *3)) (-4 *3 (-558)) (-4 *3 (-842)) (-4 *1 (-432 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1113 *3 (-607 *1))) (-4 *3 (-1047)) (-4 *3 (-842)) (-4 *1 (-432 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1094)) (-5 *1 (-436)))) ((*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-436)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-436)))) ((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-436)))) ((*1 *1 *2) (-12 (-5 *2 (-436)) (-5 *1 (-439)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-439)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) (-4 *1 (-441)))) ((*1 *1 *2) (-12 (-5 *2 (-328)) (-4 *1 (-441)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-4 *1 (-441)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-688))) (-4 *1 (-441)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |localSymbols| (-1165)) (|:| -2848 (-634 (-328))))) (-4 *1 (-442)))) ((*1 *1 *2) (-12 (-5 *2 (-328)) (-4 *1 (-442)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-4 *1 (-442)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-409 (-953 *3)))) (-4 *3 (-172)) (-14 *6 (-1244 (-679 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *1 (-473)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-473)))) ((*1 *1 *2) (-12 (-5 *2 (-1228 *3 *4 *5)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3) (-5 *1 (-479 *3 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-479 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-1004 16)) (-5 *1 (-497)))) ((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-497)))) ((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-500)))) ((*1 *1 *2) (-12 (-5 *2 (-1113 (-568) (-607 (-504)))) (-5 *1 (-504)))) ((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-511)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6)))) ((*1 *1 *2) (-12 (-4 *3 (-172)) (-5 *1 (-602 *3 *2)) (-4 *2 (-736 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-608 *2)) (-4 *2 (-1195)))) ((*1 *1 *2) (-12 (-4 *1 (-612 *2)) (-4 *2 (-1047)))) ((*1 *2 *1) (-12 (-5 *2 (-1262 *3 *4)) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917)))) ((*1 *2 *1) (-12 (-5 *2 (-1257 *3 *4)) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917)))) ((*1 *1 *2) (-12 (-4 *3 (-172)) (-5 *1 (-626 *3 *2)) (-4 *2 (-736 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-641 *3)) (-4 *3 (-365)) (-5 *2 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *3)))))) ((*1 *1 *2) (-12 (-5 *2 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *3)))) (-4 *3 (-365)) (-4 *1 (-641 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-667 *3)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-814 *3)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-958 (-958 (-958 *3)))) (-5 *1 (-666 *3)) (-4 *3 (-1090)))) ((*1 *1 *2) (-12 (-5 *2 (-958 (-958 (-958 *3)))) (-4 *3 (-1090)) (-5 *1 (-666 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-814 *3)) (-5 *1 (-667 *3)) (-4 *3 (-842)))) ((*1 *2 *3) (-12 (-5 *2 (-1 *3)) (-5 *1 (-671 *3)) (-4 *3 (-1090)))) ((*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *2)) (-4 *4 (-375 *3)) (-4 *2 (-375 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-169 (-381))) (-5 *1 (-683)))) ((*1 *1 *2) (-12 (-5 *2 (-169 (-690))) (-5 *1 (-683)))) ((*1 *1 *2) (-12 (-5 *2 (-169 (-688))) (-5 *1 (-683)))) ((*1 *1 *2) (-12 (-5 *2 (-169 (-568))) (-5 *1 (-683)))) ((*1 *1 *2) (-12 (-5 *2 (-169 (-381))) (-5 *1 (-683)))) ((*1 *1 *2) (-12 (-5 *2 (-690)) (-5 *1 (-688)))) ((*1 *2 *1) (-12 (-5 *2 (-381)) (-5 *1 (-688)))) ((*1 *2 *3) (-12 (-5 *3 (-310 (-568))) (-5 *2 (-310 (-690))) (-5 *1 (-690)))) ((*1 *1 *2) (-12 (-5 *1 (-692 *2)) (-4 *2 (-1090)))) ((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-700)))) ((*1 *2 *1) (-12 (-4 *2 (-172)) (-5 *1 (-701 *2 *3 *4 *5 *6)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-702 *3 *2)) (-4 *2 (-1219 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-2 (|:| -4357 *3) (|:| -3483 *4))) (-5 *1 (-703 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-1090)) (-14 *5 (-1 (-121) *2 *2)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| -4357 *3) (|:| -3483 *4))) (-4 *3 (-842)) (-4 *4 (-1090)) (-5 *1 (-703 *3 *4 *5)) (-14 *5 (-1 (-121) *2 *2)))) ((*1 *2 *1) (-12 (-4 *2 (-172)) (-5 *1 (-705 *2 *3 *4 *5 *6)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| -2350 *3) (|:| -2356 *4)))) (-4 *3 (-1047)) (-4 *4 (-716)) (-5 *1 (-725 *3 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-409 (-734 *3 *4))) (-14 *3 (-1161)) (-4 *4 (-13 (-1047) (-842) (-558))) (-5 *1 (-733 *3 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-953 *4)) (-4 *4 (-1047)) (-5 *1 (-734 *3 *4)) (-14 *3 (-1161)))) ((*1 *1 *2) (-12 (-5 *2 (-1240 *3)) (-14 *3 (-1161)) (-5 *1 (-734 *3 *4)) (-4 *4 (-1047)))) ((*1 *1 *2) (-12 (-5 *1 (-734 *3 *2)) (-14 *3 (-1161)) (-4 *2 (-1047)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-755)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (|:| |nia| (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| |mdnia| (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))))) (-5 *1 (-761)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |fn| (-310 (-215))) (|:| -3581 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *1 (-761)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *1 (-761)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-761)))) ((*1 *2 *3) (-12 (-5 *2 (-766)) (-5 *1 (-765 *3)) (-4 *3 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *1 (-803)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-803)))) ((*1 *2 *1) (-12 (-4 *2 (-895 *3)) (-5 *1 (-812 *3 *2 *4)) (-4 *3 (-1090)) (-14 *4 *3))) ((*1 *1 *2) (-12 (-4 *3 (-1090)) (-14 *4 *3) (-5 *1 (-812 *3 *2 *4)) (-4 *2 (-895 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-819)))) ((*1 *1 *2) (-12 (-5 *2 (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))))) (-5 *1 (-833)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) (-5 *1 (-833)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (-5 *1 (-833)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-833)))) ((*1 *1 *2) (-12 (-5 *2 (-1240 *3)) (-14 *3 (-1161)) (-5 *1 (-847 *3 *4 *5 *6)) (-4 *4 (-1047)) (-14 *5 (-101 *4)) (-14 *6 (-1 *4 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-849)))) ((*1 *1 *2) (-12 (-5 *2 (-953 *3)) (-4 *3 (-1047)) (-5 *1 (-853 *3 *4 *5 *6)) (-14 *4 (-634 (-1161))) (-14 *5 (-634 (-763))) (-14 *6 (-763)))) ((*1 *2 *1) (-12 (-5 *2 (-953 *3)) (-5 *1 (-853 *3 *4 *5 *6)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))) (-14 *5 (-634 (-763))) (-14 *6 (-763)))) ((*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869)))) ((*1 *2 *3) (-12 (-5 *3 (-953 (-53))) (-5 *2 (-310 (-568))) (-5 *1 (-870)))) ((*1 *2 *3) (-12 (-5 *3 (-409 (-953 (-53)))) (-5 *2 (-310 (-568))) (-5 *1 (-870)))) ((*1 *1 *2) (-12 (-5 *1 (-888 *2)) (-4 *2 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-814 *3)) (-5 *1 (-888 *3)) (-4 *3 (-842)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) (-5 *1 (-893)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-893)))) ((*1 *2 *1) (-12 (-5 *2 (-1182 *3)) (-5 *1 (-896 *3)) (-4 *3 (-1090)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-900 *3))) (-4 *3 (-1090)) (-5 *1 (-899 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-900 *3))) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-900 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-1090)) (-5 *1 (-900 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-409 (-420 *3))) (-4 *3 (-301)) (-5 *1 (-910 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-409 *3)) (-5 *1 (-910 *3)) (-4 *3 (-301)))) ((*1 *2 *3) (-12 (-5 *3 (-489)) (-5 *2 (-310 *4)) (-5 *1 (-915 *4)) (-4 *4 (-13 (-842) (-558))))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-4 *1 (-971 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-634 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-972)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568)))) ((*1 *2 *3) (-12 (-5 *2 (-1249)) (-5 *1 (-1033 *3)) (-4 *3 (-1195)))) ((*1 *2 *3) (-12 (-5 *3 (-305)) (-5 *1 (-1033 *2)) (-4 *2 (-1195)))) ((*1 *1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-1034 *3 *4 *5 *2 *6)) (-4 *2 (-950 *3 *4 *5)) (-14 *6 (-634 *2)))) ((*1 *1 *2) (-12 (-4 *1 (-1037 *2)) (-4 *2 (-1195)))) ((*1 *2 *3) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-1042 *3)) (-4 *3 (-558)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-1047)))) ((*1 *2 *1) (-12 (-5 *2 (-679 *5)) (-5 *1 (-1051 *3 *4 *5)) (-14 *3 (-763)) (-14 *4 (-763)) (-4 *5 (-1047)))) ((*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-842)) (-5 *1 (-1114 *3 *4 *2)) (-4 *2 (-950 *3 (-534 *4) *4)))) ((*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *2 (-842)) (-5 *1 (-1114 *3 *2 *4)) (-4 *4 (-950 *3 (-534 *2) *2)))) ((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-850)))) ((*1 *2 *1) (-12 (-5 *2 (-679 *4)) (-5 *1 (-1127 *3 *4)) (-14 *3 (-763)) (-4 *4 (-1047)))) ((*1 *1 *2) (-12 (-5 *2 (-147)) (-4 *1 (-1129)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-1141 *3)))) ((*1 *2 *3) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-1145 *3)) (-4 *3 (-1047)))) ((*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1151 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1158 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1159 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1216 *4 *3)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3) (-5 *1 (-1159 *3 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1160)))) ((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1161)))) ((*1 *2 *1) (-12 (-5 *2 (-1169 (-1161) (-439))) (-5 *1 (-1165)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1168 *3)) (-4 *3 (-1090)))) ((*1 *2 *3) (-12 (-5 *2 (-1176)) (-5 *1 (-1175 *3)) (-4 *3 (-1090)))) ((*1 *1 *2) (-12 (-5 *2 (-850)) (-5 *1 (-1176)))) ((*1 *1 *2) (-12 (-5 *2 (-953 *3)) (-4 *3 (-1047)) (-5 *1 (-1190 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1190 *3)) (-4 *3 (-1047)))) ((*1 *1 *2) (-12 (-5 *2 (-958 *3)) (-4 *3 (-1195)) (-5 *1 (-1193 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1240 (QUOTE |x|))) (-5 *1 (-1201 *3)) (-4 *3 (-1047)))) ((*1 *1 *2) (-12 (-5 *2 (-1216 (QUOTE |x|) *3)) (-4 *3 (-1047)) (-5 *1 (-1201 *3)))) ((*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *1 (-1205 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1207 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1084 *3)) (-4 *3 (-1195)) (-5 *1 (-1210 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1240 *3)) (-14 *3 (-1161)) (-5 *1 (-1216 *3 *4)) (-4 *4 (-1047)))) ((*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *1 (-1226 *3 *2)) (-4 *2 (-1203 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1228 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *2) (-12 (-5 *2 (-1216 *4 *3)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3) (-5 *1 (-1235 *3 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-1047)))) ((*1 *1 *2) (-12 (-5 *2 (-1216 *4 *3)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-5 *1 (-1239 *3 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-1240 *3)) (-14 *3 *2))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1245)))) ((*1 *2 *3) (-12 (-5 *3 (-473)) (-5 *2 (-1245)) (-5 *1 (-1248)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1249)))) ((*1 *1 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-788)) (-14 *6 (-634 *4)) (-5 *1 (-1254 *3 *4 *5 *2 *6 *7 *8)) (-4 *2 (-950 *3 *5 *4)) (-14 *7 (-634 (-763))) (-14 *8 (-763)))) ((*1 *2 *1) (-12 (-4 *2 (-950 *3 *5 *4)) (-5 *1 (-1254 *3 *4 *5 *2 *6 *7 *8)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-788)) (-14 *6 (-634 *4)) (-14 *7 (-634 (-763))) (-14 *8 (-763)))) ((*1 *1 *2) (-12 (-4 *1 (-1256 *2)) (-4 *2 (-1047)))) ((*1 *1 *2) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) ((*1 *2 *1) (-12 (-5 *2 (-1266 *3 *4)) (-5 *1 (-1262 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) ((*1 *2 *1) (-12 (-5 *2 (-1257 *3 *4)) (-5 *1 (-1262 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) ((*1 *1 *2) (-12 (-5 *2 (-656 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *1 (-1262 *3 *4)))) ((*1 *1 *2) (-12 (-5 *1 (-1265 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-838))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1244 (-2 (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)) (|:| -4158 (-568)) (|:| -2887 (-568)) (|:| |spline| (-568)) (|:| -3705 (-568)) (|:| |axesColor| (-869)) (|:| -2833 (-568)) (|:| |unitsColor| (-869)) (|:| |showing| (-568))))) (-5 *1 (-1245))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |cd| (-1143)) (|:| -3393 (-1143)))) (-5 *1 (-817))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-409 (-568))) (-5 *1 (-299))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-763)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1064 *6 *7 *8 *3 *4)) (-4 *4 (-1066 *6 *7 *8 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1064 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-763)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1130 *6 *7 *8 *3 *4)) (-4 *4 (-1099 *6 *7 *8 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1130 *5 *6 *7 *3 *4)) (-4 *4 (-1099 *5 *6 *7 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164)))) ((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-1165))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1244 (-310 (-215)))) (-5 *4 (-634 (-1161))) (-5 *2 (-679 (-310 (-215)))) (-5 *1 (-197)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-4 *6 (-895 *5)) (-5 *2 (-679 *6)) (-5 *1 (-681 *5 *6 *3 *4)) (-4 *3 (-375 *6)) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4521))))))) 
 (((*1 *1 *1) (-4 *1 (-1129)))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-453)))) ((*1 *1 *1 *1) (-4 *1 (-453)))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *2 *3 *4 *5 *6) (-12 (-5 *6 (-917)) (-4 *5 (-301)) (-4 *3 (-1219 *5)) (-5 *2 (-2 (|:| |plist| (-634 *3)) (|:| |modulo| *5))) (-5 *1 (-462 *5 *3)) (-5 *4 (-634 *3))))) 
+(((*1 *1 *1) (-12 (-4 *2 (-350)) (-4 *2 (-1047)) (-5 *1 (-702 *2 *3)) (-4 *3 (-1219 *2))))) 
 (((*1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-112)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-541))) (-5 *1 (-541))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 *5)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 (-763)) (-4 *5 (-172))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-14 *5 (-634 (-1161))) (-4 *3 (-950 *2 *6 (-852 *5))) (-4 *6 (-230 (-1699 *5) (-763))) (-4 *7 (-971 *2)) (-4 *8 (-641 *2)) (-4 *4 (-920 *2 *8)) (-4 *9 (-235 *4)) (-4 *10 (-536 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) ((*1 *2 *3 *3 *4) (|partial| -12 (-14 *5 (-634 (-1161))) (-4 *3 (-950 *2 *6 (-852 *5))) (-4 *6 (-230 (-1699 *5) (-763))) (-4 *7 (-971 *2)) (-4 *8 (-641 *2)) (-4 *4 (-920 *2 *8)) (-4 *9 (-235 *4)) (-4 *10 (-536 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 *6)) (-4 *6 (-950 *2 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-14 *5 (-634 (-1161))) (-4 *8 (-971 *2)) (-4 *9 (-641 *2)) (-4 *4 (-920 *2 *9)) (-4 *10 (-235 *4)) (-4 *11 (-536 *2 *5 *6 *7 *8 *9 *4 *10 *13)) (-4 *13 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *6 *7 *8 *9 *4 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-242 *5 *2)) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-242 *5 *2)) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 (-242 *5 *2))) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-242 *5 *2)) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-242 *5 *2)) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 (-242 *5 *2))) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-169 (-310 *4))) (-5 *1 (-180 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 (-169 *4)))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-169 *3)) (-5 *1 (-1185 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4)))))) 
 (((*1 *2 *3) (-12 (-4 *4 (-842)) (-5 *2 (-634 (-634 *4))) (-5 *1 (-1167 *4)) (-5 *3 (-634 *4))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-900 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *1 *3 *3 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-666 *2)) (-4 *2 (-1090))))) 
+(((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) ((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) ((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927))))) 
 (((*1 *2 *2 *1) (-12 (-5 *2 (-634 *6)) (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-4 *4 (-172)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)) (-4 *3 (-172))))) 
+(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160))))) 
+(((*1 *1 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-420 *2)) (-4 *2 (-558))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-453)))) ((*1 *1 *1 *1) (-4 *1 (-453))) ((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-5 *1 (-496 *2)) (-4 *2 (-1219 (-568))))) ((*1 *2 *2 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-685 *2)) (-4 *2 (-1219 *3)))) ((*1 *1 *1 *1) (-5 *1 (-763))) ((*1 *2 *2 *2) (-12 (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-301)) (-5 *1 (-912 *3 *4 *5 *2)) (-4 *2 (-950 *5 *3 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *6 *4 *5)) (-5 *1 (-912 *4 *5 *6 *2)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1157 *6)) (-4 *6 (-950 *5 *3 *4)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-301)) (-5 *1 (-912 *3 *4 *5 *6)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-1157 *7))) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)) (-5 *2 (-1157 *7)) (-5 *1 (-912 *4 *5 *6 *7)) (-4 *7 (-950 *6 *4 *5)))) ((*1 *1 *1 *1) (-5 *1 (-917))) ((*1 *2 *2 *2) (-12 (-4 *3 (-453)) (-4 *3 (-558)) (-5 *1 (-970 *3 *2)) (-4 *2 (-1219 *3)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-350)) (-5 *2 (-763)))) ((*1 *2 *1 *1) (|partial| -12 (-4 *1 (-404)) (-5 *2 (-763))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-99)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-99))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558) (-609 (-541)))) (-5 *1 (-1024 *3 *2)) (-4 *2 (-13 (-432 *3) (-23) (-1037 (-568)) (-1037 (-1161)) (-895 (-1161)) (-161)))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *3 (-365)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-529 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-558)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-4 *7 (-993 *4)) (-4 *2 (-677 *7 *8 *9)) (-5 *1 (-530 *4 *5 *6 *3 *7 *8 *9 *2)) (-4 *3 (-677 *4 *5 *6)) (-4 *8 (-375 *7)) (-4 *9 (-375 *7)))) ((*1 *1 *1) (|partial| -12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (-4 *2 (-365)))) ((*1 *2 *2) (|partial| -12 (-4 *3 (-365)) (-4 *3 (-172)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-678 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5)))) ((*1 *1 *1) (|partial| -12 (-5 *1 (-679 *2)) (-4 *2 (-365)) (-4 *2 (-1047)))) ((*1 *1 *1) (|partial| -12 (-4 *1 (-1111 *2 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-230 *2 *3)) (-4 *5 (-230 *2 *3)) (-4 *3 (-365)))) ((*1 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-1167 *3))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-409 (-568))) (-5 *1 (-299))))) 
+(((*1 *2 *2 *3 *3) (-12 (-5 *3 (-568)) (-4 *4 (-172)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *1 (-678 *4 *5 *6 *2)) (-4 *2 (-677 *4 *5 *6))))) 
+(((*1 *2 *3 *1) (|partial| -12 (-5 *3 (-1 (-121) *2)) (-4 *1 (-154 *2)) (-4 *2 (-1195))))) 
+(((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-239 *2)) (-4 *2 (-1195))))) 
 (((*1 *2 *3) (-12 (-5 *2 (-568)) (-5 *1 (-446 *3)) (-4 *3 (-406)) (-4 *3 (-1047))))) 
+(((*1 *2 *3 *3 *4) (-12 (-5 *3 (-634 *5)) (-4 *5 (-13 (-558) (-453))) (-5 *4 (-763)) (-5 *2 (-409 (-1157 *5))) (-5 *1 (-346 *5 *6)) (-4 *6 (-52 *5 *4)))) ((*1 *2 *3 *3 *4) (-12 (-5 *3 (-634 (-409 *5))) (-4 *5 (-13 (-558) (-453))) (-5 *4 (-763)) (-5 *2 (-409 (-1157 *5))) (-5 *1 (-346 *5 *6)) (-4 *6 (-52 *5 *4)))) ((*1 *2 *2 *3 *3) (-12 (-5 *2 (-1216 *4 *5)) (-5 *3 (-634 *5)) (-14 *4 (-1161)) (-4 *5 (-365)) (-5 *1 (-919 *4 *5)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-634 *5)) (-4 *5 (-365)) (-5 *2 (-1157 *5)) (-5 *1 (-919 *4 *5)) (-14 *4 (-1161)))) ((*1 *2 *3 *3 *4 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-763)) (-4 *6 (-365)) (-5 *2 (-409 (-953 *6))) (-5 *1 (-1048 *5 *6)) (-14 *5 (-1161))))) 
+(((*1 *1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))))) ((*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161))))) ((*1 *1) (-12 (-4 *1 (-327 *2)) (-4 *2 (-370)) (-4 *2 (-365)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-333 *3 *4 *5 *2)) (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *2 (-340 *3 *4 *5)))) ((*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-392 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-172)))) ((*1 *1) (-12 (-4 *2 (-172)) (-4 *1 (-714 *2 *3)) (-4 *3 (-1219 *2))))) 
 (((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |%expansion| (-307 *5 *3 *6 *7)) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143)))))) (-5 *1 (-422 *5 *3 *6 *7)) (-4 *3 (-13 (-27) (-1181) (-432 *5))) (-14 *6 (-1161)) (-14 *7 *3)))) 
+(((*1 *2 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *1 (-616 *3 *4 *5 *6 *7 *2)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *2 (-1099 *3 *4 *5 *6))))) 
+(((*1 *2 *1 *3) (-12 (-4 *1 (-138)) (-5 *3 (-763)) (-5 *2 (-1249))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-239 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-301)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-2 (|:| |Hermite| *3) (|:| |eqMat| *3))) (-5 *1 (-1112 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6))))) 
 (((*1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247)))) ((*1 *2 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-634 *3))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1219 *3)) (-4 *3 (-1047))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-150)) (-4 *3 (-301)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6))))) 
 (((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
+(((*1 *2 *3 *4 *4 *4 *5 *6 *7) (|partial| -12 (-5 *5 (-1161)) (-5 *6 (-1 (-3 (-2 (|:| |mainpart| *4) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *4) (|:| |logand| *4))))) "failed") *4 (-634 *4))) (-5 *7 (-1 (-3 (-2 (|:| -4151 *4) (|:| |coeff| *4)) "failed") *4 *4)) (-4 *4 (-13 (-1181) (-27) (-432 *8))) (-4 *8 (-13 (-453) (-842) (-150) (-1037 *3) (-630 *3))) (-5 *3 (-568)) (-5 *2 (-634 *4)) (-5 *1 (-1014 *8 *4))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-1141 *4)) (-5 *3 (-1 *4 (-568))) (-4 *4 (-1047)) (-5 *1 (-1145 *4))))) 
+(((*1 *1) (-5 *1 (-142)))) 
 (((*1 *2 *2 *3 *3) (|partial| -12 (-5 *3 (-1161)) (-4 *4 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-579 *4 *2)) (-4 *2 (-13 (-1181) (-959) (-1124) (-29 *4)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-863 *3)) (-5 *2 (-568))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-850))))) 
+(((*1 *1 *1 *1) (|partial| -4 *1 (-137)))) 
 (((*1 *1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-1047))))) 
+(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160))))) 
+(((*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1161)) (-4 *5 (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-2 (|:| -4151 *3) (|:| |coeff| *3))) (-5 *1 (-559 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5)))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-328))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-634 (-492 *4 *5))) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *2 (-2 (|:| |gblist| (-634 (-242 *4 *5))) (|:| |gvlist| (-634 (-568))))) (-5 *1 (-622 *4 *5))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 (-310 (-215)))) (-5 *1 (-263))))) 
+(((*1 *2 *2 *3) (-12 (-4 *3 (-365)) (-5 *1 (-280 *3 *2)) (-4 *2 (-1234 *3))))) 
+(((*1 *2 *3 *3) (-12 (-4 *3 (-1199)) (-4 *5 (-1219 *3)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-121)) (-5 *1 (-339 *4 *3 *5 *6)) (-4 *4 (-340 *3 *5 *6)))) ((*1 *2 *3 *3) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121))))) 
+(((*1 *2 *3 *1) (|partial| -12 (-4 *1 (-605 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-568)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-465))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-536 *4 *5 *6 *7 *8 *9 *10 *2 *12)) (-4 *12 (-117)) (-4 *2 (-235 *10)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *2 *11 *3 *12)) (-4 *3 (-258 *11)))) ((*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-536 *3 *4 *5 *6 *7 *8 *9 *2 *12)) (-4 *12 (-117)) (-4 *2 (-235 *9)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *2 *10 *11 *12)) (-4 *11 (-258 *10)))) ((*1 *2) (-12 (-5 *2 (-236 (-922 *3))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-236 (-921 *3))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-121))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-409 *5)) (-4 *5 (-1219 *4)) (-4 *4 (-558)) (-4 *4 (-1047)) (-4 *2 (-1234 *4)) (-5 *1 (-1237 *4 *5 *6 *2)) (-4 *6 (-646 *5))))) 
+(((*1 *2 *1) (-12 (-4 *4 (-1090)) (-5 *2 (-884 *3 *5)) (-5 *1 (-880 *3 *4 *5)) (-4 *3 (-1090)) (-4 *5 (-658 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381)))) (-5 *2 (-1035)) (-5 *1 (-299))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1219 *3)) (-4 *3 (-1047)) (-5 *2 (-1157 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1092 *3)) (-5 *1 (-900 *3)) (-4 *3 (-370)) (-4 *3 (-1090))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-536 *4 *5 *6 *7 *8 *9 *10 *2 *12)) (-4 *12 (-117)) (-4 *2 (-235 *10)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *2 *11 *3 *12)) (-4 *3 (-258 *11)))) ((*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-536 *3 *4 *5 *6 *7 *8 *9 *2 *12)) (-4 *12 (-117)) (-4 *2 (-235 *9)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *2 *10 *11 *12)) (-4 *11 (-258 *10)))) ((*1 *2) (-12 (-5 *2 (-236 (-922 *3))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-236 (-921 *3))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-1161)) (-4 *6 (-432 *5)) (-4 *5 (-842)) (-5 *2 (-634 (-607 *6))) (-5 *1 (-577 *5 *6))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *2 (-634 (-215))) (-5 *1 (-473))))) 
+(((*1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-634 *1)) (-4 *1 (-920 *3 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
 (((*1 *2 *3 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-970 *5 *3)) (-4 *3 (-1219 *5))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-436)) (-5 *2 (-634 (-3 (|:| -3391 (-1161)) (|:| |bounds| (-634 (-3 (|:| S (-1161)) (|:| P (-953 (-568))))))))) (-5 *1 (-1165))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-559 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5)))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-917)) (-4 *1 (-920 *4 *5)) (-4 *4 (-365)) (-4 *5 (-641 *4)) (-5 *2 (-1249))))) 
+(((*1 *2 *2 *3) (-12 (-4 *3 (-365)) (-5 *1 (-280 *3 *2)) (-4 *2 (-1234 *3))))) 
+(((*1 *2 *3 *3 *2) (-12 (-5 *2 (-679 (-568))) (-5 *3 (-634 (-568))) (-5 *1 (-1100))))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-436)) (-5 *2 (-634 (-3 (|:| -3393 (-1161)) (|:| |bounds| (-634 (-3 (|:| S (-1161)) (|:| P (-953 (-568))))))))) (-5 *1 (-1165))))) 
+(((*1 *1 *1) (-5 *1 (-215))) ((*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) ((*1 *1 *1) (-5 *1 (-381))) ((*1 *1) (-5 *1 (-381)))) 
+(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-634 (-1244 *4))) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-4 *3 (-558)) (-5 *2 (-634 (-1244 *3)))))) 
+(((*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 (-679 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1244 *5)) (-4 *5 (-787)) (-5 *2 (-121)) (-5 *1 (-837 *4 *5)) (-14 *4 (-763))))) 
 (((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-344 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *2 *2 *3 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-568)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-450 *4 *5 *6 *7))))) 
+(((*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2707 *1))) (-4 *1 (-844 *3))))) 
+(((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-666 *3)) (-4 *3 (-1090))))) 
 (((*1 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-365))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *3 (-1219 *4)) (-4 *2 (-1234 *4)) (-5 *1 (-1237 *4 *3 *5 *2)) (-4 *5 (-646 *3))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-256))) (-5 *4 (-1161)) (-5 *2 (-121)) (-5 *1 (-256)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-465))) (-5 *4 (-1161)) (-5 *2 (-121)) (-5 *1 (-465))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-679 *7)) (-5 *3 (-634 *7)) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *1 (-924 *4 *5 *6 *7))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 (-634 *7) *7 (-1157 *7))) (-5 *5 (-1 (-420 *7) *7)) (-4 *7 (-1219 *6)) (-4 *6 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-5 *2 (-634 (-2 (|:| |frac| (-409 *7)) (|:| -2410 *3)))) (-5 *1 (-804 *6 *7 *3 *8)) (-4 *3 (-646 *7)) (-4 *8 (-646 (-409 *7))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-420 *6) *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-634 (-2 (|:| |frac| (-409 *6)) (|:| -2410 (-644 *6 (-409 *6)))))) (-5 *1 (-807 *5 *6)) (-5 *3 (-644 *6 (-409 *6)))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-250))))) 
 (((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *4)) (-5 *1 (-1116 *3 *4)) (-4 *3 (-1219 *4)))) ((*1 *2 *3 *3 *3 *3) (-12 (-4 *3 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *3)) (-5 *1 (-1116 *4 *3)) (-4 *4 (-1219 *3))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568)))))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-1161)) (-5 *2 (-1165)) (-5 *1 (-1164))))) 
+(((*1 *1 *2 *3) (-12 (-5 *3 (-420 *2)) (-4 *2 (-301)) (-5 *1 (-910 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-150))) (-5 *2 (-57)) (-5 *1 (-911 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-420 (-953 *6))) (-5 *5 (-1161)) (-5 *3 (-953 *6)) (-4 *6 (-13 (-301) (-150))) (-5 *2 (-57)) (-5 *1 (-911 *6))))) 
+(((*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) ((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-900 (-568))) (-5 *4 (-568)) (-5 *2 (-679 *4)) (-5 *1 (-1028 *5)) (-4 *5 (-1047)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-679 (-568))) (-5 *1 (-1028 *4)) (-4 *4 (-1047)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-900 (-568)))) (-5 *4 (-568)) (-5 *2 (-634 (-679 *4))) (-5 *1 (-1028 *5)) (-4 *5 (-1047)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-634 (-568)))) (-5 *2 (-634 (-679 (-568)))) (-5 *1 (-1028 *4)) (-4 *4 (-1047))))) 
 (((*1 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) ((*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1141 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-184)))) ((*1 *2 *3) (-12 (-5 *3 (-1141 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-294)))) ((*1 *2 *3) (-12 (-5 *3 (-1141 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-299))))) 
+(((*1 *1 *2) (-12 (-5 *1 (-1026 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-842) (-1037 (-568)))) (-5 *1 (-180 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 (-169 *3)))))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3)))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
 (((*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) ((*1 *1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1061 *3 *4 *5))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-1084 *3)) (-4 *3 (-950 *7 *6 *4)) (-4 *6 (-788)) (-4 *4 (-842)) (-4 *7 (-558)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| (-568)))) (-5 *1 (-592 *6 *4 *7 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-788)) (-4 *4 (-842)) (-4 *6 (-558)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| (-568)))) (-5 *1 (-592 *5 *4 *6 *3)) (-4 *3 (-950 *6 *5 *4)))) ((*1 *1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1) (-5 *1 (-850))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1152 *4 *2)) (-4 *2 (-13 (-432 *4) (-161) (-27) (-1181))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1082 *2)) (-4 *2 (-13 (-432 *4) (-161) (-27) (-1181))) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1152 *4 *2)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-409 (-953 *5))) (-5 *1 (-1153 *5)) (-5 *3 (-953 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-3 (-409 (-953 *5)) (-310 *5))) (-5 *1 (-1153 *5)) (-5 *3 (-409 (-953 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1082 (-953 *5))) (-5 *3 (-953 *5)) (-4 *5 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-409 *3)) (-5 *1 (-1153 *5)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1082 (-409 (-953 *5)))) (-5 *3 (-409 (-953 *5))) (-4 *5 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-3 *3 (-310 *5))) (-5 *1 (-1153 *5))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-310 *4)) (-4 *4 (-13 (-823) (-842) (-1047))) (-5 *2 (-1143)) (-5 *1 (-821 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-310 *5)) (-5 *4 (-121)) (-4 *5 (-13 (-823) (-842) (-1047))) (-5 *2 (-1143)) (-5 *1 (-821 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-817)) (-5 *4 (-310 *5)) (-4 *5 (-13 (-823) (-842) (-1047))) (-5 *2 (-1249)) (-5 *1 (-821 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-817)) (-5 *4 (-310 *6)) (-5 *5 (-121)) (-4 *6 (-13 (-823) (-842) (-1047))) (-5 *2 (-1249)) (-5 *1 (-821 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-823)) (-5 *2 (-1143)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-823)) (-5 *3 (-121)) (-5 *2 (-1143)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-823)) (-5 *3 (-817)) (-5 *2 (-1249)))) ((*1 *2 *3 *1 *4) (-12 (-4 *1 (-823)) (-5 *3 (-817)) (-5 *4 (-121)) (-5 *2 (-1249))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-554))))) 
 (((*1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-1090)) (-5 *1 (-1168 *3))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-171)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)) (-4 *5 (-1047))))) 
+(((*1 *1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3 *3 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-106 *3)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1 *2 *2 *2)) (-5 *1 (-106 *2)) (-4 *2 (-1090))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-172)))) ((*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-943)) (-5 *3 (-568))))) 
+(((*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-3 (-409 (-953 *6)) (-1150 (-1161) (-953 *6)))) (-5 *5 (-763)) (-4 *6 (-453)) (-5 *2 (-634 (-679 (-409 (-953 *6))))) (-5 *1 (-286 *6)) (-5 *4 (-679 (-409 (-953 *6)))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-2 (|:| |eigval| (-3 (-409 (-953 *5)) (-1150 (-1161) (-953 *5)))) (|:| |eigmult| (-763)) (|:| |eigvec| (-634 *4)))) (-4 *5 (-453)) (-5 *2 (-634 (-679 (-409 (-953 *5))))) (-5 *1 (-286 *5)) (-5 *4 (-679 (-409 (-953 *5))))))) 
 (((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-288 (-828 *3))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-828 *3)) (-5 *1 (-627 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-288 (-828 (-953 *5)))) (-4 *5 (-453)) (-5 *2 (-828 (-409 (-953 *5)))) (-5 *1 (-628 *5)) (-5 *3 (-409 (-953 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-288 (-409 (-953 *5)))) (-5 *3 (-409 (-953 *5))) (-4 *5 (-453)) (-5 *2 (-828 *3)) (-5 *1 (-628 *5))))) 
+(((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926))))) 
+(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-473)) (-5 *4 (-917)) (-5 *2 (-1249)) (-5 *1 (-1245))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-1109 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090))))) 
+(((*1 *2 *1 *3) (|partial| -12 (-5 *3 (-1161)) (-4 *4 (-1047)) (-4 *4 (-842)) (-5 *2 (-2 (|:| |var| (-607 *1)) (|:| -3483 (-568)))) (-4 *1 (-432 *4)))) ((*1 *2 *1 *3) (|partial| -12 (-5 *3 (-123)) (-4 *4 (-1047)) (-4 *4 (-842)) (-5 *2 (-2 (|:| |var| (-607 *1)) (|:| -3483 (-568)))) (-4 *1 (-432 *4)))) ((*1 *2 *1) (|partial| -12 (-4 *3 (-1102)) (-4 *3 (-842)) (-5 *2 (-2 (|:| |var| (-607 *1)) (|:| -3483 (-568)))) (-4 *1 (-432 *3)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |val| (-887 *3)) (|:| -3483 (-763)))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-950 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| |var| *5) (|:| -3483 (-763)))))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-2 (|:| |var| *5) (|:| -3483 (-568)))) (-5 *1 (-951 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2747 ($ *7)) (-15 -2319 (*7 $)) (-15 -2326 (*7 $)))))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-1195))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-381)))) ((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-381))))) 
+(((*1 *1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-37 *3)) (-4 *3 (-365)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-634 *1)) (-5 *3 (-763)) (-4 *1 (-37 *4)) (-4 *4 (-365)))) ((*1 *2 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-971 *3)) (-4 *3 (-365)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-634 *1)) (-5 *3 (-763)) (-4 *1 (-971 *4)) (-4 *4 (-365))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *3)))) (-5 *1 (-593 *3)) (-4 *3 (-1047))))) 
+(((*1 *2 *3 *3 *3 *3) (-12 (-4 *4 (-453)) (-4 *3 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-450 *4 *3 *5 *6)) (-4 *6 (-950 *4 *3 *5))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-558)) (-4 *4 (-993 *3)) (-5 *1 (-143 *3 *4 *2)) (-4 *2 (-375 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-993 *4)) (-4 *2 (-375 *4)) (-5 *1 (-512 *4 *5 *2 *3)) (-4 *3 (-375 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-679 *5)) (-4 *5 (-993 *4)) (-4 *4 (-558)) (-5 *2 (-679 *4)) (-5 *1 (-682 *4 *5)))) ((*1 *2 *2) (-12 (-4 *3 (-558)) (-4 *4 (-993 *3)) (-5 *1 (-1212 *3 *4 *2)) (-4 *2 (-1219 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3848 *4) (|:| -3206 (-568))))) (-4 *4 (-1219 (-568))) (-5 *2 (-727 (-763))) (-5 *1 (-443 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-420 *5)) (-4 *5 (-1219 *4)) (-4 *4 (-1047)) (-5 *2 (-727 (-763))) (-5 *1 (-445 *4 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
+(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
+(((*1 *2 *3 *1) (-12 (-4 *1 (-977 *4 *5 *6 *3)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-5 *2 (-2 (|:| |rnum| *4) (|:| |polnum| *3) (|:| |den| *4)))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *4 (-568))) (-5 *5 (-1 (-1141 *4))) (-4 *4 (-365)) (-4 *4 (-1047)) (-5 *2 (-1141 *4)) (-5 *1 (-1145 *4))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *2)) (-4 *2 (-138)) (-5 *1 (-1076 *2)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-568) *2 *2)) (-4 *2 (-138)) (-5 *1 (-1076 *2))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3850 *4) (|:| -1836 (-568))))) (-4 *4 (-1219 (-568))) (-5 *2 (-727 (-763))) (-5 *1 (-443 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-420 *5)) (-4 *5 (-1219 *4)) (-4 *4 (-1047)) (-5 *2 (-727 (-763))) (-5 *1 (-445 *4 *5))))) 
+(((*1 *2) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-634 (-634 *4))) (-5 *1 (-339 *3 *4 *5 *6)) (-4 *3 (-340 *4 *5 *6)))) ((*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *3 (-370)) (-5 *2 (-634 (-634 *3))))) ((*1 *2) (-12 (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *7)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2) (-12 (-5 *2 (-634 (-967 *3))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-634 (-966 *3))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1699 *6) (-763))) (-5 *2 (-634 *8)) (-5 *1 (-963 *5 *6 *3 *7 *8)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5))))) 
+(((*1 *1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *2 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1249)) (-5 *1 (-450 *4 *5 *6 *3)) (-4 *3 (-950 *4 *5 *6))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-365)) (-5 *1 (-758 *2 *3)) (-4 *2 (-698 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 *5 (-634 *5))) (-4 *5 (-1234 *4)) (-4 *4 (-43 (-409 (-568)))) (-5 *2 (-1 (-1141 *4) (-634 (-1141 *4)))) (-5 *1 (-1236 *4 *5))))) 
 (((*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) ((*1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *2 *3) (-12 (-4 *4 (-375 *2)) (-4 *5 (-375 *2)) (-4 *2 (-365)) (-5 *1 (-529 *2 *4 *5 *3)) (-4 *3 (-677 *2 *4 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (|has| *2 (-6 (-4521 "*"))) (-4 *2 (-1047)))) ((*1 *2 *3) (-12 (-4 *4 (-375 *2)) (-4 *5 (-375 *2)) (-4 *2 (-172)) (-5 *1 (-678 *2 *4 *5 *3)) (-4 *3 (-677 *2 *4 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-1111 *3 *2 *4 *5)) (-4 *4 (-230 *3 *2)) (-4 *5 (-230 *3 *2)) (|has| *2 (-6 (-4521 "*"))) (-4 *2 (-1047))))) 
+(((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-166 *2)) (-4 *2 (-172)) (-4 *2 (-558)))) ((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-324 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)) (-4 *2 (-558)))) ((*1 *1 *1 *1) (|partial| -4 *1 (-558))) ((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (-4 *2 (-558)))) ((*1 *1 *1 *1) (|partial| -5 *1 (-763))) ((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-558)))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1244 *4)) (-4 *4 (-1219 *3)) (-4 *3 (-558)) (-5 *1 (-970 *3 *4)))) ((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-1050 *3 *4 *2 *5 *6)) (-4 *2 (-1047)) (-4 *5 (-230 *4 *2)) (-4 *6 (-230 *3 *2)) (-4 *2 (-558)))) ((*1 *2 *2 *2) (|partial| -12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-634 *3)) (-4 *3 (-1195))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))) (-5 *1 (-444 *4 *3 *2)) (-4 *3 (-1219 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-917)) (-4 *5 (-842)) (-5 *2 (-64 (-634 (-663 *5)))) (-5 *1 (-663 *5))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-375 *2)) (-4 *5 (-375 *2)) (-4 *2 (-365)) (-5 *1 (-529 *2 *4 *5 *3)) (-4 *3 (-677 *2 *4 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (|has| *2 (-6 (-4523 "*"))) (-4 *2 (-1047)))) ((*1 *2 *3) (-12 (-4 *4 (-375 *2)) (-4 *5 (-375 *2)) (-4 *2 (-172)) (-5 *1 (-678 *2 *4 *5 *3)) (-4 *3 (-677 *2 *4 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-1111 *3 *2 *4 *5)) (-4 *4 (-230 *3 *2)) (-4 *5 (-230 *3 *2)) (|has| *2 (-6 (-4523 "*"))) (-4 *2 (-1047))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-301)) (-5 *2 (-121))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1244 *4)) (-4 *4 (-419 *3)) (-4 *3 (-301)) (-4 *3 (-558)) (-5 *1 (-48 *3 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-365)) (-5 *2 (-1244 *1)) (-4 *1 (-327 *4)))) ((*1 *2) (-12 (-4 *3 (-365)) (-5 *2 (-1244 *1)) (-4 *1 (-327 *3)))) ((*1 *2) (-12 (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-1244 *1)) (-4 *1 (-411 *3 *4)))) ((*1 *2 *1) (-12 (-4 *3 (-301)) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-5 *2 (-1244 *6)) (-5 *1 (-415 *3 *4 *5 *6)) (-4 *6 (-13 (-411 *4 *5) (-1037 *4))))) ((*1 *2 *1) (-12 (-4 *3 (-301)) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-5 *2 (-1244 *6)) (-5 *1 (-416 *3 *4 *5 *6 *7)) (-4 *6 (-411 *4 *5)) (-14 *7 *2))) ((*1 *2) (-12 (-4 *3 (-172)) (-5 *2 (-1244 *1)) (-4 *1 (-419 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1244 (-1244 *4))) (-5 *1 (-532 *4)) (-4 *4 (-350))))) 
+(((*1 *2) (|partial| -12 (-4 *3 (-558)) (-4 *3 (-172)) (-5 *2 (-2 (|:| |particular| *1) (|:| -2588 (-634 *1)))) (-4 *1 (-369 *3)))) ((*1 *2) (|partial| -12 (-5 *2 (-2 (|:| |particular| (-454 *3 *4 *5 *6)) (|:| -2588 (-634 (-454 *3 *4 *5 *6))))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
 (((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-910 *3)) (-4 *3 (-301))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1084 *3)) (-5 *1 (-1082 *3)) (-4 *3 (-1195)))) ((*1 *1 *2 *2) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195)))) ((*1 *1 *2) (-12 (-5 *1 (-1210 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *5 "failed") *7)) (-5 *4 (-1157 *7)) (-4 *5 (-1047)) (-4 *7 (-1047)) (-4 *2 (-1219 *5)) (-5 *1 (-510 *5 *2 *6 *7)) (-4 *6 (-1219 *2))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *3 *3 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-679 (-568))) (-5 *1 (-1100))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-123)) (-5 *4 (-1161)) (-4 *6 (-1047)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-2 (|:| -2047 (-3 (-568) "failed")) (|:| -3894 (-3 (-568) "failed")) (|:| |ker| (-607 *5)))) (-5 *1 (-1024 *6 *5)) (-4 *5 (-13 (-432 *6) (-23) (-1037 (-568)) (-1037 *4) (-895 *4) (-161)))))) 
 (((*1 *2 *1) (-12 (-4 *2 (-558)) (-5 *1 (-615 *2 *3)) (-4 *3 (-1219 *2))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-111 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) ((*1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-568)) (-5 *2 (-634 (-634 (-215)))) (-5 *1 (-1192))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-568)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-817)) (-5 *1 (-816))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-271))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1219 (-409 *2))) (-5 *2 (-568)) (-5 *1 (-909 *4 *3)) (-4 *3 (-1219 (-409 *4)))))) 
+(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-230 *5 (-763))) (-14 *5 (-763)) (-5 *1 (-908 *3 *2 *4 *5)) (-4 *2 (-324 *3 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568)))))) (-5 *2 (-634 (-409 (-568)))) (-5 *1 (-1019 *4)) (-4 *4 (-1219 (-568)))))) 
 (((*1 *1 *1 *1) (-5 *1 (-121))) ((*1 *1 *1 *1) (-4 *1 (-132)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-310 (-215)))) (-5 *2 (-121)) (-5 *1 (-263))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3145 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *1 (-1145 *3))))) 
+(((*1 *2 *3 *2 *4) (|partial| -12 (-5 *4 (-1 (-3 (-568) "failed") *5)) (-4 *5 (-1047)) (-5 *2 (-568)) (-5 *1 (-548 *5 *3)) (-4 *3 (-1219 *5)))) ((*1 *2 *3 *4 *2 *5) (|partial| -12 (-5 *5 (-1 (-3 (-568) "failed") *4)) (-4 *4 (-1047)) (-5 *2 (-568)) (-5 *1 (-548 *4 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-1 (-3 (-568) "failed") *4)) (-4 *4 (-1047)) (-5 *2 (-568)) (-5 *1 (-548 *4 *3)) (-4 *3 (-1219 *4))))) 
 (((*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 *2)) (-4 *2 (-1234 *4)) (-5 *1 (-1236 *4 *2)) (-4 *4 (-43 (-409 (-568))))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-173 *2)) (-4 *2 (-301)))) ((*1 *2 *1) (-12 (-5 *1 (-910 *2)) (-4 *2 (-301)))) ((*1 *2 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)) (-4 *2 (-301)))) ((*1 *2 *1) (-12 (-4 *1 (-1056)) (-5 *2 (-568))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 *6 *4 *5)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-1 *6 *5 *4)) (-5 *1 (-673 *4 *5 *6))))) 
+(((*1 *1 *2 *3 *3 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-121)) (-5 *1 (-887 *4)) (-4 *4 (-1090))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-568))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4436 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))))) (-5 *2 (-634 (-1143))) (-5 *1 (-263))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1094)) (-5 *1 (-328))))) 
+(((*1 *1 *2 *2 *2 *2 *2 *2 *2 *2) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-999 *3)) (-4 *3 (-172)) (-5 *1 (-794 *3))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 (-310 (-215)))) (-5 *1 (-263))))) 
 (((*1 *2 *1) (|partial| -12 (-5 *2 (-1143)) (-5 *1 (-1177))))) 
+(((*1 *1 *1 *1) (|partial| -12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
+(((*1 *2 *3 *3 *3) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1100)) (-5 *3 (-568))))) 
+(((*1 *2 *3) (-12 (-4 *3 (-1219 (-409 (-568)))) (-5 *2 (-2 (|:| |den| (-568)) (|:| |gcdnum| (-568)))) (-5 *1 (-909 *3 *4)) (-4 *4 (-1219 (-409 *3))))) ((*1 *2 *3) (-12 (-4 *4 (-1219 (-409 *2))) (-5 *2 (-568)) (-5 *1 (-909 *4 *3)) (-4 *3 (-1219 (-409 *4)))))) 
+(((*1 *2 *3 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-121)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-121)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) ((*1 *2 *3 *1) (-12 (|has| *1 (-6 -4521)) (-4 *1 (-499 *3)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-900 *4)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-899 *4)))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-121)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-917)) (-5 *2 (-121)) (-5 *1 (-1091 *4 *5)) (-14 *4 *3) (-14 *5 *3))) ((*1 *2 *3 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-121)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-568))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *3 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-634 *3)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13)) (-4 *12 (-258 *3))))) 
+(((*1 *2 *1 *3) (-12 (-4 *1 (-340 *4 *3 *5)) (-4 *4 (-1199)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 (-409 *3))) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *1 *1 *1) (-4 *1 (-1124)))) 
+(((*1 *2 *2 *2 *3) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-5 *1 (-653 *3))))) 
 (((*1 *2 *1) (|partial| -12 (-4 *1 (-641 *3)) (-4 *3 (-365)) (-5 *2 (-568))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-679 *4)) (-5 *3 (-917)) (|has| *4 (-6 (-4523 "*"))) (-4 *4 (-1047)) (-5 *1 (-1028 *4)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-634 (-679 *4))) (-5 *3 (-917)) (|has| *4 (-6 (-4523 "*"))) (-4 *4 (-1047)) (-5 *1 (-1028 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-121))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-491))))) 
+(((*1 *2 *3 *4 *5 *6) (-12 (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *9 (-230 (-1699 *7) (-763))) (-5 *2 (-2 (|:| |mult| (-763)) (|:| |subMult| (-763)) (|:| |blUpRec| (-634 (-2 (|:| |recTransStr| (-242 (-4289 (QUOTE X) (QUOTE -2928)) *6)) (|:| |recPoint| (-33 *6)) (|:| |recChart| *5) (|:| |definingExtension| *6)))))) (-5 *1 (-119 *6 *7 *8 *9 *5)) (-5 *3 (-242 (-4289 (QUOTE X) (QUOTE -2928)) *6)) (-5 *4 (-33 *6)) (-4 *8 (-324 *6 *9)) (-4 *5 (-117))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-601 *2 *3)) (-4 *3 (-1195)) (-4 *2 (-1090)) (-4 *2 (-842))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-4 *6 (-324 *5 *7)) (-4 *7 (-230 *8 (-763))) (-14 *8 (-763)) (-4 *5 (-365)) (-5 *2 (-121)) (-5 *1 (-929 *5 *6 *7 *8 *4)) (-4 *4 (-971 *5))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-5 *2 (-121))))) 
 (((*1 *1 *1 *2) (-12 (-5 *1 (-1125 *3 *2)) (-4 *3 (-13 (-1090) (-39))) (-4 *2 (-13 (-1090) (-39)))))) 
+(((*1 *2 *3 *3) (-12 (-4 *2 (-558)) (-4 *2 (-453)) (-5 *1 (-970 *2 *3)) (-4 *3 (-1219 *2))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-2 (|:| -3497 *5) (|:| -2410 *3)))) (-5 *1 (-804 *5 *6 *3 *7)) (-4 *3 (-646 *6)) (-4 *7 (-646 (-409 *6)))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -2910 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-634 (-1161))) (-5 *2 (-634 (-634 (-381)))) (-5 *1 (-1022)) (-5 *5 (-381)))) ((*1 *2 *3) (-12 (-5 *3 (-1044 *4 *5)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *5 (-634 (-1161))) (-5 *2 (-634 (-634 (-1023 (-409 *4))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *6 (-634 (-1161))))) ((*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *5))))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *5))))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *5))))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *4))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161)))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-1249)) (-5 *1 (-465))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-634 (-2 (|:| |deg| (-763)) (|:| -1632 *3)))) (-5 *1 (-207 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *1 *2 *2 *2 *2 *2 *3 *4) (-12 (-5 *2 (-568)) (-5 *3 (-121)) (-5 *4 (-3 "left" "center" "right" "vertical" "horizontal")) (-4 *1 (-117))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-977 *3 *4 *2 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *5 (-1061 *3 *4 *2))))) 
+(((*1 *2 *2 *3 *4) (|partial| -12 (-5 *4 (-1 *3)) (-4 *3 (-842)) (-4 *5 (-788)) (-4 *6 (-558)) (-4 *7 (-950 *6 *5 *3)) (-5 *1 (-466 *5 *3 *6 *7 *2)) (-4 *2 (-13 (-1037 (-409 (-568))) (-365) (-10 -8 (-15 -2747 ($ *7)) (-15 -2319 (*7 $)) (-15 -2326 (*7 $)))))))) 
 (((*1 *1 *1 *2 *3) (-12 (-5 *2 (-568)) (-4 *1 (-62 *4 *5 *3)) (-4 *4 (-1195)) (-4 *5 (-375 *4)) (-4 *3 (-375 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *5 (-370)) (-5 *2 (-763))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1092 (-1161))) (-5 *1 (-58)) (-5 *3 (-1161))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-62 *4 *5 *2)) (-4 *4 (-1195)) (-4 *5 (-375 *4)) (-4 *2 (-375 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1050 *4 *5 *6 *7 *2)) (-4 *6 (-1047)) (-4 *7 (-230 *5 *6)) (-4 *2 (-230 *4 *6))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
 (((*1 *2 *2 *2) (-12 (-4 *3 (-365)) (-5 *1 (-758 *2 *3)) (-4 *2 (-698 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
+(((*1 *1 *1 *1) (-4 *1 (-550)))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *3 (-634 (-256))) (-5 *1 (-254))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1201 *2)) (-4 *2 (-1047)))) ((*1 *1 *1) (-12 (-5 *1 (-1235 *2 *3 *4)) (-4 *2 (-1047)) (-14 *3 (-1161)) (-14 *4 *2))) ((*1 *1 *1) (-12 (-5 *1 (-1239 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-1161))))) 
+(((*1 *1 *2) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181)))))) 
 (((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-3 "nil" "sqfr" "irred" "prime")) (-5 *1 (-420 *4)) (-4 *4 (-558))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $))))) (-4 *6 (-558)) (-5 *2 (-2 (|:| -1462 (-953 *6)) (|:| -3582 (-953 *6)))) (-5 *1 (-722 *4 *5 *6 *3)) (-4 *3 (-950 (-409 (-953 *6)) *4 *5))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-105)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-917)) (-5 *1 (-1032 *2)) (-4 *2 (-13 (-1090) (-10 -8 (-15 * ($ $ $)))))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-634 *2)) (-5 *1 (-122 *2)) (-4 *2 (-1090)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *4 (-634 *4))) (-4 *4 (-1090)) (-5 *1 (-122 *4)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *4 *4)) (-4 *4 (-1090)) (-5 *1 (-122 *4)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-123)) (-5 *2 (-1 *4 (-634 *4))) (-5 *1 (-122 *4)) (-4 *4 (-1090)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-637 *3)) (-4 *3 (-1047)) (-5 *1 (-704 *3 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-829 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *5)) (-4 *5 (-13 (-27) (-1181) (-432 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-409 (-568))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-288 *3)) (-5 *5 (-409 (-568))) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *6 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 (-568))) (-5 *4 (-288 *6)) (-4 *6 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *6 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *7 (-568))) (-5 *4 (-288 *7)) (-5 *5 (-1210 (-568))) (-4 *7 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *6 *7)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-5 *6 (-1210 (-568))) (-4 *3 (-13 (-27) (-1181) (-432 *7))) (-4 *7 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *7 *3)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *8 (-409 (-568)))) (-5 *4 (-288 *8)) (-5 *5 (-1210 (-409 (-568)))) (-5 *6 (-409 (-568))) (-4 *8 (-13 (-27) (-1181) (-432 *7))) (-4 *7 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *7 *8)))) ((*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-5 *6 (-1210 (-409 (-568)))) (-5 *7 (-409 (-568))) (-4 *3 (-13 (-27) (-1181) (-432 *8))) (-4 *8 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *8 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *3)))) (-4 *3 (-1047)) (-5 *1 (-593 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-594 *3)))) ((*1 *1 *2 *3 *1) (-12 (-5 *2 (-568)) (-4 *1 (-641 *3)) (-4 *3 (-365)))) ((*1 *1 *2) (-12 (-5 *2 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *3)))) (-4 *3 (-1047)) (-4 *1 (-1203 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *3 (-1141 (-2 (|:| |k| (-409 (-568))) (|:| |c| *4)))) (-4 *4 (-1047)) (-4 *1 (-1224 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-4 *1 (-1234 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1141 (-2 (|:| |k| (-763)) (|:| |c| *3)))) (-4 *3 (-1047)) (-4 *1 (-1234 *3))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $))))) (-4 *6 (-558)) (-5 *2 (-2 (|:| -2409 (-953 *6)) (|:| -2933 (-953 *6)))) (-5 *1 (-722 *4 *5 *6 *3)) (-4 *3 (-950 (-409 (-953 *6)) *4 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *5)) (-4 *5 (-432 *4)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-850)) (-5 *1 (-36 *4 *5))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-256))) (-5 *1 (-1245)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-256))) (-5 *1 (-1245)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-256))) (-5 *1 (-1246)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-256))) (-5 *1 (-1246))))) 
+(((*1 *2 *2 *3 *3) (-12 (-5 *2 (-679 *3)) (-4 *3 (-301)) (-5 *1 (-689 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1141 (-1141 *4))) (-5 *2 (-1141 *4)) (-5 *1 (-1145 *4)) (-4 *4 (-1047))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-139))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (-5 *1 (-184))))) 
+(((*1 *1 *2 *3 *3 *4 *5) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *3 (-634 (-869))) (-5 *4 (-634 (-917))) (-5 *5 (-634 (-256))) (-5 *1 (-473)))) ((*1 *1 *2 *3 *3 *4) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *3 (-634 (-869))) (-5 *4 (-634 (-917))) (-5 *1 (-473)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *1 (-473)))) ((*1 *1 *1) (-5 *1 (-473)))) 
+(((*1 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) ((*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-634 (-634 *4))) (-5 *3 (-634 *4)) (-4 *4 (-365)) (-5 *1 (-653 *4))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (-5 *1 (-184))))) 
+(((*1 *1 *1) (-4 *1 (-1129)))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-453)))) ((*1 *1 *1 *1) (-4 *1 (-453)))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-450 *4 *5 *6 *2))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-328))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-13 (-558) (-453))) (-5 *2 (-634 *4)) (-5 *1 (-346 *4 *5)) (-4 *5 (-52 *4 *3))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-381)) (-5 *1 (-1039))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *7 *7)) (-4 *7 (-1219 *6)) (-4 *6 (-13 (-27) (-432 *5))) (-4 *5 (-13 (-842) (-558) (-1037 (-568)))) (-4 *8 (-1219 (-409 *7))) (-5 *2 (-585 *3)) (-5 *1 (-553 *5 *6 *7 *8 *3)) (-4 *3 (-340 *6 *7 *8))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1249)) (-5 *1 (-1245)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-666 *3)) (-4 *3 (-1047)) (-4 *3 (-1090))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-62 *2 *3 *4)) (-4 *2 (-1195)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) ((*1 *1 *1 *2) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-601 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195))))) 
+(((*1 *2) (-12 (-5 *2 (-634 (-763))) (-5 *1 (-1247)))) ((*1 *2 *2) (-12 (-5 *2 (-634 (-763))) (-5 *1 (-1247))))) 
 (((*1 *2 *2 *2 *3 *3 *4 *2 *5) (|partial| -12 (-5 *3 (-607 *2)) (-5 *4 (-1 (-3 *2 "failed") *2 *2 (-1161))) (-5 *5 (-1157 *2)) (-4 *2 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *1 (-564 *6 *2 *7)) (-4 *7 (-1090)))) ((*1 *2 *2 *2 *3 *3 *4 *3 *2 *5) (|partial| -12 (-5 *3 (-607 *2)) (-5 *4 (-1 (-3 *2 "failed") *2 *2 (-1161))) (-5 *5 (-409 (-1157 *2))) (-4 *2 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *1 (-564 *6 *2 *7)) (-4 *7 (-1090))))) 
+(((*1 *2 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-842)) (-5 *2 (-2 (|:| |f1| (-634 *4)) (|:| |f2| (-634 (-634 (-634 *4)))) (|:| |f3| (-634 (-634 *4))) (|:| |f4| (-634 (-634 (-634 *4)))))) (-5 *1 (-1167 *4)) (-5 *3 (-634 (-634 (-634 *4))))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-13 (-301) (-10 -8 (-15 -3498 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *1 (-508 *3 *4 *5)) (-4 *5 (-411 *3 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -2852 *4) (|:| -4308 (-568))))) (-4 *4 (-1090)) (-5 *2 (-1 *4)) (-5 *1 (-1017 *4))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *1 (-1145 *3))))) 
 (((*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-1244 *6)) (-5 *1 (-334 *3 *4 *5 *6)) (-4 *6 (-340 *3 *4 *5))))) 
+(((*1 *2 *1 *3 *3) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-601 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1195)) (-5 *2 (-1249))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-889 *2 *3)) (-4 *2 (-1219 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-679 (-409 (-568)))) (-5 *2 (-634 *4)) (-5 *1 (-773 *4)) (-4 *4 (-13 (-365) (-840)))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-634 *7)) (|:| |badPols| (-634 *7)))) (-5 *1 (-978 *4 *5 *6 *7)) (-5 *3 (-634 *7))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-172)) (-4 *2 (-23)) (-5 *1 (-284 *3 *4 *2 *5 *6 *7)) (-4 *4 (-1219 *3)) (-14 *5 (-1 *4 *4 *2)) (-14 *6 (-1 (-3 *2 "failed") *2 *2)) (-14 *7 (-1 (-3 *4 "failed") *4 *4 *2)))) ((*1 *2 *1) (-12 (-4 *2 (-23)) (-5 *1 (-701 *3 *2 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-1 *3 *3 *2)) (-14 *5 (-1 (-3 *2 "failed") *2 *2)) (-14 *6 (-1 (-3 *3 "failed") *3 *3 *2)))) ((*1 *2) (-12 (-4 *2 (-1219 *3)) (-5 *1 (-702 *3 *2)) (-4 *3 (-1047)))) ((*1 *2 *1) (-12 (-4 *2 (-23)) (-5 *1 (-705 *3 *2 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-1 *3 *3 *2)) (-14 *5 (-1 (-3 *2 "failed") *2 *2)) (-14 *6 (-1 (-3 *3 "failed") *3 *3 *2)))) ((*1 *2) (-12 (-4 *1 (-863 *3)) (-5 *2 (-568))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1265 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-838))))) 
+(((*1 *1 *1) (-4 *1 (-858)))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *1 (-799 *4 *2)) (-4 *2 (-13 (-29 *4) (-1181) (-959))))) ((*1 *1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1) (-5 *1 (-850))) ((*1 *2 *3) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-1145 *3)) (-4 *3 (-1047))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-565)) (-5 *3 (-568))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-993 *2)) (-4 *2 (-558)) (-5 *1 (-143 *2 *4 *3)) (-4 *3 (-375 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-993 *2)) (-4 *2 (-558)) (-5 *1 (-512 *2 *4 *5 *3)) (-4 *5 (-375 *2)) (-4 *3 (-375 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-679 *4)) (-4 *4 (-993 *2)) (-4 *2 (-558)) (-5 *1 (-682 *2 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-993 *2)) (-4 *2 (-558)) (-5 *1 (-1212 *2 *4 *3)) (-4 *3 (-1219 *4))))) 
 (((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-1132 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-369 *2)) (-4 *2 (-172))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| -2350 (-409 *5)) (|:| |poly| *3))) (-5 *1 (-151 *4 *5 *3)) (-4 *3 (-1219 (-409 *5)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1084 *3)) (-5 *1 (-1082 *3)) (-4 *3 (-1195)))) ((*1 *1 *2 *2) (-12 (-4 *1 (-1083 *2)) (-4 *2 (-1195)))) ((*1 *1 *2) (-12 (-5 *1 (-1210 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-139))))) 
 (((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-409 (-953 *4))) (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-1037 (-568)) (-150))) (-5 *1 (-574 *4))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-250))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-634 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-763)) (|:| |poli| *3) (|:| |polj| *3)))) (-4 *5 (-788)) (-4 *3 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *6 (-842)) (-5 *1 (-450 *4 *5 *6 *3))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-950 *4 *5 *6)) (-5 *2 (-634 (-634 *7))) (-5 *1 (-449 *4 *5 *6 *7)) (-5 *3 (-634 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-950 *5 *6 *7)) (-5 *2 (-634 (-634 *8))) (-5 *1 (-449 *5 *6 *7 *8)) (-5 *3 (-634 *8))))) 
+(((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-128 *2)) (-4 *2 (-1195))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047))))) 
+(((*1 *1 *2 *3 *4) (-12 (-14 *5 (-634 (-1161))) (-4 *2 (-172)) (-4 *4 (-230 (-1699 *5) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4357 *3) (|:| -3483 *4)) (-2 (|:| -4357 *3) (|:| -3483 *4)))) (-5 *1 (-463 *5 *2 *3 *4 *6 *7)) (-4 *3 (-842)) (-4 *7 (-950 *2 *4 (-852 *5)))))) 
+(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-563))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-953 *4)) (-4 *4 (-1047)) (-4 *4 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-953 *5)) (-5 *4 (-917)) (-4 *5 (-1047)) (-4 *5 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-558)) (-4 *4 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-310 *4)) (-4 *4 (-558)) (-4 *4 (-842)) (-4 *4 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-310 *5)) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-842)) (-4 *5 (-609 *2)) (-5 *2 (-381)) (-5 *1 (-780 *5))))) 
+(((*1 *1 *1 *2 *3 *1) (-12 (-4 *1 (-324 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787))))) 
 (((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *1 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-37 *2)) (-4 *2 (-365)))) ((*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1195)) (-4 *4 (-375 *2)) (-4 *5 (-375 *2)))) ((*1 *1 *1 *2 *1) (-12 (-5 *2 "right") (|has| *1 (-6 -4520)) (-4 *1 (-128 *3)) (-4 *3 (-1195)))) ((*1 *1 *1 *2 *1) (-12 (-5 *2 "left") (|has| *1 (-6 -4520)) (-4 *1 (-128 *3)) (-4 *3 (-1195)))) ((*1 *2 *1 *3 *2) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-283 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195)))) ((*1 *2 *1 *3 *2) (-12 (-5 *2 (-57)) (-5 *3 (-1161)) (-5 *1 (-623)))) ((*1 *2 *1 *3 *2) (-12 (-5 *3 (-1210 (-568))) (|has| *1 (-6 -4520)) (-4 *1 (-640 *2)) (-4 *2 (-1195)))) ((*1 *1 *1 *2 *2 *1) (-12 (-5 *2 (-634 (-568))) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *2 *1 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-971 *2)) (-4 *2 (-365)))) ((*1 *2 *1 *3 *2) (-12 (-5 *3 "value") (|has| *1 (-6 -4520)) (-4 *1 (-1010 *2)) (-4 *2 (-1195)))) ((*1 *2 *1 *2) (-12 (-5 *1 (-1026 *2)) (-4 *2 (-1195)))) ((*1 *2 *1 *3 *2) (-12 (-4 *1 (-1172 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090)))) ((*1 *2 *1 *3 *2) (-12 (-5 *3 "last") (|has| *1 (-6 -4520)) (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) ((*1 *1 *1 *2 *1) (-12 (-5 *2 "rest") (|has| *1 (-6 -4520)) (-4 *1 (-1231 *3)) (-4 *3 (-1195)))) ((*1 *2 *1 *3 *2) (-12 (-5 *3 "first") (|has| *1 (-6 -4520)) (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *3 *1) (-12 (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-1006))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-105)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-420 (-1157 (-568)))) (-5 *1 (-183)) (-5 *3 (-568))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-288 (-409 (-953 *5)))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-1150 (-634 (-310 *5)) (-634 (-288 (-310 *5))))) (-5 *1 (-1117 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-1150 (-634 (-310 *5)) (-634 (-288 (-310 *5))))) (-5 *1 (-1117 *5))))) 
+(((*1 *2 *3) (-12 (-4 *3 (-13 (-301) (-10 -8 (-15 -3498 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *2 (-2 (|:| -2588 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-5 *1 (-351 *3 *4 *5)) (-4 *5 (-411 *3 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1219 *3)) (-5 *2 (-2 (|:| -2588 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-5 *1 (-760 *4 *5)) (-4 *5 (-411 *3 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-350)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 *3)) (-5 *2 (-2 (|:| -2588 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-5 *1 (-986 *4 *3 *5 *6)) (-4 *6 (-714 *3 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-350)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 *3)) (-5 *2 (-2 (|:| -2588 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-5 *1 (-1253 *4 *3 *5 *6)) (-4 *6 (-411 *3 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) ((*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
 (((*1 *2 *2 *3 *3 *4) (-12 (-5 *4 (-763)) (-4 *3 (-558)) (-5 *1 (-970 *3 *2)) (-4 *2 (-1219 *3))))) 
+(((*1 *2 *1) (|partial| -12 (-5 *2 (-763)) (-5 *1 (-123))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-1161)) (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117))))) 
+(((*1 *2 *1 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-37 *2)) (-4 *2 (-365)))) ((*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1195)) (-4 *4 (-375 *2)) (-4 *5 (-375 *2)))) ((*1 *1 *1 *2 *1) (-12 (-5 *2 "right") (|has| *1 (-6 -4522)) (-4 *1 (-128 *3)) (-4 *3 (-1195)))) ((*1 *1 *1 *2 *1) (-12 (-5 *2 "left") (|has| *1 (-6 -4522)) (-4 *1 (-128 *3)) (-4 *3 (-1195)))) ((*1 *2 *1 *3 *2) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-283 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195)))) ((*1 *2 *1 *3 *2) (-12 (-5 *2 (-57)) (-5 *3 (-1161)) (-5 *1 (-623)))) ((*1 *2 *1 *3 *2) (-12 (-5 *3 (-1210 (-568))) (|has| *1 (-6 -4522)) (-4 *1 (-640 *2)) (-4 *2 (-1195)))) ((*1 *1 *1 *2 *2 *1) (-12 (-5 *2 (-634 (-568))) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *2 *1 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-971 *2)) (-4 *2 (-365)))) ((*1 *2 *1 *3 *2) (-12 (-5 *3 "value") (|has| *1 (-6 -4522)) (-4 *1 (-1010 *2)) (-4 *2 (-1195)))) ((*1 *2 *1 *2) (-12 (-5 *1 (-1026 *2)) (-4 *2 (-1195)))) ((*1 *2 *1 *3 *2) (-12 (-4 *1 (-1172 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090)))) ((*1 *2 *1 *3 *2) (-12 (-5 *3 "last") (|has| *1 (-6 -4522)) (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) ((*1 *1 *1 *2 *1) (-12 (-5 *2 "rest") (|has| *1 (-6 -4522)) (-4 *1 (-1231 *3)) (-4 *3 (-1195)))) ((*1 *2 *1 *3 *2) (-12 (-5 *3 "first") (|has| *1 (-6 -4522)) (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-634 (-944 *3)))))) ((*1 *1 *2 *3 *3) (-12 (-5 *2 (-634 (-634 (-944 *4)))) (-5 *3 (-121)) (-4 *4 (-1047)) (-4 *1 (-1122 *4)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-634 (-944 *3)))) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) ((*1 *1 *1 *2 *3 *3) (-12 (-5 *2 (-634 (-634 (-634 *4)))) (-5 *3 (-121)) (-4 *1 (-1122 *4)) (-4 *4 (-1047)))) ((*1 *1 *1 *2 *3 *3) (-12 (-5 *2 (-634 (-634 (-944 *4)))) (-5 *3 (-121)) (-4 *1 (-1122 *4)) (-4 *4 (-1047)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-634 (-634 (-634 *5)))) (-5 *3 (-634 (-171))) (-5 *4 (-171)) (-4 *1 (-1122 *5)) (-4 *5 (-1047)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-634 (-634 (-944 *5)))) (-5 *3 (-634 (-171))) (-5 *4 (-171)) (-4 *1 (-1122 *5)) (-4 *5 (-1047))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-39)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-494 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-4 *3 (-453)) (-4 *4 (-842)) (-4 *5 (-788)) (-5 *2 (-121)) (-5 *1 (-988 *3 *4 *5 *6)) (-4 *6 (-950 *3 *5 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1132 *3)) (-4 *3 (-1090))))) 
 (((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
+(((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 *5))) (-5 *3 (-1157 *5)) (-4 *5 (-166 *4)) (-4 *4 (-550)) (-5 *1 (-152 *4 *5)))) ((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-1219 *4)) (-4 *4 (-350)) (-5 *1 (-359 *4 *5 *3)))) ((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 (-568)))) (-5 *3 (-1157 (-568))) (-5 *1 (-576)))) ((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 *1))) (-5 *3 (-1157 *1)) (-4 *1 (-904))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *2 (-13 (-432 *4) (-881 *3) (-609 (-887 *3)))) (-5 *1 (-1069 *3 *4 *2)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 (-887 *3)))))) ((*1 *2 *1) (-12 (-4 *2 (-1090)) (-5 *1 (-1150 *2 *3)) (-4 *3 (-1090))))) 
+(((*1 *1 *1 *1) (-4 *1 (-651))) ((*1 *1 *1 *1) (-5 *1 (-1108)))) 
+(((*1 *2 *1) (-12 (-5 *2 (-2 (|:| -3591 *1) (|:| -4508 *1) (|:| |associate| *1))) (-4 *1 (-558))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-256))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-427 *3)) (-4 *3 (-1090)) (-5 *2 (-763))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) ((*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-5 *2 (-634 (-2 (|:| -3850 *3) (|:| -1836 *4)))) (-5 *1 (-685 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-234))))) 
 (((*1 *1 *1 *1) (-4 *1 (-651))) ((*1 *1 *1 *1) (-5 *1 (-1108)))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-1143)) (-5 *3 (-818)) (-5 *1 (-817))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (|has| *2 (-6 (-4523 "*"))) (-4 *2 (-1047)))) ((*1 *2 *3) (-12 (-4 *4 (-375 *2)) (-4 *5 (-375 *2)) (-4 *2 (-172)) (-5 *1 (-678 *2 *4 *5 *3)) (-4 *3 (-677 *2 *4 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-1111 *3 *2 *4 *5)) (-4 *4 (-230 *3 *2)) (-4 *5 (-230 *3 *2)) (|has| *2 (-6 (-4523 "*"))) (-4 *2 (-1047))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) ((*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-390)) (-5 *1 (-623))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-568))) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-558)) (-4 *8 (-950 *7 *5 *6)) (-5 *2 (-2 (|:| -3483 (-763)) (|:| -2350 *9) (|:| |radicand| *9))) (-5 *1 (-954 *5 *6 *7 *8 *9)) (-5 *4 (-763)) (-4 *9 (-13 (-365) (-10 -8 (-15 -2319 (*8 $)) (-15 -2326 (*8 $)) (-15 -2747 ($ *8)))))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850))))) 
 (((*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-541))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-365)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-529 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5))))) 
+(((*1 *1 *1 *1) (-4 *1 (-301))) ((*1 *1 *1 *1) (-5 *1 (-763))) ((*1 *1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1006)))) ((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1006))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 (-634 (-568)))) (-5 *1 (-924 *4 *5 *6 *7)) (-5 *3 (-568)) (-4 *7 (-950 *4 *6 *5))))) 
 (((*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181))))) ((*1 *1 *1 *1) (-4 *1 (-788)))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-3 (-409 (-953 *5)) (-1150 (-1161) (-953 *5)))) (-4 *5 (-453)) (-5 *2 (-634 (-679 (-409 (-953 *5))))) (-5 *1 (-286 *5)) (-5 *4 (-679 (-409 (-953 *5))))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-835 (-381))) (-5 *2 (-835 (-215))) (-5 *1 (-299))))) 
 (((*1 *1 *1) (-4 *1 (-146))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *2 *2) (-12 (-5 *1 (-160 *2)) (-4 *2 (-550))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1244 (-679 *4))) (-4 *4 (-172)) (-5 *2 (-1244 (-679 (-953 *4)))) (-5 *1 (-181 *4))))) 
+(((*1 *2) (-12 (-4 *1 (-406)) (-5 *2 (-917)))) ((*1 *1) (-4 *1 (-550))) ((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-688)))) ((*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-688)))) ((*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-899 *3)) (-4 *3 (-1090))))) 
+(((*1 *1 *1 *1) (-4 *1 (-301))) ((*1 *1 *1 *1) (-5 *1 (-763))) ((*1 *1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1094)) (-5 *1 (-57))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-381)) (-5 *1 (-197))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-568))) (-5 *4 (-568)) (-5 *2 (-57)) (-5 *1 (-1005))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1108)) (-5 *2 (-121)) (-5 *1 (-816))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-593 *3)) (-4 *3 (-43 *2)) (-4 *3 (-1047))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-166 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-409 (-568))))) ((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-420 *3)) (-4 *3 (-550)) (-4 *3 (-558)))) ((*1 *2 *1) (-12 (-4 *1 (-550)) (-5 *2 (-409 (-568))))) ((*1 *2 *1) (-12 (-4 *1 (-792 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-409 (-568))))) ((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-828 *3)) (-4 *3 (-550)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-835 *3)) (-4 *3 (-550)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-997 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-409 (-568))))) ((*1 *2 *3) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-1008 *3)) (-4 *3 (-1037 *2))))) 
-(((*1 *1 *1 *1) (-4 *1 (-651))) ((*1 *1 *1 *1) (-5 *1 (-1108)))) 
+(((*1 *2 *2 *3 *4) (-12 (-5 *2 (-242 (-4289 (QUOTE X) (QUOTE -2928)) *5)) (-4 *5 (-365)) (-5 *3 (-763)) (-14 *6 (-634 (-1161))) (-4 *8 (-230 (-1699 *6) *3)) (-5 *1 (-119 *5 *6 *7 *8 *4)) (-4 *7 (-324 *5 *8)) (-4 *4 (-117))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-171))))) 
+(((*1 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 (-2 (|:| -4151 *4) (|:| |coeff| *4)) "failed") *4)) (-4 *4 (-365)) (-5 *1 (-578 *4 *2)) (-4 *2 (-1219 *4))))) 
+(((*1 *2 *2 *3 *4) (|partial| -12 (-5 *3 (-763)) (-4 *4 (-13 (-558) (-150))) (-5 *1 (-1213 *4 *2)) (-4 *2 (-1219 *4))))) 
 (((*1 *2 *2) (|partial| -12 (-5 *2 (-310 (-215))) (-5 *1 (-263))))) 
+(((*1 *2 *1 *3) (|partial| -12 (-5 *3 (-887 *4)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-884 *4 *5)) (-4 *5 (-1090)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-5 *2 (-121)) (-5 *1 (-885 *5 *3)) (-4 *3 (-1195)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-4 *6 (-1195)) (-5 *2 (-121)) (-5 *1 (-885 *5 *6))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-365)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-37 *3)) (-4 *3 (-365)))) ((*1 *1 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)))) ((*1 *1 *1 *1) (-4 *1 (-478))) ((*1 *1 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) ((*1 *1 *1) (-4 *1 (-858))) ((*1 *2 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-878)))) ((*1 *1 *1) (-12 (-4 *1 (-971 *2)) (-4 *2 (-365)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-971 *3)) (-4 *3 (-365)))) ((*1 *1 *1) (-5 *1 (-972))) ((*1 *1 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-390)) (-5 *1 (-438)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-390)) (-5 *1 (-438))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-213 *2 *3)) (-4 *2 (-13 (-1047) (-842))) (-14 *3 (-634 (-1161)))))) 
 (((*1 *2 *1) (-12 (-4 *3 (-453)) (-4 *4 (-842)) (-4 *5 (-788)) (-5 *2 (-634 *6)) (-5 *1 (-988 *3 *4 *5 *6)) (-4 *6 (-950 *3 *5 *4))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) ((*1 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *1 *1) (-4 *1 (-1124)))) 
+(((*1 *1 *1 *1 *1) (-4 *1 (-550)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1092 *4)) (-4 *4 (-1090)) (-5 *2 (-1 *4)) (-5 *1 (-1017 *4)))) ((*1 *2 *3 *3) (-12 (-5 *2 (-1 (-381))) (-5 *1 (-1039)) (-5 *3 (-381)))) ((*1 *2 *3) (-12 (-5 *3 (-1084 (-568))) (-5 *2 (-1 (-568))) (-5 *1 (-1045))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *1 (-1226 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1203 *3))))) 
 (((*1 *1 *1) (-12 (-4 *1 (-641 *2)) (-4 *2 (-365))))) 
+(((*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *7)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2) (-12 (-5 *2 (-634 (-967 *3))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-634 (-966 *3))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-230 (-1699 *5) (-763))) (-5 *2 (-634 *7)) (-5 *1 (-963 *4 *5 *3 *6 *7)) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *7 (-971 *4))))) 
+(((*1 *2 *2 *2 *3 *3) (-12 (-5 *3 (-763)) (-4 *4 (-1047)) (-5 *1 (-1215 *4 *2)) (-4 *2 (-1219 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) ((*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
 (((*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 (-409 (-953 *4)))) (-5 *1 (-924 *4 *5 *6 *7)) (-4 *7 (-950 *4 *6 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-1 *6 *4 *5)) (-5 *1 (-673 *4 *5 *6)) (-4 *4 (-1090))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 *2) (-4 *5 (-172)))) ((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-917)) (-5 *1 (-165 *3 *4)) (-4 *3 (-166 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-917)))) ((*1 *2) (-12 (-4 *1 (-372 *3 *4)) (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-917)))) ((*1 *2 *3) (-12 (-4 *4 (-365)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-763)) (-5 *1 (-529 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-679 *5)) (-5 *4 (-1244 *5)) (-4 *5 (-365)) (-5 *2 (-763)) (-5 *1 (-659 *5)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-13 (-375 *5) (-10 -7 (-6 -4522)))) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4522)))) (-5 *2 (-763)) (-5 *1 (-660 *5 *6 *4 *3)) (-4 *3 (-677 *5 *6 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-4 *3 (-558)) (-5 *2 (-763)))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *4 (-172)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-763)) (-5 *1 (-678 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-4 *5 (-558)) (-5 *2 (-763))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
 (((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-727 *3)))) ((*1 *1 *2) (-12 (-5 *1 (-727 *2)) (-4 *2 (-1090)))) ((*1 *1) (-12 (-5 *1 (-727 *2)) (-4 *2 (-1090))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-390)) (-5 *1 (-623))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3850 (-1157 *6)) (|:| -3483 (-568))))) (-4 *6 (-301)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-568)) (-5 *1 (-732 *4 *5 *6 *7)) (-4 *7 (-950 *6 *4 *5))))) 
+(((*1 *2 *3 *4 *4 *4 *5 *4 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *2 (-1035)) (-5 *1 (-743))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-953 *5)) (-4 *5 (-1047)) (-5 *2 (-492 *4 *5)) (-5 *1 (-945 *4 *5)) (-14 *4 (-634 (-1161)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1249)) (-5 *1 (-1123)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-850))) (-5 *2 (-1249)) (-5 *1 (-1123))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-634 (-634 (-763)))))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-4 *3 (-895 *5)) (-5 *2 (-1244 *3)) (-5 *1 (-681 *5 *3 *6 *4)) (-4 *6 (-375 *3)) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4521))))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-350)) (-5 *2 (-958 (-1108))) (-5 *1 (-347 *4))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-169 *4)) (-5 *1 (-178 *4 *3)) (-4 *4 (-13 (-365) (-840))) (-4 *3 (-1219 *2))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
 (((*1 *2 *2 *3) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *3 (-634 (-869))) (-5 *1 (-473))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1 *3 *4)) (-5 *1 (-672 *4 *3)) (-4 *4 (-1090)) (-4 *3 (-1090))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2852 *4) (|:| -2185 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568))))) 
+(((*1 *1 *2 *3) (-12 (-4 *1 (-384 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1090)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-5 *2 (-1141 *3)) (-5 *1 (-1145 *3)) (-4 *3 (-1047)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-814 *4)) (-4 *4 (-842)) (-4 *1 (-1259 *4 *3)) (-4 *3 (-1047))))) 
+(((*1 *1 *1 *1) (|partial| -12 (-4 *2 (-172)) (-5 *1 (-284 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1219 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-701 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-705 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 *10)) (-5 *1 (-616 *5 *6 *7 *8 *9 *10)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *10 (-1099 *5 *6 *7 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-775 *5 (-852 *6)))) (-5 *4 (-121)) (-4 *5 (-453)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-1044 *5 *6))) (-5 *1 (-619 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-775 *5 (-852 *6)))) (-5 *4 (-121)) (-4 *5 (-453)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-1131 *5 (-534 (-852 *6)) (-852 *6) (-775 *5 (-852 *6))))) (-5 *1 (-619 *5 *6)))) ((*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1027 *5 *6 *7 *8))) (-5 *1 (-1027 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1027 *5 *6 *7 *8))) (-5 *1 (-1027 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 (-775 *5 (-852 *6)))) (-5 *4 (-121)) (-4 *5 (-453)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-1044 *5 *6))) (-5 *1 (-1044 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1131 *5 *6 *7 *8))) (-5 *1 (-1131 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1131 *5 *6 *7 *8))) (-5 *1 (-1131 *5 *6 *7 *8)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1189 *4 *5 *6 *7))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1244 (-1244 (-568)))) (-5 *1 (-471))))) 
+(((*1 *2 *2) (|partial| -12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3))))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-1266 *4 *2)) (-4 *1 (-376 *4 *2)) (-4 *4 (-842)) (-4 *2 (-172)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1259 *3 *2)) (-4 *3 (-842)) (-4 *2 (-1047)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-814 *4)) (-4 *1 (-1259 *4 *2)) (-4 *4 (-842)) (-4 *2 (-1047)))) ((*1 *2 *1 *3) (-12 (-4 *2 (-1047)) (-5 *1 (-1265 *2 *3)) (-4 *3 (-838))))) 
+(((*1 *1 *1 *1 *2) (|partial| -12 (-5 *2 (-121)) (-5 *1 (-593 *3)) (-4 *3 (-1047))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-1219 *4)) (-5 *2 (-1 *6 (-634 *6))) (-5 *1 (-1237 *4 *5 *3 *6)) (-4 *3 (-646 *5)) (-4 *6 (-1234 *4))))) 
 (((*1 *1 *2) (-12 (-5 *2 (-634 (-328))) (-5 *1 (-328))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
+(((*1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-751))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-875 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-875 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-944 (-215)) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-944 (-215)) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-877 (-1 (-215) (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-877 (-1 (-215) (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-875 *6)) (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-4 *6 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-875 *5)) (-5 *4 (-1082 (-381))) (-4 *5 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *5)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-1082 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090))))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-877 *6)) (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-4 *6 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *6)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-877 *5)) (-5 *4 (-1082 (-381))) (-4 *5 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *5))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-5 *2 (-121))))) 
+(((*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-158))))) 
 (((*1 *1 *1 *1) (-4 *1 (-146))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *2 *2 *2) (-12 (-5 *1 (-160 *2)) (-4 *2 (-550))))) 
-(((*1 *1 *1 *1) (-4 *1 (-301))) ((*1 *1 *1 *1) (-5 *1 (-763))) ((*1 *1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *6 (-230 (-1697 *5) (-763))) (-4 *7 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-536 *4 *5 *3 *6 *7 *8 *9 *2 *12)) (-4 *12 (-117)) (-4 *2 (-235 *9)) (-5 *1 (-467 *4 *5 *3 *6 *7 *8 *9 *2 *10 *11 *12)) (-4 *11 (-258 *10)))) ((*1 *2 *3 *3 *4 *5) (-12 (-5 *4 (-634 *13)) (-5 *5 (-634 *9)) (-4 *9 (-971 *6)) (-4 *13 (-258 *12)) (-4 *6 (-365)) (-4 *12 (-536 *6 *7 *3 *8 *9 *10 *11 *2 *14)) (-4 *14 (-117)) (-14 *7 (-634 (-1161))) (-4 *3 (-950 *6 *8 (-852 *7))) (-4 *8 (-230 (-1697 *7) (-763))) (-4 *10 (-641 *6)) (-4 *11 (-920 *6 *10)) (-4 *2 (-235 *11)) (-5 *1 (-556 *6 *7 *3 *8 *9 *10 *11 *2 *12 *13 *14)))) ((*1 *2 *3) (-12 (-5 *3 (-242 *5 *4)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-5 *2 (-236 (-922 *4))) (-5 *1 (-867 *4 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-242 *5 *4)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *2 (-236 (-921 *4))) (-5 *1 (-868 *4 *5 *6)) (-4 *6 (-117))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) ((*1 *1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *2) (-12 (-4 *3 (-1047)) (-5 *2 (-958 (-702 *3 *4))) (-5 *1 (-702 *3 *4)) (-4 *4 (-1219 *3))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-248)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1245)) (-5 *1 (-248)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-873 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-248)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-873 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *2 (-1245)) (-5 *1 (-248)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-875 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-248)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-875 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *2 (-1246)) (-5 *1 (-248)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-944 (-215)) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-248)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-944 (-215)) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1246)) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1246)) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1246)) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-877 (-1 (-215) (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-877 (-1 (-215) (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *2 (-1246)) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-288 *7)) (-5 *4 (-1161)) (-5 *5 (-634 (-256))) (-4 *7 (-432 *6)) (-4 *6 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-1245)) (-5 *1 (-249 *6 *7)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1082 (-381))) (-5 *2 (-1245)) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090))))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-873 *6)) (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-4 *6 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1245)) (-5 *1 (-252 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-873 *5)) (-5 *4 (-1082 (-381))) (-4 *5 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1245)) (-5 *1 (-252 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-875 *6)) (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-4 *6 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1246)) (-5 *1 (-252 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-875 *5)) (-5 *4 (-1082 (-381))) (-4 *5 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1246)) (-5 *1 (-252 *5)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-1082 (-381))) (-5 *2 (-1246)) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090))))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-877 *6)) (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-4 *6 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1246)) (-5 *1 (-252 *6)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-877 *5)) (-5 *4 (-1082 (-381))) (-4 *5 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1246)) (-5 *1 (-252 *5)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-1245)) (-5 *1 (-253)))) ((*1 *2 *3 *3 *4) (-12 (-5 *3 (-634 (-215))) (-5 *4 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-253)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-944 (-215)))) (-5 *2 (-1245)) (-5 *1 (-253)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-944 (-215)))) (-5 *4 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-253)))) ((*1 *2 *3 *3 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-1246)) (-5 *1 (-253)))) ((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-634 (-215))) (-5 *4 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-253))))) 
+(((*1 *2 *1) (|partial| -12 (-5 *2 (-607 *1)) (-4 *1 (-296))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-926))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *6 (-230 (-1699 *5) (-763))) (-4 *7 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-536 *4 *5 *3 *6 *7 *8 *9 *2 *12)) (-4 *12 (-117)) (-4 *2 (-235 *9)) (-5 *1 (-467 *4 *5 *3 *6 *7 *8 *9 *2 *10 *11 *12)) (-4 *11 (-258 *10)))) ((*1 *2 *3 *3 *4 *5) (-12 (-5 *4 (-634 *13)) (-5 *5 (-634 *9)) (-4 *9 (-971 *6)) (-4 *13 (-258 *12)) (-4 *6 (-365)) (-4 *12 (-536 *6 *7 *3 *8 *9 *10 *11 *2 *14)) (-4 *14 (-117)) (-14 *7 (-634 (-1161))) (-4 *3 (-950 *6 *8 (-852 *7))) (-4 *8 (-230 (-1699 *7) (-763))) (-4 *10 (-641 *6)) (-4 *11 (-920 *6 *10)) (-4 *2 (-235 *11)) (-5 *1 (-556 *6 *7 *3 *8 *9 *10 *11 *2 *12 *13 *14)))) ((*1 *2 *3) (-12 (-5 *3 (-242 *5 *4)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-5 *2 (-236 (-922 *4))) (-5 *1 (-867 *4 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-242 *5 *4)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *2 (-236 (-921 *4))) (-5 *1 (-868 *4 *5 *6)) (-4 *6 (-117))))) 
+(((*1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *2 *3 *4 *4) (-12 (-5 *4 (-607 *3)) (-4 *3 (-13 (-432 *5) (-27) (-1181))) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-570 *5 *3 *6)) (-4 *6 (-1090))))) 
+(((*1 *1) (-5 *1 (-328)))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1244 *1)) (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4)))))) 
+(((*1 *1) (-4 *1 (-350)))) 
 (((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *2 *1 *1 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-2 (|:| -2348 *1) (|:| |gap| (-763)) (|:| -1500 *1))) (-4 *1 (-1061 *4 *5 *3)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -2348 *1) (|:| |gap| (-763)) (|:| -1500 *1))) (-4 *1 (-1061 *3 *4 *5))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-504))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-450 *4 *5 *6 *2))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1113 (-568) (-607 (-53)))) (-5 *1 (-53)))) ((*1 *2 *1) (-12 (-4 *3 (-993 *2)) (-4 *4 (-1219 *3)) (-4 *2 (-301)) (-5 *1 (-415 *2 *3 *4 *5)) (-4 *5 (-13 (-411 *3 *4) (-1037 *3))))) ((*1 *2 *1) (-12 (-4 *3 (-558)) (-4 *3 (-842)) (-5 *2 (-1113 *3 (-607 *1))) (-4 *1 (-432 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1113 (-568) (-607 (-504)))) (-5 *1 (-504)))) ((*1 *2 *1) (-12 (-4 *4 (-172)) (-4 *2 (|SubsetCategory| (-716) *4)) (-5 *1 (-613 *3 *4 *2)) (-4 *3 (-43 *4)))) ((*1 *2 *1) (-12 (-4 *4 (-172)) (-4 *2 (|SubsetCategory| (-716) *4)) (-5 *1 (-652 *3 *4 *2)) (-4 *3 (-707 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558))))) 
+(((*1 *2 *1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-1143)) (-5 *1 (-1245)))) ((*1 *2 *1 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1245)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1245)))) ((*1 *2 *1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-1143)) (-5 *1 (-1246)))) ((*1 *2 *1 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1246)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1246))))) 
+(((*1 *2 *3 *4 *5 *6 *7 *7 *8) (-12 (-5 *3 (-2 (|:| |det| *12) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568))))) (-5 *4 (-679 *12)) (-5 *5 (-634 (-409 (-953 *9)))) (-5 *6 (-634 (-634 *12))) (-5 *7 (-763)) (-5 *8 (-568)) (-4 *9 (-13 (-301) (-150))) (-4 *12 (-950 *9 *11 *10)) (-4 *10 (-13 (-842) (-609 (-1161)))) (-4 *11 (-788)) (-5 *2 (-2 (|:| |eqzro| (-634 *12)) (|:| |neqzro| (-634 *12)) (|:| |wcond| (-634 (-953 *9))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *9)))) (|:| -2588 (-634 (-1244 (-409 (-953 *9))))))))) (-5 *1 (-924 *9 *10 *11 *12))))) 
+(((*1 *2 *3) (-12 (-5 *3 |RationalNumber|) (-5 *2 (-1 (-568))) (-5 *1 (-1045))))) 
+(((*1 *2 *1 *1 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-2 (|:| -2350 *1) (|:| |gap| (-763)) (|:| -2607 *1))) (-4 *1 (-1061 *4 *5 *3)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -2350 *1) (|:| |gap| (-763)) (|:| -2607 *1))) (-4 *1 (-1061 *3 *4 *5))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926))))) 
+(((*1 *2 *1) (-12 (-14 *3 (-634 (-1161))) (-4 *4 (-172)) (-4 *5 (-230 (-1699 *3) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4357 *2) (|:| -3483 *5)) (-2 (|:| -4357 *2) (|:| -3483 *5)))) (-4 *2 (-842)) (-5 *1 (-463 *3 *4 *2 *5 *6 *7)) (-4 *7 (-950 *4 *5 (-852 *3)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1113 (-568) (-607 (-53)))) (-5 *1 (-53)))) ((*1 *2 *1) (-12 (-4 *3 (-301)) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-5 *2 (-1244 *6)) (-5 *1 (-415 *3 *4 *5 *6)) (-4 *6 (-13 (-411 *4 *5) (-1037 *4))))) ((*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *3 (-842)) (-5 *2 (-1113 *3 (-607 *1))) (-4 *1 (-432 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1113 (-568) (-607 (-504)))) (-5 *1 (-504)))) ((*1 *2 *1) (-12 (-4 *3 (-172)) (-4 *2 (-43 *3)) (-5 *1 (-613 *2 *3 *4)) (-4 *4 (|SubsetCategory| (-716) *3)))) ((*1 *2 *1) (-12 (-4 *3 (-172)) (-4 *2 (-707 *3)) (-5 *1 (-652 *2 *3 *4)) (-4 *4 (|SubsetCategory| (-716) *3)))) ((*1 *2 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558))))) 
+(((*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-1249)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-1245)))) ((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-1246))))) 
+(((*1 *1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *1 (-585 *2)) (-4 *2 (-1037 *3)) (-4 *2 (-365)))) ((*1 *1 *2 *2) (-12 (-5 *1 (-585 *2)) (-4 *2 (-365)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-621 *4 *2)) (-4 *2 (-13 (-432 *4) (-1002) (-1181))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1082 *2)) (-4 *2 (-13 (-432 *4) (-1002) (-1181))) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-621 *4 *2)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-959)) (-5 *2 (-1161)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1082 *1)) (-4 *1 (-959))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-1047)) (-4 *6 (-230 *7 *3)) (-14 *7 *3) (-5 *2 (-634 *5)) (-5 *1 (-908 *4 *5 *6 *7)) (-4 *5 (-324 *4 *6))))) 
 (((*1 *2 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-363 *3)) (-4 *3 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-763)) (-5 *1 (-388 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *2 (-23)) (-5 *1 (-638 *4 *2 *5)) (-4 *4 (-1090)) (-14 *5 *2))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-763)) (-5 *1 (-814 *4)) (-4 *4 (-842))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-646 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) ((*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 *4 *4)) (-4 *4 (-365)) (-5 *1 (-649 *4 *2)) (-4 *2 (-646 *4))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-320 *4 *2)) (-4 *4 (-1090)) (-4 *2 (-137))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1026 (-835 (-568)))) (-5 *1 (-593 *3)) (-4 *3 (-1047))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-310 (-381))) (-5 *1 (-299))))) 
 (((*1 *1 *1) (-12 (-4 *1 (-376 *2 *3)) (-4 *2 (-842)) (-4 *3 (-172)))) ((*1 *1 *1) (-12 (-5 *1 (-618 *2 *3 *4)) (-4 *2 (-842)) (-4 *3 (-13 (-172) (-707 (-409 (-568))))) (-14 *4 (-917)))) ((*1 *1 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-842)))) ((*1 *1 *1) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) ((*1 *1 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047))))) 
+(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -4158 (-763)) (|:| |curves| (-763)) (|:| |polygons| (-763)) (|:| |constructs| (-763))))))) 
+(((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-3 (-1 (-215) (-215) (-215) (-215)) "undefined")) (-5 *5 (-1084 (-215))) (-5 *6 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-686))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-775 *5 (-852 *6)))) (-5 *4 (-121)) (-4 *5 (-453)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-1044 *5 *6))) (-5 *1 (-619 *5 *6))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1244 (-634 (-2 (|:| -2850 *4) (|:| -4355 (-1108)))))) (-4 *4 (-350)) (-5 *2 (-679 *4)) (-5 *1 (-347 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-1157 (-1157 *4)))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *7 (-230 (-1699 *5) (-763))) (-5 *2 (-3 (-634 *8) "failed" "Infinite" (-568))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *8 (-971 *4))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 *6)) (-5 *4 (-1 *6 (-763) (-1244 (-1157 *6)))) (-5 *5 (-634 (-763))) (-4 *6 (-13 (-558) (-453))) (-5 *2 (-679 (-1157 *6))) (-5 *1 (-346 *6 *7)) (-4 *7 (-52 *6 (-763)))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *3 (-1195)) (-5 *1 (-179 *3 *2)) (-4 *2 (-665 *3))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |val| (-634 *7)) (|:| -3145 *8))) (-4 *7 (-1061 *4 *5 *6)) (-4 *8 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *8)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |val| (-634 *7)) (|:| -3145 *8))) (-4 *7 (-1061 *4 *5 *6)) (-4 *8 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *8))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-13 (-301) (-10 -8 (-15 -3498 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *1 (-508 *3 *4 *5)) (-4 *5 (-411 *3 *4)))) ((*1 *2 *2 *2 *3) (-12 (-5 *2 (-679 *3)) (-4 *3 (-13 (-301) (-10 -8 (-15 -3498 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *1 (-508 *3 *4 *5)) (-4 *5 (-411 *3 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1244 (-634 (-2 (|:| -2852 *4) (|:| -4357 (-1108)))))) (-4 *4 (-350)) (-5 *2 (-679 *4)) (-5 *1 (-347 *4))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1244 *5)) (-4 *5 (-787)) (-5 *2 (-121)) (-5 *1 (-837 *4 *5)) (-14 *4 (-763))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-381)))) ((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-381))))) 
+(((*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1161)) (-4 *5 (-13 (-558) (-1037 (-568)) (-150))) (-5 *2 (-2 (|:| -4151 (-409 (-953 *5))) (|:| |coeff| (-409 (-953 *5))))) (-5 *1 (-574 *5)) (-5 *3 (-409 (-953 *5)))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558))))) 
 (((*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-381)) (-5 *1 (-1059))))) 
+(((*1 *2 *2 *3) (-12 (-4 *3 (-365)) (-5 *1 (-1025 *3 *2)) (-4 *2 (-646 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-5 *2 (-2 (|:| -2410 *3) (|:| -4194 (-634 *5)))) (-5 *1 (-1025 *5 *3)) (-5 *4 (-634 *5)) (-4 *3 (-646 *5))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-235 *2)) (-4 *2 (-1090))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-370)) (-5 *2 (-917)))) ((*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-350)) (-5 *2 (-917)) (-5 *1 (-532 *4))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-944 (-215))) (-5 *2 (-1249)) (-5 *1 (-473))))) 
 (((*1 *1 *1 *1) (-12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1866 *7) (|:| -1844 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *5 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3)))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-230 *3 *2)) (-4 *2 (-1195)) (-4 *2 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-850)))) ((*1 *1 *1) (-5 *1 (-850))) ((*1 *2 *3 *3) (-12 (-5 *3 (-944 (-215))) (-5 *2 (-215)) (-5 *1 (-1192)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-1047))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-1 *6 *4)) (-4 *4 (-1090)) (-4 *6 (-1090)) (-5 *2 (-1 *6 *4 *5)) (-5 *1 (-673 *4 *5 *6)) (-4 *5 (-1090))))) 
-(((*1 *1 *1 *1) (-4 *1 (-301))) ((*1 *1 *1 *1) (-5 *1 (-763))) ((*1 *1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1094)) (-5 *1 (-57))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-1244 (-1161))) (-5 *3 (-1244 (-454 *4 *5 *6 *7))) (-5 *1 (-454 *4 *5 *6 *7)) (-4 *4 (-172)) (-14 *5 (-917)) (-14 *6 (-634 (-1161))) (-14 *7 (-1244 (-679 *4))))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-454 *4 *5 *6 *7))) (-5 *1 (-454 *4 *5 *6 *7)) (-4 *4 (-172)) (-14 *5 (-917)) (-14 *6 (-634 *2)) (-14 *7 (-1244 (-679 *4))))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-454 *3 *4 *5 *6))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-1161))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 *2)) (-14 *6 (-1244 (-679 *3))))) ((*1 *1) (-12 (-5 *1 (-454 *2 *3 *4 *5)) (-4 *2 (-172)) (-14 *3 (-917)) (-14 *4 (-634 (-1161))) (-14 *5 (-1244 (-679 *2)))))) 
+(((*1 *2 *3 *2 *4) (-12 (-5 *3 (-123)) (-5 *4 (-763)) (-4 *5 (-453)) (-4 *5 (-842)) (-4 *5 (-1037 (-568))) (-4 *5 (-558)) (-5 *1 (-46 *5 *2)) (-4 *2 (-432 *5)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2319 ((-1113 *5 (-607 $)) $)) (-15 -2326 ((-1113 *5 (-607 $)) $)) (-15 -2747 ($ (-1113 *5 (-607 $)))))))))) 
+(((*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1039))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-121)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-465))))) 
 (((*1 *1 *2 *2 *3) (-12 (-5 *2 (-1143)) (-5 *3 (-818)) (-5 *1 (-817))))) 
+(((*1 *2 *3 *3) (|partial| -12 (-4 *4 (-558)) (-5 *2 (-2 (|:| -4409 *3) (|:| -2607 *3))) (-5 *1 (-1214 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *1 *2 *2 *2) (-12 (-5 *1 (-877 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *1 *3 *3 *4) (-12 (-5 *3 (-1 (-850) (-850) (-850))) (-5 *4 (-568)) (-5 *2 (-850)) (-5 *1 (-638 *5 *6 *7)) (-4 *5 (-1090)) (-4 *6 (-23)) (-14 *7 *6))) ((*1 *2 *1 *2) (-12 (-5 *2 (-850)) (-5 *1 (-846 *3 *4 *5)) (-4 *3 (-1047)) (-14 *4 (-101 *3)) (-14 *5 (-1 *3 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-215)) (-5 *1 (-850)))) ((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-850)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-850)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-850)) (-5 *1 (-1157 *3)) (-4 *3 (-1047))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1157 *4))) (-4 *4 (-365)) (-5 *2 (-2 (|:| |zeros| (-634 *4)) (|:| -3917 (-568)))) (-5 *1 (-1043 *4))))) 
 (((*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) ((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-558)) (-5 *2 (-121))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-1161))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *5)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-634 (-850)))) (-5 *1 (-850)))) ((*1 *2 *1) (-12 (-5 *2 (-1127 *3 *4)) (-5 *1 (-994 *3 *4)) (-14 *3 (-917)) (-4 *4 (-365)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-634 *5))) (-4 *5 (-1047)) (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |preimage| (-634 *3)) (|:| |image| (-634 *3)))) (-5 *1 (-900 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 (-763))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1037 (-568))) (-4 *1 (-296)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-550)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-900 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *4 *5 *6 *7))))) 
 (((*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)) (-5 *2 (-634 (-763))) (-5 *1 (-771 *3 *4 *5 *6 *7)) (-4 *3 (-1219 *6)) (-4 *7 (-950 *6 *4 *5))))) 
+(((*1 *1 *1 *2 *2 *2 *2) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-171)))))) 
 (((*1 *2 *3 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-324 *4 *5)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-4 *4 (-1047)) (-5 *1 (-772 *4 *3 *5 *6))))) 
-(((*1 *2 *1 *2) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
+(((*1 *1 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-420 *2)) (-4 *2 (-558))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *1 (-64 *3)) (-4 *3 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-64 *3))))) 
+(((*1 *2 *2) (|partial| -12 (-5 *2 (-310 (-215))) (-5 *1 (-299)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |num| (-887 *3)) (|:| |den| (-887 *3)))) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-33 *3)) (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-1219 *4)) (-5 *1 (-544 *4 *2 *5 *6)) (-4 *4 (-301)) (-14 *5 *4) (-14 *6 (-1 *4 *4 (-763)))))) 
+(((*1 *2 *1 *2) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
+(((*1 *1 *2 *1) (-12 (-4 *1 (-21)) (-5 *2 (-568)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-23)) (-5 *2 (-763)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-25)) (-5 *2 (-917)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-215)) (-5 *1 (-158)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-917)) (-5 *1 (-158)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181))) (-5 *1 (-219 *3)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1102)) (-4 *2 (-1195)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1102)) (-4 *2 (-1195)))) ((*1 *1 *2 *3) (-12 (-4 *1 (-320 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-137)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-363 *2)) (-4 *2 (-1090)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-363 *2)) (-4 *2 (-1090)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-383 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-842)))) ((*1 *1 *2 *3) (-12 (-4 *1 (-384 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-1090)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) ((*1 *1 *2 *1) (-12 (-14 *3 (-634 (-1161))) (-4 *4 (-172)) (-4 *6 (-230 (-1699 *3) (-763))) (-14 *7 (-1 (-121) (-2 (|:| -4357 *5) (|:| -3483 *6)) (-2 (|:| -4357 *5) (|:| -3483 *6)))) (-5 *1 (-463 *3 *4 *5 *6 *7 *2)) (-4 *5 (-842)) (-4 *2 (-950 *4 *6 (-852 *3))))) ((*1 *1 *1 *2) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-350)) (-5 *1 (-532 *3)))) ((*1 *1 *1 *1) (-5 *1 (-541))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-594 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-594 *2)) (-4 *2 (-1047)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-594 *2)) (-4 *2 (-1047)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-637 *2)) (-4 *2 (-1054)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-842)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-1 *6 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-1 *7 *5)) (-5 *1 (-673 *5 *6 *7)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1090)) (-4 *4 (-1047)) (-5 *1 (-674 *3 *4)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-677 *3 *2 *4)) (-4 *3 (-1047)) (-4 *2 (-375 *3)) (-4 *4 (-375 *3)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-677 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *2 (-375 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) ((*1 *1 *1 *1) (-4 *1 (-710))) ((*1 *1 *1 *1) (-12 (-5 *1 (-733 *2 *3)) (-14 *2 (-1161)) (-4 *3 (-13 (-1047) (-842) (-558))))) ((*1 *1 *1 *2) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-568)) (-4 *4 (-365)) (-4 *5 (-641 *4)) (-5 *2 (-236 *1)) (-4 *1 (-920 *4 *5)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-1244 *4)) (-4 *4 (-1219 *3)) (-4 *3 (-558)) (-5 *1 (-970 *3 *4)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1053 *2)) (-4 *2 (-1054)))) ((*1 *1 *1 *1) (-4 *1 (-1102))) ((*1 *2 *2 *1) (-12 (-4 *1 (-1111 *3 *4 *2 *5)) (-4 *4 (-1047)) (-4 *2 (-230 *3 *4)) (-4 *5 (-230 *3 *4)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-1111 *3 *4 *5 *2)) (-4 *4 (-1047)) (-4 *5 (-230 *3 *4)) (-4 *2 (-230 *3 *4)))) ((*1 *1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-842)) (-5 *1 (-1114 *3 *4 *2)) (-4 *2 (-950 *3 (-534 *4) *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-944 (-215))) (-5 *3 (-215)) (-5 *1 (-1192)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-716)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-716)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-4 *1 (-1242 *3)) (-4 *3 (-1195)) (-4 *3 (-21)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1259 *3 *2)) (-4 *3 (-842)) (-4 *2 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-1265 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-838))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-679 *5))) (-5 *4 (-568)) (-4 *5 (-365)) (-4 *5 (-1047)) (-5 *2 (-121)) (-5 *1 (-1029 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-679 *4))) (-4 *4 (-365)) (-4 *4 (-1047)) (-5 *2 (-121)) (-5 *1 (-1029 *4))))) 
+(((*1 *1 *2 *3 *3 *3 *3) (-12 (-5 *2 (-1 (-944 (-215)) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-926)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 (-944 (-215)) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-926)))) ((*1 *1 *2 *3 *3 *3) (-12 (-5 *2 (-1 (-944 (-215)) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 (-944 (-215)) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4522)) (-4 *3 (-1090)) (-5 *1 (-96 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4522)) (-4 *3 (-1090)) (-5 *1 (-212 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4522)) (-4 *3 (-842)) (-5 *1 (-494 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| *1 (-6 -4522)) (-4 *1 (-499 *3)) (-4 *3 (-1195)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4522)) (-4 *3 (-1090)) (-5 *1 (-1000 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (|has| $ (-6 -4522)) (-4 *3 (-1090)) (-5 *1 (-1132 *3))))) 
+(((*1 *1 *1) (-4 *1 (-1056)))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-1157 *1)) (-5 *4 (-1161)) (-4 *1 (-27)) (-5 *2 (-634 *1)))) ((*1 *2 *3) (-12 (-5 *3 (-1157 *1)) (-4 *1 (-27)) (-5 *2 (-634 *1)))) ((*1 *2 *3) (-12 (-5 *3 (-953 *1)) (-4 *1 (-27)) (-5 *2 (-634 *1)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-634 *1)) (-4 *1 (-29 *4)))) ((*1 *2 *1) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *2 (-634 *1)) (-4 *1 (-29 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-215))) (-5 *4 (-634 (-1161))) (-5 *5 (-1084 (-835 (-215)))) (-5 *2 (-1141 (-215))) (-5 *1 (-294))))) 
+(((*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-763)) (-4 *5 (-365)) (-5 *2 (-409 *6)) (-5 *1 (-861 *5 *4 *6)) (-4 *4 (-1234 *5)) (-4 *6 (-1219 *5)))) ((*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-763)) (-5 *4 (-1235 *5 *6 *7)) (-4 *5 (-365)) (-14 *6 (-1161)) (-14 *7 *5) (-5 *2 (-409 (-1216 *6 *5))) (-5 *1 (-862 *5 *6 *7)))) ((*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-763)) (-5 *4 (-1235 *5 *6 *7)) (-4 *5 (-365)) (-14 *6 (-1161)) (-14 *7 *5) (-5 *2 (-409 (-1216 *6 *5))) (-5 *1 (-862 *5 *6 *7))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-634 *5))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-121))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-817))))) 
 (((*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002)))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *3 (-25)) (-4 *3 (-842)) (-5 *2 (-2 (|:| -2348 (-568)) (|:| |var| (-607 *1)))) (-4 *1 (-432 *3))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-1157 *3)) (-5 *1 (-46 *4 *3)) (-4 *3 (-13 (-365) (-296) (-10 -8 (-15 -2317 ((-1113 *4 (-607 $)) $)) (-15 -2324 ((-1113 *4 (-607 $)) $)) (-15 -2745 ($ (-1113 *4 (-607 $)))))))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1249)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-258 *12))))) 
+(((*1 *2 *2) (-12 (-5 *1 (-961 *2)) (-4 *2 (-550))))) 
+(((*1 *2 *3 *3) (-12 (-5 *2 (-1 (-381))) (-5 *1 (-1039)) (-5 *3 (-381))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-43 (-409 (-568)))) (-5 *2 (-2 (|:| -2788 (-1141 *4)) (|:| -2792 (-1141 *4)))) (-5 *1 (-1147 *4)) (-5 *3 (-1141 *4))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-958 (-1157 *4))) (-5 *1 (-358 *4)) (-5 *3 (-1157 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-763))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *3 (-25)) (-4 *3 (-842)) (-5 *2 (-2 (|:| -2350 (-568)) (|:| |var| (-607 *1)))) (-4 *1 (-432 *3))))) 
+(((*1 *2) (-12 (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-1244 *1)) (-4 *1 (-340 *3 *4 *5))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1160)) (-5 *1 (-328))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-568)) (-5 *1 (-381))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-679 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-679 *3))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-1157 *3)) (-5 *1 (-46 *4 *3)) (-4 *3 (-13 (-365) (-296) (-10 -8 (-15 -2319 ((-1113 *4 (-607 $)) $)) (-15 -2326 ((-1113 *4 (-607 $)) $)) (-15 -2747 ($ (-1113 *4 (-607 $)))))))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-158)))) ((*1 *2 *1) (-12 (-5 *2 (-158)) (-5 *1 (-869)))) ((*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-126 *3)) (-14 *3 *2))) ((*1 *1 *1) (-12 (-5 *1 (-126 *2)) (-14 *2 (-568)))) ((*1 *1 *1) (-12 (-4 *1 (-641 *2)) (-4 *2 (-365)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-4 *1 (-641 *3)) (-4 *3 (-365)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-865 *3)) (-14 *3 *2))) ((*1 *1 *1) (-12 (-5 *1 (-865 *2)) (-14 *2 (-568)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-14 *3 *2) (-5 *1 (-866 *3 *4)) (-4 *4 (-863 *3)))) ((*1 *1 *1) (-12 (-14 *2 (-568)) (-5 *1 (-866 *2 *3)) (-4 *3 (-863 *2)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-4 *1 (-1205 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1234 *3)))) ((*1 *1 *1) (-12 (-4 *1 (-1205 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-1234 *2))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1157 *6)) (-4 *6 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-1157 *7)) (-5 *1 (-318 *4 *5 *6 *7)) (-4 *7 (-950 *6 *4 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1157 (-568))) (-5 *2 (-568)) (-5 *1 (-943))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1249)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-258 *12))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-62 *4 *2 *5)) (-4 *4 (-1195)) (-4 *5 (-375 *4)) (-4 *2 (-375 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1050 *4 *5 *6 *2 *7)) (-4 *6 (-1047)) (-4 *7 (-230 *4 *6)) (-4 *2 (-230 *5 *6))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *5)) (-4 *5 (-172)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 (-763))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *4)) (-5 *1 (-1116 *3 *4)) (-4 *3 (-1219 *4)))) ((*1 *2 *3 *3 *3 *3 *3) (-12 (-4 *3 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *3)) (-5 *1 (-1116 *4 *3)) (-4 *4 (-1219 *3))))) 
 (((*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)) (-5 *2 (-420 *3)) (-5 *1 (-732 *4 *5 *6 *3)) (-4 *3 (-950 *6 *4 *5))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *7 (-230 (-1697 *6) (-763))) (-4 *8 (-971 *5)) (-4 *9 (-641 *5)) (-4 *10 (-920 *5 *9)) (-4 *11 (-536 *5 *6 *3 *7 *8 *9 *10 *2 *12)) (-4 *12 (-117)) (-4 *2 (-235 *10)) (-5 *1 (-260 *5 *6 *3 *7 *8 *9 *10 *2 *11 *4 *12)) (-4 *4 (-258 *11))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-634 (-2 (|:| -4092 *1) (|:| -1798 (-634 *7))))) (-5 *3 (-634 *7)) (-4 *1 (-1189 *4 *5 *6 *7))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-1234 *4)) (-4 *4 (-43 (-409 (-568)))) (-5 *2 (-1 (-1141 *4) (-1141 *4))) (-5 *1 (-1236 *4 *5))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-910 *3)) (-4 *3 (-301))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-3 "left" "center" "right" "vertical" "horizontal"))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-972))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *2 (-950 *4 *6 (-852 *5))) (-4 *6 (-230 (-1699 *5) (-763))) (-4 *7 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *4 *5 *2 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *1 (-467 *4 *5 *2 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-242 *5 *4)) (-5 *3 (-568)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-5 *1 (-867 *4 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-242 *5 *4)) (-5 *3 (-568)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *1 (-868 *4 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5)))) ((*1 *1 *1) (-12 (-4 *1 (-971 *2)) (-4 *2 (-365)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-971 *3)) (-4 *3 (-365))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *7 (-230 (-1699 *6) (-763))) (-4 *8 (-971 *5)) (-4 *9 (-641 *5)) (-4 *10 (-920 *5 *9)) (-4 *11 (-536 *5 *6 *3 *7 *8 *9 *10 *2 *12)) (-4 *12 (-117)) (-4 *2 (-235 *10)) (-5 *1 (-260 *5 *6 *3 *7 *8 *9 *10 *2 *11 *4 *12)) (-4 *4 (-258 *11))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-121)) (-5 *1 (-293 *4 *5)) (-14 *4 *3) (-14 *5 *3))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1084 (-835 (-215)))) (-5 *3 (-215)) (-5 *2 (-121)) (-5 *1 (-299)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5))))) 
+(((*1 *2 *2 *3) (-12 (-4 *4 (-1090)) (-4 *2 (-895 *4)) (-5 *1 (-681 *4 *2 *5 *3)) (-4 *5 (-375 *2)) (-4 *3 (-13 (-375 *4) (-10 -7 (-6 -4521))))))) 
+(((*1 *2 *1) (-12 (-4 *2 (-13 (-1090) (-39))) (-5 *1 (-1125 *3 *2)) (-4 *3 (-13 (-1090) (-39)))))) 
+(((*1 *1 *1) (|partial| -4 *1 (-1136)))) 
+(((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-634 (-2 (|:| -4094 *1) (|:| -2133 (-634 *7))))) (-5 *3 (-634 *7)) (-4 *1 (-1189 *4 *5 *6 *7))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-123)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-842)) (-5 *1 (-930 *4 *2)) (-4 *2 (-432 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-1143)) (-5 *2 (-310 (-568))) (-5 *1 (-931))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-634 *8))) (-5 *3 (-634 *8)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-121)) (-5 *1 (-924 *5 *6 *7 *8))))) 
+(((*1 *1 *1) (-5 *1 (-215))) ((*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) ((*1 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *1 *1) (-4 *1 (-1124))) ((*1 *1 *1 *1) (-4 *1 (-1124)))) 
+(((*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-679 (-409 *4)))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-944 *3)))))) 
+(((*1 *1 *1) (-5 *1 (-1059)))) 
+(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))) (-5 *1 (-444 *4 *3 *2)) (-4 *3 (-1219 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-1047)) (-4 *2 (-13 (-406) (-1037 *5) (-365) (-1181) (-279))) (-5 *1 (-444 *5 *3 *2)) (-4 *3 (-1219 *5))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-688)) (-5 *1 (-299))))) 
 (((*1 *2 *3 *4) (-12 (-5 *2 (-634 (-169 *4))) (-5 *1 (-157 *3 *4)) (-4 *3 (-1219 (-169 (-568)))) (-4 *4 (-13 (-365) (-840))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-634 (-169 *4))) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) ((*1 *2 *3 *4) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-634 (-169 *4))) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4)))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-158)))) ((*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047))))) 
+(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-450 *3 *4 *5 *2)) (-4 *2 (-950 *3 *4 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-169 (-568))) (-5 *2 (-121)) (-5 *1 (-447)))) ((*1 *2 *3) (-12 (-5 *3 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568))))) (-14 *4 (-634 (-1161))) (-14 *5 (-763)) (-5 *2 (-121)) (-5 *1 (-515 *4 *5)))) ((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-961 *3)) (-4 *3 (-550)))) ((*1 *2 *1) (-12 (-4 *1 (-1199)) (-5 *2 (-121))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-814 *3)) (-4 *3 (-842)) (-5 *1 (-663 *3))))) 
 (((*1 *2 *3) (-12 (-5 *2 (-607 *4)) (-5 *1 (-606 *3 *4)) (-4 *3 (-842)) (-4 *4 (-842))))) 
+(((*1 *1 *1) (-5 *1 (-1160))) ((*1 *1 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160))))) 
+(((*1 *2 *1 *1) (|partial| -12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)) (-5 *2 (-1157 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)) (-5 *2 (-1157 *3))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217))))) 
+(((*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-917)) (-4 *5 (-558)) (-5 *2 (-679 *5)) (-5 *1 (-956 *5 *3)) (-4 *3 (-646 *5))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-173 *2)) (-4 *2 (-301)))) ((*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568)))) ((*1 *1 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-1195)))) ((*1 *1 *1) (-4 *1 (-863 *2))) ((*1 *1 *1) (-12 (-4 *1 (-974 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-787)) (-4 *4 (-842))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3145 *4)))) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-453)) (-5 *2 (-634 (-2 (|:| |eigval| (-3 (-409 (-953 *4)) (-1150 (-1161) (-953 *4)))) (|:| |eigmult| (-763)) (|:| |eigvec| (-634 (-679 (-409 (-953 *4)))))))) (-5 *1 (-286 *4)) (-5 *3 (-679 (-409 (-953 *4))))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-305)) (-5 *1 (-290)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-305)) (-5 *1 (-290)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-305)) (-5 *1 (-290)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-1143))) (-5 *3 (-1143)) (-5 *2 (-305)) (-5 *1 (-290))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4)))))) 
 (((*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-1047)) (-5 *2 (-568)) (-5 *1 (-444 *5 *3 *6)) (-4 *3 (-1219 *5)) (-4 *6 (-13 (-406) (-1037 *5) (-365) (-1181) (-279))))) ((*1 *2 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-568)) (-5 *1 (-444 *4 *3 *5)) (-4 *3 (-1219 *4)) (-4 *5 (-13 (-406) (-1037 *4) (-365) (-1181) (-279)))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1244 *5)) (-4 *5 (-787)) (-5 *2 (-121)) (-5 *1 (-837 *4 *5)) (-14 *4 (-763))))) 
+(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-634 (-607 *5))) (-5 *3 (-1161)) (-4 *5 (-432 *4)) (-4 *4 (-842)) (-5 *1 (-577 *4 *5))))) 
 (((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-446 *3)) (-4 *3 (-1047))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-310 (-409 (-568)))) (-5 *1 (-299))))) 
+(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-173 *3)) (-4 *3 (-301))))) 
 (((*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1061 *3 *4 *5))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -4265 *3) (|:| |coef1| (-777 *3)) (|:| |coef2| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-123))))) 
+(((*1 *2) (-12 (-4 *1 (-350)) (-5 *2 (-634 (-2 (|:| -3850 (-568)) (|:| -3483 (-568)))))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-52 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-593 *3)) (-4 *3 (-1047)))) ((*1 *2 *1) (-12 (-4 *3 (-558)) (-5 *2 (-121)) (-5 *1 (-615 *3 *4)) (-4 *4 (-1219 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-725 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-716)))) ((*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-121))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-900 *3))) (-5 *1 (-899 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2910 *3) (|:| |coef1| (-777 *3)) (|:| |coef2| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-173 *3)) (-4 *3 (-301)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-665 *3)) (-4 *3 (-1195)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-730 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-842)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-863 *3)) (-5 *2 (-568)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *1 (-981 *3)) (-4 *3 (-1047)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-5 *3 (-634 *7)) (-4 *1 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)))) ((*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1221 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-135 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1249)) (-5 *1 (-1123)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-850))) (-5 *2 (-1249)) (-5 *1 (-1123))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-953 (-169 *4))) (-4 *4 (-172)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-953 (-169 *5))) (-5 *4 (-917)) (-4 *5 (-172)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-953 *4)) (-4 *4 (-1047)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-953 *5)) (-5 *4 (-917)) (-4 *5 (-1047)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-558)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-409 (-953 (-169 *4)))) (-4 *4 (-558)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-409 (-953 (-169 *5)))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-310 *4)) (-4 *4 (-558)) (-4 *4 (-842)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-310 *5)) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-842)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-310 (-169 *4))) (-4 *4 (-558)) (-4 *4 (-842)) (-4 *4 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *4)))) ((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-310 (-169 *5))) (-5 *4 (-917)) (-4 *5 (-558)) (-4 *5 (-842)) (-4 *5 (-609 (-381))) (-5 *2 (-169 (-381))) (-5 *1 (-780 *5))))) 
 (((*1 *1 *2 *3 *3 *4 *4) (-12 (-5 *2 (-953 (-568))) (-5 *3 (-1161)) (-5 *4 (-1084 (-409 (-568)))) (-5 *1 (-30))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-917))) (-5 *1 (-1091 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-763)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-334 *5 *6 *7 *8)) (-4 *5 (-432 *4)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-4 *8 (-340 *5 *6 *7)) (-4 *4 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-121)) (-5 *1 (-906 *4 *5 *6 *7 *8)))) ((*1 *2 *3) (-12 (-5 *3 (-334 (-409 (-568)) *4 *5 *6)) (-4 *4 (-1219 (-409 (-568)))) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 (-409 (-568)) *4 *5)) (-5 *2 (-121)) (-5 *1 (-907 *4 *5 *6))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-296)) (-5 *2 (-634 (-123)))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-1 (-121) *6)) (-4 *6 (-13 (-1090) (-1037 *5))) (-4 *5 (-881 *4)) (-4 *4 (-1090)) (-5 *2 (-1 (-121) *5)) (-5 *1 (-932 *4 *5 *6))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 *3)) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-1061 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1189 *4 *5 *6 *3)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-5 *1 (-439))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-634 (-953 *4))))) ((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-634 (-953 *4))) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4)))) ((*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-634 (-953 *3))))) ((*1 *2) (-12 (-5 *2 (-634 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) ((*1 *2 *3) (-12 (-5 *3 (-1244 (-454 *4 *5 *6 *7))) (-5 *2 (-634 (-953 *4))) (-5 *1 (-454 *4 *5 *6 *7)) (-4 *4 (-558)) (-4 *4 (-172)) (-14 *5 (-917)) (-14 *6 (-634 (-1161))) (-14 *7 (-1244 (-679 *4)))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1157 *4)) (-5 *1 (-532 *4)) (-4 *4 (-350))))) 
+(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1866 *7) (|:| -1844 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *5 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)) (-5 *2 (-121)))) ((*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-350)) (-5 *2 (-121)) (-5 *1 (-358 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-350)) (-5 *2 (-121)) (-5 *1 (-532 *4))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2852 *4) (|:| -2185 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568))))) 
 (((*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *1 *1 *1) (-4 *1 (-1124)))) 
+(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *6 (-230 (-1699 *5) (-763))) (-4 *7 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-568)) (-5 *1 (-260 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-568)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
+(((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1006))))) 
+(((*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1 (-121) *7 (-634 *7))) (-4 *1 (-1189 *4 *5 *6 *7)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121))))) 
 (((*1 *2 *3 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-763)) (|:| |poli| *7) (|:| |polj| *7))) (-4 *5 (-788)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-450 *4 *5 *6 *7))))) 
-(((*1 *1 *2 *3) (-12 (-4 *4 (-365)) (-4 *6 (-230 (-1697 *5) (-763))) (-4 *7 (-641 *4)) (-4 *8 (-920 *4 *7)) (-4 *1 (-536 *4 *5 *3 *6 *2 *7 *8 *9 *10)) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *2 (-971 *4)) (-4 *9 (-235 *8)) (-4 *10 (-117)))) ((*1 *1 *2 *3 *4 *5 *6 *5 *7 *8 *9) (-12 (-5 *3 (-242 (-4287 (QUOTE X) (QUOTE -2926)) *8)) (-5 *4 (-33 *8)) (-5 *9 (-1161)) (-4 *8 (-365)) (-5 *5 (-763)) (-4 *12 (-230 (-1697 *10) *5)) (-4 *13 (-641 *8)) (-4 *14 (-920 *8 *13)) (-4 *1 (-536 *8 *10 *11 *12 *2 *13 *14 *7 *6)) (-4 *11 (-950 *8 *12 (-852 *10))) (-4 *2 (-971 *8)) (-4 *7 (-235 *14)) (-4 *6 (-117)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-4 *3 (-365)) (-4 *1 (-920 *3 *4)) (-4 *4 (-641 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-4 *1 (-920 *3 *4)) (-4 *4 (-641 *3)))) ((*1 *1) (-5 *1 (-1075)))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1201 *2)) (-4 *2 (-1047)))) ((*1 *1 *1) (-12 (-5 *1 (-1235 *2 *3 *4)) (-4 *2 (-1047)) (-14 *3 (-1161)) (-14 *4 *2))) ((*1 *1 *1) (-12 (-5 *1 (-1239 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-1161))))) 
-(((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-492 *4 *5))) (-5 *3 (-634 (-852 *4))) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *1 (-476 *4 *5 *6)) (-4 *6 (-453))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-995 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-96 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-4 *1 (-111 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-212 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-494 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-1000 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-1132 *3))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-296)) (-4 *2 (-1195)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-607 *1))) (-5 *3 (-634 *1)) (-4 *1 (-296)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-288 *1))) (-4 *1 (-296)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-288 *1)) (-4 *1 (-296))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-4 *3 (-301)) (-5 *2 (-634 *5))))) 
-(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *4)))) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
-(((*1 *1 *1) (|partial| -12 (-5 *1 (-288 *2)) (-4 *2 (-716)) (-4 *2 (-1195))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1195)) (-5 *1 (-377 *4 *2)) (-4 *2 (-13 (-375 *4) (-10 -7 (-6 -4520))))))) 
-(((*1 *1 *1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *3 (-558))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-420 *3)) (-5 *1 (-910 *3)) (-4 *3 (-301))))) 
-(((*1 *2 *3) (-12 (-4 *2 (-365)) (-4 *2 (-840)) (-5 *1 (-946 *2 *3)) (-4 *3 (-1219 *2))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) ((*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *1 *1) (-4 *1 (-1124)))) 
-(((*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *2 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-1061 *3 *4 *2)) (-4 *2 (-842)))) ((*1 *2 *1) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842))))) 
-(((*1 *2 *2 *1) (-12 (-5 *2 (-634 *6)) (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558))))) 
-(((*1 *1 *2 *3) (-12 (-4 *1 (-384 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1090)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-5 *2 (-1141 *3)) (-5 *1 (-1145 *3)) (-4 *3 (-1047)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-814 *4)) (-4 *4 (-842)) (-4 *1 (-1259 *4 *3)) (-4 *3 (-1047))))) 
-(((*1 *1 *1 *1) (-4 *1 (-478))) ((*1 *1 *1 *1) (-4 *1 (-753)))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-310 *3)) (-4 *3 (-558)) (-4 *3 (-842))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *7 (-230 (-1697 *5) (-763))) (-5 *2 (-634 (-634 (-1157 (-1157 *4))))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-5 *3 (-634 (-1157 (-1157 *4)))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *8 (-971 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *1 *1) (-4 *1 (-550)))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-1266 *4 *2)) (-4 *1 (-376 *4 *2)) (-4 *4 (-842)) (-4 *2 (-172)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1259 *3 *2)) (-4 *3 (-842)) (-4 *2 (-1047)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-814 *4)) (-4 *1 (-1259 *4 *2)) (-4 *4 (-842)) (-4 *2 (-1047)))) ((*1 *2 *1 *3) (-12 (-4 *2 (-1047)) (-5 *1 (-1265 *2 *3)) (-4 *3 (-838))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-634 (-1157 (-568)))) (-5 *1 (-183)) (-5 *3 (-568))))) 
-(((*1 *1 *1) (-12 (-4 *2 (-453)) (-4 *3 (-842)) (-4 *4 (-788)) (-5 *1 (-988 *2 *3 *4 *5)) (-4 *5 (-950 *2 *4 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *2 (-1035)) (-5 *1 (-299))))) 
-(((*1 *2 *2 *1) (|partial| -12 (-5 *2 (-634 *1)) (-4 *1 (-916))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-497))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-875 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-875 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-944 (-215)) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-944 (-215)) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-877 (-1 (-215) (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-877 (-1 (-215) (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-248)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-875 *6)) (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-4 *6 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-875 *5)) (-5 *4 (-1082 (-381))) (-4 *5 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *5)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-1082 (-381))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090))))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-877 *6)) (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-4 *6 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *6)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-877 *5)) (-5 *4 (-1082 (-381))) (-4 *5 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1121 (-215))) (-5 *1 (-252 *5))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-1 (-944 (-215)) (-215) (-215))) (-5 *3 (-1 (-215) (-215) (-215) (-215))) (-5 *1 (-248))))) 
-(((*1 *1 *2 *3) (-12 (-5 *1 (-965 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090))))) 
-(((*1 *1) (-5 *1 (-439)))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-248)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1245)) (-5 *1 (-248)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-873 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-248)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-873 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *2 (-1245)) (-5 *1 (-248)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-875 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-248)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-875 (-1 (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *2 (-1246)) (-5 *1 (-248)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-944 (-215)) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-248)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-944 (-215)) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1246)) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-215) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1246)) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-944 (-215)) (-215) (-215))) (-5 *4 (-1084 (-381))) (-5 *2 (-1246)) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-877 (-1 (-215) (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-877 (-1 (-215) (-215) (-215)))) (-5 *4 (-1084 (-381))) (-5 *2 (-1246)) (-5 *1 (-248)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-288 *7)) (-5 *4 (-1161)) (-5 *5 (-634 (-256))) (-4 *7 (-432 *6)) (-4 *6 (-13 (-558) (-842) (-1037 (-568)))) (-5 *2 (-1245)) (-5 *1 (-249 *6 *7)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1082 (-381))) (-5 *2 (-1245)) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090))))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-873 *6)) (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-4 *6 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1245)) (-5 *1 (-252 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-873 *5)) (-5 *4 (-1082 (-381))) (-4 *5 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1245)) (-5 *1 (-252 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-875 *6)) (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-4 *6 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1246)) (-5 *1 (-252 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-875 *5)) (-5 *4 (-1082 (-381))) (-4 *5 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1246)) (-5 *1 (-252 *5)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-1082 (-381))) (-5 *2 (-1246)) (-5 *1 (-252 *3)) (-4 *3 (-13 (-609 (-541)) (-1090))))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-877 *6)) (-5 *4 (-1082 (-381))) (-5 *5 (-634 (-256))) (-4 *6 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1246)) (-5 *1 (-252 *6)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-877 *5)) (-5 *4 (-1082 (-381))) (-4 *5 (-13 (-609 (-541)) (-1090))) (-5 *2 (-1246)) (-5 *1 (-252 *5)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-1245)) (-5 *1 (-253)))) ((*1 *2 *3 *3 *4) (-12 (-5 *3 (-634 (-215))) (-5 *4 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-253)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-944 (-215)))) (-5 *2 (-1245)) (-5 *1 (-253)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-944 (-215)))) (-5 *4 (-634 (-256))) (-5 *2 (-1245)) (-5 *1 (-253)))) ((*1 *2 *3 *3 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-1246)) (-5 *1 (-253)))) ((*1 *2 *3 *3 *3 *4) (-12 (-5 *3 (-634 (-215))) (-5 *4 (-634 (-256))) (-5 *2 (-1246)) (-5 *1 (-253))))) 
-(((*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-399))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-150)) (-4 *3 (-301)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1047)) (-5 *2 (-1244 *3)) (-5 *1 (-702 *3 *4)) (-4 *4 (-1219 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-568)) (-5 *4 (-420 *2)) (-4 *2 (-950 *7 *5 *6)) (-5 *1 (-732 *5 *6 *7 *2)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-301))))) 
-(((*1 *1) (-5 *1 (-328)))) 
-(((*1 *2 *2 *3 *4) (-12 (-5 *2 (-1244 *5)) (-5 *3 (-763)) (-5 *4 (-1108)) (-4 *5 (-350)) (-5 *1 (-532 *5))))) 
-(((*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 (-679 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3))))) 
-(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-798))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1113 (-568) (-607 (-53)))) (-5 *1 (-53)))) ((*1 *2 *1) (-12 (-4 *3 (-993 *2)) (-4 *4 (-1219 *3)) (-4 *2 (-301)) (-5 *1 (-415 *2 *3 *4 *5)) (-4 *5 (-13 (-411 *3 *4) (-1037 *3))))) ((*1 *2 *1) (-12 (-4 *3 (-558)) (-4 *3 (-842)) (-5 *2 (-1113 *3 (-607 *1))) (-4 *1 (-432 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1113 (-568) (-607 (-504)))) (-5 *1 (-504)))) ((*1 *2 *1) (-12 (-4 *4 (-172)) (-4 *2 (|SubsetCategory| (-716) *4)) (-5 *1 (-613 *3 *4 *2)) (-4 *3 (-43 *4)))) ((*1 *2 *1) (-12 (-4 *4 (-172)) (-4 *2 (|SubsetCategory| (-716) *4)) (-5 *1 (-652 *3 *4 *2)) (-4 *3 (-707 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558))))) 
-(((*1 *2 *1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-1143)) (-5 *1 (-1245)))) ((*1 *2 *1 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1245)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1245)))) ((*1 *2 *1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-1143)) (-5 *1 (-1246)))) ((*1 *2 *1 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1246)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1246))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-842)) (-4 *4 (-365)) (-4 *5 (-788)) (-5 *2 (-2 (|:| |mval| (-679 *4)) (|:| |invmval| (-679 *4)) (|:| |genIdeal| (-514 *4 *5 *6 *7)))) (-5 *1 (-514 *4 *5 *6 *7)) (-4 *7 (-950 *4 *5 *6))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568)))))) 
-(((*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-677 *4 *5 *6)) (-5 *1 (-108 *4 *3 *2 *5 *6)) (-4 *3 (-1219 *4)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1113 (-568) (-607 (-53)))) (-5 *1 (-53)))) ((*1 *2 *1) (-12 (-4 *3 (-301)) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-5 *2 (-1244 *6)) (-5 *1 (-415 *3 *4 *5 *6)) (-4 *6 (-13 (-411 *4 *5) (-1037 *4))))) ((*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *3 (-842)) (-5 *2 (-1113 *3 (-607 *1))) (-4 *1 (-432 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1113 (-568) (-607 (-504)))) (-5 *1 (-504)))) ((*1 *2 *1) (-12 (-4 *3 (-172)) (-4 *2 (-43 *3)) (-5 *1 (-613 *2 *3 *4)) (-4 *4 (|SubsetCategory| (-716) *3)))) ((*1 *2 *1) (-12 (-4 *3 (-172)) (-4 *2 (-707 *3)) (-5 *1 (-652 *2 *3 *4)) (-4 *4 (|SubsetCategory| (-716) *3)))) ((*1 *2 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558))))) 
-(((*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-1249)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-1245)))) ((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-1246))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-2 (|:| |k| *4) (|:| |c| *3)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-57))) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *3 *4 *4 *2 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *3 (-2 (|:| |lcmfij| *6) (|:| |totdeg| (-763)) (|:| |poli| *4) (|:| |polj| *4))) (-4 *6 (-788)) (-4 *4 (-950 *5 *6 *7)) (-4 *5 (-453)) (-4 *7 (-842)) (-5 *1 (-450 *5 *6 *7 *4))))) 
-(((*1 *2 *3 *4 *4 *5) (-12 (-5 *4 (-568)) (-5 *5 (-3 "left" "center" "right" "vertical" "horizontal")) (-4 *6 (-1047)) (-4 *7 (-230 *8 (-763))) (-14 *8 (-763)) (-5 *2 (-634 (-634 *3))) (-5 *1 (-772 *6 *3 *7 *8)) (-4 *3 (-324 *6 *7))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *3 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| -2242 (-420 *3)) (|:| |special| (-420 *3)))) (-5 *1 (-717 *5 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-184)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-294)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-299))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *1 *1) (|partial| -12 (-5 *1 (-288 *2)) (-4 *2 (-716)) (-4 *2 (-1195))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-917)) (-5 *1 (-781))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-634 (-171))))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 *5 *4 *4)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-5 *2 (-1 *5 *4)) (-5 *1 (-672 *4 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-314 *3 *4 *5)) (-4 *3 (-13 (-365) (-842))) (-14 *4 (-1161)) (-14 *5 *3)))) 
-(((*1 *2 *2 *3) (-12 (-4 *3 (-558)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-1186 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5))))) 
-(((*1 *1 *2 *3 *1 *3) (-12 (-5 *2 (-887 *4)) (-4 *4 (-1090)) (-5 *1 (-884 *4 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-350)) (-5 *2 (-420 (-1157 (-1157 *5)))) (-5 *1 (-1194 *5)) (-5 *3 (-1157 (-1157 *5)))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5))))) 
+(((*1 *1 *1 *1) (-5 *1 (-121))) ((*1 *1 *1 *1) (-4 *1 (-132))) ((*1 *1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172))))) 
+(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-684 *3)) (-4 *3 (-1090)) (-5 *2 (-634 (-2 (|:| -4085 *3) (|:| -4170 (-763)))))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-350)) (-4 *2 (-13 (-404) (-10 -7 (-15 -2747 (*2 *4)) (-15 -2291 ((-917) *2)) (-15 -2588 ((-1244 *2) (-917))) (-15 -3412 (*2 *2))))) (-5 *1 (-357 *2 *4))))) 
+(((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-27) (-432 *4))) (-4 *4 (-13 (-842) (-558) (-1037 (-568)))) (-4 *7 (-1219 (-409 *6))) (-5 *1 (-553 *4 *5 *6 *7 *2)) (-4 *2 (-340 *5 *6 *7))))) 
 (((*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-121))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 (-381))) (-5 *1 (-256)))) ((*1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-558)) (-4 *2 (-172)))) ((*1 *2 *1) (-12 (-5 *1 (-420 *2)) (-4 *2 (-558))))) 
-(((*1 *1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |integrand| *3) (|:| |intvar| *3)))) (-5 *1 (-585 *3)) (-4 *3 (-365))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1094)) (-5 *2 (-1249)) (-5 *1 (-102))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1157 *2)) (-4 *2 (-950 (-409 (-953 *6)) *5 *4)) (-5 *1 (-722 *5 *4 *6 *2)) (-4 *5 (-788)) (-4 *4 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $))))) (-4 *6 (-558))))) 
-(((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 (-169 (-215)) (-169 (-215)))) (-5 *4 (-1084 (-215))) (-5 *2 (-1246)) (-5 *1 (-250))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-171))))) 
-(((*1 *2 *3 *1) (-12 (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1195)) (-5 *2 (-634 *1)) (-4 *1 (-1010 *3))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-350)) (-4 *5 (-327 *4)) (-4 *6 (-1219 *5)) (-5 *2 (-634 *3)) (-5 *1 (-769 *4 *5 *6 *3 *7)) (-4 *3 (-1219 *6)) (-14 *7 (-917))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)) (-4 *2 (-550)))) ((*1 *1 *1) (-4 *1 (-1056)))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 (-887 *3)))) (-5 *2 (-634 (-1161))) (-5 *1 (-1069 *3 *4 *5)) (-4 *5 (-13 (-432 *4) (-881 *3) (-609 (-887 *3))))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *1 (-989 *3 *4 *5 *6 *7)))) ((*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *1 (-1097 *3 *4 *5 *6 *7))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *5)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *5)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-1047)) (-5 *1 (-679 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *4)) (-4 *4 (-1047)) (-4 *1 (-1111 *3 *4 *5 *6)) (-4 *5 (-230 *3 *4)) (-4 *6 (-230 *3 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-1143)) (-5 *1 (-184)))) ((*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-1143)) (-5 *1 (-294)))) ((*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-1143)) (-5 *1 (-299))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |polnum| (-777 *3)) (|:| |polden| *3) (|:| -3741 (-763)))) (-5 *1 (-777 *3)) (-4 *3 (-1047)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| |polnum| *1) (|:| |polden| *1) (|:| -3741 (-763)))) (-4 *1 (-1061 *3 *4 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1244 *5)) (-4 *5 (-630 *4)) (-4 *4 (-558)) (-5 *2 (-121)) (-5 *1 (-629 *4 *5))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-121)) (-5 *1 (-445 *4 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121))))) 
-(((*1 *2) (-12 (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-568)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-867 *3 *4 *5)) (-4 (-857 *3) (-370)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
-(((*1 *1 *2 *3) (-12 (-5 *3 (-363 (-123))) (-4 *2 (-1047)) (-5 *1 (-704 *2 *4)) (-4 *4 (-637 *2)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-363 (-123))) (-5 *1 (-829 *2)) (-4 *2 (-1047))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 (-679 (-310 (-568))))) (-5 *1 (-1031))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-453)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1244 (-1244 *4))) (-4 *4 (-1047)) (-5 *2 (-679 *4)) (-5 *1 (-1029 *4))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-121)) (-5 *1 (-824))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176))))) 
-(((*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-1067 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6)))) ((*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-1098 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *5)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-634 (-850)))) (-5 *1 (-850)))) ((*1 *2 *1) (-12 (-5 *2 (-1127 *3 *4)) (-5 *1 (-994 *3 *4)) (-14 *3 (-917)) (-4 *4 (-365)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-634 *5))) (-4 *5 (-1047)) (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *2) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| |radval| (-310 (-568))) (|:| |radmult| (-568)) (|:| |radvect| (-634 (-679 (-310 (-568)))))))) (-5 *1 (-1031))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-4 *3 (-558)) (-5 *2 (-1157 *3))))) 
-(((*1 *1 *2) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181)))))) 
-(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-1108)) (-5 *2 (-121)) (-5 *1 (-816))))) 
-(((*1 *2) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-121)) (-5 *1 (-339 *3 *4 *5 *6)) (-4 *3 (-340 *4 *5 *6)))) ((*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *2 *2 *2) (|partial| -12 (-4 *3 (-365)) (-5 *1 (-758 *2 *3)) (-4 *2 (-698 *3)))) ((*1 *1 *1 *1) (|partial| -12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-568))))) 
-(((*1 *2 *2) (|partial| -12 (-5 *2 (-310 (-215))) (-5 *1 (-299)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-2 (|:| |num| (-887 *3)) (|:| |den| (-887 *3)))) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *3 *3 *3 *4 *5 *6) (-12 (-5 *3 (-310 (-568))) (-5 *4 (-1 (-215) (-215))) (-5 *5 (-1084 (-215))) (-5 *6 (-634 (-256))) (-5 *2 (-1121 (-215))) (-5 *1 (-686))))) 
-(((*1 *1 *1 *1 *2) (-12 (-5 *2 (-568)) (|has| *1 (-6 -4520)) (-4 *1 (-375 *3)) (-4 *3 (-1195))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-641 *2)) (-4 *2 (-365))))) 
-(((*1 *1 *2 *1) (-12 (-4 *1 (-21)) (-5 *2 (-568)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-23)) (-5 *2 (-763)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-25)) (-5 *2 (-917)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-215)) (-5 *1 (-158)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-917)) (-5 *1 (-158)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181))) (-5 *1 (-219 *3)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1102)) (-4 *2 (-1195)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1102)) (-4 *2 (-1195)))) ((*1 *1 *2 *3) (-12 (-4 *1 (-320 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-137)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-363 *2)) (-4 *2 (-1090)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-363 *2)) (-4 *2 (-1090)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-383 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-842)))) ((*1 *1 *2 *3) (-12 (-4 *1 (-384 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-1090)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) ((*1 *1 *2 *1) (-12 (-14 *3 (-634 (-1161))) (-4 *4 (-172)) (-4 *6 (-230 (-1697 *3) (-763))) (-14 *7 (-1 (-121) (-2 (|:| -4355 *5) (|:| -3438 *6)) (-2 (|:| -4355 *5) (|:| -3438 *6)))) (-5 *1 (-463 *3 *4 *5 *6 *7 *2)) (-4 *5 (-842)) (-4 *2 (-950 *4 *6 (-852 *3))))) ((*1 *1 *1 *2) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-350)) (-5 *1 (-532 *3)))) ((*1 *1 *1 *1) (-5 *1 (-541))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-594 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-594 *2)) (-4 *2 (-1047)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-594 *2)) (-4 *2 (-1047)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-637 *2)) (-4 *2 (-1054)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-667 *2)) (-4 *2 (-842)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *6)) (-5 *4 (-1 *6 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-1 *7 *5)) (-5 *1 (-673 *5 *6 *7)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1090)) (-4 *4 (-1047)) (-5 *1 (-674 *3 *4)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-677 *3 *2 *4)) (-4 *3 (-1047)) (-4 *2 (-375 *3)) (-4 *4 (-375 *3)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-677 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *2 (-375 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) ((*1 *1 *1 *1) (-4 *1 (-710))) ((*1 *1 *1 *1) (-12 (-5 *1 (-733 *2 *3)) (-14 *2 (-1161)) (-4 *3 (-13 (-1047) (-842) (-558))))) ((*1 *1 *1 *2) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-568)) (-4 *4 (-365)) (-4 *5 (-641 *4)) (-5 *2 (-236 *1)) (-4 *1 (-920 *4 *5)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-1244 *4)) (-4 *4 (-1219 *3)) (-4 *3 (-558)) (-5 *1 (-970 *3 *4)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1053 *2)) (-4 *2 (-1054)))) ((*1 *1 *1 *1) (-4 *1 (-1102))) ((*1 *2 *2 *1) (-12 (-4 *1 (-1111 *3 *4 *2 *5)) (-4 *4 (-1047)) (-4 *2 (-230 *3 *4)) (-4 *5 (-230 *3 *4)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-1111 *3 *4 *5 *2)) (-4 *4 (-1047)) (-4 *5 (-230 *3 *4)) (-4 *2 (-230 *3 *4)))) ((*1 *1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-842)) (-5 *1 (-1114 *3 *4 *2)) (-4 *2 (-950 *3 (-534 *4) *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-944 (-215))) (-5 *3 (-215)) (-5 *1 (-1192)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-716)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-716)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-4 *1 (-1242 *3)) (-4 *3 (-1195)) (-4 *3 (-21)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1259 *3 *2)) (-4 *3 (-842)) (-4 *2 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-1265 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-838))))) 
-(((*1 *1 *2) (|partial| -12 (-5 *2 (-1257 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *1 (-656 *3 *4)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-656 *3 *4)) (-5 *1 (-1262 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-310 *5))) (-5 *1 (-1117 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 *5)))) (-5 *4 (-634 (-1161))) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-634 (-634 (-310 *5)))) (-5 *1 (-1117 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| |ir| (-585 (-409 *6))) (|:| |specpart| (-409 *6)) (|:| |polypart| *6))) (-5 *1 (-578 *5 *6)) (-5 *3 (-409 *6))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-634 (-777 *3))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-634 *8)) (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *3 (-235 *10)) (-4 *11 (-536 *4 *5 *6 *7 *8 *9 *10 *3 *13)) (-4 *13 (-117)) (-5 *2 (-2 (|:| |num| (-634 *6)) (|:| |den| *6))) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *3 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-236 (-922 *5))) (-5 *4 (-763)) (-4 *5 (-350)) (-5 *2 (-634 (-409 (-242 *6 *5)))) (-5 *1 (-867 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-236 (-922 *4))) (-4 *4 (-350)) (-5 *2 (-2 (|:| |num| (-634 (-242 *5 *4))) (|:| |den| (-242 *5 *4)))) (-5 *1 (-867 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-236 (-921 *5))) (-5 *4 (-763)) (-4 *5 (-365)) (-5 *2 (-634 (-409 (-242 *6 *5)))) (-5 *1 (-868 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-236 (-921 *4))) (-4 *4 (-365)) (-5 *2 (-2 (|:| |num| (-634 (-242 *5 *4))) (|:| |den| (-242 *5 *4)))) (-5 *1 (-868 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-555 *3)) (-4 *3 (-13 (-406) (-1181))) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-840)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1063 *4 *3)) (-4 *4 (-13 (-840) (-365))) (-4 *3 (-1219 *4)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *1 (-950 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-788)) (-4 *5 (-1047)) (-4 *6 (-950 *5 *4 *2)) (-4 *2 (-842)) (-5 *1 (-951 *4 *2 *5 *6 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2745 ($ *6)) (-15 -2317 (*6 $)) (-15 -2324 (*6 $))))))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-558)) (-5 *2 (-1161)) (-5 *1 (-1042 *4))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-106 *3))))) 
-(((*1 *2 *3 *3) (-12 (-5 *2 (-1 (-381))) (-5 *1 (-1039)) (-5 *3 (-381))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-900 *3)) (-4 *3 (-1090))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-4 *4 (-172)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)) (-4 *3 (-172))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *3 *3) (-12 (-4 *3 (-1199)) (-4 *5 (-1219 *3)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-121)) (-5 *1 (-339 *4 *3 *5 *6)) (-4 *4 (-340 *3 *5 *6)))) ((*1 *2 *3 *3) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-4 *4 (-1090)) (-5 *2 (-884 *3 *5)) (-5 *1 (-880 *3 *4 *5)) (-4 *3 (-1090)) (-4 *5 (-658 *4))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-679 *7)) (-5 *3 (-634 *7)) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *1 (-924 *4 *5 *6 *7))))) 
-(((*1 *1 *2 *3) (-12 (-5 *3 (-420 *2)) (-4 *2 (-301)) (-5 *1 (-910 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-150))) (-5 *2 (-57)) (-5 *1 (-911 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-420 (-953 *6))) (-5 *5 (-1161)) (-5 *3 (-953 *6)) (-4 *6 (-13 (-301) (-150))) (-5 *2 (-57)) (-5 *1 (-911 *6))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-679 *5))) (-4 *5 (-301)) (-4 *5 (-1047)) (-5 *2 (-1244 (-1244 *5))) (-5 *1 (-1029 *5)) (-5 *4 (-1244 *5))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *3 (-365)) (-5 *1 (-653 *3))))) 
-(((*1 *1 *1) (-4 *1 (-558)))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -1880 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1 (-1114 *4 *3 *5))) (-4 *4 (-43 (-409 (-568)))) (-4 *4 (-1047)) (-4 *3 (-842)) (-5 *1 (-1114 *4 *3 *5)) (-4 *5 (-950 *4 (-534 *3) *3)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1 (-1190 *4))) (-5 *3 (-1161)) (-5 *1 (-1190 *4)) (-4 *4 (-43 (-409 (-568)))) (-4 *4 (-1047))))) 
-(((*1 *2 *2 *3 *3) (-12 (-5 *2 (-1141 *4)) (-5 *3 (-568)) (-4 *4 (-1047)) (-5 *1 (-1145 *4)))) ((*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1201 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3))) ((*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-1161))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-601 *2 *3)) (-4 *3 (-1195)) (-4 *2 (-1090)) (-4 *2 (-842))))) 
-(((*1 *2 *3 *3 *4 *5 *5) (-12 (-5 *5 (-121)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *4)))) (-5 *1 (-1067 *6 *7 *8 *3 *4)) (-4 *4 (-1066 *6 *7 *8 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-2 (|:| |val| (-634 *8)) (|:| -3001 *9)))) (-5 *5 (-121)) (-4 *8 (-1061 *6 *7 *4)) (-4 *9 (-1066 *6 *7 *4 *8)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *4 (-842)) (-5 *2 (-634 (-2 (|:| |val| *8) (|:| -3001 *9)))) (-5 *1 (-1067 *6 *7 *4 *8 *9))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 *4)) (-5 *1 (-1126 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-852 *5))) (-14 *5 (-634 (-1161))) (-4 *6 (-453)) (-5 *2 (-634 (-634 (-242 *5 *6)))) (-5 *1 (-476 *5 *6 *7)) (-5 *3 (-634 (-242 *5 *6))) (-4 *7 (-453))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-3 "left" "center" "right" "vertical" "horizontal"))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-763)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4))))) 
-(((*1 *2) (-12 (-4 *2 (-172)) (-5 *1 (-165 *3 *2)) (-4 *3 (-166 *2)))) ((*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-372 *2 *4)) (-4 *4 (-1219 *2)) (-4 *2 (-172)))) ((*1 *2) (-12 (-4 *4 (-1219 *2)) (-4 *2 (-172)) (-5 *1 (-410 *3 *2 *4)) (-4 *3 (-411 *2 *4)))) ((*1 *2) (-12 (-4 *1 (-411 *2 *3)) (-4 *3 (-1219 *2)) (-4 *2 (-172)))) ((*1 *2) (-12 (-4 *3 (-1219 *2)) (-5 *2 (-568)) (-5 *1 (-760 *3 *4)) (-4 *4 (-411 *2 *3)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-950 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *3 (-172)))) ((*1 *2 *3) (-12 (-4 *2 (-558)) (-5 *1 (-970 *2 *3)) (-4 *3 (-1219 *2)))) ((*1 *2 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-172))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-121))))) 
+(((*1 *1 *2 *3) (-12 (-5 *3 (-1143)) (-4 *1 (-366 *2 *4)) (-4 *2 (-1090)) (-4 *4 (-1090)))) ((*1 *1 *2) (-12 (-4 *1 (-366 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1249)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-258 *12))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-381)) (-5 *1 (-197))))) 
+(((*1 *2 *3 *4 *2 *5 *6 *7 *8 *9 *10) (|partial| -12 (-5 *2 (-634 (-1157 *13))) (-5 *3 (-1157 *13)) (-5 *4 (-634 *12)) (-5 *5 (-634 *10)) (-5 *6 (-634 *13)) (-5 *7 (-634 (-634 (-2 (|:| -2514 (-763)) (|:| |pcoef| *13))))) (-5 *8 (-634 (-763))) (-5 *9 (-1244 (-634 (-1157 *10)))) (-4 *12 (-842)) (-4 *10 (-301)) (-4 *13 (-950 *10 *11 *12)) (-4 *11 (-788)) (-5 *1 (-697 *11 *12 *10 *13))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-121)) (-5 *1 (-824))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-1 *6 (-634 *6)))) (-4 *5 (-43 (-409 (-568)))) (-4 *6 (-1234 *5)) (-5 *2 (-634 *6)) (-5 *1 (-1236 *5 *6))))) 
+(((*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-690)))) ((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-690))))) 
+(((*1 *2 *1 *1 *3 *4) (-12 (-5 *3 (-1 (-121) *5 *5)) (-5 *4 (-1 (-121) *6 *6)) (-4 *5 (-13 (-1090) (-39))) (-4 *6 (-13 (-1090) (-39))) (-5 *2 (-121)) (-5 *1 (-1125 *5 *6))))) 
+(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-763)) (-4 *4 (-301)) (-4 *6 (-1219 *4)) (-5 *2 (-1244 (-634 *6))) (-5 *1 (-457 *4 *6)) (-5 *5 (-634 *6))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-558)) (-4 *7 (-950 *3 *5 *6)) (-5 *2 (-2 (|:| -3483 (-763)) (|:| -2350 *8) (|:| |radicand| *8))) (-5 *1 (-954 *5 *6 *3 *7 *8)) (-5 *4 (-763)) (-4 *8 (-13 (-365) (-10 -8 (-15 -2319 (*7 $)) (-15 -2326 (*7 $)) (-15 -2747 ($ *7)))))))) 
+(((*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |val| (-634 *8)) (|:| |towers| (-634 (-1027 *5 *6 *7 *8))))) (-5 *1 (-1027 *5 *6 *7 *8)) (-5 *3 (-634 *8)))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |val| (-634 *8)) (|:| |towers| (-634 (-1131 *5 *6 *7 *8))))) (-5 *1 (-1131 *5 *6 *7 *8)) (-5 *3 (-634 *8))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *2 (-1035)) (-5 *1 (-299)))) ((*1 *2 *3) (-12 (-5 *3 (-2 (|:| -3031 (-381)) (|:| -3393 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035)))) (-5 *2 (-1035)) (-5 *1 (-299))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (|has| *1 (-6 -4522)) (-4 *1 (-1231 *3)) (-4 *3 (-1195))))) 
 (((*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *7 (-230 (-1697 *6) (-763))) (-4 *8 (-971 *5)) (-4 *4 (-920 *5 *2)) (-4 *9 (-235 *4)) (-4 *10 (-536 *5 *6 *3 *7 *8 *2 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-641 *5)) (-5 *1 (-467 *5 *6 *3 *7 *8 *2 *4 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-242 *6 *5)) (-5 *4 (-922 *5)) (-4 *5 (-350)) (-14 *6 (-634 (-1161))) (-5 *2 (-774 (-857 *5))) (-5 *1 (-867 *5 *6 *7)) (-4 *7 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-242 *6 *5)) (-5 *4 (-921 *5)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-5 *2 (-774 *5)) (-5 *1 (-868 *5 *6 *7)) (-4 *7 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 *2)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1697 *6) (-763))) (-4 *2 (-641 *5)) (-5 *1 (-871 *5 *6 *3 *7 *8 *2 *9)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5)) (-4 *9 (-920 *5 *2)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1697 *6) (-763))) (-4 *2 (-641 *5)) (-5 *1 (-871 *5 *6 *3 *7 *8 *2 *4)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5)) (-4 *4 (-920 *5 *2)))) ((*1 *2 *3 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1697 *6) (-763))) (-4 *2 (-641 *5)) (-5 *1 (-871 *5 *6 *3 *7 *8 *2 *4)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5)) (-4 *4 (-920 *5 *2)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-568)) (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *8 (-230 (-1697 *7) (-763))) (-4 *2 (-641 *6)) (-5 *1 (-871 *6 *7 *3 *8 *9 *2 *4)) (-4 *3 (-950 *6 *8 (-852 *7))) (-4 *9 (-971 *6)) (-4 *4 (-920 *6 *2))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-328))))) 
-(((*1 *2 *1) (-12 (-4 *2 (-13 (-1090) (-39))) (-5 *1 (-1125 *3 *2)) (-4 *3 (-13 (-1090) (-39)))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-989 *5 *6 *7 *8 *3)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-1097 *5 *6 *7 *8 *3))))) 
-(((*1 *2 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *2 (-558)) (-5 *1 (-970 *2 *4)) (-4 *4 (-1219 *2))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *5 *4)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-5 *2 (-1 *5)) (-5 *1 (-672 *4 *5))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-123)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-842)) (-5 *1 (-930 *4 *2)) (-4 *2 (-432 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-1143)) (-5 *2 (-310 (-568))) (-5 *1 (-931))))) 
-(((*1 *1) (-5 *1 (-142)))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) ((*1 *1 *1) (-12 (-5 *1 (-1265 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-838))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *4)) (-5 *1 (-1116 *3 *4)) (-4 *3 (-1219 *4)))) ((*1 *2 *3 *3) (-12 (-4 *3 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-634 *3)) (-5 *1 (-1116 *4 *3)) (-4 *4 (-1219 *3))))) 
-(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *1 (-106 *3)) (-4 *3 (-1090))))) 
-(((*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *3 *3 *2) (|partial| -12 (-5 *2 (-763)) (-4 *3 (-13 (-716) (-370) (-10 -7 (-15 ** (*3 *3 (-568)))))) (-5 *1 (-241 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-1143)) (-5 *1 (-184)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850))))) 
-(((*1 *1 *2 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-492 *4 *5))) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *2 (-634 (-242 *4 *5))) (-5 *1 (-622 *4 *5))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-541))))) 
-(((*1 *2 *3 *4 *4 *3 *5) (-12 (-5 *4 (-607 *3)) (-5 *5 (-1157 *3)) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-564 *6 *3 *7)) (-4 *7 (-1090)))) ((*1 *2 *3 *4 *4 *4 *3 *5) (-12 (-5 *4 (-607 *3)) (-5 *5 (-409 (-1157 *3))) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-564 *6 *3 *7)) (-4 *7 (-1090))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) ((*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-814 *4)) (-4 *4 (-842)) (-5 *2 (-121)) (-5 *1 (-663 *4))))) 
-(((*1 *1 *1) (-5 *1 (-1160))) ((*1 *1 *2) (-12 (-5 *2 (-3 (|:| I (-310 (-568))) (|:| -1478 (-310 (-381))) (|:| CF (-310 (-169 (-381)))) (|:| |switch| (-1160)))) (-5 *1 (-1160))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-409 *2)) (-5 *4 (-1 *2 *2)) (-4 *2 (-1219 *5)) (-5 *1 (-717 *5 *2)) (-4 *5 (-365))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1249)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-258 *12)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 *7)) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1697 *6) (-763))) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *9 (-971 *5)) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-4 *12 (-235 *11)) (-4 *13 (-536 *5 *6 *7 *8 *9 *10 *11 *12 *14)) (-4 *14 (-117)) (-5 *2 (-1249)) (-5 *1 (-260 *5 *6 *7 *8 *9 *10 *11 *12 *13 *3 *14)) (-4 *3 (-258 *13))))) 
-(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-568))) (-5 *4 (-900 (-568))) (-5 *2 (-679 (-568))) (-5 *1 (-589)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-634 (-679 (-568)))) (-5 *1 (-589)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-568))) (-5 *4 (-634 (-900 (-568)))) (-5 *2 (-634 (-679 (-568)))) (-5 *1 (-589))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-910 *2)) (-4 *2 (-301))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1141 (-568))) (-5 *1 (-1145 *4)) (-4 *4 (-1047)) (-5 *3 (-568))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-259 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-513 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-537 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2 *1) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-5 *2 (-850)) (-5 *1 (-538 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *7 (-971 *3)) (-4 *10 (-235 *9)) (-4 *11 (-117))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-305)) (-5 *1 (-290)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-1143))) (-5 *2 (-305)) (-5 *1 (-290)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-305)) (-5 *1 (-290)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-1143))) (-5 *3 (-1143)) (-5 *2 (-305)) (-5 *1 (-290))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *3 (-1195)) (-5 *1 (-179 *3 *2)) (-4 *2 (-665 *3))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-666 *3)) (-4 *3 (-1047)) (-4 *3 (-1090))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-13 (-301) (-10 -8 (-15 -1678 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *1 (-508 *3 *4 *5)) (-4 *5 (-411 *3 *4))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-679 (-409 (-568)))) (-5 *2 (-634 *4)) (-5 *1 (-773 *4)) (-4 *4 (-13 (-365) (-840)))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *1 (-799 *4 *2)) (-4 *2 (-13 (-29 *4) (-1181) (-959))))) ((*1 *1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1) (-5 *1 (-850))) ((*1 *2 *3) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-1145 *3)) (-4 *3 (-1047))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| -2348 (-409 *5)) (|:| |poly| *3))) (-5 *1 (-151 *4 *5 *3)) (-4 *3 (-1219 (-409 *5)))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *6 (-230 (-1697 *5) (-763))) (-4 *7 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *12)) (-5 *1 (-260 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *12)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2) (-12 (-5 *2 (-634 (-259 (-537 *3 *4 *5)))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-634 (-259 (-513 *3 *4 *5)))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 *6 *5)) (-5 *1 (-696 *4 *5 *6)) (-4 *4 (-609 (-541))) (-4 *5 (-1195)) (-4 *6 (-1195))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1168 (-634 *4))) (-4 *4 (-842)) (-5 *2 (-634 (-634 *4))) (-5 *1 (-1167 *4))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *3)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-978 *4 *5 *6 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) ((*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 (-634 *7) (-634 *7))) (-5 *2 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-978 *4 *5 *6 *7))))) 
-(((*1 *2) (-12 (-5 *2 (-2 (|:| -4100 (-634 *3)) (|:| -2971 (-634 *3)))) (-5 *1 (-1196 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 (-763)) (-4 *5 (-172))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 (-2 (|:| |lcmfij| *4) (|:| |totdeg| (-763)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *4 (-788)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-453)) (-4 *5 (-842)) (-5 *1 (-450 *3 *4 *5 *6))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-634 *7)) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1697 *6) (-763))) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-5 *2 (-634 (-1244 *5))) (-5 *1 (-562 *5 *6 *7 *8 *9 *10 *11 *3)) (-4 *9 (-971 *5)) (-4 *3 (-235 *11))))) 
-(((*1 *1 *1 *2) (|partial| -12 (-5 *2 (-763)) (-4 *1 (-1219 *3)) (-4 *3 (-1047))))) 
-(((*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-763)) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-96 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-212 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-494 *4)) (-4 *4 (-842)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1000 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1132 *4)) (-4 *4 (-1090)))) ((*1 *2 *3 *3) (|partial| -12 (-5 *2 (-121)) (-5 *1 (-1196 *3)) (-4 *3 (-1090)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-1 (-121) *3 *3)) (-4 *3 (-1090)) (-5 *2 (-121)) (-5 *1 (-1196 *3))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *1 (-989 *3 *4 *5 *6 *7)))) ((*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *1 (-1097 *3 *4 *5 *6 *7))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3))))) 
-(((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-763)) (-4 *4 (-13 (-558) (-150))) (-5 *1 (-1213 *4 *2)) (-4 *2 (-1219 *4))))) 
-(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-438))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-427 *2)) (-4 *2 (-1090)) (-4 *2 (-370))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-2 (|:| |ans| *6) (|:| -3284 *6) (|:| |sol?| (-121))) (-568) *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-5 *2 (-2 (|:| |answer| (-585 (-409 *7))) (|:| |a0| *6))) (-5 *1 (-578 *6 *7)) (-5 *3 (-409 *7))))) 
-(((*1 *2) (-12 (-4 *2 (-13 (-432 *3) (-1002))) (-5 *1 (-272 *3 *2)) (-4 *3 (-13 (-842) (-558)))))) 
-(((*1 *2 *3 *4 *5 *6 *7 *8 *9) (|partial| -12 (-5 *4 (-634 *11)) (-5 *5 (-634 (-1157 *9))) (-5 *6 (-634 *9)) (-5 *7 (-634 *12)) (-5 *8 (-634 (-763))) (-4 *11 (-842)) (-4 *9 (-301)) (-4 *12 (-950 *9 *10 *11)) (-4 *10 (-788)) (-5 *2 (-634 (-1157 *12))) (-5 *1 (-697 *10 *11 *9 *12)) (-5 *3 (-1157 *12))))) 
-(((*1 *1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *3 (-558))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-453)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1157 *6)) (-4 *6 (-950 *5 *3 *4)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-904)) (-5 *1 (-459 *3 *4 *5 *6)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-904))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-1215 *3 *2)) (-4 *2 (-1219 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-259 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-230 (-1697 *5) (-763))) (-5 *2 (-1157 (-1157 *4))) (-5 *1 (-32 *4 *5 *3 *6 *7)) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *7 (-971 *4))))) 
-(((*1 *2 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3))))) 
-(((*1 *2 *3 *3) (|partial| -12 (-4 *4 (-13 (-365) (-150) (-1037 (-568)))) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| -1924 (-409 *5)) (|:| |coeff| (-409 *5)))) (-5 *1 (-572 *4 *5)) (-5 *3 (-409 *5))))) 
-(((*1 *2 *2 *3) (-12 (-4 *3 (-558)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-1186 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5))))) 
-(((*1 *1) (-12 (-5 *1 (-233 *2)) (-4 *2 (-1047))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *4) (-12 (-5 *2 (-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568))) (-5 *4 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))))) ((*1 *2 *3 *4) (-12 (-5 *2 (-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568))) (-5 *4 (-409 (-568))))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-409 (-568))) (-5 *2 (-634 (-2 (|:| -3028 *5) (|:| -3284 *5)))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568))) (-5 *4 (-2 (|:| -3028 *5) (|:| -3284 *5))))) ((*1 *2 *3) (-12 (-5 *2 (-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 (-409 (-568)))))) ((*1 *2 *3 *4) (-12 (-5 *2 (-634 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568)))))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 (-409 (-568)))) (-5 *4 (-2 (|:| -3028 (-409 (-568))) (|:| -3284 (-409 (-568))))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-409 (-568))) (-5 *2 (-634 (-2 (|:| -3028 *4) (|:| -3284 *4)))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-409 (-568))) (-5 *2 (-634 (-2 (|:| -3028 *5) (|:| -3284 *5)))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 *5)) (-5 *4 (-2 (|:| -3028 *5) (|:| -3284 *5)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-568)) (-4 *6 (-641 *5)) (-4 *5 (-365)) (-5 *2 (-679 *5)) (-5 *1 (-635 *5 *6))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-324 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787)))) ((*1 *2 *1) (-12 (-4 *1 (-698 *3)) (-4 *3 (-1047)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-844 *3)) (-4 *3 (-1047)) (-5 *2 (-763)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *1 (-950 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 (-763))))) ((*1 *2 *1 *3) (-12 (-4 *1 (-950 *4 *5 *3)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-763))))) 
-(((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1) (-5 *1 (-850))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *3 (-568)) (-4 *1 (-863 *4))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1157 *5)) (-4 *5 (-453)) (-5 *2 (-634 *6)) (-5 *1 (-543 *5 *6 *4)) (-4 *6 (-365)) (-4 *4 (-13 (-365) (-840))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-953 *5)) (-4 *5 (-453)) (-5 *2 (-634 *6)) (-5 *1 (-543 *5 *6 *4)) (-4 *6 (-365)) (-4 *4 (-13 (-365) (-840)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-1149 3 *3)))) ((*1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1121 (-215))) (-5 *1 (-1246)))) ((*1 *2 *1) (-12 (-5 *2 (-1121 (-215))) (-5 *1 (-1246))))) 
-(((*1 *1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *1 *1 *1) (-5 *1 (-121))) ((*1 *1 *1 *1) (-4 *1 (-132))) ((*1 *1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *4 (-1161)) (-5 *5 (-634 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-559 *6 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-1177)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1177))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)))) ((*1 *1 *1) (-12 (-5 *1 (-55 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-634 (-1161))))) ((*1 *1 *1) (-12 (-5 *1 (-213 *2 *3)) (-4 *2 (-13 (-1047) (-842))) (-14 *3 (-634 (-1161))))) ((*1 *1 *1) (-12 (-5 *1 (-236 *2)) (-4 *2 (-1088)))) ((*1 *1 *1) (-12 (-4 *1 (-384 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-1090)))) ((*1 *1 *1) (-12 (-14 *2 (-634 (-1161))) (-4 *3 (-172)) (-4 *5 (-230 (-1699 *2) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4357 *4) (|:| -3483 *5)) (-2 (|:| -4357 *4) (|:| -3483 *5)))) (-5 *1 (-463 *2 *3 *4 *5 *6 *7)) (-4 *4 (-842)) (-4 *7 (-950 *3 *5 (-852 *2))))) ((*1 *1 *1) (-12 (-4 *1 (-518 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-842)))) ((*1 *1 *1) (-12 (-4 *2 (-558)) (-5 *1 (-615 *2 *3)) (-4 *3 (-1219 *2)))) ((*1 *1 *1) (-12 (-4 *1 (-698 *2)) (-4 *2 (-1047)))) ((*1 *1 *1) (-12 (-5 *1 (-725 *2 *3)) (-4 *3 (-842)) (-4 *2 (-1047)) (-4 *3 (-716)))) ((*1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) ((*1 *1 *1) (-12 (-5 *1 (-1265 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-838))))) 
+(((*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1061 *3 *4 *5))))) 
+(((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *4 (-568)) (-5 *6 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783)))) ((*1 *2 *3 *4 *5 *5 *6 *3 *3 *3 *3) (-12 (-5 *4 (-568)) (-5 *6 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-3 (-121) "failed")) (-4 *3 (-453)) (-4 *4 (-842)) (-4 *5 (-788)) (-5 *1 (-988 *3 *4 *5 *6)) (-4 *6 (-950 *3 *5 *4))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1108)) (-5 *2 (-1249)) (-5 *1 (-826))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-634 *8))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-360 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-123))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1201 *2)) (-4 *2 (-1047)))) ((*1 *1 *1) (-12 (-5 *1 (-1235 *2 *3 *4)) (-4 *2 (-1047)) (-14 *3 (-1161)) (-14 *4 *2))) ((*1 *1 *1) (-12 (-5 *1 (-1239 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-1161))))) 
-(((*1 *1 *2 *3) (-12 (-5 *1 (-429 *3 *2)) (-4 *3 (-13 (-172) (-43 (-409 (-568))))) (-4 *2 (-13 (-842) (-21)))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-43 (-409 (-568)))) (-5 *2 (-2 (|:| -1974 (-1141 *4)) (|:| -1978 (-1141 *4)))) (-5 *1 (-1147 *4)) (-5 *3 (-1141 *4))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *6 (-230 (-1697 *5) *2)) (-4 *7 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-763)) (-5 *1 (-260 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-763)) (-5 *1 (-339 *3 *4 *5 *6)) (-4 *3 (-340 *4 *5 *6)))) ((*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-763)))) ((*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) *2)) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-763)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
-(((*1 *2 *3 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-634 (-568))))) ((*1 *2 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-634 (-568)))))) 
-(((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-634 (-2 (|:| |func| *2) (|:| |pole| (-121))))) (-4 *2 (-13 (-432 *4) (-1002))) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-272 *4 *2))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-634 (-215))) (-5 *1 (-196))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-365)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-763)) (-5 *1 (-529 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-4 *3 (-558)) (-5 *2 (-763)))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *4 (-172)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-763)) (-5 *1 (-678 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-4 *5 (-558)) (-5 *2 (-763))))) 
-(((*1 *2 *3 *4 *5 *5 *5 *5 *4 *6) (-12 (-5 *4 (-568)) (-5 *6 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783))))) 
-(((*1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-824))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| |deg| (-763)) (|:| -4435 *5)))) (-4 *5 (-1219 *4)) (-4 *4 (-350)) (-5 *2 (-634 *5)) (-5 *1 (-207 *4 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-2 (|:| -3848 *5) (|:| -3206 (-568))))) (-5 *4 (-568)) (-4 *5 (-1219 *4)) (-5 *2 (-634 *5)) (-5 *1 (-685 *5))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-1141 *3))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-917)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-256))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)))) ((*1 *1 *1) (-12 (-5 *1 (-55 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-634 (-1161))))) ((*1 *1 *1) (-12 (-5 *1 (-213 *2 *3)) (-4 *2 (-13 (-1047) (-842))) (-14 *3 (-634 (-1161))))) ((*1 *1 *1) (-12 (-5 *1 (-236 *2)) (-4 *2 (-1088)))) ((*1 *1 *1) (-12 (-4 *1 (-384 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-1090)))) ((*1 *1 *1) (-12 (-14 *2 (-634 (-1161))) (-4 *3 (-172)) (-4 *5 (-230 (-1697 *2) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4355 *4) (|:| -3438 *5)) (-2 (|:| -4355 *4) (|:| -3438 *5)))) (-5 *1 (-463 *2 *3 *4 *5 *6 *7)) (-4 *4 (-842)) (-4 *7 (-950 *3 *5 (-852 *2))))) ((*1 *1 *1) (-12 (-4 *1 (-518 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-842)))) ((*1 *1 *1) (-12 (-4 *2 (-558)) (-5 *1 (-615 *2 *3)) (-4 *3 (-1219 *2)))) ((*1 *1 *1) (-12 (-4 *1 (-698 *2)) (-4 *2 (-1047)))) ((*1 *1 *1) (-12 (-5 *1 (-725 *2 *3)) (-4 *3 (-842)) (-4 *2 (-1047)) (-4 *3 (-716)))) ((*1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) ((*1 *1 *1) (-12 (-5 *1 (-1265 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-838))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-358 *3)) (-4 *3 (-350))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-1143)) (-5 *3 (-568)) (-5 *1 (-234))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453))))) 
-(((*1 *1 *1 *1) (-4 *1 (-550)))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-1157 *3)) (-4 *3 (-370)) (-4 *1 (-327 *3)) (-4 *3 (-365))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *3 (-25)) (-4 *3 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-432 *3)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (|partial| -12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-950 *3 *4 *5)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-634 *3)) (-5 *1 (-951 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2747 ($ *7)) (-15 -2319 (*7 $)) (-15 -2326 (*7 $)))))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-1141 (-953 *4)) (-1141 (-953 *4)))) (-5 *1 (-1252 *4)) (-4 *4 (-365))))) 
 (((*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-950 *3 *4 *5))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *2 (-13 (-432 *4) (-881 *3) (-609 (-887 *3)))) (-5 *1 (-1069 *3 *4 *2)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 (-887 *3)))))) ((*1 *2 *1) (-12 (-4 *2 (-1090)) (-5 *1 (-1150 *3 *2)) (-4 *3 (-1090))))) 
-(((*1 *1 *1) (-5 *1 (-1059)))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-944 *4)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047)))) ((*1 *2 *1) (-12 (-4 *2 (-1047)) (-5 *1 (-55 *2 *3)) (-14 *3 (-634 (-1161))))) ((*1 *2 *1) (-12 (-5 *2 (-310 *3)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161))))) ((*1 *2 *1) (-12 (-4 *1 (-384 *2 *3)) (-4 *3 (-1090)) (-4 *2 (-1047)))) ((*1 *2 *1) (-12 (-14 *3 (-634 (-1161))) (-4 *5 (-230 (-1697 *3) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4355 *4) (|:| -3438 *5)) (-2 (|:| -4355 *4) (|:| -3438 *5)))) (-4 *2 (-172)) (-5 *1 (-463 *3 *2 *4 *5 *6 *7)) (-4 *4 (-842)) (-4 *7 (-950 *2 *5 (-852 *3))))) ((*1 *2 *1) (-12 (-4 *1 (-518 *2 *3)) (-4 *3 (-842)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *2 (-558)) (-5 *1 (-615 *2 *3)) (-4 *3 (-1219 *2)))) ((*1 *2 *1) (-12 (-4 *1 (-698 *2)) (-4 *2 (-1047)))) ((*1 *2 *1) (-12 (-4 *2 (-1047)) (-5 *1 (-725 *2 *3)) (-4 *3 (-842)) (-4 *3 (-716)))) ((*1 *2 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)))) ((*1 *2 *1) (-12 (-4 *1 (-974 *2 *3 *4)) (-4 *3 (-787)) (-4 *4 (-842)) (-4 *2 (-1047)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-150))) (-5 *2 (-634 *3)) (-5 *1 (-1213 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *1 (-873 *2)) (-4 *2 (-1195)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *1 (-875 *2)) (-4 *2 (-1195)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *1 (-877 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1027 *5 *6 *7 *8))) (-5 *1 (-1027 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-121)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-634 (-1131 *5 *6 *7 *8))) (-5 *1 (-1131 *5 *6 *7 *8))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)))) ((*1 *2 *1) (-12 (-4 *1 (-384 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-14 *3 (-634 (-1161))) (-4 *4 (-172)) (-4 *6 (-230 (-1697 *3) (-763))) (-14 *7 (-1 (-121) (-2 (|:| -4355 *5) (|:| -3438 *6)) (-2 (|:| -4355 *5) (|:| -3438 *6)))) (-5 *2 (-703 *5 *6 *7)) (-5 *1 (-463 *3 *4 *5 *6 *7 *8)) (-4 *5 (-842)) (-4 *8 (-950 *4 *6 (-852 *3))))) ((*1 *2 *1) (-12 (-4 *2 (-716)) (-4 *2 (-842)) (-5 *1 (-725 *3 *2)) (-4 *3 (-1047)))) ((*1 *1 *1) (-12 (-4 *1 (-974 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-787)) (-4 *4 (-842))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *1 (-320 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-137)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-363 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-388 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-638 *3 *4 *5)) (-4 *4 (-23)) (-14 *5 *4)))) 
-(((*1 *1) (-5 *1 (-818)))) 
+(((*1 *1 *1) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-375 *2)) (-4 *2 (-1195)) (-4 *2 (-842)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (|has| *1 (-6 -4522)) (-4 *1 (-375 *3)) (-4 *3 (-1195))))) 
+(((*1 *2 *2 *3 *4 *5) (-12 (-5 *3 (-123)) (-5 *2 (-568)) (-5 *4 (-1161)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *1 (-1024 *6 *5)) (-4 *5 (-13 (-432 *6) (-23) (-1037 *2) (-1037 *4) (-895 *4) (-161)))))) 
+(((*1 *2 *3 *4 *5 *5) (-12 (-5 *4 (-121)) (-5 *5 (-568)) (-4 *6 (-365)) (-4 *6 (-370)) (-4 *6 (-1047)) (-5 *2 (-634 (-634 (-679 *6)))) (-5 *1 (-1029 *6)) (-5 *3 (-634 (-679 *6))))) ((*1 *2 *3) (-12 (-4 *4 (-365)) (-4 *4 (-370)) (-4 *4 (-1047)) (-5 *2 (-634 (-634 (-679 *4)))) (-5 *1 (-1029 *4)) (-5 *3 (-634 (-679 *4))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-365)) (-4 *5 (-370)) (-4 *5 (-1047)) (-5 *2 (-634 (-634 (-679 *5)))) (-5 *1 (-1029 *5)) (-5 *3 (-634 (-679 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-365)) (-4 *5 (-370)) (-4 *5 (-1047)) (-5 *2 (-634 (-634 (-679 *5)))) (-5 *1 (-1029 *5)) (-5 *3 (-634 (-679 *5)))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1174))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047)))) ((*1 *2 *1) (-12 (-4 *2 (-1047)) (-5 *1 (-55 *2 *3)) (-14 *3 (-634 (-1161))))) ((*1 *2 *1) (-12 (-5 *2 (-310 *3)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161))))) ((*1 *2 *1) (-12 (-4 *1 (-384 *2 *3)) (-4 *3 (-1090)) (-4 *2 (-1047)))) ((*1 *2 *1) (-12 (-14 *3 (-634 (-1161))) (-4 *5 (-230 (-1699 *3) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4357 *4) (|:| -3483 *5)) (-2 (|:| -4357 *4) (|:| -3483 *5)))) (-4 *2 (-172)) (-5 *1 (-463 *3 *2 *4 *5 *6 *7)) (-4 *4 (-842)) (-4 *7 (-950 *2 *5 (-852 *3))))) ((*1 *2 *1) (-12 (-4 *1 (-518 *2 *3)) (-4 *3 (-842)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *2 (-558)) (-5 *1 (-615 *2 *3)) (-4 *3 (-1219 *2)))) ((*1 *2 *1) (-12 (-4 *1 (-698 *2)) (-4 *2 (-1047)))) ((*1 *2 *1) (-12 (-4 *2 (-1047)) (-5 *1 (-725 *2 *3)) (-4 *3 (-842)) (-4 *3 (-716)))) ((*1 *2 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)))) ((*1 *2 *1) (-12 (-4 *1 (-974 *2 *3 *4)) (-4 *3 (-787)) (-4 *4 (-842)) (-4 *2 (-1047)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842))))) 
+(((*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-568)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1201 *2)) (-4 *2 (-1047)))) ((*1 *1 *1) (-12 (-5 *1 (-1235 *2 *3 *4)) (-4 *2 (-1047)) (-14 *3 (-1161)) (-14 *4 *2))) ((*1 *1 *1) (-12 (-5 *1 (-1239 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-1161))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-240 *3))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)))) ((*1 *2 *1) (-12 (-4 *1 (-384 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-14 *3 (-634 (-1161))) (-4 *4 (-172)) (-4 *6 (-230 (-1699 *3) (-763))) (-14 *7 (-1 (-121) (-2 (|:| -4357 *5) (|:| -3483 *6)) (-2 (|:| -4357 *5) (|:| -3483 *6)))) (-5 *2 (-703 *5 *6 *7)) (-5 *1 (-463 *3 *4 *5 *6 *7 *8)) (-4 *5 (-842)) (-4 *8 (-950 *4 *6 (-852 *3))))) ((*1 *2 *1) (-12 (-4 *2 (-716)) (-4 *2 (-842)) (-5 *1 (-725 *3 *2)) (-4 *3 (-1047)))) ((*1 *1 *1) (-12 (-4 *1 (-974 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-787)) (-4 *4 (-842))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1157 *9)) (-5 *4 (-634 *7)) (-5 *5 (-634 (-634 *8))) (-4 *7 (-842)) (-4 *8 (-301)) (-4 *9 (-950 *8 *6 *7)) (-4 *6 (-788)) (-5 *2 (-2 (|:| |upol| (-1157 *8)) (|:| |Lval| (-634 *8)) (|:| |Lfact| (-634 (-2 (|:| -3850 (-1157 *8)) (|:| -3483 (-568))))) (|:| |ctpol| *8))) (-5 *1 (-732 *6 *7 *8 *9))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
 (((*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 (-887 *3)))) (-5 *2 (-634 (-1069 *3 *4 *5))) (-5 *1 (-1070 *3 *4 *5)) (-4 *5 (-13 (-432 *4) (-881 *3) (-609 (-887 *3))))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3001 *4)))) (-5 *1 (-768 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-296)))) ((*1 *1 *1) (-4 *1 (-296))) ((*1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-1161)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-465))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-324 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047)))) ((*1 *2 *1) (-12 (-4 *1 (-432 *2)) (-4 *2 (-842))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1216 *5 *4)) (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-568)) (-5 *1 (-1104 *4 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |k| (-663 *3)) (|:| |c| *4)))) (-5 *1 (-618 *3 *4 *5)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-14 *5 (-917))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-568)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-568))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-568)) (-4 *6 (-641 *5)) (-4 *5 (-365)) (-5 *2 (-679 *5)) (-5 *1 (-635 *5 *6))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1219 (-568))) (-5 *1 (-496 *3))))) 
+(((*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-230 (-1699 *4) (-763))) (-4 *6 (-971 *3)) (-4 *7 (-641 *3)) (-4 *8 (-920 *3 *7)) (-4 *9 (-235 *8)) (-4 *10 (-536 *3 *4 *2 *5 *6 *7 *8 *9 *12)) (-4 *12 (-117)) (-4 *2 (-950 *3 *5 (-852 *4))) (-5 *1 (-467 *3 *4 *2 *5 *6 *7 *8 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) ((*1 *2) (-12 (-5 *2 (-242 *4 *3)) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-242 *4 *3)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-169 (-215))) (-5 *2 (-215)) (-5 *1 (-115))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-324 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-432 *3)) (-4 *3 (-842)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-733 *3 *4)) (-14 *3 (-1161)) (-4 *4 (-13 (-1047) (-842) (-558))))) ((*1 *2 *1) (-12 (-4 *1 (-858)) (-5 *2 (-121))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-4 *1 (-227 *3)))) ((*1 *1) (-12 (-4 *1 (-227 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-817))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-637 *3)) (-4 *3 (-1047)) (-5 *1 (-704 *3 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-829 *3))))) 
-(((*1 *1 *1) (-4 *1 (-238))) ((*1 *1 *1) (-12 (-4 *2 (-172)) (-5 *1 (-284 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1219 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) ((*1 *1 *1) (-2198 (-12 (-5 *1 (-288 *2)) (-4 *2 (-365)) (-4 *2 (-1195))) (-12 (-5 *1 (-288 *2)) (-4 *2 (-478)) (-4 *2 (-1195))))) ((*1 *1 *1) (-4 *1 (-478))) ((*1 *2 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-350)) (-5 *1 (-532 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-705 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)) (-4 *2 (-365))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-420 *2)) (-4 *2 (-558))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-453)) (-4 *3 (-842)) (-4 *3 (-1037 (-568))) (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-432 *3)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2319 ((-1113 *3 (-607 $)) $)) (-15 -2326 ((-1113 *3 (-607 $)) $)) (-15 -2747 ($ (-1113 *3 (-607 $)))))))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-215))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047))))) 
+(((*1 *1 *1) (-4 *1 (-238))) ((*1 *1 *1) (-12 (-4 *2 (-172)) (-5 *1 (-284 *2 *3 *4 *5 *6 *7)) (-4 *3 (-1219 *2)) (-4 *4 (-23)) (-14 *5 (-1 *3 *3 *4)) (-14 *6 (-1 (-3 *4 "failed") *4 *4)) (-14 *7 (-1 (-3 *3 "failed") *3 *3 *4)))) ((*1 *1 *1) (-2199 (-12 (-5 *1 (-288 *2)) (-4 *2 (-365)) (-4 *2 (-1195))) (-12 (-5 *1 (-288 *2)) (-4 *2 (-478)) (-4 *2 (-1195))))) ((*1 *1 *1) (-4 *1 (-478))) ((*1 *2 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-350)) (-5 *1 (-532 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-705 *2 *3 *4 *5 *6)) (-4 *2 (-172)) (-4 *3 (-23)) (-14 *4 (-1 *2 *2 *3)) (-14 *5 (-1 (-3 *3 "failed") *3 *3)) (-14 *6 (-1 (-3 *2 "failed") *2 *2 *3)))) ((*1 *1 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)) (-4 *2 (-365))))) 
 (((*1 *1) (-5 *1 (-121)))) 
-(((*1 *2) (-12 (-5 *2 (-1121 (-215))) (-5 *1 (-1179))))) 
-(((*1 *1) (-5 *1 (-215))) ((*1 *1) (-5 *1 (-381)))) 
-(((*1 *2 *2 *2) (-12 (-5 *1 (-160 *2)) (-4 *2 (-550))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (-4 *2 (-1047)) (-4 *2 (-172))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-663 *3)) (-4 *3 (-842)) (-4 *1 (-376 *3 *4)) (-4 *4 (-172))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1037 (-568))) (-4 *1 (-296)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-550)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-900 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *1 *3) (-12 (-4 *1 (-52 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047)))) ((*1 *2 *1 *1) (-12 (-4 *2 (-1047)) (-5 *1 (-55 *2 *3)) (-14 *3 (-634 (-1161))))) ((*1 *2 *1 *3) (-12 (-5 *3 (-634 (-917))) (-4 *2 (-365)) (-5 *1 (-155 *4 *2 *5)) (-14 *4 (-917)) (-14 *5 (-994 *4 *2)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-310 *3)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161))))) ((*1 *2 *3 *1) (-12 (-4 *1 (-320 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-137)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-384 *2 *3)) (-4 *3 (-1090)) (-4 *2 (-1047)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *2 (-558)) (-5 *1 (-615 *2 *4)) (-4 *4 (-1219 *2)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-698 *2)) (-4 *2 (-1047)))) ((*1 *2 *1 *3) (-12 (-4 *2 (-1047)) (-5 *1 (-725 *2 *3)) (-4 *3 (-716)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *5)) (-5 *3 (-634 (-763))) (-4 *1 (-730 *4 *5)) (-4 *4 (-1047)) (-4 *5 (-842)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-730 *4 *2)) (-4 *4 (-1047)) (-4 *2 (-842)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-844 *2)) (-4 *2 (-1047)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *6)) (-5 *3 (-634 (-763))) (-4 *1 (-950 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-950 *4 *5 *2)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *2 (-842)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *2 (-950 *4 (-534 *5) *5)) (-5 *1 (-1114 *4 *5 *2)) (-4 *4 (-1047)) (-4 *5 (-842)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-953 *4)) (-5 *1 (-1190 *4)) (-4 *4 (-1047))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *5)) (-4 *5 (-13 (-27) (-1181) (-432 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-409 (-568))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-288 *3)) (-5 *5 (-409 (-568))) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *6 *3)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *8 (-409 (-568)))) (-5 *4 (-288 *8)) (-5 *5 (-1210 (-409 (-568)))) (-5 *6 (-409 (-568))) (-4 *8 (-13 (-27) (-1181) (-432 *7))) (-4 *7 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *7 *8)))) ((*1 *2 *3 *4 *5 *6 *7) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-5 *6 (-1210 (-409 (-568)))) (-5 *7 (-409 (-568))) (-4 *3 (-13 (-27) (-1181) (-432 *8))) (-4 *8 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *8 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-409 (-568))) (-4 *4 (-1047)) (-4 *1 (-1226 *4 *3)) (-4 *3 (-1203 *4))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1100))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *1) (-5 *1 (-142))) ((*1 *1 *1) (-5 *1 (-147))) ((*1 *1 *1) (-4 *1 (-1129)))) 
-(((*1 *2 *3 *4 *5 *5 *4 *6) (-12 (-5 *5 (-607 *4)) (-5 *6 (-1157 *4)) (-4 *4 (-13 (-432 *7) (-27) (-1181))) (-4 *7 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -3746 (-634 *4)))) (-5 *1 (-564 *7 *4 *3)) (-4 *3 (-646 *4)) (-4 *3 (-1090)))) ((*1 *2 *3 *4 *5 *5 *5 *4 *6) (-12 (-5 *5 (-607 *4)) (-5 *6 (-409 (-1157 *4))) (-4 *4 (-13 (-432 *7) (-27) (-1181))) (-4 *7 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -3746 (-634 *4)))) (-5 *1 (-564 *7 *4 *3)) (-4 *3 (-646 *4)) (-4 *3 (-1090))))) 
+(((*1 *2 *1 *3) (-12 (-4 *1 (-246 *4 *3 *5 *6)) (-4 *4 (-1047)) (-4 *3 (-842)) (-4 *5 (-262 *3)) (-4 *6 (-788)) (-5 *2 (-634 (-763))))) ((*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-634 (-763)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1894 (-568))))) (-5 *1 (-363 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1894 (-763))))) (-5 *1 (-388 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| -3850 *3) (|:| -3483 (-568))))) (-5 *1 (-420 *3)) (-4 *3 (-558)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1894 (-763))))) (-5 *1 (-814 *3)) (-4 *3 (-842))))) 
+(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-751))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-242 (-4289 (QUOTE X) (QUOTE -2928)) *3)) (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *5)) (-4 *5 (-13 (-27) (-1181) (-432 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-13 (-453) (-842) (-1037 *4) (-630 *4))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-453) (-842) (-1037 *5) (-630 *5))) (-5 *5 (-568)) (-5 *2 (-57)) (-5 *1 (-309 *6 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *7 (-568))) (-5 *4 (-288 *7)) (-5 *5 (-1210 (-568))) (-4 *7 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *6 *7)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-5 *6 (-1210 (-568))) (-4 *3 (-13 (-27) (-1181) (-432 *7))) (-4 *7 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *7 *3)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-568)) (-4 *4 (-1047)) (-4 *1 (-1205 *4 *3)) (-4 *3 (-1234 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-1226 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1203 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-5 *2 (-1249)) (-5 *1 (-1164)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-5 *2 (-1249)) (-5 *1 (-1164)))) ((*1 *2 *3 *4 *1) (-12 (-5 *3 (-1161)) (-5 *4 (-3 (|:| |fst| (-436)) (|:| -3611 "void"))) (-5 *2 (-1249)) (-5 *1 (-1164))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-634 *3)) (-5 *1 (-590 *5 *6 *7 *8 *3)) (-4 *3 (-1099 *5 *6 *7 *8)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-5 *2 (-634 (-2 (|:| -3471 (-1157 *5)) (|:| -4073 (-634 (-953 *5)))))) (-5 *1 (-1071 *5 *6)) (-5 *3 (-634 (-953 *5))) (-14 *6 (-634 (-1161))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-5 *2 (-634 (-2 (|:| -3471 (-1157 *4)) (|:| -4073 (-634 (-953 *4)))))) (-5 *1 (-1071 *4 *5)) (-5 *3 (-634 (-953 *4))) (-14 *5 (-634 (-1161))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-5 *2 (-634 (-2 (|:| -3471 (-1157 *5)) (|:| -4073 (-634 (-953 *5)))))) (-5 *1 (-1071 *5 *6)) (-5 *3 (-634 (-953 *5))) (-14 *6 (-634 (-1161)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-184)))) ((*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-294)))) ((*1 *2 *3) (-12 (-5 *3 (-1084 (-835 (-215)))) (-5 *2 (-215)) (-5 *1 (-299))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 (-900 *3))) (-4 *3 (-1090)) (-5 *1 (-899 *3))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *1 (-62 *2 *4 *5)) (-4 *4 (-375 *2)) (-4 *5 (-375 *2)) (-4 *2 (-1195)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-283 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1050 *4 *5 *2 *6 *7)) (-4 *6 (-230 *5 *2)) (-4 *7 (-230 *4 *2)) (-4 *2 (-1047))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))) (-5 *1 (-184))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *5)) (-4 *5 (-13 (-27) (-1181) (-432 *4))))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *4 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *4))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *5 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-288 *3)) (-5 *5 (-763)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-309 *6 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *6 (-568))) (-5 *4 (-288 *6)) (-4 *6 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *6 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *7 (-568))) (-5 *4 (-288 *7)) (-5 *5 (-1210 (-763))) (-4 *7 (-13 (-27) (-1181) (-432 *6))) (-4 *6 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *6 *7)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-1161)) (-5 *5 (-288 *3)) (-5 *6 (-1210 (-763))) (-4 *3 (-13 (-27) (-1181) (-432 *7))) (-4 *7 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-57)) (-5 *1 (-461 *7 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-1205 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1234 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-763)) (|:| |poli| *2) (|:| |polj| *2))) (-4 *5 (-788)) (-4 *2 (-950 *4 *5 *6)) (-5 *1 (-450 *4 *5 *6 *2)) (-4 *4 (-453)) (-4 *6 (-842))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-453)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6))))) 
-(((*1 *2 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-763)) (-4 *3 (-13 (-301) (-10 -8 (-15 -1678 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *1 (-508 *3 *4 *5)) (-4 *5 (-411 *3 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-1 *5 *5)) (-5 *1 (-799 *4 *5)) (-4 *5 (-13 (-29 *4) (-1181) (-959)))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1161)) (-5 *5 (-1084 (-215))) (-5 *2 (-927)) (-5 *1 (-925 *3)) (-4 *3 (-609 (-541))))) ((*1 *2 *3 *3 *4 *5) (-12 (-5 *4 (-1161)) (-5 *5 (-1084 (-215))) (-5 *2 (-927)) (-5 *1 (-925 *3)) (-4 *3 (-609 (-541))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-926)))) ((*1 *1 *2 *2 *2 *2 *3 *3 *3 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-926)))) ((*1 *1 *2 *2 *2 *2 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-926)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-927)))) ((*1 *1 *2 *2 *3 *3 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) ((*1 *1 *2 *2 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) ((*1 *1 *2 *3 *3) (-12 (-5 *2 (-634 (-1 (-215) (-215)))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-634 (-1 (-215) (-215)))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) ((*1 *1 *2 *3 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927))))) 
-(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-634 *4)) (-4 *4 (-365)) (-5 *2 (-1244 *4)) (-5 *1 (-809 *4 *3)) (-4 *3 (-646 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-5 *1 (-1170 *2)) (-4 *2 (-365))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))) (-5 *2 (-634 (-1161))) (-5 *1 (-263)))) ((*1 *2 *3) (-12 (-5 *3 (-1157 *7)) (-4 *7 (-950 *6 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-5 *2 (-634 *5)) (-5 *1 (-318 *4 *5 *6 *7)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-337 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-389)))) ((*1 *2 *1) (-12 (-4 *1 (-432 *3)) (-4 *3 (-842)) (-5 *2 (-634 (-1161))))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-950 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-634 *5)) (-5 *1 (-951 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2745 ($ *7)) (-15 -2317 (*7 $)) (-15 -2324 (*7 $))))))) ((*1 *2 *1) (-12 (-4 *1 (-974 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-787)) (-4 *5 (-842)) (-5 *2 (-634 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-634 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-558)) (-5 *2 (-634 (-1161))) (-5 *1 (-1042 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-121))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-634 *7)) (|:| |badPols| (-634 *7)))) (-5 *1 (-978 *4 *5 *6 *7)) (-5 *3 (-634 *7))))) 
-(((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1157 (-409 (-1157 *2)))) (-5 *4 (-607 *2)) (-4 *2 (-13 (-432 *5) (-27) (-1181))) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *1 (-564 *5 *2 *6)) (-4 *6 (-1090)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-950 *4 *5 *3)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1157 *4)) (-4 *4 (-1047)) (-4 *1 (-950 *4 *5 *3)) (-4 *5 (-788)) (-4 *3 (-842)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-1157 *2))) (-4 *5 (-788)) (-4 *4 (-842)) (-4 *6 (-1047)) (-4 *2 (-13 (-365) (-10 -8 (-15 -2745 ($ *7)) (-15 -2317 (*7 $)) (-15 -2324 (*7 $))))) (-5 *1 (-951 *5 *4 *6 *7 *2)) (-4 *7 (-950 *6 *5 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-1157 (-409 (-953 *5))))) (-5 *4 (-1161)) (-5 *2 (-409 (-953 *5))) (-5 *1 (-1042 *5)) (-4 *5 (-558))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-150))) (-5 *1 (-542 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-4 *4 (-1219 *3)) (-4 *5 (-714 *3 *4)) (-5 *1 (-546 *3 *4 *5 *2)) (-4 *2 (-1234 *5)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-5 *1 (-547 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-13 (-558) (-150))) (-5 *1 (-1137 *3))))) 
-(((*1 *2 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-558)) (-5 *1 (-970 *4 *2)) (-4 *2 (-1219 *4))))) 
-(((*1 *1 *2 *3) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-634 (-917))) (-5 *1 (-155 *4 *2 *5)) (-14 *4 (-917)) (-4 *2 (-365)) (-14 *5 (-994 *4 *2)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-703 *5 *6 *7)) (-4 *5 (-842)) (-4 *6 (-230 (-1697 *4) (-763))) (-14 *7 (-1 (-121) (-2 (|:| -4355 *5) (|:| -3438 *6)) (-2 (|:| -4355 *5) (|:| -3438 *6)))) (-14 *4 (-634 (-1161))) (-4 *2 (-172)) (-5 *1 (-463 *4 *2 *5 *6 *7 *8)) (-4 *8 (-950 *2 *6 (-852 *4))))) ((*1 *1 *2 *3) (-12 (-4 *1 (-518 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-842)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-568)) (-4 *2 (-558)) (-5 *1 (-615 *2 *4)) (-4 *4 (-1219 *2)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-698 *2)) (-4 *2 (-1047)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-725 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-716)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *5)) (-5 *3 (-634 (-763))) (-4 *1 (-730 *4 *5)) (-4 *4 (-1047)) (-4 *5 (-842)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-730 *4 *2)) (-4 *4 (-1047)) (-4 *2 (-842)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-844 *2)) (-4 *2 (-1047)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *6)) (-5 *3 (-634 (-763))) (-4 *1 (-950 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-950 *4 *5 *2)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *2 (-842)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *6)) (-5 *3 (-634 *5)) (-4 *1 (-974 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-787)) (-4 *6 (-842)))) ((*1 *1 *1 *2 *3) (-12 (-4 *1 (-974 *4 *3 *2)) (-4 *4 (-1047)) (-4 *3 (-787)) (-4 *2 (-842))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-453)) (-4 *4 (-842)) (-5 *1 (-577 *4 *2)) (-4 *2 (-279)) (-4 *2 (-432 *4))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-5 *2 (-1157 *1)) (-4 *1 (-327 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-5 *2 (-1157 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-372 *3 *2)) (-4 *3 (-172)) (-4 *3 (-365)) (-4 *2 (-1219 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-350)) (-5 *2 (-1157 *4)) (-5 *1 (-532 *4))))) 
+(((*1 *2) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-763)) (-5 *1 (-339 *3 *4 *5 *6)) (-4 *3 (-340 *4 *5 *6)))) ((*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-763))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-953 (-568)))) (-5 *1 (-439)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-679 (-215))) (-5 *2 (-1094)) (-5 *1 (-751)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-679 (-568))) (-5 *2 (-1094)) (-5 *1 (-751))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-634 (-2 (|:| |lcmfij| *4) (|:| |totdeg| (-763)) (|:| |poli| *6) (|:| |polj| *6)))) (-4 *4 (-788)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-453)) (-4 *5 (-842)) (-5 *1 (-450 *3 *4 *5 *6))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2852 *4) (|:| -2185 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-159 *4 *2)) (-4 *2 (-432 *4)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1082 *2)) (-4 *2 (-432 *4)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-159 *4 *2)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1082 *1)) (-4 *1 (-161)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-161)) (-5 *2 (-1161)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-470 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) ((*1 *1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1262 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172))))) 
+(((*1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-558)) (-4 *2 (-172))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *2)) (-4 *2 (-172)))) ((*1 *2) (-12 (-4 *2 (-172)) (-5 *1 (-418 *3 *2)) (-4 *3 (-419 *2)))) ((*1 *2) (-12 (-4 *1 (-419 *2)) (-4 *2 (-172))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1127 *4 *2)) (-14 *4 (-917)) (-4 *2 (-13 (-1047) (-10 -7 (-6 (-4523 "*"))))) (-5 *1 (-897 *4 *2))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 (-1255 *4 *5 *6 *7))) (-5 *1 (-1255 *4 *5 *6 *7)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 *9)) (-5 *4 (-1 (-121) *9 *9)) (-5 *5 (-1 *9 *9 *9)) (-4 *9 (-1061 *6 *7 *8)) (-4 *6 (-558)) (-4 *7 (-788)) (-4 *8 (-842)) (-5 *2 (-634 (-1255 *6 *7 *8 *9))) (-5 *1 (-1255 *6 *7 *8 *9))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) (-5 *2 (-634 (-1161))) (-5 *1 (-263)))) ((*1 *2 *3) (-12 (-5 *3 (-1157 *7)) (-4 *7 (-950 *6 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-5 *2 (-634 *5)) (-5 *1 (-318 *4 *5 *6 *7)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-337 *3 *4 *5)) (-14 *3 *2) (-14 *4 *2) (-4 *5 (-389)))) ((*1 *2 *1) (-12 (-4 *1 (-432 *3)) (-4 *3 (-842)) (-5 *2 (-634 (-1161))))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-950 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-634 *5)) (-5 *1 (-951 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2747 ($ *7)) (-15 -2319 (*7 $)) (-15 -2326 (*7 $))))))) ((*1 *2 *1) (-12 (-4 *1 (-974 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-787)) (-4 *5 (-842)) (-5 *2 (-634 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-634 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-409 (-953 *4))) (-4 *4 (-558)) (-5 *2 (-634 (-1161))) (-5 *1 (-1042 *4))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| -3649 (-1161)) (|:| -4083 *4)))) (-5 *1 (-884 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)))) ((*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-634 *1)) (-4 *1 (-1093 *3 *4 *5 *6 *7))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-121)) (-5 *1 (-214 *4 *5)) (-4 *5 (-13 (-1181) (-29 *4)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| -3649 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4083 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-5 *1 (-563)))) ((*1 *2 *1) (-12 (-4 *1 (-601 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1195)) (-5 *2 (-634 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1044 *4 *5)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *5 (-634 (-1161))) (-5 *2 (-634 (-634 (-1023 (-409 *4))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *6 (-634 (-1161))))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *5))))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *5))))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *4))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-159 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
+(((*1 *2) (-12 (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-1239 (-568) -3494)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-1239 (-568) -3494)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) ((*1 *2) (-12 (-5 *2 (-1239 (-568) -3494)) (-5 *1 (-867 *3 *4 *5)) (-4 (-857 *3) (-370)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1239 (-568) -3494)) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2) (-12 (-5 *2 (-1239 (-568) -3494)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1239 (-568) -3494)) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117))))) 
+(((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1157 (-409 (-1157 *2)))) (-5 *4 (-607 *2)) (-4 *2 (-13 (-432 *5) (-27) (-1181))) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *1 (-564 *5 *2 *6)) (-4 *6 (-1090)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-950 *4 *5 *3)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1157 *4)) (-4 *4 (-1047)) (-4 *1 (-950 *4 *5 *3)) (-4 *5 (-788)) (-4 *3 (-842)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-1157 *2))) (-4 *5 (-788)) (-4 *4 (-842)) (-4 *6 (-1047)) (-4 *2 (-13 (-365) (-10 -8 (-15 -2747 ($ *7)) (-15 -2319 (*7 $)) (-15 -2326 (*7 $))))) (-5 *1 (-951 *5 *4 *6 *7 *2)) (-4 *7 (-950 *6 *5 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-1157 (-409 (-953 *5))))) (-5 *4 (-1161)) (-5 *2 (-409 (-953 *5))) (-5 *1 (-1042 *5)) (-4 *5 (-558))))) 
+(((*1 *2 *3 *3 *3) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1100)) (-5 *3 (-568))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *1 *2 *3) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-634 (-917))) (-5 *1 (-155 *4 *2 *5)) (-14 *4 (-917)) (-4 *2 (-365)) (-14 *5 (-994 *4 *2)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-703 *5 *6 *7)) (-4 *5 (-842)) (-4 *6 (-230 (-1699 *4) (-763))) (-14 *7 (-1 (-121) (-2 (|:| -4357 *5) (|:| -3483 *6)) (-2 (|:| -4357 *5) (|:| -3483 *6)))) (-14 *4 (-634 (-1161))) (-4 *2 (-172)) (-5 *1 (-463 *4 *2 *5 *6 *7 *8)) (-4 *8 (-950 *2 *6 (-852 *4))))) ((*1 *1 *2 *3) (-12 (-4 *1 (-518 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-842)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-568)) (-4 *2 (-558)) (-5 *1 (-615 *2 *4)) (-4 *4 (-1219 *2)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-698 *2)) (-4 *2 (-1047)))) ((*1 *1 *2 *3) (-12 (-5 *1 (-725 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-716)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *5)) (-5 *3 (-634 (-763))) (-4 *1 (-730 *4 *5)) (-4 *4 (-1047)) (-4 *5 (-842)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-730 *4 *2)) (-4 *4 (-1047)) (-4 *2 (-842)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-844 *2)) (-4 *2 (-1047)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *6)) (-5 *3 (-634 (-763))) (-4 *1 (-950 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)))) ((*1 *1 *1 *2 *3) (-12 (-5 *3 (-763)) (-4 *1 (-950 *4 *5 *2)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *2 (-842)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *6)) (-5 *3 (-634 *5)) (-4 *1 (-974 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-787)) (-4 *6 (-842)))) ((*1 *1 *1 *2 *3) (-12 (-4 *1 (-974 *4 *3 *2)) (-4 *4 (-1047)) (-4 *3 (-787)) (-4 *2 (-842))))) 
+(((*1 *2 *2 *3) (-12 (-4 *3 (-1047)) (-5 *1 (-445 *3 *2)) (-4 *2 (-1219 *3))))) 
+(((*1 *1) (-12 (-4 *1 (-406)) (-3046 (|has| *1 (-6 -4512))) (-3046 (|has| *1 (-6 -4504))))) ((*1 *2 *1) (-12 (-4 *1 (-427 *2)) (-4 *2 (-1090)) (-4 *2 (-842)))) ((*1 *2 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-4 *1 (-842))) ((*1 *2 *1) (-12 (-4 *1 (-969 *2)) (-4 *2 (-842)))) ((*1 *1) (-5 *1 (-1108)))) 
+(((*1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-558)) (-4 *2 (-172))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| -3651 (-1161)) (|:| -4085 *4)))) (-5 *1 (-884 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)))) ((*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-634 *1)) (-4 *1 (-1093 *3 *4 *5 *6 *7))))) 
+(((*1 *1 *2 *3 *4) (-12 (-5 *3 (-634 (-2 (|:| |scalar| (-409 (-568))) (|:| |coeff| (-1157 *2)) (|:| |logand| (-1157 *2))))) (-5 *4 (-634 (-2 (|:| |integrand| *2) (|:| |intvar| *2)))) (-4 *2 (-365)) (-5 *1 (-585 *2))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-953 *4)) (-4 *4 (-13 (-301) (-150))) (-4 *2 (-950 *4 *6 *5)) (-5 *1 (-924 *4 *5 *6 *2)) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-310 (-169 (-381)))) (-5 *1 (-328)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-568))) (-5 *1 (-328)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-381))) (-5 *1 (-328)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-683))) (-5 *1 (-328)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-690))) (-5 *1 (-328)))) ((*1 *1 *2) (-12 (-5 *2 (-310 (-688))) (-5 *1 (-328)))) ((*1 *1) (-5 *1 (-328)))) 
 (((*1 *1 *2) (-12 (-5 *2 (-1244 *4)) (-4 *4 (-1195)) (-4 *1 (-230 *3 *4))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1157 (-953 *6))) (-4 *6 (-558)) (-4 *2 (-950 (-409 (-953 *6)) *5 *4)) (-5 *1 (-722 *5 *4 *6 *2)) (-4 *5 (-788)) (-4 *4 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $)))))))) 
+(((*1 *1) (-5 *1 (-439)))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| -2910 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *1) (-5 *1 (-1059)))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7))))) 
+(((*1 *1 *2 *2 *2 *2) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365))))) 
+(((*1 *1 *2) (|partial| -12 (-5 *2 (-814 *3)) (-4 *3 (-842)) (-5 *1 (-663 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-365)) (-5 *2 (-634 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-634 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-57)) (-5 *1 (-824))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-1219 *3)) (-5 *1 (-164 *3 *4 *2)) (-4 *2 (-1219 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-2 (|:| |deg| (-763)) (|:| -2410 *5)))) (-5 *1 (-804 *4 *5 *3 *6)) (-4 *3 (-646 *5)) (-4 *6 (-646 (-409 *5)))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-422 *3 *2 *4 *5)) (-4 *2 (-13 (-27) (-1181) (-432 *3))) (-14 *4 (-1161)) (-14 *5 *2))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-4 *2 (-13 (-27) (-1181) (-432 *3) (-10 -8 (-15 -2747 ($ *4))))) (-4 *4 (-840)) (-4 *5 (-13 (-1221 *2 *4) (-365) (-1181) (-10 -8 (-15 -4191 ($ $)) (-15 -1845 ($ $))))) (-5 *1 (-424 *3 *2 *4 *5 *6 *7)) (-4 *6 (-984 *5)) (-14 *7 (-1161))))) 
 (((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *2 (-634 *8)) (-5 *1 (-963 *4 *5 *6 *7 *8)) (-4 *8 (-971 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)) (-5 *2 (-1157 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3700 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| *7) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 *7))))) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-763)) (-5 *1 (-924 *4 *5 *6 *7))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-555 *3)) (-4 *3 (-13 (-406) (-1181))) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-840)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1063 *4 *3)) (-4 *4 (-13 (-840) (-365))) (-4 *3 (-1219 *4)) (-5 *2 (-121))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-1087 *3)) (-4 *3 (-1090)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (|partial| -12 (-5 *2 (-1157 *1)) (-4 *1 (-1012))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-242 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *2 (-492 *4 *5)) (-5 *1 (-622 *4 *5))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-763)) (-5 *4 (-568)) (-5 *1 (-446 *2)) (-4 *2 (-1047))))) 
-(((*1 *1) (-12 (-4 *1 (-327 *2)) (-4 *2 (-370)) (-4 *2 (-365))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *3 (-944 *5)) (-4 *5 (-1047)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-763)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)) (-4 *5 (-1047)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-944 *5)) (-4 *5 (-1047)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-453) (-150))) (-5 *2 (-420 *3)) (-5 *1 (-103 *4 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-13 (-453) (-150))) (-5 *2 (-420 *3)) (-5 *1 (-103 *5 *3))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-763)) (-5 *1 (-446 *3)) (-4 *3 (-406)) (-4 *3 (-1047)))) ((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-446 *3)) (-4 *3 (-406)) (-4 *3 (-1047))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3))))) 
-(((*1 *2) (-12 (-4 *1 (-350)) (-5 *2 (-3 "prime" "polynomial" "normal" "cyclic"))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-550)) (-5 *1 (-160 *2))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6))))) 
-(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-99))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-814 *3)))) ((*1 *2 *1) (-12 (-4 *2 (-838)) (-5 *1 (-1265 *3 *2)) (-4 *3 (-1047))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1864 *7) (|:| -4477 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *5 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *5))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-375 *3)) (-4 *3 (-1195)) (-4 *3 (-842)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *1 (-375 *4)) (-4 *4 (-1195)) (-5 *2 (-121))))) 
-(((*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) ((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-634 (-1216 *5 *4))) (-5 *1 (-1104 *4 *5)) (-5 *3 (-1216 *5 *4))))) 
+(((*1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-536 *4 *5 *6 *7 *8 *9 *10 *2 *12)) (-4 *12 (-117)) (-4 *2 (-235 *10)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *2 *11 *3 *12)) (-4 *3 (-258 *11))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-1143))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-242 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-1047)) (-5 *2 (-953 *5)) (-5 *1 (-945 *4 *5))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -2534 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *2 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-230 (-1699 *5) (-763))) (-5 *1 (-119 *4 *5 *2 *6 *3)) (-4 *2 (-324 *4 *6)) (-4 *3 (-117))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-568)))) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| |ans| (-409 *5)) (|:| |nosol| (-121)))) (-5 *1 (-1015 *4 *5)) (-5 *3 (-409 *5))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-634 *7)) (|:| |badPols| (-634 *7)))) (-5 *1 (-978 *4 *5 *6 *7)) (-5 *3 (-634 *7))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| -2723 *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *2 *2 *3 *4 *4) (-12 (-5 *4 (-568)) (-4 *3 (-172)) (-4 *5 (-375 *3)) (-4 *6 (-375 *3)) (-5 *1 (-678 *3 *5 *6 *2)) (-4 *2 (-677 *3 *5 *6))))) 
 (((*1 *1 *1) (-4 *1 (-40))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1201 *2)) (-4 *2 (-1047)))) ((*1 *1 *1) (-12 (-5 *1 (-1235 *2 *3 *4)) (-4 *2 (-1047)) (-14 *3 (-1161)) (-14 *4 *2))) ((*1 *1 *1) (-12 (-5 *1 (-1239 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-1161))))) 
+(((*1 *1 *2) (|partial| -12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-1255 *3 *4 *5 *6)))) ((*1 *1 *2 *3 *4) (|partial| -12 (-5 *2 (-634 *8)) (-5 *3 (-1 (-121) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-1255 *5 *6 *7 *8))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)) (-4 *2 (-1181)))) ((*1 *2 *1) (-12 (-5 *1 (-329 *2)) (-4 *2 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-607 *3)) (-4 *3 (-842))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-320 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-137)) (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1894 *4)))))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| -2350 *3) (|:| -2356 *4)))) (-5 *1 (-725 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-716)))) ((*1 *2 *1) (-12 (-4 *1 (-1221 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-1141 (-2 (|:| |k| *4) (|:| |c| *3))))))) 
 (((*1 *1 *1) (-4 *1 (-40))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3))))) 
-(((*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-1044 *5 *6))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-1044 *5 *6))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-1044 *4 *5))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161)))))) 
-(((*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-989 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6)))) ((*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-1097 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-121))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *3 (-558)) (-4 *3 (-172)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-678 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-842) (-1037 (-568)))) (-5 *1 (-180 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 (-169 *3)))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-5 *1 (-180 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 (-169 *4)))))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *3 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *3))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-1185 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4)))))) 
 (((*1 *1 *1) (-4 *1 (-40))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-428 *5 *3)) (-4 *3 (-13 (-1181) (-29 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-558) (-1037 (-568)) (-150))) (-5 *2 (-585 (-409 (-953 *5)))) (-5 *1 (-574 *5)) (-5 *3 (-409 (-953 *5)))))) 
-(((*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-634 (-679 *6))) (-5 *4 (-121)) (-5 *5 (-568)) (-5 *2 (-679 *6)) (-5 *1 (-1029 *6)) (-4 *6 (-365)) (-4 *6 (-1047)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-634 (-679 *4))) (-5 *2 (-679 *4)) (-5 *1 (-1029 *4)) (-4 *4 (-365)) (-4 *4 (-1047)))) ((*1 *2 *3 *3 *4) (-12 (-5 *3 (-634 (-679 *5))) (-5 *4 (-568)) (-5 *2 (-679 *5)) (-5 *1 (-1029 *5)) (-4 *5 (-365)) (-4 *5 (-1047))))) 
-(((*1 *1) (-5 *1 (-142))) ((*1 *1 *1) (-5 *1 (-147))) ((*1 *1 *1) (-4 *1 (-1129)))) 
+(((*1 *1 *1 *1 *1) (-4 *1 (-753)))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-256))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
 (((*1 *1 *1) (-4 *1 (-40))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-3 (-1157 *4) (-1244 (-634 (-2 (|:| -2850 *4) (|:| -4355 (-1108))))))) (-5 *1 (-347 *4)) (-4 *4 (-350))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| |func| *3) (|:| |poly| *3) (|:| |c1| (-409 *5)) (|:| |c2| (-409 *5)) (|:| |deg| (-763)))) (-5 *1 (-151 *4 *5 *3)) (-4 *3 (-1219 (-409 *5)))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-139))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-169 (-568)))))) (-5 *2 (-634 (-634 (-288 (-953 (-169 *4)))))) (-5 *1 (-380 *4)) (-4 *4 (-13 (-365) (-840))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-288 (-409 (-953 (-169 (-568))))))) (-5 *2 (-634 (-634 (-288 (-953 (-169 *4)))))) (-5 *1 (-380 *4)) (-4 *4 (-13 (-365) (-840))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 (-169 (-568))))) (-5 *2 (-634 (-288 (-953 (-169 *4))))) (-5 *1 (-380 *4)) (-4 *4 (-13 (-365) (-840))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-288 (-409 (-953 (-169 (-568)))))) (-5 *2 (-634 (-288 (-953 (-169 *4))))) (-5 *1 (-380 *4)) (-4 *4 (-13 (-365) (-840)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-500)))) ((*1 *2 *3) (-12 (-5 *3 (-850)) (-5 *2 (-1143)) (-5 *1 (-700))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1157 *5)) (-4 *5 (-365)) (-5 *2 (-634 *6)) (-5 *1 (-535 *5 *6 *4)) (-4 *6 (-365)) (-4 *4 (-13 (-365) (-840)))))) 
 (((*1 *1 *1) (-4 *1 (-40))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-2 (|:| -1924 *6) (|:| |coeff| *6)) "failed") *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-5 *2 (-2 (|:| |answer| (-585 (-409 *7))) (|:| |a0| *6))) (-5 *1 (-578 *6 *7)) (-5 *3 (-409 *7))))) 
-(((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927))))) 
-(((*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 (-679 *3))) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-112)))) ((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-208)))) ((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-497)))) ((*1 *1 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)) (-4 *2 (-301)))) ((*1 *2 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568)))) ((*1 *1 *1) (-4 *1 (-1056)))) 
+(((*1 *1 *1) (-12 (-4 *1 (-324 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)) (-4 *2 (-453)))) ((*1 *1 *1) (-12 (-4 *1 (-340 *2 *3 *4)) (-4 *2 (-1199)) (-4 *3 (-1219 *2)) (-4 *4 (-1219 (-409 *3))))) ((*1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-453)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-950 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *3 (-453)))) ((*1 *1 *1) (-12 (-4 *1 (-950 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453)))) ((*1 *2 *2 *3) (-12 (-4 *3 (-301)) (-4 *3 (-558)) (-5 *1 (-1148 *3 *2)) (-4 *2 (-1219 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *1 *1) (-4 *1 (-502))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217)) (-5 *3 (-215))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-4 *5 (-432 *4)) (-5 *2 (-420 *3)) (-5 *1 (-437 *4 *5 *3)) (-4 *3 (-1219 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *2 (-3 (-634 *8) "failed" "Infinite" (-568))) (-5 *1 (-31 *4 *5 *6 *7 *8)) (-4 *8 (-971 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *2 (-3 (-634 *8) "failed" "Infinite" (-568))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *8 (-971 *4))))) 
+(((*1 *1) (-5 *1 (-1059)))) 
+(((*1 *1 *1) (-5 *1 (-1059)))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-634 (-1161))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *5)))))) (-5 *1 (-762 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *4)))))) (-5 *1 (-762 *4)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *7)) (-5 *5 (-1 (-2 (|:| |particular| (-3 *6 "failed")) (|:| -2588 (-634 *6))) *7 *6)) (-4 *6 (-365)) (-4 *7 (-646 *6)) (-5 *2 (-2 (|:| |particular| (-3 (-1244 *6) "failed")) (|:| -2588 (-634 (-1244 *6))))) (-5 *1 (-808 *6 *7)) (-5 *4 (-1244 *6))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *1 *1) (-4 *1 (-502))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-585 *2)) (-4 *2 (-13 (-29 *4) (-1181))) (-5 *1 (-583 *4 *2)) (-4 *4 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))))) ((*1 *2 *3) (-12 (-5 *3 (-585 (-409 (-953 *4)))) (-4 *4 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *2 (-310 *4)) (-5 *1 (-588 *4))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-641 *2)) (-4 *2 (-365))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-173 (-409 (-568)))) (-5 *1 (-126 *3)) (-14 *3 (-568)))) ((*1 *1 *2 *3 *3) (-12 (-5 *3 (-1141 *2)) (-4 *2 (-301)) (-5 *1 (-173 *2)))) ((*1 *1 *2) (-12 (-5 *2 (-409 *3)) (-4 *3 (-301)) (-5 *1 (-173 *3)))) ((*1 *2 *3) (-12 (-5 *2 (-173 (-568))) (-5 *1 (-757 *3)) (-4 *3 (-406)))) ((*1 *2 *1) (-12 (-5 *2 (-173 (-409 (-568)))) (-5 *1 (-865 *3)) (-14 *3 (-568)))) ((*1 *2 *1) (-12 (-14 *3 (-568)) (-5 *2 (-173 (-409 (-568)))) (-5 *1 (-866 *3 *4)) (-4 *4 (-863 *3))))) 
+(((*1 *1) (-4 *1 (-39))) ((*1 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) ((*1 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) ((*1 *1) (-5 *1 (-850))) ((*1 *1) (-12 (-4 *2 (-453)) (-4 *3 (-842)) (-4 *4 (-788)) (-5 *1 (-988 *2 *3 *4 *5)) (-4 *5 (-950 *2 *4 *3)))) ((*1 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) ((*1 *1) (-12 (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39))))) ((*1 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) ((*1 *1) (-5 *1 (-1164))) ((*1 *1) (-5 *1 (-1165)))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |scalar| (-409 (-568))) (|:| |coeff| (-1157 *3)) (|:| |logand| (-1157 *3))))) (-5 *1 (-585 *3)) (-4 *3 (-365))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *1 *1) (-4 *1 (-502))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3))))) 
-(((*1 *2 *3 *3) (-12 (-5 *2 (-1157 *3)) (-5 *1 (-910 *3)) (-4 *3 (-301))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-944 *3))))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047))))) 
-(((*1 *2 *3) (-12 (-4 *1 (-916)) (-5 *2 (-2 (|:| -2348 (-634 *1)) (|:| -2704 *1))) (-5 *3 (-634 *1))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181))))) ((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) ((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-850))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-392 *3 *4 *5)) (-14 *3 (-763)) (-14 *4 (-763)) (-4 *5 (-172))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) ((*1 *1 *1) (-4 *1 (-502))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-5 *2 (-1249)) (-5 *1 (-1197)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-634 (-1161))) (-5 *2 (-1249)) (-5 *1 (-1197))))) 
-(((*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-634 *3)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-634 *3)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-634 *3)) (-5 *1 (-494 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (|has| *1 (-6 -4519)) (-4 *1 (-499 *3)) (-4 *3 (-1195)) (-5 *2 (-634 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-727 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-634 *3)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-634 *3)) (-5 *1 (-1132 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *3 *4 *5 *6 *7 *6) (|partial| -12 (-5 *5 (-2 (|:| |contp| *3) (|:| -2075 (-634 (-2 (|:| |irr| *10) (|:| -4402 (-568))))))) (-5 *6 (-634 *3)) (-5 *7 (-634 *8)) (-4 *8 (-842)) (-4 *3 (-301)) (-4 *10 (-950 *3 *9 *8)) (-4 *9 (-788)) (-5 *2 (-2 (|:| |polfac| (-634 *10)) (|:| |correct| *3) (|:| |corrfact| (-634 (-1157 *3))))) (-5 *1 (-617 *8 *9 *3 *10)) (-5 *4 (-634 (-1157 *3)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-953 (-215))) (-5 *2 (-310 (-381))) (-5 *1 (-299))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-817))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) ((*1 *1 *1) (-4 *1 (-502))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1047)) (-5 *2 (-1244 *3)) (-5 *1 (-702 *3 *4)) (-4 *4 (-1219 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1141 (-1141 *4))) (-5 *2 (-1141 *4)) (-5 *1 (-1145 *4)) (-4 *4 (-43 (-409 (-568)))) (-4 *4 (-1047))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-150))) (-5 *1 (-542 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-4 *4 (-1219 *3)) (-4 *5 (-714 *3 *4)) (-5 *1 (-546 *3 *4 *5 *2)) (-4 *2 (-1234 *5)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-5 *1 (-547 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-13 (-558) (-150))) (-5 *1 (-1137 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-121)) (-4 *4 (-13 (-365) (-840))) (-5 *2 (-420 *3)) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4))))) ((*1 *2 *3 *4) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-420 *3)) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4)))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-5 *3 (-634 *7)) (-4 *1 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)))) ((*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) ((*1 *1 *1) (-4 *1 (-502))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-1141 *4)) (-4 *4 (-43 *3)) (-4 *4 (-1047)) (-5 *3 (-409 (-568))) (-5 *1 (-1145 *4))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568)))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-958 *3)) (-5 *1 (-1148 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1143)) (-5 *3 (-766)) (-5 *1 (-123))))) 
+(((*1 *1 *1) (|partial| -12 (-4 *1 (-369 *2)) (-4 *2 (-172)) (-4 *2 (-558)))) ((*1 *1 *1) (|partial| -4 *1 (-712)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-568)) (|has| *1 (-6 -4512)) (-4 *1 (-406)) (-5 *2 (-917))))) 
 (((*1 *1 *1) (-4 *1 (-98))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217)))) ((*1 *1 *1) (-4 *1 (-620))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-679 (-409 (-953 (-568))))) (-5 *2 (-634 (-679 (-310 (-568))))) (-5 *1 (-1031)) (-5 *3 (-310 (-568)))))) 
-(((*1 *2) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-109))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-301) (-150))) (-4 *4 (-13 (-842) (-609 (-1161)))) (-4 *5 (-788)) (-5 *1 (-924 *3 *4 *5 *2)) (-4 *2 (-950 *3 *5 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1249)) (-5 *1 (-450 *4 *5 *6 *7))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-1244 *1)) (-4 *1 (-858)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-1219 *4)) (-4 *4 (-1047)) (-5 *2 (-1244 *4))))) 
 (((*1 *1 *1) (-4 *1 (-98))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3))))) 
-(((*1 *2 *3) (-12 (-4 *1 (-340 *4 *3 *5)) (-4 *4 (-1199)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 (-409 *3))) (-5 *2 (-121)))) ((*1 *2 *3) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-568)) (-4 *4 (-350)) (-5 *1 (-532 *4))))) 
+(((*1 *1) (-5 *1 (-158)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-679 *2)) (-4 *4 (-1219 *2)) (-4 *2 (-13 (-301) (-10 -8 (-15 -3498 ((-420 $) $))))) (-5 *1 (-508 *2 *4 *5)) (-4 *5 (-411 *2 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-1111 *3 *2 *4 *5)) (-4 *4 (-230 *3 *2)) (-4 *5 (-230 *3 *2)) (-4 *2 (-1047))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-158)) (-5 *1 (-869))))) 
 (((*1 *1 *1) (-4 *1 (-98))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1864 *7) (|:| -4477 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *5 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3)))) 
-(((*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-453)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *3)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6))))) 
+(((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-169 (-381)))) (-5 *1 (-328)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-381))) (-5 *1 (-328)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-568))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-169 (-381))))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-381)))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-568)))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-169 (-381))))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-381)))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-568)))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-169 (-381)))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-381))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-568))) (-5 *1 (-328)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-683))) (-5 *1 (-328)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-688))) (-5 *1 (-328)))) ((*1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-953 (-568)))) (-5 *4 (-310 (-690))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-683)))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-688)))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-310 (-690)))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-683)))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-688)))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-310 (-690)))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-683))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-688))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-690))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-683))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-688))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-679 (-690))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-683))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-688))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-310 (-690))) (-5 *1 (-328)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1143)) (-5 *1 (-328)))) ((*1 *1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *1) (-5 *1 (-1164)))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-1047)) (-4 *7 (-1047)) (-4 *6 (-1219 *5)) (-5 *2 (-1157 (-1157 *7))) (-5 *1 (-510 *5 *6 *4 *7)) (-4 *4 (-1219 *6))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-910 *2)) (-4 *2 (-301))))) 
 (((*1 *1 *1) (-4 *1 (-98))) ((*1 *1 *1 *1) (-5 *1 (-215))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) ((*1 *1 *1 *1) (-5 *1 (-381))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *5 *7)) (-5 *4 (-1157 *7)) (-4 *5 (-1047)) (-4 *7 (-1047)) (-4 *2 (-1219 *5)) (-5 *1 (-510 *5 *2 *6 *7)) (-4 *6 (-1219 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *7 *5)) (-4 *5 (-1047)) (-4 *7 (-1047)) (-4 *4 (-1219 *5)) (-5 *2 (-1157 *7)) (-5 *1 (-510 *5 *4 *6 *7)) (-4 *6 (-1219 *4))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-1126 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39)))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-453)) (-5 *2 (-634 (-2 (|:| |eigval| (-3 (-409 (-953 *4)) (-1150 (-1161) (-953 *4)))) (|:| |geneigvec| (-634 (-679 (-409 (-953 *4)))))))) (-5 *1 (-286 *4)) (-5 *3 (-679 (-409 (-953 *4))))))) 
-(((*1 *1) (-5 *1 (-818)))) 
+(((*1 *1 *1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1141 *3)) (-4 *3 (-1195)))) ((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
+(((*1 *1 *1) (|partial| -12 (-5 *1 (-1126 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39)))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) ((*1 *2 *2 *2 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-121)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-978 *4 *5 *6 *7))))) 
 (((*1 *1 *1) (-4 *1 (-98))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3))))) 
-(((*1 *2 *2 *3 *4) (-12 (-5 *3 (-123)) (-5 *4 (-1161)) (-4 *5 (-13 (-842) (-558) (-609 (-541)))) (-4 *2 (-432 *5)) (-5 *1 (-312 *5 *2 *6 *7)) (-4 *6 (-1234 *2)) (-4 *7 (-1234 (-1155 *2)))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-688)))) ((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-688))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1191 *3)) (-4 *3 (-975))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-763)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4))))) 
+(((*1 *2 *2 *2 *2 *2 *2) (-12 (-4 *2 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *1 (-1116 *3 *2)) (-4 *3 (-1219 *2))))) 
 (((*1 *1 *1) (-4 *1 (-98))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-777 *2)) (-4 *2 (-1047))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-173 *3)) (-4 *3 (-301))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-5 *1 (-563)))) ((*1 *2 *1) (-12 (-4 *1 (-605 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-5 *2 (-634 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))) (-5 *1 (-798))))) 
+(((*1 *1 *2 *2) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181)))))) 
+(((*1 *2 *2 *3 *4) (-12 (-5 *2 (-634 *8)) (-5 *3 (-1 (-121) *8 *8)) (-5 *4 (-1 *8 *8 *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-978 *5 *6 *7 *8))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-172)))) ((*1 *2 *3 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-172))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) ((*1 *1 *1) (-4 *1 (-1184)))) 
-(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
-(((*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3))))) 
-(((*1 *2) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
+(((*1 *1 *1 *2) (-12 (-5 *1 (-1125 *2 *3)) (-4 *2 (-13 (-1090) (-39))) (-4 *3 (-13 (-1090) (-39)))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
+(((*1 *2 *3 *4 *4) (-12 (-5 *3 (-1 *2 *2 *2)) (-4 *2 (-1234 *4)) (-5 *1 (-1236 *4 *2)) (-4 *4 (-43 (-409 (-568))))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) ((*1 *1 *1) (-4 *1 (-1184)))) 
-(((*1 *2 *1) (-12 (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-880 *3 *4 *5)) (-4 *3 (-1090)) (-4 *5 (-658 *4)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-884 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-301)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-2 (|:| |Smith| *3) (|:| |leftEqMat| *3) (|:| |rightEqMat| *3))) (-5 *1 (-1112 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1143)) (-5 *1 (-781))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1039))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-850))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) ((*1 *1 *1) (-4 *1 (-1184)))) 
-(((*1 *2) (-12 (-5 *2 (-958 (-1108))) (-5 *1 (-341 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917)))) ((*1 *2) (-12 (-5 *2 (-958 (-1108))) (-5 *1 (-342 *3 *4)) (-4 *3 (-350)) (-14 *4 (-1157 *3)))) ((*1 *2) (-12 (-5 *2 (-958 (-1108))) (-5 *1 (-343 *3 *4)) (-4 *3 (-350)) (-14 *4 (-917))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-310 (-215)))) (-5 *4 (-763)) (-5 *2 (-679 (-215))) (-5 *1 (-263))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-634 *7)) (|:| |badPols| (-634 *7)))) (-5 *1 (-978 *4 *5 *6 *7)) (-5 *3 (-634 *7))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-910 *2)) (-4 *2 (-301))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-365)))) ((*1 *2 *1) (-12 (-4 *1 (-971 *2)) (-4 *2 (-365))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-230 *5 (-763))) (-14 *5 (-763)) (-5 *1 (-908 *3 *2 *4 *5)) (-4 *2 (-324 *3 *4)))) ((*1 *2 *2 *3) (-12 (-4 *4 (-365)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-929 *4 *2 *5 *6 *3)) (-4 *2 (-324 *4 *5)) (-4 *3 (-971 *4)))) ((*1 *2 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-365)) (-4 *6 (-230 *7 (-763))) (-14 *7 (-763)) (-5 *1 (-929 *5 *2 *6 *7 *3)) (-4 *2 (-324 *5 *6)) (-4 *3 (-971 *5))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) ((*1 *1 *1) (-4 *1 (-1184)))) 
 (((*1 *1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)))) ((*1 *2 *1) (-12 (-4 *1 (-327 *2)) (-4 *2 (-365)))) ((*1 *2 *1) (-12 (-4 *1 (-372 *2 *3)) (-4 *3 (-1219 *2)) (-4 *2 (-172)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1244 *4)) (-5 *3 (-917)) (-4 *4 (-350)) (-5 *1 (-532 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-1111 *3 *2 *4 *5)) (-4 *4 (-230 *3 *2)) (-4 *5 (-230 *3 *2)) (-4 *2 (-1047))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878))))) 
-(((*1 *2 *3 *3 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-568)))) ((*1 *2 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-568)))) ((*1 *2 *3 *3) (-12 (-5 *2 (-1141 (-634 (-568)))) (-5 *1 (-878)) (-5 *3 (-568))))) 
+(((*1 *2 *1) (|partial| -12 (-5 *2 (-1108)) (-5 *1 (-113)))) ((*1 *2 *1) (|partial| -12 (-5 *1 (-367 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-1143)) (-5 *1 (-1177))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-365)) (-5 *2 (-634 *5)) (-5 *1 (-635 *5 *3)) (-4 *3 (-641 *5))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3))))) 
 (((*1 *1 *1) (-4 *1 (-620))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) ((*1 *2 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-842) (-558))) (-5 *2 (-121)) (-5 *1 (-272 *4 *3)) (-4 *3 (-13 (-432 *4) (-1002)))))) 
-(((*1 *1 *2 *3 *4) (-12 (-5 *3 (-568)) (-5 *4 (-3 "nil" "sqfr" "irred" "prime")) (-5 *1 (-420 *2)) (-4 *2 (-558))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-585 *2)) (-4 *2 (-365))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1047)) (-5 *2 (-634 *1)) (-4 *1 (-1122 *3))))) 
-(((*1 *1) (-5 *1 (-439)))) 
-(((*1 *1 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-5 *2 (-1161)) (-5 *1 (-328))))) 
-(((*1 *2 *2 *3 *3) (-12 (-5 *3 (-568)) (-4 *4 (-172)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *1 (-678 *4 *5 *6 *2)) (-4 *2 (-677 *4 *5 *6))))) 
-(((*1 *2 *3 *3 *4) (-12 (-5 *3 (-634 *5)) (-4 *5 (-13 (-558) (-453))) (-5 *4 (-763)) (-5 *2 (-409 (-1157 *5))) (-5 *1 (-346 *5 *6)) (-4 *6 (-52 *5 *4)))) ((*1 *2 *3 *3 *4) (-12 (-5 *3 (-634 (-409 *5))) (-4 *5 (-13 (-558) (-453))) (-5 *4 (-763)) (-5 *2 (-409 (-1157 *5))) (-5 *1 (-346 *5 *6)) (-4 *6 (-52 *5 *4)))) ((*1 *2 *2 *3 *3) (-12 (-5 *2 (-1216 *4 *5)) (-5 *3 (-634 *5)) (-14 *4 (-1161)) (-4 *5 (-365)) (-5 *1 (-919 *4 *5)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-634 *5)) (-4 *5 (-365)) (-5 *2 (-1157 *5)) (-5 *1 (-919 *4 *5)) (-14 *4 (-1161)))) ((*1 *2 *3 *3 *4 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-763)) (-4 *6 (-365)) (-5 *2 (-409 (-953 *6))) (-5 *1 (-1048 *5 *6)) (-14 *5 (-1161))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *1 (-616 *3 *4 *5 *6 *7 *2)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *2 (-1099 *3 *4 *5 *6))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-634 *3))))) 
+(((*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-995 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-679 (-310 (-215)))) (-5 *2 (-381)) (-5 *1 (-197))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1 *2 *2)) (-5 *1 (-671 *2)) (-4 *2 (-1090)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-634 *5) (-634 *5))) (-5 *4 (-568)) (-5 *2 (-634 *5)) (-5 *1 (-671 *5)) (-4 *5 (-1090))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *4 *5 *6 *7))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-926)))) ((*1 *2 *1) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-927))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161)))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1 *1)) (-4 *1 (-641 *3)) (-4 *3 (-365)))) ((*1 *1 *2) (-12 (-5 *2 (-1 (-1141 *3))) (-5 *1 (-1141 *3)) (-4 *3 (-1195))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |var| (-634 (-1161))) (|:| |pred| (-57)))) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *2 *2 *3) (-12 (-5 *2 (-634 (-568))) (-5 *3 (-679 (-568))) (-5 *1 (-1100))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1 (-215) (-215) (-215) (-215))) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-1 (-215) (-215) (-215))) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *1 (-256))))) 
 (((*1 *1 *1) (-4 *1 (-620))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181)))))) 
-(((*1 *2 *3 *4 *4 *4 *5 *6 *7) (|partial| -12 (-5 *5 (-1161)) (-5 *6 (-1 (-3 (-2 (|:| |mainpart| *4) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *4) (|:| |logand| *4))))) "failed") *4 (-634 *4))) (-5 *7 (-1 (-3 (-2 (|:| -1924 *4) (|:| |coeff| *4)) "failed") *4 *4)) (-4 *4 (-13 (-1181) (-27) (-432 *8))) (-4 *8 (-13 (-453) (-842) (-150) (-1037 *3) (-630 *3))) (-5 *3 (-568)) (-5 *2 (-634 *4)) (-5 *1 (-1014 *8 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-863 *3)) (-5 *2 (-568))))) 
-(((*1 *2 *3 *4 *3) (|partial| -12 (-5 *4 (-1161)) (-4 *5 (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-2 (|:| -1924 *3) (|:| |coeff| *3))) (-5 *1 (-559 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 (-310 (-215)))) (-5 *1 (-263))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047))))) 
+(((*1 *2 *2) (-12 (-5 *1 (-586 *2)) (-4 *2 (-550))))) 
+(((*1 *1) (-5 *1 (-158)))) 
 (((*1 *1 *1) (-4 *1 (-620))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-1161)) (-4 *6 (-432 *5)) (-4 *5 (-842)) (-5 *2 (-634 (-607 *6))) (-5 *1 (-577 *5 *6))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-559 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5)))))) 
-(((*1 *1 *1) (-5 *1 (-215))) ((*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) ((*1 *1 *1) (-5 *1 (-381))) ((*1 *1) (-5 *1 (-381)))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *3 (-1219 *4)) (-4 *2 (-1234 *4)) (-5 *1 (-1237 *4 *3 *5 *2)) (-4 *5 (-646 *3))))) 
+(((*1 *2 *3 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *4)))) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-1177))))) 
+(((*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
+(((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-381))) (-5 *5 (-1143)) (-5 *6 (-634 (-256))) (-5 *2 (-1249)) (-5 *1 (-456)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-381))) (-5 *5 (-1143)) (-5 *2 (-1249)) (-5 *1 (-456)))) ((*1 *2 *3 *4 *4 *5 *6) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-381))) (-5 *5 (-1143)) (-5 *6 (-634 (-256))) (-5 *2 (-1249)) (-5 *1 (-456)))) ((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-381))) (-5 *5 (-1143)) (-5 *2 (-1249)) (-5 *1 (-456))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
 (((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1141 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-184)))) ((*1 *2 *3) (-12 (-5 *3 (-1141 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-294)))) ((*1 *2 *3) (-12 (-5 *3 (-1141 (-215))) (-5 *2 (-634 (-1143))) (-5 *1 (-299))))) 
 (((*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-863 *3)) (-5 *2 (-568)))) ((*1 *1 *1) (-4 *1 (-1002))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-1012)))) ((*1 *1 *2) (-12 (-5 *2 (-409 (-568))) (-4 *1 (-1012)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1012)) (-5 *2 (-763)))) ((*1 *1 *1) (-4 *1 (-1012)))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1061 *3 *4 *5))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-171)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)) (-4 *5 (-1047))))) 
-(((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1141 (-2 (|:| |k| (-568)) (|:| |c| *3)))) (-5 *1 (-593 *3)) (-4 *3 (-1047))))) 
-(((*1 *2) (-12 (-4 *2 (-13 (-432 *3) (-1002))) (-5 *1 (-272 *3 *2)) (-4 *3 (-13 (-842) (-558))))) ((*1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) ((*1 *1) (-5 *1 (-489))) ((*1 *1) (-4 *1 (-1181)))) 
-(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
-(((*1 *2) (-12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-634 (-634 *4))) (-5 *1 (-339 *3 *4 *5 *6)) (-4 *3 (-340 *4 *5 *6)))) ((*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *3 (-370)) (-5 *2 (-634 (-634 *3))))) ((*1 *2) (-12 (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *7)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2) (-12 (-5 *2 (-634 (-967 *3))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-634 (-966 *3))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1697 *6) (-763))) (-5 *2 (-634 *8)) (-5 *1 (-963 *5 *6 *3 *7 *8)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *8 (-971 *5))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-819))))) 
 (((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-763))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-1219 *4)) (-4 *4 (-1199)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-2 (|:| |num| *1) (|:| |den| *5) (|:| |derivden| *5) (|:| |gd| *5))) (-4 *1 (-340 *4 *5 *6))))) 
+(((*1 *2) (-12 (-4 *2 (-13 (-432 *3) (-1002))) (-5 *1 (-272 *3 *2)) (-4 *3 (-13 (-842) (-558))))) ((*1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) ((*1 *1) (-5 *1 (-489))) ((*1 *1) (-4 *1 (-1181)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-665 *3)) (-4 *3 (-1195)) (-5 *2 (-121))))) 
+(((*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-850))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-57))))) 
 (((*1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-55 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *1 *1) (-4 *1 (-279))) ((*1 *1 *1) (-12 (-5 *1 (-337 *2 *3 *4)) (-14 *2 (-634 (-1161))) (-14 *3 (-634 (-1161))) (-4 *4 (-389)))) ((*1 *1 *2) (-12 (-5 *2 (-656 *3 *4)) (-4 *3 (-842)) (-4 *4 (-13 (-172) (-707 (-409 (-568))))) (-5 *1 (-618 *3 *4 *5)) (-14 *5 (-917)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-13 (-1047) (-707 (-409 (-568))))) (-4 *5 (-842)) (-5 *1 (-1258 *4 *5 *2)) (-4 *2 (-1263 *5 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-1262 *3 *4)) (-4 *4 (-707 (-409 (-568)))) (-4 *3 (-842)) (-4 *4 (-172))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *5 "failed") *7)) (-5 *4 (-1157 *7)) (-4 *5 (-1047)) (-4 *7 (-1047)) (-4 *2 (-1219 *5)) (-5 *1 (-510 *5 *2 *6 *7)) (-4 *6 (-1219 *2))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-111 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) ((*1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-271))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-310 (-215)))) (-5 *2 (-121)) (-5 *1 (-263))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-1090)) (-5 *2 (-1143)))) ((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-171)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
+(((*1 *1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *1 *1) (-4 *1 (-550)))) 
 (((*1 *1 *1) (-5 *1 (-121))) ((*1 *1 *1) (-4 *1 (-132))) ((*1 *1 *1 *2) (-12 (-4 *1 (-238)) (-5 *2 (-568)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-478)) (-5 *2 (-568)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-716)) (-5 *2 (-763)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1102)) (-5 *2 (-917))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 *2)) (-4 *2 (-1234 *4)) (-5 *1 (-1236 *4 *2)) (-4 *4 (-43 (-409 (-568))))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-3 (|:| |noa| (-2 (|:| |fn| (-310 (-215))) (|:| -4434 (-634 (-215))) (|:| |lb| (-634 (-835 (-215)))) (|:| |cf| (-634 (-310 (-215)))) (|:| |ub| (-634 (-835 (-215)))))) (|:| |lsa| (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4434 (-634 (-215))))))) (-5 *2 (-634 (-1143))) (-5 *1 (-263))))) 
-(((*1 *1 *1 *1) (|partial| -12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *3 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-634 *3)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13)) (-4 *12 (-258 *3))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-679 *4)) (-5 *3 (-917)) (|has| *4 (-6 (-4521 "*"))) (-4 *4 (-1047)) (-5 *1 (-1028 *4)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-634 (-679 *4))) (-5 *3 (-917)) (|has| *4 (-6 (-4521 "*"))) (-4 *4 (-1047)) (-5 *1 (-1028 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-601 *2 *3)) (-4 *3 (-1195)) (-4 *2 (-1090)) (-4 *2 (-842))))) 
-(((*1 *2 *3 *3) (-12 (-4 *2 (-558)) (-4 *2 (-453)) (-5 *1 (-970 *2 *3)) (-4 *3 (-1219 *2))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-634 (-2 (|:| |deg| (-763)) (|:| -4435 *3)))) (-5 *1 (-207 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *5 (-370)) (-5 *2 (-763))))) 
-(((*1 *1 *1 *1) (-4 *1 (-550)))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-917)) (-5 *1 (-1032 *2)) (-4 *2 (-13 (-1090) (-10 -8 (-15 * ($ $ $)))))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *5)) (-4 *5 (-432 *4)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-850)) (-5 *1 (-36 *4 *5))))) 
-(((*1 *1 *2 *3 *3 *4 *5) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *3 (-634 (-869))) (-5 *4 (-634 (-917))) (-5 *5 (-634 (-256))) (-5 *1 (-473)))) ((*1 *1 *2 *3 *3 *4) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *3 (-634 (-869))) (-5 *4 (-634 (-917))) (-5 *1 (-473)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *1 (-473)))) ((*1 *1 *1) (-5 *1 (-473)))) 
-(((*1 *1 *1) (-4 *1 (-1129)))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *7 *7)) (-4 *7 (-1219 *6)) (-4 *6 (-13 (-27) (-432 *5))) (-4 *5 (-13 (-842) (-558) (-1037 (-568)))) (-4 *8 (-1219 (-409 *7))) (-5 *2 (-585 *3)) (-5 *1 (-553 *5 *6 *7 *8 *3)) (-4 *3 (-340 *6 *7 *8))))) 
-(((*1 *2 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))) (-5 *1 (-444 *4 *3 *2)) (-4 *3 (-1219 *4))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-404)) (-5 *2 (-763)))) ((*1 *1 *1) (-4 *1 (-404)))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1894 *4)))) (-4 *3 (-1090)) (-4 *4 (-23)) (-14 *5 *4) (-5 *1 (-638 *3 *4 *5))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-117)) (-5 *2 (-568))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-1 (-121) *8))) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-2 (|:| |goodPols| (-634 *8)) (|:| |badPols| (-634 *8)))) (-5 *1 (-978 *5 *6 *7 *8)) (-5 *4 (-634 *8))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-679 *5)) (-5 *4 (-1244 *5)) (-4 *5 (-365)) (-5 *2 (-121)) (-5 *1 (-659 *5)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-13 (-375 *5) (-10 -7 (-6 -4522)))) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4522)))) (-5 *2 (-121)) (-5 *1 (-660 *5 *6 *4 *3)) (-4 *3 (-677 *5 *6 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *5 *5)) (-4 *5 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *2 (-2 (|:| |solns| (-634 *5)) (|:| |maps| (-634 (-2 (|:| |arg| *5) (|:| |res| *5)))))) (-5 *1 (-1116 *3 *5)) (-4 *3 (-1219 *5))))) 
+(((*1 *2 *3 *4 *4 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *3 (-2 (|:| |lcmfij| *6) (|:| |totdeg| (-763)) (|:| |poli| *4) (|:| |polj| *4))) (-4 *6 (-788)) (-4 *4 (-950 *5 *6 *7)) (-4 *5 (-453)) (-4 *7 (-842)) (-5 *1 (-450 *5 *6 *7 *4))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-5 *2 (-121))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1 (-121) *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-2 (|:| |goodPols| (-634 *8)) (|:| |badPols| (-634 *8)))) (-5 *1 (-978 *5 *6 *7 *8)) (-5 *4 (-634 *8))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-955)) (-5 *2 (-634 (-634 (-944 (-215))))))) ((*1 *2 *1) (-12 (-4 *1 (-975)) (-5 *2 (-634 (-634 (-944 (-215)))))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 *3)) (-5 *1 (-360 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-239 *2)) (-4 *2 (-1195)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-277 *2)) (-4 *2 (-1195)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-277 *2)) (-4 *2 (-1195)))) ((*1 *1 *1 *2) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-1231 *2)) (-4 *2 (-1195)))) ((*1 *1 *1 *1) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *2 *2 *2 *2 *3) (-12 (-5 *2 (-679 *4)) (-5 *3 (-763)) (-4 *4 (-1047)) (-5 *1 (-680 *4))))) 
+(((*1 *2 *1 *3 *4 *4 *4 *4 *5 *5 *5 *5 *6 *5 *6 *5) (-12 (-5 *3 (-917)) (-5 *4 (-215)) (-5 *5 (-568)) (-5 *6 (-869)) (-5 *2 (-1249)) (-5 *1 (-1245))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
 (((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-381)))) ((*1 *1 *1 *1) (-4 *1 (-550))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-641 *3)) (-4 *3 (-365)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) ((*1 *1 *2) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-763))))) 
 (((*1 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-142)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-147))))) 
-(((*1 *2 *1 *3 *3) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-601 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1195)) (-5 *2 (-1249))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1265 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-838))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-369 *2)) (-4 *2 (-172))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-250))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1035))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-2 (|:| |poly| *6) (|:| -2410 *3)))) (-5 *1 (-804 *5 *6 *3 *7)) (-4 *3 (-646 *6)) (-4 *7 (-646 (-409 *6))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-2 (|:| |poly| *6) (|:| -2410 (-644 *6 (-409 *6)))))) (-5 *1 (-807 *5 *6)) (-5 *3 (-644 *6 (-409 *6)))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-230 (-1699 *5) (-763))) (-5 *2 (-3 (-634 *7) "failed" "Infinite" (-568))) (-5 *1 (-31 *4 *5 *3 *6 *7)) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *7 (-971 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-230 (-1699 *5) (-763))) (-5 *2 (-3 (-634 *7) "failed" "Infinite" (-568))) (-5 *1 (-32 *4 *5 *3 *6 *7)) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *7 (-971 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1157 (-1157 *4))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *7 (-230 (-1699 *5) (-763))) (-5 *2 (-3 (-634 *8) "failed" "Infinite" (-568))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *8 (-971 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1157 *1)) (-5 *4 (-1161)) (-4 *1 (-27)) (-5 *2 (-634 *1)))) ((*1 *2 *3) (-12 (-5 *3 (-1157 *1)) (-4 *1 (-27)) (-5 *2 (-634 *1)))) ((*1 *2 *3) (-12 (-5 *3 (-953 *1)) (-4 *1 (-27)) (-5 *2 (-634 *1)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *2 (-634 *1)) (-4 *1 (-29 *4)))) ((*1 *2 *1) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *2 (-634 *1)) (-4 *1 (-29 *3))))) 
 (((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-1161)) (-5 *1 (-541)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-694 *3)) (-4 *3 (-609 (-541))))) ((*1 *2 *3 *2 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-694 *3)) (-4 *3 (-609 (-541))))) ((*1 *2 *3 *2 *2 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-694 *3)) (-4 *3 (-609 (-541))))) ((*1 *2 *3 *2 *4) (-12 (-5 *4 (-634 (-1161))) (-5 *2 (-1161)) (-5 *1 (-694 *3)) (-4 *3 (-609 (-541)))))) 
-(((*1 *1 *2 *3 *4) (-12 (-14 *5 (-634 (-1161))) (-4 *2 (-172)) (-4 *4 (-230 (-1697 *5) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4355 *3) (|:| -3438 *4)) (-2 (|:| -4355 *3) (|:| -3438 *4)))) (-5 *1 (-463 *5 *2 *3 *4 *6 *7)) (-4 *3 (-842)) (-4 *7 (-950 *2 *4 (-852 *5)))))) 
-(((*1 *2 *3 *1) (-12 (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-420 (-1157 (-568)))) (-5 *1 (-183)) (-5 *3 (-568))))) 
-(((*1 *2 *1) (|partial| -12 (-5 *2 (-763)) (-5 *1 (-123))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *1 (-324 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-4 *4 (-1047)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 (-514 *3 *4 *5 *6))) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-5 *3 (-634 *7)) (-4 *1 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090))))) 
+(((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926))))) 
+(((*1 *2 *3) (-12 (-4 *1 (-340 *4 *3 *5)) (-4 *4 (-1199)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 (-409 *3))) (-5 *2 (-121)))) ((*1 *2 *3) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121))))) 
 (((*1 *1 *2 *2 *2) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181))))) ((*1 *2 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-568)) (-4 *5 (-1047)) (-4 *6 (-230 *7 (-763))) (-14 *7 (-763)) (-5 *1 (-908 *5 *2 *6 *7)) (-4 *2 (-324 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5)))) ((*1 *2 *1 *3 *4 *4) (-12 (-5 *3 (-917)) (-5 *4 (-381)) (-5 *2 (-1249)) (-5 *1 (-1245)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
-(((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 *5))) (-5 *3 (-1157 *5)) (-4 *5 (-166 *4)) (-4 *4 (-550)) (-5 *1 (-152 *4 *5)))) ((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-1219 *4)) (-4 *4 (-350)) (-5 *1 (-359 *4 *5 *3)))) ((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 (-568)))) (-5 *3 (-1157 (-568))) (-5 *1 (-576)))) ((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 *1))) (-5 *3 (-1157 *1)) (-4 *1 (-904))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-5 *2 (-634 (-2 (|:| -3848 *3) (|:| -3206 *4)))) (-5 *1 (-685 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-1047)) (-4 *4 (-230 *5 (-763))) (-14 *5 (-763)) (-5 *1 (-908 *3 *2 *4 *5)) (-4 *2 (-324 *3 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1216 *5 *4)) (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-568)) (-5 *1 (-1104 *4 *5))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
 (((*1 *1 *1 *1) (-12 (-5 *1 (-634 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-541))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1244 (-679 *4))) (-4 *4 (-172)) (-5 *2 (-1244 (-679 (-953 *4)))) (-5 *1 (-181 *4))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-568))) (-5 *4 (-568)) (-5 *2 (-57)) (-5 *1 (-1005))))) 
-(((*1 *2 *2 *3 *4) (-12 (-5 *2 (-242 (-4287 (QUOTE X) (QUOTE -2926)) *5)) (-4 *5 (-365)) (-5 *3 (-763)) (-14 *6 (-634 (-1161))) (-4 *8 (-230 (-1697 *6) *3)) (-5 *1 (-119 *5 *6 *7 *8 *4)) (-4 *7 (-324 *5 *8)) (-4 *4 (-117))))) 
+(((*1 *2 *3) (-12 (-4 *1 (-350)) (-5 *3 (-568)) (-5 *2 (-1169 (-917) (-763)))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-301)))) ((*1 *2 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |lm| (-388 *3)) (|:| |rm| (-388 *3)))) (-5 *1 (-388 *3)) (-4 *3 (-1090)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -4409 (-763)) (|:| -2607 (-763)))) (-5 *1 (-763)))) ((*1 *2 *1 *1) (|partial| -12 (-5 *2 (-2 (|:| |lm| (-3 (-814 *3) "failed")) (|:| |rm| (-3 (-814 *3) "failed")))) (-5 *1 (-814 *3)) (-4 *3 (-842)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| -4409 *3) (|:| -2607 *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6))))) 
+(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
 (((*1 *1 *2 *2 *3) (-12 (-5 *2 (-763)) (-4 *3 (-1195)) (-4 *1 (-62 *3 *4 *5)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *1) (-5 *1 (-171))) ((*1 *1 *2 *2 *2) (-12 (-5 *2 (-1143)) (-4 *1 (-391)))) ((*1 *1) (-5 *1 (-396))) ((*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-4 *1 (-640 *3)) (-4 *3 (-1195)))) ((*1 *1) (-12 (-4 *3 (-1090)) (-5 *1 (-880 *2 *3 *4)) (-4 *2 (-1090)) (-4 *4 (-658 *3)))) ((*1 *1) (-12 (-5 *1 (-884 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090)))) ((*1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047)))) ((*1 *1 *1) (-5 *1 (-1161))) ((*1 *1) (-5 *1 (-1161))) ((*1 *1) (-5 *1 (-1176)))) 
-(((*1 *2 *1 *3) (|partial| -12 (-5 *3 (-887 *4)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-884 *4 *5)) (-4 *5 (-1090)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-5 *2 (-121)) (-5 *1 (-885 *5 *3)) (-4 *3 (-1195)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-4 *6 (-1195)) (-5 *2 (-121)) (-5 *1 (-885 *5 *6))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) ((*1 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *1 *1) (-4 *1 (-1124)))) 
-(((*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *7)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2) (-12 (-5 *2 (-634 (-967 *3))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-634 (-966 *3))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-230 (-1697 *5) (-763))) (-5 *2 (-634 *7)) (-5 *1 (-963 *4 *5 *3 *6 *7)) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *7 (-971 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 (-409 (-953 *4)))) (-5 *1 (-924 *4 *5 *6 *7)) (-4 *7 (-950 *4 *6 *5))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-763))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-634 (-944 (-215))))) (-5 *1 (-1191 *3)) (-4 *3 (-975))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-634 (-634 (-634 *4)))) (-5 *2 (-634 (-634 *4))) (-4 *4 (-842)) (-5 *1 (-1167 *4))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-365)) (-5 *1 (-1043 *3))))) 
 (((*1 *1 *1 *1) (-12 (-5 *1 (-896 *2)) (-4 *2 (-1090)))) ((*1 *1 *2) (-12 (-5 *1 (-896 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -3848 (-1157 *6)) (|:| -3438 (-568))))) (-4 *6 (-301)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-568)) (-5 *1 (-732 *4 *5 *6 *7)) (-4 *7 (-950 *6 *4 *5))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-4 *3 (-895 *5)) (-5 *2 (-1244 *3)) (-5 *1 (-681 *5 *3 *6 *4)) (-4 *6 (-375 *3)) (-4 *4 (-13 (-375 *5) (-10 -7 (-6 -4519))))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1 *3 *4)) (-5 *1 (-672 *4 *3)) (-4 *4 (-1090)) (-4 *3 (-1090))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1244 (-1244 (-568)))) (-5 *1 (-471))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850)))) ((*1 *1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-504))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-926))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-646 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) ((*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 *4 *4)) (-4 *4 (-365)) (-5 *1 (-649 *4 *2)) (-4 *2 (-646 *4))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-1157 (-1157 *4)))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *7 (-230 (-1697 *5) (-763))) (-5 *2 (-3 (-634 *8) "failed" "Infinite" (-568))) (-5 *1 (-32 *4 *5 *6 *7 *8)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *8 (-971 *4))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1244 *5)) (-4 *5 (-787)) (-5 *2 (-121)) (-5 *1 (-837 *4 *5)) (-14 *4 (-763))))) 
-(((*1 *2 *2 *3) (-12 (-4 *3 (-365)) (-5 *1 (-1025 *3 *2)) (-4 *2 (-646 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-5 *2 (-2 (|:| -1853 *3) (|:| -4192 (-634 *5)))) (-5 *1 (-1025 *5 *3)) (-5 *4 (-634 *5)) (-4 *3 (-646 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1864 *7) (|:| -4477 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *5 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3)))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-1244 (-1161))) (-5 *3 (-1244 (-454 *4 *5 *6 *7))) (-5 *1 (-454 *4 *5 *6 *7)) (-4 *4 (-172)) (-14 *5 (-917)) (-14 *6 (-634 (-1161))) (-14 *7 (-1244 (-679 *4))))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1244 (-454 *4 *5 *6 *7))) (-5 *1 (-454 *4 *5 *6 *7)) (-4 *4 (-172)) (-14 *5 (-917)) (-14 *6 (-634 *2)) (-14 *7 (-1244 (-679 *4))))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-454 *3 *4 *5 *6))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) ((*1 *1 *2) (-12 (-5 *2 (-1244 (-1161))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3))))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 *2)) (-14 *6 (-1244 (-679 *3))))) ((*1 *1) (-12 (-5 *1 (-454 *2 *3 *4 *5)) (-4 *2 (-172)) (-14 *3 (-917)) (-14 *4 (-634 (-1161))) (-14 *5 (-1244 (-679 *2)))))) 
-(((*1 *2 *3 *3) (|partial| -12 (-4 *4 (-558)) (-5 *2 (-2 (|:| -3961 *3) (|:| -1500 *3))) (-5 *1 (-1214 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-558)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1037 (-568))) (-4 *1 (-296)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-550)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-900 *3)) (-4 *3 (-1090))))) 
-(((*1 *1 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-420 *2)) (-4 *2 (-558))))) 
-(((*1 *1 *2 *3 *3 *3 *3) (-12 (-5 *2 (-1 (-944 (-215)) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-926)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 (-944 (-215)) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-926)))) ((*1 *1 *2 *3 *3 *3) (-12 (-5 *2 (-1 (-944 (-215)) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 (-944 (-215)) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927))))) 
-(((*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-763)) (-4 *5 (-365)) (-5 *2 (-409 *6)) (-5 *1 (-861 *5 *4 *6)) (-4 *4 (-1234 *5)) (-4 *6 (-1219 *5)))) ((*1 *2 *3 *3 *4 *4) (|partial| -12 (-5 *3 (-763)) (-5 *4 (-1235 *5 *6 *7)) (-4 *5 (-365)) (-14 *6 (-1161)) (-14 *7 *5) (-5 *2 (-409 (-1216 *6 *5))) (-5 *1 (-862 *5 *6 *7)))) ((*1 *2 *3 *3 *4) (|partial| -12 (-5 *3 (-763)) (-5 *4 (-1235 *5 *6 *7)) (-4 *5 (-365)) (-14 *6 (-1161)) (-14 *7 *5) (-5 *2 (-409 (-1216 *6 *5))) (-5 *1 (-862 *5 *6 *7))))) 
-(((*1 *2 *2) (-12 (-5 *1 (-961 *2)) (-4 *2 (-550))))) 
-(((*1 *2) (-12 (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-1244 *1)) (-4 *1 (-340 *3 *4 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-158)))) ((*1 *2 *1) (-12 (-5 *2 (-158)) (-5 *1 (-869)))) ((*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-62 *4 *2 *5)) (-4 *4 (-1195)) (-4 *5 (-375 *4)) (-4 *2 (-375 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1050 *4 *5 *6 *2 *7)) (-4 *6 (-1047)) (-4 *7 (-230 *4 *6)) (-4 *2 (-230 *5 *6))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *5 (-1234 *4)) (-4 *4 (-43 (-409 (-568)))) (-5 *2 (-1 (-1141 *4) (-1141 *4))) (-5 *1 (-1236 *4 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-121)) (-5 *1 (-293 *4 *5)) (-14 *4 *3) (-14 *5 *3))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1084 (-835 (-215)))) (-5 *3 (-215)) (-5 *2 (-121)) (-5 *1 (-299)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195))))) 
-(((*1 *1 *1) (-5 *1 (-1059)))) 
-(((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-158)))) ((*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-173 *2)) (-4 *2 (-301)))) ((*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568)))) ((*1 *1 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-1195)))) ((*1 *1 *1) (-4 *1 (-863 *2))) ((*1 *1 *1) (-12 (-4 *1 (-974 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-787)) (-4 *4 (-842))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-1244 *5)) (-4 *5 (-787)) (-5 *2 (-121)) (-5 *1 (-837 *4 *5)) (-14 *4 (-763))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-310 (-215))) (-5 *2 (-310 (-409 (-568)))) (-5 *1 (-299))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-123))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-173 *3)) (-4 *3 (-301)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-665 *3)) (-4 *3 (-1195)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-730 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-842)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-863 *3)) (-5 *2 (-568)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *1 (-981 *3)) (-4 *3 (-1047)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-5 *3 (-634 *7)) (-4 *1 (-1066 *4 *5 *6 *7)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)))) ((*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-634 *1)) (-4 *1 (-1066 *4 *5 *6 *3)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1221 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-917))) (-5 *1 (-1091 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 *3)) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1082 (-835 *3))) (-4 *3 (-13 (-1181) (-959) (-29 *5))) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 *3)) (|:| |f2| (-634 (-835 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-209 *5 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1082 (-835 *3))) (-5 *5 (-1143)) (-4 *3 (-13 (-1181) (-959) (-29 *6))) (-4 *6 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 *3)) (|:| |f2| (-634 (-835 *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-209 *6 *3)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1082 (-835 (-310 *5)))) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 (-310 *5))) (|:| |f2| (-634 (-835 (-310 *5)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-210 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-409 (-953 *6))) (-5 *4 (-1082 (-835 (-310 *6)))) (-5 *5 (-1143)) (-4 *6 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 (-310 *6))) (|:| |f2| (-634 (-835 (-310 *6)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-210 *6)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1082 (-835 (-409 (-953 *5))))) (-5 *3 (-409 (-953 *5))) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 (-310 *5))) (|:| |f2| (-634 (-835 (-310 *5)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-210 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1082 (-835 (-409 (-953 *6))))) (-5 *5 (-1143)) (-5 *3 (-409 (-953 *6))) (-4 *6 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 (|:| |f1| (-835 (-310 *6))) (|:| |f2| (-634 (-835 (-310 *6)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (-5 *1 (-210 *6)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-3 *3 (-634 *3))) (-5 *1 (-430 *5 *3)) (-4 *3 (-13 (-1181) (-959) (-29 *5))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-479 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1084 (-835 (-381)))) (-5 *5 (-381)) (-5 *6 (-1059)) (-5 *2 (-1035)) (-5 *1 (-569)))) ((*1 *2 *3) (-12 (-5 *3 (-761)) (-5 *2 (-1035)) (-5 *1 (-569)))) ((*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1084 (-835 (-381)))) (-5 *5 (-381)) (-5 *2 (-1035)) (-5 *1 (-569)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1084 (-835 (-381)))) (-5 *5 (-381)) (-5 *2 (-1035)) (-5 *1 (-569)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-1084 (-835 (-381)))) (-5 *2 (-1035)) (-5 *1 (-569)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-634 (-1084 (-835 (-381))))) (-5 *2 (-1035)) (-5 *1 (-569)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-634 (-1084 (-835 (-381))))) (-5 *5 (-381)) (-5 *2 (-1035)) (-5 *1 (-569)))) ((*1 *2 *3 *4 *5 *5) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-634 (-1084 (-835 (-381))))) (-5 *5 (-381)) (-5 *2 (-1035)) (-5 *1 (-569)))) ((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *3 (-310 (-381))) (-5 *4 (-634 (-1084 (-835 (-381))))) (-5 *5 (-381)) (-5 *6 (-1059)) (-5 *2 (-1035)) (-5 *1 (-569)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-835 (-381)))) (-5 *5 (-1143)) (-5 *2 (-1035)) (-5 *1 (-569)))) ((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-310 (-381))) (-5 *4 (-1082 (-835 (-381)))) (-5 *5 (-1161)) (-5 *2 (-1035)) (-5 *1 (-569)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-150) (-1037 (-568)))) (-4 *5 (-1219 *4)) (-5 *2 (-585 (-409 *5))) (-5 *1 (-572 *4 *5)) (-5 *3 (-409 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-150)) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-630 (-568)))) (-5 *2 (-3 (-310 *5) (-634 (-310 *5)))) (-5 *1 (-588 *5)))) ((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-730 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-842)) (-4 *3 (-43 (-409 (-568)))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-953 *3)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)))) ((*1 *1 *1 *2 *3) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-4 *2 (-842)) (-5 *1 (-1114 *3 *2 *4)) (-4 *4 (-950 *3 (-534 *2) *2)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1151 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1158 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1159 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *1 (-1190 *3)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 (QUOTE |x|))) (-5 *1 (-1201 *3)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-2199 (-12 (-5 *2 (-1161)) (-4 *1 (-1203 *3)) (-4 *3 (-1047)) (-12 (-4 *3 (-29 (-568))) (-4 *3 (-959)) (-4 *3 (-1181)) (-4 *3 (-43 (-409 (-568)))))) (-12 (-5 *2 (-1161)) (-4 *1 (-1203 *3)) (-4 *3 (-1047)) (-12 (|has| *3 (-15 -2057 ((-634 *2) *3))) (|has| *3 (-15 -1845 (*3 *3 *2))) (-4 *3 (-43 (-409 (-568)))))))) ((*1 *1 *1) (-12 (-4 *1 (-1203 *2)) (-4 *2 (-1047)) (-4 *2 (-43 (-409 (-568)))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1207 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-43 (-409 (-568)))))) ((*1 *1 *1 *2) (-2199 (-12 (-5 *2 (-1161)) (-4 *1 (-1224 *3)) (-4 *3 (-1047)) (-12 (-4 *3 (-29 (-568))) (-4 *3 (-959)) (-4 *3 (-1181)) (-4 *3 (-43 (-409 (-568)))))) (-12 (-5 *2 (-1161)) (-4 *1 (-1224 *3)) (-4 *3 (-1047)) (-12 (|has| *3 (-15 -2057 ((-634 *2) *3))) (|has| *3 (-15 -1845 (*3 *3 *2))) (-4 *3 (-43 (-409 (-568)))))))) ((*1 *1 *1) (-12 (-4 *1 (-1224 *2)) (-4 *2 (-1047)) (-4 *2 (-43 (-409 (-568)))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1228 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *1 *2) (-2199 (-12 (-5 *2 (-1161)) (-4 *1 (-1234 *3)) (-4 *3 (-1047)) (-12 (-4 *3 (-29 (-568))) (-4 *3 (-959)) (-4 *3 (-1181)) (-4 *3 (-43 (-409 (-568)))))) (-12 (-5 *2 (-1161)) (-4 *1 (-1234 *3)) (-4 *3 (-1047)) (-12 (|has| *3 (-15 -2057 ((-634 *2) *3))) (|has| *3 (-15 -1845 (*3 *3 *2))) (-4 *3 (-43 (-409 (-568)))))))) ((*1 *1 *1) (-12 (-4 *1 (-1234 *2)) (-4 *2 (-1047)) (-4 *2 (-43 (-409 (-568)))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047)) (-14 *5 *3))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1240 *4)) (-14 *4 (-1161)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-763)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-246 *4 *3 *5 *6)) (-4 *4 (-1047)) (-4 *3 (-842)) (-4 *5 (-262 *3)) (-4 *6 (-788)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-262 *3)) (-4 *3 (-842)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-350)) (-5 *2 (-917)))) ((*1 *2 *3) (-12 (-5 *3 (-334 *4 *5 *6 *7)) (-4 *4 (-13 (-370) (-365))) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-4 *7 (-340 *4 *5 *6)) (-5 *2 (-763)) (-5 *1 (-394 *4 *5 *6 *7)))) ((*1 *2 *1) (-12 (-4 *1 (-404)) (-5 *2 (-828 (-917))))) ((*1 *2 *1) (-12 (-4 *1 (-406)) (-5 *2 (-568)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-594 *3)) (-4 *3 (-1047)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-594 *3)) (-4 *3 (-1047)))) ((*1 *2 *1) (-12 (-4 *3 (-558)) (-5 *2 (-568)) (-5 *1 (-615 *3 *4)) (-4 *4 (-1219 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-641 *3)) (-4 *3 (-365)) (-5 *2 (-568)))) ((*1 *2 *1) (-12 (-4 *1 (-641 *3)) (-4 *3 (-365)) (-5 *2 (-568)))) ((*1 *2 *1 *3 *2) (-12 (-5 *2 (-763)) (-4 *1 (-730 *4 *3)) (-4 *4 (-1047)) (-4 *3 (-842)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-730 *4 *3)) (-4 *4 (-1047)) (-4 *3 (-842)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-863 *3)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-334 *5 *6 *7 *8)) (-4 *5 (-432 *4)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-4 *8 (-340 *5 *6 *7)) (-4 *4 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-763)) (-5 *1 (-906 *4 *5 *6 *7 *8)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-334 (-409 (-568)) *4 *5 *6)) (-4 *4 (-1219 (-409 (-568)))) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 (-409 (-568)) *4 *5)) (-5 *2 (-763)) (-5 *1 (-907 *4 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-334 *6 *7 *4 *8)) (-5 *5 (-1 *9 *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-4 *4 (-1219 (-409 *7))) (-4 *8 (-340 *6 *7 *4)) (-4 *9 (-13 (-370) (-365))) (-5 *2 (-763)) (-5 *1 (-1018 *6 *7 *4 *8 *9)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1219 *3)) (-4 *3 (-1047)) (-4 *3 (-558)) (-5 *2 (-763)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-1221 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787)))) ((*1 *2 *1) (-12 (-4 *1 (-1221 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-634 (-634 *3))))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-634 (-634 *5))))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-634 *3))) (-5 *1 (-1168 *3)) (-4 *3 (-1090))))) 
+(((*1 *1 *1 *2) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-665 *3)) (-4 *3 (-1195)) (-5 *2 (-763))))) 
+(((*1 *2 *1 *2) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *2 *10)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *2 (-235 *9)) (-4 *10 (-117))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-565)) (-5 *3 (-568)))) ((*1 *2 *3) (-12 (-5 *2 (-1157 (-409 (-568)))) (-5 *1 (-943)) (-5 *3 (-568))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-1157 *2)) (-4 *2 (-432 *4)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-36 *4 *2))))) 
+(((*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-763)) (-5 *6 (-121)) (-4 *7 (-453)) (-4 *8 (-788)) (-4 *9 (-842)) (-4 *3 (-1061 *7 *8 *9)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1064 *7 *8 *9 *3 *4)) (-4 *4 (-1066 *7 *8 *9 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-763)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1064 *6 *7 *8 *3 *4)) (-4 *4 (-1066 *6 *7 *8 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1064 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-763)) (-5 *6 (-121)) (-4 *7 (-453)) (-4 *8 (-788)) (-4 *9 (-842)) (-4 *3 (-1061 *7 *8 *9)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1130 *7 *8 *9 *3 *4)) (-4 *4 (-1099 *7 *8 *9 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-763)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1130 *6 *7 *8 *3 *4)) (-4 *4 (-1099 *6 *7 *8 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3145 *4)))))) (-5 *1 (-1130 *5 *6 *7 *3 *4)) (-4 *4 (-1099 *5 *6 *7 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-52 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-787)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))))) ((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161))))) ((*1 *2 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-568)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-246 *4 *3 *5 *6)) (-4 *4 (-1047)) (-4 *3 (-842)) (-4 *5 (-262 *3)) (-4 *6 (-788)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-271)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1157 *8)) (-5 *4 (-634 *6)) (-4 *6 (-842)) (-4 *8 (-950 *7 *5 *6)) (-4 *5 (-788)) (-4 *7 (-1047)) (-5 *2 (-634 (-763))) (-5 *1 (-318 *5 *6 *7 *8)))) ((*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-5 *2 (-917)))) ((*1 *2 *1) (-12 (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-475 *3 *2)) (-4 *3 (-172)) (-4 *2 (-23)))) ((*1 *2 *1) (-12 (-4 *3 (-558)) (-5 *2 (-568)) (-5 *1 (-615 *3 *4)) (-4 *4 (-1219 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-698 *3)) (-4 *3 (-1047)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-844 *3)) (-4 *3 (-1047)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-900 *3)) (-4 *3 (-1090)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *5 (-1047)) (-4 *6 (-230 *7 *2)) (-14 *7 *2) (-5 *2 (-763)) (-5 *1 (-908 *5 *3 *6 *7)) (-4 *3 (-324 *5 *6)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *1 (-950 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-634 (-763))))) ((*1 *2 *1 *3) (-12 (-4 *1 (-950 *4 *5 *3)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-974 *3 *2 *4)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *2 (-787)))) ((*1 *2 *1) (-12 (-4 *1 (-1088)) (-5 *2 (-917)))) ((*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-1205 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1234 *3)) (-5 *2 (-568)))) ((*1 *2 *1) (-12 (-4 *1 (-1226 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1203 *3)) (-5 *2 (-409 (-568))))) ((*1 *2 *1) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-828 (-917))))) ((*1 *2 *1) (-12 (-4 *1 (-1263 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-763))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-778 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-172))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3)))) ((*1 *2 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-1219 (-409 (-568)))) (-5 *1 (-909 *3 *2)) (-4 *2 (-1219 (-409 *3)))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2723 (-777 *3)) (|:| |coef1| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -2723 *1) (|:| |coef1| *1))) (-4 *1 (-1061 *3 *4 *5))))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-1161)) (-5 *2 (-439)) (-5 *1 (-1165))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-634 (-409 *6))) (-5 *3 (-409 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-572 *5 *6))))) 
+(((*1 *2 *2) (-12 (-5 *1 (-160 *2)) (-4 *2 (-550)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-972))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-473)) (-5 *3 (-634 (-256))) (-5 *1 (-1245)))) ((*1 *1 *1) (-5 *1 (-1245)))) 
+(((*1 *1) (-5 *1 (-147))) ((*1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *1 *1) (-4 *1 (-620))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181)))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-256)))) ((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472))))) 
+(((*1 *2 *2 *3 *4) (-12 (-5 *3 (-634 (-607 *2))) (-5 *4 (-634 (-1161))) (-4 *2 (-13 (-432 (-169 *5)) (-1002) (-1181))) (-4 *5 (-13 (-558) (-842))) (-5 *1 (-597 *5 *6 *2)) (-4 *6 (-13 (-432 *5) (-1002) (-1181)))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -2723 *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-679 (-409 *4)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-953 (-568))))) (-5 *2 (-634 (-679 (-310 (-568))))) (-5 *1 (-1031))))) 
+(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-472))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-23)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1063 *4 *3)) (-4 *4 (-13 (-840) (-365))) (-4 *3 (-1219 *4)) (-5 *2 (-121))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1 *3 *3 (-568))) (-4 *3 (-1047)) (-5 *1 (-101 *3)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-101 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-101 *3))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-944 *5)) (-4 *5 (-1047)) (-5 *2 (-763)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-763)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)) (-4 *5 (-1047)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-944 *5)) (-4 *5 (-1047)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-568)) (-5 *1 (-444 *4 *3 *5)) (-4 *3 (-1219 *4)) (-4 *5 (-13 (-406) (-1037 *4) (-365) (-1181) (-279)))))) 
+(((*1 *2 *3) (|partial| -12 (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| |radicand| (-409 *5)) (|:| |deg| (-763)))) (-5 *1 (-151 *4 *5 *3)) (-4 *3 (-1219 (-409 *5)))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) ((*1 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *1 *1) (-4 *1 (-1124)))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436)))) ((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-573 *3)) (-4 *3 (-1037 (-568))))) ((*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-634 *8))) (-5 *3 (-634 *8)) (-4 *8 (-1061 *5 *6 *7)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *5 *6 *7 *8))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-634 *1)) (|has| *1 (-6 -4522)) (-4 *1 (-1010 *3)) (-4 *3 (-1195))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-5 *2 (-634 (-2 (|:| C (-679 *5)) (|:| |g| (-1244 *5))))) (-5 *1 (-979 *5)) (-5 *3 (-679 *5)) (-5 *4 (-1244 *5))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1157 *3)) (-4 *3 (-1047)) (-4 *1 (-1219 *3))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-420 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-1047)) (-5 *2 (-634 *6)) (-5 *1 (-445 *5 *6))))) 
 (((*1 *2 *3 *4 *4 *4 *5 *4 *6 *6 *3) (-12 (-5 *4 (-679 (-215))) (-5 *5 (-679 (-568))) (-5 *6 (-215)) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-743))))) 
 (((*1 *2 *1 *1) (-12 (-4 *1 (-1242 *3)) (-4 *3 (-1195)) (-4 *3 (-1047)) (-5 *2 (-679 *3))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *3 (-950 *4 *6 (-852 *5))) (-4 *6 (-230 (-1697 *5) (-763))) (-4 *7 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *4 *5 *3 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-568)) (-5 *1 (-260 *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-568)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-684 *3)) (-4 *3 (-1090)) (-5 *2 (-634 (-2 (|:| -4083 *3) (|:| -4168 (-763)))))))) 
-(((*1 *1 *2 *3) (-12 (-5 *3 (-1143)) (-4 *1 (-366 *2 *4)) (-4 *2 (-1090)) (-4 *4 (-1090)))) ((*1 *1 *2) (-12 (-4 *1 (-366 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-1 *6 (-634 *6)))) (-4 *5 (-43 (-409 (-568)))) (-4 *6 (-1234 *5)) (-5 *2 (-634 *6)) (-5 *1 (-1236 *5 *6))))) 
-(((*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |val| (-634 *8)) (|:| |towers| (-634 (-1027 *5 *6 *7 *8))))) (-5 *1 (-1027 *5 *6 *7 *8)) (-5 *3 (-634 *8)))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-121)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |val| (-634 *8)) (|:| |towers| (-634 (-1131 *5 *6 *7 *8))))) (-5 *1 (-1131 *5 *6 *7 *8)) (-5 *3 (-634 *8))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *3 (-25)) (-4 *3 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-432 *3)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (|partial| -12 (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-634 *1)) (-4 *1 (-950 *3 *4 *5)))) ((*1 *2 *3) (|partial| -12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-634 *3)) (-5 *1 (-951 *4 *5 *6 *7 *3)) (-4 *3 (-13 (-365) (-10 -8 (-15 -2745 ($ *7)) (-15 -2317 (*7 $)) (-15 -2324 (*7 $)))))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1216 *5 *4)) (-5 *1 (-1159 *4 *5 *6)) (-4 *4 (-1047)) (-14 *5 (-1161)) (-14 *6 *4))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1216 (QUOTE |x|) *4)) (-5 *1 (-1201 *4)) (-4 *4 (-1047)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1216 *5 *4)) (-5 *1 (-1235 *4 *5 *6)) (-4 *4 (-1047)) (-14 *5 (-1161)) (-14 *6 *4))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1216 *5 *4)) (-5 *1 (-1239 *4 *5)) (-4 *4 (-1047)) (-14 *5 (-1161))))) 
+(((*1 *2 *3 *1) (-12 (|has| *1 (-6 -4521)) (-4 *1 (-601 *4 *3)) (-4 *4 (-1090)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-121))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-634 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-953 (-568))))) (-5 *2 (-634 (-310 (-568)))) (-5 *1 (-1031))))) 
+(((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-1067 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-1098 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7))))) 
+(((*1 *2 *2 *1) (-12 (-5 *2 (-1266 *3 *4)) (-4 *1 (-376 *3 *4)) (-4 *3 (-842)) (-4 *4 (-172)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-388 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *2) (|partial| -12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-814 *2)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-814 *3)) (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1259 *2 *3)) (-4 *2 (-842)) (-4 *3 (-1047))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| |den| (-568)) (|:| |gcdnum| (-568))))) (-4 *4 (-1219 (-409 *2))) (-5 *2 (-568)) (-5 *1 (-909 *4 *5)) (-4 *5 (-1219 (-409 *4)))))) 
 (((*1 *2 *3 *4 *5 *5 *5 *6 *4 *4 *4 *5 *4 *5 *7) (-12 (-5 *3 (-1143)) (-5 *5 (-679 (-215))) (-5 *6 (-215)) (-5 *7 (-679 (-568))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-744))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1174))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-5 *2 (-121))))) 
 (((*1 *2 *2 *2) (-12 (-5 *2 (-634 (-607 *4))) (-4 *4 (-432 *3)) (-4 *3 (-842)) (-5 *1 (-577 *3 *4)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-884 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *2 (-634 (-1084 (-215)))) (-5 *1 (-928))))) 
-(((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-763)) (-5 *1 (-586 *2)) (-4 *2 (-550)))) ((*1 *2 *3) (-12 (-5 *2 (-2 (|:| -1461 *3) (|:| -3438 (-763)))) (-5 *1 (-586 *3)) (-4 *3 (-550))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1066 *4 *5 *6 *3)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121))))) 
+(((*1 *1 *2 *3 *1) (-12 (-5 *2 (-1082 (-953 (-568)))) (-5 *3 (-953 (-568))) (-5 *1 (-328)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1082 (-953 (-568)))) (-5 *1 (-328))))) 
 (((*1 *2 *3 *3 *3 *4 *4 *4 *4 *4 *5 *3 *3 *3 *6 *4 *3) (-12 (-5 *4 (-679 (-215))) (-5 *5 (-679 (-568))) (-5 *6 (-215)) (-5 *3 (-568)) (-5 *2 (-1035)) (-5 *1 (-744))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-917)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-256))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1134 *3)) (-4 *3 (-1195)) (-5 *2 (-121))))) 
-(((*1 *1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-1143)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-256)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-1210 (-568))) (-4 *1 (-277 *3)) (-4 *3 (-1195)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-277 *3)) (-4 *3 (-1195))))) 
+(((*1 *1 *2) (-12 (-5 *1 (-219 *2)) (-4 *2 (-13 (-365) (-1181)))))) 
+(((*1 *2 *3 *4 *3 *5 *5 *5 *5 *5) (|partial| -12 (-5 *5 (-121)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *9 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| -2410 (-634 *9)) (|:| -3145 *4) (|:| |ineq| (-634 *9)))) (-5 *1 (-989 *6 *7 *8 *9 *4)) (-5 *3 (-634 *9)) (-4 *4 (-1066 *6 *7 *8 *9)))) ((*1 *2 *3 *4 *3 *5 *5 *5 *5 *5) (|partial| -12 (-5 *5 (-121)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *9 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| -2410 (-634 *9)) (|:| -3145 *4) (|:| |ineq| (-634 *9)))) (-5 *1 (-1097 *6 *7 *8 *9 *4)) (-5 *3 (-634 *9)) (-4 *4 (-1066 *6 *7 *8 *9))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1092 *3)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-1092 *3)) (-5 *1 (-900 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2852 *4) (|:| -2185 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1244 (-634 (-2 (|:| -2852 *4) (|:| -4357 (-1108)))))) (-4 *4 (-350)) (-5 *2 (-1249)) (-5 *1 (-532 *4))))) 
 (((*1 *2 *3 *4 *5 *4 *5 *5 *6 *4 *4 *4 *4 *4 *5 *4 *5 *5 *7 *4) (-12 (-5 *3 (-1143)) (-5 *5 (-679 (-215))) (-5 *6 (-215)) (-5 *7 (-679 (-568))) (-5 *4 (-568)) (-5 *2 (-1035)) (-5 *1 (-744))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-561 *3)) (-4 *3 (-550))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)) (-4 *2 (-365)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-215)))) ((*1 *1 *1 *1) (-2198 (-12 (-5 *1 (-288 *2)) (-4 *2 (-365)) (-4 *2 (-1195))) (-12 (-5 *1 (-288 *2)) (-4 *2 (-478)) (-4 *2 (-1195))))) ((*1 *1 *1 *1) (-4 *1 (-365))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-381)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-1113 *3 (-607 *1))) (-4 *3 (-558)) (-4 *3 (-842)) (-4 *1 (-432 *3)))) ((*1 *1 *1 *1) (-4 *1 (-478))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-350)) (-5 *1 (-532 *3)))) ((*1 *1 *1 *1) (-5 *1 (-541))) ((*1 *1 *2 *3) (-12 (-4 *4 (-172)) (-5 *1 (-613 *2 *4 *3)) (-4 *2 (-43 *4)) (-4 *3 (|SubsetCategory| (-716) *4)))) ((*1 *1 *1 *2) (-12 (-4 *4 (-172)) (-5 *1 (-613 *3 *4 *2)) (-4 *3 (-43 *4)) (-4 *2 (|SubsetCategory| (-716) *4)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-625 *2)) (-4 *2 (-172)) (-4 *2 (-365)))) ((*1 *1 *2 *3) (-12 (-4 *4 (-172)) (-5 *1 (-652 *2 *4 *3)) (-4 *2 (-707 *4)) (-4 *3 (|SubsetCategory| (-716) *4)))) ((*1 *1 *1 *2) (-12 (-4 *4 (-172)) (-5 *1 (-652 *3 *4 *2)) (-4 *3 (-707 *4)) (-4 *2 (|SubsetCategory| (-716) *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1 (-310 (-568)) *3)) (-4 *3 (-1090)) (-5 *1 (-674 *3 *4)) (-4 *4 (-1047)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (-4 *2 (-365)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-733 *2 *3)) (-14 *2 (-1161)) (-4 *3 (-13 (-1047) (-842) (-558))))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-853 *2 *3 *4 *5)) (-4 *2 (-365)) (-4 *2 (-1047)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-763))) (-14 *5 (-763)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) ((*1 *1 *2 *2) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1050 *3 *4 *2 *5 *6)) (-4 *2 (-1047)) (-4 *5 (-230 *4 *2)) (-4 *6 (-230 *3 *2)) (-4 *2 (-365)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1251 *2)) (-4 *2 (-365)))) ((*1 *1 *1 *1) (|partial| -12 (-4 *2 (-365)) (-4 *2 (-1047)) (-4 *3 (-842)) (-4 *4 (-788)) (-14 *6 (-634 *3)) (-5 *1 (-1254 *2 *3 *4 *5 *6 *7 *8)) (-4 *5 (-950 *2 *4 *3)) (-14 *7 (-634 (-763))) (-14 *8 (-763)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-1265 *2 *3)) (-4 *2 (-365)) (-4 *2 (-1047)) (-4 *3 (-838))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-409 (-568))) (-5 *1 (-1023 *3)) (-4 *3 (-13 (-840) (-365) (-1021))))) ((*1 *2 *3 *1 *2) (-12 (-4 *2 (-13 (-840) (-365))) (-5 *1 (-1057 *2 *3)) (-4 *3 (-1219 *2)))) ((*1 *2 *3 *1 *2) (-12 (-4 *1 (-1063 *2 *3)) (-4 *2 (-13 (-840) (-365))) (-4 *3 (-1219 *2))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-52 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-787)) (-4 *2 (-365)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-215)))) ((*1 *1 *1 *1) (-2199 (-12 (-5 *1 (-288 *2)) (-4 *2 (-365)) (-4 *2 (-1195))) (-12 (-5 *1 (-288 *2)) (-4 *2 (-478)) (-4 *2 (-1195))))) ((*1 *1 *1 *1) (-4 *1 (-365))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-381)))) ((*1 *1 *2 *2) (-12 (-5 *2 (-1113 *3 (-607 *1))) (-4 *3 (-558)) (-4 *3 (-842)) (-4 *1 (-432 *3)))) ((*1 *1 *1 *1) (-4 *1 (-478))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1244 *3)) (-4 *3 (-350)) (-5 *1 (-532 *3)))) ((*1 *1 *1 *1) (-5 *1 (-541))) ((*1 *1 *2 *3) (-12 (-4 *4 (-172)) (-5 *1 (-613 *2 *4 *3)) (-4 *2 (-43 *4)) (-4 *3 (|SubsetCategory| (-716) *4)))) ((*1 *1 *1 *2) (-12 (-4 *4 (-172)) (-5 *1 (-613 *3 *4 *2)) (-4 *3 (-43 *4)) (-4 *2 (|SubsetCategory| (-716) *4)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-625 *2)) (-4 *2 (-172)) (-4 *2 (-365)))) ((*1 *1 *2 *3) (-12 (-4 *4 (-172)) (-5 *1 (-652 *2 *4 *3)) (-4 *2 (-707 *4)) (-4 *3 (|SubsetCategory| (-716) *4)))) ((*1 *1 *1 *2) (-12 (-4 *4 (-172)) (-5 *1 (-652 *3 *4 *2)) (-4 *3 (-707 *4)) (-4 *2 (|SubsetCategory| (-716) *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1 (-310 (-568)) *3)) (-4 *3 (-1090)) (-5 *1 (-674 *3 *4)) (-4 *4 (-1047)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)) (-4 *2 (-365)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-733 *2 *3)) (-14 *2 (-1161)) (-4 *3 (-13 (-1047) (-842) (-558))))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *1) (|partial| -12 (-5 *1 (-853 *2 *3 *4 *5)) (-4 *2 (-365)) (-4 *2 (-1047)) (-14 *3 (-634 (-1161))) (-14 *4 (-634 (-763))) (-14 *5 (-763)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) ((*1 *1 *2 *2) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1050 *3 *4 *2 *5 *6)) (-4 *2 (-1047)) (-4 *5 (-230 *4 *2)) (-4 *6 (-230 *3 *2)) (-4 *2 (-365)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1251 *2)) (-4 *2 (-365)))) ((*1 *1 *1 *1) (|partial| -12 (-4 *2 (-365)) (-4 *2 (-1047)) (-4 *3 (-842)) (-4 *4 (-788)) (-14 *6 (-634 *3)) (-5 *1 (-1254 *2 *3 *4 *5 *6 *7 *8)) (-4 *5 (-950 *2 *4 *3)) (-14 *7 (-634 (-763))) (-14 *8 (-763)))) ((*1 *1 *1 *2) (-12 (-5 *1 (-1265 *2 *3)) (-4 *2 (-365)) (-4 *2 (-1047)) (-4 *3 (-838))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1161)) (-4 *5 (-609 (-887 (-568)))) (-4 *5 (-881 (-568))) (-4 *5 (-13 (-842) (-1037 (-568)) (-453) (-630 (-568)))) (-5 *2 (-2 (|:| |special| *3) (|:| |integrand| *3))) (-5 *1 (-571 *5 *3)) (-4 *3 (-620)) (-4 *3 (-13 (-27) (-1181) (-432 *5))))) ((*1 *2 *2 *3 *4 *4) (|partial| -12 (-5 *3 (-1161)) (-5 *4 (-835 *2)) (-4 *2 (-1124)) (-4 *2 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-609 (-887 (-568)))) (-4 *5 (-881 (-568))) (-4 *5 (-13 (-842) (-1037 (-568)) (-453) (-630 (-568)))) (-5 *1 (-571 *5 *2))))) 
 (((*1 *2 *3 *4 *5 *5 *5 *5 *6 *4 *4 *4 *4 *4 *5 *4 *5 *5 *4) (-12 (-5 *3 (-1143)) (-5 *4 (-568)) (-5 *5 (-679 (-215))) (-5 *6 (-215)) (-5 *2 (-1035)) (-5 *1 (-744))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-1201 *3)) (-4 *3 (-1047)) (-5 *1 (-1200 *3))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-1191 *2)) (-4 *2 (-975))))) 
-(((*1 *1 *1 *1) (-4 *1 (-21))) ((*1 *1 *1) (-4 *1 (-21))) ((*1 *1 *1 *1) (|partial| -5 *1 (-139))) ((*1 *1 *1 *1) (-12 (-5 *1 (-205 *2)) (-4 *2 (-13 (-842) (-10 -8 (-15 -2779 ((-1143) $ (-1161))) (-15 -4125 ((-1249) $)) (-15 -1352 ((-1249) $))))))) ((*1 *1 *1 *2) (-12 (-5 *1 (-288 *2)) (-4 *2 (-21)) (-4 *2 (-1195)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-21)) (-4 *2 (-1195)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) ((*1 *1 *1) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1090)) (-4 *4 (-1047)) (-5 *1 (-674 *3 *4)))) ((*1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) ((*1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)))) ((*1 *2 *2 *1) (-12 (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-944 (-215))) (-5 *1 (-1192)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-21)))) ((*1 *1 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-21))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-634 (-679 *4))) (-5 *2 (-679 *4)) (-4 *4 (-1047)) (-5 *1 (-1029 *4))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-1143)) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-256))))) 
+(((*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-1067 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6)))) ((*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-1098 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
+(((*1 *1 *1 *1) (-4 *1 (-21))) ((*1 *1 *1) (-4 *1 (-21))) ((*1 *1 *1 *1) (|partial| -5 *1 (-139))) ((*1 *1 *1 *1) (-12 (-5 *1 (-205 *2)) (-4 *2 (-13 (-842) (-10 -8 (-15 -2781 ((-1143) $ (-1161))) (-15 -4127 ((-1249) $)) (-15 -3687 ((-1249) $))))))) ((*1 *1 *1 *2) (-12 (-5 *1 (-288 *2)) (-4 *2 (-21)) (-4 *2 (-1195)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-21)) (-4 *2 (-1195)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) ((*1 *1 *1) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1090)) (-4 *4 (-1047)) (-5 *1 (-674 *3 *4)))) ((*1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) ((*1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)))) ((*1 *2 *2 *1) (-12 (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-944 (-215))) (-5 *1 (-1192)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-21)))) ((*1 *1 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-21))))) 
+(((*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1 *8 *8)) (-5 *5 (-1 (-3 (-2 (|:| -4151 *7) (|:| |coeff| *7)) "failed") *7)) (-5 *6 (-634 (-409 *8))) (-4 *7 (-365)) (-4 *8 (-1219 *7)) (-5 *3 (-409 *8)) (-5 *2 (-2 (|:| |answer| (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (|:| |a0| *7))) (-5 *1 (-578 *7 *8))))) 
 (((*1 *2 *3 *3 *3 *4 *4 *4 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-744))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-763)) (-5 *4 (-1244 *2)) (-4 *5 (-301)) (-4 *6 (-993 *5)) (-4 *2 (-13 (-411 *6 *7) (-1037 *6))) (-5 *1 (-415 *5 *6 *7 *2)) (-4 *7 (-1219 *6))))) 
-(((*1 *2) (-12 (-5 *2 (-2 (|:| -2971 (-634 (-1161))) (|:| -4100 (-634 (-1161))))) (-5 *1 (-1197))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-1099 *5 *6 *7 *8)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-1061 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-590 *5 *6 *7 *8 *3))))) 
-(((*1 *1 *1 *1) (-4 *1 (-25))) ((*1 *1 *1 *1) (-5 *1 (-158))) ((*1 *1 *1 *1) (-12 (-5 *1 (-205 *2)) (-4 *2 (-13 (-842) (-10 -8 (-15 -2779 ((-1143) $ (-1161))) (-15 -4125 ((-1249) $)) (-15 -1352 ((-1249) $))))))) ((*1 *1 *1 *2) (-12 (-5 *1 (-288 *2)) (-4 *2 (-25)) (-4 *2 (-1195)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-25)) (-4 *2 (-1195)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-320 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-137)))) ((*1 *1 *2 *1) (-12 (-4 *3 (-13 (-365) (-150))) (-5 *1 (-401 *3 *2)) (-4 *2 (-1219 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) ((*1 *1 *1 *1) (-5 *1 (-541))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1090)) (-4 *4 (-1047)) (-5 *1 (-674 *3 *4)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)))) ((*1 *2 *2 *1) (-12 (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-944 (-215))) (-5 *1 (-1192)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-25))))) 
-(((*1 *2 *3 *4 *2) (-12 (-5 *2 (-634 (-2 (|:| |totdeg| (-763)) (|:| -2700 *3)))) (-5 *4 (-763)) (-4 *3 (-950 *5 *6 *7)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *1 (-450 *5 *6 *7 *3))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *4 *4 *4 *4 *3 *3 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-744))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-320 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-137)) (-4 *3 (-787))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) ((*1 *2 *3) (-12 (-5 *3 (-972)) (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-842)) (-4 *4 (-365)) (-4 *5 (-788)) (-5 *1 (-514 *4 *5 *6 *2)) (-4 *2 (-950 *4 *5 *6)))) ((*1 *1 *1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *2)) (-4 *2 (-950 *3 *4 *5))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *1 (-1012)) (-5 *2 (-850))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-819))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-53))) (-1201 (-53)))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-53)))) (-1201 (-1157 (-53))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-53) (-763) (-763) (-1157 (-53)))) (|:| AF (-1 (-1157 (-53)) (-763) (-763) (-1201 (-1157 (-53))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-53)) (-763)))) (-634 (-465)))) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 *4 (-763) (-763) (-1157 *4))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 *4) (-763)))) (-634 (-465)))) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-568)))) (-1201 (-409 (-568))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-568))))) (-1201 (-1157 (-409 (-568)))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-568) (-763) (-763) (-1157 (-568)))) (|:| AF (-1 (-1157 (-409 (-568))) (-763) (-763) (-1201 (-1157 (-409 (-568)))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-568)) (-763)))) (-634 (-465)))) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 *4)) (-1201 *4))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 *4))) (-1201 (-1157 *4)))) (|:| |exprStream| (-1 (-1141 *6) *6 (-1161))) (|:| A (-1 *5 (-763) (-763) (-1157 *5))) (|:| AF (-1 (-1157 *4) (-763) (-763) (-1201 (-1157 *4)))) (|:| AX (-1 *6 (-763) (-1161) *6)) (|:| C (-1 (-634 *5) (-763)))) (-634 (-465)))) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-14 *9 (-1 *6 *4)) (-5 *2 (-1 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)))) ((*1 *2 *3) (-12 (-5 *3 (-1 (-2 (|:| |guessStream| (-1 (-1141 (-1201 (-409 (-953 (-568))))) (-1201 (-409 (-953 (-568)))))) (|:| |degreeStream| (-1141 (-763))) (|:| |testStream| (-1 (-1141 (-1201 (-1157 (-409 (-953 (-568)))))) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| |exprStream| (-1 (-1141 (-310 (-568))) (-310 (-568)) (-1161))) (|:| A (-1 (-953 (-568)) (-763) (-763) (-1157 (-953 (-568))))) (|:| AF (-1 (-1157 (-409 (-953 (-568)))) (-763) (-763) (-1201 (-1157 (-409 (-953 (-568))))))) (|:| AX (-1 (-310 (-568)) (-763) (-1161) (-310 (-568)))) (|:| C (-1 (-634 (-953 (-568))) (-763)))) (-634 (-465)))) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-1 HPSPEC (-634 (-465)))) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 (-1161))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-953 *4)))) (-4 *4 (-453)) (-5 *2 (-634 (-3 (-409 (-953 *4)) (-1150 (-1161) (-953 *4))))) (-5 *1 (-286 *4))))) 
+(((*1 *1 *1 *1) (-4 *1 (-25))) ((*1 *1 *1 *1) (-5 *1 (-158))) ((*1 *1 *1 *1) (-12 (-5 *1 (-205 *2)) (-4 *2 (-13 (-842) (-10 -8 (-15 -2781 ((-1143) $ (-1161))) (-15 -4127 ((-1249) $)) (-15 -3687 ((-1249) $))))))) ((*1 *1 *1 *2) (-12 (-5 *1 (-288 *2)) (-4 *2 (-25)) (-4 *2 (-1195)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-25)) (-4 *2 (-1195)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-320 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-137)))) ((*1 *1 *2 *1) (-12 (-4 *3 (-13 (-365) (-150))) (-5 *1 (-401 *3 *2)) (-4 *2 (-1219 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-475 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) ((*1 *1 *1 *1) (-5 *1 (-541))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1 *4 *3)) (-4 *3 (-1090)) (-4 *4 (-1047)) (-5 *1 (-674 *3 *4)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-677 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-375 *2)) (-4 *4 (-375 *2)))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)))) ((*1 *2 *2 *1) (-12 (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-236 *1)) (-4 *1 (-920 *3 *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-944 (-215))) (-5 *1 (-1192)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-25))))) 
+(((*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-568)) (-4 *5 (-840)) (-4 *5 (-365)) (-5 *2 (-763)) (-5 *1 (-946 *5 *6)) (-4 *6 (-1219 *5))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *4 *4 *4 *4 *3 *3 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-744))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 (-1157 (-1157 *4)))) (-5 *1 (-1194 *4)) (-5 *3 (-1157 (-1157 *4)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-242 (-4289 (QUOTE X) (QUOTE -2928)) *3))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-887 *4)) (-4 *4 (-1090)) (-5 *1 (-885 *4 *3)) (-4 *3 (-1195)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-57)) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-310 *3)) (-4 *3 (-558)) (-4 *3 (-842))))) 
 (((*1 *2 *3 *3 *3 *4 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *5 (-679 (-215))) (-5 *4 (-215)) (-5 *2 (-1035)) (-5 *1 (-744))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-944 *4)) (-4 *4 (-1047)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-679 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| |outval| *4) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 *4)))))) (-5 *1 (-773 *4)) (-4 *4 (-13 (-365) (-840)))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3001 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
-(((*1 *2 *3 *4 *4) (-12 (-5 *4 (-1161)) (-5 *2 (-1 *7 *5 *6)) (-5 *1 (-691 *3 *5 *6 *7)) (-4 *3 (-609 (-541))) (-4 *5 (-1195)) (-4 *6 (-1195)) (-4 *7 (-1195)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-5 *2 (-1 *6 *5)) (-5 *1 (-696 *3 *5 *6)) (-4 *3 (-609 (-541))) (-4 *5 (-1195)) (-4 *6 (-1195))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1111 *3 *4 *2 *5)) (-4 *4 (-1047)) (-4 *5 (-230 *3 *4)) (-4 *2 (-230 *3 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-5 *2 (-1 (-215) (-215))) (-5 *1 (-693 *3)) (-4 *3 (-609 (-541))))) ((*1 *2 *3 *4 *4) (-12 (-5 *4 (-1161)) (-5 *2 (-1 (-215) (-215) (-215))) (-5 *1 (-693 *3)) (-4 *3 (-609 (-541)))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *3 (-235 *10)) (-4 *11 (-536 *4 *5 *6 *7 *8 *9 *10 *3 *13)) (-4 *13 (-117)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *3 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-5 *1 (-562 *4 *5 *6 *7 *8 *9 *10 *3)) (-4 *8 (-971 *4)) (-4 *3 (-235 *10)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-236 (-922 *5))) (-5 *4 (-634 (-242 *6 *5))) (-4 *5 (-350)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-242 *6 (-857 *5)))) (-5 *1 (-867 *5 *6 *7)) (-4 *7 (-117)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-634 (-242 *5 *4))) (-5 *3 (-236 (-921 *4))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *1 (-868 *4 *5 *6)) (-4 *6 (-117))))) 
+(((*1 *2 *2 *3 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3))))) 
 (((*1 *2 *3 *3 *4 *4 *3 *4 *4 *3 *3 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-744))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-568)) (-5 *3 (-763)) (-5 *1 (-565))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-242 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-1047)) (-5 *2 (-492 *4 *5)) (-5 *1 (-945 *4 *5))))) 
+(((*1 *1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164)))) ((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1164))))) 
 (((*1 *2 *1 *1) (-12 (-4 *1 (-842)) (-5 *2 (-121)))) ((*1 *1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *2 *3) (-12 (-5 *2 (-420 (-1157 *1))) (-5 *1 (-310 *4)) (-5 *3 (-1157 *1)) (-4 *4 (-453)) (-4 *4 (-558)) (-4 *4 (-842)))) ((*1 *2 *3) (-12 (-4 *1 (-904)) (-5 *2 (-420 (-1157 *1))) (-5 *3 (-1157 *1))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
 (((*1 *2 *3 *4 *4 *3 *3 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-743))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-5 *1 (-60 *4 *5 *2)) (-4 *2 (-13 (-432 *5) (-881 *4) (-609 (-887 *4))))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-334 *5 *6 *7 *8)) (-4 *5 (-432 *4)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-4 *8 (-340 *5 *6 *7)) (-4 *4 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-2 (|:| -4477 (-763)) (|:| -1864 *8))) (-5 *1 (-906 *4 *5 *6 *7 *8)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-334 (-409 (-568)) *4 *5 *6)) (-4 *4 (-1219 (-409 (-568)))) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 (-409 (-568)) *4 *5)) (-5 *2 (-2 (|:| -4477 (-763)) (|:| -1864 *6))) (-5 *1 (-907 *4 *5 *6))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-816)) (-5 *2 (-57)) (-5 *1 (-826))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-21)) (-4 *2 (-1195))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-350)) (-5 *2 (-121)))) ((*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-350)) (-5 *2 (-121)) (-5 *1 (-358 *4))))) 
 (((*1 *2 *1 *1) (-12 (-4 *1 (-235 *3)) (-4 *3 (-1090)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-842)) (-5 *2 (-121)))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-899 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *2) (|partial| -12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-1028 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-634 (-679 *3))) (-4 *3 (-1047)) (-5 *1 (-1028 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-1028 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-634 (-679 *3))) (-4 *3 (-1047)) (-5 *1 (-1028 *3))))) 
 (((*1 *2 *3 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-743))))) 
 (((*1 *1 *1) (-5 *1 (-850))) ((*1 *2 *1) (-12 (-4 *1 (-1093 *2 *3 *4 *5 *6)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-1090)))) ((*1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-1142)))) ((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-1161))))) 
-(((*1 *2) (-12 (-4 *3 (-172)) (-5 *2 (-1244 *1)) (-4 *1 (-369 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-4 *5 (-365)) (-5 *2 (-634 (-1190 *5))) (-5 *1 (-1252 *5)) (-5 *4 (-1190 *5))))) 
-(((*1 *2) (-12 (-4 *4 (-365)) (-5 *2 (-763)) (-5 *1 (-326 *3 *4)) (-4 *3 (-327 *4)))) ((*1 *2) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-763))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-927)) (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-927)) (-5 *4 (-409 (-568))) (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156)))) ((*1 *2 *3) (-12 (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156)) (-5 *3 (-634 (-944 (-215)))))) ((*1 *2 *3) (-12 (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 (-215))))) (|:| |xValues| (-1084 (-215))) (|:| |yValues| (-1084 (-215))))) (-5 *1 (-156)) (-5 *3 (-634 (-634 (-944 (-215))))))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-1084 (-381)))) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-256))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
+(((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-1067 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-1098 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7))))) 
 (((*1 *2 *1 *1) (-12 (-4 *1 (-842)) (-5 *2 (-121)))) ((*1 *1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-763)) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-96 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-212 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-494 *4)) (-4 *4 (-842)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1000 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1132 *4)) (-4 *4 (-1090)))) ((*1 *2 *3 *3) (-12 (-5 *2 (-121)) (-5 *1 (-1196 *3)) (-4 *3 (-842)) (-4 *3 (-1090))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-409 *2)) (-4 *2 (-1219 *5)) (-5 *1 (-802 *5 *2 *3 *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *3 (-646 *2)) (-4 *6 (-646 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-409 *2))) (-4 *2 (-1219 *5)) (-5 *1 (-802 *5 *2 *3 *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *3 (-646 *2)) (-4 *6 (-646 (-409 *2)))))) 
 (((*1 *2 *3 *4 *4 *4 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-743))))) 
-(((*1 *2) (-12 (-4 *2 (-13 (-432 *3) (-1002))) (-5 *1 (-272 *3 *2)) (-4 *3 (-13 (-842) (-558)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-634 (-634 *4)))) (-5 *2 (-634 (-634 *4))) (-5 *1 (-1167 *4)) (-4 *4 (-842))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |gen| *3) (|:| -1892 (-568)))) (-5 *1 (-236 *3)) (-4 *3 (-1088)))) ((*1 *1 *1) (-12 (-4 *1 (-239 *2)) (-4 *2 (-1195)))) ((*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-409 (-568))) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *4 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4)))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-970 *3 *2)) (-4 *2 (-1219 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1219 *2)) (-4 *2 (-1047)) (-4 *2 (-558))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1216 *5 *4)) (-4 *4 (-453)) (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-568)) (-5 *1 (-1104 *4 *5))))) 
 (((*1 *2 *1 *1) (-12 (-4 *1 (-842)) (-5 *2 (-121)))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *2 *1 *1) (-12 (-4 *1 (-898 *3)) (-4 *3 (-1090)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1087 *3)) (-4 *3 (-1090)) (-5 *2 (-121))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350)))) ((*1 *1) (-4 *1 (-370))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1244 *4)) (-5 *1 (-532 *4)) (-4 *4 (-350)))) ((*1 *1 *1) (-4 *1 (-550))) ((*1 *1) (-4 *1 (-550))) ((*1 *1 *1) (-5 *1 (-568))) ((*1 *1 *1) (-5 *1 (-763))) ((*1 *2 *1) (-12 (-5 *2 (-900 *3)) (-5 *1 (-899 *3)) (-4 *3 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-900 *4)) (-5 *1 (-899 *4)) (-4 *4 (-1090)))) ((*1 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-550)) (-4 *2 (-558))))) 
-(((*1 *2 *2) (-12 (-4 *2 (-172)) (-4 *2 (-1047)) (-5 *1 (-704 *2 *3)) (-4 *3 (-637 *2)))) ((*1 *2 *2) (-12 (-5 *1 (-829 *2)) (-4 *2 (-172)) (-4 *2 (-1047))))) 
+(((*1 *1) (-12 (-4 *1 (-406)) (-3046 (|has| *1 (-6 -4512))) (-3046 (|has| *1 (-6 -4504))))) ((*1 *2 *1) (-12 (-4 *1 (-427 *2)) (-4 *2 (-1090)) (-4 *2 (-842)))) ((*1 *2 *1) (-12 (-4 *1 (-825 *2)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-4 *1 (-842))) ((*1 *1) (-5 *1 (-1108)))) 
 (((*1 *2 *3 *4 *4 *4 *3 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-743))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
+(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-1157 (-953 *4))) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4)))) ((*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-4 *3 (-365)) (-5 *2 (-1157 (-953 *3))))) ((*1 *2) (-12 (-5 *2 (-1157 (-409 (-953 *3)))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
 (((*1 *2 *3 *2) (-12 (-5 *1 (-669 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-415 *3 *4 *5 *6)) (-4 *6 (-1037 *4)) (-4 *3 (-301)) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-4 *6 (-411 *4 *5)) (-14 *7 (-1244 *6)) (-5 *1 (-416 *3 *4 *5 *6 *7)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 *6)) (-4 *6 (-411 *4 *5)) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-4 *3 (-301)) (-5 *1 (-416 *3 *4 *5 *6 *7)) (-14 *7 *2)))) 
-(((*1 *1 *1 *1) (-5 *1 (-850)))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-568)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-301)) (-4 *9 (-950 *8 *6 *7)) (-5 *2 (-2 (|:| -2700 (-1157 *9)) (|:| |polval| (-1157 *8)))) (-5 *1 (-732 *6 *7 *8 *9)) (-5 *3 (-1157 *9)) (-5 *4 (-1157 *8))))) 
-(((*1 *1) (-5 *1 (-142)))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-381)) (-5 *1 (-1059))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-1 (-3 *5 "failed") *8)) (-5 *4 (-679 (-1157 *8))) (-4 *5 (-1047)) (-4 *8 (-1047)) (-4 *6 (-1219 *5)) (-5 *2 (-679 *6)) (-5 *1 (-510 *5 *6 *7 *8)) (-4 *7 (-1219 *6))))) 
+(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1197))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-350)) (-5 *2 (-2 (|:| |cont| *5) (|:| -2075 (-634 (-2 (|:| |irr| *3) (|:| -4402 (-568))))))) (-5 *1 (-207 *5 *3)) (-4 *3 (-1219 *5))))) 
 (((*1 *2 *3 *4 *4 *4 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *2 (-1035)) (-5 *1 (-743))))) 
 (((*1 *2 *3) (-12 (-5 *2 (-568)) (-5 *1 (-573 *3)) (-4 *3 (-1037 *2)))) ((*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *2 *5 *6)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-1090))))) 
 (((*1 *2 *2 *3) (-12 (-5 *1 (-669 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1090))))) 
-(((*1 *2 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-3 (-121) (-634 *1))) (-4 *1 (-1066 *4 *5 *6 *3))))) 
-(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-869)) (-5 *2 (-1249)) (-5 *1 (-1245)))) ((*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) *2)) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-763))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-310 (-215))) (-5 *1 (-202))))) 
 (((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-105)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-212 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *1 *2 *2) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1195)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-436)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-494 *3)) (-4 *3 (-1090)) (-4 *3 (-842)))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)) (-4 *3 (-1090)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1026 *3)) (-4 *3 (-1195)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)) (-4 *3 (-1090))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-568))) (-4 *3 (-1047)) (-5 *1 (-593 *3)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-568))) (-4 *1 (-1203 *3)) (-4 *3 (-1047)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *3 (-568))) (-4 *1 (-1234 *3)) (-4 *3 (-1047))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |lm| (-388 *3)) (|:| |mm| (-388 *3)) (|:| |rm| (-388 *3)))) (-5 *1 (-388 *3)) (-4 *3 (-1090)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| |lm| (-814 *3)) (|:| |mm| (-814 *3)) (|:| |rm| (-814 *3)))) (-5 *1 (-814 *3)) (-4 *3 (-842))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-27)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *5 (-1219 *4)) (-5 *2 (-634 (-643 (-409 *5)))) (-5 *1 (-647 *4 *5)) (-5 *3 (-643 (-409 *5)))))) 
 (((*1 *2 *3 *3 *4 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-743))))) 
 (((*1 *2 *2) (-12 (-5 *1 (-671 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *2 (-568)) (-5 *1 (-1178 *3)) (-4 *3 (-1047))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-372 *4 *5)) (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-679 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-411 *3 *4)) (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-679 *3))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-159 *4 *2)) (-4 *2 (-432 *4)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1082 *2)) (-4 *2 (-432 *4)) (-4 *4 (-13 (-842) (-558))) (-5 *1 (-159 *4 *2)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1082 *1)) (-4 *1 (-161)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-161)) (-5 *2 (-1161))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *6))) (-5 *4 (-634 (-1161))) (-4 *6 (-13 (-558) (-1037 *5))) (-4 *5 (-558)) (-5 *2 (-634 (-634 (-288 (-409 (-953 *6)))))) (-5 *1 (-1038 *5 *6))))) 
+(((*1 *2) (-12 (-5 *2 (-1 *3 *3)) (-5 *1 (-533 *3)) (-4 *3 (-13 (-716) (-25)))))) 
+(((*1 *2 *3) (|partial| -12 (-4 *4 (-13 (-558) (-150))) (-5 *2 (-2 (|:| -3030 *3) (|:| -3286 *3))) (-5 *1 (-1213 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-381)) (-5 *1 (-197))))) 
 (((*1 *2 *3 *4 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-743))))) 
 (((*1 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-328)))) ((*1 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-328))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-121)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-465))))) 
-(((*1 *2 *1 *2) (-12 (-4 *1 (-366 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1249)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-258 *12))))) 
+(((*1 *1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-111 *2)) (-4 *2 (-1195)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-130 *2)) (-4 *2 (-842)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-135 *2)) (-4 *2 (-842)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *1 *2) (-12 (-5 *2 (-568)) (-4 *1 (-277 *3)) (-4 *3 (-1195)))) ((*1 *1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-277 *2)) (-4 *2 (-1195)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| -3651 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) (-5 *1 (-563)))) ((*1 *1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-684 *2)) (-4 *2 (-1090)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| -3651 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381)))))) (-5 *1 (-798)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) ((*1 *1 *2 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090)))) ((*1 *2 *3 *4) (-12 (-5 *2 (-1249)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-358 *4)) (-4 *4 (-350))))) 
+(((*1 *2 *1 *2) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-230 (-1699 *6) (-763))) (-5 *2 (-242 (-4289 (QUOTE X) (QUOTE -2928)) *5)) (-5 *1 (-119 *5 *6 *3 *7 *4)) (-4 *3 (-324 *5 *7)) (-4 *4 (-117))))) 
 (((*1 *2 *3 *4 *4 *4 *3 *3 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *2 (-1035)) (-5 *1 (-743))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-4 *3 (-1090)) (-5 *2 (-121))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *4) (|:| |xpnt| (-568)))) (-4 *4 (-13 (-1219 *3) (-558) (-10 -8 (-15 -2721 ($ $ $))))) (-4 *3 (-558)) (-5 *1 (-1222 *3 *4))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-130 *3))))) 
-(((*1 *2 *1) (-12 (|has| *1 (-6 -4519)) (-4 *1 (-39)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-763)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-763)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-763)) (-5 *1 (-494 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-763)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-568)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4519)) (-5 *2 (-763)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1265 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-838))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-917))) (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-39)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-494 *3)) (-4 *3 (-842)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) ((*1 *2 *1 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1132 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *3 *4 *2) (-12 (-5 *2 (-634 (-634 (-634 *5)))) (-5 *3 (-1 (-121) *5 *5)) (-5 *4 (-634 *5)) (-4 *5 (-842)) (-5 *1 (-1167 *5))))) 
+(((*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121))))) 
+(((*1 *2 *1) (-12 (|has| *1 (-6 -4521)) (-4 *1 (-39)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-763)) (-5 *1 (-96 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-763)) (-5 *1 (-212 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-763)) (-5 *1 (-494 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-763)) (-5 *1 (-1000 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-568)))) ((*1 *2 *1) (-12 (|has| $ (-6 -4521)) (-5 *2 (-763)) (-5 *1 (-1132 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1265 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-838))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-850))))) 
-(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
-(((*1 *2 *2 *2 *3) (-12 (-5 *2 (-1244 (-568))) (-5 *3 (-568)) (-5 *1 (-1100)))) ((*1 *2 *3 *2 *4) (-12 (-5 *2 (-1244 (-568))) (-5 *3 (-634 (-568))) (-5 *4 (-568)) (-5 *1 (-1100))))) 
-(((*1 *2 *3 *2 *4 *5) (-12 (-5 *2 (-634 *3)) (-5 *5 (-917)) (-4 *3 (-1219 *4)) (-4 *4 (-301)) (-5 *1 (-462 *4 *3))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-634 (-1 *4 (-634 *4)))) (-4 *4 (-1090)) (-5 *1 (-122 *4)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *4 *4)) (-4 *4 (-1090)) (-5 *1 (-122 *4)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-123)) (-5 *2 (-634 (-1 *4 (-634 *4)))) (-5 *1 (-122 *4)) (-4 *4 (-1090))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-325 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-525 *3 *4)) (-14 *4 (-568))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-679 (-310 (-568)))) (-5 *1 (-1031))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1219 (-409 *3))) (-5 *2 (-917)) (-5 *1 (-909 *4 *5)) (-4 *5 (-1219 (-409 *4)))))) 
+(((*1 *2 *3 *2) (|partial| -12 (-5 *3 (-917)) (-5 *1 (-443 *2)) (-4 *2 (-1219 (-568))))) ((*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-917)) (-5 *4 (-763)) (-5 *1 (-443 *2)) (-4 *2 (-1219 (-568))))) ((*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-917)) (-5 *4 (-634 (-763))) (-5 *1 (-443 *2)) (-4 *2 (-1219 (-568))))) ((*1 *2 *3 *2 *4 *5) (|partial| -12 (-5 *3 (-917)) (-5 *4 (-634 (-763))) (-5 *5 (-763)) (-5 *1 (-443 *2)) (-4 *2 (-1219 (-568))))) ((*1 *2 *3 *2 *4 *5 *6) (|partial| -12 (-5 *3 (-917)) (-5 *4 (-634 (-763))) (-5 *5 (-763)) (-5 *6 (-121)) (-5 *1 (-443 *2)) (-4 *2 (-1219 (-568))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-420 *2)) (-4 *2 (-1219 *5)) (-5 *1 (-445 *5 *2)) (-4 *5 (-1047))))) 
 (((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-58))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *2 *5)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-788)) (-4 *2 (-262 *4))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-301)) (-4 *6 (-375 *5)) (-4 *4 (-375 *5)) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -3746 (-634 *4)))) (-5 *1 (-1112 *5 *6 *4 *3)) (-4 *3 (-677 *5 *6 *4))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-641 *2)) (-4 *2 (-365))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-2 (|:| |k| (-814 *3)) (|:| |c| *4)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-975)) (-5 *2 (-1084 (-215)))))) 
+(((*1 *2 *1) (|partial| -12 (-5 *2 (-1161)) (-5 *1 (-607 *3)) (-4 *3 (-842))))) 
 (((*1 *2 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-634 (-541))) (-5 *1 (-541))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1157 (-409 (-953 *3)))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-215))) (-5 *4 (-1161)) (-5 *5 (-1084 (-835 (-215)))) (-5 *2 (-634 (-215))) (-5 *1 (-184)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-215))) (-5 *4 (-1161)) (-5 *5 (-1084 (-835 (-215)))) (-5 *2 (-634 (-215))) (-5 *1 (-294))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-169 *5)) (-4 *5 (-13 (-432 *4) (-1002) (-1181))) (-4 *4 (-13 (-558) (-842))) (-4 *2 (-13 (-432 (-169 *4)) (-1002) (-1181))) (-5 *1 (-597 *4 *5 *2))))) 
-(((*1 *2 *1 *3) (-12 (-5 *2 (-2 (|:| |k| (-568)) (|:| |c| *4))) (-5 *1 (-774 *4)) (-4 *4 (-365)) (-5 *3 (-568))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-1157 *1)) (-5 *3 (-1161)) (-4 *1 (-27)))) ((*1 *1 *2) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-27)))) ((*1 *1 *2) (-12 (-5 *2 (-953 *1)) (-4 *1 (-27)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1161)) (-4 *1 (-29 *3)) (-4 *3 (-13 (-842) (-558))))) ((*1 *1 *1) (-12 (-4 *1 (-29 *2)) (-4 *2 (-13 (-842) (-558)))))) 
+(((*1 *2 *1 *1 *3) (-12 (-5 *3 (-1 (-121) *5 *5)) (-4 *5 (-13 (-1090) (-39))) (-5 *2 (-121)) (-5 *1 (-1125 *4 *5)) (-4 *4 (-13 (-1090) (-39)))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1203 *4)) (-4 *4 (-1047)) (-4 *4 (-558)) (-5 *2 (-409 (-953 *4))))) ((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-1203 *4)) (-4 *4 (-1047)) (-4 *4 (-558)) (-5 *2 (-409 (-953 *4)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |gen| *3) (|:| -1894 *4)))) (-5 *1 (-638 *3 *4 *5)) (-4 *3 (-1090)) (-4 *4 (-23)) (-14 *5 *4)))) 
+(((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-615 *4 *5)) (-5 *3 (-1 (-2 (|:| |ans| *4) (|:| -3286 *4) (|:| |sol?| (-121))) (-568) *4)) (-4 *4 (-365)) (-4 *5 (-1219 *4)) (-5 *1 (-578 *4 *5))))) 
 (((*1 *2 *3 *3 *3 *4 *5 *3 *6) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *6 (-3 (|:| |fn| (-390)) (|:| |fp| (-79 FCN)))) (-5 *2 (-1035)) (-5 *1 (-738))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-420 *3)) (-5 *1 (-561 *3)) (-4 *3 (-550)))) ((*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)) (-5 *2 (-420 *3)) (-5 *1 (-732 *4 *5 *6 *3)) (-4 *3 (-950 *6 *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-732 *4 *5 *6 *7)) (-5 *3 (-1157 *7)))) ((*1 *2 *1) (-12 (-4 *3 (-453)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-420 *1)) (-4 *1 (-950 *3 *4 *5)))) ((*1 *2 *3) (-12 (-4 *4 (-842)) (-4 *5 (-788)) (-4 *6 (-453)) (-5 *2 (-420 *3)) (-5 *1 (-980 *4 *5 *6 *3)) (-4 *3 (-950 *6 *5 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-453)) (-4 *7 (-950 *6 *4 *5)) (-5 *2 (-420 (-1157 (-409 *7)))) (-5 *1 (-1156 *4 *5 *6 *7)) (-5 *3 (-1157 (-409 *7))))) ((*1 *2 *1) (-12 (-5 *2 (-420 *1)) (-4 *1 (-1199)))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-420 *3)) (-5 *1 (-1222 *4 *3)) (-4 *3 (-13 (-1219 *4) (-558) (-10 -8 (-15 -2721 ($ $ $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1044 *4 *5)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *5 (-634 (-1161))) (-5 *2 (-634 (-1131 *4 (-534 (-852 *6)) (-852 *6) (-775 *4 (-852 *6))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *6 (-634 (-1161)))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *5 (-121)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1064 *6 *7 *8 *3 *4)) (-4 *4 (-1066 *6 *7 *8 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-2 (|:| |done| (-634 *4)) (|:| |todo| (-634 (-2 (|:| |val| (-634 *3)) (|:| -3001 *4)))))) (-5 *1 (-1130 *5 *6 *7 *3 *4)) (-4 *4 (-1099 *5 *6 *7 *3))))) 
-(((*1 *2 *3 *3 *4 *5 *5) (-12 (-5 *5 (-121)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *3 (-1061 *6 *7 *8)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3001 *4)))) (-5 *1 (-1098 *6 *7 *8 *3 *4)) (-4 *4 (-1066 *6 *7 *8 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 (-2 (|:| |val| (-634 *8)) (|:| -3001 *9)))) (-5 *5 (-121)) (-4 *8 (-1061 *6 *7 *4)) (-4 *9 (-1066 *6 *7 *4 *8)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *4 (-842)) (-5 *2 (-634 (-2 (|:| |val| *8) (|:| -3001 *9)))) (-5 *1 (-1098 *6 *7 *4 *8 *9))))) 
-(((*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -1338 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *1 (-563))))) 
+(((*1 *1 *2 *2 *3) (-12 (-5 *2 (-568)) (-5 *3 (-917)) (-5 *1 (-688)))) ((*1 *2 *2 *2 *3 *4) (-12 (-5 *2 (-679 *5)) (-5 *3 (-101 *5)) (-5 *4 (-1 *5 *5)) (-4 *5 (-365)) (-5 *1 (-979 *5))))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-1125 *4 *5)) (-4 *4 (-13 (-1090) (-39))) (-4 *5 (-13 (-1090) (-39))) (-5 *2 (-121)) (-5 *1 (-1126 *4 *5))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-64 *6)) (-4 *6 (-1195)) (-4 *5 (-1195)) (-5 *2 (-64 *5)) (-5 *1 (-63 *6 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *7 *5)) (-5 *4 (-232 *6 *7)) (-14 *6 (-763)) (-4 *7 (-1195)) (-4 *5 (-1195)) (-5 *2 (-232 *6 *5)) (-5 *1 (-231 *6 *7 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-4 *6 (-1195)) (-4 *5 (-1195)) (-4 *2 (-375 *5)) (-5 *1 (-373 *6 *4 *5 *2)) (-4 *4 (-375 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-4 *6 (-1090)) (-4 *5 (-1090)) (-4 *2 (-427 *5)) (-5 *1 (-425 *6 *4 *5 *2)) (-4 *4 (-427 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-634 *6)) (-4 *6 (-1195)) (-4 *5 (-1195)) (-5 *2 (-634 *5)) (-5 *1 (-632 *6 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-958 *6)) (-4 *6 (-1195)) (-4 *5 (-1195)) (-5 *2 (-958 *5)) (-5 *1 (-957 *6 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *3 *6 *3)) (-5 *5 (-1141 *6)) (-4 *6 (-1195)) (-4 *3 (-1195)) (-5 *2 (-1141 *3)) (-5 *1 (-1139 *6 *3)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *5 *6 *5)) (-5 *4 (-1244 *6)) (-4 *6 (-1195)) (-4 *5 (-1195)) (-5 *2 (-1244 *5)) (-5 *1 (-1243 *6 *5))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (-5 *1 (-563))))) 
 (((*1 *2 *3 *3 *3 *4 *4 *4 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *2 (-1035)) (-5 *1 (-744))))) 
-(((*1 *2 *3 *3 *3 *4 *5 *4 *6) (-12 (-5 *3 (-310 (-568))) (-5 *4 (-1 (-215) (-215))) (-5 *5 (-1084 (-215))) (-5 *6 (-568)) (-5 *2 (-1191 (-926))) (-5 *1 (-313)))) ((*1 *2 *3 *3 *3 *4 *5 *4 *6 *7) (-12 (-5 *3 (-310 (-568))) (-5 *4 (-1 (-215) (-215))) (-5 *5 (-1084 (-215))) (-5 *6 (-568)) (-5 *7 (-1143)) (-5 *2 (-1191 (-926))) (-5 *1 (-313)))) ((*1 *2 *3 *3 *3 *4 *5 *6 *7) (-12 (-5 *3 (-310 (-568))) (-5 *4 (-1 (-215) (-215))) (-5 *5 (-1084 (-215))) (-5 *6 (-215)) (-5 *7 (-568)) (-5 *2 (-1191 (-926))) (-5 *1 (-313)))) ((*1 *2 *3 *3 *3 *4 *5 *6 *7 *8) (-12 (-5 *3 (-310 (-568))) (-5 *4 (-1 (-215) (-215))) (-5 *5 (-1084 (-215))) (-5 *6 (-215)) (-5 *7 (-568)) (-5 *8 (-1143)) (-5 *2 (-1191 (-926))) (-5 *1 (-313))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-634 *5)) (-4 *5 (-1219 *3)) (-4 *3 (-301)) (-5 *2 (-121)) (-5 *1 (-457 *3 *5))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-159 *3 *2)) (-4 *2 (-432 *3))))) 
-(((*1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850))))) 
+(((*1 *2 *1 *3 *4 *4 *5) (-12 (-5 *3 (-944 (-215))) (-5 *4 (-869)) (-5 *5 (-917)) (-5 *2 (-1249)) (-5 *1 (-473)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-944 (-215))) (-5 *2 (-1249)) (-5 *1 (-473)))) ((*1 *2 *1 *3 *4 *4 *5) (-12 (-5 *3 (-634 (-944 (-215)))) (-5 *4 (-869)) (-5 *5 (-917)) (-5 *2 (-1249)) (-5 *1 (-473))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-1143)) (-4 *1 (-366 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090))))) 
 (((*1 *2 *3 *4 *5 *4) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *5 (-121)) (-5 *2 (-1035)) (-5 *1 (-737))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-365)) (-5 *2 (-634 *3)) (-5 *1 (-946 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1141 (-409 *3))) (-5 *1 (-173 *3)) (-4 *3 (-301))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1263 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-814 *3)))) ((*1 *2 *1) (-12 (-4 *2 (-838)) (-5 *1 (-1265 *3 *2)) (-4 *3 (-1047))))) 
-(((*1 *1 *1 *2) (|partial| -12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5))))) 
+(((*1 *1 *1) (-5 *1 (-1059)))) 
+(((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-586 *3)) (-4 *3 (-550))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-679 *1)) (-5 *4 (-1244 *1)) (-4 *1 (-630 *5)) (-4 *5 (-1047)) (-5 *2 (-2 (|:| -2908 (-679 *5)) (|:| |vec| (-1244 *5)))))) ((*1 *2 *3) (-12 (-5 *3 (-679 *1)) (-4 *1 (-630 *4)) (-4 *4 (-1047)) (-5 *2 (-679 *4))))) 
+(((*1 *2 *1 *3) (-12 (-4 *1 (-39)) (-5 *3 (-763)) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-96 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-212 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-494 *4)) (-4 *4 (-842)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1000 *4)) (-4 *4 (-1090)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-121)) (-5 *1 (-1132 *4)) (-4 *4 (-1090))))) 
 (((*1 *2 *3 *4 *5 *4) (-12 (-5 *3 (-679 (-215))) (-5 *4 (-568)) (-5 *5 (-121)) (-5 *2 (-1035)) (-5 *1 (-737))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-568)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-568))))) 
-(((*1 *1) (-5 *1 (-158)))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(((*1 *2 *3 *1) (-12 (-5 *2 (-634 (-1161))) (-5 *1 (-1164)) (-5 *3 (-1161))))) 
-(((*1 *2 *1 *2) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-1010 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-2 (|:| |num| (-1244 *4)) (|:| |den| *4)))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *2 (-2 (|:| -2961 (-568)) (|:| -1461 (-568)) (|:| -3961 (-568)) (|:| |reste| (-568)) (|:| -2219 (-3 "left" "center" "right" "vertical" "horizontal")))) (-5 *1 (-772 *4 *3 *5 *6)) (-4 *3 (-324 *4 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *5)) (-4 *5 (-324 *4 *6)) (-4 *6 (-230 *7 (-763))) (-14 *7 (-763)) (-4 *4 (-1047)) (-5 *2 (-2 (|:| -2961 (-568)) (|:| -1461 (-568)) (|:| -3961 (-568)) (|:| |reste| (-568)) (|:| -2219 (-3 "left" "center" "right" "vertical" "horizontal")))) (-5 *1 (-772 *4 *5 *6 *7))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-541)) (-5 *1 (-540 *4)) (-4 *4 (-1195))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-5 *2 (-568))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1141 (-409 *3))) (-5 *1 (-173 *3)) (-4 *3 (-301))))) 
+(((*1 *2 *1) (|partial| -12 (-5 *2 (-634 (-887 *3))) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1141 (-568))) (-5 *1 (-1145 *4)) (-4 *4 (-1047)) (-5 *3 (-568))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-634 (-634 (-634 *4)))) (-5 *3 (-634 *4)) (-4 *4 (-842)) (-5 *1 (-1167 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-634 (-1141 *7))) (-4 *6 (-842)) (-4 *7 (-950 *5 (-534 *6) *6)) (-4 *5 (-1047)) (-5 *2 (-1 (-1141 *7) *7)) (-5 *1 (-1114 *5 *6 *7))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3))))) 
+(((*1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1164))))) 
 (((*1 *2 *3 *4 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *2 (-1035)) (-5 *1 (-744))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-1047)) (-4 *2 (-1219 *4)) (-5 *1 (-445 *4 *2)))) ((*1 *2 *3 *2 *4) (-12 (-5 *2 (-409 (-1157 (-310 *5)))) (-5 *3 (-1244 (-310 *5))) (-5 *4 (-568)) (-4 *5 (-13 (-558) (-842))) (-5 *1 (-1118 *5))))) 
-(((*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-844 *3)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-365)) (-4 *5 (-1047)) (-5 *2 (-2 (|:| -3961 *3) (|:| -1500 *3))) (-5 *1 (-845 *5 *3)) (-4 *3 (-844 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) ((*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1010 *3)) (-4 *3 (-1195)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-215)) (-5 *2 (-310 (-381))) (-5 *1 (-299))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-634 *3)) (-4 *3 (-301)) (-5 *1 (-177 *3))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1 (-944 (-215)) (-944 (-215)))) (-5 *1 (-256)))) ((*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-327 *4)) (-4 *4 (-365)) (-5 *2 (-679 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-5 *2 (-1244 *3)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-679 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-1244 *4)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-372 *4 *5)) (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-679 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-372 *4 *5)) (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-1244 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-411 *4 *5)) (-4 *4 (-172)) (-4 *5 (-1219 *4)) (-5 *2 (-679 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-411 *3 *4)) (-4 *3 (-172)) (-4 *4 (-1219 *3)) (-5 *2 (-1244 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-419 *4)) (-4 *4 (-172)) (-5 *2 (-679 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-1244 *3)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-679 *5))) (-5 *3 (-679 *5)) (-4 *5 (-365)) (-5 *2 (-1244 *5)) (-5 *1 (-1077 *5))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-215))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-4 *5 (-350)) (-5 *2 (-634 *3)) (-5 *1 (-344 *5 *3)) (-4 *3 (-1219 *5))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-777 *2)) (-4 *2 (-1047)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1219 (-568))) (-5 *1 (-496 *3))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-310 (-215))) (-5 *1 (-263))))) 
 (((*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245))))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-1246)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568)))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-634 (-2 (|:| -3848 (-1157 *6)) (|:| -3438 (-568))))) (-4 *6 (-301)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-732 *4 *5 *6 *7)) (-4 *7 (-950 *6 *4 *5)))) ((*1 *1 *1) (-12 (-4 *1 (-1122 *2)) (-4 *2 (-1047))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *4 (-1047)) (-5 *2 (-2 (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-1219 *4))))) 
-(((*1 *2 *1) (|partial| -12 (-4 *1 (-166 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-409 (-568))))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-409 (-568))) (-5 *1 (-420 *3)) (-4 *3 (-550)) (-4 *3 (-558)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-550)) (-5 *2 (-409 (-568))))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-792 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-409 (-568))))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-409 (-568))) (-5 *1 (-828 *3)) (-4 *3 (-550)) (-4 *3 (-1090)))) ((*1 *2 *1) (|partial| -12 (-5 *2 (-409 (-568))) (-5 *1 (-835 *3)) (-4 *3 (-550)) (-4 *3 (-1090)))) ((*1 *2 *1) (|partial| -12 (-4 *1 (-997 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-409 (-568))))) ((*1 *2 *3) (|partial| -12 (-5 *2 (-409 (-568))) (-5 *1 (-1008 *3)) (-4 *3 (-1037 *2))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-365) (-840))) (-5 *2 (-2 (|:| |start| *3) (|:| -2075 (-420 *3)))) (-5 *1 (-178 *4 *3)) (-4 *3 (-1219 (-169 *4)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-679 (-169 (-409 (-568))))) (-5 *2 (-634 (-169 *4))) (-5 *1 (-756 *4)) (-4 *4 (-13 (-365) (-840)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-215)) (-5 *1 (-817))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-634 (-242 *4 *5))) (-5 *2 (-242 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *1 (-622 *4 *5))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-568) (-568))) (-5 *1 (-363 *3)) (-4 *3 (-1090)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-763) (-763))) (-5 *1 (-388 *3)) (-4 *3 (-1090)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-23)) (-14 *5 *4) (-5 *1 (-638 *3 *4 *5)) (-4 *3 (-1090))))) 
 (((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-58))))) 
-(((*1 *2 *3 *4 *4) (-12 (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1697 *6) (-763))) (-4 *9 (-971 *5)) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-4 *3 (-235 *11)) (-4 *12 (-536 *5 *6 *7 *8 *9 *10 *11 *3 *14)) (-4 *14 (-117)) (-5 *2 (-2 (|:| -1379 (-568)) (|:| |num| *7) (|:| |den| *7) (|:| |upTo| (-568)))) (-5 *1 (-467 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13 *14)) (-5 *4 (-568)) (-4 *13 (-258 *12)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-236 (-922 *5))) (-4 *5 (-350)) (-5 *2 (-2 (|:| -1379 (-568)) (|:| |num| (-242 *6 *5)) (|:| |den| (-242 *6 *5)) (|:| |upTo| (-568)))) (-5 *1 (-867 *5 *6 *7)) (-5 *4 (-568)) (-14 *6 (-634 (-1161))) (-4 *7 (-117)))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-236 (-921 *5))) (-4 *5 (-365)) (-5 *2 (-2 (|:| -1379 (-568)) (|:| |num| (-242 *6 *5)) (|:| |den| (-242 *6 *5)) (|:| |upTo| (-568)))) (-5 *1 (-868 *5 *6 *7)) (-5 *4 (-568)) (-14 *6 (-634 (-1161))) (-4 *7 (-117))))) 
-(((*1 *2 *1 *3) (-12 (-4 *1 (-555 *3)) (-4 *3 (-13 (-406) (-1181))) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-123))))) 
-(((*1 *2) (-12 (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-1157 (-568))) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-1157 (-568))) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) ((*1 *2) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-867 *3 *4 *5)) (-4 (-857 *3) (-370)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 (-568))) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 (-568))) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117))))) 
-(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1161))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-634 (-3 (|:| -3391 (-1161)) (|:| |bounds| (-634 (-3 (|:| S (-1161)) (|:| P (-953 (-568)))))))))) (-5 *1 (-1165))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -2217 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 *6) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 *6)) (-4 *6 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *6)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 *7) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 *7)) (-4 *7 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *7)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1864 *7) (|:| -4477 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 *8) (|:| -4477 (-763)))) (-634 *6) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 *6)) (-4 *6 (-365)) (-14 *11 (-1 *8 *6)) (-4 *9 (-13 (-842) (-558))) (-14 *10 (-1 *6 *9)) (-5 *2 (-634 (-2 (|:| -1864 *8) (|:| -4477 (-763))))) (-5 *1 (-486 *6 *7 *8 *9 *10 *11)) (-4 *7 (-453)) (-4 *8 (-13 (-432 (-568)) (-558) (-1037 *9) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 *9) (|:| -4477 (-763)))) (-634 *7) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 *7)) (-4 *7 (-365)) (-14 *12 (-1 *9 *7)) (-4 *10 (-13 (-842) (-558))) (-14 *11 (-1 *7 *10)) (-5 *2 (-634 (-2 (|:| -1864 *9) (|:| -4477 (-763))))) (-5 *1 (-486 *7 *8 *9 *10 *11 *12)) (-4 *8 (-453)) (-4 *9 (-13 (-432 (-568)) (-558) (-1037 *10) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *5 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 (-733 *6 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 *6 (-568)))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 (-409 (-734 *6 (-568))))) (-14 *6 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *6 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *6)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1864 (-733 *7 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 *7 (-568)))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 (-409 (-734 *7 (-568))))) (-14 *7 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *7 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *7))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-215)) (-5 *1 (-30)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-420 *4) *4)) (-4 *4 (-558)) (-5 *2 (-420 *4)) (-5 *1 (-421 *4)))) ((*1 *1 *1) (-5 *1 (-926))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-926)))) ((*1 *1 *1) (-5 *1 (-927))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-927)))) ((*1 *2 *3 *2 *4) (-12 (-5 *2 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) (-5 *4 (-409 (-568))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *2 *2) (|partial| -12 (-5 *2 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) (-5 *1 (-1019 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *3 *2 *4) (-12 (-5 *2 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) (-5 *4 (-409 (-568))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *3 *2 *2) (|partial| -12 (-5 *2 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) (-5 *1 (-1020 *3)) (-4 *3 (-1219 (-409 (-568)))))) ((*1 *1 *1) (-12 (-4 *2 (-13 (-840) (-365))) (-5 *1 (-1057 *2 *3)) (-4 *3 (-1219 *2))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *6 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-365)) (-5 *2 (-2 (|:| |ir| (-585 (-409 *6))) (|:| |specpart| (-409 *6)) (|:| |polypart| *6))) (-5 *1 (-578 *5 *6)) (-5 *3 (-409 *6))))) 
+(((*1 *2) (-12 (-5 *2 (-1132 (-1143))) (-5 *1 (-393))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-301)) (-5 *1 (-177 *3))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-850)))) ((*1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-4 *3 (-1047)) (-4 *1 (-677 *3 *4 *5)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)))) ((*1 *1 *2) (-12 (-4 *2 (-1047)) (-4 *1 (-1111 *3 *2 *4 *5)) (-4 *4 (-230 *3 *2)) (-4 *5 (-230 *3 *2))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-1161))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-288 *3))) (-5 *1 (-288 *3)) (-4 *3 (-558)) (-4 *3 (-1195))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-121)) (-5 *1 (-207 *4 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-121)) (-5 *1 (-344 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *7 (-1219 *5)) (-4 *4 (-714 *5 *7)) (-5 *2 (-2 (|:| -2908 (-679 *6)) (|:| |vec| (-1244 *5)))) (-5 *1 (-806 *5 *6 *7 *4 *3)) (-4 *6 (-646 *5)) (-4 *3 (-646 *4))))) 
+(((*1 *1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1161))))) 
+(((*1 *2) (-12 (-5 *2 (-1132 (-1143))) (-5 *1 (-393))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-904)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-950 *4 *5 *6)) (-5 *2 (-420 (-1157 *7))) (-5 *1 (-901 *4 *5 *6 *7)) (-5 *3 (-1157 *7)))) ((*1 *2 *3) (-12 (-4 *4 (-904)) (-4 *5 (-1219 *4)) (-5 *2 (-420 (-1157 *5))) (-5 *1 (-902 *4 *5)) (-5 *3 (-1157 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1244 (-634 (-2 (|:| -2852 *4) (|:| -4357 (-1108)))))) (-4 *4 (-350)) (-5 *2 (-763)) (-5 *1 (-347 *4)))) ((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-352 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917)))) ((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-353 *3 *4)) (-4 *3 (-350)) (-14 *4 (-3 (-1157 *3) (-1244 (-634 (-2 (|:| -2852 *3) (|:| -4357 (-1108))))))))) ((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-354 *3 *4)) (-4 *3 (-350)) (-14 *4 (-917))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)))) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)))) (-5 *1 (-256)))) ((*1 *2 *1 *3 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) ((*1 *2 *1 *3 *3 *4 *4 *4) (-12 (-5 *3 (-568)) (-5 *4 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)))) (-5 *2 (-1249)) (-5 *1 (-1246)))) ((*1 *2 *1) (-12 (-5 *2 (-2 (|:| |theta| (-215)) (|:| |phi| (-215)) (|:| -3225 (-215)) (|:| |scaleX| (-215)) (|:| |scaleY| (-215)) (|:| |scaleZ| (-215)) (|:| |deltaX| (-215)) (|:| |deltaY| (-215)))) (-5 *1 (-1246)))) ((*1 *2 *1 *3 *3 *3 *3 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-775 *5 (-852 *6)))) (-5 *4 (-121)) (-4 *5 (-453)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 (-1131 *5 (-534 (-852 *6)) (-852 *6) (-775 *5 (-852 *6))))) (-5 *1 (-619 *5 *6))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-123)) (-4 *4 (-1047)) (-5 *1 (-704 *4 *2)) (-4 *2 (-637 *4)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-123)) (-5 *1 (-829 *2)) (-4 *2 (-1047))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-887 *3)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-1161))) (-5 *2 (-1249)) (-5 *1 (-1164)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-1161))) (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164)))) ((*1 *2 *3 *4 *1) (-12 (-5 *4 (-634 (-1161))) (-5 *3 (-1161)) (-5 *2 (-1249)) (-5 *1 (-1164))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| *3) (|:| -3145 *4)))) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-763)) (|:| |poli| *2) (|:| |polj| *2))) (-4 *5 (-788)) (-4 *2 (-950 *4 *5 *6)) (-5 *1 (-450 *4 *5 *6 *2)) (-4 *4 (-453)) (-4 *6 (-842))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-329 *3)) (-4 *3 (-842))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-13 (-558) (-842) (-1037 (-568)))) (-4 *5 (-432 *4)) (-5 *2 (-3 (|:| |overq| (-1157 (-409 (-568)))) (|:| |overan| (-1157 (-53))) (|:| -3485 (-121)))) (-5 *1 (-437 *4 *5 *3)) (-4 *3 (-1219 *5))))) 
+(((*1 *2 *3 *2) (-12 (-5 *2 (-1 (-944 (-215)) (-944 (-215)))) (-5 *3 (-634 (-256))) (-5 *1 (-254)))) ((*1 *1 *2) (-12 (-5 *2 (-1 (-944 (-215)) (-944 (-215)))) (-5 *1 (-256)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-492 *5 *6))) (-5 *3 (-492 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-453)) (-5 *2 (-1244 *6)) (-5 *1 (-622 *5 *6))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-763)) (-5 *1 (-446 *3)) (-4 *3 (-1047)))) ((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-446 *3)) (-4 *3 (-1047))))) 
+(((*1 *1 *2 *2) (-12 (-5 *1 (-873 *2)) (-4 *2 (-1195)))) ((*1 *1 *2 *2 *2) (-12 (-5 *1 (-875 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-634 (-944 *3))))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *3 (-1047)) (-4 *1 (-1122 *3)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-634 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-944 *3))) (-4 *1 (-1122 *3)) (-4 *3 (-1047))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-568)) (-5 *4 (-1 (-1249) (-1094))) (-5 *2 (-1249)) (-5 *1 (-102))))) 
+(((*1 *1 *1) (-4 *1 (-651))) ((*1 *1 *1) (-5 *1 (-1108)))) 
+(((*1 *2 *3) (-12 (-5 *2 (-568)) (-5 *1 (-446 *3)) (-4 *3 (-406)) (-4 *3 (-1047))))) 
+(((*1 *1) (-12 (-4 *1 (-427 *2)) (-4 *2 (-370)) (-4 *2 (-1090))))) 
+(((*1 *2 *3) (-12 (-14 *4 (-634 (-1161))) (-14 *5 (-763)) (-5 *2 (-634 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568)))))) (-5 *1 (-515 *4 *5)) (-5 *3 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568)))))))) 
+(((*1 *2 *1 *3) (-12 (-4 *1 (-296)) (-5 *3 (-1161)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-296)) (-5 *2 (-121))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-1047))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 (-634 *6))) (-4 *6 (-950 *3 *5 *4)) (-4 *3 (-13 (-301) (-150))) (-4 *4 (-13 (-842) (-609 (-1161)))) (-4 *5 (-788)) (-5 *1 (-924 *3 *4 *5 *6))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-685 *2)) (-4 *2 (-1219 *3))))) 
+(((*1 *2 *3 *1) (-12 (-5 *3 (-1161)) (-5 *2 (-3 (|:| |fst| (-436)) (|:| -3613 "void"))) (-5 *1 (-1164))))) 
+(((*1 *1 *1 *1 *2) (-12 (-4 *1 (-1061 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 (-2 (|:| |val| (-634 *6)) (|:| -3145 *7)))) (-4 *6 (-1061 *3 *4 *5)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-989 *3 *4 *5 *6 *7)))) ((*1 *2 *2) (-12 (-5 *2 (-634 (-2 (|:| |val| (-634 *6)) (|:| -3145 *7)))) (-4 *6 (-1061 *3 *4 *5)) (-4 *7 (-1066 *3 *4 *5 *6)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-1097 *3 *4 *5 *6 *7))))) 
+(((*1 *2 *3 *2 *3 *2 *3) (-12 (-5 *2 (-958 (-215))) (-5 *3 (-1108)) (-5 *1 (-115))))) 
+(((*1 *2 *3) (-12 (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *2 (-2 (|:| |glbase| (-634 (-242 *4 *5))) (|:| |glval| (-634 (-568))))) (-5 *1 (-622 *4 *5)) (-5 *3 (-634 (-242 *4 *5)))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1059))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) ((*1 *2 *1) (-12 (-4 *1 (-712)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-716)) (-5 *2 (-121))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-5 *2 (-1157 *3)) (-5 *1 (-1170 *3)) (-4 *3 (-365))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-242 *3 *4)) (-14 *3 (-634 (-1161))) (-4 *4 (-1047)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-14 *3 (-634 (-1161))) (-5 *1 (-455 *3 *4 *5)) (-4 *4 (-1047)) (-4 *5 (-230 (-1699 *3) (-763))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-492 *3 *4)) (-14 *3 (-634 (-1161))) (-4 *4 (-1047))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121))))) 
+(((*1 *2 *2 *2 *3) (-12 (-5 *2 (-679 *3)) (-4 *3 (-1047)) (-5 *1 (-680 *3))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-634 *13)) (-4 *13 (-258 *12)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) *2)) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-5 *2 (-763)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14))))) 
+(((*1 *2 *3) (-12 (|has| *2 (-6 (-4523 "*"))) (-4 *5 (-375 *2)) (-4 *6 (-375 *2)) (-4 *2 (-1047)) (-5 *1 (-108 *2 *3 *4 *5 *6)) (-4 *3 (-1219 *2)) (-4 *4 (-677 *2 *5 *6))))) 
+(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-751))))) 
+(((*1 *2 *3 *3 *2) (-12 (-5 *2 (-1141 *4)) (-5 *3 (-568)) (-4 *4 (-1047)) (-5 *1 (-1145 *4)))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1201 *3)) (-4 *3 (-1047)))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1235 *3 *4 *5)) (-4 *3 (-1047)) (-14 *4 (-1161)) (-14 *5 *3))) ((*1 *1 *2 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-1239 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-1161))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-242 (-4289 (QUOTE X) (QUOTE -2928)) *4)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *7 (-230 (-1699 *5) (-763))) (-5 *2 (-634 (-634 (-763)))) (-5 *1 (-119 *4 *5 *6 *7 *8)) (-4 *6 (-324 *4 *7)) (-4 *8 (-117))))) 
+(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1076 *3)) (-4 *3 (-138))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-173 *3)) (-4 *3 (-301))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-99))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-4 *6 (-881 *5)) (-5 *2 (-880 *5 *6 (-634 *6))) (-5 *1 (-882 *5 *6 *4)) (-5 *3 (-634 *6)) (-4 *4 (-609 (-887 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-5 *2 (-634 (-288 *3))) (-5 *1 (-882 *5 *3 *4)) (-4 *3 (-1037 (-1161))) (-4 *3 (-881 *5)) (-4 *4 (-609 (-887 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-5 *2 (-634 (-288 (-953 *3)))) (-5 *1 (-882 *5 *3 *4)) (-4 *3 (-1047)) (-3046 (-4 *3 (-1037 (-1161)))) (-4 *3 (-881 *5)) (-4 *4 (-609 (-887 *5))))) ((*1 *2 *3 *4) (-12 (-4 *5 (-1090)) (-5 *2 (-884 *5 *3)) (-5 *1 (-882 *5 *3 *4)) (-3046 (-4 *3 (-1037 (-1161)))) (-3046 (-4 *3 (-1047))) (-4 *3 (-881 *5)) (-4 *4 (-609 (-887 *5)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-634 (-2 (|:| -2371 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| *8) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 *8))))) (-5 *1 (-924 *5 *6 *7 *8)) (-5 *4 (-763))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-766)) (-5 *1 (-57))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-310 (-381))) (-5 *2 (-310 (-215))) (-5 *1 (-299))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-763)) (-5 *2 (-121)) (-5 *1 (-586 *3)) (-4 *3 (-550))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-842)) (-5 *2 (-1168 (-634 *4))) (-5 *1 (-1167 *4)) (-5 *3 (-634 *4))))) 
+(((*1 *2 *3 *4) (|partial| -12 (-5 *4 (-1161)) (-4 *5 (-609 (-887 (-568)))) (-4 *5 (-881 (-568))) (-4 *5 (-13 (-842) (-1037 (-568)) (-453) (-630 (-568)))) (-5 *2 (-2 (|:| |special| *3) (|:| |integrand| *3))) (-5 *1 (-571 *5 *3)) (-4 *3 (-620)) (-4 *3 (-13 (-27) (-1181) (-432 *5)))))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-763)) (-4 *3 (-13 (-301) (-10 -8 (-15 -3498 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *1 (-508 *3 *4 *5)) (-4 *5 (-411 *3 *4))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-3 (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print"))) (-5 *1 (-328))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-817)) (-5 *1 (-816))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *2 (-1 *5 *5)) (-5 *1 (-799 *4 *5)) (-4 *5 (-13 (-29 *4) (-1181) (-959)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-350)) (-5 *2 (-1244 (-634 (-2 (|:| -2852 *4) (|:| -4357 (-1108)))))) (-5 *1 (-347 *4))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7))))) 
+(((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (|has| *1 (-6 -4521)) (-4 *1 (-227 *3)) (-4 *3 (-1090)))) ((*1 *1 *2 *1) (-12 (|has| *1 (-6 -4521)) (-4 *1 (-227 *2)) (-4 *2 (-1090)))) ((*1 *1 *2 *1) (-12 (-4 *1 (-277 *2)) (-4 *2 (-1195)) (-4 *2 (-1090)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1 (-121) *3)) (-4 *1 (-277 *3)) (-4 *3 (-1195)))) ((*1 *2 *3 *1) (|partial| -12 (-4 *1 (-605 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1090)))) ((*1 *1 *2 *1 *3) (-12 (-5 *2 (-1 (-121) *4)) (-5 *3 (-568)) (-4 *4 (-1090)) (-5 *1 (-727 *4)))) ((*1 *1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *1 (-727 *2)) (-4 *2 (-1090)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-1125 *3 *4)) (-4 *3 (-13 (-1090) (-39))) (-4 *4 (-13 (-1090) (-39))) (-5 *1 (-1126 *3 *4))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-2 (|:| |xinit| (-215)) (|:| |xend| (-215)) (|:| |fn| (-1244 (-310 (-215)))) (|:| |yinit| (-634 (-215))) (|:| |intvals| (-634 (-215))) (|:| |g| (-310 (-215))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-2 (|:| |stiffness| (-381)) (|:| |stability| (-381)) (|:| |expense| (-381)) (|:| |accuracy| (-381)) (|:| |intermediateResults| (-381)))) (-5 *1 (-798))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1161)) (-5 *5 (-1084 (-215))) (-5 *2 (-927)) (-5 *1 (-925 *3)) (-4 *3 (-609 (-541))))) ((*1 *2 *3 *3 *4 *5) (-12 (-5 *4 (-1161)) (-5 *5 (-1084 (-215))) (-5 *2 (-927)) (-5 *1 (-925 *3)) (-4 *3 (-609 (-541))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-926)))) ((*1 *1 *2 *2 *2 *2 *3 *3 *3 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-926)))) ((*1 *1 *2 *2 *2 *2 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-926)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1084 (-215))) (-5 *1 (-927)))) ((*1 *1 *2 *2 *3 *3 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) ((*1 *1 *2 *2 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) ((*1 *1 *2 *3 *3) (-12 (-5 *2 (-634 (-1 (-215) (-215)))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-634 (-1 (-215) (-215)))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) ((*1 *1 *2 *3 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927))))) 
+(((*1 *1 *1) (-4 *1 (-620))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181)))))) 
+(((*1 *1 *1 *1 *1) (-4 *1 (-550)))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-887 *4)) (-5 *3 (-1 (-121) *5)) (-4 *4 (-1090)) (-4 *5 (-1195)) (-5 *1 (-885 *4 *5)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-887 *4)) (-5 *3 (-634 (-1 (-121) *5))) (-4 *4 (-1090)) (-4 *5 (-1195)) (-5 *1 (-885 *4 *5)))) ((*1 *2 *2 *3 *4) (-12 (-5 *2 (-887 *5)) (-5 *3 (-634 (-1161))) (-5 *4 (-1 (-121) (-634 *6))) (-4 *5 (-1090)) (-4 *6 (-1195)) (-5 *1 (-885 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *5)) (-4 *5 (-1195)) (-4 *4 (-842)) (-5 *1 (-938 *4 *2 *5)) (-4 *2 (-432 *4)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-634 (-1 (-121) *5))) (-4 *5 (-1195)) (-4 *4 (-842)) (-5 *1 (-938 *4 *2 *5)) (-4 *2 (-432 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-1 (-121) *5)) (-4 *5 (-1195)) (-5 *2 (-310 (-568))) (-5 *1 (-939 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-634 (-1 (-121) *5))) (-4 *5 (-1195)) (-5 *2 (-310 (-568))) (-5 *1 (-939 *5)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-1 (-121) (-634 *6))) (-4 *6 (-13 (-432 *5) (-881 *4) (-609 (-887 *4)))) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-5 *1 (-1069 *4 *5 *6))))) 
+(((*1 *1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *2 *3 *4 *2 *5 *6) (-12 (-5 *5 (-2 (|:| |done| (-634 *11)) (|:| |todo| (-634 (-2 (|:| |val| *3) (|:| -3145 *11)))))) (-5 *6 (-763)) (-5 *2 (-634 (-2 (|:| |val| (-634 *10)) (|:| -3145 *11)))) (-5 *3 (-634 *10)) (-5 *4 (-634 *11)) (-4 *10 (-1061 *7 *8 *9)) (-4 *11 (-1066 *7 *8 *9 *10)) (-4 *7 (-453)) (-4 *8 (-788)) (-4 *9 (-842)) (-5 *1 (-1064 *7 *8 *9 *10 *11)))) ((*1 *2 *3 *4 *2 *5 *6) (-12 (-5 *5 (-2 (|:| |done| (-634 *11)) (|:| |todo| (-634 (-2 (|:| |val| *3) (|:| -3145 *11)))))) (-5 *6 (-763)) (-5 *2 (-634 (-2 (|:| |val| (-634 *10)) (|:| -3145 *11)))) (-5 *3 (-634 *10)) (-5 *4 (-634 *11)) (-4 *10 (-1061 *7 *8 *9)) (-4 *11 (-1099 *7 *8 *9 *10)) (-4 *7 (-453)) (-4 *8 (-788)) (-4 *9 (-842)) (-5 *1 (-1130 *7 *8 *9 *10 *11))))) 
+(((*1 *1 *1 *1) (-12 (-5 *1 (-777 *2)) (-4 *2 (-1047))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927))))) 
+(((*1 *1 *1) (-4 *1 (-620))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-621 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002) (-1181)))))) 
+(((*1 *1) (-12 (-4 *1 (-470 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) ((*1 *1) (-5 *1 (-541))) ((*1 *1) (-4 *1 (-712))) ((*1 *1) (-4 *1 (-716))) ((*1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) ((*1 *1) (-12 (-5 *1 (-888 *2)) (-4 *2 (-842))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1157 (-409 (-953 *3)))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
+(((*1 *2 *3 *3) (-12 (-4 *3 (-301)) (-4 *3 (-172)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-2 (|:| -4409 *3) (|:| -2607 *3))) (-5 *1 (-678 *3 *4 *5 *6)) (-4 *6 (-677 *3 *4 *5)))) ((*1 *2 *3 *3) (-12 (-5 *2 (-2 (|:| -4409 *3) (|:| -2607 *3))) (-5 *1 (-689 *3)) (-4 *3 (-301))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-978 *4 *5 *6 *2))))) 
+(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090))))) 
+(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *5 (-634 *4)) (-4 *4 (-365)) (-5 *2 (-1244 *4)) (-5 *1 (-809 *4 *3)) (-4 *3 (-646 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-950 *5 *7 (-852 *6))) (-4 *7 (-230 (-1699 *6) (-763))) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-5 *2 (-634 *8)) (-5 *1 (-963 *5 *6 *3 *7 *8)) (-4 *8 (-971 *5))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-420 *5)) (-4 *5 (-558)) (-5 *2 (-2 (|:| -3483 (-763)) (|:| -2350 *5) (|:| |radicand| (-634 *5)))) (-5 *1 (-316 *5)) (-5 *4 (-763)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1002)) (-5 *2 (-568))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2852 *4) (|:| -2185 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-950 *4 *5 *6)) (-5 *2 (-634 (-634 *7))) (-5 *1 (-449 *4 *5 *6 *7)) (-5 *3 (-634 *7)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-950 *5 *6 *7)) (-5 *2 (-634 (-634 *8))) (-5 *1 (-449 *5 *6 *7 *8)) (-5 *3 (-634 *8)))) ((*1 *2 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-950 *4 *5 *6)) (-5 *2 (-634 (-634 *7))) (-5 *1 (-449 *4 *5 *6 *7)) (-5 *3 (-634 *7)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-121)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-950 *5 *6 *7)) (-5 *2 (-634 (-634 *8))) (-5 *1 (-449 *5 *6 *7 *8)) (-5 *3 (-634 *8))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-5 *1 (-1170 *2)) (-4 *2 (-365))))) 
+(((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-634 *7)) (-5 *4 (-1 *7 (-763) (-763) *8)) (-5 *5 (-1244 *9)) (-5 *6 (-634 (-763))) (-4 *7 (-13 (-558) (-453))) (-4 *8 (-324 *7 (-763))) (-4 *9 (-324 (-409 *7) (-763))) (-5 *2 (-679 (-1157 *7))) (-5 *1 (-345 *7 *8 *9)))) ((*1 *2 *3 *4 *5 *6 *6) (-12 (-5 *3 (-634 *7)) (-5 *4 (-1 *7 (-763) (-763) *8)) (-5 *5 (-1244 *9)) (-5 *6 (-763)) (-4 *7 (-13 (-558) (-453))) (-4 *8 (-324 *7 *6)) (-4 *9 (-324 (-409 *7) *6)) (-5 *2 (-1141 (-679 (-1157 *7)))) (-5 *1 (-345 *7 *8 *9)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-634 *7)) (-5 *4 (-1 *7 (-763) (-763) *8)) (-5 *5 (-1244 *8)) (-5 *6 (-634 (-763))) (-4 *7 (-13 (-558) (-453))) (-4 *8 (-52 *7 (-763))) (-5 *2 (-679 (-1157 *7))) (-5 *1 (-346 *7 *8)))) ((*1 *2 *3 *4 *5 *6 *6) (-12 (-5 *3 (-634 *7)) (-5 *4 (-1 *7 (-763) (-763) *8)) (-5 *5 (-1244 *8)) (-5 *6 (-763)) (-4 *7 (-13 (-558) (-453))) (-4 *8 (-52 *7 *6)) (-5 *2 (-1141 (-679 (-1157 *7)))) (-5 *1 (-346 *7 *8))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-848 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-172))))) 
+(((*1 *2 *1) (-12 (-14 *3 (-634 (-1161))) (-4 *4 (-172)) (-14 *6 (-1 (-121) (-2 (|:| -4357 *5) (|:| -3483 *2)) (-2 (|:| -4357 *5) (|:| -3483 *2)))) (-4 *2 (-230 (-1699 *3) (-763))) (-5 *1 (-463 *3 *4 *5 *2 *6 *7)) (-4 *5 (-842)) (-4 *7 (-950 *4 *2 (-852 *3)))))) 
+(((*1 *1 *1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-763)) (-4 *5 (-172)))) ((*1 *1 *1 *2 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 *2) (-14 *4 (-763)) (-4 *5 (-172)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-514 (-409 (-568)) (-232 *5 (-763)) (-852 *4) (-242 *4 (-409 (-568))))) (-5 *3 (-634 (-852 *4))) (-14 *4 (-634 (-1161))) (-14 *5 (-763)) (-5 *1 (-515 *4 *5))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-121))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1047)) (-5 *1 (-318 *4 *5 *2 *6)) (-4 *6 (-950 *2 *4 *5))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *3 (-121)) (-5 *1 (-114)))) ((*1 *2 *2) (-12 (-5 *2 (-917)) (|has| *1 (-6 -4512)) (-4 *1 (-406)))) ((*1 *2) (-12 (-4 *1 (-406)) (-5 *2 (-917))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-301)) (-5 *1 (-912 *3 *4 *5 *2)) (-4 *2 (-950 *5 *3 *4)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1157 *6)) (-4 *6 (-950 *5 *3 *4)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-301)) (-5 *1 (-912 *3 *4 *5 *6)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *6 *4 *5)) (-5 *1 (-912 *4 *5 *6 *2)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-301))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-910 *2)) (-4 *2 (-301))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-453))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-53)) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 *6) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 *6)) (-4 *6 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *6)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 *7) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 *7)) (-4 *7 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *7)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-568))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1866 *7) (|:| -1844 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 *8) (|:| -1844 (-763)))) (-634 *6) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 *6)) (-4 *6 (-365)) (-14 *11 (-1 *8 *6)) (-4 *9 (-13 (-842) (-558))) (-14 *10 (-1 *6 *9)) (-5 *2 (-634 (-2 (|:| -1866 *8) (|:| -1844 (-763))))) (-5 *1 (-486 *6 *7 *8 *9 *10 *11)) (-4 *7 (-453)) (-4 *8 (-13 (-432 (-568)) (-558) (-1037 *9) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 *9) (|:| -1844 (-763)))) (-634 *7) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 *7)) (-4 *7 (-365)) (-14 *12 (-1 *9 *7)) (-4 *10 (-13 (-842) (-558))) (-14 *11 (-1 *7 *10)) (-5 *2 (-634 (-2 (|:| -1866 *9) (|:| -1844 (-763))))) (-5 *1 (-486 *7 *8 *9 *10 *11 *12)) (-4 *8 (-453)) (-4 *9 (-13 (-432 (-568)) (-558) (-1037 *10) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *5 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 (-733 *6 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 *6 (-568)))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *3 (-634 (-409 (-734 *6 (-568))))) (-14 *6 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *6 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *6)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *4 (-634 (-1 (-634 (-2 (|:| -1866 (-733 *7 (-568))) (|:| -1844 (-763)))) (-634 (-409 (-734 *7 (-568)))) (-634 (-465))))) (-5 *5 (-634 (-1161))) (-5 *6 (-634 (-465))) (-5 *3 (-634 (-409 (-734 *7 (-568))))) (-14 *7 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *7 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *7))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3))))) 
+(((*1 *2 *3 *4 *5 *5 *6) (-12 (-5 *5 (-607 *4)) (-5 *6 (-1161)) (-4 *4 (-13 (-432 *7) (-27) (-1181))) (-4 *7 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2588 (-634 *4)))) (-5 *1 (-570 *7 *4 *3)) (-4 *3 (-646 *4)) (-4 *3 (-1090))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-4 *1 (-258 *3)))) ((*1 *1 *2) (-12 (-4 *1 (-258 *2)) (-4 *2 (-1090)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-258 *2)) (-4 *2 (-1090)))) ((*1 *1 *2) (-12 (-5 *1 (-1182 *2)) (-4 *2 (-1090)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-1182 *3)))) ((*1 *1 *2 *3) (-12 (-5 *3 (-634 (-1182 *2))) (-5 *1 (-1182 *2)) (-4 *2 (-1090))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-643 (-409 *6))) (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-409 *6))) (-5 *1 (-807 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-643 (-409 *7))) (-5 *4 (-1 (-634 *6) *7)) (-5 *5 (-1 (-420 *7) *7)) (-4 *6 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *7 (-1219 *6)) (-5 *2 (-634 (-409 *7))) (-5 *1 (-807 *6 *7)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-644 *6 (-409 *6))) (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-409 *6))) (-5 *1 (-807 *5 *6)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-644 *7 (-409 *7))) (-5 *4 (-1 (-634 *6) *7)) (-5 *5 (-1 (-420 *7) *7)) (-4 *6 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *7 (-1219 *6)) (-5 *2 (-634 (-409 *7))) (-5 *1 (-807 *6 *7)))) ((*1 *2 *3) (-12 (-5 *3 (-643 (-409 *5))) (-4 *5 (-1219 *4)) (-4 *4 (-27)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-634 (-409 *5))) (-5 *1 (-807 *4 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-643 (-409 *6))) (-5 *4 (-1 (-420 *6) *6)) (-4 *6 (-1219 *5)) (-4 *5 (-27)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-634 (-409 *6))) (-5 *1 (-807 *5 *6)))) ((*1 *2 *3) (-12 (-5 *3 (-644 *5 (-409 *5))) (-4 *5 (-1219 *4)) (-4 *4 (-27)) (-4 *4 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-634 (-409 *5))) (-5 *1 (-807 *4 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-644 *6 (-409 *6))) (-5 *4 (-1 (-420 *6) *6)) (-4 *6 (-1219 *5)) (-4 *5 (-27)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-634 (-409 *6))) (-5 *1 (-807 *5 *6))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-2 (|:| |goodPols| (-634 *7)) (|:| |badPols| (-634 *7)))) (-5 *1 (-978 *4 *5 *6 *7)) (-5 *3 (-634 *7))))) 
 (((*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-943)) (-5 *3 (-568))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-568)) (|has| *1 (-6 -4512)) (-4 *1 (-406)) (-5 *2 (-917))))) 
+(((*1 *2 *2) (|partial| -12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1093 *2 *3 *4 *5 *6)) (-4 *2 (-1090)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-183)) (-5 *3 (-568)))) ((*1 *2 *3 *2) (-12 (-5 *3 (-763)) (-5 *1 (-778 *2)) (-4 *2 (-172)))) ((*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-943)) (-5 *3 (-568))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-1244 *1)) (-4 *1 (-369 *4)) (-4 *4 (-172)) (-5 *2 (-679 *4)))) ((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-679 *4)) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4)))) ((*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-5 *2 (-679 *3))))) 
+(((*1 *2 *3 *4 *2 *3 *2 *3) (-12 (-5 *2 (-958 (-215))) (-5 *3 (-1108)) (-5 *4 (-215)) (-5 *1 (-115))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-99)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-99))))) 
+(((*1 *1 *1 *1) (-5 *1 (-850)))) 
+(((*1 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) ((*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246))))) 
+(((*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *3)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-4 *3 (-166 *6)) (-4 (-953 *6) (-881 *5)) (-4 *6 (-13 (-881 *5) (-172))) (-5 *1 (-176 *5 *6 *3)))) ((*1 *2 *1 *3 *2) (-12 (-5 *2 (-884 *4 *1)) (-5 *3 (-887 *4)) (-4 *1 (-881 *4)) (-4 *4 (-1090)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *6)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-4 *6 (-13 (-1090) (-1037 *3))) (-4 *3 (-881 *5)) (-5 *1 (-932 *5 *3 *6)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *3)) (-4 *5 (-1090)) (-4 *3 (-13 (-432 *6) (-609 *4) (-881 *5) (-1037 (-607 $)))) (-5 *4 (-887 *5)) (-4 *6 (-13 (-558) (-842) (-881 *5))) (-5 *1 (-933 *5 *6 *3)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 (-568) *3)) (-5 *4 (-887 (-568))) (-4 *3 (-550)) (-5 *1 (-934 *3)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *6)) (-5 *3 (-607 *6)) (-4 *5 (-1090)) (-4 *6 (-13 (-842) (-1037 (-607 $)) (-609 *4) (-881 *5))) (-5 *4 (-887 *5)) (-5 *1 (-935 *5 *6)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-880 *5 *6 *3)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-4 *6 (-881 *5)) (-4 *3 (-658 *6)) (-5 *1 (-936 *5 *6 *3)))) ((*1 *2 *3 *4 *2 *5) (-12 (-5 *5 (-1 (-884 *6 *3) *8 (-887 *6) (-884 *6 *3))) (-4 *8 (-842)) (-5 *2 (-884 *6 *3)) (-5 *4 (-887 *6)) (-4 *6 (-1090)) (-4 *3 (-13 (-950 *9 *7 *8) (-609 *4))) (-4 *7 (-788)) (-4 *9 (-13 (-1047) (-842) (-881 *6))) (-5 *1 (-937 *6 *7 *8 *9 *3)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *3)) (-4 *5 (-1090)) (-4 *3 (-13 (-950 *8 *6 *7) (-609 *4))) (-5 *4 (-887 *5)) (-4 *7 (-881 *5)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *8 (-13 (-1047) (-842) (-881 *5))) (-5 *1 (-937 *5 *6 *7 *8 *3)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 *3)) (-4 *5 (-1090)) (-4 *3 (-993 *6)) (-4 *6 (-13 (-558) (-881 *5) (-609 *4))) (-5 *4 (-887 *5)) (-5 *1 (-940 *5 *6 *3)))) ((*1 *2 *3 *4 *2) (-12 (-5 *2 (-884 *5 (-1161))) (-5 *3 (-1161)) (-5 *4 (-887 *5)) (-4 *5 (-1090)) (-5 *1 (-941 *5)))) ((*1 *2 *3 *4 *5 *2 *6) (-12 (-5 *4 (-634 (-887 *7))) (-5 *5 (-1 *9 (-634 *9))) (-5 *6 (-1 (-884 *7 *9) *9 (-887 *7) (-884 *7 *9))) (-4 *7 (-1090)) (-4 *9 (-13 (-1047) (-609 (-887 *7)) (-1037 *8))) (-5 *2 (-884 *7 *9)) (-5 *3 (-634 *9)) (-4 *8 (-13 (-1047) (-842))) (-5 *1 (-942 *7 *8 *9))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-1093 *2 *3 *4 *5 *6)) (-4 *2 (-1090)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-150))) (-5 *1 (-542 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-4 *4 (-1219 *3)) (-4 *5 (-714 *3 *4)) (-5 *1 (-546 *3 *4 *5 *2)) (-4 *2 (-1234 *5)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-5 *1 (-547 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-13 (-558) (-150))) (-5 *1 (-1137 *3))))) 
+(((*1 *2 *3 *3 *1) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-3 *3 (-634 *1))) (-4 *1 (-1066 *4 *5 *6 *3))))) 
 (((*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-679 (-409 *4)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1143)) (-5 *1 (-299))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-405 *3)) (-4 *3 (-406)))) ((*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-405 *3)) (-4 *3 (-406)))) ((*1 *2 *2) (-12 (-5 *2 (-917)) (|has| *1 (-6 -4512)) (-4 *1 (-406)))) ((*1 *2) (-12 (-4 *1 (-406)) (-5 *2 (-917)))) ((*1 *2 *1) (-12 (-4 *1 (-863 *3)) (-5 *2 (-1141 (-568)))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
+(((*1 *2 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-558)) (-5 *1 (-970 *4 *2)) (-4 *2 (-1219 *4))))) 
 (((*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *3 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-450 *4 *3 *5 *6)) (-4 *6 (-950 *4 *3 *5))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-369 *2)) (-4 *2 (-172))))) 
+(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-409 (-568))) (-5 *1 (-215)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-409 (-568))) (-5 *1 (-215)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-409 (-568))) (-5 *1 (-381)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-5 *2 (-409 (-568))) (-5 *1 (-381))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-350)) (-5 *2 (-420 (-1157 (-1157 *4)))) (-5 *1 (-1194 *4)) (-5 *3 (-1157 (-1157 *4)))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-634 (-953 *3))) (-4 *3 (-453)) (-5 *1 (-362 *3 *4)) (-14 *4 (-634 (-1161))))) ((*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-451 *3 *4 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-1143)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-451 *4 *5 *6 *7)))) ((*1 *2 *2 *3 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-1143)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-451 *4 *5 *6 *7)))) ((*1 *1 *1) (-12 (-4 *2 (-365)) (-4 *3 (-788)) (-4 *4 (-842)) (-5 *1 (-514 *2 *3 *4 *5)) (-4 *5 (-950 *2 *3 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-634 *7)) (-4 *7 (-950 *3 *5 *6)) (-4 *3 (-365)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-560 *3 *4 *5 *6 *7)) (-14 *4 (-634 (-1161))))) ((*1 *2 *2) (-12 (-5 *2 (-634 (-775 *3 (-852 *4)))) (-4 *3 (-453)) (-14 *4 (-634 (-1161))) (-5 *1 (-619 *3 *4))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-453)) (-4 *4 (-842)) (-5 *1 (-577 *4 *2)) (-4 *2 (-279)) (-4 *2 (-432 *4))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-558)) (-4 *3 (-172)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-678 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5))))) 
+(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-1157 (-953 *4))) (-5 *1 (-418 *3 *4)) (-4 *3 (-419 *4)))) ((*1 *2) (-12 (-4 *1 (-419 *3)) (-4 *3 (-172)) (-4 *3 (-365)) (-5 *2 (-1157 (-953 *3))))) ((*1 *2) (-12 (-5 *2 (-1157 (-409 (-953 *3)))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
+(((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) ((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-472)))) ((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927))))) 
+(((*1 *2 *1 *2) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) *2)) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-763))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-634 (-1216 *5 *4))) (-5 *1 (-1104 *4 *5)) (-5 *3 (-1216 *5 *4))))) 
+(((*1 *1 *1) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-1231 *2)) (-4 *2 (-1195))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) ((*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-5 *2 (-1157 *1)) (-4 *1 (-327 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-5 *2 (-1157 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-372 *3 *2)) (-4 *3 (-172)) (-4 *3 (-365)) (-4 *2 (-1219 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-350)) (-5 *2 (-1157 *4)) (-5 *1 (-532 *4))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-568)) (-4 *2 (-432 *3)) (-5 *1 (-36 *3 *2)) (-4 *3 (-1037 *4)) (-4 *3 (-13 (-842) (-558)))))) 
+(((*1 *2 *3 *1) (-12 (-4 *1 (-977 *4 *5 *3 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-4 *6 (-1061 *4 *5 *3)) (-5 *2 (-121))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-860)) (-5 *1 (-855 *3)) (-14 *3 *2)))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-1037 (-568))) (-4 *3 (-13 (-842) (-558))) (-5 *1 (-36 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-1157 *4)) (-5 *1 (-165 *3 *4)) (-4 *3 (-166 *4)))) ((*1 *1 *1) (-12 (-4 *1 (-1047)) (-4 *1 (-296)))) ((*1 *2) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-5 *2 (-1157 *3)))) ((*1 *2) (-12 (-4 *1 (-714 *3 *2)) (-4 *3 (-172)) (-4 *2 (-1219 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-858)))) ((*1 *2) (-12 (-5 *2 (-1157 *1)) (-4 *1 (-858)))) ((*1 *2 *1) (-12 (-4 *1 (-1063 *3 *2)) (-4 *3 (-13 (-840) (-365))) (-4 *2 (-1219 *3))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *6)) (-5 *4 (-634 (-1161))) (-4 *6 (-365)) (-5 *2 (-634 (-288 (-953 *6)))) (-5 *1 (-543 *5 *6 *7)) (-4 *5 (-453)) (-4 *7 (-13 (-365) (-840)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 *9)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-763)) (-5 *1 (-1064 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 *9)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1099 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-763)) (-5 *1 (-1130 *5 *6 *7 *8 *9))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1092 (-1092 *3))) (-5 *1 (-899 *3)) (-4 *3 (-1090))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-2 (|:| |mval| (-679 *3)) (|:| |invmval| (-679 *3)) (|:| |genIdeal| (-514 *3 *4 *5 *6)))) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5))))) 
+(((*1 *2 *3) (-12 (-4 *1 (-340 *4 *3 *5)) (-4 *4 (-1199)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 (-409 *3))) (-5 *2 (-121)))) ((*1 *2 *3) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121))))) 
 (((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-121)) (-5 *1 (-214 *4 *5)) (-4 *5 (-13 (-1181) (-29 *4)))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-246 *2 *3 *4 *5)) (-4 *2 (-1047)) (-4 *3 (-842)) (-4 *4 (-262 *3)) (-4 *5 (-788))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-1108)) (-5 *1 (-113))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-850)) (-5 *1 (-1141 *3)) (-4 *3 (-1090)) (-4 *3 (-1195))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-1215 *3 *2)) (-4 *2 (-1219 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| -3651 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -3581 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (|:| -4085 (-2 (|:| |endPointContinuity| (-3 (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (-3 (|:| |str| (-1141 (-215))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| -3581 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (-5 *1 (-563)))) ((*1 *2 *1) (-12 (-4 *1 (-601 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1195)) (-5 *2 (-634 *4))))) 
 (((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-381))) (-5 *1 (-1039))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-607 *2)) (-4 *2 (-13 (-27) (-1181) (-432 *4))) (-4 *4 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *4 *2))))) 
+(((*1 *2 *3) (-12 (-4 *1 (-890)) (-5 *3 (-2 (|:| |pde| (-634 (-310 (-215)))) (|:| |constraints| (-634 (-2 (|:| |start| (-215)) (|:| |finish| (-215)) (|:| |grid| (-763)) (|:| |boundaryType| (-568)) (|:| |dStart| (-679 (-215))) (|:| |dFinish| (-679 (-215)))))) (|:| |f| (-634 (-634 (-310 (-215))))) (|:| |st| (-1143)) (|:| |tol| (-215)))) (-5 *2 (-1035))))) 
+(((*1 *2 *3 *4 *4) (-12 (-5 *4 (-763)) (-4 *5 (-350)) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-2 (|:| -2588 (-679 *6)) (|:| |basisDen| *6) (|:| |basisInv| (-679 *6))))) (-5 *1 (-507 *5 *6 *7)) (-5 *3 (-2 (|:| -2588 (-679 *6)) (|:| |basisDen| *6) (|:| |basisInv| (-679 *6)))) (-4 *7 (-1219 *6))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-142)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-1129)) (-5 *2 (-147))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1044 *4 *5)) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-14 *5 (-634 (-1161))) (-5 *2 (-634 (-634 (-1023 (-409 *4))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *6 (-634 (-1161))))) ((*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *5))))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *5))))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-634 (-1023 (-409 *4))))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161)))))) 
 (((*1 *2 *2 *3) (|partial| -12 (-5 *3 (-763)) (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-13 (-558) (-150))) (-5 *1 (-542 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-4 *4 (-1219 *3)) (-4 *5 (-714 *3 *4)) (-5 *1 (-546 *3 *4 *5 *2)) (-4 *2 (-1234 *5)))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-365) (-370) (-609 (-568)))) (-5 *1 (-547 *3 *2)) (-4 *2 (-1234 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-13 (-558) (-150))) (-5 *1 (-1137 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-634 *5))) (-4 *5 (-324 *4 *6)) (-4 *6 (-230 *7 *2)) (-14 *7 *2) (-4 *4 (-1047)) (-5 *2 (-763)) (-5 *1 (-772 *4 *5 *6 *7)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-230 *7 *2)) (-14 *7 *2) (-5 *2 (-763)) (-5 *1 (-929 *5 *3 *6 *7 *4)) (-4 *3 (-324 *5 *6)) (-4 *4 (-971 *5)))) ((*1 *2 *3 *4 *5) (-12 (-5 *5 (-568)) (-4 *6 (-365)) (-4 *7 (-230 *8 *2)) (-14 *8 *2) (-5 *2 (-763)) (-5 *1 (-929 *6 *3 *7 *8 *4)) (-4 *3 (-324 *6 *7)) (-4 *4 (-971 *6))))) 
+(((*1 *2 *2 *2) (|partial| -12 (-4 *3 (-365)) (-5 *1 (-891 *2 *3)) (-4 *2 (-1219 *3))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 *4)) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1157 (-953 *6))) (-4 *6 (-558)) (-4 *2 (-950 (-409 (-953 *6)) *5 *4)) (-5 *1 (-722 *5 *4 *6 *2)) (-4 *5 (-788)) (-4 *4 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $)))))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-301)) (-5 *2 (-763))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-568)) (-5 *2 (-828 (-215))) (-5 *1 (-217)) (-5 *4 (-215))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-514 (-409 (-568)) (-232 *4 (-763)) (-852 *3) (-242 *3 (-409 (-568))))) (-14 *3 (-634 (-1161))) (-14 *4 (-763)) (-5 *1 (-515 *3 *4))))) 
+(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2852 *4) (|:| -2185 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568))))) 
+(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
 (((*1 *2 *2 *2 *2 *2) (-12 (-4 *2 (-13 (-365) (-10 -8 (-15 ** ($ $ (-409 (-568))))))) (-5 *1 (-1116 *3 *2)) (-4 *3 (-1219 *2))))) 
+(((*1 *2 *2 *3) (-12 (-5 *2 (-1157 *7)) (-5 *3 (-568)) (-4 *7 (-950 *6 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-5 *1 (-318 *4 *5 *6 *7))))) 
+(((*1 *2 *3 *4 *3 *5) (-12 (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *8 (-230 (-1699 *7) (-763))) (-4 *9 (-641 *6)) (-5 *2 (-2 (|:| |fnc| *3) (|:| |crv| *3) (|:| |chart| (-634 (-568))))) (-5 *1 (-654 *6 *7 *3 *8 *4 *9 *10)) (-5 *5 (-568)) (-4 *3 (-950 *6 *8 (-852 *7))) (-4 *4 (-971 *6)) (-4 *10 (-920 *6 *9))))) 
+(((*1 *2 *2) (|partial| -12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3))))) 
+(((*1 *2 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1236 *3 *2)) (-4 *2 (-1234 *3))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-5 *2 (-634 *8)) (-5 *1 (-963 *4 *5 *6 *7 *8)) (-4 *8 (-971 *4))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-365)) (-4 *4 (-558)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| -2848 (-615 *4 *5)) (|:| -4367 (-409 *5)))) (-5 *1 (-615 *4 *5)) (-5 *3 (-409 *5)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-1149 *3 *4))) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-453)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| |primePart| *1) (|:| |commonPart| *1))) (-4 *1 (-1219 *3))))) 
+(((*1 *2 *3 *1) (-12 (-4 *4 (-13 (-840) (-365))) (-5 *2 (-121)) (-5 *1 (-1057 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-679 (-310 (-215)))) (-5 *2 (-2 (|:| |stiffnessFactor| (-381)) (|:| |stabilityFactor| (-381)))) (-5 *1 (-197))))) 
+(((*1 *2) (-12 (-4 *3 (-370)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *9)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2) (-12 (-5 *2 (-634 (-922 *3))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-634 (-921 *3))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
+(((*1 *2 *2) (|partial| -12 (-5 *2 (-409 *4)) (-4 *4 (-1219 *3)) (-4 *3 (-13 (-365) (-150) (-1037 (-568)))) (-5 *1 (-572 *3 *4))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-365)) (-4 *4 (-558)) (-4 *5 (-1219 *4)) (-5 *2 (-2 (|:| -3949 (-615 *4 *5)) (|:| -3358 (-409 *5)))) (-5 *1 (-615 *4 *5)) (-5 *3 (-409 *5)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-1149 *3 *4))) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-453)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| |primePart| *1) (|:| |commonPart| *1))) (-4 *1 (-1219 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)) (-5 *2 (-1157 *3))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *6)) (-5 *4 (-1 *6 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-1090)) (-5 *1 (-670 *5 *6 *2))))) 
+(((*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1039))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-603 *2)) (-4 *2 (-1090)))) ((*1 *1 *1) (-5 *1 (-623)))) 
+(((*1 *1 *1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *2 (-558))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-2 (|:| -2371 (-763)) (|:| |eqns| (-634 (-2 (|:| |det| *7) (|:| |rows| (-634 (-568))) (|:| |cols| (-634 (-568)))))) (|:| |fgb| (-634 *7))))) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-763)) (-5 *1 (-924 *4 *5 *6 *7))))) 
 (((*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6))))) 
+(((*1 *2 *3 *1) (-12 (-4 *1 (-977 *4 *5 *6 *3)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-5 *2 (-2 (|:| |num| *3) (|:| |den| *4)))))) 
+(((*1 *1 *1) (-4 *1 (-40))) ((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002))))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1234 *3)) (-5 *1 (-274 *3 *4 *2)) (-4 *2 (-1205 *3 *4)))) ((*1 *2 *2) (-12 (-4 *3 (-43 (-409 (-568)))) (-4 *4 (-1203 *3)) (-5 *1 (-275 *3 *4 *2 *5)) (-4 *2 (-1226 *3 *4)) (-4 *5 (-984 *4)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1146 *3)))) ((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-43 (-409 (-568)))) (-5 *1 (-1147 *3))))) 
+(((*1 *2 *1 *1 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-842)) (-5 *2 (-2 (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-950 *4 *5 *3)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-1047)) (-5 *2 (-2 (|:| -4409 *1) (|:| -2607 *1))) (-4 *1 (-1219 *3))))) 
+(((*1 *1 *2) (-12 (-5 *2 (-1257 (-1161) *3)) (-4 *3 (-1047)) (-5 *1 (-1264 *3)))) ((*1 *1 *2) (-12 (-5 *2 (-1257 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *1 (-1266 *3 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-555 *3)) (-4 *3 (-13 (-406) (-1181))) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-840)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1063 *4 *3)) (-4 *4 (-13 (-840) (-365))) (-4 *3 (-1219 *4)) (-5 *2 (-121))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *2 *10)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-117)) (-4 *2 (-235 *9))))) 
 (((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-358 *3)) (-4 *3 (-350))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-636 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-166 *3)) (-4 *3 (-172)) (-4 *3 (-1056)) (-4 *3 (-1181)) (-5 *2 (-2 (|:| |r| *3) (|:| |phi| *3)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-842) (-1037 (-568)) (-453) (-630 (-568)))) (-5 *2 (-2 (|:| -2358 *3) (|:| |nconst| *3))) (-5 *1 (-571 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5)))))) 
+(((*1 *2 *1 *1) (-12 (-4 *1 (-1087 *3)) (-4 *3 (-1090)) (-5 *2 (-121))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-953 (-568))) (-5 *2 (-328)) (-5 *1 (-330))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-121)) (-5 *2 (-1143)) (-5 *1 (-57))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-121))))) 
+(((*1 *2 *3 *4 *5 *5) (-12 (-5 *5 (-763)) (-4 *6 (-1090)) (-4 *7 (-895 *6)) (-5 *2 (-679 *7)) (-5 *1 (-681 *6 *7 *3 *4)) (-4 *3 (-375 *7)) (-4 *4 (-13 (-375 *6) (-10 -7 (-6 -4521))))))) 
+(((*1 *2 *1) (|partial| -12 (-5 *2 (-1157 *1)) (-4 *1 (-1012))))) 
+(((*1 *2 *3 *3 *3 *3) (-12 (-5 *3 (-568)) (-5 *2 (-121)) (-5 *1 (-491))))) 
 (((*1 *2 *3 *4 *4 *4 *4) (-12 (-5 *4 (-215)) (-5 *2 (-2 (|:| |brans| (-634 (-634 (-944 *4)))) (|:| |xValues| (-1084 *4)) (|:| |yValues| (-1084 *4)))) (-5 *1 (-156)) (-5 *3 (-634 (-634 (-944 *4))))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-955)) (-5 *2 (-1084 (-215))))) ((*1 *2 *1) (-12 (-4 *1 (-975)) (-5 *2 (-1084 (-215)))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1195)) (-5 *1 (-377 *4 *2)) (-4 *2 (-13 (-375 *4) (-10 -7 (-6 -4522))))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-646 *2)) (-4 *2 (-1047)))) ((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *4 (-172)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4)) (-5 *2 (-2 (|:| |adjMat| *3) (|:| |detMat| *4))) (-5 *1 (-678 *4 *5 *6 *3)) (-4 *3 (-677 *4 *5 *6)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-172)) (-4 *2 (-1047)) (-5 *1 (-704 *2 *3)) (-4 *3 (-637 *2)))) ((*1 *1 *1) (-12 (-4 *2 (-172)) (-4 *2 (-1047)) (-5 *1 (-704 *2 *3)) (-4 *3 (-637 *2)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-829 *2)) (-4 *2 (-172)) (-4 *2 (-1047)))) ((*1 *1 *1) (-12 (-5 *1 (-829 *2)) (-4 *2 (-172)) (-4 *2 (-1047))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-242 *4 *5)) (-14 *4 (-634 (-1161))) (-4 *5 (-453)) (-5 *2 (-492 *4 *5)) (-5 *1 (-622 *4 *5))))) 
 (((*1 *1 *2) (-12 (-5 *2 (-634 (-917))) (-5 *1 (-1091 *3 *4)) (-14 *3 (-917)) (-14 *4 (-917))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1244 *4)) (-4 *4 (-350)) (-5 *2 (-1157 *4)) (-5 *1 (-532 *4))))) 
+(((*1 *2 *1) (|partial| -12 (-4 *1 (-1205 *3 *2)) (-4 *3 (-1047)) (-4 *2 (-1234 *3))))) 
+(((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-129 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *2) (-12 (-5 *2 (-763)) (-5 *1 (-129 *3)) (-4 *3 (-1219 (-568)))))) 
+(((*1 *2 *3 *1) (-12 (-4 *1 (-1189 *4 *5 *3 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *3 (-842)) (-4 *6 (-1061 *4 *5 *3)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-121))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-646 *3)) (-4 *3 (-1047)) (-4 *3 (-365)))) ((*1 *2 *2 *3 *4) (-12 (-5 *3 (-763)) (-5 *4 (-1 *5 *5)) (-4 *5 (-365)) (-5 *1 (-649 *5 *2)) (-4 *2 (-646 *5))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
 (((*1 *2 *3 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-763))) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
+(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-57))) (-5 *1 (-887 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-55 *3 *4)) (-4 *3 (-1047)) (-14 *4 (-634 (-1161))))) ((*1 *2 *3) (-12 (-5 *3 (-57)) (-5 *2 (-121)) (-5 *1 (-56 *4)) (-4 *4 (-1195)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-213 *3 *4)) (-4 *3 (-13 (-1047) (-842))) (-14 *4 (-634 (-1161))))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-663 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-667 *3)) (-4 *3 (-842)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-888 *3)) (-4 *3 (-842))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1108)) (-5 *1 (-835 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-763)) (-5 *4 (-568)) (-5 *1 (-446 *2)) (-4 *2 (-1047))))) 
+(((*1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-393))))) 
 (((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-212 *3)))) ((*1 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-4 *1 (-247 *3)))) ((*1 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195))))) 
-(((*1 *1 *1) (-4 *1 (-651))) ((*1 *1 *1) (-5 *1 (-1108)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |lfn| (-634 (-310 (-215)))) (|:| -4436 (-634 (-215))))) (-5 *2 (-381)) (-5 *1 (-263)))) ((*1 *2 *3) (-12 (-5 *3 (-1244 (-310 (-215)))) (-5 *2 (-381)) (-5 *1 (-299))))) 
+(((*1 *2 *3 *4 *5) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-607 *7)) (-4 *7 (-13 (-432 *6) (-23) (-1037 *2) (-1037 *5) (-895 *5) (-161))) (-5 *5 (-1161)) (-4 *6 (-1047)) (-4 *6 (-13 (-842) (-558) (-609 (-541)))) (-5 *2 (-568)) (-5 *1 (-1024 *6 *7))))) 
+(((*1 *2 *1) (-12 (-4 *3 (-1047)) (-5 *2 (-634 *1)) (-4 *1 (-1122 *3))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-634 *7)) (-4 *7 (-950 *5 *8 (-852 *6))) (-4 *8 (-230 (-1699 *6) (-763))) (-4 *5 (-365)) (-14 *6 (-634 (-1161))) (-4 *10 (-641 *5)) (-4 *11 (-920 *5 *10)) (-5 *2 (-634 (-1244 *5))) (-5 *1 (-562 *5 *6 *7 *8 *9 *10 *11 *3)) (-4 *9 (-971 *5)) (-4 *3 (-235 *11))))) 
+(((*1 *1) (-12 (-4 *1 (-327 *2)) (-4 *2 (-370)) (-4 *2 (-365))))) 
 (((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 *3)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4))))) 
+(((*1 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2319 ((-1113 *3 (-607 $)) $)) (-15 -2326 ((-1113 *3 (-607 $)) $)) (-15 -2747 ($ (-1113 *3 (-607 $))))))))) ((*1 *2 *2 *2) (-12 (-4 *3 (-558)) (-5 *1 (-46 *3 *2)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2319 ((-1113 *3 (-607 $)) $)) (-15 -2326 ((-1113 *3 (-607 $)) $)) (-15 -2747 ($ (-1113 *3 (-607 $))))))))) ((*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2319 ((-1113 *4 (-607 $)) $)) (-15 -2326 ((-1113 *4 (-607 $)) $)) (-15 -2747 ($ (-1113 *4 (-607 $))))))) (-4 *4 (-558)) (-5 *1 (-46 *4 *2)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-634 (-607 *2))) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2319 ((-1113 *4 (-607 $)) $)) (-15 -2326 ((-1113 *4 (-607 $)) $)) (-15 -2747 ($ (-1113 *4 (-607 $))))))) (-4 *4 (-558)) (-5 *1 (-46 *4 *2))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-121)) (-5 *1 (-123))))) 
+(((*1 *2 *3 *3) (-12 (-5 *3 (-1216 *5 *4)) (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-634 *4)) (-5 *1 (-1104 *4 *5))))) 
+(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *3 (-944 *5)) (-4 *5 (-1047)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-763)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917)) (-4 *5 (-1047)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-763))) (-5 *3 (-944 *5)) (-4 *5 (-1047)) (-5 *1 (-1149 *4 *5)) (-14 *4 (-917))))) 
 (((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-1244 *1)) (-5 *4 (-1 *5 *5)) (-4 *5 (-365)) (-4 *1 (-714 *5 *6)) (-4 *5 (-172)) (-4 *6 (-1219 *5)) (-5 *2 (-679 *5))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-927))))) 
+(((*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-869)))) ((*1 *2 *3) (-12 (-5 *3 (-944 *2)) (-5 *1 (-983 *2)) (-4 *2 (-1047))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *7)) (-4 *7 (-842)) (-4 *5 (-904)) (-4 *6 (-788)) (-4 *8 (-950 *5 *6 *7)) (-5 *2 (-420 (-1157 *8))) (-5 *1 (-901 *5 *6 *7 *8)) (-5 *4 (-1157 *8)))) ((*1 *2 *3) (-12 (-4 *4 (-904)) (-4 *5 (-1219 *4)) (-5 *2 (-420 (-1157 *5))) (-5 *1 (-902 *4 *5)) (-5 *3 (-1157 *5))))) 
 (((*1 *2 *2 *3) (-12 (-5 *2 (-1244 (-1244 (-568)))) (-5 *3 (-917)) (-5 *1 (-471))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -4265 *3) (|:| |coef1| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-453) (-150))) (-5 *2 (-420 *3)) (-5 *1 (-103 *4 *3)) (-4 *3 (-1219 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-634 *3)) (-4 *3 (-1219 *5)) (-4 *5 (-13 (-453) (-150))) (-5 *2 (-420 *3)) (-5 *1 (-103 *5 *3))))) 
+(((*1 *2 *3 *4 *4 *5) (-12 (-5 *3 (-1 (-169 (-215)) (-169 (-215)))) (-5 *4 (-1084 (-215))) (-5 *5 (-121)) (-5 *2 (-1246)) (-5 *1 (-250))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-381)) (-5 *2 (-215)) (-5 *1 (-299))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-634 *2)) (-5 *4 (-1 (-121) *2 *2)) (-5 *1 (-1196 *2)) (-4 *2 (-1090)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-1090)) (-4 *2 (-842)) (-5 *1 (-1196 *2))))) 
+(((*1 *2 *2 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1045))))) 
+(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2910 *3) (|:| |coef1| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-763)) (-5 *1 (-446 *3)) (-4 *3 (-406)) (-4 *3 (-1047)))) ((*1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-446 *3)) (-4 *3 (-406)) (-4 *3 (-1047))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-381)) (-5 *2 (-215)) (-5 *1 (-1247)))) ((*1 *2) (-12 (-5 *2 (-215)) (-5 *1 (-1247))))) 
+(((*1 *1 *1) (-12 (-4 *1 (-277 *2)) (-4 *2 (-1195)) (-4 *2 (-1090)))) ((*1 *1 *1) (-12 (-4 *1 (-684 *2)) (-4 *2 (-1090))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1173 *4 *5)) (-4 *4 (-1090)) (-4 *5 (-1090))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3))))) 
+(((*1 *2 *2 *3 *2) (-12 (-5 *2 (-1143)) (-5 *3 (-568)) (-5 *1 (-234)))) ((*1 *2 *2 *3 *4) (-12 (-5 *2 (-634 (-1143))) (-5 *3 (-568)) (-5 *4 (-1143)) (-5 *1 (-234)))) ((*1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) ((*1 *2 *1) (-12 (-4 *1 (-1221 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047))))) 
 (((*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-4 *2 (-1047)) (-5 *1 (-908 *2 *3 *5 *6)) (-4 *3 (-324 *2 *5))))) 
+(((*1 *2 *3 *4 *2 *5) (-12 (-5 *3 (-634 *8)) (-5 *4 (-634 (-887 *6))) (-5 *5 (-1 (-884 *6 *8) *8 (-887 *6) (-884 *6 *8))) (-4 *6 (-1090)) (-4 *8 (-13 (-1047) (-609 (-887 *6)) (-1037 *7))) (-5 *2 (-884 *6 *8)) (-4 *7 (-13 (-1047) (-842))) (-5 *1 (-942 *6 *7 *8))))) 
+(((*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *12)) (-5 *1 (-467 *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2) (-12 (-5 *2 (-634 (-259 (-537 *3 *4 *5)))) (-5 *1 (-867 *3 *4 *5)) (-4 *3 (-350)) (-14 *4 (-634 (-1161))) (-4 *5 (-117)))) ((*1 *2) (-12 (-5 *2 (-634 (-259 (-513 *3 *4 *5)))) (-5 *1 (-868 *3 *4 *5)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *5 (-117))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-215)) (-5 *5 (-568)) (-5 *2 (-1191 *3)) (-5 *1 (-785 *3)) (-4 *3 (-975)))) ((*1 *1 *2 *3 *4) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *4 (-121)) (-5 *1 (-1191 *2)) (-4 *2 (-975))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-381))) (-5 *1 (-1039))))) 
+(((*1 *2) (-12 (-4 *1 (-350)) (-5 *2 (-3 "prime" "polynomial" "normal" "cyclic"))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-365)) (-4 *5 (-1219 *4)) (-5 *2 (-1249)) (-5 *1 (-45 *4 *5 *6 *7)) (-4 *6 (-1219 (-409 *5))) (-14 *7 *6)))) 
+(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| -3030 (-409 (-568))) (|:| -3286 (-409 (-568))))) (-5 *2 (-409 (-568))) (-5 *1 (-1019 *4)) (-4 *4 (-1219 (-568)))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-324 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047)) (-4 *2 (-453)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1219 (-568))) (-5 *2 (-634 (-568))) (-5 *1 (-496 *4)))) ((*1 *2 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-453)))) ((*1 *1 *1 *2) (-12 (-4 *1 (-950 *3 *4 *2)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *3 (-453))))) 
+(((*1 *1 *1 *2) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090))))) 
+(((*1 *2 *2 *2) (-12 (-5 *1 (-160 *2)) (-4 *2 (-550))))) 
 (((*1 *2) (-12 (-5 *2 (-634 *3)) (-5 *1 (-1043 *3)) (-4 *3 (-365))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-550)) (-5 *1 (-160 *2))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-1061 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) ((*1 *2 *3 *1 *4) (-12 (-5 *4 (-1 (-121) *3 *3)) (-4 *1 (-1189 *5 *6 *7 *3)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-121))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-828 (-215))) (-5 *1 (-217))))) 
+(((*1 *2 *2 *2 *2 *3) (-12 (-4 *3 (-558)) (-5 *1 (-970 *3 *2)) (-4 *2 (-1219 *3))))) 
+(((*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-1143)) (-4 *6 (-453)) (-4 *7 (-788)) (-4 *8 (-842)) (-4 *4 (-1061 *6 *7 *8)) (-5 *2 (-1249)) (-5 *1 (-768 *6 *7 *8 *4 *5)) (-4 *5 (-1066 *6 *7 *8 *4))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *4 *5 *6 *3)) (-4 *3 (-1061 *4 *5 *6))))) 
 (((*1 *2 *2 *2) (|partial| -12 (-4 *3 (-13 (-558) (-150))) (-5 *1 (-1213 *3 *2)) (-4 *2 (-1219 *3))))) 
+(((*1 *1 *1 *1 *1) (-4 *1 (-550)))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -2910 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *4 *5 *6)) (-4 *4 (-301)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-448 *4 *5 *6 *2))))) 
+(((*1 *1) (-5 *1 (-563)))) 
+(((*1 *2 *1) (-12 (-4 *1 (-391)) (-5 *2 (-121))))) 
+(((*1 *1) (-12 (-5 *1 (-141 *2 *3 *4)) (-14 *2 (-568)) (-14 *3 (-763)) (-4 *4 (-172))))) 
 (((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-850))))) 
+(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-99))))) 
+(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-641 *4)) (-4 *3 (-920 *4 *8)) (-4 *9 (-235 *3)) (-4 *10 (-536 *4 *5 *6 *7 *2 *8 *3 *9 *12)) (-4 *12 (-117)) (-4 *2 (-971 *4)) (-5 *1 (-467 *4 *5 *6 *7 *2 *8 *3 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) ((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-641 *4)) (-4 *2 (-971 *4)) (-5 *1 (-654 *4 *5 *6 *7 *2 *8 *3)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *3 (-920 *4 *8)))) ((*1 *2 *3) (-12 (-5 *3 (-922 *4)) (-4 *4 (-350)) (-5 *2 (-967 *4)) (-5 *1 (-867 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-921 *4)) (-4 *4 (-365)) (-5 *2 (-966 *4)) (-5 *1 (-868 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1195)) (-5 *1 (-377 *4 *2)) (-4 *2 (-13 (-375 *4) (-10 -7 (-6 -4522))))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-62 *3 *4 *5)) (-4 *3 (-1195)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-568)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-568))))) 
+(((*1 *2 *3) (|partial| -12 (-5 *3 (-1244 *4)) (-4 *4 (-630 (-568))) (-5 *2 (-1244 (-568))) (-5 *1 (-1269 *4))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-814 *3)))) ((*1 *2 *1) (-12 (-4 *2 (-838)) (-5 *1 (-1265 *3 *2)) (-4 *3 (-1047))))) 
 (((*1 *2 *1) (-12 (-4 *1 (-1134 *3)) (-4 *3 (-1195)) (-5 *2 (-121))))) 
-(((*1 *2 *1 *2) (-12 (-4 *1 (-536 *3 *4 *5 *6 *2 *7 *8 *9 *10)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *2 (-971 *3)) (-4 *7 (-641 *3)) (-4 *8 (-920 *3 *7)) (-4 *9 (-235 *8)) (-4 *10 (-117))))) 
+(((*1 *2 *2 *3 *3) (-12 (-5 *3 (-409 *5)) (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-5 *1 (-151 *4 *5 *2)) (-4 *2 (-1219 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1163 (-409 (-568)))) (-5 *2 (-409 (-568))) (-5 *1 (-182)))) ((*1 *2 *2 *3 *4) (-12 (-5 *2 (-679 (-310 (-215)))) (-5 *3 (-634 (-1161))) (-5 *4 (-1244 (-310 (-215)))) (-5 *1 (-197)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-288 *3))) (-4 *3 (-303 *3)) (-4 *3 (-1090)) (-4 *3 (-1195)) (-5 *1 (-288 *3)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-303 *2)) (-4 *2 (-1090)) (-4 *2 (-1195)) (-5 *1 (-288 *2)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *1 *1)) (-4 *1 (-296)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *1 (-634 *1))) (-4 *1 (-296)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-123))) (-5 *3 (-634 (-1 *1 (-634 *1)))) (-4 *1 (-296)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-123))) (-5 *3 (-634 (-1 *1 *1))) (-4 *1 (-296)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1 *1 *1)) (-4 *1 (-296)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1 *1 (-634 *1))) (-4 *1 (-296)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-634 (-1 *1 (-634 *1)))) (-4 *1 (-296)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-634 (-1 *1 *1))) (-4 *1 (-296)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-288 *3))) (-4 *1 (-303 *3)) (-4 *3 (-1090)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-288 *3)) (-4 *1 (-303 *3)) (-4 *3 (-1090)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 (-568))) (-5 *4 (-1163 (-409 (-568)))) (-5 *1 (-304 *2)) (-4 *2 (-43 (-409 (-568)))))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *4)) (-5 *3 (-634 *1)) (-4 *1 (-376 *4 *5)) (-4 *4 (-842)) (-4 *5 (-172)))) ((*1 *1 *1 *2 *1) (-12 (-4 *1 (-376 *2 *3)) (-4 *2 (-842)) (-4 *3 (-172)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-763)) (-5 *4 (-1 *1 *1)) (-4 *1 (-432 *5)) (-4 *5 (-842)) (-4 *5 (-1047)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-763)) (-5 *4 (-1 *1 (-634 *1))) (-4 *1 (-432 *5)) (-4 *5 (-842)) (-4 *5 (-1047)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-634 (-763))) (-5 *4 (-634 (-1 *1 (-634 *1)))) (-4 *1 (-432 *5)) (-4 *5 (-842)) (-4 *5 (-1047)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-634 (-763))) (-5 *4 (-634 (-1 *1 *1))) (-4 *1 (-432 *5)) (-4 *5 (-842)) (-4 *5 (-1047)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-634 (-123))) (-5 *3 (-634 *1)) (-5 *4 (-1161)) (-4 *1 (-432 *5)) (-4 *5 (-842)) (-4 *5 (-609 (-541))))) ((*1 *1 *1 *2 *1 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1161)) (-4 *1 (-432 *4)) (-4 *4 (-842)) (-4 *4 (-609 (-541))))) ((*1 *1 *1) (-12 (-4 *1 (-432 *2)) (-4 *2 (-842)) (-4 *2 (-609 (-541))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-1161))) (-4 *1 (-432 *3)) (-4 *3 (-842)) (-4 *3 (-609 (-541))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1161)) (-4 *1 (-432 *3)) (-4 *3 (-842)) (-4 *3 (-609 (-541))))) ((*1 *2 *3 *4) (-12 (-14 *5 (-634 (-1161))) (-4 *3 (-950 *2 *6 (-852 *5))) (-4 *6 (-230 (-1699 *5) (-763))) (-4 *7 (-971 *2)) (-4 *8 (-641 *2)) (-4 *4 (-920 *2 *8)) (-4 *9 (-235 *4)) (-4 *10 (-536 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) ((*1 *2 *3 *3 *4) (-12 (-14 *5 (-634 (-1161))) (-4 *3 (-950 *2 *6 (-852 *5))) (-4 *6 (-230 (-1699 *5) (-763))) (-4 *7 (-971 *2)) (-4 *8 (-641 *2)) (-4 *4 (-920 *2 *8)) (-4 *9 (-235 *4)) (-4 *10 (-536 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 *6)) (-4 *6 (-950 *2 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-14 *5 (-634 (-1161))) (-4 *8 (-971 *2)) (-4 *9 (-641 *2)) (-4 *4 (-920 *2 *9)) (-4 *10 (-235 *4)) (-4 *11 (-536 *2 *5 *6 *7 *8 *9 *4 *10 *13)) (-4 *13 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *6 *7 *8 *9 *4 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *1 *1 *2 *3) (-12 (-4 *1 (-523 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1195)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *4)) (-5 *3 (-634 *5)) (-4 *1 (-523 *4 *5)) (-4 *4 (-1090)) (-4 *5 (-1195)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-828 *3)) (-4 *3 (-365)) (-5 *1 (-708 *3)))) ((*1 *2 *1 *2) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-242 *5 *2)) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *3 *4) (-12 (-5 *3 (-242 *5 *2)) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-242 *5 *2))) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-242 *5 *2)) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *3 *4) (-12 (-5 *3 (-242 *5 *2)) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-242 *5 *2))) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-898 *2)) (-4 *2 (-1090)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-4 *2 (-365)) (-5 *1 (-929 *2 *3 *5 *6 *4)) (-4 *3 (-324 *2 *5)) (-4 *4 (-971 *2)))) ((*1 *2 *2 *3 *2) (-12 (-5 *2 (-409 (-953 *4))) (-5 *3 (-1161)) (-4 *4 (-558)) (-5 *1 (-1042 *4)))) ((*1 *2 *2 *3 *4) (-12 (-5 *3 (-634 (-1161))) (-5 *4 (-634 (-409 (-953 *5)))) (-5 *2 (-409 (-953 *5))) (-4 *5 (-558)) (-5 *1 (-1042 *5)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-288 (-409 (-953 *4)))) (-5 *2 (-409 (-953 *4))) (-4 *4 (-558)) (-5 *1 (-1042 *4)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-634 (-288 (-409 (-953 *4))))) (-5 *2 (-409 (-953 *4))) (-4 *4 (-558)) (-5 *1 (-1042 *4)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-1221 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (|has| *3 (-15 ** (*3 *3 *4))) (-5 *2 (-1141 *3))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-37 *3)) (-4 *3 (-365)) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-37 *4)) (-4 *4 (-365)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-166 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-420 *3)) (-4 *3 (-550)) (-4 *3 (-558)))) ((*1 *2 *1) (-12 (-4 *1 (-550)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-792 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-828 *3)) (-4 *3 (-550)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-835 *3)) (-4 *3 (-550)) (-4 *3 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-971 *3)) (-4 *3 (-365)) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-971 *4)) (-4 *4 (-365)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-997 *3)) (-4 *3 (-172)) (-4 *3 (-550)) (-5 *2 (-121)))) ((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-1008 *3)) (-4 *3 (-1037 (-409 (-568))))))) 
+(((*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1210 *3)) (-4 *3 (-1195))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-1259 *3 *4)) (-4 *3 (-842)) (-4 *4 (-1047)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-1265 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-838))))) 
+(((*1 *2 *2 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-558)) (-5 *1 (-970 *4 *2)) (-4 *2 (-1219 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-484 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1866 *6) (|:| -1844 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1866 *7) (|:| -1844 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1781 ($ $ $)) (-15 ** ($ $ $)) (-15 -3539 ($ $)) (-15 -3210 ($ $)) (-15 -2088 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1866 (-310 (-568))) (|:| -1844 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *4 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1866 (-733 *5 (-568))) (|:| -1844 (-763))))) (-5 *1 (-488 *5))))) 
+(((*1 *2 *1 *2) (-12 (-4 *1 (-536 *3 *4 *5 *6 *2 *7 *8 *9 *10)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *2 (-971 *3)) (-4 *7 (-641 *3)) (-4 *8 (-920 *3 *7)) (-4 *9 (-235 *8)) (-4 *10 (-117))))) 
+(((*1 *1) (-5 *1 (-147)))) 
+(((*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3))))) 
+(((*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-2 (|:| |ans| *6) (|:| -3286 *6) (|:| |sol?| (-121))) (-568) *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-5 *2 (-3 (-2 (|:| |answer| (-409 *7)) (|:| |a0| *6)) (-2 (|:| -4151 (-409 *7)) (|:| |coeff| (-409 *7))) "failed")) (-5 *1 (-578 *6 *7)) (-5 *3 (-409 *7))))) 
+(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568)))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *8)) (|:| |neqzro| (-634 *8)) (|:| |wcond| (-634 (-953 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *5)))) (|:| -2588 (-634 (-1244 (-409 (-953 *5)))))))))) (-5 *1 (-924 *5 *6 *7 *8)) (-5 *4 (-634 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-5 *4 (-634 (-1161))) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *8)) (|:| |neqzro| (-634 *8)) (|:| |wcond| (-634 (-953 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *5)))) (|:| -2588 (-634 (-1244 (-409 (-953 *5)))))))))) (-5 *1 (-924 *5 *6 *7 *8)))) ((*1 *2 *3) (-12 (-5 *3 (-679 *7)) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *7)) (|:| |neqzro| (-634 *7)) (|:| |wcond| (-634 (-953 *4))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *4)))) (|:| -2588 (-634 (-1244 (-409 (-953 *4)))))))))) (-5 *1 (-924 *4 *5 *6 *7)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *9)) (-5 *5 (-917)) (-4 *9 (-950 *6 *8 *7)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-13 (-842) (-609 (-1161)))) (-4 *8 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *9)) (|:| |neqzro| (-634 *9)) (|:| |wcond| (-634 (-953 *6))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *6)))) (|:| -2588 (-634 (-1244 (-409 (-953 *6)))))))))) (-5 *1 (-924 *6 *7 *8 *9)) (-5 *4 (-634 *9)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *9)) (-5 *4 (-634 (-1161))) (-5 *5 (-917)) (-4 *9 (-950 *6 *8 *7)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-13 (-842) (-609 (-1161)))) (-4 *8 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *9)) (|:| |neqzro| (-634 *9)) (|:| |wcond| (-634 (-953 *6))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *6)))) (|:| -2588 (-634 (-1244 (-409 (-953 *6)))))))))) (-5 *1 (-924 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-5 *4 (-917)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *8)) (|:| |neqzro| (-634 *8)) (|:| |wcond| (-634 (-953 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *5)))) (|:| -2588 (-634 (-1244 (-409 (-953 *5)))))))))) (-5 *1 (-924 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *9)) (-5 *4 (-634 *9)) (-5 *5 (-1143)) (-4 *9 (-950 *6 *8 *7)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-13 (-842) (-609 (-1161)))) (-4 *8 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *6 *7 *8 *9)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *9)) (-5 *4 (-634 (-1161))) (-5 *5 (-1143)) (-4 *9 (-950 *6 *8 *7)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-13 (-842) (-609 (-1161)))) (-4 *8 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-679 *8)) (-5 *4 (-1143)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *5 *6 *7 *8)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-679 *10)) (-5 *4 (-634 *10)) (-5 *5 (-917)) (-5 *6 (-1143)) (-4 *10 (-950 *7 *9 *8)) (-4 *7 (-13 (-301) (-150))) (-4 *8 (-13 (-842) (-609 (-1161)))) (-4 *9 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *7 *8 *9 *10)))) ((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-679 *10)) (-5 *4 (-634 (-1161))) (-5 *5 (-917)) (-5 *6 (-1143)) (-4 *10 (-950 *7 *9 *8)) (-4 *7 (-13 (-301) (-150))) (-4 *8 (-13 (-842) (-609 (-1161)))) (-4 *9 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *7 *8 *9 *10)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-679 *9)) (-5 *4 (-917)) (-5 *5 (-1143)) (-4 *9 (-950 *6 *8 *7)) (-4 *6 (-13 (-301) (-150))) (-4 *7 (-13 (-842) (-609 (-1161)))) (-4 *8 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *6 *7 *8 *9))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 *4)) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
 (((*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-453)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-121)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-453)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-978 *4 *5 *6 *7))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-375 *3)) (-4 *3 (-1195)) (-4 *3 (-842)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *1 (-375 *4)) (-4 *4 (-1195)) (-5 *2 (-121))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-121)) (-4 *6 (-13 (-453) (-842) (-1037 (-568)) (-630 (-568)))) (-4 *3 (-13 (-27) (-1181) (-432 *6) (-10 -8 (-15 -2747 ($ *7))))) (-4 *7 (-840)) (-4 *8 (-13 (-1221 *3 *7) (-365) (-1181) (-10 -8 (-15 -4191 ($ $)) (-15 -1845 ($ $))))) (-5 *2 (-3 (|:| |%series| *8) (|:| |%problem| (-2 (|:| |func| (-1143)) (|:| |prob| (-1143)))))) (-5 *1 (-424 *6 *3 *7 *8 *9 *10)) (-5 *5 (-1143)) (-4 *9 (-984 *8)) (-14 *10 (-1161))))) 
+(((*1 *2 *1) (-12 (-4 *1 (-920 *3 *4)) (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-634 *4))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-1047)) (-5 *2 (-1244 *4)) (-5 *1 (-1162 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-5 *2 (-1244 *3)) (-5 *1 (-1162 *3)) (-4 *3 (-1047))))) 
+(((*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247)))) ((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-1247))))) 
 (((*1 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) ((*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-568)) (-5 *1 (-496 *4)) (-4 *4 (-1219 *2))))) 
+(((*1 *2 *1 *3) (-12 (-5 *3 (-381)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-1141 *3))) (-5 *2 (-1141 *3)) (-5 *1 (-1145 *3)) (-4 *3 (-43 (-409 (-568)))) (-4 *3 (-1047))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *2)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *2 (-1061 *3 *4 *5))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
 (((*1 *2 *1 *3) (-12 (-5 *3 (-634 (-944 *4))) (-4 *1 (-1122 *4)) (-4 *4 (-1047)) (-5 *2 (-763))))) 
+(((*1 *2 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-1047)) (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-5 *1 (-908 *4 *2 *5 *6)) (-4 *2 (-324 *4 *5))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-646 *2)) (-4 *2 (-1047)) (-4 *2 (-365)))) ((*1 *2 *2 *2 *3) (-12 (-5 *3 (-1 *4 *4)) (-4 *4 (-365)) (-5 *1 (-649 *4 *2)) (-4 *2 (-646 *4))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
+(((*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
 (((*1 *2 *3 *4 *5 *4 *4 *4) (-12 (-4 *6 (-842)) (-5 *3 (-634 *6)) (-5 *5 (-634 *3)) (-5 *2 (-2 (|:| |f1| *3) (|:| |f2| (-634 *5)) (|:| |f3| *5) (|:| |f4| (-634 *5)))) (-5 *1 (-1167 *6)) (-5 *4 (-634 *5))))) 
+(((*1 *2 *3) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-447)) (-5 *3 (-568))))) 
+(((*1 *2 *2) (|partial| -12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *1 *1) (-12 (-5 *1 (-1201 *2)) (-4 *2 (-1047)))) ((*1 *1 *1) (-12 (-5 *1 (-1235 *2 *3 *4)) (-4 *2 (-1047)) (-14 *3 (-1161)) (-14 *4 *2))) ((*1 *1 *1) (-12 (-5 *1 (-1239 *2 *3)) (-4 *2 (-1047)) (-14 *3 (-1161))))) 
 (((*1 *1 *1) (-12 (-4 *1 (-1061 *2 *3 *4)) (-4 *2 (-1047)) (-4 *3 (-788)) (-4 *4 (-842))))) 
+(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-594 *3)) (-4 *3 (-1047)))) ((*1 *2 *1) (-12 (-4 *1 (-974 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-787)) (-4 *5 (-842)) (-5 *2 (-121))))) 
+(((*1 *1 *2 *3) (-12 (-5 *2 (-1157 *1)) (-5 *3 (-1161)) (-4 *1 (-858)))) ((*1 *1 *2 *1 *3) (-12 (-5 *2 (-1157 *1)) (-5 *3 (-1161)) (-4 *1 (-858)))) ((*1 *1 *2 *2 *3 *1 *4) (-12 (-5 *2 (-1157 (-860))) (-5 *3 (-917)) (-5 *4 (-1161)) (-5 *1 (-860))))) 
+(((*1 *2 *1 *3) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1059)) (-5 *3 (-1143))))) 
+(((*1 *2 *3 *4 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-1044 *5 *6))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-953 *5))) (-5 *4 (-121)) (-4 *5 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-1044 *5 *6))) (-5 *1 (-1268 *5 *6 *7)) (-14 *6 (-634 (-1161))) (-14 *7 (-634 (-1161))))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-953 *4))) (-4 *4 (-13 (-840) (-301) (-150) (-1021))) (-5 *2 (-634 (-1044 *4 *5))) (-5 *1 (-1268 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-14 *6 (-634 (-1161)))))) 
 (((*1 *2 *1 *3 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-899 *4)) (-4 *4 (-1090)))) ((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-899 *3)) (-4 *3 (-1090))))) 
+(((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-5 *2 (-2 (|:| A (-679 *5)) (|:| |eqs| (-634 (-2 (|:| C (-679 *5)) (|:| |g| (-1244 *5)) (|:| -2410 *6) (|:| |rh| *5)))))) (-5 *1 (-808 *5 *6)) (-5 *3 (-679 *5)) (-5 *4 (-1244 *5)) (-4 *6 (-646 *5)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-365)) (-4 *6 (-646 *5)) (-5 *2 (-2 (|:| -2908 (-679 *6)) (|:| |vec| (-1244 *5)))) (-5 *1 (-808 *5 *6)) (-5 *3 (-679 *6)) (-5 *4 (-1244 *5))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-568)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-568)) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117))))) 
+(((*1 *2 *3 *2) (-12 (-5 *3 (-679 *2)) (-4 *2 (-172)) (-5 *1 (-149 *2)))) ((*1 *2 *3) (-12 (-4 *4 (-172)) (-4 *2 (-1219 *4)) (-5 *1 (-175 *4 *2 *3)) (-4 *3 (-714 *4 *2)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-679 (-409 (-953 *5)))) (-5 *4 (-1161)) (-5 *2 (-953 *5)) (-5 *1 (-286 *5)) (-4 *5 (-453)))) ((*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-953 *4)))) (-5 *2 (-953 *4)) (-5 *1 (-286 *4)) (-4 *4 (-453)))) ((*1 *2 *1) (-12 (-4 *1 (-372 *3 *2)) (-4 *3 (-172)) (-4 *2 (-1219 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-679 (-169 (-409 (-568))))) (-5 *2 (-953 (-169 (-409 (-568))))) (-5 *1 (-756 *4)) (-4 *4 (-13 (-365) (-840))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-679 (-169 (-409 (-568))))) (-5 *4 (-1161)) (-5 *2 (-953 (-169 (-409 (-568))))) (-5 *1 (-756 *5)) (-4 *5 (-13 (-365) (-840))))) ((*1 *2 *3) (-12 (-5 *3 (-679 (-409 (-568)))) (-5 *2 (-953 (-409 (-568)))) (-5 *1 (-773 *4)) (-4 *4 (-13 (-365) (-840))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-679 (-409 (-568)))) (-5 *4 (-1161)) (-5 *2 (-953 (-409 (-568)))) (-5 *1 (-773 *5)) (-4 *5 (-13 (-365) (-840)))))) 
+(((*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-989 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6)))) ((*1 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-1249)) (-5 *1 (-1097 *3 *4 *5 *6 *7)) (-4 *7 (-1066 *3 *4 *5 *6))))) 
 (((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-679 *5))) (-5 *4 (-1244 *5)) (-4 *5 (-301)) (-4 *5 (-1047)) (-5 *2 (-679 *5)) (-5 *1 (-1029 *5))))) 
+(((*1 *2 *1 *3 *3 *2) (-12 (-5 *3 (-568)) (-4 *1 (-62 *2 *4 *5)) (-4 *2 (-1195)) (-4 *4 (-375 *2)) (-4 *5 (-375 *2)))) ((*1 *2 *1 *3 *2) (-12 (|has| *1 (-6 -4522)) (-4 *1 (-283 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-1195))))) 
+(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
+(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 (-121) *6 *6)) (-4 *6 (-842)) (-5 *4 (-634 *6)) (-5 *2 (-2 (|:| |fs| (-121)) (|:| |sd| *4) (|:| |td| (-634 *4)))) (-5 *1 (-1167 *6)) (-5 *5 (-634 *4))))) 
+(((*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3))))) 
 (((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-1249)) (-5 *1 (-582))))) 
+(((*1 *2 *3 *2 *4) (|partial| -12 (-5 *3 (-634 (-607 *2))) (-5 *4 (-1161)) (-4 *2 (-13 (-27) (-1181) (-432 *5))) (-4 *5 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *1 (-273 *5 *2))))) 
+(((*1 *2 *2 *3) (-12 (-4 *4 (-788)) (-4 *3 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $))))) (-4 *5 (-558)) (-5 *1 (-722 *4 *3 *5 *2)) (-4 *2 (-950 (-409 (-953 *5)) *4 *3)))) ((*1 *2 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *3 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $)) (-15 -3325 ((-3 $ "failed") (-1161)))))) (-5 *1 (-985 *4 *5 *3 *2)) (-4 *2 (-950 (-953 *4) *5 *3)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-13 (-842) (-10 -8 (-15 -4280 ((-1161) $)) (-15 -3325 ((-3 $ "failed") (-1161)))))) (-4 *4 (-1047)) (-4 *5 (-788)) (-5 *1 (-985 *4 *5 *6 *2)) (-4 *2 (-950 (-953 *4) *5 *6))))) 
+(((*1 *1 *1 *2) (|partial| -12 (-5 *2 (-917)) (-5 *1 (-1091 *3 *4)) (-14 *3 *2) (-14 *4 *2)))) 
+(((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-428 *5 *3)) (-4 *3 (-13 (-1181) (-29 *5))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-558) (-1037 (-568)) (-150))) (-5 *2 (-585 (-409 (-953 *5)))) (-5 *1 (-574 *5)) (-5 *3 (-409 (-953 *5)))))) 
 (((*1 *1 *1) (-12 (-4 *1 (-646 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-643 (-409 *6))) (-5 *4 (-409 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -3746 (-634 *4)))) (-5 *1 (-805 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-643 (-409 *6))) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-2 (|:| -3746 (-634 (-409 *6))) (|:| -2928 (-679 *5)))) (-5 *1 (-805 *5 *6)) (-5 *4 (-634 (-409 *6))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-644 *6 (-409 *6))) (-5 *4 (-409 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -3746 (-634 *4)))) (-5 *1 (-805 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-644 *6 (-409 *6))) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-2 (|:| -3746 (-634 (-409 *6))) (|:| -2928 (-679 *5)))) (-5 *1 (-805 *5 *6)) (-5 *4 (-634 (-409 *6)))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-788)) (-4 *4 (-842)) (-4 *6 (-301)) (-5 *2 (-420 *3)) (-5 *1 (-732 *5 *4 *6 *3)) (-4 *3 (-950 *6 *5 *4))))) 
-(((*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568))))) ((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-443 *3)) (-4 *3 (-1219 (-568)))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-751))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 (-492 *3 *4))) (-14 *3 (-634 (-1161))) (-4 *4 (-453)) (-5 *1 (-622 *3 *4))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1216 *5 *4)) (-4 *4 (-453)) (-4 *4 (-815)) (-14 *5 (-1161)) (-5 *2 (-568)) (-5 *1 (-1104 *4 *5))))) 
-(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-1076 *3)) (-4 *3 (-138))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-365)) (-5 *1 (-653 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-763)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-465))))) 
-(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-679 (-169 (-409 (-568))))) (-5 *2 (-634 (-2 (|:| |outval| (-169 *4)) (|:| |outmult| (-568)) (|:| |outvect| (-634 (-679 (-169 *4))))))) (-5 *1 (-756 *4)) (-4 *4 (-13 (-365) (-840)))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *1 *1) (-12 (-4 *1 (-247 *2)) (-4 *2 (-1195)))) ((*1 *1 *1) (-12 (|has| *1 (-6 -4520)) (-4 *1 (-375 *2)) (-4 *2 (-1195)))) ((*1 *1 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3)))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1047)) (-5 *2 (-568)) (-5 *1 (-444 *4 *3 *5)) (-4 *3 (-1219 *4)) (-4 *5 (-13 (-406) (-1037 *4) (-365) (-1181) (-279)))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1195)) (-5 *2 (-763)) (-5 *1 (-179 *4 *3)) (-4 *3 (-665 *4))))) 
-(((*1 *2 *3 *4 *5 *6) (-12 (-5 *5 (-1 (-585 *3) *3 (-1161))) (-5 *6 (-1 (-3 (-2 (|:| |special| *3) (|:| |integrand| *3)) "failed") *3 (-1161))) (-4 *3 (-279)) (-4 *3 (-620)) (-4 *3 (-1037 *4)) (-4 *3 (-432 *7)) (-5 *4 (-1161)) (-4 *7 (-609 (-887 (-568)))) (-4 *7 (-453)) (-4 *7 (-881 (-568))) (-4 *7 (-842)) (-5 *2 (-585 *3)) (-5 *1 (-577 *7 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-819)) (-5 *1 (-820))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-558)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-763))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(((*1 *1) (-5 *1 (-818)))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-634 *6) "failed") (-568) *6 *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-5 *2 (-2 (|:| |answer| (-585 (-409 *7))) (|:| |a0| *6))) (-5 *1 (-578 *6 *7)) (-5 *3 (-409 *7))))) 
-(((*1 *2 *3 *2) (-12 (-5 *3 (-634 (-1069 *4 *5 *2))) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-4 *2 (-13 (-432 *5) (-881 *4) (-609 (-887 *4)))) (-5 *1 (-60 *4 *5 *2)))) ((*1 *2 *3 *2 *4) (-12 (-5 *3 (-634 (-1069 *5 *6 *2))) (-5 *4 (-917)) (-4 *5 (-1090)) (-4 *6 (-13 (-1047) (-881 *5) (-842) (-609 (-887 *5)))) (-4 *2 (-13 (-432 *6) (-881 *5) (-609 (-887 *5)))) (-5 *1 (-60 *5 *6 *2))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1189 *2 *3 *4 *5)) (-4 *2 (-558)) (-4 *3 (-788)) (-4 *4 (-842)) (-4 *5 (-1061 *2 *3 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-1182 *3))) (-5 *1 (-1182 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-558)) (-5 *2 (-121))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-763)) (-4 *4 (-13 (-558) (-453))) (-5 *2 (-634 *4)) (-5 *1 (-346 *4 *5)) (-4 *5 (-52 *4 *3))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-887 *4)) (-5 *3 (-1 (-121) *5)) (-4 *4 (-1090)) (-4 *5 (-1195)) (-5 *1 (-885 *4 *5)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-887 *4)) (-5 *3 (-634 (-1 (-121) *5))) (-4 *4 (-1090)) (-4 *5 (-1195)) (-5 *1 (-885 *4 *5)))) ((*1 *2 *2 *3 *4) (-12 (-5 *2 (-887 *5)) (-5 *3 (-634 (-1161))) (-5 *4 (-1 (-121) (-634 *6))) (-4 *5 (-1090)) (-4 *6 (-1195)) (-5 *1 (-885 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *5)) (-4 *5 (-1195)) (-4 *4 (-842)) (-5 *1 (-938 *4 *2 *5)) (-4 *2 (-432 *4)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-634 (-1 (-121) *5))) (-4 *5 (-1195)) (-4 *4 (-842)) (-5 *1 (-938 *4 *2 *5)) (-4 *2 (-432 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-1 (-121) *5)) (-4 *5 (-1195)) (-5 *2 (-310 (-568))) (-5 *1 (-939 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-634 (-1 (-121) *5))) (-4 *5 (-1195)) (-5 *2 (-310 (-568))) (-5 *1 (-939 *5)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-1 (-121) (-634 *6))) (-4 *6 (-13 (-432 *5) (-881 *4) (-609 (-887 *4)))) (-4 *4 (-1090)) (-4 *5 (-13 (-1047) (-881 *4) (-842) (-609 (-887 *4)))) (-5 *1 (-1069 *4 *5 *6))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 *2))) (-5 *2 (-887 *3)) (-5 *1 (-1069 *3 *4 *5)) (-4 *5 (-13 (-432 *4) (-881 *3) (-609 *2)))))) 
-(((*1 *2 *2) (|partial| -12 (-5 *2 (-634 (-953 *3))) (-4 *3 (-453)) (-5 *1 (-362 *3 *4)) (-14 *4 (-634 (-1161))))) ((*1 *2 *2) (|partial| -12 (-5 *2 (-634 (-775 *3 (-852 *4)))) (-4 *3 (-453)) (-14 *4 (-634 (-1161))) (-5 *1 (-619 *3 *4))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-409 (-953 *4))) (-5 *1 (-924 *4 *5 *6 *3)) (-4 *3 (-950 *4 *6 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-679 *7)) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-679 (-409 (-953 *4)))) (-5 *1 (-924 *4 *5 *6 *7)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-950 *4 *6 *5)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 (-409 (-953 *4)))) (-5 *1 (-924 *4 *5 *6 *7))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *7 *7)) (-4 *7 (-1219 *6)) (-4 *6 (-13 (-27) (-432 *5))) (-4 *5 (-13 (-842) (-558) (-1037 (-568)))) (-4 *8 (-1219 (-409 *7))) (-5 *2 (-585 *3)) (-5 *1 (-553 *5 *6 *7 *8 *3)) (-4 *3 (-340 *6 *7 *8))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 *5 *5)) (-4 *1 (-340 *4 *5 *6)) (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-5 *2 (-2 (|:| |num| (-679 *5)) (|:| |den| *5)))))) 
-(((*1 *1) (-12 (-4 *1 (-470 *2 *3)) (-4 *2 (-172)) (-4 *3 (-23)))) ((*1 *1) (-5 *1 (-541))) ((*1 *1) (-4 *1 (-712))) ((*1 *1) (-4 *1 (-716))) ((*1 *1) (-12 (-5 *1 (-887 *2)) (-4 *2 (-1090)))) ((*1 *1) (-12 (-5 *1 (-888 *2)) (-4 *2 (-842))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-634 *3)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef1| *3) (|:| |coef2| *3) (|:| -4265 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2) (-12 (-4 *4 (-365)) (-5 *2 (-917)) (-5 *1 (-326 *3 *4)) (-4 *3 (-327 *4)))) ((*1 *2) (-12 (-4 *4 (-365)) (-5 *2 (-828 (-917))) (-5 *1 (-326 *3 *4)) (-4 *3 (-327 *4)))) ((*1 *2) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-5 *2 (-917)))) ((*1 *2) (-12 (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-5 *2 (-828 (-917)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-333 *3 *4 *5 *6)) (-4 *3 (-365)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-4 *6 (-340 *3 *4 *5)) (-5 *2 (-415 *4 (-409 *4) *5 *6)))) ((*1 *1 *2) (-12 (-5 *2 (-1244 *6)) (-4 *6 (-13 (-411 *4 *5) (-1037 *4))) (-4 *4 (-993 *3)) (-4 *5 (-1219 *4)) (-4 *3 (-301)) (-5 *1 (-415 *3 *4 *5 *6)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-514 *3 *4 *5 *6))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-5 *1 (-123)))) ((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-123)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-246 *4 *3 *5 *6)) (-4 *4 (-1047)) (-4 *3 (-842)) (-4 *5 (-262 *3)) (-4 *6 (-788)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-246 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-842)) (-4 *5 (-262 *4)) (-4 *6 (-788)) (-5 *2 (-763)))) ((*1 *2 *1) (-12 (-4 *1 (-262 *3)) (-4 *3 (-842)) (-5 *2 (-763))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1242 *2)) (-4 *2 (-1195)) (-4 *2 (-1002)) (-4 *2 (-1047))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2850 *4) (|:| -2183 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568))))) 
-(((*1 *1 *1 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3))) ((*1 *1 *2 *3 *1) (-12 (-5 *1 (-638 *2 *3 *4)) (-4 *2 (-1090)) (-4 *3 (-23)) (-14 *4 *3))) ((*1 *1 *1 *1) (-12 (-5 *1 (-666 *2)) (-4 *2 (-1047)) (-4 *2 (-1090))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *3 (-971 *4)) (-4 *8 (-641 *4)) (-4 *9 (-920 *4 *8)) (-4 *10 (-235 *9)) (-4 *11 (-536 *4 *5 *6 *7 *3 *8 *9 *10 *13)) (-4 *13 (-117)) (-5 *2 (-634 *9)) (-5 *1 (-467 *4 *5 *6 *7 *3 *8 *9 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *2 *3) (-12 (-5 *3 (-967 *4)) (-4 *4 (-350)) (-5 *2 (-634 (-922 *4))) (-5 *1 (-867 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-966 *4)) (-4 *4 (-365)) (-5 *2 (-634 (-921 *4))) (-5 *1 (-868 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-250))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-4 *7 (-950 *4 *6 *5)) (-5 *2 (-2 (|:| |sysok| (-121)) (|:| |z0| (-634 *7)) (|:| |n0| (-634 *7)))) (-5 *1 (-924 *4 *5 *6 *7)) (-5 *3 (-634 *7))))) 
-(((*1 *2) (-12 (-4 *3 (-13 (-842) (-558) (-1037 (-568)))) (-5 *2 (-1249)) (-5 *1 (-435 *3 *4)) (-4 *4 (-432 *3))))) 
-(((*1 *1 *2 *3) (-12 (-5 *3 (-568)) (-5 *1 (-420 *2)) (-4 *2 (-558))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-558) (-842) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-2 (|:| |func| *3) (|:| |kers| (-634 (-607 *3))) (|:| |vals| (-634 *3)))) (-5 *1 (-273 *5 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *5)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-944 *3)) (-4 *3 (-13 (-365) (-1181) (-1002))) (-5 *1 (-174 *3))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-123)) (-5 *1 (-122 *3)) (-4 *3 (-842)) (-4 *3 (-1090))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-1141 (-215))) (-5 *1 (-184)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-310 (-215))) (-5 *4 (-634 (-1161))) (-5 *5 (-1084 (-835 (-215)))) (-5 *2 (-1141 (-215))) (-5 *1 (-294)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1244 (-310 (-215)))) (-5 *4 (-634 (-1161))) (-5 *5 (-1084 (-835 (-215)))) (-5 *2 (-1141 (-215))) (-5 *1 (-294))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1176))))) 
-(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-1087 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1163 (-409 (-568)))) (-5 *1 (-182)) (-5 *3 (-568))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-147))))) 
-(((*1 *2 *3 *2) (-12 (-4 *2 (-13 (-365) (-840))) (-5 *1 (-178 *2 *3)) (-4 *3 (-1219 (-169 *2))))) ((*1 *2 *3) (-12 (-4 *2 (-13 (-365) (-840))) (-5 *1 (-178 *2 *3)) (-4 *3 (-1219 (-169 *2)))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-634 (-953 *4))) (-5 *3 (-634 (-1161))) (-4 *4 (-453)) (-5 *1 (-914 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 *5 *5 *5)) (-4 *5 (-1234 *4)) (-4 *4 (-43 (-409 (-568)))) (-5 *2 (-1 (-1141 *4) (-1141 *4) (-1141 *4))) (-5 *1 (-1236 *4 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-840)) (-4 *4 (-365)) (-5 *2 (-763)) (-5 *1 (-946 *4 *5)) (-4 *5 (-1219 *4))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1 (-944 *3) (-944 *3))) (-5 *1 (-174 *3)) (-4 *3 (-13 (-365) (-1181) (-1002)))))) 
-(((*1 *2 *2 *3 *4 *4) (-12 (-5 *4 (-568)) (-4 *3 (-172)) (-4 *5 (-375 *3)) (-4 *6 (-375 *3)) (-5 *1 (-678 *3 *5 *6 *2)) (-4 *2 (-677 *3 *5 *6))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1093 *2 *3 *4 *5 *6)) (-4 *2 (-1090)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090))))) 
-(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-365)) (-5 *1 (-758 *2 *3)) (-4 *2 (-698 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *3 (-944 *4)) (-4 *1 (-1122 *4)) (-4 *4 (-1047)))) ((*1 *2 *1 *3 *4) (-12 (-5 *3 (-763)) (-5 *4 (-944 (-215))) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
-(((*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| |coef1| *1) (|:| |coef2| *1) (|:| -2704 *1))) (-4 *1 (-844 *3))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-677 *4 *5 *6)) (-5 *1 (-108 *4 *3 *2 *5 *6)) (-4 *3 (-1219 *4)) (-4 *5 (-375 *4)) (-4 *6 (-375 *4))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-301)) (-5 *1 (-689 *3))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-1093 *2 *3 *4 *5 *6)) (-4 *2 (-1090)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)) (-4 *2 (-550)))) ((*1 *1 *1) (-4 *1 (-1056)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-917)) (-5 *1 (-781))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1157 *7)) (-4 *7 (-950 *6 *4 *5)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1047)) (-5 *2 (-1157 *6)) (-5 *1 (-318 *4 *5 *6 *7))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-129 *3)) (-4 *3 (-1219 (-568)))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-1 (-121) (-123) (-123))) (-5 *1 (-123))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 *3)) (-5 *1 (-924 *4 *5 *6 *3)) (-4 *3 (-950 *4 *6 *5))))) 
-(((*1 *2 *2 *3) (-12 (-4 *3 (-365)) (-5 *1 (-280 *3 *2)) (-4 *2 (-1234 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-409 *5)) (-4 *5 (-1219 *4)) (-4 *4 (-558)) (-4 *4 (-1047)) (-4 *2 (-1234 *4)) (-5 *1 (-1237 *4 *5 *6 *2)) (-4 *6 (-646 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-634 (-944 (-215))))) (-5 *2 (-634 (-215))) (-5 *1 (-473))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-917)) (-4 *1 (-920 *4 *5)) (-4 *4 (-365)) (-4 *5 (-641 *4)) (-5 *2 (-1249))))) 
-(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-634 (-1244 *4))) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-4 *3 (-558)) (-5 *2 (-634 (-1244 *3)))))) 
-(((*1 *2 *2 *3 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-568)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-450 *4 *5 *6 *7))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-256))) (-5 *4 (-1161)) (-5 *2 (-121)) (-5 *1 (-256)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-465))) (-5 *4 (-1161)) (-5 *2 (-121)) (-5 *1 (-465))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-1161)) (-5 *2 (-1165)) (-5 *1 (-1164))))) 
-(((*1 *1 *2) (-12 (-5 *1 (-1026 *2)) (-4 *2 (-1195))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3 *3 *3 *3)) (-4 *3 (-1090)) (-5 *1 (-106 *3)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-1 *2 *2 *2)) (-5 *1 (-106 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-473)) (-5 *4 (-917)) (-5 *2 (-1249)) (-5 *1 (-1245))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-37 *3)) (-4 *3 (-365)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-634 *1)) (-5 *3 (-763)) (-4 *1 (-37 *4)) (-4 *4 (-365)))) ((*1 *2 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-971 *3)) (-4 *3 (-365)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-634 *1)) (-5 *3 (-763)) (-4 *1 (-971 *4)) (-4 *4 (-365))))) 
-(((*1 *2 *3 *1) (-12 (-4 *1 (-977 *4 *5 *6 *3)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-5 *2 (-2 (|:| |rnum| *4) (|:| |polnum| *3) (|:| |den| *4)))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1249)) (-5 *1 (-450 *4 *5 *6 *3)) (-4 *3 (-950 *4 *5 *6))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))) (-5 *1 (-444 *4 *3 *2)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *1 *1) (-12 (-4 *1 (-301)) (-5 *2 (-121))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-665 *2)) (-4 *2 (-1195))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-850))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1219 (-409 *2))) (-5 *2 (-568)) (-5 *1 (-909 *4 *3)) (-4 *3 (-1219 (-409 *4)))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3001 *4)))) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-173 *2)) (-4 *2 (-301)))) ((*1 *2 *1) (-12 (-5 *1 (-910 *2)) (-4 *2 (-301)))) ((*1 *2 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558)) (-4 *2 (-301)))) ((*1 *2 *1) (-12 (-4 *1 (-1056)) (-5 *2 (-568))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1094)) (-5 *1 (-328))))) 
-(((*1 *2 *3 *3 *3) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1100)) (-5 *3 (-568))))) 
-(((*1 *2 *1 *3) (-12 (-4 *1 (-340 *4 *3 *5)) (-4 *4 (-1199)) (-4 *3 (-1219 *4)) (-4 *5 (-1219 (-409 *3))) (-5 *2 (-121)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1093 *3 *4 *5 *6 *7)) (-4 *3 (-1090)) (-4 *4 (-1090)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *7 (-1090)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1 (-634 *5) *6)) (-4 *5 (-13 (-365) (-150) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-5 *2 (-634 (-2 (|:| -3495 *5) (|:| -1853 *3)))) (-5 *1 (-804 *5 *6 *3 *7)) (-4 *3 (-646 *6)) (-4 *7 (-646 (-409 *6)))))) 
-(((*1 *1 *2 *2 *2 *2 *2 *3 *4) (-12 (-5 *2 (-568)) (-5 *3 (-121)) (-5 *4 (-3 "left" "center" "right" "vertical" "horizontal")) (-4 *1 (-117))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-246 *2 *3 *4 *5)) (-4 *2 (-1047)) (-4 *3 (-842)) (-4 *4 (-262 *3)) (-4 *5 (-788))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1092 (-1161))) (-5 *1 (-58)) (-5 *3 (-1161))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-121)) (-5 *3 (-634 (-256))) (-5 *1 (-254))))) 
-(((*1 *2 *3 *4) (|partial| -12 (-5 *3 (-123)) (-5 *4 (-634 *2)) (-5 *1 (-122 *2)) (-4 *2 (-1090)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *4 (-634 *4))) (-4 *4 (-1090)) (-5 *1 (-122 *4)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *4 *4)) (-4 *4 (-1090)) (-5 *1 (-122 *4)))) ((*1 *2 *3) (|partial| -12 (-5 *3 (-123)) (-5 *2 (-1 *4 (-634 *4))) (-5 *1 (-122 *4)) (-4 *4 (-1090)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 *4 *4)) (-4 *4 (-637 *3)) (-4 *3 (-1047)) (-5 *1 (-704 *3 *4)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1 *3 *3)) (-4 *3 (-1047)) (-5 *1 (-829 *3))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-256))) (-5 *1 (-1245)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-256))) (-5 *1 (-1245)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-256))) (-5 *1 (-1246)))) ((*1 *2 *1) (-12 (-5 *2 (-634 (-256))) (-5 *1 (-1246))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246)))) ((*1 *2) (-12 (-5 *2 (-381)) (-5 *1 (-1246))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-381))) (-5 *1 (-1039))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-450 *4 *5 *6 *2))))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1249)) (-5 *1 (-1245)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1249)) (-5 *1 (-1246))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-842)) (-5 *2 (-2 (|:| |f1| (-634 *4)) (|:| |f2| (-634 (-634 (-634 *4)))) (|:| |f3| (-634 (-634 *4))) (|:| |f4| (-634 (-634 (-634 *4)))))) (-5 *1 (-1167 *4)) (-5 *3 (-634 (-634 (-634 *4))))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-1047)) (-5 *1 (-889 *2 *3)) (-4 *2 (-1219 *3)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3))))) 
-(((*1 *1 *1) (-4 *1 (-858)))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1090)) (-5 *1 (-1132 *3))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-634 (-2 (|:| |lcmfij| *5) (|:| |totdeg| (-763)) (|:| |poli| *3) (|:| |polj| *3)))) (-4 *5 (-788)) (-4 *3 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *6 (-842)) (-5 *1 (-450 *4 *5 *6 *3))))) 
-(((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-563))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-1006))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-288 (-409 (-953 *5)))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-1150 (-634 (-310 *5)) (-634 (-288 (-310 *5))))) (-5 *1 (-1117 *5)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-953 *5))) (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150))) (-5 *2 (-1150 (-634 (-310 *5)) (-634 (-288 (-310 *5))))) (-5 *1 (-1117 *5))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-1161)) (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-288 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-4 *3 (-1090)) (-4 *2 (-13 (-432 *4) (-881 *3) (-609 (-887 *3)))) (-5 *1 (-1069 *3 *4 *2)) (-4 *4 (-13 (-1047) (-881 *3) (-842) (-609 (-887 *3)))))) ((*1 *2 *1) (-12 (-4 *2 (-1090)) (-5 *1 (-1150 *2 *3)) (-4 *3 (-1090))))) 
-(((*1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-234))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-365)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-529 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-555 *2)) (-4 *2 (-13 (-406) (-1181))))) ((*1 *1 *1 *1) (-4 *1 (-788)))) 
-(((*1 *2) (-12 (-4 *1 (-406)) (-5 *2 (-917)))) ((*1 *1) (-4 *1 (-550))) ((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-688)))) ((*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-688)))) ((*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-899 *3)) (-4 *3 (-1090))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-1108)) (-5 *2 (-121)) (-5 *1 (-816))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-171))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-37 *2)) (-4 *2 (-365)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-37 *3)) (-4 *3 (-365)))) ((*1 *1 *1) (-12 (-4 *1 (-166 *2)) (-4 *2 (-172)))) ((*1 *1 *1 *1) (-4 *1 (-478))) ((*1 *1 *1) (-12 (-4 *1 (-792 *2)) (-4 *2 (-172)))) ((*1 *1 *1) (-4 *1 (-858))) ((*1 *2 *2) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-878)))) ((*1 *1 *1) (-12 (-4 *1 (-971 *2)) (-4 *2 (-365)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-971 *3)) (-4 *3 (-365)))) ((*1 *1 *1) (-5 *1 (-972))) ((*1 *1 *1) (-12 (-4 *1 (-997 *2)) (-4 *2 (-172))))) 
-(((*1 *1 *1 *1 *1) (-4 *1 (-550)))) 
-(((*1 *2 *2 *2 *3 *3) (-12 (-5 *3 (-763)) (-4 *4 (-1047)) (-5 *1 (-1215 *4 *2)) (-4 *2 (-1219 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1 *6 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-5 *2 (-1 *6 *4 *5)) (-5 *1 (-673 *4 *5 *6)) (-4 *4 (-1090))))) 
-(((*1 *2 *3 *4 *4 *4 *5 *4 *5 *5 *3) (-12 (-5 *3 (-568)) (-5 *4 (-679 (-215))) (-5 *5 (-215)) (-5 *2 (-1035)) (-5 *1 (-743))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-350)) (-5 *2 (-958 (-1108))) (-5 *1 (-347 *4))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (-12 (-5 *3 (-1 (-381) (-381))) (-5 *4 (-381)) (-5 *2 (-2 (|:| -2850 *4) (|:| -2183 *4) (|:| |totalpts| (-568)) (|:| |success| (-121)))) (-5 *1 (-784)) (-5 *5 (-568))))) 
-(((*1 *2 *2) (|partial| -12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3))))) 
-(((*1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-751))))) 
-(((*1 *2) (-12 (-4 *3 (-1047)) (-5 *2 (-958 (-702 *3 *4))) (-5 *1 (-702 *3 *4)) (-4 *4 (-1219 *3))))) 
-(((*1 *2 *3 *4 *4) (-12 (-5 *4 (-607 *3)) (-4 *3 (-13 (-432 *5) (-27) (-1181))) (-4 *5 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-570 *5 *3 *6)) (-4 *6 (-1090))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-950 *4 *5 *6)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-450 *4 *5 *6 *2))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1 *2 *6)) (-5 *4 (-1 *6 *5)) (-4 *5 (-1090)) (-4 *6 (-1090)) (-4 *2 (-1090)) (-5 *1 (-670 *5 *6 *2))))) 
-(((*1 *2 *1) (-12 (-14 *3 (-634 (-1161))) (-4 *4 (-172)) (-4 *5 (-230 (-1697 *3) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4355 *2) (|:| -3438 *5)) (-2 (|:| -4355 *2) (|:| -3438 *5)))) (-4 *2 (-842)) (-5 *1 (-463 *3 *4 *2 *5 *6 *7)) (-4 *7 (-950 *4 *5 (-852 *3)))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-4 *1 (-320 *4 *2)) (-4 *4 (-1090)) (-4 *2 (-137))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1122 *3)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -1526 (-763)) (|:| |curves| (-763)) (|:| |polygons| (-763)) (|:| |constructs| (-763))))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-634 *6)) (-5 *4 (-1 *6 (-763) (-1244 (-1157 *6)))) (-5 *5 (-634 (-763))) (-4 *6 (-13 (-558) (-453))) (-5 *2 (-679 (-1157 *6))) (-5 *1 (-346 *6 *7)) (-4 *7 (-52 *6 (-763)))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1249)) (-5 *1 (-381)))) ((*1 *2) (-12 (-5 *2 (-1249)) (-5 *1 (-381))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-235 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *2 *3 *2 *4) (-12 (-5 *3 (-123)) (-5 *4 (-763)) (-4 *5 (-453)) (-4 *5 (-842)) (-4 *5 (-1037 (-568))) (-4 *5 (-558)) (-5 *1 (-46 *5 *2)) (-4 *2 (-432 *5)) (-4 *2 (-13 (-365) (-296) (-10 -8 (-15 -2317 ((-1113 *5 (-607 $)) $)) (-15 -2324 ((-1113 *5 (-607 $)) $)) (-15 -2745 ($ (-1113 *5 (-607 $)))))))))) 
-(((*1 *1 *2 *2 *2) (-12 (-5 *1 (-877 *2)) (-4 *2 (-1195))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-1161))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *7)) (-4 *7 (-1061 *4 *5 *6)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)) (-5 *1 (-978 *4 *5 *6 *7))))) 
-(((*1 *1 *2 *3) (-12 (-5 *2 (-763)) (-5 *1 (-64 *3)) (-4 *3 (-1195)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-1195)) (-5 *1 (-64 *3))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-679 *5))) (-5 *4 (-568)) (-4 *5 (-365)) (-4 *5 (-1047)) (-5 *2 (-121)) (-5 *1 (-1029 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-679 *4))) (-4 *4 (-365)) (-4 *4 (-1047)) (-5 *2 (-121)) (-5 *1 (-1029 *4))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-977 *3 *4 *5 *6)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-634 *5))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-43 (-409 (-568)))) (-5 *2 (-2 (|:| -2786 (-1141 *4)) (|:| -2790 (-1141 *4)))) (-5 *1 (-1147 *4)) (-5 *3 (-1141 *4))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-1160)) (-5 *1 (-328))))) 
-(((*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-126 *3)) (-14 *3 *2))) ((*1 *1 *1) (-12 (-5 *1 (-126 *2)) (-14 *2 (-568)))) ((*1 *1 *1) (-12 (-4 *1 (-641 *2)) (-4 *2 (-365)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-4 *1 (-641 *3)) (-4 *3 (-365)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-865 *3)) (-14 *3 *2))) ((*1 *1 *1) (-12 (-5 *1 (-865 *2)) (-14 *2 (-568)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-14 *3 *2) (-5 *1 (-866 *3 *4)) (-4 *4 (-863 *3)))) ((*1 *1 *1) (-12 (-14 *2 (-568)) (-5 *1 (-866 *2 *3)) (-4 *3 (-863 *2)))) ((*1 *1 *2 *1) (-12 (-5 *2 (-568)) (-4 *1 (-1205 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1234 *3)))) ((*1 *1 *1) (-12 (-4 *1 (-1205 *2 *3)) (-4 *2 (-1047)) (-4 *3 (-1234 *2))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *5)) (-4 *5 (-172)) (-5 *1 (-141 *3 *4 *5)) (-14 *3 (-568)) (-14 *4 (-763))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-910 *3)) (-4 *3 (-301))))) 
-(((*1 *2 *2 *3) (-12 (-4 *4 (-1090)) (-4 *2 (-895 *4)) (-5 *1 (-681 *4 *2 *5 *3)) (-4 *5 (-375 *2)) (-4 *3 (-13 (-375 *4) (-10 -7 (-6 -4519))))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-634 (-634 *8))) (-5 *3 (-634 *8)) (-4 *8 (-950 *5 *7 *6)) (-4 *5 (-13 (-301) (-150))) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-121)) (-5 *1 (-924 *5 *6 *7 *8))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *2 (-13 (-406) (-1037 *4) (-365) (-1181) (-279))) (-5 *1 (-444 *4 *3 *2)) (-4 *3 (-1219 *4)))) ((*1 *2 *3 *4) (-12 (-5 *4 (-917)) (-4 *5 (-1047)) (-4 *2 (-13 (-406) (-1037 *5) (-365) (-1181) (-279))) (-5 *1 (-444 *5 *3 *2)) (-4 *3 (-1219 *5))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-453)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-450 *3 *4 *5 *2)) (-4 *2 (-950 *3 *4 *5))))) 
-(((*1 *2 *1 *1) (|partial| -12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)) (-5 *2 (-1157 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-327 *3)) (-4 *3 (-365)) (-4 *3 (-370)) (-5 *2 (-1157 *3))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-121)) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 (-2 (|:| |val| (-121)) (|:| -3001 *4)))) (-5 *1 (-1067 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1173 *3 *4)) (-4 *3 (-1090)) (-4 *4 (-1090))))) 
-(((*1 *2 *1 *3 *4) (-12 (-5 *3 (-917)) (-5 *4 (-1143)) (-5 *2 (-1249)) (-5 *1 (-1245))))) 
-(((*1 *2) (-12 (-4 *1 (-350)) (-5 *2 (-634 (-2 (|:| -3848 (-568)) (|:| -3438 (-568)))))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-135 *3))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-558)) (-5 *2 (-763)) (-5 *1 (-48 *4 *3)) (-4 *3 (-419 *4))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-1061 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1189 *4 *5 *6 *3)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-53))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-53))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-482)))) ((*1 *2 *3) (-12 (-4 (-53) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-53)) (-634 (-465)))) (-5 *1 (-482)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-13 (-350) (-609 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-484 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-484 *4)) (-4 *4 (-1037 *3)) (-4 *4 (-13 (-350) (-609 (-568)))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-568)))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-485)))) ((*1 *2 *3) (-12 (-4 (-409 (-568)) (-1037 *3)) (-4 (-568) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-568))) (-634 (-465)))) (-5 *1 (-485)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 *5)) (-5 *4 (-634 (-465))) (-4 *5 (-365)) (-14 *10 (-1 *7 *5)) (-4 *8 (-13 (-842) (-558))) (-14 *9 (-1 *5 *8)) (-5 *2 (-634 (-2 (|:| -1864 *7) (|:| -4477 (-763))))) (-5 *1 (-486 *5 *6 *7 *8 *9 *10)) (-4 *6 (-453)) (-4 *7 (-13 (-432 (-568)) (-558) (-1037 *8) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-14 *9 (-1 *6 *4)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763))))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 (-1161)) (-1037 (-568)) (-161) (-895 (-1161)) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *7 (-13 (-842) (-558))) (-14 *8 (-1 *4 *7)) (-5 *2 (-1 (-634 (-2 (|:| -1864 *6) (|:| -4477 (-763)))) (-634 *4) (-634 (-465)))) (-5 *1 (-486 *4 *5 *6 *7 *8 *9)) (-4 *4 (-1037 *3)) (-4 *5 (-1037 *3)) (-4 *4 (-365)) (-4 *5 (-453)) (-4 *6 (-13 (-432 (-568)) (-558) (-1037 *7) (-1037 *3) (-1037 (-568)) (-161) (-895 *3) (-10 -8 (-15 * ($ $ $)) (-15 -1779 ($ $ $)) (-15 ** ($ $ $)) (-15 -1332 ($ $)) (-15 -3013 ($ $)) (-15 -2086 ((-121) $))))) (-14 *9 (-1 *6 *4)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *4 (-634 (-465))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-953 (-568))))) (-5 *2 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763))))) (-5 *1 (-487)))) ((*1 *2 *3) (-12 (-4 (-409 (-953 (-568))) (-1037 *3)) (-4 (-953 (-568)) (-1037 *3)) (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-310 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-953 (-568)))) (-634 (-465)))) (-5 *1 (-487)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-409 (-734 *5 (-568))))) (-5 *4 (-634 (-465))) (-14 *5 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *5 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *5)))) ((*1 *2 *3) (-12 (-5 *3 (-634 (-409 (-734 *4 (-568))))) (-14 *4 (-1161)) (-5 *2 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763))))) (-5 *1 (-488 *4)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-5 *2 (-1 (-634 (-2 (|:| -1864 (-733 *4 (-568))) (|:| -4477 (-763)))) (-634 (-409 (-734 *4 (-568)))) (-634 (-465)))) (-5 *1 (-488 *4)) (-14 *4 *3)))) 
-(((*1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-1006))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1157 *4)) (-4 *4 (-350)) (-4 *2 (-13 (-404) (-10 -7 (-15 -2745 (*2 *4)) (-15 -3683 ((-917) *2)) (-15 -3746 ((-1244 *2) (-917))) (-15 -1316 (*2 *2))))) (-5 *1 (-357 *2 *4))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *13)) (-4 *13 (-117)) (-5 *2 (-1249)) (-5 *1 (-260 *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (-4 *3 (-258 *12))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-763))) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
-(((*1 *2) (-12 (-5 *2 (-917)) (-5 *1 (-690)))) ((*1 *2 *2) (-12 (-5 *2 (-917)) (-5 *1 (-690))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))))) (-5 *2 (-1035)) (-5 *1 (-299)))) ((*1 *2 *3) (-12 (-5 *3 (-2 (|:| -3029 (-381)) (|:| -3391 (-1143)) (|:| |explanations| (-634 (-1143))) (|:| |extra| (-1035)))) (-5 *2 (-1035)) (-5 *1 (-299))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1143)) (-5 *1 (-1177)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-1143)) (-5 *1 (-1177))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-763)) (-5 *2 (-1 (-1141 (-953 *4)) (-1141 (-953 *4)))) (-5 *1 (-1252 *4)) (-4 *4 (-365))))) 
+(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-139))))) 
 (((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-272 *3 *2)) (-4 *2 (-13 (-432 *3) (-1002)))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-240 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-465))) (-5 *2 (-1161)) (-5 *1 (-464)))) ((*1 *1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-465))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-169 (-215))) (-5 *2 (-215)) (-5 *1 (-115))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-568))) (-5 *1 (-1004 *3)) (-14 *3 (-568))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-242 (-4287 (QUOTE X) (QUOTE -2926)) *3)) (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))) (-5 *2 (-3 (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))) (-5 *1 (-184))))) 
-(((*1 *2 *1) (-12 (-4 *3 (-365)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)) (-5 *1 (-514 *3 *4 *5 *6)) (-4 *6 (-950 *3 *4 *5)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-634 *6)) (-4 *6 (-842)) (-4 *4 (-365)) (-4 *5 (-788)) (-5 *2 (-121)) (-5 *1 (-514 *4 *5 *6 *7)) (-4 *7 (-950 *4 *5 *6))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-121)) (-5 *1 (-44 *3)) (-4 *3 (-1219 (-53)))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-917)) (-4 *1 (-230 *3 *4)) (-4 *4 (-1047)) (-4 *4 (-1195)))) ((*1 *1 *2) (-12 (-14 *3 (-634 (-1161))) (-4 *4 (-172)) (-4 *5 (-230 (-1697 *3) (-763))) (-14 *6 (-1 (-121) (-2 (|:| -4355 *2) (|:| -3438 *5)) (-2 (|:| -4355 *2) (|:| -3438 *5)))) (-5 *1 (-463 *3 *4 *2 *5 *6 *7)) (-4 *2 (-842)) (-4 *7 (-950 *4 *5 (-852 *3))))) ((*1 *2 *2) (-12 (-5 *2 (-944 (-215))) (-5 *1 (-1192))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-679 *3)) (-4 *3 (-365)) (-5 *1 (-653 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-887 *4)) (-4 *4 (-1090)) (-5 *2 (-1 (-121) *5)) (-5 *1 (-885 *4 *5)) (-4 *5 (-1195))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *2 *2) (|partial| -12 (-4 *1 (-984 *2)) (-4 *2 (-1181))))) 
-(((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-850))) (-5 *1 (-1161))))) 
-(((*1 *2 *3 *4) (-12 (-4 *6 (-558)) (-4 *2 (-950 *3 *5 *4)) (-5 *1 (-722 *5 *4 *6 *2)) (-5 *3 (-409 (-953 *6))) (-4 *5 (-788)) (-4 *4 (-13 (-842) (-10 -8 (-15 -4278 ((-1161) $)))))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-96 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-212 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-842)) (-5 *2 (-121)) (-5 *1 (-494 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| *1 (-6 -4519)) (-4 *1 (-499 *4)) (-4 *4 (-1195)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-1000 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-1132 *4))))) 
-(((*1 *1 *1 *2 *1) (-12 (-4 *1 (-1129)) (-5 *2 (-1210 (-568)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-634 (-2 (|:| |flg| (-3 "nil" "sqfr" "irred" "prime")) (|:| |fctr| *3) (|:| |xpnt| (-568))))) (-5 *1 (-420 *3)) (-4 *3 (-558)))) ((*1 *2 *3 *4 *4 *4) (-12 (-5 *4 (-763)) (-4 *3 (-350)) (-4 *5 (-1219 *3)) (-5 *2 (-634 (-1157 *3))) (-5 *1 (-507 *3 *5 *6)) (-4 *6 (-1219 *5))))) 
-(((*1 *2 *2 *2 *3 *4) (-12 (-5 *3 (-101 *5)) (-5 *4 (-1 *5 *5)) (-4 *5 (-1047)) (-5 *1 (-845 *5 *2)) (-4 *2 (-844 *5))))) 
-(((*1 *2 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *2 *1) (-12 (-4 *1 (-995 *2)) (-4 *2 (-1195)))) ((*1 *2 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *2 *2) (-12 (-4 *3 (-365)) (-5 *1 (-758 *2 *3)) (-4 *2 (-698 *3)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-844 *2)) (-4 *2 (-1047)) (-4 *2 (-365))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-568)) (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *1) (-5 *1 (-439)))) 
-(((*1 *2 *1) (-12 (-5 *2 (-568)) (-5 *1 (-147))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *2)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *2 (-117))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-634 *6))))) 
-(((*1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-1247))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-917)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-634 *10)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) ((*1 *2 *3 *4 *5) (-12 (-5 *3 (-917)) (-5 *5 (-634 *9)) (-4 *9 (-971 *6)) (-4 *6 (-365)) (-14 *7 (-634 (-1161))) (-4 *4 (-950 *6 *8 (-852 *7))) (-4 *8 (-230 (-1697 *7) (-763))) (-4 *10 (-641 *6)) (-4 *11 (-920 *6 *10)) (-4 *12 (-235 *11)) (-4 *13 (-536 *6 *7 *4 *8 *9 *10 *11 *12 *15)) (-4 *15 (-117)) (-5 *2 (-1249)) (-5 *1 (-556 *6 *7 *4 *8 *9 *10 *11 *12 *13 *14 *15)) (-4 *14 (-258 *13)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-634 (-922 *4))) (-5 *1 (-867 *4 *5 *6)) (-4 (-857 *4) (-370)) (-4 *4 (-350)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-634 (-921 *4))) (-5 *1 (-868 *4 *5 *6)) (-4 *4 (-370)) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-117))))) 
-(((*1 *2 *2 *3 *2) (-12 (-5 *2 (-1143)) (-5 *3 (-568)) (-5 *1 (-234)))) ((*1 *2 *2 *3 *4) (-12 (-5 *2 (-634 (-1143))) (-5 *3 (-568)) (-5 *4 (-1143)) (-5 *1 (-234)))) ((*1 *1 *1) (-5 *1 (-850))) ((*1 *1 *1 *2) (-12 (-5 *2 (-568)) (-5 *1 (-850)))) ((*1 *2 *1) (-12 (-4 *1 (-1221 *2 *3)) (-4 *3 (-787)) (-4 *2 (-1047))))) 
-(((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-989 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *3 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-1249)) (-5 *1 (-1097 *4 *5 *6 *7 *8)) (-4 *8 (-1066 *4 *5 *6 *7))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1 *2 *2)) (-4 *5 (-365)) (-4 *6 (-1219 (-409 *2))) (-4 *2 (-1219 *5)) (-5 *1 (-206 *5 *2 *6 *3)) (-4 *3 (-340 *5 *2 *6))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-4 *3 (-558)) (-5 *2 (-1157 *3))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-4 *4 (-13 (-301) (-150))) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *2 (-634 (-2 (|:| |eqzro| (-634 *7)) (|:| |neqzro| (-634 *7)) (|:| |wcond| (-634 (-953 *4))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *4)))) (|:| -3746 (-634 (-1244 (-409 (-953 *4)))))))))) (-5 *1 (-924 *4 *5 *6 *7)) (-4 *7 (-950 *4 *6 *5))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-215)) (-5 *1 (-217)))) ((*1 *2 *2 *2) (-12 (-5 *2 (-169 (-215))) (-5 *1 (-217)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *1 *1 *1) (-4 *1 (-1124)))) 
-(((*1 *2 *1) (-12 (-4 *1 (-665 *3)) (-4 *3 (-1195)) (-5 *2 (-121))))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-4 *1 (-730 *4 *5)) (-4 *4 (-1047)) (-4 *5 (-842)) (-5 *2 (-953 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-730 *4 *5)) (-4 *4 (-1047)) (-4 *5 (-842)) (-5 *2 (-953 *4)))) ((*1 *2 *1 *3 *3) (-12 (-5 *3 (-763)) (-4 *1 (-1234 *4)) (-4 *4 (-1047)) (-5 *2 (-953 *4)))) ((*1 *2 *1 *3) (-12 (-5 *3 (-763)) (-4 *1 (-1234 *4)) (-4 *4 (-1047)) (-5 *2 (-953 *4))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-558)) (-5 *2 (-2 (|:| -2928 (-679 *5)) (|:| |vec| (-1244 (-634 (-917)))))) (-5 *1 (-95 *5 *3)) (-5 *4 (-917)) (-4 *3 (-646 *5))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-763)) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-634 (-679 (-568)))) (-5 *1 (-1100))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-763)) (-4 *6 (-365)) (-5 *4 (-1190 *6)) (-5 *2 (-1 (-1141 *4) (-1141 *4))) (-5 *1 (-1252 *6)) (-5 *5 (-1141 *4))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-1061 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1189 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-4 *6 (-1061 *3 *4 *5)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-4 *1 (-1189 *4 *5 *6 *3)) (-4 *4 (-558)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *3 (-1061 *4 *5 *6)) (-5 *2 (-121))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1244 (-763))) (-5 *1 (-666 *3)) (-4 *3 (-1090))))) 
-(((*1 *1) (-5 *1 (-439)))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 *3)) (-4 *3 (-842)) (-5 *1 (-494 *3))))) 
-(((*1 *1 *2 *1) (-12 (-5 *1 (-130 *2)) (-4 *2 (-842))))) 
-(((*1 *2 *3 *4 *4 *5) (|partial| -12 (-5 *4 (-607 *3)) (-5 *5 (-634 *3)) (-4 *3 (-13 (-432 *6) (-27) (-1181))) (-4 *6 (-13 (-453) (-1037 (-568)) (-842) (-150) (-630 (-568)))) (-5 *2 (-2 (|:| |mainpart| *3) (|:| |limitedlogs| (-634 (-2 (|:| |coeff| *3) (|:| |logand| *3)))))) (-5 *1 (-570 *6 *3 *7)) (-4 *7 (-1090))))) 
-(((*1 *1) (-5 *1 (-818)))) 
-(((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 *7))) (-5 *3 (-1157 *7)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-904)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-901 *4 *5 *6 *7)))) ((*1 *2 *2 *3) (|partial| -12 (-5 *2 (-634 (-1157 *5))) (-5 *3 (-1157 *5)) (-4 *5 (-1219 *4)) (-4 *4 (-904)) (-5 *1 (-902 *4 *5))))) 
-(((*1 *2 *3 *4 *5 *3) (-12 (-5 *4 (-1 *7 *7)) (-5 *5 (-1 (-3 (-2 (|:| -1924 *6) (|:| |coeff| *6)) "failed") *6)) (-4 *6 (-365)) (-4 *7 (-1219 *6)) (-5 *2 (-3 (-2 (|:| |answer| (-409 *7)) (|:| |a0| *6)) (-2 (|:| -1924 (-409 *7)) (|:| |coeff| (-409 *7))) "failed")) (-5 *1 (-578 *6 *7)) (-5 *3 (-409 *7))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-1161)) (-5 *4 (-953 (-568))) (-5 *2 (-328)) (-5 *1 (-330))))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1249)) (-5 *1 (-205 *4)) (-4 *4 (-13 (-842) (-10 -8 (-15 -2779 ((-1143) $ (-1161))) (-15 -4125 (*2 $)) (-15 -1352 (*2 $))))))) ((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-205 *3)) (-4 *3 (-13 (-842) (-10 -8 (-15 -2779 ((-1143) $ (-1161))) (-15 -4125 (*2 $)) (-15 -1352 (*2 $))))))) ((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-511))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-955)) (-5 *2 (-1084 (-215))))) ((*1 *2 *1) (-12 (-4 *1 (-975)) (-5 *2 (-1084 (-215)))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-2 (|:| -3746 (-679 *3)) (|:| |basisDen| *3) (|:| |basisInv| (-679 *3)))) (-4 *3 (-13 (-301) (-10 -8 (-15 -1678 ((-420 $) $))))) (-4 *4 (-1219 *3)) (-5 *1 (-508 *3 *4 *5)) (-4 *5 (-411 *3 *4))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-643 *4)) (-4 *4 (-340 *5 *6 *7)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -3746 (-634 *4)))) (-5 *1 (-801 *5 *6 *7 *4))))) 
-(((*1 *2 *3 *4 *5 *6) (|partial| -12 (-5 *4 (-1161)) (-5 *6 (-634 (-607 *3))) (-5 *5 (-607 *3)) (-4 *3 (-13 (-27) (-1181) (-432 *7))) (-4 *7 (-13 (-453) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-2 (|:| -1924 *3) (|:| |coeff| *3))) (-5 *1 (-559 *7 *3))))) 
-(((*1 *1 *1 *1) (-12 (-4 *1 (-375 *2)) (-4 *2 (-1195)) (-4 *2 (-842)))) ((*1 *1 *2 *1 *1) (-12 (-5 *2 (-1 (-121) *3 *3)) (-4 *1 (-375 *3)) (-4 *3 (-1195)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-969 *2)) (-4 *2 (-842)))) ((*1 *1 *1 *1) (-12 (-4 *1 (-1122 *2)) (-4 *2 (-1047)))) ((*1 *1 *2) (-12 (-5 *2 (-634 *1)) (-4 *1 (-1122 *3)) (-4 *3 (-1047)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-1149 *3 *4))) (-5 *1 (-1149 *3 *4)) (-14 *3 (-917)) (-4 *4 (-1047)))) ((*1 *1 *1 *1) (-12 (-5 *1 (-1149 *2 *3)) (-14 *2 (-917)) (-4 *3 (-1047))))) 
-(((*1 *2) (-12 (-4 *4 (-172)) (-5 *2 (-121)) (-5 *1 (-368 *3 *4)) (-4 *3 (-369 *4)))) ((*1 *2) (-12 (-4 *1 (-369 *3)) (-4 *3 (-172)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -2721 *3))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-917)) (-5 *2 (-1157 *4)) (-5 *1 (-587 *4)) (-4 *4 (-350))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *4 (-1161)) (-5 *5 (-1084 (-215))) (-5 *2 (-927)) (-5 *1 (-925 *3)) (-4 *3 (-609 (-541))))) ((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-5 *2 (-927)) (-5 *1 (-925 *3)) (-4 *3 (-609 (-541))))) ((*1 *1 *2) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *1 (-927)))) ((*1 *1 *2 *3) (-12 (-5 *2 (-1 (-215) (-215))) (-5 *3 (-1084 (-215))) (-5 *1 (-927))))) 
-(((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-381)) (-5 *1 (-1059))))) 
-(((*1 *2 *1) (|partial| -12 (-5 *2 (-1057 (-1023 *3) (-1157 (-1023 *3)))) (-5 *1 (-1023 *3)) (-4 *3 (-13 (-840) (-365) (-1021)))))) 
-(((*1 *2) (-12 (-5 *2 (-121)) (-5 *1 (-1141 *3)) (-4 *3 (-1090)) (-4 *3 (-1195))))) 
-(((*1 *2 *2 *3 *3) (-12 (-5 *3 (-409 *5)) (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-5 *1 (-151 *4 *5 *2)) (-4 *2 (-1219 *3)))) ((*1 *2 *3) (-12 (-5 *3 (-1163 (-409 (-568)))) (-5 *2 (-409 (-568))) (-5 *1 (-182)))) ((*1 *2 *2 *3 *4) (-12 (-5 *2 (-679 (-310 (-215)))) (-5 *3 (-634 (-1161))) (-5 *4 (-1244 (-310 (-215)))) (-5 *1 (-197)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-288 *3))) (-4 *3 (-303 *3)) (-4 *3 (-1090)) (-4 *3 (-1195)) (-5 *1 (-288 *3)))) ((*1 *1 *1 *1) (-12 (-4 *2 (-303 *2)) (-4 *2 (-1090)) (-4 *2 (-1195)) (-5 *1 (-288 *2)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *1 *1)) (-4 *1 (-296)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1 *1 (-634 *1))) (-4 *1 (-296)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-123))) (-5 *3 (-634 (-1 *1 (-634 *1)))) (-4 *1 (-296)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-123))) (-5 *3 (-634 (-1 *1 *1))) (-4 *1 (-296)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1 *1 *1)) (-4 *1 (-296)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-1161)) (-5 *3 (-1 *1 (-634 *1))) (-4 *1 (-296)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-634 (-1 *1 (-634 *1)))) (-4 *1 (-296)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-634 (-1 *1 *1))) (-4 *1 (-296)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-288 *3))) (-4 *1 (-303 *3)) (-4 *3 (-1090)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-288 *3)) (-4 *1 (-303 *3)) (-4 *3 (-1090)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-1 *2 (-568))) (-5 *4 (-1163 (-409 (-568)))) (-5 *1 (-304 *2)) (-4 *2 (-43 (-409 (-568)))))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *4)) (-5 *3 (-634 *1)) (-4 *1 (-376 *4 *5)) (-4 *4 (-842)) (-4 *5 (-172)))) ((*1 *1 *1 *2 *1) (-12 (-4 *1 (-376 *2 *3)) (-4 *2 (-842)) (-4 *3 (-172)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-763)) (-5 *4 (-1 *1 *1)) (-4 *1 (-432 *5)) (-4 *5 (-842)) (-4 *5 (-1047)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-1161)) (-5 *3 (-763)) (-5 *4 (-1 *1 (-634 *1))) (-4 *1 (-432 *5)) (-4 *5 (-842)) (-4 *5 (-1047)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-634 (-763))) (-5 *4 (-634 (-1 *1 (-634 *1)))) (-4 *1 (-432 *5)) (-4 *5 (-842)) (-4 *5 (-1047)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-634 (-1161))) (-5 *3 (-634 (-763))) (-5 *4 (-634 (-1 *1 *1))) (-4 *1 (-432 *5)) (-4 *5 (-842)) (-4 *5 (-1047)))) ((*1 *1 *1 *2 *3 *4) (-12 (-5 *2 (-634 (-123))) (-5 *3 (-634 *1)) (-5 *4 (-1161)) (-4 *1 (-432 *5)) (-4 *5 (-842)) (-4 *5 (-609 (-541))))) ((*1 *1 *1 *2 *1 *3) (-12 (-5 *2 (-123)) (-5 *3 (-1161)) (-4 *1 (-432 *4)) (-4 *4 (-842)) (-4 *4 (-609 (-541))))) ((*1 *1 *1) (-12 (-4 *1 (-432 *2)) (-4 *2 (-842)) (-4 *2 (-609 (-541))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-634 (-1161))) (-4 *1 (-432 *3)) (-4 *3 (-842)) (-4 *3 (-609 (-541))))) ((*1 *1 *1 *2) (-12 (-5 *2 (-1161)) (-4 *1 (-432 *3)) (-4 *3 (-842)) (-4 *3 (-609 (-541))))) ((*1 *2 *3 *4) (-12 (-14 *5 (-634 (-1161))) (-4 *3 (-950 *2 *6 (-852 *5))) (-4 *6 (-230 (-1697 *5) (-763))) (-4 *7 (-971 *2)) (-4 *8 (-641 *2)) (-4 *4 (-920 *2 *8)) (-4 *9 (-235 *4)) (-4 *10 (-536 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) ((*1 *2 *3 *3 *4) (-12 (-14 *5 (-634 (-1161))) (-4 *3 (-950 *2 *6 (-852 *5))) (-4 *6 (-230 (-1697 *5) (-763))) (-4 *7 (-971 *2)) (-4 *8 (-641 *2)) (-4 *4 (-920 *2 *8)) (-4 *9 (-235 *4)) (-4 *10 (-536 *2 *5 *3 *6 *7 *8 *4 *9 *12)) (-4 *12 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 *6)) (-4 *6 (-950 *2 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-14 *5 (-634 (-1161))) (-4 *8 (-971 *2)) (-4 *9 (-641 *2)) (-4 *4 (-920 *2 *9)) (-4 *10 (-235 *4)) (-4 *11 (-536 *2 *5 *6 *7 *8 *9 *4 *10 *13)) (-4 *13 (-117)) (-4 *2 (-365)) (-5 *1 (-467 *2 *5 *6 *7 *8 *9 *4 *10 *11 *12 *13)) (-4 *12 (-258 *11)))) ((*1 *1 *1 *2 *3) (-12 (-4 *1 (-523 *2 *3)) (-4 *2 (-1090)) (-4 *3 (-1195)))) ((*1 *1 *1 *2 *3) (-12 (-5 *2 (-634 *4)) (-5 *3 (-634 *5)) (-4 *1 (-523 *4 *5)) (-4 *4 (-1090)) (-4 *5 (-1195)))) ((*1 *2 *1 *2) (-12 (-5 *2 (-828 *3)) (-4 *3 (-365)) (-5 *1 (-708 *3)))) ((*1 *2 *1 *2) (-12 (-5 *1 (-708 *2)) (-4 *2 (-365)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-242 *5 *2)) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *3 *4) (-12 (-5 *3 (-242 *5 *2)) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-242 *5 *2))) (-5 *4 (-922 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-350)) (-5 *1 (-867 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-242 *5 *2)) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *3 *4) (-12 (-5 *3 (-242 *5 *2)) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-409 (-242 *5 *2))) (-5 *4 (-921 *2)) (-14 *5 (-634 (-1161))) (-4 *2 (-365)) (-5 *1 (-868 *2 *5 *6)) (-4 *6 (-117)))) ((*1 *2 *1 *2) (-12 (-4 *1 (-898 *2)) (-4 *2 (-1090)))) ((*1 *2 *3 *4) (-12 (-4 *5 (-230 *6 (-763))) (-14 *6 (-763)) (-4 *2 (-365)) (-5 *1 (-929 *2 *3 *5 *6 *4)) (-4 *3 (-324 *2 *5)) (-4 *4 (-971 *2)))) ((*1 *2 *2 *3 *2) (-12 (-5 *2 (-409 (-953 *4))) (-5 *3 (-1161)) (-4 *4 (-558)) (-5 *1 (-1042 *4)))) ((*1 *2 *2 *3 *4) (-12 (-5 *3 (-634 (-1161))) (-5 *4 (-634 (-409 (-953 *5)))) (-5 *2 (-409 (-953 *5))) (-4 *5 (-558)) (-5 *1 (-1042 *5)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-288 (-409 (-953 *4)))) (-5 *2 (-409 (-953 *4))) (-4 *4 (-558)) (-5 *1 (-1042 *4)))) ((*1 *2 *2 *3) (-12 (-5 *3 (-634 (-288 (-409 (-953 *4))))) (-5 *2 (-409 (-953 *4))) (-4 *4 (-558)) (-5 *1 (-1042 *4)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3)))) ((*1 *2 *1 *3) (-12 (-4 *1 (-1221 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (|has| *3 (-15 ** (*3 *3 *4))) (-5 *2 (-1141 *3))))) 
-(((*1 *1 *2) (-12 (-5 *2 (-634 (-1084 (-409 (-568))))) (-5 *1 (-256)))) ((*1 *1 *2) (-12 (-5 *2 (-634 (-1084 (-381)))) (-5 *1 (-256))))) 
-(((*1 *2 *2 *3 *4 *5) (-12 (-5 *2 (-634 *9)) (-5 *3 (-1 (-121) *9)) (-5 *4 (-1 (-121) *9 *9)) (-5 *5 (-1 *9 *9 *9)) (-4 *9 (-1061 *6 *7 *8)) (-4 *6 (-558)) (-4 *7 (-788)) (-4 *8 (-842)) (-5 *1 (-978 *6 *7 *8 *9))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-1219 *4)) (-5 *1 (-544 *4 *2 *5 *6)) (-4 *4 (-301)) (-14 *5 *4) (-14 *6 (-1 *4 *4 (-763)))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-677 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *2 (-121)))) ((*1 *2 *1) (-12 (-4 *1 (-1050 *3 *4 *5 *6 *7)) (-4 *5 (-1047)) (-4 *6 (-230 *4 *5)) (-4 *7 (-230 *3 *5)) (-5 *2 (-121))))) 
-(((*1 *2 *2 *3) (-12 (-5 *3 (-1 (-121) *4 *4)) (-4 *4 (-1195)) (-5 *1 (-1120 *4 *2)) (-4 *2 (-13 (-601 (-568) *4) (-10 -7 (-6 -4519) (-6 -4520)))))) ((*1 *2 *2) (-12 (-4 *3 (-842)) (-4 *3 (-1195)) (-5 *1 (-1120 *3 *2)) (-4 *2 (-13 (-601 (-568) *3) (-10 -7 (-6 -4519) (-6 -4520))))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-1249)) (-5 *1 (-817))))) 
-(((*1 *1 *1) (-12 (-4 *1 (-432 *2)) (-4 *2 (-842)) (-4 *2 (-1047)))) ((*1 *1 *1) (-12 (-5 *1 (-733 *2 *3)) (-14 *2 (-1161)) (-4 *3 (-13 (-1047) (-842) (-558))))) ((*1 *1 *1) (-12 (-4 *1 (-993 *2)) (-4 *2 (-558))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-173 *2)) (-4 *2 (-301))))) 
-(((*1 *2 *3) (-12 (-4 *3 (-1219 *2)) (-4 *2 (-1219 *4)) (-5 *1 (-986 *4 *2 *3 *5)) (-4 *4 (-350)) (-4 *5 (-714 *2 *3))))) 
-(((*1 *2 *2 *3) (-12 (-5 *2 (-2 (|:| |partsol| (-1244 (-409 (-953 *4)))) (|:| -3746 (-634 (-1244 (-409 (-953 *4))))))) (-5 *3 (-634 *7)) (-4 *4 (-13 (-301) (-150))) (-4 *7 (-950 *4 *6 *5)) (-4 *5 (-13 (-842) (-609 (-1161)))) (-4 *6 (-788)) (-5 *1 (-924 *4 *5 *6 *7))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-950 *3 *4 *5)) (-4 *3 (-301)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-448 *3 *4 *5 *6)))) ((*1 *2 *2 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-1143)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-301)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-448 *4 *5 *6 *7)))) ((*1 *2 *2 *3 *3) (-12 (-5 *2 (-634 *7)) (-5 *3 (-1143)) (-4 *7 (-950 *4 *5 *6)) (-4 *4 (-301)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *1 (-448 *4 *5 *6 *7))))) 
-(((*1 *2 *3 *3) (-12 (-5 *3 (-634 *4)) (-4 *4 (-365)) (-4 *2 (-1219 *4)) (-5 *1 (-918 *4 *2))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-121)) (-5 *1 (-926))))) 
-(((*1 *2 *1 *3 *3) (-12 (-5 *3 (-917)) (-5 *2 (-763)) (-5 *1 (-1091 *4 *5)) (-14 *4 *3) (-14 *5 *3)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 *2)) (-4 *2 (-432 *4)) (-5 *1 (-433 *4 *2)) (-4 *4 (-13 (-842) (-558)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *4 (-1161)) (-4 *5 (-13 (-301) (-842) (-150) (-1037 (-568)) (-630 (-568)))) (-5 *2 (-585 *3)) (-5 *1 (-428 *5 *3)) (-4 *3 (-13 (-1181) (-29 *5)))))) 
-(((*1 *2 *2) (-12 (-5 *2 (-634 *6)) (-4 *6 (-1061 *3 *4 *5)) (-4 *3 (-150)) (-4 *3 (-301)) (-4 *3 (-558)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *1 (-978 *3 *4 *5 *6))))) 
-(((*1 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247)))) ((*1 *2 *2) (-12 (-5 *2 (-869)) (-5 *1 (-1247))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-763)) (-5 *1 (-589))))) 
-(((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-96 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-212 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-842)) (-5 *2 (-121)) (-5 *1 (-494 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| *1 (-6 -4519)) (-4 *1 (-499 *4)) (-4 *4 (-1195)) (-5 *2 (-121)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-1000 *4)))) ((*1 *2 *3 *1) (-12 (-5 *3 (-1 (-121) *4)) (|has| $ (-6 -4519)) (-4 *4 (-1090)) (-5 *2 (-121)) (-5 *1 (-1132 *4))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-409 (-953 *3))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-558)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-13 (-842) (-453))) (-5 *1 (-1187 *3 *2)) (-4 *2 (-13 (-432 *3) (-1181)))))) 
-(((*1 *2 *2) (-12 (-4 *3 (-350)) (-4 *4 (-327 *3)) (-4 *5 (-1219 *4)) (-5 *1 (-769 *3 *4 *5 *2 *6)) (-4 *2 (-1219 *5)) (-14 *6 (-917)))) ((*1 *1 *1 *2) (-12 (-5 *2 (-763)) (-4 *1 (-1261 *3)) (-4 *3 (-365)) (-4 *3 (-370)))) ((*1 *1 *1) (-12 (-4 *1 (-1261 *2)) (-4 *2 (-365)) (-4 *2 (-370))))) 
-(((*1 *2 *1) (-12 (-5 *1 (-96 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-4 *1 (-111 *2)) (-4 *2 (-1195)))) ((*1 *2 *1) (-12 (-5 *1 (-212 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-5 *1 (-494 *2)) (-4 *2 (-842)))) ((*1 *2 *1) (-12 (-5 *1 (-1000 *2)) (-4 *2 (-1090)))) ((*1 *2 *1) (-12 (-5 *1 (-1132 *2)) (-4 *2 (-1090))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-536 *3 *4 *5 *6 *7 *8 *9 *10 *11)) (-4 *3 (-365)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *6 (-230 (-1697 *4) *2)) (-4 *7 (-971 *3)) (-4 *8 (-641 *3)) (-4 *9 (-920 *3 *8)) (-4 *10 (-235 *9)) (-4 *11 (-117)) (-5 *2 (-763))))) 
-(((*1 *2) (-12 (-4 *3 (-558)) (-5 *2 (-634 *4)) (-5 *1 (-48 *3 *4)) (-4 *4 (-419 *3))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-819))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-518 *3 *2)) (-4 *3 (-1090)) (-4 *2 (-842))))) 
-(((*1 *2 *3 *4) (-12 (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-634 *4)) (-5 *1 (-1098 *5 *6 *7 *3 *4)) (-4 *4 (-1066 *5 *6 *7 *3))))) 
-(((*1 *2) (|partial| -12 (-4 *3 (-558)) (-4 *3 (-172)) (-5 *2 (-2 (|:| |particular| *1) (|:| -3746 (-634 *1)))) (-4 *1 (-369 *3)))) ((*1 *2) (|partial| -12 (-5 *2 (-2 (|:| |particular| (-454 *3 *4 *5 *6)) (|:| -3746 (-634 (-454 *3 *4 *5 *6))))) (-5 *1 (-454 *3 *4 *5 *6)) (-4 *3 (-172)) (-14 *4 (-917)) (-14 *5 (-634 (-1161))) (-14 *6 (-1244 (-679 *3)))))) 
-(((*1 *2 *3) (-12 (-5 *2 (-1157 (-568))) (-5 *1 (-943)) (-5 *3 (-568)))) ((*1 *2 *2) (-12 (-4 *3 (-301)) (-4 *4 (-375 *3)) (-4 *5 (-375 *3)) (-5 *1 (-1112 *3 *4 *5 *2)) (-4 *2 (-677 *3 *4 *5))))) 
-(((*1 *2 *3 *4 *5 *5 *4 *6) (-12 (-5 *4 (-568)) (-5 *6 (-1 (-1249) (-1244 *5) (-1244 *5) (-381))) (-5 *3 (-1244 (-381))) (-5 *5 (-381)) (-5 *2 (-1249)) (-5 *1 (-783))))) 
-(((*1 *2 *2) (|partial| -12 (-5 *2 (-1157 *3)) (-4 *3 (-350)) (-5 *1 (-358 *3))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-262 *2)) (-4 *2 (-842)))) ((*1 *1 *2) (|partial| -12 (-5 *2 (-1161)) (-5 *1 (-852 *3)) (-14 *3 (-634 *2)))) ((*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-990)))) ((*1 *2 *1) (-12 (-5 *2 (-1161)) (-5 *1 (-1082 *3)) (-4 *3 (-1195)))) ((*1 *2 *1) (-12 (-4 *1 (-1221 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-1161)))) ((*1 *2) (-12 (-5 *2 (-1161)) (-5 *1 (-1240 *3)) (-14 *3 *2)))) 
-(((*1 *2 *3 *2) (-12 (-4 *1 (-782)) (-5 *2 (-1035)) (-5 *3 (-2 (|:| |fn| (-310 (-215))) (|:| -1338 (-634 (-1084 (-835 (-215))))) (|:| |abserr| (-215)) (|:| |relerr| (-215)))))) ((*1 *2 *3 *2) (-12 (-4 *1 (-782)) (-5 *2 (-1035)) (-5 *3 (-2 (|:| |var| (-1161)) (|:| |fn| (-310 (-215))) (|:| -1338 (-1084 (-835 (-215)))) (|:| |abserr| (-215)) (|:| |relerr| (-215))))))) 
-(((*1 *2 *3 *2) (-12 (-5 *2 (-215)) (-5 *3 (-763)) (-5 *1 (-217)))) ((*1 *2 *3 *2) (-12 (-5 *2 (-169 (-215))) (-5 *3 (-763)) (-5 *1 (-217)))) ((*1 *2 *2 *2) (-12 (-4 *3 (-13 (-842) (-558))) (-5 *1 (-433 *3 *2)) (-4 *2 (-432 *3)))) ((*1 *1 *1 *1) (-4 *1 (-1124)))) 
-(((*1 *2 *1) (-12 (-4 *1 (-324 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-787)) (-5 *2 (-634 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-384 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-1090)) (-5 *2 (-634 *3)))) ((*1 *2 *1) (-12 (-5 *2 (-1141 *3)) (-5 *1 (-594 *3)) (-4 *3 (-1047)))) ((*1 *2 *1) (-12 (-5 *2 (-634 *3)) (-5 *1 (-725 *3 *4)) (-4 *3 (-1047)) (-4 *4 (-716)))) ((*1 *2 *1) (-12 (-4 *1 (-844 *3)) (-4 *3 (-1047)) (-5 *2 (-634 *3)))) ((*1 *2 *1) (-12 (-4 *1 (-1234 *3)) (-4 *3 (-1047)) (-5 *2 (-1141 *3))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-1047)) (-4 *5 (-230 *6 *2)) (-14 *6 *2) (-5 *2 (-763)) (-5 *1 (-908 *4 *3 *5 *6)) (-4 *3 (-324 *4 *5))))) 
-(((*1 *2) (-12 (-4 *1 (-340 *3 *4 *5)) (-4 *3 (-1199)) (-4 *4 (-1219 *3)) (-4 *5 (-1219 (-409 *4))) (-5 *2 (-679 (-409 *4)))))) 
-(((*1 *2 *1) (-12 (-5 *2 (-121)) (-5 *1 (-123))))) 
-(((*1 *2 *3) (-12 (-5 *3 |RationalNumber|) (-5 *2 (-1 (-568))) (-5 *1 (-1045))))) 
-(((*1 *2 *1 *1) (-12 (-5 *2 (-2 (|:| -2721 (-777 *3)) (|:| |coef1| (-777 *3)) (|:| |coef2| (-777 *3)))) (-5 *1 (-777 *3)) (-4 *3 (-558)) (-4 *3 (-1047)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-558)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-2 (|:| -2721 *1) (|:| |coef1| *1) (|:| |coef2| *1))) (-4 *1 (-1061 *3 *4 *5))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *5 (-1199)) (-4 *6 (-1219 *5)) (-4 *7 (-1219 (-409 *6))) (-5 *2 (-634 (-953 *5))) (-5 *1 (-339 *4 *5 *6 *7)) (-4 *4 (-340 *5 *6 *7)))) ((*1 *2 *3) (-12 (-5 *3 (-1161)) (-4 *1 (-340 *4 *5 *6)) (-4 *4 (-1199)) (-4 *5 (-1219 *4)) (-4 *6 (-1219 (-409 *5))) (-4 *4 (-365)) (-5 *2 (-634 (-953 *4)))))) 
-(((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-2 (|:| |eqzro| (-634 *8)) (|:| |neqzro| (-634 *8)) (|:| |wcond| (-634 (-953 *5))) (|:| |bsoln| (-2 (|:| |partsol| (-1244 (-409 (-953 *5)))) (|:| -3746 (-634 (-1244 (-409 (-953 *5)))))))))) (-5 *4 (-1143)) (-4 *5 (-13 (-301) (-150))) (-4 *8 (-950 *5 *7 *6)) (-4 *6 (-13 (-842) (-609 (-1161)))) (-4 *7 (-788)) (-5 *2 (-568)) (-5 *1 (-924 *5 *6 *7 *8))))) 
-(((*1 *2 *3 *4 *5 *6) (-12 (-5 *3 (-1 *2 (-763) (-763) *7)) (-5 *4 (-1244 *7)) (-5 *5 (-763)) (-5 *6 (-1244 (-1157 *2))) (-4 *7 (-52 *2 *5)) (-4 *2 (-13 (-558) (-453))) (-5 *1 (-346 *2 *7))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-365)) (-5 *2 (-2 (|:| -3961 *3) (|:| -1500 *3))) (-5 *1 (-758 *3 *4)) (-4 *3 (-698 *4)))) ((*1 *2 *1 *1) (-12 (-4 *3 (-365)) (-4 *3 (-1047)) (-5 *2 (-2 (|:| -3961 *1) (|:| -1500 *1))) (-4 *1 (-844 *3)))) ((*1 *2 *3 *3 *4) (-12 (-5 *4 (-101 *5)) (-4 *5 (-365)) (-4 *5 (-1047)) (-5 *2 (-2 (|:| -3961 *3) (|:| -1500 *3))) (-5 *1 (-845 *5 *3)) (-4 *3 (-844 *5))))) 
-(((*1 *2 *1 *2) (-12 (-5 *2 (-634 (-1143))) (-5 *1 (-396))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-568)) (-5 *1 (-565)))) ((*1 *2 *3) (-12 (-5 *2 (-1157 (-409 (-568)))) (-5 *1 (-943)) (-5 *3 (-568))))) 
-(((*1 *1 *1 *2) (-12 (-4 *1 (-977 *3 *4 *2 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *2 (-842)) (-4 *5 (-1061 *3 *4 *2))))) 
-(((*1 *2 *3 *4 *5) (-12 (-5 *3 (-1244 *6)) (-5 *4 (-1244 (-568))) (-5 *5 (-568)) (-4 *6 (-1090)) (-5 *2 (-1 *6)) (-5 *1 (-1017 *6))))) 
-(((*1 *2) (-12 (-4 *3 (-365)) (-4 *4 (-641 *3)) (-5 *2 (-634 *1)) (-4 *1 (-920 *3 *4))))) 
-(((*1 *2 *3 *4 *2) (-12 (-5 *3 (-1 *2 *2)) (-5 *4 (-763)) (-4 *2 (-1090)) (-5 *1 (-668 *2))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-568))) (-5 *2 (-899 (-568))) (-5 *1 (-913)))) ((*1 *2) (-12 (-5 *2 (-899 (-568))) (-5 *1 (-913))))) 
-(((*1 *2 *1) (-12 (-4 *1 (-858)) (-5 *2 (-1249))))) 
-(((*1 *1 *1) (-12 (-5 *1 (-593 *2)) (-4 *2 (-43 (-409 (-568)))) (-4 *2 (-1047))))) 
-(((*1 *1 *1 *1) (-4 *1 (-550)))) 
-(((*1 *2 *3) (-12 (-5 *3 (-568)) (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-1249)) (-5 *1 (-450 *4 *5 *6 *7)) (-4 *7 (-950 *4 *5 *6))))) 
-(((*1 *2 *1 *3) (-12 (-5 *3 (-634 *1)) (-4 *1 (-1061 *4 *5 *6)) (-4 *4 (-1047)) (-4 *5 (-788)) (-4 *6 (-842)) (-5 *2 (-121)))) ((*1 *2 *1 *1) (-12 (-4 *1 (-1061 *3 *4 *5)) (-4 *3 (-1047)) (-4 *4 (-788)) (-4 *5 (-842)) (-5 *2 (-121)))) ((*1 *2 *3 *1 *4) (-12 (-5 *4 (-1 (-121) *3 *3)) (-4 *1 (-1189 *5 *6 *7 *3)) (-4 *5 (-558)) (-4 *6 (-788)) (-4 *7 (-842)) (-4 *3 (-1061 *5 *6 *7)) (-5 *2 (-121))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-558)) (-5 *2 (-2 (|:| |coef2| *3) (|:| -4265 *4))) (-5 *1 (-970 *4 *3)) (-4 *3 (-1219 *4))))) 
-(((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-641 *4)) (-4 *3 (-920 *4 *8)) (-4 *9 (-235 *3)) (-4 *10 (-536 *4 *5 *6 *7 *2 *8 *3 *9 *12)) (-4 *12 (-117)) (-4 *2 (-971 *4)) (-5 *1 (-467 *4 *5 *6 *7 *2 *8 *3 *9 *10 *11 *12)) (-4 *11 (-258 *10)))) ((*1 *2 *3) (-12 (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-641 *4)) (-4 *2 (-971 *4)) (-5 *1 (-654 *4 *5 *6 *7 *2 *8 *3)) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *3 (-920 *4 *8)))) ((*1 *2 *3) (-12 (-5 *3 (-922 *4)) (-4 *4 (-350)) (-5 *2 (-967 *4)) (-5 *1 (-867 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117)))) ((*1 *2 *3) (-12 (-5 *3 (-921 *4)) (-4 *4 (-365)) (-5 *2 (-966 *4)) (-5 *1 (-868 *4 *5 *6)) (-14 *5 (-634 (-1161))) (-4 *6 (-117))))) 
-(((*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-989 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7)))) ((*1 *2 *3 *3) (-12 (-4 *4 (-453)) (-4 *5 (-788)) (-4 *6 (-842)) (-4 *7 (-1061 *4 *5 *6)) (-5 *2 (-121)) (-5 *1 (-1097 *4 *5 *6 *7 *3)) (-4 *3 (-1066 *4 *5 *6 *7))))) 
-(((*1 *2 *3) (-12 (-5 *3 (-634 (-121))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1697 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-1249)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) ((*1 *2) (-12 (-4 *1 (-641 *3)) (-4 *3 (-365)) (-5 *2 (-121)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-4 *1 (-641 *3)) (-4 *3 (-365)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *8 (-641 *3)) (-5 *1 (-654 *3 *4 *5 *6 *7 *8 *9)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *7 (-971 *3)) (-4 *9 (-920 *3 *8)))) ((*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *6 (-230 (-1697 *4) (-763))) (-4 *8 (-641 *3)) (-5 *2 (-121)) (-5 *1 (-654 *3 *4 *5 *6 *7 *8 *9)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *7 (-971 *3)) (-4 *9 (-920 *3 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-2 (|:| |val| (-634 *8)) (|:| -3001 *9)))) (-5 *4 (-763)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-1249)) (-5 *1 (-1064 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-2 (|:| |val| (-634 *8)) (|:| -3001 *9)))) (-5 *4 (-763)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1099 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-1249)) (-5 *1 (-1130 *5 *6 *7 *8 *9))))) 
-(((*1 *2 *2 *2) (-12 (-5 *2 (-1141 *3)) (-4 *3 (-1047)) (-5 *1 (-1145 *3))))) 
-((-1276 . 830226) (-1277 . 828784) (-1278 . 828450) (-1279 . 827638) (-1280 . 827513) (-1281 . 827112) (-1282 . 826963) (-1283 . 826929) (-1284 . 826845) (-1285 . 826792) (-1286 . 826658) (-1287 . 826562) (-1288 . 826471) (-1289 . 826335) (-1290 . 826212) (-1291 . 826078) (-1292 . 826015) (-1293 . 825623) (-1294 . 825429) (-1295 . 825039) (-1296 . 824704) (-1297 . 824377) (-1298 . 824294) (-1299 . 824242) (-1300 . 824113) (-1301 . 823979) (-1302 . 823492) (-1303 . 823227) (-1304 . 822859) (-1305 . 822451) (-1306 . 822367) (-1307 . 822196) (-1308 . 821999) (-1309 . 821641) (-1310 . 821469) (-1311 . 821395) (-1312 . 821343) (-1313 . 821253) (-1314 . 821005) (-1315 . 820684) (-1316 . 820391) (-1317 . 820287) (-1318 . 820116) (-1319 . 819422) (-1320 . 819348) (-1321 . 819248) (-1322 . 819081) (-1323 . 818906) (-1324 . 818799) (-1325 . 818695) (-1326 . 818643) (-1327 . 818545) (-1328 . 818102) (-1329 . 817831) (-1330 . 817708) (-1331 . 817653) (-1332 . 817437) (-1333 . 817384) (-1334 . 817099) (-1335 . 816863) (-1336 . 816723) (-1337 . 816506) (-1338 . 816368) (-1339 . 810536) (-1340 . 810451) (-1341 . 810318) (-1342 . 810243) (-1343 . 809880) (-1344 . 809791) (-1345 . 809666) (-1346 . 809514) (-1347 . 808938) (-1348 . 808670) (-1349 . 808395) (-1350 . 808169) (-1351 . 808052) (-1352 . 807672) (-1353 . 807579) (-1354 . 807272) (-1355 . 806964) (-1356 . 806936) (-1357 . 806617) (-1358 . 806559) (-1359 . 806486) (-1360 . 806458) (-1361 . 806379) (-1362 . 805875) (-1363 . 805725) (-1364 . 805636) (-1365 . 805545) (-1366 . 805383) (-1367 . 804980) (-1368 . 804909) (-1369 . 804674) (-1370 . 804302) (-1371 . 804213) (-1372 . 804058) (-1373 . 803684) (-1374 . 803364) (-1375 . 802272) (-1376 . 802214) (-1377 . 802076) (-1378 . 801841) (-1379 . 801789) (-1380 . 801761) (-1381 . 801690) (-1382 . 801540) (-1383 . 801368) (-1384 . 801245) (-1385 . 800942) (-1386 . 800875) (-1387 . 800181) (-1388 . 799996) (-1389 . 799933) (-1390 . 799867) (-1391 . 799783) (-1392 . 799667) (-1393 . 799594) (-1394 . 799186) (-1395 . 799110) (-1396 . 798826) (-1397 . 798384) (-1398 . 798094) (-1399 . 798015) (-1400 . 797939) (-1401 . 797865) (-1402 . 797740) (-1403 . 797667) (-1404 . 797564) (-1405 . 797444) (-1406 . 797336) (-1407 . 797035) (-1408 . 796937) (-1409 . 796836) (-1410 . 796484) (-1411 . 796281) (-1412 . 796148) (-1413 . 796098) (-1414 . 792174) (-1415 . 791670) (-1416 . 791580) (-1417 . 791507) (-1418 . 791415) (-1419 . 791324) (-1420 . 791236) (-1421 . 790862) (-1422 . 790674) (-1423 . 790556) (-1424 . 790271) (-1425 . 790058) (-1426 . 789910) (-1427 . 789840) (-1428 . 789729) (-1429 . 789032) (-1430 . 788976) (-1431 . 788829) (-1432 . 788691) (-1433 . 788452) (-1434 . 788309) (-1435 . 788157) (-1436 . 788094) (-1437 . 788032) (-1438 . 787723) (-1439 . 787620) (-1440 . 787564) (-1441 . 787449) (-1442 . 787240) (-1443 . 787079) (-1444 . 786987) (-1445 . 786723) (-1446 . 786585) (-1447 . 786446) (-1448 . 786240) (-1449 . 786137) (-1450 . 786087) (-1451 . 786003) (-1452 . 785801) (-1453 . 785704) (-1454 . 785575) (-1455 . 785440) (-1456 . 785337) (-1457 . 785300) (-1458 . 784756) (-1459 . 784704) (-1460 . 784633) (-1461 . 784393) (-1462 . 784293) (-1463 . 784169) (-1464 . 784116) (-1465 . 784066) (-1466 . 783770) (-1467 . 783514) (-1468 . 783156) (-1469 . 783087) (-1470 . 783037) (-1471 . 782824) (-1472 . 782749) (-1473 . 782718) (-1474 . 782561) (-1475 . 782341) (-1476 . 782194) (-1477 . 782055) (-1478 . 781979) (-1479 . 781879) (-1480 . 781642) (-1481 . 781078) (-1482 . 781001) (-1483 . 780925) (-1484 . 780812) (-1485 . 780666) (-1486 . 780426) (-1487 . 780278) (-1488 . 780206) (-1489 . 779840) (-1490 . 779759) (-1491 . 779706) (-1492 . 779482) (-1493 . 779274) (-1494 . 779164) (-1495 . 779105) (-1496 . 779049) (-1497 . 778994) (-1498 . 778859) (-1499 . 778725) (-1500 . 778525) (-1501 . 778208) (-1502 . 778118) (-1503 . 777950) (-1504 . 777847) (-1505 . 777790) (-1506 . 777717) (-1507 . 777534) (-1508 . 777377) (-1509 . 777188) (-1510 . 777078) (-1511 . 776983) (-1512 . 776828) (-1513 . 776748) (-1514 . 776578) (-1515 . 776504) (-1516 . 776426) (-1517 . 776269) (-1518 . 776201) (-1519 . 776102) (-1520 . 775969) (-1521 . 775896) (-1522 . 775746) (-1523 . 775610) (-1524 . 775420) (-1525 . 775270) (-1526 . 775179) (-1527 . 775046) (-1528 . 774898) (-1529 . 774788) (-1530 . 774663) (-1531 . 774504) (-1532 . 774398) (-1533 . 774204) (-1534 . 774152) (-1535 . 774070) (-1536 . 774010) (-1537 . 773858) (-1538 . 773740) (-1539 . 773260) (-1540 . 773174) (-1541 . 773079) (-1542 . 772840) (-1543 . 772767) (-1544 . 772650) (-1545 . 772401) (-1546 . 772349) (-1547 . 771717) (-1548 . 771463) (-1549 . 771258) (-1550 . 771169) (-1551 . 770745) (-1552 . 770290) (-1553 . 769974) (-1554 . 769832) (-1555 . 769739) (-1556 . 769496) (-1557 . 769320) (-1558 . 769086) (-1559 . 768511) (-1560 . 768270) (-1561 . 768096) (-1562 . 766995) (-1563 . 766892) (-1564 . 766768) (-1565 . 766618) (-1566 . 766535) (-1567 . 766415) (-1568 . 765994) (-1569 . 765765) (-1570 . 765737) (-1571 . 765633) (-1572 . 765561) (-1573 . 765509) (-1574 . 765457) (-1575 . 765106) (-1576 . 765014) (-1577 . 764864) (-1578 . 764595) (-1579 . 764380) (-1580 . 764228) (-1581 . 764105) (-1582 . 764032) (-1583 . 763963) (-1584 . 763835) (-1585 . 763699) (-1586 . 763589) (-1587 . 763540) (-1588 . 763390) (-1589 . 763251) (-1590 . 762278) (-1591 . 762207) (-1592 . 762138) (-1593 . 762001) (-1594 . 761839) (-1595 . 761746) (-1596 . 761538) (-1597 . 761438) (-1598 . 761338) (-1599 . 761019) (-1600 . 760781) (-1601 . 760709) (-1602 . 760657) (-1603 . 760553) (-1604 . 760482) (-1605 . 760429) (-1606 . 760284) (-1607 . 760158) (-1608 . 760072) (-1609 . 759983) (-1610 . 759890) (-1611 . 759830) (-1612 . 759585) (-1613 . 759493) (-1614 . 759395) (-1615 . 759194) (-1616 . 759101) (-1617 . 759031) (-1618 . 758894) (-1619 . 758494) (-1620 . 758346) (-1621 . 758215) (-1622 . 758123) (-1623 . 758039) (-1624 . 757987) (-1625 . 757903) (-1626 . 757323) (-1627 . 757189) (-1628 . 757050) (-1629 . 756914) (-1630 . 756785) (-1631 . 756538) (-1632 . 756463) (-1633 . 749932) (-1634 . 749793) (-1635 . 749643) (-1636 . 749592) (-1637 . 748257) (-1638 . 748205) (-1639 . 748118) (-1640 . 747186) (-1641 . 747137) (-1642 . 746383) (-1643 . 746265) (-1644 . 746013) (-1645 . 745935) (-1646 . 745788) (-1647 . 745697) (-1648 . 745631) (-1649 . 745555) (-1650 . 745481) (-1651 . 745233) (-1652 . 745099) (-1653 . 744826) (-1654 . 744583) (-1655 . 744469) (-1656 . 744382) (-1657 . 743798) (-1658 . 743640) (-1659 . 743558) (-1660 . 743478) (-1661 . 743374) (-1662 . 743346) (-1663 . 743111) (-1664 . 742997) (-1665 . 742864) (-1666 . 742699) (-1667 . 742618) (-1668 . 742520) (-1669 . 742406) (-1670 . 742351) (-1671 . 742262) (-1672 . 742149) (-1673 . 741430) (-1674 . 741322) (-1675 . 740379) (-1676 . 739875) (-1677 . 739356) (-1678 . 738142) (-1679 . 738085) (-1680 . 737910) (-1681 . 737586) (-1682 . 737470) (-1683 . 737291) (-1684 . 737215) (-1685 . 736952) (-1686 . 736773) (-1687 . 736695) (-1688 . 736571) (-1689 . 736372) (-1690 . 736259) (-1691 . 736210) (-1692 . 735902) (-1693 . 735783) (-1694 . 735600) (-1695 . 735448) (-1696 . 735396) (-1697 . 734646) (-1698 . 734573) (-1699 . 734358) (-1700 . 734267) (-1701 . 734164) (-1702 . 734035) (-1703 . 733683) (-1704 . 733532) (-1705 . 733454) (-1706 . 733331) (-1707 . 733221) (-1708 . 733119) (-1709 . 732910) (-1710 . 732806) (-1711 . 732699) (-1712 . 732617) (-1713 . 732561) (-1714 . 732456) (-1715 . 732190) (-1716 . 731948) (-1717 . 731247) (-1718 . 730999) (-1719 . 730846) (-1720 . 730768) (-1721 . 730564) (-1722 . 730441) (-1723 . 730413) (-1724 . 730174) (-1725 . 730140) (-1726 . 729796) (-1727 . 729718) (-1728 . 729615) (-1729 . 729507) (-1730 . 729347) (-1731 . 728725) (-1732 . 728425) (-1733 . 728179) (-1734 . 728066) (-1735 . 727966) (-1736 . 727858) (-1737 . 727272) (-1738 . 727186) (-1739 . 727033) (-1740 . 726913) (-1741 . 726842) (-1742 . 726580) (-1743 . 726481) (-1744 . 726390) (-1745 . 726162) (-1746 . 726096) (-1747 . 725601) (-1748 . 725407) (-1749 . 725302) (-1750 . 725093) (-1751 . 725007) (-1752 . 724882) (-1753 . 724812) (-1754 . 724695) (-1755 . 724397) (-1756 . 724023) (-1757 . 723829) (-1758 . 723732) (-1759 . 723609) (-1760 . 723459) (-1761 . 719778) (-1762 . 719726) (-1763 . 719574) (-1764 . 719482) (-1765 . 719359) (-1766 . 719163) (-1767 . 717656) (-1768 . 717457) (-1769 . 717355) (-1770 . 717179) (-1771 . 717065) (-1772 . 716962) (-1773 . 715363) (-1774 . 715307) (-1775 . 715228) (-1776 . 715176) (-1777 . 715007) (-1778 . 714941) (-1779 . 712645) (-1780 . 712579) (-1781 . 712506) (-1782 . 712312) (-1783 . 712159) (-1784 . 711891) (-1785 . 711769) (-1786 . 711697) (-1787 . 711571) (-1788 . 711402) (-1789 . 711220) (-1790 . 711117) (-1791 . 710767) (-1792 . 710713) (-1793 . 710534) (-1794 . 709998) (-1795 . 709850) (-1796 . 709381) (-1797 . 709218) (-1798 . 709052) (-1799 . 708942) (-1800 . 708883) (-1801 . 707973) (-1802 . 707879) (-1803 . 707728) (-1804 . 707576) (-1805 . 707478) (-1806 . 707380) (-1807 . 706235) (-1808 . 706179) (-1809 . 706091) (-1810 . 705980) (-1811 . 705673) (-1812 . 705614) (-1813 . 705491) (-1814 . 705459) (-1815 . 705350) (-1816 . 705023) (-1817 . 704878) (-1818 . 704637) (-1819 . 704465) (-1820 . 704342) (-1821 . 704287) (-1822 . 703789) (-1823 . 703395) (-1824 . 703322) (-1825 . 703130) (-1826 . 703075) (-1827 . 702941) (-1828 . 701992) (-1829 . 698068) (-1830 . 697843) (-1831 . 697732) (-1832 . 697476) (-1833 . 697401) (-1834 . 697229) (-1835 . 697177) (-1836 . 697122) (-1837 . 697091) (-1838 . 697001) (-1839 . 696928) (-1840 . 696845) (-1841 . 696751) (-1842 . 696584) (-1843 . 696389) (-1844 . 696277) (-1845 . 696070) (-1846 . 695295) (-1847 . 695072) (-1848 . 694717) (-1849 . 694112) (-1850 . 693885) (-1851 . 693793) (-1852 . 693679) (-1853 . 693528) (-1854 . 693475) (-1855 . 693416) (-1856 . 693350) (-1857 . 693223) (-1858 . 692770) (-1859 . 692225) (-1860 . 692163) (-1861 . 692081) (-1862 . 691943) (-1863 . 691673) (-1864 . 691244) (-1865 . 691192) (-1866 . 691137) (-1867 . 690892) (-1868 . 690773) (-1869 . 690664) (-1870 . 690349) (-1871 . 690234) (-1872 . 690000) (-1873 . 689968) (-1874 . 689596) (-1875 . 689475) (-1876 . 689369) (-1877 . 689335) (-1878 . 689185) (-1879 . 689054) (-1880 . 688959) (-1881 . 688869) (-1882 . 688623) (-1883 . 688270) (-1884 . 688186) (-1885 . 687873) (-1886 . 687760) (-1887 . 687492) (-1888 . 687411) (-1889 . 687352) (-1890 . 687031) (-1891 . 686847) (-1892 . 685697) (-1893 . 685613) (-1894 . 685561) (-1895 . 684459) (-1896 . 684236) (-1897 . 683982) (-1898 . 683875) (-1899 . 683826) (-1900 . 683707) (-1901 . 683596) (-1902 . 683214) (-1903 . 682971) (-1904 . 682893) (-1905 . 682771) (-1906 . 682718) (-1907 . 682528) (-1908 . 682346) (-1909 . 682208) (-1910 . 681972) (-1911 . 681833) (-1912 . 681767) (-1913 . 681545) (-1914 . 681490) (-1915 . 681073) (-1916 . 680934) (-1917 . 680860) (-1918 . 680679) (-1919 . 679993) (-1920 . 679848) (-1921 . 679769) (-1922 . 679741) (-1923 . 679666) (-1924 . 679611) (-1925 . 679493) (-1926 . 679375) (-1927 . 679268) (-1928 . 679129) (-1929 . 678880) (-1930 . 678813) (-1931 . 678740) (-1932 . 678332) (-1933 . 677679) (-1934 . 677476) (-1935 . 677370) (-1936 . 677089) (-1937 . 676542) (-1938 . 676474) (-1939 . 676276) (-1940 . 676078) (-1941 . 675531) (-1942 . 675363) (-1943 . 675273) (-1944 . 675050) (-1945 . 674503) (-1946 . 673979) (-1947 . 673905) (-1948 . 673846) (-1949 . 673195) (-1950 . 673097) (-1951 . 673013) (-1952 . 672821) (-1953 . 672170) (-1954 . 672142) (-1955 . 671923) (-1956 . 671823) (-1957 . 671506) (-1958 . 670793) (-1959 . 670641) (-1960 . 670405) (-1961 . 666481) (-1962 . 665936) (-1963 . 665844) (-1964 . 665792) (-1965 . 665551) (-1966 . 665006) (-1967 . 664949) (-1968 . 664814) (-1969 . 664619) (-1970 . 664074) (-1971 . 663975) (-1972 . 663900) (-1973 . 663782) (-1974 . 663130) (-1975 . 662707) (-1976 . 662576) (-1977 . 662479) (-1978 . 661827) (-1979 . 661200) (-1980 . 661046) (-1981 . 660980) (-1982 . 660328) (-1983 . 660223) (-1984 . 659898) (-1985 . 659821) (-1986 . 659275) (-1987 . 659202) (-1988 . 658909) (-1989 . 658781) (-1990 . 658235) (-1991 . 657758) (-1992 . 657614) (-1993 . 657540) (-1994 . 656994) (-1995 . 656897) (-1996 . 656848) (-1997 . 656602) (-1998 . 656057) (-1999 . 656005) (-2000 . 655789) (-2001 . 655640) (-2002 . 655095) (-2003 . 655010) (-2004 . 654608) (-2005 . 654277) (-2006 . 653732) (-2007 . 653637) (-2008 . 653313) (-2009 . 652704) (-2010 . 652159) (-2011 . 651866) (-2012 . 651792) (-2013 . 651739) (-2014 . 651194) (-2015 . 651094) (-2016 . 650911) (-2017 . 648474) (-2018 . 648309) (-2019 . 648260) (-2020 . 648126) (-2021 . 648050) (-2022 . 647964) (-2023 . 647888) (-2024 . 647722) (-2025 . 647485) (-2026 . 647135) (-2027 . 647068) (-2028 . 646979) (-2029 . 646895) (-2030 . 646771) (-2031 . 646704) (-2032 . 646629) (-2033 . 646390) (-2034 . 646068) (-2035 . 645979) (-2036 . 645770) (-2037 . 645704) (-2038 . 645504) (-2039 . 645426) (-2040 . 644587) (-2041 . 643536) (-2042 . 643374) (-2043 . 643096) (-2044 . 642992) (-2045 . 642635) (-2046 . 642510) (-2047 . 640963) (-2048 . 640865) (-2049 . 640442) (-2050 . 640389) (-2051 . 639573) (-2052 . 639370) (-2053 . 639262) (-2054 . 639190) (-2055 . 637973) (-2056 . 637899) (-2057 . 637770) (-2058 . 637718) (-2059 . 636599) (-2060 . 636419) (-2061 . 636260) (-2062 . 636137) (-2063 . 635982) (-2064 . 635779) (-2065 . 634045) (-2066 . 633805) (-2067 . 632997) (-2068 . 632663) (-2069 . 632313) (-2070 . 630883) (-2071 . 630266) (-2072 . 630181) (-2073 . 630078) (-2074 . 630022) (-2075 . 628560) (-2076 . 628447) (-2077 . 628389) (-2078 . 628336) (-2079 . 628278) (-2080 . 628250) (-2081 . 627544) (-2082 . 627370) (-2083 . 627286) (-2084 . 627233) (-2085 . 627109) (-2086 . 626796) (-2087 . 626561) (-2088 . 626389) (-2089 . 626336) (-2090 . 626220) (-2091 . 626094) (-2092 . 625983) (-2093 . 625776) (-2094 . 625574) (-2095 . 625546) (-2096 . 625193) (-2097 . 624588) (-2098 . 624535) (-2099 . 624144) (-2100 . 623928) (-2101 . 623819) (-2102 . 622704) (-2103 . 622610) (-2104 . 622517) (-2105 . 622444) (-2106 . 622412) (-2107 . 622116) (-2108 . 622006) (-2109 . 621914) (-2110 . 621880) (-2111 . 621772) (-2112 . 621701) (-2113 . 621631) (-2114 . 620498) (-2115 . 620372) (-2116 . 620297) (-2117 . 620002) (-2118 . 619928) (-2119 . 619871) (-2120 . 619694) (-2121 . 619141) (-2122 . 618936) (-2123 . 618883) (-2124 . 618711) (-2125 . 618533) (-2126 . 617372) (-2127 . 617225) (-2128 . 617111) (-2129 . 616818) (-2130 . 616766) (-2131 . 616684) (-2132 . 616613) (-2133 . 616518) (-2134 . 616263) (-2135 . 616191) (-2136 . 616125) (-2137 . 615975) (-2138 . 615872) (-2139 . 615776) (-2140 . 615742) (-2141 . 615475) (-2142 . 615191) (-2143 . 615051) (-2144 . 614602) (-2145 . 614472) (-2146 . 613137) (-2147 . 613064) (-2148 . 613011) (-2149 . 612883) (-2150 . 612688) (-2151 . 612608) (-2152 . 612409) (-2153 . 612337) (-2154 . 612255) (-2155 . 612003) (-2156 . 611874) (-2157 . 611569) (-2158 . 611469) (-2159 . 611212) (-2160 . 611141) (-2161 . 611091) (-2162 . 610972) (-2163 . 610883) (-2164 . 610549) (-2165 . 610435) (-2166 . 609753) (-2167 . 609668) (-2168 . 609376) (-2169 . 609166) (-2170 . 609048) (-2171 . 608957) (-2172 . 608846) (-2173 . 608125) (-2174 . 608018) (-2175 . 607883) (-2176 . 606919) (-2177 . 606761) (-2178 . 606431) (-2179 . 606313) (-2180 . 606151) (-2181 . 606064) (-2182 . 605977) (-2183 . 605678) (-2184 . 605110) (-2185 . 605015) (-2186 . 604960) (-2187 . 604652) (-2188 . 604568) (-2189 . 604416) (-2190 . 603690) (-2191 . 603573) (-2192 . 603392) (-2193 . 603304) (-2194 . 603204) (-2195 . 602735) (-2196 . 602682) (-2197 . 602544) (-2198 . 602389) (-2199 . 602257) (-2200 . 602125) (-2201 . 602054) (-2202 . 601964) (-2203 . 601890) (-12 . 601735) (-2205 . 601455) (-2206 . 601402) (-2207 . 601255) (-2208 . 601227) (-2209 . 600988) (-2210 . 600875) (-2211 . 600777) (-2212 . 600076) (-2213 . 599976) (-2214 . 599917) (-2215 . 598351) (-2216 . 598242) (-2217 . 597568) (-2218 . 597478) (-2219 . 597380) (-2220 . 597189) (-2221 . 597071) (-2222 . 596567) (-2223 . 596477) (-2224 . 596100) (-2225 . 595799) (-2226 . 595659) (-2227 . 595628) (-2228 . 595545) (-2229 . 595399) (-2230 . 595163) (-2231 . 594820) (-2232 . 594629) (-2233 . 594512) (-2234 . 594238) (-2235 . 594181) (-2236 . 594115) (-2237 . 594011) (-2238 . 593813) (-2239 . 593742) (-2240 . 593638) (-2241 . 593579) (-2242 . 593503) (-2243 . 593426) (-2244 . 593004) (-2245 . 592765) (-2246 . 591646) (-2247 . 591388) (-2248 . 591300) (-2249 . 591201) (-2250 . 590996) (-2251 . 590925) (-2252 . 590617) (-2253 . 590410) (* . 585905) (-2255 . 585850) (-2256 . 585751) (-2257 . 585582) (-2258 . 585393) (-2259 . 585341) (-2260 . 585171) (-2261 . 585068) (-2262 . 584806) (-2263 . 584716) (-2264 . 584647) (-2265 . 584558) (-2266 . 584368) (-2267 . 584200) (-2268 . 584116) (-2269 . 583704) (-2270 . 583379) (-2271 . 583315) (-2272 . 583244) (-2273 . 583142) (-2274 . 582987) (-2275 . 582913) (-2276 . 582733) (-2277 . 582117) (-2278 . 581919) (-2279 . 581809) (-2280 . 581514) (-2281 . 581316) (-2282 . 580892) (-2283 . 580558) (-2284 . 580365) (-2285 . 580266) (-2286 . 580109) (-2287 . 580034) (-2288 . 579896) (-2289 . 579841) (-2290 . 579718) (-2291 . 579525) (-2292 . 579456) (-2293 . 579342) (-2294 . 579246) (-2295 . 579061) (-2296 . 578989) (-2297 . 578881) (-2298 . 578746) (-2299 . 578644) (-2300 . 578516) (-2301 . 578391) (-2302 . 578275) (-2303 . 578186) (-2304 . 578100) (-2305 . 578047) (-2306 . 577979) (-2307 . 577898) (-2308 . 577845) (-2309 . 577605) (-2310 . 577553) (-2311 . 577393) (-2312 . 577156) (-2313 . 576920) (-2314 . 576843) (-2315 . 576729) (-2316 . 576280) (-2317 . 575608) (-2318 . 575458) (-2319 . 575402) (-2320 . 575324) (-2321 . 575087) (-2322 . 575003) (-2323 . 574618) (-2324 . 573966) (-2325 . 573856) (-2326 . 573786) (-2327 . 573736) (-2328 . 573639) (-2329 . 573528) (-2330 . 573500) (-2331 . 573346) (-2332 . 573249) (-2333 . 573082) (-2334 . 573022) (-2335 . 572881) (-2336 . 569015) (-2337 . 568987) (-2338 . 568909) (-2339 . 568787) (-2340 . 568730) (-2341 . 568582) (-2342 . 566347) (-2343 . 566288) (-2344 . 566220) (-2345 . 565407) (-2346 . 565289) (-2347 . 565207) (-2348 . 564866) (-2349 . 564835) (-2350 . 564782) (-2351 . 564535) (-2352 . 564447) (-2353 . 564382) (-2354 . 564120) (-2355 . 563964) (-2356 . 563754) (-2357 . 563531) (-2358 . 563458) (-2359 . 563366) (-2360 . 563293) (-2361 . 563161) (-2362 . 563029) (-2363 . 562948) (-2364 . 562741) (-2365 . 562610) (-2366 . 562336) (-2367 . 561907) (-2368 . 561744) (-2369 . 561678) (-2370 . 561625) (-2371 . 561459) (-2372 . 561166) (-2373 . 560360) (-2374 . 560139) (-2375 . 559904) (-2376 . 559815) (-2377 . 559656) (-2378 . 559540) (-2379 . 559390) (-2380 . 559279) (-2381 . 559210) (-2382 . 558895) (-2383 . 558843) (-2384 . 558752) (-2385 . 558382) (-2386 . 558300) (-2387 . 558105) (-2388 . 557769) (-2389 . 557633) (-2390 . 557281) (-2391 . 557060) (-2392 . 556927) (-2393 . 556817) (-2394 . 556265) (-2395 . 556183) (-2396 . 556028) (-2397 . 555866) (-2398 . 555766) (-2399 . 555692) (-2400 . 555640) (-2401 . 555544) (-2402 . 555409) (-2403 . 555295) (-2404 . 555223) (-2405 . 555087) (-2406 . 554923) (-2407 . 554558) (-2408 . 554210) (-2409 . 553894) (-2410 . 553810) (-2411 . 552811) (-2412 . 552715) (-2413 . 552537) (-2414 . 552478) (-2415 . 550609) (-2416 . 550511) (-2417 . 550418) (-2418 . 550366) (-2419 . 550189) (-2420 . 550115) (-2421 . 550060) (-2422 . 549924) (-2423 . 549855) (-2424 . 549789) (-2425 . 549115) (-2426 . 548850) (-2427 . 548681) (-2428 . 548586) (-2429 . 548493) (-2430 . 548427) (-2431 . 548327) (-2432 . 548256) (-2433 . 548104) (-2434 . 548003) (-2435 . 547899) (-2436 . 546514) (-2437 . 546380) (-2438 . 546306) (-2439 . 546169) (-2440 . 546120) (-2441 . 546031) (-2442 . 545879) (-2443 . 545326) (-2444 . 545258) (-2445 . 544754) (-2446 . 544702) (-2447 . 544212) (-2448 . 543984) (-2449 . 543869) (-2450 . 543719) (-2451 . 543601) (-2452 . 543526) (-2453 . 543423) (-2454 . 543334) (-2455 . 543254) (-2456 . 543202) (-2457 . 543138) (-2458 . 543086) (-2459 . 543034) (-2460 . 542969) (-2461 . 542917) (-2462 . 542840) (-2463 . 542653) (-2464 . 542580) (-2465 . 542079) (-2466 . 541992) (-2467 . 541901) (-2468 . 541647) (-2469 . 541230) (-2470 . 541115) (-2471 . 540647) (-2472 . 540565) (-2473 . 540475) (-2474 . 540375) (-2475 . 540089) (-2476 . 540038) (-2477 . 539943) (-2478 . 539782) (-2479 . 539613) (-2480 . 538717) (-2481 . 538613) (-2482 . 538426) (-2483 . 538367) (-2484 . 538182) (-2485 . 538098) (-2486 . 537998) (-2487 . 537692) (-2488 . 537606) (-2489 . 537525) (-2490 . 537391) (-2491 . 537243) (-2492 . 537087) (-2493 . 536988) (-2494 . 536870) (-2495 . 536784) (-2496 . 536752) (-2497 . 535717) (-2498 . 535617) (-2499 . 535394) (-2500 . 535178) (-2501 . 533941) (-2502 . 533888) (-2503 . 533792) (-2504 . 533716) (-2505 . 533440) (-2506 . 533291) (-2507 . 533139) (-2508 . 533088) (-2509 . 532993) (-2510 . 532494) (-2511 . 532400) (-2512 . 531269) (-2513 . 531131) (-2514 . 531071) (-2515 . 530946) (-2516 . 530808) (-2517 . 530726) (-2518 . 530582) (-2519 . 530384) (-2520 . 530333) (-2521 . 530062) (-2522 . 529691) (-2523 . 529380) (-2524 . 529296) (-2525 . 528339) (-2526 . 528173) (-2527 . 528027) (-2528 . 527767) (-2529 . 527639) (-2530 . 527434) (-2531 . 527365) (-2532 . 526828) (-2533 . 526754) (-2534 . 526622) (-2535 . 526442) (-2536 . 526266) (-2537 . 525979) (-2538 . 525837) (-2539 . 525781) (-2540 . 525709) (-2541 . 525608) (-2542 . 525455) (-2543 . 525364) (-2544 . 525248) (-2545 . 525111) (-2546 . 525058) (-2547 . 525009) (-2548 . 524322) (-2549 . 524169) (-2550 . 524026) (-2551 . 523790) (-2552 . 523652) (-2553 . 523618) (-2554 . 523549) (-2555 . 523314) (-2556 . 523236) (-2557 . 523158) (-2558 . 523103) (-2559 . 523015) (-2560 . 522898) (-2561 . 522794) (-2562 . 522699) (-2563 . 522260) (-2564 . 522208) (-2565 . 522089) (-2566 . 521943) (-2567 . 521809) (-2568 . 521514) (-2569 . 521346) (-2570 . 521294) (-2571 . 521139) (-2572 . 520989) (-2573 . 520900) (-2574 . 520309) (-2575 . 520256) (-2576 . 520148) (-2577 . 519993) (-2578 . 519433) (-2579 . 519363) (-2580 . 519219) (-2581 . 519153) (-2582 . 518584) (-2583 . 518220) (-2584 . 518072) (-2585 . 517969) (-2586 . 517812) (-2587 . 517479) (-2588 . 517413) (-2589 . 517260) (-2590 . 517177) (-2591 . 517148) (-2592 . 516777) (-2593 . 516700) (-2594 . 516596) (-2595 . 515779) (-2596 . 514408) (-2597 . 514337) (-2598 . 513940) (-2599 . 513863) (-2600 . 513650) (-2601 . 513616) (-2602 . 513294) (-2603 . 513244) (-2604 . 511726) (-2605 . 511667) (-2606 . 511109) (-2607 . 511035) (-2608 . 510742) (-2609 . 510100) (-2610 . 509997) (-2611 . 509702) (-2612 . 509668) (-2613 . 509375) (-2614 . 509307) (-2615 . 509236) (-2616 . 509020) (-2617 . 508835) (-2618 . 508688) (-2619 . 508553) (-2620 . 508153) (-2621 . 508057) (-2622 . 507960) (-2623 . 507807) (-2624 . 507708) (-2625 . 507373) (-2626 . 507277) (-2627 . 505880) (-2628 . 505343) (-2629 . 505294) (-2630 . 504445) (-2631 . 504338) (-2632 . 504026) (-2633 . 503687) (-2634 . 503592) (-2635 . 503540) (-2636 . 503194) (-2637 . 503122) (-2638 . 503093) (-2639 . 503008) (-2640 . 502923) (-2641 . 502895) (-2642 . 502723) (-2643 . 502520) (-2644 . 501907) (-2645 . 501855) (-2646 . 501697) (-2647 . 501644) (-2648 . 501545) (-2649 . 501463) (-2650 . 501353) (-2651 . 500976) (-2652 . 500897) (-2653 . 500615) (-2654 . 500482) (-2655 . 500430) (-2656 . 500348) (-2657 . 498636) (-2658 . 498534) (-2659 . 496097) (-2660 . 496024) (-2661 . 495187) (-2662 . 495071) (-2663 . 494915) (-2664 . 493928) (-2665 . 493780) (-2666 . 493713) (-2667 . 493268) (-2668 . 493042) (-2669 . 492769) (-2670 . 492496) (-2671 . 492057) (-2672 . 491546) (-2673 . 491438) (-2674 . 491350) (-2675 . 491186) (-2676 . 491090) (-2677 . 490900) (-2678 . 489871) (-2679 . 489791) (-2680 . 489700) (-2681 . 489626) (-2682 . 489410) (-2683 . 489357) (-2684 . 489202) (-2685 . 489017) (-2686 . 488845) (-2687 . 488817) (-2688 . 487886) (-2689 . 487834) (-2690 . 487797) (-2691 . 487739) (-2692 . 487666) (-2693 . 487400) (-2694 . 487338) (-2695 . 487035) (-2696 . 486916) (-2697 . 486841) (-2698 . 486769) (-2699 . 486567) (-2700 . 486474) (-2701 . 486398) (-2702 . 486331) (-2703 . 486153) (-2704 . 485576) (-2705 . 485395) (-2706 . 485262) (-2707 . 485153) (-2708 . 484997) (-2709 . 484945) (-2710 . 484522) (-2711 . 484363) (-2712 . 484122) (-2713 . 484055) (-2714 . 483976) (-2715 . 483040) (-2716 . 482936) (-2717 . 482784) (-2718 . 482650) (-2719 . 482561) (-2720 . 482506) (-2721 . 481455) (-2722 . 481047) (-2723 . 480892) (-2724 . 480163) (-2725 . 479951) (-2726 . 479772) (-2727 . 479367) (-2728 . 479315) (-2729 . 479029) (-2730 . 478686) (-2731 . 478583) (-2732 . 478408) (-2733 . 478297) (-2734 . 478204) (-2735 . 477973) (-2736 . 477561) (-2737 . 477484) (-2738 . 477346) (-2739 . 477208) (-2740 . 477134) (-2741 . 477037) (-2742 . 476972) (-2743 . 476790) (-2744 . 476701) (-2745 . 453193) (-2746 . 453136) (-2747 . 453030) (-2748 . 452838) (-2749 . 452712) (-2750 . 452594) (-2751 . 452469) (-2752 . 452377) (-2753 . 452325) (-2754 . 452268) (-2755 . 452197) (-2756 . 452025) (-2757 . 451574) (-2758 . 451158) (-2759 . 450993) (-2760 . 450928) (-2761 . 450813) (-2762 . 450738) (-2763 . 449554) (-2764 . 449054) (-2765 . 448916) (-2766 . 448291) (-2767 . 448139) (-2768 . 447469) (-2769 . 446931) (-2770 . 446860) (-2771 . 446560) (-2772 . 446461) (-2773 . 446098) (-2774 . 445943) (-2775 . 445871) (-2776 . 445208) (-2777 . 445105) (-2778 . 445029) (-2779 . 439931) (-2780 . 439879) (-2781 . 439573) (-2782 . 439385) (-2783 . 439165) (-2784 . 438890) (-2785 . 438804) (-2786 . 438099) (-2787 . 437792) (-2788 . 433868) (-2789 . 432909) (-2790 . 432204) (-2791 . 432149) (-2792 . 431778) (-2793 . 431687) (-2794 . 431525) (-2795 . 417693) (-2796 . 417493) (-2797 . 417404) (-2798 . 417242) (-2799 . 417171) (-2800 . 417097) (-2801 . 416633) (-2802 . 416503) (-2803 . 415542) (-2804 . 415441) (-2805 . 415360) (-2806 . 414854) (-2807 . 414802) (-2808 . 414729) (-2809 . 414609) (-2810 . 414410) (-2811 . 414313) (-2812 . 414058) (-2813 . 413977) (-2814 . 413759) (-2815 . 413670) (-2816 . 413572) (-2817 . 413447) (-2818 . 412878) (-2819 . 412755) (-2820 . 412468) (-2821 . 412287) (-2822 . 412122) (-2823 . 412041) (-2824 . 411912) (-2825 . 411839) (-2826 . 411686) (-2827 . 411578) (-2828 . 411502) (-2829 . 411307) (-2830 . 411168) (-2831 . 411021) (-2832 . 410647) (-2833 . 410522) (-2834 . 410372) (-2835 . 410254) (-2836 . 410129) (-2837 . 409841) (-2838 . 409731) (-2839 . 409590) (-2840 . 409498) (-2841 . 408863) (-2842 . 408811) (-2843 . 408489) (-2844 . 408347) (-2845 . 407389) (-2846 . 407276) (-2847 . 405786) (-2848 . 405696) (-2849 . 404973) (-2850 . 404720) (-2851 . 404692) (-2852 . 404592) (-2853 . 404437) (-2854 . 399375) (-2855 . 399040) (-2856 . 398957) (-2857 . 398824) (-2858 . 398723) (-2859 . 398670) (-2860 . 398518) (-2861 . 398382) (-2862 . 398316) (-2863 . 398206) (-2864 . 398135) (-2865 . 397921) (-2866 . 397781) (-2867 . 397678) (-2868 . 397342) (-2869 . 397267) (-2870 . 396804) (-2871 . 396663) (-2872 . 396629) (-2873 . 396565) (-2874 . 396491) (-2875 . 396299) (-2876 . 396091) (-2877 . 395972) (-2878 . 395856) (-2879 . 395570) (-2880 . 395396) (-2881 . 395326) (-2882 . 394849) (-2883 . 394696) (-2884 . 394573) (-2885 . 394520) (-2886 . 394372) (-2887 . 393505) (-2888 . 393425) (-2889 . 393370) (-2890 . 393042) (-2891 . 392972) (-2892 . 392916) (-2893 . 392681) (-2894 . 392544) (-2895 . 392454) (-2896 . 392336) (-2897 . 391851) (-2898 . 391761) (-2899 . 391545) (-2900 . 391467) (-2901 . 391209) (-2902 . 391070) (-2903 . 390985) (-2904 . 390893) (-2905 . 390811) (-2906 . 390777) (-2907 . 390681) (-2908 . 390631) (-2909 . 390578) (-2910 . 390498) (-2911 . 390423) (-2912 . 390310) (-2913 . 390239) (-2914 . 390163) (-2915 . 390106) (-2916 . 390004) (-2917 . 389406) (-2918 . 389178) (-2919 . 389026) (-2920 . 388902) (-2921 . 388821) (-2922 . 388681) (-2923 . 388593) (-2924 . 388478) (-2925 . 387340) (-2926 . 387082) (-2927 . 386930) (-2928 . 386831) (-2929 . 386682) (-2930 . 386531) (-2931 . 386406) (-2932 . 385661) (-2933 . 385562) (-2934 . 385445) (-2935 . 385378) (-2936 . 385048) (-2937 . 384992) (-2938 . 384823) (-2939 . 384762) (-2940 . 384626) (-2941 . 384573) (-2942 . 383694) (-2943 . 383534) (-2944 . 383419) (-2945 . 383329) (-2946 . 383116) (-2947 . 382820) (-2948 . 382705) (-2949 . 382131) (-2950 . 381968) (-2951 . 381864) (-2952 . 381719) (-2953 . 381502) (-2954 . 381158) (-2955 . 381067) (-2956 . 380929) (-2957 . 380845) (-2958 . 380707) (-2959 . 380012) (-2960 . 379707) (-2961 . 379225) (-2962 . 378710) (-2963 . 378630) (-2964 . 378578) (-2965 . 378504) (-2966 . 378360) (-2967 . 378270) (-2968 . 377721) (-2969 . 377396) (-2970 . 377299) (-2971 . 377242) (-2972 . 377116) (-2973 . 377007) (-2974 . 376879) (-2975 . 376596) (-2976 . 376155) (-2977 . 376044) (-2978 . 375887) (-2979 . 375707) (-2980 . 375546) (-2981 . 375441) (-2982 . 375293) (-2983 . 375216) (-2984 . 375139) (-2985 . 375065) (-2986 . 374869) (-2987 . 374758) (-2988 . 374535) (-2989 . 374461) (-2990 . 374157) (-2991 . 374039) (-2992 . 373934) (-2993 . 373779) (-2994 . 373598) (-2995 . 373566) (-2996 . 373463) (-2997 . 373358) (-2998 . 373278) (-2999 . 373216) (-3000 . 373133) (-3001 . 373071) (-3002 . 373011) (-3003 . 372760) (-3004 . 372527) (-3005 . 372436) (-3006 . 372337) (-3007 . 372102) (-3008 . 371998) (-3009 . 371945) (-3010 . 371867) (-3011 . 371759) (-3012 . 371687) (-3013 . 371472) (-3014 . 371405) (-3015 . 371300) (-3016 . 371174) (-3017 . 371048) (-3018 . 370912) (-3019 . 370808) (-3020 . 370706) (-3021 . 370509) (-3022 . 370434) (-3023 . 370356) (-3024 . 370257) (-3025 . 370084) (-3026 . 369987) (-3027 . 369617) (-3028 . 369289) (-3029 . 366334) (-3030 . 366214) (-3031 . 365922) (-3032 . 365800) (-3033 . 365652) (-3034 . 365579) (-3035 . 365512) (-3036 . 365383) (-3037 . 365235) (-3038 . 365193) (-3039 . 364305) (-3040 . 364016) (-3041 . 363941) (-3042 . 363776) (-3043 . 363541) (-3044 . 363425) (-3045 . 363372) (-3046 . 363247) (-3047 . 363215) (-3048 . 363075) (-3049 . 362996) (-3050 . 362876) (-3051 . 362735) (-3052 . 362612) (-3053 . 362546) (-3054 . 362468) (-3055 . 362249) (-3056 . 362081) (-3057 . 361757) (-3058 . 361363) (-3059 . 361257) (-3060 . 361150) (-3061 . 361069) (-3062 . 360917) (-3063 . 360807) (-3064 . 360724) (-3065 . 360696) (-3066 . 360644) (-3067 . 360595) (-3068 . 360447) (-3069 . 360339) (-3070 . 360286) (-3071 . 360144) (-3072 . 360091) (-3073 . 359939) (-3074 . 359850) (-3075 . 359754) (-3076 . 359632) (-3077 . 359534) (-3078 . 359420) (-3079 . 359339) (-3080 . 359140) (-3081 . 359081) (-3082 . 358701) (-3083 . 358600) (-3084 . 357967) (-3085 . 357059) (-3086 . 356925) (-3087 . 356754) (-3088 . 356671) (-3089 . 356590) (-3090 . 356538) (-3091 . 356441) (-3092 . 352831) (-3093 . 352432) (-3094 . 351752) (-3095 . 351658) (-3096 . 351544) (-3097 . 351420) (-3098 . 351367) (-3099 . 351264) (-3100 . 351180) (-3101 . 351111) (-3102 . 350940) (-3103 . 350678) (-3104 . 350582) (-3105 . 349382) (-3106 . 349229) (-3107 . 348772) (-3108 . 348693) (-3109 . 347854) (-3110 . 347788) (-3111 . 347692) (-3112 . 347257) (-3113 . 347092) (-3114 . 346409) (-3115 . 346096) (-3116 . 345738) (-3117 . 345683) (-3118 . 345524) (-3119 . 345360) (-3120 . 345307) (-3121 . 345251) (-3122 . 344795) (-3123 . 344740) (-3124 . 344656) (-3125 . 344205) (-3126 . 344153) (-3127 . 344075) (-3128 . 343964) (-3129 . 343876) (-3130 . 343769) (-3131 . 343679) (-3132 . 343481) (-3133 . 343377) (-3134 . 343333) (-3135 . 343305) (-3136 . 343135) (-3137 . 342961) (-3138 . 342890) (-3139 . 342809) (-3140 . 341909) (-3141 . 341757) (-3142 . 341637) (-3143 . 341523) (-3144 . 341379) (-3145 . 341069) (-3146 . 340976) (-3147 . 340691) (-3148 . 340574) (-3149 . 340500) (-3150 . 340181) (-3151 . 340106) (-3152 . 340025) (-3153 . 339966) (-3154 . 339858) (-3155 . 339746) (-3156 . 339348) (-3157 . 339149) (-3158 . 339015) (-3159 . 338956) (-3160 . 338830) (-3161 . 338717) (-3162 . 338628) (-3163 . 338537) (-3164 . 338294) (-3165 . 338157) (-3166 . 338017) (-3167 . 337885) (-3168 . 337696) (-3169 . 337575) (-3170 . 337508) (-3171 . 337099) (-3172 . 336886) (-3173 . 336760) (-3174 . 336505) (-3175 . 336240) (-3176 . 336181) (-3177 . 335999) (-3178 . 335868) (-3179 . 335493) (-3180 . 335360) (-3181 . 334982) (-3182 . 334139) (-3183 . 334069) (-3184 . 333989) (-3185 . 333904) (-3186 . 333852) (-3187 . 333493) (-3188 . 333227) (-3189 . 333104) (-3190 . 332308) (-3191 . 331767) (-3192 . 331620) (-3193 . 331350) (-3194 . 330975) (-3195 . 330828) (-3196 . 330350) (-3197 . 330274) (-3198 . 330185) (-3199 . 330035) (-3200 . 329937) (-3201 . 329722) (-3202 . 329615) (-3203 . 329329) (-3204 . 329160) (-3205 . 328961) (-3206 . 326671) (-3207 . 326561) (-3208 . 326226) (-3209 . 326134) (-3210 . 325574) (-3211 . 325492) (-3212 . 324577) (-3213 . 324414) (-3214 . 324000) (-3215 . 323897) (-3216 . 323668) (-3217 . 323435) (-3218 . 323352) (-3219 . 323189) (-3220 . 323075) (-3221 . 322984) (-3222 . 322933) (-3223 . 322727) (-3224 . 322609) (-3225 . 322555) (-3226 . 322527) (-3227 . 322412) (-3228 . 322195) (-3229 . 322126) (-3230 . 321971) (-3231 . 321890) (-3232 . 321778) (-3233 . 321672) (-3234 . 321622) (-3235 . 321538) (-3236 . 321347) (-3237 . 321213) (-3238 . 321123) (-3239 . 321013) (-3240 . 320984) (-3241 . 320720) (-3242 . 320568) (-3243 . 320450) (-3244 . 320307) (-3245 . 320056) (-3246 . 319975) (-3247 . 319923) (-3248 . 319363) (-3249 . 319331) (-3250 . 318766) (-3251 . 318681) (-3252 . 318572) (-3253 . 318439) (-3254 . 318313) (-3255 . 318164) (-3256 . 317971) (-3257 . 317846) (-3258 . 317719) (-3259 . 317536) (-3260 . 317414) (-3261 . 317324) (-3262 . 316838) (-3263 . 316771) (-3264 . 316707) (-3265 . 316582) (-3266 . 316446) (-3267 . 316276) (-3268 . 315953) (-3269 . 315887) (-3270 . 315780) (-3271 . 315651) (-3272 . 315069) (-3273 . 314821) (-3274 . 314726) (-3275 . 314624) (-3276 . 314195) (-3277 . 314003) (-3278 . 313730) (-3279 . 313649) (-3280 . 313318) (-3281 . 312644) (-3282 . 312434) (-3283 . 312089) (-3284 . 311761) (-3285 . 311637) (-3286 . 311528) (-3287 . 311376) (-3288 . 310987) (-3289 . 310808) (-3290 . 310700) (-3291 . 310486) (-3292 . 310315) (-3293 . 310224) (-3294 . 310022) (-3295 . 309386) (-3296 . 309327) (-3297 . 307596) (-3298 . 307515) (-3299 . 307372) (-3300 . 307102) (-3301 . 307049) (-3302 . 306978) (-3303 . 306800) (-3304 . 306598) (-3305 . 306507) (-3306 . 306473) (-3307 . 306391) (-3308 . 306194) (-3309 . 306100) (-3310 . 306026) (-3311 . 305876) (-3312 . 305769) (-3313 . 305703) (-3314 . 305627) (-3315 . 305574) (-3316 . 305352) (-3317 . 305086) (-3318 . 305017) (-3319 . 304965) (-3320 . 304868) (-3321 . 304796) (-3322 . 304730) (-3323 . 304623) (-3324 . 304085) (-3325 . 303973) (-3326 . 303936) (-3327 . 303861) (-3328 . 302638) (-3329 . 302583) (-3330 . 302532) (-3331 . 302429) (-3332 . 302242) (-3333 . 302064) (-3334 . 301939) (-3335 . 301882) (-3336 . 301762) (-3337 . 301580) (-3338 . 301441) (-3339 . 301376) (-3340 . 300707) (-3341 . 300645) (-3342 . 300413) (-3343 . 300291) (-3344 . 300193) (-3345 . 300041) (-3346 . 299908) (-3347 . 299807) (-3348 . 299732) (-3349 . 299463) (-3350 . 299378) (-3351 . 299275) (-3352 . 298677) (-3353 . 298593) (-3354 . 297919) (-3355 . 297669) (-3356 . 297585) (-3357 . 297413) (-3358 . 297282) (-3359 . 297067) (-3360 . 296698) (-3361 . 296604) (-3362 . 296529) (-3363 . 296352) (-3364 . 296117) (-3365 . 296089) (-3366 . 296003) (-3367 . 295639) (-3368 . 295419) (-3369 . 295294) (-3370 . 295227) (-3371 . 295103) (-3372 . 295032) (-3373 . 294781) (-3374 . 294294) (-3375 . 294144) (-3376 . 294012) (-3377 . 293960) (-3378 . 293832) (-3379 . 293591) (-3380 . 293507) (-3381 . 293366) (-3382 . 293257) (-3383 . 293173) (-3384 . 293021) (-3385 . 292819) (-3386 . 292729) (-3387 . 292438) (-3388 . 292350) (-3389 . 292267) (-3390 . 292205) (-3391 . 291802) (-3392 . 291664) (-3393 . 291413) (-3394 . 291352) (-3395 . 291235) (-3396 . 290924) (-3397 . 290824) (-3398 . 290719) (-3399 . 290309) (-3400 . 289918) (-3401 . 289654) (-3402 . 289452) (-3403 . 289312) (-3404 . 288569) (-3405 . 287858) (-3406 . 287390) (-3407 . 287302) (-3408 . 286624) (-3409 . 286385) (-3410 . 286305) (-3411 . 286212) (-3412 . 286155) (-3413 . 285963) (-3414 . 285907) (-3415 . 285839) (-3416 . 285703) (-3417 . 285585) (-3418 . 285381) (-3419 . 285173) (-3420 . 284891) (-3421 . 284687) (-3422 . 284466) (-3423 . 284343) (-3424 . 284290) (-3425 . 284182) (-3426 . 283969) (-3427 . 283748) (-3428 . 283588) (-3429 . 283509) (-3430 . 277120) (-3431 . 277012) (-3432 . 276952) (-3433 . 276800) (-3434 . 276726) (-3435 . 276667) (-3436 . 276573) (-3437 . 276286) (-3438 . 275828) (-3439 . 275705) (-3440 . 275564) (-3441 . 275239) (-3442 . 275172) (-3443 . 274873) (-3444 . 274777) (-3445 . 274674) (-3446 . 274604) (-3447 . 274426) (-3448 . 274228) (-3449 . 274040) (-3450 . 273737) (-3451 . 273408) (-3452 . 273236) (-3453 . 273162) (-3454 . 272983) (-3455 . 272760) (-3456 . 272586) (-3457 . 272458) (-3458 . 272392) (-3459 . 272204) (-3460 . 272116) (-3461 . 271838) (-3462 . 271698) (-3463 . 271515) (-3464 . 271431) (-3465 . 271361) (-3466 . 271291) (-3467 . 271113) (-3468 . 271029) (-3469 . 270976) (-3470 . 270725) (-3471 . 270424) (-3472 . 270361) (-3473 . 269730) (-3474 . 269548) (-3475 . 269385) (-3476 . 269357) (-3477 . 269207) (-3478 . 268922) (-3479 . 268869) (-3480 . 268841) (-3481 . 268359) (-3482 . 268330) (-3483 . 268168) (-3484 . 268034) (-3485 . 267908) (-3486 . 267805) (-3487 . 267752) (-3488 . 266755) (-3489 . 266678) (-3490 . 266621) (-3491 . 266530) (-3492 . 266457) (-3493 . 266335) (-3494 . 266013) (-3495 . 265490) (-3496 . 265244) (-3497 . 265163) (-3498 . 264591) (-3499 . 264514) (-3500 . 264480) (-3501 . 264302) (-3502 . 264240) (-3503 . 264166) (-3504 . 263959) (-3505 . 263855) (-3506 . 263778) (-3507 . 263595) (-3508 . 263411) (-3509 . 263345) (-3510 . 263282) (-3511 . 263216) (-3512 . 263164) (-3513 . 263061) (-3514 . 262871) (-3515 . 262818) (-3516 . 262709) (-3517 . 262643) (-3518 . 262591) (-3519 . 262510) (-3520 . 262440) (-3521 . 262317) (-3522 . 262110) (-3523 . 261921) (-3524 . 261683) (-3525 . 261617) (-3526 . 261543) (-3527 . 261509) (-3528 . 261405) (-3529 . 261203) (-3530 . 261128) (-3531 . 261047) (-3532 . 260979) (-3533 . 260878) (-3534 . 260532) (-3535 . 260374) (-3536 . 260130) (-3537 . 259756) (-3538 . 259687) (-3539 . 259631) (-3540 . 259559) (-3541 . 259307) (-3542 . 259225) (-3543 . 259118) (-3544 . 259017) (-3545 . 258808) (-3546 . 258774) (-3547 . 258281) (-3548 . 258188) (-3549 . 257679) (-3550 . 257561) (-3551 . 257454) (-3552 . 257383) (-3553 . 256797) (-3554 . 256378) (-3555 . 255929) (-3556 . 255452) (-3557 . 255349) (-3558 . 255242) (-3559 . 255140) (-3560 . 255018) (-3561 . 254746) (-3562 . 254678) (-3563 . 254370) (-3564 . 254269) (-3565 . 254160) (-3566 . 254081) (-3567 . 254049) (-3568 . 253980) (-3569 . 253787) (-3570 . 253551) (-3571 . 253425) (-3572 . 253373) (-3573 . 253302) (-3574 . 253201) (-3575 . 253043) (-3576 . 252969) (-3577 . 252892) (-3578 . 252799) (-3579 . 252637) (-3580 . 252545) (-3581 . 252470) (-3582 . 252401) (-3583 . 252264) (-3584 . 252109) (-3585 . 252057) (-3586 . 251958) (-3587 . 251905) (-3588 . 251792) (-3589 . 251515) (-3590 . 251427) (-3591 . 251293) (-3592 . 251225) (-3593 . 251130) (-3594 . 251024) (-3595 . 250241) (-3596 . 250189) (-3597 . 250137) (-3598 . 249929) (-3599 . 248712) (-3600 . 248473) (-3601 . 248352) (-3602 . 248246) (-3603 . 248139) (-3604 . 247965) (-3605 . 247873) (-3606 . 247802) (-3607 . 247635) (-3608 . 247549) (-3609 . 247476) (-3610 . 247234) (-3611 . 247205) (-3612 . 247044) (-3613 . 246965) (-3614 . 246910) (-3615 . 246705) (-3616 . 246637) (-3617 . 246534) (-3618 . 246437) (-3619 . 246333) (-3620 . 246207) (-3621 . 246005) (-3622 . 245886) (-3623 . 245536) (-3624 . 245285) (-3625 . 245172) (-3626 . 245098) (-3627 . 244819) (-3628 . 244299) (-3629 . 244001) (-3630 . 243897) (-3631 . 243763) (-3632 . 243523) (-3633 . 243164) (-3634 . 243039) (-3635 . 242862) (-3636 . 242793) (-3637 . 242690) (-3638 . 242539) (-3639 . 242391) (-3640 . 242178) (-3641 . 238254) (-3642 . 238019) (-3643 . 237900) (-3644 . 237487) (-3645 . 237387) (-3646 . 237115) (-3647 . 236996) (-3648 . 236633) (-3649 . 236481) (-3650 . 236425) (-3651 . 236394) (-3652 . 236296) (-3653 . 236185) (-3654 . 236101) (-3655 . 236050) (-3656 . 235910) (-3657 . 235675) (-3658 . 235579) (-3659 . 235551) (-3660 . 235184) (-3661 . 234266) (-3662 . 232996) (-3663 . 232756) (-3664 . 232659) (-3665 . 232607) (-3666 . 228432) (-3667 . 228329) (-3668 . 228142) (-3669 . 227985) (-3670 . 227930) (-3671 . 227830) (-3672 . 227758) (-3673 . 227702) (-3674 . 227006) (-3675 . 226749) (-3676 . 226624) (-3677 . 226525) (-3678 . 225734) (-3679 . 225632) (-3680 . 225085) (-3681 . 225035) (-3682 . 224729) (-3683 . 224591) (-3684 . 224378) (-3685 . 224194) (-3686 . 223760) (-3687 . 223516) (-3688 . 223307) (-3689 . 223221) (-3690 . 222707) (-3691 . 222140) (-3692 . 222014) (-3693 . 221949) (-3694 . 221851) (-3695 . 221701) (-3696 . 221614) (-3697 . 221016) (-3698 . 220908) (-3699 . 220786) (-3700 . 219599) (-3701 . 219442) (-3702 . 219308) (-3703 . 219065) (-3704 . 218961) (-3705 . 218801) (-3706 . 218697) (-3707 . 218624) (-3708 . 218439) (-3709 . 218339) (-3710 . 218024) (-3711 . 217953) (-3712 . 217852) (-3713 . 217086) (-3714 . 216281) (-3715 . 215998) (-3716 . 215939) (-3717 . 215158) (-3718 . 214795) (-3719 . 214742) (-3720 . 214668) (-3721 . 214465) (-3722 . 213945) (-3723 . 213818) (-3724 . 213621) (-3725 . 213568) (-3726 . 213467) (-3727 . 213388) (-3728 . 210549) (-3729 . 210296) (-3730 . 210003) (-3731 . 209762) (-3732 . 209639) (-3733 . 209497) (-3734 . 209314) (-3735 . 209259) (-3736 . 209066) (-3737 . 208831) (-3738 . 208571) (-3739 . 208422) (-3740 . 208284) (-3741 . 208190) (-3742 . 208060) (-3743 . 207978) (-3744 . 207607) (-3745 . 207519) (-3746 . 206696) (-3747 . 206574) (-3748 . 206424) (-3749 . 206280) (-3750 . 206138) (-3751 . 205176) (-3752 . 204868) (-3753 . 204723) (-3754 . 203948) (-3755 . 203681) (-3756 . 203581) (-3757 . 203037) (-3758 . 202901) (-3759 . 202804) (-3760 . 202730) (-3761 . 202496) (-3762 . 202416) (-3763 . 202325) (-3764 . 202249) (-3765 . 202126) (-3766 . 202070) (-3767 . 201996) (-3768 . 201741) (-3769 . 201502) (-3770 . 201449) (-3771 . 201347) (-3772 . 201272) (-3773 . 201216) (-3774 . 201024) (-3775 . 200932) (-3776 . 200763) (-3777 . 200711) (-3778 . 200582) (-3779 . 200509) (-3780 . 200426) (-3781 . 198462) (-3782 . 198288) (-3783 . 198167) (-3784 . 198078) (-3785 . 198044) (-3786 . 197964) (-3787 . 197882) (-3788 . 197637) (-3789 . 197529) (-3790 . 197388) (-3791 . 197278) (-3792 . 196939) (-3793 . 196735) (-3794 . 196596) (-3795 . 196465) (-3796 . 196362) (-3797 . 195940) (-3798 . 195756) (-3799 . 195567) (-3800 . 195420) (-3801 . 195339) (-3802 . 195175) (-3803 . 195094) (-3804 . 195032) (-3805 . 194943) (-3806 . 194860) (-3807 . 194612) (-3808 . 194403) (-3809 . 194143) (-3810 . 194059) (-3811 . 193985) (-3812 . 193951) (-3813 . 193483) (-3814 . 193287) (-3815 . 193179) (-3816 . 193062) (-3817 . 193007) (-3818 . 192682) (-3819 . 190645) (-3820 . 190355) (-3821 . 189783) (-3822 . 189548) (-3823 . 189171) (-3824 . 189021) (-3825 . 188918) (-3826 . 188770) (-3827 . 188670) (-3828 . 188447) (-3829 . 188395) (-3830 . 188285) (-3831 . 188064) (-3832 . 187932) (-3833 . 187793) (-3834 . 187694) (-3835 . 187540) (-3836 . 187469) (-3837 . 180629) (-3838 . 180521) (-3839 . 179056) (-3840 . 178904) (-3841 . 178774) (-3842 . 178532) (-3843 . 178479) (-3844 . 178269) (-3845 . 177918) (-3846 . 177765) (-3847 . 177529) (-3848 . 172039) (-3849 . 171904) (-3850 . 171873) (-3851 . 171802) (-3852 . 171718) (-3853 . 171602) (-3854 . 171498) (-3855 . 171291) (-3856 . 171235) (-3857 . 170794) (-3858 . 170587) (-3859 . 170390) (-3860 . 170227) (-3861 . 170040) (-3862 . 169985) (-3863 . 169402) (-3864 . 169336) (-3865 . 169233) (-3866 . 168896) (-3867 . 168824) (-3868 . 168753) (-3869 . 168596) (-3870 . 165930) (-3871 . 165902) (-3872 . 165750) (-3873 . 165676) (-3874 . 165554) (-3875 . 165165) (-3876 . 164648) (-3877 . 164484) (-3878 . 163993) (-3879 . 163964) (-3880 . 163621) (-3881 . 163004) (-3882 . 162967) (-3883 . 162895) (-3884 . 162548) (-3885 . 162345) (-3886 . 162182) (-3887 . 162129) (-3888 . 161999) (-3889 . 161784) (-3890 . 161642) (-3891 . 161308) (-3892 . 161280) (-3893 . 161060) (-3894 . 160979) (-3895 . 160898) (-3896 . 160645) (-3897 . 160541) (-3898 . 160348) (-3899 . 160143) (-3900 . 159812) (-3901 . 159731) (-3902 . 159461) (-3903 . 159370) (-3904 . 159315) (-3905 . 159185) (-3906 . 159114) (-3907 . 159024) (-3908 . 158827) (-3909 . 158698) (-3910 . 158601) (-3911 . 158573) (-3912 . 158397) (-3913 . 158132) (-3914 . 157906) (-3915 . 157851) (-3916 . 157761) (-3917 . 157504) (-3918 . 157416) (-3919 . 157005) (-3920 . 156863) (-3921 . 156358) (-3922 . 156284) (-3923 . 156175) (-3924 . 156081) (-3925 . 155842) (-3926 . 155723) (-3927 . 155357) (-3928 . 155291) (-3929 . 154919) (-3930 . 154887) (-3931 . 154699) (-3932 . 154527) (-3933 . 154435) (-3934 . 154181) (-3935 . 153769) (-3936 . 152415) (-3937 . 152142) (-3938 . 152025) (-3939 . 151850) (-3940 . 151698) (-3941 . 151623) (-3942 . 151276) (-3943 . 151060) (-3944 . 150884) (-3945 . 150476) (-3946 . 150424) (-3947 . 150154) (-3948 . 150055) (-3949 . 149730) (-3950 . 149473) (-3951 . 149398) (-3952 . 149285) (-3953 . 149099) (-3954 . 149028) (-3955 . 148938) (-3956 . 148839) (-3957 . 148754) (-3958 . 148686) (-3959 . 148583) (-3960 . 148508) (-3961 . 148269) (-3962 . 148163) (-3963 . 148067) (-3964 . 147923) (-3965 . 147771) (-3966 . 147616) (-3967 . 147537) (-3968 . 147272) (-3969 . 146144) (-3970 . 146025) (-3971 . 145950) (-3972 . 145854) (-3973 . 145801) (-3974 . 145767) (-3975 . 145709) (-3976 . 145611) (-3977 . 145535) (-3978 . 145390) (-3979 . 145309) (-3980 . 145182) (-3981 . 145098) (-3982 . 144967) (-3983 . 144009) (-3984 . 143943) (-3985 . 143875) (-3986 . 143826) (-3987 . 143631) (-3988 . 143507) (-3989 . 143286) (-3990 . 142876) (-3991 . 142814) (-3992 . 142639) (-3993 . 142565) (-3994 . 142420) (-3995 . 142299) (-3996 . 141657) (-3997 . 141585) (-3998 . 141134) (-3999 . 140816) (-4000 . 140744) (-4001 . 140612) (-4002 . 140473) (-4003 . 140415) (-4004 . 140294) (-4005 . 140235) (-4006 . 140084) (-4007 . 139470) (-4008 . 139355) (-4009 . 139214) (-4010 . 139162) (-4011 . 139020) (-4012 . 138918) (-4013 . 138067) (-4014 . 137864) (-4015 . 137784) (-4016 . 137695) (-4017 . 137578) (-4018 . 137468) (-4019 . 137296) (-4020 . 137225) (-4021 . 137126) (-4022 . 136506) (-4023 . 135961) (-4024 . 135911) (-4025 . 135695) (-4026 . 135380) (-4027 . 135217) (-4028 . 135121) (-4029 . 134636) (-4030 . 134279) (-4031 . 134223) (-4032 . 133816) (-4033 . 133691) (-4034 . 133595) (-4035 . 133451) (-4036 . 133146) (-4037 . 133078) (-4038 . 133044) (-4039 . 132960) (-4040 . 132827) (-4041 . 132528) (-4042 . 132341) (-4043 . 132240) (-4044 . 132022) (-4045 . 131739) (-4046 . 131606) (-4047 . 131572) (-4048 . 131202) (-4049 . 130983) (-4050 . 130902) (-4051 . 130851) (-4052 . 130765) (-4053 . 130388) (-4054 . 130280) (-4055 . 130189) (-4056 . 130003) (-4057 . 129895) (-4058 . 129809) (-4059 . 129686) (-4060 . 129600) (-4061 . 129272) (-4062 . 129198) (-4063 . 128932) (-4064 . 128787) (-4065 . 128701) (-4066 . 128643) (-4067 . 128462) (-4068 . 128379) (-4069 . 127367) (-4070 . 127235) (-4071 . 127149) (-4072 . 127076) (-4073 . 125942) (-4074 . 125833) (-4075 . 125758) (-4076 . 125672) (-4077 . 125640) (-4078 . 124819) (-4079 . 124696) (-4080 . 124573) (-4081 . 124360) (-4082 . 124304) (-4083 . 123371) (-4084 . 123285) (-4085 . 123161) (-4086 . 122512) (-4087 . 122438) (-4088 . 122362) (-4089 . 115973) (-4090 . 115887) (-4091 . 115812) (-4092 . 115655) (-4093 . 115544) (-4094 . 115453) (-4095 . 115404) (-4096 . 115224) (-4097 . 114905) (-4098 . 114819) (-4099 . 114722) (-4100 . 114665) (-4101 . 114637) (-4102 . 112200) (-4103 . 112119) (-4104 . 111985) (-4105 . 111899) (-4106 . 111817) (-4107 . 111665) (-4108 . 111395) (-4109 . 111099) (-4110 . 110833) (-4111 . 110774) (-4112 . 110688) (-4113 . 110584) (-4114 . 109764) (-4115 . 109595) (-4116 . 109406) (-4117 . 109308) (-4118 . 108952) (-4119 . 108902) (-4120 . 108810) (-4121 . 108695) (-4122 . 108544) (-4123 . 108271) (-4124 . 107749) (-4125 . 106960) (-4126 . 106820) (-4127 . 106734) (-4128 . 106194) (-4129 . 106166) (-4130 . 106111) (-4131 . 106041) (-4132 . 105912) (-4133 . 105800) (-4134 . 105748) (-4135 . 105662) (-4136 . 105573) (-4137 . 105474) (-4138 . 105368) (-4139 . 105264) (-4140 . 105178) (-4141 . 105106) (-4142 . 104940) (-4143 . 104865) (-4144 . 104461) (-4145 . 104409) (-4146 . 104164) (-4147 . 104012) (-4148 . 103926) (-4149 . 103330) (-4150 . 103278) (-4151 . 103145) (-4152 . 102961) (-4153 . 102891) (-4154 . 102547) (-4155 . 102461) (-4156 . 102400) (-4157 . 101559) (-4158 . 101304) (-4159 . 101186) (-4160 . 101075) (-4161 . 100982) (-4162 . 100673) (-4163 . 100483) (-4164 . 100358) (-4165 . 100286) (-4166 . 100212) (-4167 . 99435) (-4168 . 98092) (-4169 . 98001) (-4170 . 97906) (-4171 . 97796) (-4172 . 97699) (-4173 . 97520) (-4174 . 97427) (-4175 . 97335) (-4176 . 96912) (-4177 . 96760) (-4178 . 96498) (-4179 . 96391) (-4180 . 96278) (-4181 . 95945) (-4182 . 95853) (-4183 . 95472) (-4184 . 95365) (-4185 . 95306) (-4186 . 95255) (-4187 . 95171) (-4188 . 95082) (-4189 . 92837) (-4190 . 92674) (-4191 . 92594) (-4192 . 92517) (-4193 . 92447) (-4194 . 92283) (-4195 . 92123) (-4196 . 92037) (-4197 . 91910) (-4198 . 91842) (-4199 . 91723) (-4200 . 91387) (-4201 . 91314) (-4202 . 91142) (-4203 . 90528) (-4204 . 90472) (-4205 . 90362) (-4206 . 90296) (-4207 . 89906) (-4208 . 89820) (-4209 . 89682) (-4210 . 89435) (-4211 . 89300) (-4212 . 89225) (-4213 . 89089) (-4214 . 88932) (-4215 . 88740) (-4216 . 88241) (-4217 . 88080) (-4218 . 87955) (-4219 . 87869) (-4220 . 86803) (-4221 . 86696) (-4222 . 86589) (-4223 . 86557) (-4224 . 86443) (-4225 . 86384) (-4226 . 86221) (-4227 . 86075) (-4228 . 86009) (-4229 . 85898) (-4230 . 85684) (-4231 . 85411) (-4232 . 85325) (-4233 . 85209) (-4234 . 85091) (-4235 . 85038) (-4236 . 84836) (-4237 . 84722) (-4238 . 84562) (-4239 . 84482) (-4240 . 84395) (-4241 . 84306) (-4242 . 84190) (-4243 . 83974) (-4244 . 83816) (-4245 . 83525) (-4246 . 83419) (-4247 . 83316) (-4248 . 83081) (-4249 . 82988) (-4250 . 82802) (-4251 . 80691) (-4252 . 80432) (-4253 . 80259) (-4254 . 80206) (-4255 . 79890) (-4256 . 79804) (-4257 . 79713) (-4258 . 79580) (-4259 . 79467) (-4260 . 79418) (-4261 . 79323) (-4262 . 79165) (-4263 . 79099) (-4264 . 79025) (-4265 . 78655) (-4266 . 78582) (-4267 . 78304) (-4268 . 78218) (-4269 . 78105) (-4270 . 78002) (-4271 . 77906) (-4272 . 77066) (-4273 . 76993) (-4274 . 76835) (-4275 . 76640) (-4276 . 76073) (-4277 . 75984) (-4278 . 71576) (-4279 . 71485) (-4280 . 71310) (-4281 . 71114) (-4282 . 70981) (-4283 . 70793) (-4284 . 70762) (-4285 . 70191) (-4286 . 70053) (-4287 . 67515) (-4288 . 67463) (-4289 . 67330) (-4290 . 67199) (-4291 . 67120) (-4292 . 67031) (-4293 . 66839) (-4294 . 66753) (-4295 . 66346) (-4296 . 66286) (-4297 . 65919) (-4298 . 65776) (-4299 . 65692) (-4300 . 65338) (-4301 . 65252) (-4302 . 64882) (-4303 . 64787) (-4304 . 64714) (-4305 . 64291) (-4306 . 64188) (-4307 . 64102) (-4308 . 63987) (-4309 . 63419) (-4310 . 63362) (-4311 . 63191) (-4312 . 63105) (-4313 . 62992) (-4314 . 62453) (-4315 . 62381) (-4316 . 62315) (-4317 . 62214) (-4318 . 61981) (-4319 . 61786) (-4320 . 61671) (-4321 . 60967) (-4322 . 60868) (-4323 . 60787) (-4324 . 60690) (-4325 . 60426) (-4326 . 60284) (-4327 . 60086) (-4328 . 59516) (-4329 . 55592) (-4330 . 55160) (-4331 . 54898) (-4332 . 54844) (-4333 . 54679) (-4334 . 54579) (-4335 . 54452) (-4336 . 54353) (-4337 . 54202) (-4338 . 53898) (-4339 . 53721) (-4340 . 53669) (-4341 . 53614) (-4342 . 53562) (-4343 . 53443) (-4344 . 53317) (-4345 . 53246) (-4346 . 53042) (-4347 . 52538) (-4348 . 52464) (-4349 . 52359) (-4350 . 52005) (-4351 . 43112) (-4352 . 42792) (-4353 . 42718) (-4354 . 42348) (-4355 . 42042) (-4356 . 41901) (-4357 . 41768) (-4358 . 41715) (-4359 . 41611) (-4360 . 40943) (-4361 . 40803) (-4362 . 40690) (-4363 . 40585) (-4364 . 40302) (-4365 . 40188) (-4366 . 39828) (-4367 . 39669) (-4368 . 39540) (-4369 . 39438) (-4370 . 39371) (-4371 . 39243) (-4372 . 39191) (-4373 . 39118) (-4374 . 39058) (-4375 . 38962) (-4376 . 35224) (-4377 . 35126) (-4378 . 35011) (-4379 . 34921) (-4380 . 34819) (-4381 . 34628) (-4382 . 34511) (-4383 . 34360) (-4384 . 34252) (-4385 . 34061) (-4386 . 33938) (-4387 . 33787) (-4388 . 33495) (-4389 . 33445) (-4390 . 33239) (-4391 . 32678) (-4392 . 32491) (-4393 . 32288) (-4394 . 32053) (-4395 . 31901) (-4396 . 31784) (-4397 . 31182) (-4398 . 31088) (-4399 . 30886) (-4400 . 30714) (-4401 . 30683) (-4402 . 30631) (-4403 . 30522) (-4404 . 30440) (-4405 . 30224) (-4406 . 30044) (-4407 . 29914) (-4408 . 29552) (-4409 . 29497) (-4410 . 27350) (-4411 . 27133) (-4412 . 25438) (-4413 . 25343) (-4414 . 25209) (-4415 . 24262) (-4416 . 23086) (-4417 . 22997) (-4418 . 22938) (-4419 . 22901) (-4420 . 22764) (-4421 . 22664) (-4422 . 22613) (-4423 . 22539) (-4424 . 22168) (-4425 . 21814) (-4426 . 21761) (-4427 . 21674) (-4428 . 21497) (-4429 . 21247) (-4430 . 20807) (-4431 . 20737) (-4432 . 20571) (-4433 . 20124) (-4434 . 20005) (-4435 . 19909) (-4436 . 19656) (-4437 . 19598) (-4438 . 19546) (-4439 . 19465) (-4440 . 19412) (-4441 . 19229) (-4442 . 19148) (-4443 . 19078) (-4444 . 19012) (-4445 . 18699) (-4446 . 18469) (-4447 . 18414) (-4448 . 17713) (-4449 . 17594) (-4450 . 15467) (-4451 . 15279) (-4452 . 14954) (-4453 . 14879) (-4454 . 14517) (-4455 . 14354) (-4456 . 14216) (-4457 . 14098) (-4458 . 13875) (-4459 . 13588) (** . 10523) (-4461 . 10460) (-4462 . 10389) (-4463 . 10305) (-4464 . 10168) (-4465 . 10006) (-4466 . 9835) (-4467 . 9704) (-4468 . 9550) (-4469 . 9278) (-4470 . 8931) (-4471 . 8702) (-4472 . 8573) (-4473 . 8462) (-4474 . 8201) (-4475 . 6596) (-4476 . 6358) (-4477 . 4074) (-4478 . 4000) (-4479 . 3945) (-4480 . 3832) (-4481 . 3591) (-4482 . 3101) (-4483 . 3000) (-4484 . 2905) (-4485 . 2604) (-4486 . 2552) (-4487 . 2073) (-4488 . 1923) (-4489 . 1871) (-4490 . 1787) (-4491 . 1260) (-4492 . 1184) (-4493 . 1035) (-4494 . 830) (-4495 . 627) (-4496 . 470) (-4497 . 271) (-4498 . 197) (-4499 . 30)) 
\ No newline at end of file
+(((*1 *2 *2 *3) (-12 (-5 *3 (-1161)) (-4 *4 (-13 (-842) (-301) (-1037 (-568)) (-630 (-568)) (-150))) (-5 *1 (-799 *4 *2)) (-4 *2 (-13 (-29 *4) (-1181) (-959)))))) 
+(((*1 *2 *3 *3 *4 *5) (-12 (-5 *3 (-634 (-679 *6))) (-5 *4 (-121)) (-5 *5 (-568)) (-5 *2 (-679 *6)) (-5 *1 (-1029 *6)) (-4 *6 (-365)) (-4 *6 (-1047)))) ((*1 *2 *3 *3) (-12 (-5 *3 (-634 (-679 *4))) (-5 *2 (-679 *4)) (-5 *1 (-1029 *4)) (-4 *4 (-365)) (-4 *4 (-1047)))) ((*1 *2 *3 *3 *4) (-12 (-5 *3 (-634 (-679 *5))) (-5 *4 (-568)) (-5 *2 (-679 *5)) (-5 *1 (-1029 *5)) (-4 *5 (-365)) (-4 *5 (-1047))))) 
+(((*1 *2 *3 *4) (-12 (-5 *3 (-643 (-409 *6))) (-5 *4 (-409 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2588 (-634 *4)))) (-5 *1 (-805 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-643 (-409 *6))) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-2 (|:| -2588 (-634 (-409 *6))) (|:| -2908 (-679 *5)))) (-5 *1 (-805 *5 *6)) (-5 *4 (-634 (-409 *6))))) ((*1 *2 *3 *4) (-12 (-5 *3 (-644 *6 (-409 *6))) (-5 *4 (-409 *6)) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-2 (|:| |particular| (-3 *4 "failed")) (|:| -2588 (-634 *4)))) (-5 *1 (-805 *5 *6)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-644 *6 (-409 *6))) (-4 *6 (-1219 *5)) (-4 *5 (-13 (-365) (-150) (-1037 (-568)) (-1037 (-409 (-568))))) (-5 *2 (-2 (|:| -2588 (-634 (-409 *6))) (|:| -2908 (-679 *5)))) (-5 *1 (-805 *5 *6)) (-5 *4 (-634 (-409 *6)))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-634 (-121))) (-4 *4 (-365)) (-14 *5 (-634 (-1161))) (-4 *6 (-950 *4 *7 (-852 *5))) (-4 *7 (-230 (-1699 *5) (-763))) (-4 *8 (-971 *4)) (-4 *9 (-641 *4)) (-4 *10 (-920 *4 *9)) (-4 *11 (-235 *10)) (-4 *12 (-536 *4 *5 *6 *7 *8 *9 *10 *11 *14)) (-4 *14 (-117)) (-5 *2 (-1249)) (-5 *1 (-467 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (-4 *13 (-258 *12)))) ((*1 *2) (-12 (-4 *1 (-641 *3)) (-4 *3 (-365)) (-5 *2 (-121)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-4 *1 (-641 *3)) (-4 *3 (-365)))) ((*1 *2 *2) (-12 (-5 *2 (-121)) (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *8 (-641 *3)) (-5 *1 (-654 *3 *4 *5 *6 *7 *8 *9)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *7 (-971 *3)) (-4 *9 (-920 *3 *8)))) ((*1 *2) (-12 (-4 *3 (-365)) (-14 *4 (-634 (-1161))) (-4 *6 (-230 (-1699 *4) (-763))) (-4 *8 (-641 *3)) (-5 *2 (-121)) (-5 *1 (-654 *3 *4 *5 *6 *7 *8 *9)) (-4 *5 (-950 *3 *6 (-852 *4))) (-4 *7 (-971 *3)) (-4 *9 (-920 *3 *8)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-2 (|:| |val| (-634 *8)) (|:| -3145 *9)))) (-5 *4 (-763)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1066 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-1249)) (-5 *1 (-1064 *5 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (-12 (-5 *3 (-634 (-2 (|:| |val| (-634 *8)) (|:| -3145 *9)))) (-5 *4 (-763)) (-4 *8 (-1061 *5 *6 *7)) (-4 *9 (-1099 *5 *6 *7 *8)) (-4 *5 (-453)) (-4 *6 (-788)) (-4 *7 (-842)) (-5 *2 (-1249)) (-5 *1 (-1130 *5 *6 *7 *8 *9))))) 
+(((*1 *2 *3) (-12 (-5 *3 (-1143)) (-5 *2 (-381)) (-5 *1 (-781))))) 
+((-1276 . 830515) (-1277 . 829073) (-1278 . 828100) (-1279 . 827698) (-1280 . 827534) (-1281 . 827431) (-1282 . 827382) (-1283 . 827311) (-1284 . 826980) (-1285 . 826884) (-1286 . 826286) (-1287 . 826091) (-1288 . 826022) (-1289 . 825927) (-1290 . 825737) (-1291 . 825653) (-1292 . 825432) (-1293 . 825295) (-1294 . 824971) (-1295 . 823942) (-1296 . 823268) (-1297 . 822858) (-1298 . 822696) (-1299 . 822087) (-1300 . 822007) (-1301 . 821757) (-1302 . 821582) (-1303 . 821489) (-1304 . 821196) (-1305 . 821105) (-1306 . 821021) (-1307 . 820947) (-1308 . 820739) (-1309 . 820665) (-1310 . 820591) (-1311 . 820419) (-1312 . 820274) (-1313 . 820174) (-1314 . 820121) (-1315 . 819905) (-1316 . 819774) (-1317 . 819702) (-1318 . 819606) (-1319 . 819506) (-1320 . 819406) (-1321 . 819221) (-1322 . 819127) (-1323 . 818676) (-1324 . 818493) (-1325 . 818174) (-1326 . 818002) (-1327 . 814264) (-1328 . 814189) (-1329 . 813871) (-1330 . 813792) (-1331 . 813764) (-1332 . 813526) (-1333 . 811089) (-1334 . 810991) (-1335 . 810814) (-1336 . 810742) (-1337 . 810408) (-1338 . 809477) (-1339 . 803645) (-1340 . 803573) (-1341 . 803408) (-1342 . 803293) (-1343 . 803058) (-1344 . 802926) (-1345 . 802114) (-1346 . 802065) (-1347 . 802013) (-1348 . 801923) (-1349 . 801871) (-1350 . 801843) (-1351 . 801704) (-1352 . 801579) (-1353 . 801542) (-1354 . 801438) (-1355 . 801304) (-1356 . 801113) (-1357 . 801027) (-1358 . 800968) (-1359 . 800567) (-1360 . 800491) (-1361 . 800420) (-1362 . 800362) (-1363 . 800245) (-1364 . 799881) (-1365 . 799730) (-1366 . 799579) (-1367 . 799526) (-1368 . 799440) (-1369 . 799367) (-1370 . 799147) (-1371 . 798533) (-1372 . 798267) (-1373 . 798122) (-1374 . 797802) (-1375 . 797726) (-1376 . 797618) (-1377 . 797493) (-1378 . 797378) (-1379 . 797212) (-1380 . 797086) (-1381 . 797024) (-1382 . 796833) (-1383 . 796766) (-1384 . 796625) (-1385 . 796388) (-1386 . 796302) (-1387 . 795999) (-1388 . 795876) (-1389 . 795752) (-1390 . 795700) (-1391 . 795549) (-1392 . 795460) (-1393 . 795110) (-1394 . 794991) (-1395 . 794920) (-1396 . 794069) (-1397 . 793976) (-1398 . 793909) (-1399 . 793617) (-1400 . 793542) (-1401 . 793291) (-1402 . 793088) (-1403 . 792843) (-1404 . 792793) (-1405 . 792704) (-1406 . 792632) (-1407 . 792145) (-1408 . 792065) (-1409 . 791964) (-1410 . 791872) (-1411 . 791788) (-1412 . 791586) (-1413 . 791380) (-1414 . 791230) (-1415 . 791141) (-1416 . 791048) (-1417 . 790950) (-1418 . 790826) (-1419 . 790265) (-1420 . 790133) (-1421 . 790016) (-1422 . 789815) (-1423 . 789739) (-1424 . 789672) (-1425 . 789485) (-1426 . 789433) (-1427 . 789323) (-1428 . 789256) (-1429 . 789163) (-1430 . 789088) (-1431 . 788885) (-1432 . 788757) (-1433 . 788686) (-1434 . 788616) (-1435 . 788381) (-1436 . 788142) (-1437 . 787964) (-1438 . 787723) (-1439 . 787178) (-1440 . 786997) (-1441 . 786860) (-1442 . 786538) (-1443 . 786421) (-1444 . 786337) (-1445 . 786287) (-1446 . 786149) (-1447 . 786060) (-1448 . 785660) (-1449 . 785527) (-1450 . 784925) (-1451 . 784784) (-1452 . 784568) (-1453 . 784459) (-1454 . 784311) (-1455 . 784102) (-1456 . 784008) (-1457 . 783924) (-1458 . 783609) (-1459 . 783453) (-1460 . 783322) (-1461 . 783256) (-1462 . 783054) (-1463 . 782902) (-1464 . 782739) (-1465 . 782647) (-1466 . 782595) (-1467 . 782395) (-1468 . 782223) (-1469 . 782133) (-1470 . 781648) (-1471 . 781225) (-1472 . 781141) (-1473 . 780302) (-1474 . 780193) (-1475 . 779902) (-1476 . 779545) (-1477 . 779386) (-1478 . 779310) (-1479 . 779258) (-1480 . 778207) (-1481 . 778125) (-1482 . 778037) (-1483 . 777981) (-1484 . 777868) (-1485 . 777706) (-1486 . 777622) (-1487 . 777381) (-1488 . 777165) (-1489 . 777082) (-1490 . 776675) (-1491 . 776495) (-1492 . 775915) (-1493 . 775811) (-1494 . 775744) (-1495 . 775606) (-1496 . 775481) (-1497 . 775124) (-1498 . 774990) (-1499 . 774911) (-1500 . 774781) (-1501 . 774530) (-1502 . 774386) (-1503 . 774024) (-1504 . 773885) (-1505 . 773760) (-1506 . 772824) (-1507 . 772707) (-1508 . 772402) (-1509 . 772347) (-1510 . 772211) (-1511 . 772113) (-1512 . 772009) (-1513 . 771698) (-1514 . 771630) (-1515 . 771501) (-1516 . 771349) (-1517 . 770926) (-1518 . 770793) (-1519 . 768646) (-1520 . 768546) (-1521 . 768512) (-1522 . 768378) (-1523 . 768273) (-1524 . 768026) (-1525 . 767973) (-1526 . 767756) (-1527 . 767623) (-1528 . 767539) (-1529 . 767450) (-1530 . 767375) (-1531 . 767172) (-1532 . 765477) (-1533 . 765067) (-1534 . 764768) (-1535 . 764673) (-1536 . 758142) (-1537 . 758034) (-1538 . 757979) (-1539 . 757588) (-1540 . 757401) (-1541 . 757267) (-1542 . 757195) (-1543 . 756787) (-1544 . 756523) (-1545 . 756422) (-1546 . 755475) (-1547 . 755401) (-1548 . 754672) (-1549 . 754470) (-1550 . 754252) (-1551 . 754040) (-1552 . 753911) (-1553 . 753822) (-1554 . 753682) (-1555 . 753399) (-1556 . 753220) (-1557 . 752977) (-1558 . 752838) (-1559 . 752786) (-1560 . 752727) (-1561 . 751984) (-1562 . 751950) (-1563 . 750849) (-1564 . 750812) (-1565 . 750673) (-1566 . 749554) (-1567 . 749149) (-1568 . 748438) (-1569 . 748068) (-1570 . 747931) (-1571 . 747751) (-1572 . 747699) (-1573 . 747231) (-1574 . 747012) (-1575 . 746853) (-1576 . 746567) (-1577 . 746467) (-1578 . 746379) (-1579 . 746298) (-1580 . 746247) (-1581 . 745904) (-1582 . 745226) (-1583 . 745175) (-1584 . 745101) (-1585 . 744998) (-1586 . 744929) (-1587 . 744690) (-1588 . 744313) (-1589 . 744264) (-1590 . 744089) (-1591 . 743718) (-1592 . 743638) (-1593 . 743530) (-1594 . 743176) (-1595 . 743083) (-1596 . 742990) (-1597 . 742899) (-1598 . 742668) (-1599 . 742615) (-1600 . 742558) (-1601 . 742372) (-1602 . 742285) (-1603 . 741873) (-1604 . 741681) (-1605 . 741573) (-1606 . 741496) (-1607 . 741319) (-1608 . 741263) (-1609 . 741140) (-1610 . 740890) (-1611 . 740822) (-1612 . 740736) (-1613 . 740676) (-1614 . 740576) (-1615 . 740136) (-1616 . 740000) (-1617 . 739672) (-1618 . 739449) (-1619 . 739379) (-1620 . 739176) (-1621 . 738972) (-1622 . 738706) (-1623 . 738490) (-1624 . 738324) (-1625 . 738116) (-1626 . 737971) (-1627 . 736734) (-1628 . 736287) (-1629 . 736005) (-1630 . 735947) (-1631 . 735894) (-1632 . 735798) (-1633 . 735594) (-1634 . 735413) (-1635 . 735317) (-1636 . 735064) (-1637 . 734843) (-1638 . 734760) (-1639 . 734684) (-1640 . 734626) (-1641 . 734421) (-1642 . 733409) (-1643 . 733360) (-1644 . 733084) (-1645 . 732950) (-1646 . 732898) (-1647 . 732766) (-1648 . 732617) (-1649 . 732526) (-1650 . 732467) (-1651 . 732386) (-1652 . 732313) (-1653 . 732161) (-1654 . 732048) (-1655 . 731995) (-1656 . 730861) (-1657 . 730747) (-1658 . 730696) (-1659 . 730607) (-1660 . 730424) (-1661 . 730315) (-1662 . 730220) (-1663 . 730129) (-1664 . 730048) (-1665 . 729973) (-1666 . 729859) (-1667 . 729360) (-1668 . 729117) (-1669 . 729047) (-1670 . 729015) (-1671 . 728901) (-1672 . 728807) (-1673 . 728670) (-1674 . 728604) (-1675 . 728291) (-1676 . 728183) (-1677 . 727240) (-1678 . 726109) (-1679 . 725969) (-1680 . 725780) (-1681 . 725723) (-1682 . 725548) (-1683 . 725359) (-1684 . 725221) (-1685 . 724991) (-1686 . 724844) (-1687 . 724766) (-1688 . 724685) (-1689 . 724625) (-1690 . 724504) (-1691 . 724449) (-1692 . 724336) (-1693 . 724287) (-1694 . 723586) (-1695 . 723461) (-1696 . 723394) (-1697 . 723230) (-1698 . 723178) (-1699 . 722428) (-1700 . 722309) (-1701 . 722171) (-1702 . 721762) (-1703 . 721681) (-1704 . 721552) (-1705 . 721339) (-1706 . 721257) (-1707 . 721168) (-1708 . 719041) (-1709 . 718931) (-1710 . 718829) (-1711 . 718564) (-1712 . 718420) (-1713 . 718337) (-1714 . 718149) (-1715 . 717824) (-1716 . 717768) (-1717 . 717663) (-1718 . 717465) (-1719 . 716764) (-1720 . 716705) (-1721 . 716457) (-1722 . 716379) (-1723 . 716175) (-1724 . 716052) (-1725 . 715870) (-1726 . 715819) (-1727 . 715610) (-1728 . 715535) (-1729 . 715457) (-1730 . 715095) (-1731 . 714987) (-1732 . 714716) (-1733 . 714094) (-1734 . 713794) (-1735 . 713663) (-1736 . 713403) (-1737 . 713240) (-1738 . 713132) (-1739 . 712761) (-1740 . 712675) (-1741 . 712300) (-1742 . 712216) (-1743 . 711373) (-1744 . 711111) (-1745 . 711012) (-1746 . 710701) (-1747 . 710473) (-1748 . 710335) (-1749 . 710261) (-1750 . 710191) (-1751 . 710086) (-1752 . 710002) (-1753 . 709916) (-1754 . 709798) (-1755 . 709764) (-1756 . 709647) (-1757 . 709567) (-1758 . 708610) (-1759 . 708387) (-1760 . 708279) (-1761 . 708156) (-1762 . 708071) (-1763 . 707905) (-1764 . 707618) (-1765 . 707501) (-1766 . 707378) (-1767 . 707323) (-1768 . 707177) (-1769 . 705670) (-1770 . 705618) (-1771 . 705555) (-1772 . 705295) (-1773 . 705181) (-1774 . 704822) (-1775 . 703223) (-1776 . 703152) (-1777 . 702827) (-1778 . 702699) (-1779 . 702530) (-1780 . 701989) (-1781 . 699693) (-1782 . 699609) (-1783 . 699319) (-1784 . 699125) (-1785 . 698988) (-1786 . 698783) (-1787 . 698636) (-1788 . 698064) (-1789 . 697995) (-1790 . 697826) (-1791 . 697664) (-1792 . 697394) (-1793 . 697044) (-1794 . 696894) (-1795 . 696715) (-1796 . 696544) (-1797 . 696007) (-1798 . 695632) (-1799 . 695529) (-1800 . 695455) (-1801 . 695324) (-1802 . 694846) (-1803 . 694698) (-1804 . 694604) (-1805 . 694453) (-1806 . 694321) (-1807 . 694245) (-1808 . 694091) (-1809 . 693991) (-1810 . 693902) (-1811 . 693722) (-1812 . 693450) (-1813 . 693227) (-1814 . 693051) (-1815 . 692901) (-1816 . 692554) (-1817 . 692502) (-1818 . 692273) (-1819 . 691986) (-1820 . 691888) (-1821 . 691778) (-1822 . 691649) (-1823 . 691507) (-1824 . 691292) (-1825 . 691071) (-1826 . 690932) (-1827 . 690876) (-1828 . 690769) (-1829 . 690658) (-1830 . 690397) (-1831 . 690325) (-1832 . 690039) (-1833 . 689940) (-1834 . 689786) (-1835 . 689685) (-1836 . 687395) (-1837 . 685790) (-1838 . 685680) (-1839 . 685527) (-1840 . 685289) (-1841 . 685218) (-1842 . 685127) (-1843 . 684792) (-1844 . 682508) (-1845 . 675668) (-1846 . 675556) (-1847 . 675482) (-1848 . 675366) (-1849 . 675274) (-1850 . 675166) (-1851 . 674561) (-1852 . 674409) (-1853 . 674272) (-1854 . 673712) (-1855 . 673657) (-1856 . 673575) (-1857 . 673516) (-1858 . 673463) (-1859 . 673350) (-1860 . 673220) (-1861 . 672675) (-1862 . 672434) (-1863 . 672385) (-1864 . 671470) (-1865 . 671228) (-1866 . 670799) (-1867 . 670385) (-1868 . 669698) (-1869 . 669208) (-1870 . 669155) (-1871 . 669046) (-1872 . 668731) (-1873 . 668628) (-1874 . 668475) (-1875 . 668374) (-1876 . 668023) (-1877 . 667928) (-1878 . 667785) (-1879 . 667556) (-1880 . 667403) (-1881 . 667170) (-1882 . 666934) (-1883 . 666633) (-1884 . 666397) (-1885 . 666345) (-1886 . 666207) (-1887 . 666124) (-1888 . 665989) (-1889 . 665721) (-1890 . 665690) (-1891 . 665656) (-1892 . 665565) (-1893 . 665086) (-1894 . 663936) (-1895 . 663885) (-1896 . 663816) (-1897 . 663666) (-1898 . 663595) (-1899 . 663341) (-1900 . 663135) (-1901 . 662900) (-1902 . 662816) (-1903 . 662764) (-1904 . 662382) (-1905 . 662304) (-1906 . 662220) (-1907 . 662102) (-1908 . 661998) (-1909 . 661471) (-1910 . 661393) (-1911 . 661339) (-1912 . 661132) (-1913 . 660993) (-1914 . 660965) (-1915 . 660910) (-1916 . 660834) (-1917 . 660778) (-1918 . 660639) (-1919 . 660432) (-1920 . 660344) (-1921 . 660229) (-1922 . 660080) (-1923 . 659875) (-1924 . 659758) (-1925 . 659603) (-1926 . 659406) (-1927 . 659302) (-1928 . 659221) (-1929 . 659058) (-1930 . 658919) (-1931 . 658824) (-1932 . 658712) (-1933 . 658525) (-1934 . 658117) (-1935 . 657464) (-1936 . 657025) (-1937 . 656919) (-1938 . 656864) (-1939 . 656317) (-1940 . 656265) (-1941 . 656215) (-1942 . 656149) (-1943 . 655602) (-1944 . 655483) (-1945 . 655399) (-1946 . 655296) (-1947 . 654749) (-1948 . 654603) (-1949 . 654412) (-1950 . 654340) (-1951 . 653689) (-1952 . 653555) (-1953 . 653465) (-1954 . 653394) (-1955 . 652743) (-1956 . 652448) (-1957 . 652338) (-1958 . 652181) (-1959 . 651468) (-1960 . 651413) (-1961 . 651245) (-1962 . 651216) (-1963 . 648550) (-1964 . 648005) (-1965 . 647953) (-1966 . 647689) (-1967 . 647661) (-1968 . 647116) (-1969 . 646966) (-1970 . 646814) (-1971 . 646662) (-1972 . 646117) (-1973 . 646028) (-1974 . 645910) (-1975 . 645836) (-1976 . 645184) (-1977 . 644593) (-1978 . 644342) (-1979 . 644220) (-1980 . 643568) (-1981 . 643515) (-1982 . 643434) (-1983 . 643045) (-1984 . 642393) (-1985 . 642285) (-1986 . 642233) (-1987 . 642069) (-1988 . 641523) (-1989 . 641368) (-1990 . 640808) (-1991 . 640317) (-1992 . 639771) (-1993 . 639211) (-1994 . 639179) (-1995 . 639150) (-1996 . 638604) (-1997 . 638534) (-1998 . 637969) (-1999 . 637626) (-2000 . 637081) (-2001 . 636937) (-2002 . 636804) (-2003 . 636187) (-2004 . 635642) (-2005 . 635576) (-2006 . 635450) (-2007 . 635413) (-2008 . 634868) (-2009 . 634299) (-2010 . 634150) (-2011 . 634078) (-2012 . 633533) (-2013 . 633169) (-2014 . 632976) (-2015 . 632629) (-2016 . 632084) (-2017 . 631936) (-2018 . 631811) (-2019 . 631608) (-2020 . 631505) (-2021 . 631322) (-2022 . 631159) (-2023 . 631002) (-2024 . 630880) (-2025 . 630827) (-2026 . 630494) (-2027 . 630404) (-2028 . 630274) (-2029 . 630208) (-2030 . 629722) (-2031 . 629507) (-2032 . 629354) (-2033 . 629287) (-2034 . 629145) (-2035 . 629062) (-2036 . 628998) (-2037 . 628664) (-2038 . 628635) (-2039 . 628510) (-2040 . 628482) (-2041 . 628404) (-2042 . 628033) (-2043 . 627863) (-2044 . 627643) (-2045 . 627365) (-2046 . 627288) (-2047 . 626965) (-2048 . 626884) (-2049 . 625337) (-2050 . 625233) (-2051 . 625167) (-2052 . 625086) (-2053 . 624270) (-2054 . 622899) (-2055 . 622792) (-2056 . 622688) (-2057 . 621471) (-2058 . 621074) (-2059 . 620945) (-2060 . 620752) (-2061 . 620675) (-2062 . 620093) (-2063 . 619888) (-2064 . 619675) (-2065 . 619427) (-2066 . 619096) (-2067 . 617362) (-2068 . 616920) (-2069 . 616598) (-2070 . 616503) (-2071 . 616422) (-2072 . 614992) (-2073 . 614702) (-2074 . 614652) (-2075 . 614223) (-2076 . 613953) (-2077 . 612491) (-2078 . 612412) (-2079 . 610894) (-2080 . 610702) (-2081 . 610611) (-2082 . 610583) (-2083 . 609877) (-2084 . 609801) (-2085 . 609742) (-2086 . 609469) (-2087 . 609414) (-2088 . 609101) (-2089 . 609027) (-2090 . 608469) (-2091 . 608388) (-2092 . 608258) (-2093 . 608132) (-2094 . 608007) (-2095 . 607805) (-2096 . 607731) (-2097 . 607400) (-2098 . 607329) (-2099 . 606724) (-2100 . 606651) (-2101 . 606358) (-2102 . 605684) (-2103 . 605594) (-2104 . 604479) (-2105 . 604376) (-2106 . 604322) (-2107 . 603680) (-2108 . 603470) (-2109 . 603273) (-2110 . 603163) (-2111 . 603043) (-2112 . 602507) (-2113 . 602404) (-2114 . 602059) (-2115 . 601930) (-2116 . 600797) (-2117 . 600689) (-2118 . 600541) (-2119 . 600246) (-2120 . 600137) (-2121 . 600040) (-2122 . 599739) (-2123 . 599270) (-2124 . 598977) (-2125 . 598825) (-2126 . 598649) (-2127 . 598551) (-2128 . 598388) (-2129 . 598320) (-2130 . 597931) (-2131 . 597666) (-2132 . 597314) (-2133 . 597148) (-2134 . 597077) (-2135 . 596969) (-2136 . 596743) (-2137 . 596540) (-2138 . 596430) (-2139 . 596216) (-2140 . 596161) (-2141 . 596065) (-2142 . 595932) (-2143 . 595873) (-2144 . 595652) (-2145 . 595481) (-2146 . 595391) (-2147 . 595341) (-2148 . 594431) (-2149 . 594196) (-2150 . 593994) (-2151 . 593737) (-2152 . 589813) (-2153 . 589661) (-2154 . 589572) (-2155 . 588936) (-2156 . 588848) (-2157 . 588344) (-2158 . 588246) (-2159 . 588087) (-2160 . 588028) (-2161 . 587617) (-2162 . 587527) (-2163 . 587429) (-2164 . 587313) (-2165 . 585582) (-2166 . 585440) (-2167 . 585367) (-2168 . 584222) (-2169 . 584072) (-2170 . 583991) (-2171 . 583486) (-2172 . 583394) (-2173 . 583338) (-2174 . 583227) (-2175 . 583153) (-2176 . 583062) (-2177 . 582974) (-2178 . 582905) (-2179 . 582785) (-2180 . 582676) (-2181 . 582588) (-2182 . 582477) (-2183 . 582162) (-2184 . 581870) (-2185 . 581571) (-2186 . 581332) (-2187 . 580958) (-2188 . 580651) (-2189 . 580599) (-2190 . 580477) (-2191 . 580358) (-2192 . 580299) (-2193 . 580111) (-2194 . 579930) (-2195 . 579839) (-2196 . 579766) (-2197 . 579400) (-2198 . 579282) (-2199 . 579127) (-2200 . 579004) (-2201 . 578634) (-2202 . 578567) (-2203 . 578501) (-2204 . 578216) (-12 . 578061) (-2206 . 578029) (-2207 . 577947) (-2208 . 577818) (-2209 . 577446) (-2210 . 577233) (-2211 . 576994) (-2212 . 576885) (-2213 . 576690) (-2214 . 576648) (-2215 . 576548) (-2216 . 576400) (-2217 . 576073) (-2218 . 575737) (-2219 . 574849) (-2220 . 574797) (-2221 . 574699) (-2222 . 574629) (-2223 . 574484) (-2224 . 574348) (-2225 . 574059) (-2226 . 573956) (-2227 . 573845) (-2228 . 573604) (-2229 . 573252) (-2230 . 573177) (-2231 . 573020) (-2232 . 572323) (-2233 . 572151) (-2234 . 571930) (-2235 . 571765) (-2236 . 571710) (-2237 . 571653) (-2238 . 571597) (-2239 . 571474) (-2240 . 571341) (-2241 . 571106) (-2242 . 571006) (-2243 . 570859) (-2244 . 570783) (-2245 . 570728) (-2246 . 570618) (-2247 . 570565) (-2248 . 570493) (-2249 . 570355) (-2250 . 569857) (-2251 . 569305) (-2252 . 569273) (-2253 . 568577) (-2254 . 568183) (-2255 . 567944) (* . 563439) (-2257 . 563357) (-2258 . 563217) (-2259 . 562960) (-2260 . 562771) (-2261 . 562628) (-2262 . 562555) (-2263 . 562400) (-2264 . 562321) (-2265 . 562196) (-2266 . 562034) (-2267 . 561882) (-2268 . 561690) (-2269 . 561588) (-2270 . 561468) (-2271 . 561056) (-2272 . 560993) (-2273 . 560938) (-2274 . 560838) (-2275 . 560697) (-2276 . 560150) (-2277 . 560088) (-2278 . 559954) (-2279 . 559880) (-2280 . 559757) (-2281 . 559707) (-2282 . 559398) (-2283 . 558449) (-2284 . 558314) (-2285 . 558248) (-2286 . 557942) (-2287 . 557839) (-2288 . 553915) (-2289 . 553801) (-2290 . 553723) (-2291 . 553585) (-2292 . 553529) (-2293 . 553304) (-2294 . 553232) (-2295 . 553013) (-2296 . 552800) (-2297 . 552685) (-2298 . 552574) (-2299 . 552438) (-2300 . 552114) (-2301 . 551680) (-2302 . 551593) (-2303 . 551384) (-2304 . 551128) (-2305 . 550964) (-2306 . 550857) (-2307 . 550648) (-2308 . 550487) (-2309 . 550412) (-2310 . 550047) (-2311 . 549966) (-2312 . 549880) (-2313 . 549788) (-2314 . 549616) (-2315 . 549268) (-2316 . 549116) (-2317 . 548602) (-2318 . 548153) (-2319 . 547481) (-2320 . 547217) (-2321 . 547165) (-2322 . 546849) (-2323 . 546766) (-2324 . 546199) (-2325 . 545814) (-2326 . 545162) (-2327 . 545023) (-2328 . 544968) (-2329 . 544884) (-2330 . 544856) (-2331 . 544730) (-2332 . 544702) (-2333 . 544496) (-2334 . 544465) (-2335 . 543466) (-2336 . 543414) (-2337 . 543349) (-2338 . 539483) (-2339 . 539380) (-2340 . 539290) (-2341 . 539112) (-2342 . 539063) (-2343 . 538913) (-2344 . 536678) (-2345 . 536628) (-2346 . 536555) (-2347 . 536496) (-2348 . 536348) (-2349 . 536261) (-2350 . 535920) (-2351 . 535836) (-2352 . 535753) (-2353 . 533884) (-2354 . 533776) (-2355 . 533178) (-2356 . 532916) (-2357 . 532714) (-2358 . 532620) (-2359 . 532522) (-2360 . 532469) (-2361 . 532361) (-2362 . 532264) (-2363 . 532097) (-2364 . 532004) (-2365 . 531862) (-2366 . 531740) (-2367 . 531611) (-2368 . 531416) (-2369 . 531239) (-2370 . 531186) (-2371 . 529999) (-2372 . 529864) (-2373 . 529657) (-2374 . 529583) (-2375 . 529431) (-2376 . 529297) (-2377 . 529194) (-2378 . 528419) (-2379 . 528364) (-2380 . 528275) (-2381 . 528032) (-2382 . 527995) (-2383 . 527772) (-2384 . 527636) (-2385 . 527540) (-2386 . 527436) (-2387 . 526892) (-2388 . 526537) (-2389 . 526468) (-2390 . 526346) (-2391 . 526186) (-2392 . 526134) (-2393 . 525907) (-2394 . 525233) (-2395 . 525135) (-2396 . 525031) (-2397 . 524960) (-2398 . 524868) (-2399 . 524603) (-2400 . 524489) (-2401 . 524416) (-2402 . 524364) (-2403 . 524268) (-2404 . 524028) (-2405 . 523914) (-2406 . 523745) (-2407 . 523664) (-2408 . 523479) (-2409 . 523379) (-2410 . 523228) (-2411 . 523133) (-2412 . 522934) (-2413 . 522834) (-2414 . 522738) (-2415 . 522614) (-2416 . 522561) (-2417 . 522468) (-2418 . 522409) (-2419 . 522094) (-2420 . 522042) (-2421 . 521989) (-2422 . 521923) (-2423 . 521823) (-2424 . 521443) (-2425 . 521372) (-2426 . 521306) (-2427 . 521256) (-2428 . 521129) (-2429 . 521058) (-2430 . 520957) (-2431 . 520856) (-2432 . 520790) (-2433 . 520494) (-2434 . 520041) (-2435 . 519889) (-2436 . 519256) (-2437 . 518490) (-2438 . 517105) (-2439 . 516849) (-2440 . 516787) (-2441 . 516686) (-2442 . 516552) (-2443 . 515747) (-2444 . 515389) (-2445 . 515307) (-2446 . 515203) (-2447 . 515032) (-2448 . 514973) (-2449 . 514483) (-2450 . 514414) (-2451 . 514276) (-2452 . 514142) (-2453 . 514059) (-2454 . 513278) (-2455 . 513228) (-2456 . 512958) (-2457 . 512884) (-2458 . 512803) (-2459 . 512440) (-2460 . 512227) (-2461 . 512175) (-2462 . 512038) (-2463 . 511986) (-2464 . 511933) (-2465 . 511746) (-2466 . 511588) (-2467 . 511533) (-2468 . 511458) (-2469 . 511367) (-2470 . 511318) (-2471 . 510919) (-2472 . 510845) (-2473 . 510515) (-2474 . 510484) (-2475 . 510239) (-2476 . 510150) (-2477 . 509470) (-2478 . 509267) (-2479 . 509149) (-2480 . 508992) (-2481 . 508873) (-2482 . 508721) (-2483 . 508627) (-2484 . 508500) (-2485 . 508338) (-2486 . 508118) (-2487 . 508003) (-2488 . 507450) (-2489 . 507336) (-2490 . 507139) (-2491 . 507052) (-2492 . 506905) (-2493 . 506671) (-2494 . 506603) (-2495 . 506479) (-2496 . 506426) (-2497 . 506287) (-2498 . 506201) (-2499 . 506169) (-2500 . 505665) (-2501 . 505612) (-2502 . 505511) (-2503 . 505411) (-2504 . 505039) (-2505 . 504987) (-2506 . 504884) (-2507 . 504805) (-2508 . 504568) (-2509 . 504447) (-2510 . 504219) (-2511 . 504135) (-2512 . 501296) (-2513 . 500732) (-2514 . 500626) (-2515 . 500511) (-2516 . 500442) (-2517 . 500149) (-2518 . 500072) (-2519 . 500038) (-2520 . 499888) (-2521 . 499717) (-2522 . 499476) (-2523 . 499400) (-2524 . 499250) (-2525 . 499132) (-2526 . 498870) (-2527 . 498747) (-2528 . 498601) (-2529 . 498470) (-2530 . 498395) (-2531 . 497195) (-2532 . 497053) (-2533 . 496813) (-2534 . 496718) (-2535 . 496615) (-2536 . 496462) (-2537 . 496279) (-2538 . 496131) (-2539 . 496041) (-2540 . 495952) (-2541 . 495495) (-2542 . 495440) (-2543 . 495368) (-2544 . 495122) (-2545 . 495042) (-2546 . 494963) (-2547 . 494728) (-2548 . 494362) (-2549 . 494009) (-2550 . 493957) (-2551 . 493118) (-2552 . 492858) (-2553 . 492777) (-2554 . 492693) (-2555 . 492629) (-2556 . 492563) (-2557 . 492414) (-2558 . 492361) (-2559 . 492048) (-2560 . 491996) (-2561 . 491900) (-2562 . 491762) (-2563 . 491538) (-2564 . 491425) (-2565 . 491373) (-2566 . 490938) (-2567 . 490844) (-2568 . 490636) (-2569 . 490555) (-2570 . 490490) (-2571 . 490325) (-2572 . 490195) (-2573 . 490040) (-2574 . 489930) (-2575 . 489871) (-2576 . 489819) (-2577 . 489136) (-2578 . 489054) (-2579 . 488995) (-2580 . 488674) (-2581 . 488597) (-2582 . 488284) (-2583 . 488196) (-2584 . 488140) (-2585 . 487956) (-2586 . 487883) (-2587 . 487525) (-2588 . 486702) (-2589 . 486647) (-2590 . 486563) (-2591 . 486062) (-2592 . 486007) (-2593 . 485885) (-2594 . 485750) (-2595 . 485679) (-2596 . 485627) (-2597 . 484810) (-2598 . 484723) (-2599 . 484564) (-2600 . 484414) (-2601 . 484280) (-2602 . 484246) (-2603 . 483144) (-2604 . 482890) (-2605 . 482726) (-2606 . 482582) (-2607 . 482382) (-2608 . 482159) (-2609 . 481742) (-2610 . 481689) (-2611 . 481547) (-2612 . 481440) (-2613 . 481123) (-2614 . 481089) (-2615 . 480974) (-2616 . 480918) (-2617 . 479956) (-2618 . 479740) (-2619 . 479650) (-2620 . 479601) (-2621 . 479133) (-2622 . 478677) (-2623 . 478532) (-2624 . 478364) (-2625 . 478245) (-2626 . 478163) (-2627 . 478108) (-2628 . 477333) (-2629 . 477230) (-2630 . 475833) (-2631 . 475722) (-2632 . 475632) (-2633 . 475548) (-2634 . 475281) (-2635 . 475224) (-2636 . 474981) (-2637 . 474881) (-2638 . 474430) (-2639 . 474330) (-2640 . 473987) (-2641 . 473914) (-2642 . 473836) (-2643 . 473550) (-2644 . 473498) (-2645 . 472954) (-2646 . 472763) (-2647 . 472580) (-2648 . 472458) (-2649 . 472407) (-2650 . 472329) (-2651 . 472193) (-2652 . 472036) (-2653 . 471983) (-2654 . 471888) (-2655 . 471777) (-2656 . 471680) (-2657 . 471491) (-2658 . 471301) (-2659 . 471140) (-2660 . 471052) (-2661 . 470972) (-2662 . 470862) (-2663 . 470680) (-2664 . 470511) (-2665 . 470404) (-2666 . 470313) (-2667 . 470218) (-2668 . 470080) (-2669 . 469184) (-2670 . 469094) (-2671 . 469018) (-2672 . 468820) (-2673 . 468703) (-2674 . 468548) (-2675 . 468312) (-2676 . 468208) (-2677 . 468085) (-2678 . 467997) (-2679 . 467723) (-2680 . 467643) (-2681 . 467577) (-2682 . 467390) (-2683 . 467286) (-2684 . 467212) (-2685 . 467159) (-2686 . 466937) (-2687 . 466782) (-2688 . 466723) (-2689 . 466679) (-2690 . 466626) (-2691 . 466571) (-2692 . 466386) (-2693 . 466358) (-2694 . 466256) (-2695 . 466190) (-2696 . 465773) (-2697 . 465689) (-2698 . 465519) (-2699 . 465444) (-2700 . 465370) (-2701 . 465270) (-2702 . 465096) (-2703 . 465040) (-2704 . 464969) (-2705 . 464788) (-2706 . 464482) (-2707 . 463905) (-2708 . 463713) (-2709 . 463027) (-2710 . 462941) (-2711 . 462860) (-2712 . 462768) (-2713 . 462623) (-2714 . 462542) (-2715 . 461642) (-2716 . 461473) (-2717 . 461339) (-2718 . 461187) (-2719 . 461135) (-2720 . 461031) (-2721 . 460917) (-2722 . 460769) (-2723 . 459718) (-2724 . 459645) (-2725 . 459490) (-2726 . 459292) (-2727 . 459136) (-2728 . 458992) (-2729 . 458909) (-2730 . 458838) (-2731 . 458739) (-2732 . 458429) (-2733 . 456465) (-2734 . 456354) (-2735 . 456236) (-2736 . 456143) (-2737 . 455969) (-2738 . 455865) (-2739 . 455833) (-2740 . 455548) (-2741 . 455427) (-2742 . 454392) (-2743 . 454318) (-2744 . 454229) (-2745 . 454170) (-2746 . 453851) (-2747 . 430343) (-2748 . 430286) (-2749 . 430252) (-2750 . 430175) (-2751 . 430049) (-2752 . 429974) (-2753 . 429849) (-2754 . 429769) (-2755 . 429688) (-2756 . 429631) (-2757 . 429549) (-2758 . 429490) (-2759 . 429245) (-2760 . 429133) (-2761 . 429025) (-2762 . 428627) (-2763 . 428486) (-2764 . 428287) (-2765 . 428212) (-2766 . 427712) (-2767 . 427602) (-2768 . 427263) (-2769 . 427110) (-2770 . 426440) (-2771 . 426236) (-2772 . 426113) (-2773 . 425974) (-2774 . 425921) (-2775 . 425790) (-2776 . 425642) (-2777 . 425487) (-2778 . 425384) (-2779 . 424517) (-2780 . 424095) (-2781 . 418997) (-2782 . 418917) (-2783 . 418611) (-2784 . 418427) (-2785 . 418207) (-2786 . 418152) (-2787 . 418066) (-2788 . 417361) (-2789 . 417033) (-2790 . 416932) (-2791 . 415973) (-2792 . 415268) (-2793 . 415028) (-2794 . 414958) (-2795 . 414749) (-2796 . 414587) (-2797 . 400755) (-2798 . 400699) (-2799 . 400665) (-2800 . 400503) (-2801 . 400268) (-2802 . 399775) (-2803 . 399311) (-2804 . 399181) (-2805 . 398373) (-2806 . 398236) (-2807 . 398143) (-2808 . 397809) (-2809 . 397719) (-2810 . 397210) (-2811 . 396725) (-2812 . 396607) (-2813 . 396517) (-2814 . 396262) (-2815 . 396155) (-2816 . 396037) (-2817 . 395615) (-2818 . 395544) (-2819 . 395328) (-2820 . 395203) (-2821 . 395150) (-2822 . 395072) (-2823 . 394486) (-2824 . 394284) (-2825 . 394203) (-2826 . 393784) (-2827 . 393526) (-2828 . 393373) (-2829 . 393259) (-2830 . 393120) (-2831 . 392671) (-2832 . 392591) (-2833 . 392217) (-2834 . 392132) (-2835 . 391655) (-2836 . 391568) (-2837 . 391476) (-2838 . 391373) (-2839 . 391284) (-2840 . 391174) (-2841 . 391092) (-2842 . 390985) (-2843 . 390869) (-2844 . 390835) (-2845 . 390733) (-2846 . 390517) (-2847 . 390421) (-2848 . 389463) (-2849 . 389341) (-2850 . 389050) (-2851 . 389000) (-2852 . 388747) (-2853 . 388475) (-2854 . 388369) (-2855 . 388301) (-2856 . 388221) (-2857 . 383159) (-2858 . 383056) (-2859 . 382817) (-2860 . 382249) (-2861 . 382174) (-2862 . 381866) (-2863 . 381631) (-2864 . 381565) (-2865 . 380446) (-2866 . 380333) (-2867 . 380238) (-2868 . 380137) (-2869 . 380044) (-2870 . 379786) (-2871 . 379715) (-2872 . 379606) (-2873 . 377495) (-2874 . 377461) (-2875 . 377385) (-2876 . 377306) (-2877 . 377047) (-2878 . 376990) (-2879 . 376958) (-2880 . 376905) (-2881 . 376307) (-2882 . 376238) (-2883 . 375922) (-2884 . 375834) (-2885 . 375606) (-2886 . 375413) (-2887 . 375322) (-2888 . 375223) (-2889 . 375071) (-2890 . 374835) (-2891 . 374702) (-2892 . 374621) (-2893 . 374495) (-2894 . 374382) (-2895 . 374242) (-2896 . 374190) (-2897 . 374141) (-2898 . 374023) (-2899 . 373935) (-2900 . 373864) (-2901 . 373769) (-2902 . 372631) (-2903 . 372530) (-2904 . 372464) (-2905 . 372312) (-2906 . 372154) (-2907 . 372080) (-2908 . 371981) (-2909 . 371907) (-2910 . 371537) (-2911 . 371484) (-2912 . 371333) (-2913 . 371256) (-2914 . 371183) (-2915 . 371058) (-2916 . 370965) (-2917 . 370687) (-2918 . 370585) (-2919 . 369840) (-2920 . 369678) (-2921 . 369565) (-2922 . 369441) (-2923 . 369324) (-2924 . 369232) (-2925 . 369129) (-2926 . 369014) (-2927 . 368947) (-2928 . 368689) (-2929 . 368614) (-2930 . 368518) (-2931 . 368369) (-2932 . 368039) (-2933 . 367970) (-2934 . 367130) (-2935 . 367031) (-2936 . 366975) (-2937 . 366838) (-2938 . 366765) (-2939 . 366596) (-2940 . 366441) (-2941 . 366246) (-2942 . 366110) (-2943 . 366049) (-2944 . 365997) (-2945 . 365430) (-2946 . 365315) (-2947 . 365262) (-2948 . 365209) (-2949 . 365120) (-2950 . 365005) (-2951 . 364126) (-2952 . 364013) (-2953 . 363922) (-2954 . 363777) (-2955 . 363617) (-2956 . 363340) (-2957 . 363165) (-2958 . 363027) (-2959 . 362937) (-2960 . 362849) (-2961 . 362653) (-2962 . 362348) (-2963 . 361866) (-2964 . 361351) (-2965 . 361138) (-2966 . 361004) (-2967 . 360816) (-2968 . 360672) (-2969 . 360582) (-2970 . 360274) (-2971 . 359978) (-2972 . 359910) (-2973 . 359339) (-2974 . 359213) (-2975 . 359129) (-2976 . 358555) (-2977 . 358460) (-2978 . 358322) (-2979 . 358211) (-2980 . 358048) (-2981 . 357265) (-2982 . 357213) (-2983 . 357108) (-2984 . 356956) (-2985 . 356825) (-2986 . 356721) (-2987 . 356669) (-2988 . 356473) (-2989 . 356362) (-2990 . 355636) (-2991 . 355419) (-2992 . 355367) (-2993 . 355288) (-2994 . 355183) (-2995 . 355028) (-2996 . 354684) (-2997 . 354476) (-2998 . 354387) (-2999 . 354282) (-3000 . 354191) (-3001 . 352974) (-3002 . 352782) (-3003 . 352698) (-3004 . 352563) (-3005 . 352324) (-3006 . 351917) (-3007 . 351826) (-3008 . 351727) (-3009 . 351667) (-3010 . 351529) (-3011 . 351408) (-3012 . 350444) (-3013 . 350336) (-3014 . 349641) (-3015 . 349534) (-3016 . 349167) (-3017 . 349062) (-3018 . 348945) (-3019 . 348865) (-3020 . 348691) (-3021 . 348548) (-3022 . 348446) (-3023 . 348394) (-3024 . 348302) (-3025 . 348218) (-3026 . 348119) (-3027 . 348045) (-3028 . 347974) (-3029 . 347620) (-3030 . 347292) (-3031 . 344337) (-3032 . 343788) (-3033 . 343621) (-3034 . 343251) (-3035 . 343103) (-3036 . 342778) (-3037 . 342692) (-3038 . 342597) (-3039 . 342449) (-3040 . 342352) (-3041 . 342279) (-3042 . 342206) (-3043 . 342149) (-3044 . 341907) (-3045 . 341484) (-3046 . 341368) (-3047 . 341280) (-3048 . 341171) (-3049 . 341046) (-3050 . 340885) (-3051 . 340782) (-3052 . 340682) (-3053 . 340554) (-3054 . 340475) (-3055 . 340360) (-3056 . 340077) (-3057 . 340022) (-3058 . 339854) (-3059 . 339286) (-3060 . 338892) (-3061 . 338786) (-3062 . 338345) (-3063 . 338140) (-3064 . 338083) (-3065 . 337973) (-3066 . 337816) (-3067 . 337748) (-3068 . 337577) (-3069 . 337108) (-3070 . 336928) (-3071 . 336825) (-3072 . 336712) (-3073 . 336551) (-3074 . 336454) (-3075 . 335915) (-3076 . 335862) (-3077 . 335245) (-3078 . 335097) (-3079 . 334993) (-3080 . 334921) (-3081 . 334844) (-3082 . 334718) (-3083 . 334633) (-3084 . 334567) (-3085 . 334365) (-3086 . 334015) (-3087 . 333107) (-3088 . 333030) (-3089 . 332927) (-3090 . 332826) (-3091 . 332752) (-3092 . 332614) (-3093 . 332517) (-3094 . 328907) (-3095 . 328674) (-3096 . 328555) (-3097 . 328499) (-3098 . 328367) (-3099 . 328252) (-3100 . 328029) (-3101 . 327679) (-3102 . 327566) (-3103 . 327508) (-3104 . 327376) (-3105 . 327302) (-3106 . 327051) (-3107 . 326955) (-3108 . 326251) (-3109 . 326138) (-3110 . 325834) (-3111 . 325781) (-3112 . 325682) (-3113 . 325611) (-3114 . 325537) (-3115 . 325419) (-3116 . 325338) (-3117 . 325280) (-3118 . 325190) (-3119 . 325093) (-3120 . 324912) (-3121 . 324633) (-3122 . 324459) (-3123 . 324385) (-3124 . 324121) (-3125 . 324089) (-3126 . 323569) (-3127 . 323485) (-3128 . 323382) (-3129 . 323184) (-3130 . 322886) (-3131 . 322833) (-3132 . 322709) (-3133 . 322629) (-3134 . 322525) (-3135 . 318601) (-3136 . 318539) (-3137 . 318107) (-3138 . 317973) (-3139 . 317738) (-3140 . 317655) (-3141 . 317415) (-3142 . 317243) (-3143 . 317189) (-3144 . 317069) (-3145 . 317007) (-3146 . 316648) (-3147 . 316483) (-3148 . 316430) (-3149 . 316281) (-3150 . 316164) (-3151 . 316039) (-3152 . 315979) (-3153 . 315863) (-3154 . 315763) (-3155 . 315729) (-3156 . 315621) (-3157 . 315370) (-3158 . 315193) (-3159 . 315082) (-3160 . 314955) (-3161 . 314871) (-3162 . 314745) (-3163 . 314465) (-3164 . 314258) (-3165 . 314025) (-3166 . 313956) (-3167 . 313857) (-3168 . 313804) (-3169 . 313672) (-3170 . 313437) (-3171 . 313334) (-3172 . 313030) (-3173 . 313002) (-3174 . 312876) (-3175 . 312742) (-3176 . 312487) (-3177 . 312134) (-3178 . 312030) (-3179 . 311879) (-3180 . 311702) (-3181 . 311606) (-3182 . 311473) (-3183 . 311095) (-3184 . 311042) (-3185 . 310989) (-3186 . 310841) (-3187 . 310788) (-3188 . 310736) (-3189 . 310645) (-3190 . 310379) (-3191 . 310166) (-3192 . 309370) (-3193 . 309247) (-3194 . 309169) (-3195 . 309114) (-3196 . 308723) (-3197 . 308576) (-3198 . 308440) (-3199 . 308301) (-3200 . 304377) (-3201 . 304230) (-3202 . 304061) (-3203 . 303989) (-3204 . 303773) (-3205 . 303721) (-3206 . 303598) (-3207 . 303399) (-3208 . 303249) (-3209 . 303014) (-3210 . 302799) (-3211 . 302680) (-3212 . 302571) (-3213 . 302408) (-3214 . 302274) (-3215 . 302223) (-3216 . 302156) (-3217 . 302093) (-3218 . 301993) (-3219 . 301899) (-3220 . 301828) (-3221 . 301665) (-3222 . 301551) (-3223 . 300216) (-3224 . 300090) (-3225 . 299818) (-3226 . 299725) (-3227 . 299521) (-3228 . 299469) (-3229 . 299077) (-3230 . 298860) (-3231 . 298791) (-3232 . 298763) (-3233 . 298637) (-3234 . 298518) (-3235 . 298445) (-3236 . 297941) (-3237 . 297747) (-3238 . 297660) (-3239 . 297526) (-3240 . 297163) (-3241 . 297027) (-3242 . 296953) (-3243 . 296921) (-3244 . 296778) (-3245 . 296388) (-3246 . 295456) (-3247 . 295121) (-3248 . 295090) (-3249 . 294986) (-3250 . 294690) (-3251 . 294336) (-3252 . 294227) (-3253 . 294142) (-3254 . 293388) (-3255 . 293265) (-3256 . 293068) (-3257 . 292976) (-3258 . 292878) (-3259 . 283985) (-3260 . 283858) (-3261 . 283531) (-3262 . 283413) (-3263 . 283258) (-3264 . 283224) (-3265 . 283149) (-3266 . 283038) (-3267 . 282718) (-3268 . 282582) (-3269 . 282499) (-3270 . 282247) (-3271 . 282176) (-3272 . 282092) (-3273 . 282014) (-3274 . 281906) (-3275 . 281832) (-3276 . 281780) (-3277 . 281702) (-3278 . 281600) (-3279 . 281292) (-3280 . 281221) (-3281 . 281092) (-3282 . 280919) (-3283 . 280868) (-3284 . 280498) (-3285 . 280374) (-3286 . 280046) (-3287 . 279899) (-3288 . 279692) (-3289 . 279595) (-3290 . 279525) (-3291 . 279384) (-3292 . 279244) (-3293 . 279065) (-3294 . 278931) (-3295 . 278840) (-3296 . 278774) (-3297 . 278719) (-3298 . 278643) (-3299 . 278517) (-3300 . 278147) (-3301 . 277912) (-3302 . 277859) (-3303 . 277788) (-3304 . 277301) (-3305 . 277123) (-3306 . 277024) (-3307 . 276928) (-3308 . 276853) (-3309 . 276749) (-3310 . 276675) (-3311 . 276410) (-3312 . 276213) (-3313 . 276044) (-3314 . 275906) (-3315 . 275878) (-3316 . 275583) (-3317 . 274915) (-3318 . 274547) (-3319 . 274299) (-3320 . 274247) (-3321 . 274109) (-3322 . 273969) (-3323 . 273602) (-3324 . 273528) (-3325 . 273120) (-3326 . 272986) (-3327 . 272816) (-3328 . 272742) (-3329 . 272629) (-3330 . 271711) (-3331 . 271654) (-3332 . 271570) (-3333 . 271297) (-3334 . 271194) (-3335 . 271097) (-3336 . 270920) (-3337 . 269650) (-3338 . 269367) (-3339 . 269196) (-3340 . 268953) (-3341 . 268691) (-3342 . 268626) (-3343 . 268386) (-3344 . 267833) (-3345 . 267719) (-3346 . 267522) (-3347 . 267435) (-3348 . 267345) (-3349 . 267163) (-3350 . 267066) (-3351 . 266861) (-3352 . 266501) (-3353 . 266432) (-3354 . 266074) (-3355 . 265490) (-3356 . 265401) (-3357 . 265288) (-3358 . 265129) (-3359 . 264914) (-3360 . 264861) (-3361 . 264689) (-3362 . 264320) (-3363 . 264162) (-3364 . 264073) (-3365 . 263967) (-3366 . 263844) (-3367 . 263672) (-3368 . 263543) (-3369 . 263469) (-3370 . 263387) (-3371 . 263197) (-3372 . 263005) (-3373 . 262897) (-3374 . 262807) (-3375 . 262740) (-3376 . 262562) (-3377 . 262394) (-3378 . 262342) (-3379 . 262262) (-3380 . 262144) (-3381 . 262046) (-3382 . 261833) (-3383 . 260672) (-3384 . 260563) (-3385 . 260435) (-3386 . 260343) (-3387 . 260141) (-3388 . 260037) (-3389 . 259953) (-3390 . 259732) (-3391 . 259585) (-3392 . 259523) (-3393 . 259120) (-3394 . 259068) (-3395 . 259040) (-3396 . 258792) (-3397 . 258731) (-3398 . 258406) (-3399 . 258354) (-3400 . 258194) (-3401 . 258080) (-3402 . 258007) (-3403 . 257686) (-3404 . 257615) (-3405 . 257380) (-3406 . 257316) (-3407 . 256615) (-3408 . 256536) (-3409 . 256243) (-3410 . 256183) (-3411 . 256124) (-3412 . 255831) (-3413 . 255698) (-3414 . 255627) (-3415 . 255455) (-3416 . 249066) (-3417 . 249014) (-3418 . 248563) (-3419 . 248445) (-3420 . 248341) (-3421 . 248176) (-3422 . 248074) (-3423 . 246508) (-3424 . 246400) (-3425 . 245579) (-3426 . 245498) (-3427 . 245416) (-3428 . 245363) (-3429 . 245192) (-3430 . 245083) (-3431 . 244928) (-3432 . 244512) (-3433 . 244452) (-3434 . 244329) (-3435 . 244258) (-3436 . 244093) (-3437 . 243399) (-3438 . 243301) (-3439 . 243227) (-3440 . 242553) (-3441 . 242401) (-3442 . 242278) (-3443 . 242188) (-3444 . 242093) (-3445 . 242019) (-3446 . 241720) (-3447 . 241665) (-3448 . 241485) (-3449 . 241420) (-3450 . 241346) (-3451 . 241133) (-3452 . 240878) (-3453 . 240789) (-3454 . 240689) (-3455 . 240574) (-3456 . 239958) (-3457 . 239767) (-3458 . 239708) (-3459 . 239652) (-3460 . 239580) (-3461 . 239413) (-3462 . 239300) (-3463 . 239102) (-3464 . 237918) (-3465 . 237824) (-3466 . 237700) (-3467 . 237630) (-3468 . 237564) (-3469 . 237490) (-3470 . 237315) (-3471 . 236596) (-3472 . 236486) (-3473 . 236348) (-3474 . 236061) (-3475 . 235958) (-3476 . 235776) (-3477 . 235626) (-3478 . 235519) (-3479 . 234894) (-3480 . 234390) (-3481 . 234095) (-3482 . 233977) (-3483 . 233519) (-3484 . 233443) (-3485 . 233281) (-3486 . 233083) (-3487 . 232931) (-3488 . 232827) (-3489 . 232308) (-3490 . 232185) (-3491 . 231681) (-3492 . 225292) (-3493 . 225240) (-3494 . 225167) (-3495 . 225133) (-3496 . 224811) (-3497 . 224288) (-3498 . 223074) (-3499 . 222650) (-3500 . 222112) (-3501 . 221971) (-3502 . 221896) (-3503 . 221629) (-3504 . 221531) (-3505 . 221207) (-3506 . 220873) (-3507 . 220802) (-3508 . 220477) (-3509 . 220366) (-3510 . 220082) (-3511 . 219639) (-3512 . 219523) (-3513 . 219330) (-3514 . 219030) (-3515 . 218963) (-3516 . 218872) (-3517 . 218732) (-3518 . 218461) (-3519 . 218282) (-3520 . 218183) (-3521 . 218084) (-3522 . 217988) (-3523 . 217939) (-3524 . 217490) (-3525 . 217367) (-3526 . 217291) (-3527 . 217134) (-3528 . 216771) (-3529 . 216668) (-3530 . 216488) (-3531 . 216358) (-3532 . 216303) (-3533 . 216040) (-3534 . 215965) (-3535 . 215893) (-3536 . 215823) (-3537 . 215504) (-3538 . 214169) (-3539 . 213953) (-3540 . 213774) (-3541 . 213636) (-3542 . 212973) (-3543 . 212795) (-3544 . 212738) (-3545 . 212665) (-3546 . 212612) (-3547 . 212488) (-3548 . 212433) (-3549 . 212330) (-3550 . 212132) (-3551 . 212104) (-3552 . 212051) (-3553 . 211766) (-3554 . 211567) (-3555 . 211444) (-3556 . 211368) (-3557 . 211180) (-3558 . 208743) (-3559 . 208615) (-3560 . 208379) (-3561 . 208071) (-3562 . 207878) (-3563 . 207826) (-3564 . 207523) (-3565 . 207442) (-3566 . 207247) (-3567 . 207107) (-3568 . 206988) (-3569 . 206919) (-3570 . 206731) (-3571 . 206402) (-3572 . 206320) (-3573 . 206240) (-3574 . 206023) (-3575 . 205840) (-3576 . 205726) (-3577 . 205451) (-3578 . 205279) (-3579 . 205127) (-3580 . 204928) (-3581 . 204790) (-3582 . 204638) (-3583 . 204542) (-3584 . 204235) (-3585 . 204161) (-3586 . 203891) (-3587 . 203819) (-3588 . 203720) (-3589 . 203635) (-3590 . 203562) (-3591 . 203377) (-3592 . 199453) (-3593 . 199274) (-3594 . 198978) (-3595 . 198896) (-3596 . 198790) (-3597 . 198657) (-3598 . 198442) (-3599 . 198370) (-3600 . 198315) (-3601 . 198092) (-3602 . 197826) (-3603 . 197574) (-3604 . 197468) (-3605 . 197393) (-3606 . 197302) (-3607 . 197194) (-3608 . 196823) (-3609 . 196649) (-3610 . 196545) (-3611 . 196416) (-3612 . 196053) (-3613 . 196024) (-3614 . 195921) (-3615 . 195786) (-3616 . 195695) (-3617 . 195567) (-3618 . 194747) (-3619 . 194442) (-3620 . 194353) (-3621 . 194001) (-3622 . 193899) (-3623 . 193699) (-3624 . 193633) (-3625 . 193464) (-3626 . 193364) (-3627 . 193275) (-3628 . 193150) (-3629 . 192999) (-3630 . 192871) (-3631 . 192781) (-3632 . 192593) (-3633 . 192404) (-3634 . 192147) (-3635 . 192022) (-3636 . 191870) (-3637 . 191792) (-3638 . 191415) (-3639 . 191344) (-3640 . 191256) (-3641 . 191158) (-3642 . 191084) (-3643 . 190961) (-3644 . 190842) (-3645 . 190266) (-3646 . 190150) (-3647 . 189737) (-3648 . 189436) (-3649 . 189158) (-3650 . 188802) (-3651 . 188650) (-3652 . 188594) (-3653 . 188385) (-3654 . 188117) (-3655 . 188028) (-3656 . 187067) (-3657 . 186927) (-3658 . 186787) (-3659 . 186672) (-3660 . 186565) (-3661 . 186534) (-3662 . 186259) (-3663 . 186155) (-3664 . 186069) (-3665 . 185968) (-3666 . 185785) (-3667 . 185512) (-3668 . 181337) (-3669 . 181111) (-3670 . 180924) (-3671 . 180840) (-3672 . 180757) (-3673 . 180704) (-3674 . 180623) (-3675 . 180567) (-3676 . 180045) (-3677 . 179946) (-3678 . 179878) (-3679 . 179761) (-3680 . 178970) (-3681 . 178888) (-3682 . 178382) (-3683 . 178236) (-3684 . 178166) (-3685 . 178026) (-3686 . 177945) (-3687 . 177565) (-3688 . 177381) (-3689 . 177137) (-3690 . 176871) (-3691 . 176635) (-3692 . 176583) (-3693 . 176405) (-3694 . 176377) (-3695 . 176306) (-3696 . 176208) (-3697 . 176115) (-3698 . 175873) (-3699 . 175820) (-3700 . 175747) (-3701 . 175663) (-3702 . 175608) (-3703 . 175451) (-3704 . 175144) (-3705 . 174896) (-3706 . 174656) (-3707 . 174536) (-3708 . 174483) (-3709 . 174413) (-3710 . 174363) (-3711 . 174055) (-3712 . 173902) (-3713 . 173850) (-3714 . 173651) (-3715 . 173400) (-3716 . 173271) (-3717 . 172988) (-3718 . 172960) (-3719 . 172932) (-3720 . 172772) (-3721 . 172675) (-3722 . 172374) (-3723 . 172322) (-3724 . 171802) (-3725 . 171483) (-3726 . 171244) (-3727 . 171007) (-3728 . 170926) (-3729 . 170863) (-3730 . 170774) (-3731 . 170521) (-3732 . 170463) (-3733 . 170429) (-3734 . 170193) (-3735 . 169975) (-3736 . 169344) (-3737 . 169245) (-3738 . 169052) (-3739 . 168979) (-3740 . 168635) (-3741 . 168558) (-3742 . 168469) (-3743 . 168306) (-3744 . 168200) (-3745 . 168081) (-3746 . 167710) (-3747 . 167682) (-3748 . 167579) (-3749 . 167465) (-3750 . 167367) (-3751 . 167339) (-3752 . 167235) (-3753 . 167146) (-3754 . 166838) (-3755 . 166759) (-3756 . 166599) (-3757 . 166449) (-3758 . 165880) (-3759 . 165730) (-3760 . 165658) (-3761 . 165424) (-3762 . 165350) (-3763 . 165104) (-3764 . 164600) (-3765 . 164315) (-3766 . 164259) (-3767 . 164136) (-3768 . 164080) (-3769 . 163914) (-3770 . 163659) (-3771 . 163420) (-3772 . 163270) (-3773 . 163157) (-3774 . 163079) (-3775 . 162792) (-3776 . 162739) (-3777 . 162335) (-3778 . 162001) (-3779 . 161904) (-3780 . 161775) (-3781 . 161686) (-3782 . 161586) (-3783 . 161349) (-3784 . 161168) (-3785 . 161140) (-3786 . 161088) (-3787 . 160974) (-3788 . 160780) (-3789 . 160618) (-3790 . 160527) (-3791 . 159941) (-3792 . 159857) (-3793 . 159692) (-3794 . 159210) (-3795 . 158965) (-3796 . 158283) (-3797 . 158165) (-3798 . 158113) (-3799 . 157910) (-3800 . 157757) (-3801 . 157647) (-3802 . 157518) (-3803 . 157489) (-3804 . 157337) (-3805 . 157252) (-3806 . 157182) (-3807 . 156987) (-3808 . 156584) (-3809 . 156464) (-3810 . 156338) (-3811 . 156265) (-3812 . 156131) (-3813 . 155535) (-3814 . 155243) (-3815 . 154775) (-3816 . 154579) (-3817 . 154508) (-3818 . 154437) (-3819 . 154387) (-3820 . 154279) (-3821 . 154176) (-3822 . 153966) (-3823 . 151929) (-3824 . 151772) (-3825 . 151537) (-3826 . 151302) (-3827 . 151211) (-3828 . 150834) (-3829 . 150758) (-3830 . 150688) (-3831 . 150504) (-3832 . 150442) (-3833 . 150243) (-3834 . 150111) (-3835 . 149739) (-3836 . 149673) (-3837 . 149562) (-3838 . 149509) (-3839 . 149420) (-3840 . 147955) (-3841 . 147864) (-3842 . 146867) (-3843 . 146713) (-3844 . 146218) (-3845 . 146144) (-3846 . 145934) (-3847 . 145795) (-3848 . 145734) (-3849 . 145623) (-3850 . 140133) (-3851 . 139978) (-3852 . 139831) (-3853 . 139754) (-3854 . 139657) (-3855 . 139490) (-3856 . 139374) (-3857 . 138533) (-3858 . 137812) (-3859 . 137371) (-3860 . 137246) (-3861 . 136991) (-3862 . 136617) (-3863 . 136408) (-3864 . 136241) (-3865 . 135658) (-3866 . 135601) (-3867 . 135494) (-3868 . 135157) (-3869 . 134065) (-3870 . 133940) (-3871 . 133880) (-3872 . 133730) (-3873 . 133639) (-3874 . 133521) (-3875 . 133451) (-3876 . 133393) (-3877 . 132876) (-3878 . 132735) (-3879 . 132617) (-3880 . 132495) (-3881 . 132384) (-3882 . 132246) (-3883 . 131948) (-3884 . 131920) (-3885 . 131795) (-3886 . 131549) (-3887 . 131359) (-3888 . 131124) (-3889 . 130750) (-3890 . 130672) (-3891 . 130384) (-3892 . 130303) (-3893 . 130178) (-3894 . 130126) (-3895 . 130004) (-3896 . 129810) (-3897 . 129557) (-3898 . 129416) (-3899 . 128844) (-3900 . 128772) (-3901 . 128744) (-3902 . 128647) (-3903 . 128590) (-3904 . 128498) (-3905 . 128421) (-3906 . 128347) (-3907 . 128276) (-3908 . 128126) (-3909 . 127978) (-3910 . 127343) (-3911 . 127309) (-3912 . 126532) (-3913 . 126504) (-3914 . 126354) (-3915 . 122673) (-3916 . 122614) (-3917 . 122562) (-3918 . 122384) (-3919 . 122293) (-3920 . 122121) (-3921 . 122069) (-3922 . 122001) (-3923 . 121679) (-3924 . 121617) (-3925 . 121507) (-3926 . 121413) (-3927 . 121290) (-3928 . 121138) (-3929 . 120325) (-3930 . 120183) (-3931 . 120109) (-3932 . 120012) (-3933 . 119920) (-3934 . 119748) (-3935 . 119445) (-3936 . 119033) (-3937 . 118915) (-3938 . 118802) (-3939 . 118595) (-3940 . 118416) (-3941 . 118334) (-3942 . 118182) (-3943 . 118115) (-3944 . 117919) (-3945 . 117703) (-3946 . 116213) (-3947 . 116109) (-3948 . 116016) (-3949 . 115926) (-3950 . 115827) (-3951 . 115133) (-3952 . 114934) (-3953 . 114903) (-3954 . 114828) (-3955 . 114751) (-3956 . 114328) (-3957 . 113605) (-3958 . 113506) (-3959 . 113321) (-3960 . 113219) (-3961 . 113166) (-3962 . 113091) (-3963 . 112908) (-3964 . 112756) (-3965 . 112660) (-3966 . 112597) (-3967 . 112421) (-3968 . 112174) (-3969 . 112146) (-3970 . 111962) (-3971 . 111700) (-3972 . 111612) (-3973 . 111559) (-3974 . 111463) (-3975 . 111397) (-3976 . 111294) (-3977 . 111219) (-3978 . 111119) (-3979 . 111053) (-3980 . 110946) (-3981 . 110862) (-3982 . 110735) (-3983 . 110580) (-3984 . 110524) (-3985 . 110459) (-3986 . 109501) (-3987 . 109438) (-3988 . 109325) (-3989 . 109263) (-3990 . 109139) (-3991 . 109023) (-3992 . 108944) (-3993 . 108788) (-3994 . 108453) (-3995 . 108387) (-3996 . 108054) (-3997 . 107981) (-3998 . 107860) (-3999 . 107218) (-4000 . 107166) (-4001 . 106956) (-4002 . 106873) (-4003 . 106821) (-4004 . 106714) (-4005 . 106656) (-4006 . 106535) (-4007 . 106127) (-4008 . 106061) (-4009 . 105838) (-4010 . 105705) (-4011 . 105602) (-4012 . 105543) (-4013 . 105401) (-4014 . 105299) (-4015 . 105223) (-4016 . 105157) (-4017 . 105084) (-4018 . 104983) (-4019 . 104793) (-4020 . 104742) (-4021 . 104570) (-4022 . 104286) (-4023 . 104187) (-4024 . 104114) (-4025 . 103494) (-4026 . 103402) (-4027 . 103349) (-4028 . 103296) (-4029 . 103212) (-4030 . 103116) (-4031 . 102963) (-4032 . 102890) (-4033 . 102738) (-4034 . 102629) (-4035 . 102466) (-4036 . 102370) (-4037 . 102102) (-4038 . 101970) (-4039 . 101834) (-4040 . 101768) (-4041 . 101688) (-4042 . 101555) (-4043 . 101433) (-4044 . 101301) (-4045 . 101191) (-4046 . 101139) (-4047 . 101069) (-4048 . 100936) (-4049 . 100864) (-4050 . 100783) (-4051 . 100712) (-4052 . 100631) (-4053 . 100467) (-4054 . 100381) (-4055 . 100255) (-4056 . 100048) (-4057 . 99834) (-4058 . 99764) (-4059 . 99604) (-4060 . 99518) (-4061 . 99395) (-4062 . 99213) (-4063 . 99082) (-4064 . 98942) (-4065 . 98868) (-4066 . 98741) (-4067 . 98655) (-4068 . 98552) (-4069 . 98278) (-4070 . 98175) (-4071 . 97968) (-4072 . 97900) (-4073 . 97814) (-4074 . 97385) (-4075 . 97049) (-4076 . 96860) (-4077 . 96741) (-4078 . 96655) (-4079 . 96485) (-4080 . 96322) (-4081 . 96247) (-4082 . 96009) (-4083 . 95673) (-4084 . 95599) (-4085 . 94666) (-4086 . 94580) (-4087 . 94514) (-4088 . 93865) (-4089 . 93402) (-4090 . 93336) (-4091 . 93263) (-4092 . 93185) (-4093 . 93099) (-4094 . 92942) (-4095 . 92889) (-4096 . 92748) (-4097 . 92674) (-4098 . 92060) (-4099 . 91903) (-4100 . 91817) (-4101 . 91720) (-4102 . 91554) (-4103 . 91490) (-4104 . 91456) (-4105 . 91400) (-4106 . 91266) (-4107 . 91180) (-4108 . 91112) (-4109 . 90819) (-4110 . 90745) (-4111 . 90641) (-4112 . 90531) (-4113 . 90472) (-4114 . 90386) (-4115 . 90287) (-4116 . 89481) (-4117 . 89289) (-4118 . 89087) (-4119 . 89021) (-4120 . 88971) (-4121 . 88898) (-4122 . 88806) (-4123 . 88416) (-4124 . 88265) (-4125 . 88057) (-4126 . 87982) (-4127 . 87193) (-4128 . 87043) (-4129 . 86957) (-4130 . 86417) (-4131 . 86338) (-4132 . 86219) (-4133 . 86138) (-4134 . 85891) (-4135 . 85779) (-4136 . 85693) (-4137 . 85557) (-4138 . 85529) (-4139 . 85413) (-4140 . 85345) (-4141 . 85210) (-4142 . 85124) (-4143 . 84934) (-4144 . 84859) (-4145 . 84784) (-4146 . 84498) (-4147 . 84397) (-4148 . 84322) (-4149 . 84236) (-4150 . 84086) (-4151 . 84031) (-4152 . 83857) (-4153 . 83724) (-4154 . 83378) (-4155 . 83242) (-4156 . 82898) (-4157 . 82812) (-4158 . 82721) (-4159 . 82603) (-4160 . 82533) (-4161 . 82375) (-4162 . 82183) (-4163 . 82035) (-4164 . 81726) (-4165 . 81633) (-4166 . 81515) (-4167 . 81038) (-4168 . 80794) (-4169 . 80295) (-4170 . 78952) (-4171 . 78842) (-4172 . 78747) (-4173 . 78640) (-4174 . 78266) (-4175 . 78105) (-4176 . 78013) (-4177 . 77888) (-4178 . 77639) (-4179 . 77454) (-4180 . 77385) (-4181 . 77260) (-4182 . 76879) (-4183 . 76787) (-4184 . 76628) (-4185 . 76561) (-4186 . 76414) (-4187 . 76358) (-4188 . 75292) (-4189 . 75203) (-4190 . 75097) (-4191 . 72852) (-4192 . 72779) (-4193 . 72644) (-4194 . 72567) (-4195 . 72495) (-4196 . 72388) (-4197 . 72194) (-4198 . 72108) (-4199 . 71905) (-4200 . 71505) (-4201 . 71253) (-4202 . 71146) (-4203 . 71094) (-4204 . 70922) (-4205 . 70816) (-4206 . 70720) (-4207 . 70638) (-4208 . 70606) (-4209 . 70524) (-4210 . 70438) (-4211 . 70300) (-4212 . 70019) (-4213 . 69922) (-4214 . 69815) (-4215 . 69701) (-4216 . 69544) (-4217 . 69484) (-4218 . 69416) (-4219 . 69263) (-4220 . 69204) (-4221 . 69052) (-4222 . 68966) (-4223 . 68768) (-4224 . 68669) (-4225 . 68526) (-4226 . 68380) (-4227 . 68217) (-4228 . 68099) (-4229 . 67901) (-4230 . 67566) (-4231 . 67296) (-4232 . 67230) (-4233 . 66750) (-4234 . 66664) (-4235 . 66496) (-4236 . 66400) (-4237 . 66347) (-4238 . 66236) (-4239 . 66150) (-4240 . 65990) (-4241 . 65900) (-4242 . 65363) (-4243 . 65161) (-4244 . 64947) (-4245 . 64852) (-4246 . 64694) (-4247 . 64471) (-4248 . 64422) (-4249 . 64331) (-4250 . 64058) (-4251 . 63819) (-4252 . 63633) (-4253 . 63109) (-4254 . 62260) (-4255 . 62087) (-4256 . 62053) (-4257 . 61937) (-4258 . 61864) (-4259 . 61778) (-4260 . 61704) (-4261 . 61597) (-4262 . 61515) (-4263 . 61398) (-4264 . 61240) (-4265 . 61181) (-4266 . 60869) (-4267 . 60775) (-4268 . 60743) (-4269 . 60657) (-4270 . 60408) (-4271 . 60310) (-4272 . 59971) (-4273 . 59897) (-4274 . 59709) (-4275 . 59657) (-4276 . 59507) (-4277 . 59349) (-4278 . 59265) (-4279 . 59170) (-4280 . 54762) (-4281 . 54670) (-4282 . 54478) (-4283 . 54345) (-4284 . 53713) (-4285 . 53682) (-4286 . 53630) (-4287 . 53523) (-4288 . 53269) (-4289 . 50731) (-4290 . 50477) (-4291 . 50344) (-4292 . 50316) (-4293 . 49970) (-4294 . 49904) (-4295 . 48550) (-4296 . 48464) (-4297 . 48259) (-4298 . 48040) (-4299 . 47968) (-4300 . 47892) (-4301 . 47619) (-4302 . 47533) (-4303 . 47444) (-4304 . 47344) (-4305 . 47315) (-4306 . 47262) (-4307 . 47145) (-4308 . 46721) (-4309 . 46635) (-4310 . 46318) (-4311 . 46233) (-4312 . 46011) (-4313 . 45836) (-4314 . 45381) (-4315 . 45295) (-4316 . 45143) (-4317 . 45058) (-4318 . 44792) (-4319 . 44717) (-4320 . 44522) (-4321 . 44206) (-4322 . 43970) (-4323 . 43942) (-4324 . 43873) (-4325 . 43526) (-4326 . 39602) (-4327 . 39460) (-4328 . 39318) (-4329 . 39146) (-4330 . 38576) (-4331 . 38524) (-4332 . 38348) (-4333 . 38255) (-4334 . 37993) (-4335 . 37901) (-4336 . 37698) (-4337 . 37601) (-4338 . 37193) (-4339 . 37017) (-4340 . 36866) (-4341 . 36814) (-4342 . 36201) (-4343 . 36129) (-4344 . 36077) (-4345 . 35843) (-4346 . 35717) (-4347 . 35476) (-4348 . 35424) (-4349 . 35358) (-4350 . 35088) (-4351 . 34983) (-4352 . 34408) (-4353 . 34351) (-4354 . 34193) (-4355 . 34086) (-4356 . 33761) (-4357 . 33455) (-4358 . 33214) (-4359 . 33081) (-4360 . 32946) (-4361 . 32893) (-4362 . 32355) (-4363 . 32098) (-4364 . 31993) (-4365 . 31819) (-4366 . 31624) (-4367 . 31525) (-4368 . 31413) (-4369 . 31300) (-4370 . 31197) (-4371 . 31095) (-4372 . 30996) (-4373 . 30914) (-4374 . 30877) (-4375 . 30691) (-4376 . 30567) (-4377 . 30492) (-4378 . 30382) (-4379 . 30307) (-4380 . 30236) (-4381 . 30134) (-4382 . 29984) (-4383 . 29866) (-4384 . 29489) (-4385 . 28266) (-4386 . 28176) (-4387 . 28093) (-4388 . 27670) (-4389 . 27591) (-4390 . 27536) (-4391 . 27451) (-4392 . 27331) (-4393 . 27200) (-4394 . 26918) (-4395 . 26867) (-4396 . 26799) (-4397 . 26647) (-4398 . 26226) (-4399 . 26129) (-4400 . 25996) (-4401 . 25893) (-4402 . 25790) (-4403 . 25759) (-4404 . 25707) (-4405 . 25478) (-4406 . 24851) (-4407 . 24799) (-4408 . 24612) (-4409 . 24373) (-4410 . 24345) (-4411 . 24191) (-4412 . 24109) (-4413 . 23931) (-4414 . 23825) (-4415 . 23759) (-4416 . 23655) (-4417 . 21943) (-4418 . 20767) (-4419 . 20642) (-4420 . 20498) (-4421 . 20426) (-4422 . 20321) (-4423 . 20219) (-4424 . 20162) (-4425 . 20010) (-4426 . 19958) (-4427 . 19633) (-4428 . 17196) (-4429 . 17076) (-4430 . 16921) (-4431 . 16869) (-4432 . 16792) (-4433 . 16719) (-4434 . 16537) (-4435 . 16458) (-4436 . 16339) (-4437 . 15988) (-4438 . 15915) (-4439 . 15078) (-4440 . 14939) (-4441 . 14674) (-4442 . 14582) (-4443 . 14289) (-4444 . 14173) (-4445 . 14108) (-4446 . 12980) (-4447 . 12830) (-4448 . 12702) (-4449 . 12546) (-4450 . 11877) (-4451 . 11758) (-4452 . 11489) (-4453 . 11012) (-4454 . 10025) (-4455 . 9963) (-4456 . 9929) (-4457 . 9697) (-4458 . 9482) (-4459 . 9338) (-4460 . 9190) (-4461 . 9132) (** . 6067) (-4463 . 5915) (-4464 . 5841) (-4465 . 5774) (-4466 . 5652) (-4467 . 5554) (-4468 . 5431) (-4469 . 5334) (-4470 . 4889) (-4471 . 4791) (-4472 . 4715) (-4473 . 4642) (-4474 . 4593) (-4475 . 4367) (-4476 . 4215) (-4477 . 4070) (-4478 . 3942) (-4479 . 3696) (-4480 . 3423) (-4481 . 3290) (-4482 . 3209) (-4483 . 3073) (-4484 . 3021) (-4485 . 2748) (-4486 . 2647) (-4487 . 2563) (-4488 . 2453) (-4489 . 2237) (-4490 . 1798) (-4491 . 1723) (-4492 . 1592) (-4493 . 1442) (-4494 . 1293) (-4495 . 782) (-4496 . 513) (-4497 . 447) (-4498 . 308) (-4499 . 223) (-4500 . 115) (-4501 . 30)) 
\ No newline at end of file
diff --git a/src/share/algebra/users.daase/index.kaf b/src/share/algebra/users.daase/index.kaf
index 6efa0b5..2daa077 100755
--- a/src/share/algebra/users.daase/index.kaf
+++ b/src/share/algebra/users.daase/index.kaf
@@ -1,15 +1,19 @@
-209919              (|FunctionSpaceUnivariatePolynomialFactor| |GenUFactorize| |LinearOrdinaryDifferentialOperatorFactorizer|)
+234547              (|ProjectiveAlgebraicSetPackage|)
+(|ProjectiveAlgebraicSetPackage|)
+(|AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |BlowUpPackage| |DesingTreePackage| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField|)
+(|AffinePlane|)
+(|FunctionSpaceUnivariatePolynomialFactor| |GenUFactorize| |LinearOrdinaryDifferentialOperatorFactorizer|)
 (|GenericNonAssociativeAlgebra|)
 (|Expression|)
 (|AlgebraicIntegrate|)
 (|ElementaryIntegration|)
 (|ConstantLODE| |ElementaryFunctionStructurePackage| |Expression| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |GenusZeroIntegration| |InnerAlgebraicNumber| |IntegrationResultToFunction| |TransSolvePackage| |TranscendentalManipulations|)
-(|AlgFactor| |Expression| |FunctionSpaceUnivariatePolynomialFactor| |PolynomialAN2Expression| |SimplifyAlgebraicNumberConvertPackage| |ToolsForSign|)
+(|AlgFactor| |Expression| |FunctionSpaceUnivariatePolynomialFactor| |GuessAlgebraicNumber| |PolynomialAN2Expression| |SimplifyAlgebraicNumberConvertPackage| |ToolsForSign|)
 (|d01TransformFunctionType|)
 (|d03AgentsPackage|)
 (|DeRhamComplex|)
-(|AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AnyFunctions1| |DrawOption| |DrawOptionFunctions1| |ExpertSystemToolsPackage| |ExpressionSpaceODESolver| |ExpressionToUnivariatePowerSeries| |FortranTemplate| |FunctionSpaceAttachPredicates| |GenUFactorize| |GenerateUnivariatePowerSeries| |InputForm| |InputFormFunctions1| |Library| |MakeFloatCompiledFunction| |MakeFunction| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |OpenMathPackage| |OpenMathServerPackage| |OutputPackage| |PartialFractionPackage| |Pattern| |PatternFunctions1| |PatternMatchPushDown| |RadixUtilities| |Result| |RoutinesTable| |TemplateUtilities| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |d01TransformFunctionType| |d01alfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d02AgentsPackage| |d03AgentsPackage| |d03eefAnnaType|)
-(|AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |DrawOption| |DrawOptionFunctions1| |ExpertSystemToolsPackage| |FunctionSpaceAttachPredicates| |GenUFactorize| |InputFormFunctions1| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |OpenMathServerPackage| |OutputPackage| |Pattern| |PatternFunctions1| |PatternMatchPushDown| |RoutinesTable| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |d01TransformFunctionType| |d01alfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d02AgentsPackage| |d03AgentsPackage| |d03eefAnnaType|)
+(|AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AnyFunctions1| |DrawOption| |DrawOptionFunctions1| |ExpertSystemToolsPackage| |ExpressionSpaceODESolver| |ExpressionToUnivariatePowerSeries| |FortranTemplate| |FunctionSpaceAttachPredicates| |GenUFactorize| |GenerateUnivariatePowerSeries| |GuessOption| |GuessOptionFunctions0| |InputForm| |InputFormFunctions1| |Library| |MakeFloatCompiledFunction| |MakeFunction| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |OpenMathPackage| |OpenMathServerPackage| |OutputPackage| |PartialFractionPackage| |Pattern| |PatternFunctions1| |PatternMatchPushDown| |RadixUtilities| |Result| |RoutinesTable| |TemplateUtilities| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |d01TransformFunctionType| |d01alfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d02AgentsPackage| |d03AgentsPackage| |d03eefAnnaType|)
+(|AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |DrawOption| |DrawOptionFunctions1| |ExpertSystemToolsPackage| |FunctionSpaceAttachPredicates| |GenUFactorize| |GuessOption| |GuessOptionFunctions0| |InputFormFunctions1| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |OpenMathServerPackage| |OutputPackage| |Pattern| |PatternFunctions1| |PatternMatchPushDown| |RoutinesTable| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |d01TransformFunctionType| |d01alfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d02AgentsPackage| |d03AgentsPackage| |d03eefAnnaType|)
 (|RewriteRule| |Ruleset| |TranscendentalManipulations|)
 (|LinearOrdinaryDifferentialOperator2|)
 (|NagIntegrationPackage| |NagRootFindingPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType|)
@@ -48,28 +52,30 @@
 (|PrimitiveRatDE| |PrimitiveRatRicDE|)
 (|BalancedPAdicRational|)
 (|ExpertSystemContinuityPackage|)
-(|AlgebraicFunction| |AlgebraicManipulations| |AlgebraicNumber| |ApplyRules| |Asp8| |BasicOperatorFunctions1| |CombinatorialFunction| |CommonOperators| |ComplexTrigonometricManipulations| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |Expression| |ExpressionSpace&| |ExpressionSpaceFunctions1| |ExpressionSpaceFunctions2| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |FortranExpression| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpaceReduce| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionalSpecialFunction| |InnerAlgebraicNumber| |InnerTrigonometricManipulations| |IntegrationTools| |Kernel| |KernelFunctions2| |LaplaceTransform| |LiouvillianFunction| |ModuleOperator| |NonLinearFirstOrderODESolver| |Operator| |Pattern| |PatternFunctions2| |PatternMatchKernel| |PatternMatchPushDown| |PointsOfFiniteOrder| |PowerSeriesLimitPackage| |Switch| |TranscendentalManipulations| |TrigonometricManipulations| |d01WeightsPackage| |d01anfAnnaType| |d01asfAnnaType|)
-(|AlgebraicFunction| |CombinatorialFunction| |ElementaryFunction| |ExpressionSpace&| |FunctionSpace&| |FunctionalSpecialFunction| |KernelFunctions2| |LiouvillianFunction|)
+(|AlgebraicFunction| |AlgebraicManipulations| |AlgebraicNumber| |ApplyRules| |Asp8| |BasicOperatorFunctions1| |CombinatorialFunction| |CommonOperators| |ComplexTrigonometricManipulations| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceFunctions1| |ExpressionSpaceFunctions2| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |FortranExpression| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpaceReduce| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionalSpecialFunction| |Guess| |InnerAlgebraicNumber| |InnerTrigonometricManipulations| |IntegrationTools| |Kernel| |KernelFunctions2| |LaplaceTransform| |LiouvillianFunction| |ModuleOperator| |MyExpression| |NonLinearFirstOrderODESolver| |Operator| |Pattern| |PatternFunctions2| |PatternMatchKernel| |PatternMatchPushDown| |PointsOfFiniteOrder| |PowerSeriesLimitPackage| |RecurrenceOperator| |Switch| |TranscendentalManipulations| |TrigonometricManipulations| |d01WeightsPackage| |d01anfAnnaType| |d01asfAnnaType|)
+(|AlgebraicFunction| |CombinatorialFunction| |ElementaryFunction| |ExpressionSpace&| |FunctionSpace&| |FunctionalSpecialFunction| |KernelFunctions2| |LiouvillianFunction| |RecurrenceOperator|)
 (|BalancedBinaryTree| |BinarySearchTree| |BinaryTournament|)
 (|SetOfMIntegersInOneToN|)
-(|AbelianMonoid&| |AbelianMonoidRing&| |Aggregate&| |AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AnonymousFunction| |AntiSymm| |Any| |AnyFunctions1| |ApplyRules| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BasicType&| |BezoutMatrix| |BinaryExpansion| |BinaryFile| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |BinaryTreeCategory&| |BitAggregate&| |Bits| |Boolean| |BoundIntegerRoots| |BrillhartTests| |CardinalNumber| |CartesianTensor| |ChangeOfVariable| |Character| |CharacterClass| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |Collection&| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |CommuteUnivariatePolynomialCategory| |Complex| |ComplexCategory&| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexPattern| |ComplexPatternMatch| |ComplexRootFindingPackage| |ComplexTrigonometricManipulations| |ConstantLODE| |ContinuedFraction| |CycleIndicators| |CyclicStreamTools| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |Dictionary&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DiscreteLogarithmPackage| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DivisionRing&| |DoubleFloat| |DoubleFloatSpecialFunctions| |DrawComplex| |DrawOption| |DrawOptionFunctions0| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EllipticFunctionsUnivariateTaylorSeries| |EqTable| |Equation| |EuclideanDomain&| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |EvaluateCycleIndicators| |Exit| |ExpertSystemContinuityPackage| |ExpertSystemContinuityPackage1| |ExpertSystemToolsPackage| |ExpertSystemToolsPackage1| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |ExtAlgBasis| |ExtensibleLinearAggregate&| |ExtensionField&| |FGLMIfCanPackage| |Factored| |FactoredFunctions| |FactoringUtilities| |Field&| |File| |FileName| |FindOrderFinite| |FiniteAbelianMonoidRing&| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteDivisorCategory&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSolveLinearPolynomialEquation| |FiniteLinearAggregate&| |FiniteLinearAggregateFunctions2| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranCode| |FortranExpression| |FortranOutputStackPackage| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |FourierComponent| |FourierSeries| |Fraction| |FractionalIdeal| |FramedModule| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionCalled| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaussianFactorizationPackage| |GcdDomain&| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralModulePolynomial| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |GraphImage| |GraphicsDefaults| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |GroebnerSolve| |HallBasis| |HashTable| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexCard| |IndexedAggregate&| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfiniteProductFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySign| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |Integer| |IntegerBits| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerLinearDependence| |IntegerMod| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRetractions| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegralBasisTools| |IntegralDomain&| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InternalRationalUnivariateRepresentationPackage| |InverseLaplaceTransform| |IrrRepSymNatPackage| |IrredPolyOverFiniteField| |Kernel| |KeyedAccessFile| |KeyedDictionary&| |LaplaceTransform| |LaurentPolynomial| |LazardSetSolvingPackage| |LazyStreamAggregate&| |LeadingCoefDetermination| |LexTriangularPackage| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorCategory&| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperatorsOps| |LinearPolynomialEquationByFractions| |LinearSystemMatrixPackage| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |LiouvillianFunction| |List| |ListAggregate&| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |Localize| |LyndonWord| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeCachableSet| |MakeFloatCompiledFunction| |Matrix| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |MergeThing| |MeshCreationRoutinesForThreeDimensions| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModularRing| |ModuleMonomial| |ModuleOperator| |MoebiusTransform| |MonadWithUnit&| |Monoid&| |MonoidRing| |MonomialExtensionTools| |MultFiniteFactorize| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |NAGLinkSupportPackage| |NPCoef| |NagEigenPackage| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagPolynomialRootsPackage| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonCommutativeOperatorDivision| |NonLinearFirstOrderODESolver| |NonNegativeInteger| |None| |NormInMonogenicAlgebra| |NormRetractPackage| |NormalizationPackage| |NumberFieldIntegralBasis| |NumberFormats| |NumberTheoreticPolynomialFunctions| |NumericContinuedFraction| |NumericTubePlot| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalOrdinaryDifferentialEquations| |NumericalPDEProblem| |NumericalQuadrature| |ODEIntegration| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |OpenMathConnection| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OpenMathPackage| |OpenMathServerPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedRing&| |OrderedSet&| |OrderedVariableList| |OrderingFunctions| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PadeApproximantPackage| |PadeApproximants| |Palette| |ParametricLinearEquations| |PartialFraction| |Partition| |Pattern| |PatternFunctions1| |PatternMatch| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchListAggregate| |PatternMatchListResult| |PatternMatchPolynomialCategory| |PatternMatchPushDown| |PatternMatchQuotientFieldCategory| |PatternMatchResult| |PatternMatchResultFunctions2| |PatternMatchSymbol| |PatternMatchTools| |PendantTree| |Permanent| |Permutation| |PermutationGroup| |Pi| |PlaneAlgebraicCurvePlot| |Plot| |Plot3D| |PlotTools| |PoincareBirkhoffWittLyndonBasis| |Point| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PolToPol| |Polynomial| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialComposition| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialNumberTheoryFunctions| |PolynomialRing| |PolynomialRoots| |PolynomialSetCategory&| |PolynomialSetUtilitiesPackage| |PolynomialSolveByFormulas| |PolynomialSquareFree| |PositiveInteger| |PowerSeriesCategory&| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |PushVariables| |QuadraticForm| |QuasiAlgebraicSet| |QuasiAlgebraicSet2| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |Queue| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RandomDistributions| |RandomFloatDistributions| |RandomIntegerDistributions| |RationalFactorize| |RationalFunctionDefiniteIntegration| |RationalFunctionLimitPackage| |RationalLODE| |RationalRetractions| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealZeroPackage| |RectangularMatrix| |RectangularMatrixCategory&| |RecursiveAggregate&| |RecursivePolynomialCategory&| |ReductionOfOrder| |Reference| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RetractSolvePackage| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RoutinesTable| |RuleCalled| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentBinding| |SegmentFunctions2| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SingletonAsOrderedSet| |SmithNormalForm| |SortPackage| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |Stack| |StorageEfficientMatrixOperations| |Stream| |StreamAggregate&| |StreamFunctions1| |StreamFunctions2| |StreamFunctions3| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringAggregate&| |StringTable| |StructuralConstantsPackage| |SturmHabichtPackage| |SubResultantPackage| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |SupFractionFactorizer| |Switch| |Symbol| |SymbolTable| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Table| |TableAggregate&| |TableauxBumpers| |TabulatedComputationPackage| |TaylorSeries| |TexFormat| |TextFile| |TheSymbolTable| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |ToolsForSign| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TransSolvePackage| |TransSolvePackageService| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDE| |TranscendentalRischDESystem| |Tree| |TriangularSetCategory&| |TrigonometricManipulations| |TubePlot| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |UnaryRecursiveAggregate&| |UniqueFactorizationDomain&| |UnivariateFactorize| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesConstructorCategory&| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategoryOps| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesODESolver| |UniversalSegment| |UniversalSegmentFunctions2| |UserDefinedPartialOrdering| |Variable| |Vector| |VectorFunctions2| |ViewDefaultsPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XExponentialPackage| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |d03fafAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|DesingTreePackage|)
+(|AbelianMonoid&| |AbelianMonoidRing&| |AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |Aggregate&| |AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AnonymousFunction| |AntiSymm| |Any| |AnyFunctions1| |ApplyRules| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |AxiomServer| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BasicType&| |BezoutMatrix| |BinaryExpansion| |BinaryFile| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |BinaryTreeCategory&| |BitAggregate&| |Bits| |BlowUpPackage| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |BoundIntegerRoots| |BrillhartTests| |CardinalNumber| |CartesianTensor| |ChangeOfVariable| |Character| |CharacterClass| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |Collection&| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |CommuteUnivariatePolynomialCategory| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexPattern| |ComplexPatternMatch| |ComplexRootFindingPackage| |ComplexTrigonometricManipulations| |ConstantLODE| |ContinuedFraction| |CycleIndicators| |CyclicStreamTools| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |Dictionary&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DivisionRing&| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DrawComplex| |DrawOption| |DrawOptionFunctions0| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EllipticFunctionsUnivariateTaylorSeries| |EqTable| |Equation| |EuclideanDomain&| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |EvaluateCycleIndicators| |Exit| |ExpertSystemContinuityPackage| |ExpertSystemContinuityPackage1| |ExpertSystemToolsPackage| |ExpertSystemToolsPackage1| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |ExtAlgBasis| |ExtensibleLinearAggregate&| |ExtensionField&| |FGLMIfCanPackage| |Factored| |FactoredFunctions| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |Field&| |File| |FileName| |FindOrderFinite| |FiniteAbelianMonoidRing&| |FiniteAbelianMonoidRingFunctions2| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteDivisorCategory&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteLinearAggregate&| |FiniteLinearAggregateFunctions2| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranCode| |FortranExpression| |FortranOutputStackPackage| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |FourierComponent| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionalIdeal| |FramedModule| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionCalled| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaussianFactorizationPackage| |GcdDomain&| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |GraphImage| |GraphicsDefaults| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |GroebnerSolve| |Guess| |GuessOption| |GuessOptionFunctions0| |HTMLFormat| |HallBasis| |HashTable| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexCard| |IndexedAggregate&| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfiniteProductFiniteField| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySign| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |Integer| |IntegerBits| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerLinearDependence| |IntegerMod| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRetractions| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegralBasisTools| |IntegralDomain&| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InternalRationalUnivariateRepresentationPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrrRepSymNatPackage| |IrredPolyOverFiniteField| |Kernel| |KeyedAccessFile| |KeyedDictionary&| |LaplaceTransform| |LaurentPolynomial| |LazardSetSolvingPackage| |LazyStreamAggregate&| |LeadingCoefDetermination| |LexTriangularPackage| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorCategory&| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperatorsOps| |LinearPolynomialEquationByFractions| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |LinesOpPack| |LiouvillianFunction| |List| |ListAggregate&| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |LocalParametrizationOfSimplePointPackage| |Localize| |LyndonWord| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeCachableSet| |MakeFloatCompiledFunction| |MathMLFormat| |Matrix| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |MergeThing| |MeshCreationRoutinesForThreeDimensions| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModularRing| |ModuleMonomial| |ModuleOperator| |MoebiusTransform| |MonadWithUnit&| |Monoid&| |MonoidRing| |MonomialExtensionTools| |MultFiniteFactorize| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NPCoef| |NagEigenPackage| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagPolynomialRootsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonPolygon| |NonCommutativeOperatorDivision| |NonLinearFirstOrderODESolver| |NonNegativeInteger| |None| |NormInMonogenicAlgebra| |NormRetractPackage| |NormalizationPackage| |NottinghamGroup| |NumberFieldIntegralBasis| |NumberFormats| |NumberTheoreticPolynomialFunctions| |NumericContinuedFraction| |NumericTubePlot| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalOrdinaryDifferentialEquations| |NumericalPDEProblem| |NumericalQuadrature| |ODEIntegration| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |OpenMathConnection| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OpenMathPackage| |OpenMathServerPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedRing&| |OrderedSet&| |OrderedVariableList| |OrderingFunctions| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |PadeApproximantPackage| |PadeApproximants| |Palette| |ParametricLinearEquations| |ParametrizationPackage| |PartialFraction| |Partition| |Pattern| |PatternFunctions1| |PatternMatch| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchListAggregate| |PatternMatchListResult| |PatternMatchPolynomialCategory| |PatternMatchPushDown| |PatternMatchQuotientFieldCategory| |PatternMatchResult| |PatternMatchResultFunctions2| |PatternMatchSymbol| |PatternMatchTools| |PendantTree| |Permanent| |Permutation| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PlotTools| |PoincareBirkhoffWittLyndonBasis| |Point| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PolToPol| |Polynomial| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialComposition| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialNumberTheoryFunctions| |PolynomialPackageForCurve| |PolynomialRing| |PolynomialRoots| |PolynomialSetCategory&| |PolynomialSetUtilitiesPackage| |PolynomialSolveByFormulas| |PolynomialSquareFree| |PositiveInteger| |PowerSeriesCategory&| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |PushVariables| |QuadraticForm| |QuasiAlgebraicSet| |QuasiAlgebraicSet2| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |Queue| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RandomDistributions| |RandomFloatDistributions| |RandomIntegerDistributions| |RationalFactorize| |RationalFunctionDefiniteIntegration| |RationalFunctionLimitPackage| |RationalInterpolation| |RationalLODE| |RationalRetractions| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealZeroPackage| |RectangularMatrix| |RectangularMatrixCategory&| |RecurrenceOperator| |RecursiveAggregate&| |RecursivePolynomialCategory&| |ReductionOfOrder| |Reference| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RetractSolvePackage| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RootsFindingPackage| |RoutinesTable| |RuleCalled| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentBinding| |SegmentFunctions2| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SingletonAsOrderedSet| |SmithNormalForm| |SortPackage| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |Stack| |StorageEfficientMatrixOperations| |Stream| |StreamAggregate&| |StreamFunctions1| |StreamFunctions2| |StreamFunctions3| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringAggregate&| |StringTable| |StructuralConstantsPackage| |SturmHabichtPackage| |SubResultantPackage| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |SupFractionFactorizer| |Switch| |Symbol| |SymbolTable| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Table| |TableAggregate&| |TableauxBumpers| |TabulatedComputationPackage| |TaylorSeries| |TaylorSolve| |TexFormat| |TextFile| |TheSymbolTable| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |ToolsForSign| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TransSolvePackage| |TransSolvePackageService| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDE| |TranscendentalRischDESystem| |Tree| |TriangularSetCategory&| |TrigonometricManipulations| |TubePlot| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |UnaryRecursiveAggregate&| |UniqueFactorizationDomain&| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesConstructorCategory&| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategoryOps| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesODESolver| |UniversalSegment| |UniversalSegmentFunctions2| |UserDefinedPartialOrdering| |Variable| |Vector| |VectorFunctions2| |ViewDefaultsPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XExponentialPackage| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |d03fafAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|PrimitiveRatDE| |RationalLODE|)
 (|GaloisGroupFactorizer|)
-(|CliffordAlgebra| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |Equation| |FiniteAlgebraicExtensionField&| |FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |HomogeneousDirectProduct| |InnerFiniteField| |InnerPrimeField| |OrderedDirectProduct| |PrimeField| |RectangularMatrix| |SplitHomogeneousDirectProduct|)
+(|CliffordAlgebra| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |Equation| |FiniteAlgebraicExtensionField&| |FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |HomogeneousDirectProduct| |InnerFiniteField| |InnerPrimeField| |OrderedDirectProduct| |PrimeField| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |RectangularMatrix| |SplitHomogeneousDirectProduct|)
 (|CartesianTensorFunctions2|)
 (|AlgebraicFunctionField| |AlgebraicIntegration| |PureAlgebraicIntegration| |RadicalFunctionField|)
-(|Character| |CharacterClass| |Float| |FortranTemplate| |IndexedBits| |IndexedString| |LieExponentials| |NumberFormats| |OutputForm| |RadixExpansion| |RecursivePolynomialCategory&| |ScriptFormulaFormat| |String| |StringAggregate&| |Symbol| |TemplateUtilities| |TexFormat| |Tree|)
-(|Character| |IndexedString| |String| |StringAggregate&|)
+(|AxiomServer| |Character| |CharacterClass| |Float| |FortranTemplate| |HTMLFormat| |IndexedBits| |IndexedString| |LieExponentials| |MathMLFormat| |NumberFormats| |OutputForm| |RadixExpansion| |RecursivePolynomialCategory&| |ScriptFormulaFormat| |String| |StringAggregate&| |Symbol| |TemplateUtilities| |TexFormat| |Tree|)
+(|Character| |IndexedString| |MathMLFormat| |String| |StringAggregate&|)
 (|MonogenicAlgebra&|)
 (|PAdicWildFunctionFieldIntegralBasis|)
 (|FramedNonAssociativeAlgebra&| |GenericNonAssociativeAlgebra|)
 (|GraphImage| |Palette| |ThreeDimensionalViewport| |TwoDimensionalViewport| |ViewDefaultsPackage|)
 (|Expression|)
-(|FractionalIdeal| |PAdicWildFunctionFieldIntegralBasis| |UnivariatePolynomialCommonDenominator|)
+(|FractionFreeFastGaussianFractions| |FractionalIdeal| |PAdicWildFunctionFieldIntegralBasis| |UnivariatePolynomialCommonDenominator|)
 (|AlgebraicFunction| |CombinatorialFunction| |ElementaryFunction| |ExpressionSpace&| |FunctionSpace&| |FunctionalSpecialFunction| |LiouvillianFunction|)
 (|FreeNilpotentLie|)
 (|DoubleResultantPackage| |InnerAlgFactor| |InnerAlgebraicNumber| |PolynomialFactorizationByRecursion| |TranscendentalIntegration| |TwoFactorize|)
-(|AlgebraicNumber| |Complex| |ComplexCategory&| |ComplexFactorization| |ComplexFunctions2| |ComplexRootFindingPackage| |ComplexRootPackage| |ComplexTrigonometricManipulations| |DoubleFloatSpecialFunctions| |DrawComplex| |FloatingComplexPackage| |GaussianFactorizationPackage| |InnerAlgebraicNumber| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerTrigonometricManipulations| |MachineComplex| |NagSpecialFunctionsPackage| |Numeric| |TransSolvePackage| |TrigonometricManipulations| |d02AgentsPackage|)
+(|AlgebraicNumber| |BlasLevelOne| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexFactorization| |ComplexFunctions2| |ComplexRootFindingPackage| |ComplexRootPackage| |ComplexTrigonometricManipulations| |DoubleFloatSpecialFunctions| |DrawComplex| |FloatingComplexPackage| |GaussianFactorizationPackage| |InnerAlgebraicNumber| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerTrigonometricManipulations| |MachineComplex| |NagSpecialFunctionsPackage| |Numeric| |TransSolvePackage| |TrigonometricManipulations| |d02AgentsPackage|)
+(|ComplexDoubleFloatMatrix|)
 (|ComplexRootPackage| |GenUFactorize| |NumericComplexEigenPackage|)
 (|Numeric| |TransSolvePackage|)
 (|ComplexCategory&|)
@@ -85,17 +91,21 @@
 (|OperationsQuery|)
 (|ElementaryFunctionDefiniteIntegration| |RationalFunctionDefiniteIntegration|)
 (|RadicalSolvePackage|)
+(|PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField|)
+(|GeneralPackageForAlgebraicFunctionField| |IntersectionDivisorPackage|)
 (|LinearOrdinaryDifferentialOperatorsOps| |OrderlyDifferentialPolynomial| |SequentialDifferentialPolynomial|)
-(|AlgebraGivenByStructuralConstants| |CartesianTensor| |CliffordAlgebra| |DirectProductFunctions2| |DirectProductMatrixModule| |DirectProductModule| |DistributedMultivariatePolynomial| |HomogeneousDirectProduct| |IdealDecompositionPackage| |LieSquareMatrix| |LinGroebnerPackage| |OrderedDirectProduct| |Permanent| |PolToPol| |QuadraticForm| |RectangularMatrix| |SplitHomogeneousDirectProduct| |SquareMatrix|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AlgebraGivenByStructuralConstants| |BlowUpPackage| |CartesianTensor| |CliffordAlgebra| |DesingTreePackage| |DirectProductFunctions2| |DirectProductMatrixModule| |DirectProductModule| |DistributedMultivariatePolynomial| |HomogeneousDirectProduct| |IdealDecompositionPackage| |InfinitlyClosePoint| |LieSquareMatrix| |LinGroebnerPackage| |OrderedDirectProduct| |PackageForAlgebraicFunctionFieldOverFiniteField| |Permanent| |PolToPol| |QuadraticForm| |RectangularMatrix| |SplitHomogeneousDirectProduct| |SquareMatrix|)
 (|FiniteFieldCategory&|)
 (|TopLevelDrawFunctions|)
 (|ChineseRemainderToolsForIntegralBases| |FiniteFieldCategory&| |FiniteFieldPolynomialPackage| |FiniteFieldSolveLinearPolynomialEquation| |GenUFactorize| |IrredPolyOverFiniteField| |MultFiniteFactorize| |PAdicWildFunctionFieldIntegralBasis| |SparseUnivariatePolynomial| |TwoFactorize| |WildFunctionFieldIntegralBasis|)
-(|FGLMIfCanPackage| |GroebnerSolve| |IdealDecompositionPackage| |LinGroebnerPackage| |PolToPol| |QuasiAlgebraicSet2|)
-(|AlgebraicNumber| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |BalancedPAdicRational| |BasicFunctions| |BinaryExpansion| |Color| |CommonOperators| |ComplexCategory&| |DecimalExpansion| |DoubleFloat| |DoubleFloatSpecialFunctions| |DrawComplex| |ExpertSystemContinuityPackage| |ExpertSystemContinuityPackage1| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExpressionTubePlot| |Factored| |Float| |FortranCode| |Fraction| |GraphImage| |HexadecimalExpansion| |InnerAlgebraicNumber| |InputForm| |Integer| |IntegerNumberSystem&| |MachineFloat| |MachineInteger| |MeshCreationRoutinesForThreeDimensions| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagRootFindingPackage| |NagSpecialFunctionsPackage| |NumericTubePlot| |OpenMathDevice| |OpenMathServerPackage| |OutputForm| |PAdicRational| |PAdicRationalConstructor| |Pi| |PlaneAlgebraicCurvePlot| |Plot| |Plot3D| |PlotTools| |QuotientFieldCategory&| |RadixExpansion| |RealNumberSystem&| |RomanNumeral| |SExpression| |SingleInteger| |SparseUnivariateLaurentSeries| |ThreeDimensionalViewport| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TubePlotTools| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |ViewDefaultsPackage| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |BlowUpPackage| |DesingTreePackage| |FGLMIfCanPackage| |GroebnerSolve| |IdealDecompositionPackage| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InterfaceGroebnerPackage| |LinGroebnerPackage| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PolToPol| |QuasiAlgebraicSet2|)
+(|InfClsPt| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |Plcs|)
+(|AlgebraicNumber| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |BalancedPAdicRational| |BasicFunctions| |BinaryExpansion| |BlasLevelOne| |Color| |ComplexCategory&| |DecimalExpansion| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DrawComplex| |ExpertSystemContinuityPackage| |ExpertSystemContinuityPackage1| |ExpertSystemToolsPackage| |ExponentialExpansion| |Export3D| |ExpressionTubePlot| |Factored| |Float| |FortranCode| |Fraction| |GnuDraw| |GraphImage| |HexadecimalExpansion| |InnerAlgebraicNumber| |InputForm| |Integer| |IntegerNumberSystem&| |MachineFloat| |MachineInteger| |MeshCreationRoutinesForThreeDimensions| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagRootFindingPackage| |NagSpecialFunctionsPackage| |NumericTubePlot| |OpenMathDevice| |OpenMathServerPackage| |OutputForm| |PAdicRational| |PAdicRationalConstructor| |Pi| |PlaneAlgebraicCurvePlot| |Plot| |Plot3D| |PlotTools| |QuotientFieldCategory&| |RadixExpansion| |RealNumberSystem&| |RomanNumeral| |SExpression| |SingleInteger| |SparseUnivariateLaurentSeries| |ThreeDimensionalViewport| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TubePlotTools| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |ViewDefaultsPackage| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|DoubleFloat|)
+(|DoubleFloatMatrix|)
 (|AlgebraicIntegrate|)
-(|DrawOptionFunctions1| |ThreeDimensionalViewport| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions|)
-(|GraphImage| |MeshCreationRoutinesForThreeDimensions| |ThreeDimensionalViewport| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TwoDimensionalViewport|)
+(|DrawOptionFunctions1| |GnuDraw| |ThreeDimensionalViewport| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions|)
+(|GnuDraw| |GraphImage| |MeshCreationRoutinesForThreeDimensions| |ThreeDimensionalViewport| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TwoDimensionalViewport|)
 (|DrawOptionFunctions0|)
 (|RadicalEigenPackage|)
 (|Expression|)
@@ -104,11 +114,12 @@
 (|ComplexTrigonometricManipulations| |ElementaryRischDE| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |GenusZeroIntegration| |ODEIntegration| |PowerSeriesLimitPackage| |TransSolvePackage| |TrigonometricManipulations|)
 (|SparseUnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor|)
 (|FunctionSpaceToExponentialExpansion|)
-(|FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |LaplaceTransform|)
+(|FunctionSpaceComplexIntegration| |FunctionSpaceIntegration|)
 (|ElementaryIntegration|)
 (|ElementaryIntegration|)
-(|AlgebraicNumber| |ApplyRules| |ArrayStack| |AssociationList| |BalancedBinaryTree| |BalancedPAdicRational| |BinaryExpansion| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |CharacterClass| |Complex| |ComplexRootFindingPackage| |DataList| |DecimalExpansion| |DefiniteIntegrationTools| |DenavitHartenbergMatrix| |Dequeue| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DiophantineSolutionPackage| |DirectProduct| |DirectProductMatrixModule| |DirectProductModule| |DistributedMultivariatePolynomial| |EigenPackage| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |EqTable| |Equation| |EquationFunctions2| |Evalable&| |ExpertSystemContinuityPackage| |ExponentialExpansion| |Expression| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToUnivariatePowerSeries| |Factored| |FlexibleArray| |FloatingComplexPackage| |FloatingRealPackage| |FortranExpression| |FortranProgram| |Fraction| |FullyEvalableOver&| |FunctionSpace&| |GeneralDistributedMultivariatePolynomial| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |HashTable| |Heap| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |IndexedBits| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InnerAlgebraicNumber| |InnerIndexedTwoDimensionalArray| |InnerNumericFloatSolvePackage| |InnerTable| |KeyedAccessFile| |LaplaceTransform| |Library| |LieExponentials| |LieSquareMatrix| |List| |ListMultiDictionary| |MachineComplex| |Matrix| |ModMonic| |Multiset| |MultivariatePolynomial| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonLinearSolvePackage| |Octonion| |OneDimensionalArray| |OrderedDirectProduct| |OrderlyDifferentialPolynomial| |PAdicRational| |PAdicRationalConstructor| |PatternMatch| |PendantTree| |Point| |Polynomial| |PolynomialCategory&| |PolynomialIdeals| |PowerSeriesLimitPackage| |PrimitiveArray| |Quaternion| |Queue| |RadicalSolvePackage| |RadixExpansion| |RationalFunction| |RationalFunctionLimitPackage| |RationalRicDE| |RectangularMatrix| |RegularChain| |RegularTriangularSet| |Result| |RetractSolvePackage| |RewriteRule| |RoutinesTable| |SequentialDifferentialPolynomial| |Set| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SplitHomogeneousDirectProduct| |SplittingTree| |SquareFreeRegularTriangularSet| |SquareMatrix| |Stack| |Stream| |String| |StringTable| |SystemSolvePackage| |Table| |TaylorSeries| |ThreeDimensionalMatrix| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |Tree| |TwoDimensionalArray| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |Vector| |WuWenTsunTriangularSet| |d01AgentsPackage| |d01TransformFunctionType| |d02AgentsPackage| |d03AgentsPackage|)
+(|AlgebraicNumber| |ApplyRules| |ArrayStack| |AssociationList| |BalancedBinaryTree| |BalancedPAdicRational| |BinaryExpansion| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |CharacterClass| |Complex| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexRootFindingPackage| |DataList| |DecimalExpansion| |DefiniteIntegrationTools| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DiophantineSolutionPackage| |DirectProduct| |DirectProductMatrixModule| |DirectProductModule| |DistributedMultivariatePolynomial| |DoubleFloatMatrix| |DoubleFloatVector| |EigenPackage| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |EqTable| |Equation| |EquationFunctions2| |Evalable&| |ExpertSystemContinuityPackage| |ExponentialExpansion| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToUnivariatePowerSeries| |Factored| |FlexibleArray| |FloatingComplexPackage| |FloatingRealPackage| |FortranExpression| |FortranProgram| |Fraction| |FullyEvalableOver&| |FunctionSpace&| |GeneralDistributedMultivariatePolynomial| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |HashTable| |Heap| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |IndexedBits| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InnerAlgebraicNumber| |InnerIndexedTwoDimensionalArray| |InnerNumericFloatSolvePackage| |InnerTable| |KeyedAccessFile| |LaplaceTransform| |Library| |LieExponentials| |LieSquareMatrix| |List| |ListMultiDictionary| |MachineComplex| |Matrix| |ModMonic| |Multiset| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonLinearSolvePackage| |Octonion| |OneDimensionalArray| |OrderedDirectProduct| |OrderlyDifferentialPolynomial| |PAdicRational| |PAdicRationalConstructor| |PatternMatch| |PendantTree| |Point| |Polynomial| |PolynomialCategory&| |PolynomialIdeals| |PowerSeriesLimitPackage| |PrimitiveArray| |Quaternion| |Queue| |RadicalSolvePackage| |RadixExpansion| |RationalFunction| |RationalFunctionLimitPackage| |RationalRicDE| |RectangularMatrix| |RecurrenceOperator| |RegularChain| |RegularTriangularSet| |Result| |RetractSolvePackage| |RewriteRule| |RoutinesTable| |SequentialDifferentialPolynomial| |Set| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SplitHomogeneousDirectProduct| |SplittingTree| |SquareFreeRegularTriangularSet| |SquareMatrix| |Stack| |Stream| |String| |StringTable| |SystemSolvePackage| |Table| |TaylorSeries| |ThreeDimensionalMatrix| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |Tree| |TwoDimensionalArray| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |Vector| |WuWenTsunTriangularSet| |d01AgentsPackage| |d01TransformFunctionType| |d02AgentsPackage| |d03AgentsPackage|)
 (|AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AttributeButtons| |RoutinesTable| |d01AgentsPackage|)
+(|ParametricLinearEquations|)
 (|InnerModularGcd|)
 (|AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AttributeButtons| |ErrorFunctions| |OpenMathPackage| |ResolveLatticeCompletion| |RoutinesTable| |d01AgentsPackage|)
 (|d01AgentsPackage| |e04gcfAnnaType|)
@@ -117,29 +128,35 @@
 (|d02AgentsPackage| |e04nafAnnaType|)
 (|FunctionSpaceToExponentialExpansion|)
 (|ExponentialExpansion| |FunctionSpaceToExponentialExpansion| |UnivariatePuiseuxSeriesWithExponentialSingularity|)
-(|AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp30| |Asp31| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AttachPredicates| |ComplexTrigonometricManipulations| |DeRhamComplex| |DegreeReductionPackage| |DrawNumericHack| |ElementaryFunctionSign| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExpressionFunctions2| |ExpressionToOpenMath| |ExpressionTubePlot| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranProgram| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |InnerAlgebraicNumber| |IntegrationResultRFToFunction| |MachineInteger| |MeshCreationRoutinesForThreeDimensions| |Numeric| |PatternMatchAssertions| |PiCoercions| |PolynomialAN2Expression| |RadicalEigenPackage| |RadicalSolvePackage| |RationalFunctionDefiniteIntegration| |RationalFunctionSum| |SimplifyAlgebraicNumberConvertPackage| |Switch| |ToolsForSign| |TransSolvePackage| |TransSolvePackageService| |TrigonometricManipulations| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp30| |Asp31| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AttachPredicates| |ComplexTrigonometricManipulations| |DeRhamComplex| |DegreeReductionPackage| |DrawNumericHack| |ElementaryFunctionSign| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExpressionFunctions2| |ExpressionToOpenMath| |ExpressionTubePlot| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranProgram| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |GnuDraw| |GuessAlgebraicNumber| |GuessFinite| |GuessFiniteFunctions| |GuessInteger| |GuessPolynomial| |InnerAlgebraicNumber| |IntegrationResultRFToFunction| |MachineInteger| |MappingPackage4| |MeshCreationRoutinesForThreeDimensions| |MyExpression| |Numeric| |PatternMatchAssertions| |PiCoercions| |PolynomialAN2Expression| |RadicalEigenPackage| |RadicalSolvePackage| |RationalFunctionDefiniteIntegration| |RationalFunctionSum| |SimplifyAlgebraicNumberConvertPackage| |Switch| |ToolsForSign| |TransSolvePackage| |TransSolvePackageService| |TrigonometricManipulations| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|AnnaOrdinaryDifferentialEquationPackage| |ExpertSystemToolsPackage| |FortranExpression| |InnerAlgebraicNumber| |MachineInteger| |Numeric| |TransSolvePackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |e04AgentsPackage|)
+(|RecurrenceOperator|)
 (|Expression| |ExpressionFunctions2| |FunctionSpaceFunctions2| |InnerTrigonometricManipulations|)
 (|AntiSymm| |DeRhamComplex|)
-(|AlgFactor| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicMultFact| |AlgebraicNumber| |BalancedFactorisation| |BalancedPAdicRational| |BinaryExpansion| |BoundIntegerRoots| |ChangeOfVariable| |ChineseRemainderToolsForIntegralBases| |Complex| |ComplexCategory&| |ComplexFactorization| |ComplexRootFindingPackage| |ComplexRootPackage| |ConstantLODE| |ContinuedFraction| |CycleIndicators| |CyclotomicPolynomialPackage| |DecimalExpansion| |DifferentialSparseMultivariatePolynomial| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DoubleFloat| |EigenPackage| |ElementaryFunctionLODESolver| |ElementaryFunctionSign| |Equation| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |Factored| |FactoredFunctionUtilities| |FactoredFunctions| |FactoredFunctions2| |Field&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |Float| |Fraction| |FullPartialFractionExpansion| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaussianFactorizationPackage| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralUnivariatePowerSeries| |GeneralizedMultivariateFactorize| |GosperSummationMethod| |GroebnerFactorizationPackage| |GroebnerSolve| |HexadecimalExpansion| |HomogeneousDistributedMultivariatePolynomial| |IdealDecompositionPackage| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerMultFact| |InnerNumericEigenPackage| |InnerPrimeField| |Integer| |IntegerFactorizationPackage| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegrationResultToFunction| |InverseLaplaceTransform| |Kovacic| |LinearOrdinaryDifferentialOperatorFactorizer| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineComplex| |MachineFloat| |MachineInteger| |ModMonic| |ModularField| |MonomialExtensionTools| |MultFiniteFactorize| |MultivariateFactorize| |MultivariatePolynomial| |MultivariateSquareFree| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NumberFieldIntegralBasis| |NumericComplexEigenPackage| |NumericRealEigenPackage| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |ParametricLinearEquations| |PartialFraction| |PartialFractionPackage| |Pi| |PlaneAlgebraicCurvePlot| |PointsOfFiniteOrder| |Polynomial| |PolynomialCategory&| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialRoots| |PolynomialSetUtilitiesPackage| |PolynomialSolveByFormulas| |PolynomialSquareFree| |PrimeField| |PrimitiveRatDE| |PrimitiveRatRicDE| |QuasiAlgebraicSet| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RationalFactorize| |RationalFunctionFactor| |RationalFunctionFactorizer| |RationalFunctionSign| |RationalRicDE| |RealClosure| |RealZeroPackage| |RomanNumeral| |SAERationalFunctionAlgFactor| |SequentialDifferentialPolynomial| |SimpleAlgebraicExtension| |SimpleAlgebraicExtensionAlgFactor| |SingleInteger| |SparseMultivariatePolynomial| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePuiseuxSeries| |SturmHabichtPackage| |SupFractionFactorizer| |SystemSolvePackage| |TransSolvePackage| |TranscendentalIntegration| |TranscendentalManipulations| |TwoFactorize| |UniqueFactorizationDomain&| |UnivariateFactorize| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |WildFunctionFieldIntegralBasis|)
+(|AlgFactor| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicMultFact| |AlgebraicNumber| |BalancedFactorisation| |BalancedPAdicRational| |BinaryExpansion| |BoundIntegerRoots| |ChangeOfVariable| |ChineseRemainderToolsForIntegralBases| |Complex| |ComplexCategory&| |ComplexFactorization| |ComplexRootFindingPackage| |ComplexRootPackage| |ConstantLODE| |ContinuedFraction| |CycleIndicators| |CyclotomicPolynomialPackage| |DecimalExpansion| |DifferentialSparseMultivariatePolynomial| |DirichletRing| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DoubleFloat| |EigenPackage| |ElementaryFunctionLODESolver| |ElementaryFunctionSign| |Equation| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |Factored| |FactoredFunctionUtilities| |FactoredFunctions| |FactoredFunctions2| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |Field&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldSquareFreeDecomposition| |Float| |Fraction| |FullPartialFractionExpansion| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaussianFactorizationPackage| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralUnivariatePowerSeries| |GeneralizedMultivariateFactorize| |GosperSummationMethod| |GroebnerFactorizationPackage| |GroebnerSolve| |Guess| |HexadecimalExpansion| |HomogeneousDistributedMultivariatePolynomial| |IdealDecompositionPackage| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerMultFact| |InnerNumericEigenPackage| |InnerPrimeField| |Integer| |IntegerFactorizationPackage| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegrationResultToFunction| |InverseLaplaceTransform| |Kovacic| |LinearOrdinaryDifferentialOperatorFactorizer| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineComplex| |MachineFloat| |MachineInteger| |ModMonic| |ModularField| |MonomialExtensionTools| |MultFiniteFactorize| |MultivariateFactorize| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NumberFieldIntegralBasis| |NumericComplexEigenPackage| |NumericRealEigenPackage| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |ParametricLinearEquations| |PartialFraction| |PartialFractionPackage| |Pi| |PlaneAlgebraicCurvePlot| |PointsOfFiniteOrder| |Polynomial| |PolynomialCategory&| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialRoots| |PolynomialSetUtilitiesPackage| |PolynomialSolveByFormulas| |PolynomialSquareFree| |PrimeField| |PrimitiveRatDE| |PrimitiveRatRicDE| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |QuasiAlgebraicSet| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RationalFactorize| |RationalFunctionFactor| |RationalFunctionFactorizer| |RationalFunctionSign| |RationalRicDE| |RealClosure| |RealZeroPackage| |RomanNumeral| |RootsFindingPackage| |SAERationalFunctionAlgFactor| |SequentialDifferentialPolynomial| |SimpleAlgebraicExtension| |SimpleAlgebraicExtensionAlgFactor| |SingleInteger| |SparseMultivariatePolynomial| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SturmHabichtPackage| |SupFractionFactorizer| |SystemSolvePackage| |TransSolvePackage| |TranscendentalIntegration| |TranscendentalManipulations| |TwoFactorize| |UniqueFactorizationDomain&| |UnivariateFactorize| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |WildFunctionFieldIntegralBasis|)
 (|ComplexCategory&| |Integer| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate|)
 (|ChangeOfVariable| |PolynomialRoots| |TranscendentalManipulations|)
 (|FunctionSpaceUnivariatePolynomialFactor| |Integer| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |RationalFunctionFactor| |UnivariatePolynomialCategory&|)
 (|InnerMultFact| |MultFiniteFactorize| |MultivariateSquareFree| |PolynomialGcdPackage|)
+(|PseudoAlgebraicClosureOfAlgExtOfRationalNumber|)
+(|FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfRationalNumber|)
 (|BinaryFile| |ParametricLinearEquations| |TextFile|)
-(|BinaryFile| |File| |FortranOutputStackPackage| |FortranPackage| |FortranTemplate| |KeyedAccessFile| |Library| |NagEigenPackage| |NagIntegrationPackage| |NagLinearEquationSolvingPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagRootFindingPackage| |ParametricLinearEquations| |TextFile|)
+(|BinaryFile| |Export3D| |File| |FortranOutputStackPackage| |FortranPackage| |FortranTemplate| |GnuDraw| |KeyedAccessFile| |Library| |NagEigenPackage| |NagIntegrationPackage| |NagLinearEquationSolvingPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagRootFindingPackage| |ParametricLinearEquations| |TextFile|)
+(|FractionFreeFastGaussianFractions|)
 (|AlgebraicIntegrate| |FindOrderFinite| |FiniteDivisorFunctions2| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |ReducedDivisor|)
 (|FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension|)
 (|InnerFiniteField|)
 (|FiniteField| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension|)
+(|PseudoAlgebraicClosureOfFiniteField| |RootsFindingPackage|)
 (|FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial|)
 (|FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension|)
 (|FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldExtension| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldPolynomialPackage2| |MultFiniteFactorize|)
 (|SparseUnivariatePolynomial|)
+(|FiniteFieldFactorizationWithSizeParseBySideEffect|)
 (|DirectProductFunctions2| |InnerCommonDenominator| |ListFunctions2| |MatrixLinearAlgebraFunctions| |OneDimensionalArrayFunctions2| |PrimitiveArrayFunctions2| |VectorFunctions2|)
 (|OneDimensionalArrayAggregate&|)
 (|GaloisGroupUtilities|)
-(|AlgebraicNumber| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |Asp19| |AttributeButtons| |BalancedPAdicRational| |BinaryExpansion| |BrillhartTests| |ComplexCategory&| |DecimalExpansion| |DoubleFloat| |DrawComplex| |DrawNumericHack| |DrawOption| |DrawOptionFunctions0| |ElementaryFunctionSign| |ExpertSystemToolsPackage| |ExponentialExpansion| |Factored| |Float| |FortranExpression| |Fraction| |GraphImage| |HexadecimalExpansion| |InnerAlgebraicNumber| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |Integer| |IntegerNumberSystem&| |MachineComplex| |MachineFloat| |MachineInteger| |NumberFormats| |Numeric| |NumericTubePlot| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |OpenMathServerPackage| |PAdicRational| |PAdicRationalConstructor| |Pi| |PlaneAlgebraicCurvePlot| |QuotientFieldCategory&| |RadixExpansion| |RandomFloatDistributions| |RealNumberSystem&| |RealSolvePackage| |RomanNumeral| |RoutinesTable| |SingleInteger| |SparseUnivariateLaurentSeries| |ThreeDimensionalViewport| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TwoDimensionalViewport| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |ViewDefaultsPackage| |d01AgentsPackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03eefAnnaType| |d03fafAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AlgebraicNumber| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |Asp19| |AttributeButtons| |BalancedPAdicRational| |BinaryExpansion| |BrillhartTests| |ComplexCategory&| |DecimalExpansion| |DoubleFloat| |DoubleFloatSpecialFunctions| |DrawComplex| |DrawNumericHack| |DrawOption| |DrawOptionFunctions0| |ElementaryFunctionSign| |ExpertSystemToolsPackage| |ExponentialExpansion| |Factored| |Float| |FortranExpression| |Fraction| |GraphImage| |HexadecimalExpansion| |InnerAlgebraicNumber| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |Integer| |IntegerNumberSystem&| |Interval| |MachineComplex| |MachineFloat| |MachineInteger| |NumberFormats| |Numeric| |NumericTubePlot| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |OpenMathServerPackage| |PAdicRational| |PAdicRationalConstructor| |Pi| |PlaneAlgebraicCurvePlot| |QuotientFieldCategory&| |RadixExpansion| |RandomFloatDistributions| |RealNumberSystem&| |RealSolvePackage| |RomanNumeral| |RoutinesTable| |SingleInteger| |SparseUnivariateLaurentSeries| |ThreeDimensionalViewport| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TwoDimensionalViewport| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |ViewDefaultsPackage| |d01AgentsPackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03eefAnnaType| |d03fafAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|RealSolvePackage|)
 (|Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |FortranCodePackage1| |FortranProgram|)
 (|Asp1| |Asp10| |Asp19| |Asp20| |Asp24| |Asp31| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp80| |Asp9|)
@@ -148,7 +165,9 @@
 (|Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |FortranPackage| |FortranType| |SimpleFortranProgram| |SymbolTable|)
 (|Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |FortranCode| |FortranPackage| |SymbolTable| |TheSymbolTable|)
 (|FourierSeries|)
-(|AbelianMonoidRing&| |AlgFactor| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedFunctionSpace&| |Asp1| |Asp10| |Asp19| |Asp20| |Asp24| |Asp31| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp80| |Asp9| |BalancedPAdicRational| |BinaryExpansion| |BoundIntegerRoots| |ChangeOfVariable| |CoerceVectorMatrixPackage| |CombinatorialFunction| |Complex| |ComplexCategory&| |ComplexFactorization| |ComplexRootFindingPackage| |ContinuedFraction| |CycleIndicators| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DivisionRing&| |DoubleFloat| |DoubleResultantPackage| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EvaluateCycleIndicators| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSpaceODESolver| |ExpressionToUnivariatePowerSeries| |Factored| |FiniteDivisor| |FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranExpression| |FourierSeries| |Fraction| |FractionFunctions2| |FractionalIdeal| |FullPartialFractionExpansion| |FullyRetractableTo&| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GeneralDistributedMultivariatePolynomial| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |InfiniteProductFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerModularGcd| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |Integer| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegrationResult| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |InverseLaplaceTransform| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LieSquareMatrix| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearPolynomialEquationByFractions| |LinearSystemPolynomialPackage| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineComplex| |MachineFloat| |MachineInteger| |ModMonic| |ModularField| |MonogenicAlgebra&| |MonomialExtensionTools| |MultipleMap| |MultivariatePolynomial| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonLinearSolvePackage| |NormalizationPackage| |NumberTheoreticPolynomialFunctions| |Numeric| |ODEIntegration| |Octonion| |OctonionCategory&| |OnePointCompletion| |OrderedCompletion| |OrderedDirectProduct| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OrthogonalPolynomialFunctions| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PadeApproximantPackage| |PadeApproximants| |ParametricLinearEquations| |PartialFraction| |PartialFractionPackage| |PatternMatchIntegration| |Pi| |PiCoercions| |PlaneAlgebraicCurvePlot| |Plot| |Plot3D| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |Polynomial| |PolynomialAN2Expression| |PolynomialCategory&| |PolynomialCategoryQuotientFunctions| |PolynomialFactorizationByRecursionUnivariate| |PolynomialNumberTheoryFunctions| |PolynomialRing| |PolynomialRoots| |PolynomialSolveByFormulas| |PowerSeriesCategory&| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveRatDE| |PrimitiveRatRicDE| |PureAlgebraicIntegration| |PureAlgebraicLODE| |QuasiAlgebraicSet2| |Quaternion| |QuaternionCategory&| |QuotientFieldCategory&| |RadicalCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RadixUtilities| |RandomIntegerDistributions| |RationalFactorize| |RationalFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionFactor| |RationalFunctionFactorizer| |RationalFunctionIntegration| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalFunctionSum| |RationalIntegration| |RationalLODE| |RationalRetractions| |RationalRicDE| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealSolvePackage| |RealZeroPackage| |RealZeroPackageQ| |RecursivePolynomialCategory&| |ReducedDivisor| |RetractSolvePackage| |RightOpenIntervalRootCharacterization| |RomanNumeral| |SequentialDifferentialPolynomial| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SquareMatrix| |SquareMatrixCategory&| |StreamInfiniteProduct| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |StructuralConstantsPackage| |SturmHabichtPackage| |SupFractionFactorizer| |SymmetricPolynomial| |SystemSolvePackage| |TangentExpansions| |TaylorSeries| |ToolsForSign| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |TransSolvePackageService| |TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalRischDE| |TranscendentalRischDESystem| |TwoDimensionalPlotClipping| |UTSodetools| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesFunctions2| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCategory&| |XExponentialPackage| |XPBWPolynomial| |ZeroDimensionalSolvePackage| |d01TransformFunctionType| |d01WeightsPackage| |d01aqfAnnaType| |d02AgentsPackage| |e04AgentsPackage| |e04ucfAnnaType|)
+(|AbelianMonoidRing&| |AlgFactor| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedFunctionSpace&| |Asp1| |Asp10| |Asp19| |Asp20| |Asp24| |Asp31| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp80| |Asp9| |BalancedPAdicRational| |BinaryExpansion| |BoundIntegerRoots| |ChangeOfVariable| |CoerceVectorMatrixPackage| |CombinatorialFunction| |Complex| |ComplexCategory&| |ComplexFactorization| |ComplexRootFindingPackage| |ContinuedFraction| |CycleIndicators| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DivisionRing&| |DoubleFloat| |DoubleFloatSpecialFunctions| |DoubleResultantPackage| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EvaluateCycleIndicators| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSpaceODESolver| |ExpressionToUnivariatePowerSeries| |Factored| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |FiniteDivisor| |FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranExpression| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionFunctions2| |FractionalIdeal| |FullPartialFractionExpansion| |FullyRetractableTo&| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GeneralDistributedMultivariatePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |Guess| |GuessInteger| |GuessPolynomial| |GuessUnivariatePolynomial| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |InfiniteProductFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerModularGcd| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |Integer| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegrationResult| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |Interval| |InverseLaplaceTransform| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LieSquareMatrix| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearPolynomialEquationByFractions| |LinearSystemPolynomialPackage| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineComplex| |MachineFloat| |MachineInteger| |ModMonic| |ModularField| |MonogenicAlgebra&| |MonomialExtensionTools| |MultipleMap| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonLinearSolvePackage| |NormalizationPackage| |NumberTheoreticPolynomialFunctions| |Numeric| |ODEIntegration| |Octonion| |OctonionCategory&| |OnePointCompletion| |OrderedCompletion| |OrderedDirectProduct| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OrthogonalPolynomialFunctions| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PadeApproximantPackage| |PadeApproximants| |ParametricLinearEquations| |PartialFraction| |PartialFractionPackage| |PatternMatchIntegration| |Pi| |PiCoercions| |PlaneAlgebraicCurvePlot| |Plot| |Plot3D| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |Polynomial| |PolynomialAN2Expression| |PolynomialCategory&| |PolynomialCategoryQuotientFunctions| |PolynomialFactorizationByRecursionUnivariate| |PolynomialNumberTheoryFunctions| |PolynomialRing| |PolynomialRoots| |PolynomialSolveByFormulas| |PowerSeriesCategory&| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveRatDE| |PrimitiveRatRicDE| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PureAlgebraicIntegration| |PureAlgebraicLODE| |QuasiAlgebraicSet2| |Quaternion| |QuaternionCategory&| |QuotientFieldCategory&| |RadicalCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RadixUtilities| |RationalFactorize| |RationalFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionFactor| |RationalFunctionFactorizer| |RationalFunctionIntegration| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalFunctionSum| |RationalIntegration| |RationalInterpolation| |RationalLODE| |RationalRetractions| |RationalRicDE| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealSolvePackage| |RealZeroPackage| |RealZeroPackageQ| |RecurrenceOperator| |RecursivePolynomialCategory&| |ReducedDivisor| |RetractSolvePackage| |RightOpenIntervalRootCharacterization| |RomanNumeral| |SequentialDifferentialPolynomial| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SquareMatrix| |SquareMatrixCategory&| |StreamInfiniteProduct| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |StructuralConstantsPackage| |SturmHabichtPackage| |SupFractionFactorizer| |SymmetricPolynomial| |SystemSolvePackage| |TangentExpansions| |TaylorSeries| |TaylorSolve| |ToolsForSign| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |TransSolvePackageService| |TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalRischDE| |TranscendentalRischDESystem| |TwoDimensionalPlotClipping| |UTSodetools| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesFunctions2| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |XExponentialPackage| |XPBWPolynomial| |ZeroDimensionalSolvePackage| |d01TransformFunctionType| |d01WeightsPackage| |d01aqfAnnaType| |d02AgentsPackage| |e04AgentsPackage| |e04ucfAnnaType|)
+(|FractionFreeFastGaussianFractions| |Guess|)
+(|Guess|)
 (|FiniteDivisor| |FiniteDivisorFunctions2| |FractionalIdealFunctions2| |FramedModule| |HyperellipticFiniteDivisor| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational|)
 (|FiniteDivisorFunctions2|)
 (|FiniteDivisor|)
@@ -162,7 +181,7 @@
 (|AttachPredicates| |PatternMatchIntegration|)
 (|FunctionSpaceIntegration|)
 (|ElementaryFunctionSign| |ExpressionFunctions2| |InnerTrigonometricManipulations|)
-(|ElementaryFunctionDefiniteIntegration| |GeneralUnivariatePowerSeries| |LaplaceTransform| |ODEIntegration| |UnivariateLaurentSeriesConstructor| |UnivariatePuiseuxSeriesConstructor| |UnivariateTaylorSeries|)
+(|ElementaryFunctionDefiniteIntegration| |GeneralUnivariatePowerSeries| |LaplaceTransform| |ODEIntegration| |UnivariateLaurentSeriesConstructor| |UnivariatePuiseuxSeriesConstructor| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero|)
 (|ElementaryFunctionLODESolver| |ElementaryIntegration| |ElementaryRischDE|)
 (|FunctionSpaceToExponentialExpansion|)
 (|AlgebraicIntegrate| |ConstantLODE| |ElementaryFunctionLODESolver| |IntegrationResultToFunction|)
@@ -175,18 +194,23 @@
 (|MultivariateFactorize| |NumericRealEigenPackage|)
 (|DistributedMultivariatePolynomial| |HomogeneousDistributedMultivariatePolynomial|)
 (|GaloisGroupFactorizer| |PAdicWildFunctionFieldIntegralBasis| |UnivariateFactorize|)
+(|PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField|)
 (|PolynomialCategory&|)
 (|LexTriangularPackage| |PolynomialSetUtilitiesPackage| |QuasiComponentPackage| |RegularSetDecompositionPackage| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage|)
 (|SparseTable|)
 (|PolynomialSetUtilitiesPackage| |WuWenTsunTriangularSet|)
-(|GroebnerSolve| |MPolyCatPolyFactorizer| |SystemSolvePackage|)
+(|GroebnerSolve| |Guess| |MPolyCatPolyFactorizer| |SystemSolvePackage|)
 (|PureAlgebraicIntegration|)
 (|FunctionSpaceSum| |RationalFunctionSum|)
-(|TopLevelDrawFunctionsForPoints| |TwoDimensionalViewport| |ViewportPackage|)
+(|GnuDraw| |TopLevelDrawFunctionsForPoints| |TwoDimensionalViewport| |ViewportPackage|)
 (|PlotTools| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions|)
 (|Permanent|)
-(|GroebnerFactorizationPackage| |GroebnerPackage| |GroebnerSolve| |LinGroebnerPackage| |ParametricLinearEquations| |PolynomialIdeals| |QuasiAlgebraicSet|)
-(|FGLMIfCanPackage| |GroebnerSolve| |IdealDecompositionPackage| |LinGroebnerPackage| |ParametricLinearEquations| |PolynomialIdeals| |QuasiAlgebraicSet| |QuasiAlgebraicSet2| |ResidueRing|)
+(|GroebnerFactorizationPackage| |GroebnerPackage| |GroebnerSolve| |LinGroebnerPackage| |PolynomialIdeals| |QuasiAlgebraicSet|)
+(|FGLMIfCanPackage| |GeneralPackageForAlgebraicFunctionField| |GroebnerSolve| |IdealDecompositionPackage| |InterfaceGroebnerPackage| |LinGroebnerPackage| |PolynomialIdeals| |QuasiAlgebraicSet| |QuasiAlgebraicSet2| |ResidueRing|)
+(|GuessAlgebraicNumber| |GuessFinite| |GuessInteger| |GuessPolynomial| |GuessUnivariatePolynomial|)
+(|GuessFinite|)
+(|Guess| |GuessOptionFunctions0|)
+(|Guess|)
 (|FreeNilpotentLie|)
 (|EqTable| |StringTable| |TabulatedComputationPackage|)
 (|Integer|)
@@ -205,10 +229,13 @@
 (|IndexedTwoDimensionalArray| |IndexedVector| |OneDimensionalArray|)
 (|String|)
 (|IndexedMatrix| |Vector|)
+(|PackageForAlgebraicFunctionField|)
 (|InfiniteTupleFunctions2| |InfiniteTupleFunctions3|)
+(|InfClsPt| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField|)
+(|PackageForAlgebraicFunctionFieldOverFiniteField|)
 (|SAERationalFunctionAlgFactor| |SimpleAlgebraicExtensionAlgFactor|)
 (|AlgebraicNumber|)
-(|AlgebraicFunctionField| |AlgebraicIntegrate| |ElementaryFunctionStructurePackage| |FractionalIdeal| |FunctionFieldCategory&| |InnerMatrixQuotientFieldFunctions| |PrimitiveRatDE| |RadicalFunctionField| |RationalLODE|)
+(|AlgebraicFunctionField| |AlgebraicIntegrate| |ElementaryFunctionStructurePackage| |FractionFreeFastGaussian| |FractionalIdeal| |FunctionFieldCategory&| |InnerMatrixQuotientFieldFunctions| |PrimitiveRatDE| |RadicalFunctionField| |RationalLODE|)
 (|FreeAbelianGroup| |FreeAbelianMonoid|)
 (|IndexedMatrix| |IndexedTwoDimensionalArray| |Matrix| |TwoDimensionalArray|)
 (|InnerMatrixQuotientFieldFunctions| |MatrixLinearAlgebraFunctions|)
@@ -223,17 +250,17 @@
 (|InnerFiniteField| |PrimeField|)
 (|SparseUnivariateLaurentSeries| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries|)
 (|Table|)
-(|SparseMultivariateTaylorSeries| |UnivariateTaylorSeries|)
+(|SparseMultivariateTaylorSeries| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero|)
 (|ComplexTrigonometricManipulations| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |TrigonometricManipulations|)
-(|AssociationList| |BalancedPAdicRational| |BasicOperatorFunctions1| |BinaryExpansion| |Bits| |Boolean| |CharacterClass| |CommonOperators| |Complex| |ComplexCategory&| |DataList| |DecimalExpansion| |DifferentialSparseMultivariatePolynomial| |DistributedMultivariatePolynomial| |DoubleFloat| |EqTable| |ExponentialExpansion| |Expression| |Factored| |FlexibleArray| |Float| |FortranPackage| |FortranProgram| |Fraction| |FunctionSpace&| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |HashTable| |HexadecimalExpansion| |HomogeneousDistributedMultivariatePolynomial| |IndexedBits| |IndexedFlexibleArray| |IndexedList| |IndexedOneDimensionalArray| |IndexedString| |IndexedVector| |InnerTable| |InputFormFunctions1| |Integer| |IntegerNumberSystem&| |Kernel| |KeyedAccessFile| |Library| |LiouvillianFunction| |List| |ListMultiDictionary| |MachineComplex| |MachineInteger| |MakeBinaryCompiledFunction| |MakeFloatCompiledFunction| |MakeFunction| |MakeUnaryCompiledFunction| |Matrix| |ModMonic| |Multiset| |MultivariatePolynomial| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OpenMathPackage| |OrderedVariableList| |OrderlyDifferentialPolynomial| |PAdicRational| |PAdicRationalConstructor| |Pi| |Point| |Polynomial| |PolynomialCategory&| |PrimitiveArray| |Quaternion| |QuaternionCategory&| |QuotientFieldCategory&| |RadixExpansion| |RectangularMatrix| |RecursivePolynomialCategory&| |RegularChain| |RegularTriangularSet| |Result| |RomanNumeral| |RoutinesTable| |SequentialDifferentialPolynomial| |Set| |SingleInteger| |SparseMultivariatePolynomial| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SquareFreeRegularTriangularSet| |SquareMatrix| |Stream| |String| |StringTable| |Symbol| |SymbolTable| |Table| |TemplateUtilities| |TopLevelDrawFunctions| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |Vector| |WuWenTsunTriangularSet|)
+(|AssociationList| |BalancedPAdicRational| |BasicOperatorFunctions1| |BinaryExpansion| |Bits| |Boolean| |CharacterClass| |CommonOperators| |Complex| |ComplexCategory&| |ComplexDoubleFloatVector| |DataList| |DecimalExpansion| |DifferentialSparseMultivariatePolynomial| |DistributedMultivariatePolynomial| |DoubleFloat| |DoubleFloatVector| |EqTable| |ExponentialExpansion| |Export3D| |Expression| |Factored| |FlexibleArray| |Float| |FortranPackage| |FortranProgram| |Fraction| |FunctionSpace&| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GnuDraw| |HashTable| |HexadecimalExpansion| |HomogeneousDistributedMultivariatePolynomial| |IndexedBits| |IndexedFlexibleArray| |IndexedList| |IndexedOneDimensionalArray| |IndexedString| |IndexedVector| |InnerTable| |InputFormFunctions1| |Integer| |IntegerNumberSystem&| |Kernel| |KeyedAccessFile| |Library| |LiouvillianFunction| |List| |ListMultiDictionary| |MachineComplex| |MachineInteger| |MakeBinaryCompiledFunction| |MakeFloatCompiledFunction| |MakeFunction| |MakeUnaryCompiledFunction| |Matrix| |ModMonic| |Multiset| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OpenMathPackage| |OrderedVariableList| |OrderlyDifferentialPolynomial| |PAdicRational| |PAdicRationalConstructor| |Pi| |Point| |Polynomial| |PolynomialCategory&| |PrimitiveArray| |Quaternion| |QuaternionCategory&| |QuotientFieldCategory&| |RadixExpansion| |RectangularMatrix| |RecursivePolynomialCategory&| |RegularChain| |RegularTriangularSet| |Result| |RomanNumeral| |RoutinesTable| |SequentialDifferentialPolynomial| |Set| |SingleInteger| |SparseMultivariatePolynomial| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SquareFreeRegularTriangularSet| |SquareMatrix| |Stream| |String| |StringTable| |Symbol| |SymbolTable| |Table| |TemplateUtilities| |TopLevelDrawFunctions| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |Vector| |WuWenTsunTriangularSet|)
 (|FunctionSpace&|)
-(|AbelianGroup&| |AbelianMonoidRing&| |AlgFactor| |Algebra&| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |ApplyRules| |ArrayStack| |Asp10| |Asp19| |Asp27| |Asp28| |Asp30| |Asp31| |Asp34| |Asp35| |Asp55| |Asp73| |Asp74| |Asp77| |Asp8| |Asp80| |Asp9| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BezoutMatrix| |BinaryExpansion| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |Boolean| |BoundIntegerRoots| |BrillhartTests| |CardinalNumber| |CartesianTensor| |ChangeOfVariable| |Character| |CharacterClass| |CharacteristicPolynomialPackage| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |Complex| |ComplexCategory&| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexRootFindingPackage| |ComplexRootPackage| |ContinuedFraction| |CoordinateSystems| |CycleIndicators| |CyclotomicPolynomialPackage| |DataList| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DiscreteLogarithmPackage| |DisplayPackage| |DistributedMultivariatePolynomial| |DivisionRing&| |DoubleFloat| |DoubleFloatSpecialFunctions| |DrawComplex| |EigenPackage| |ElementaryFunction| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EllipticFunctionsUnivariateTaylorSeries| |Equation| |EuclideanDomain&| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |ExtensibleLinearAggregate&| |Factored| |FactoredFunctions| |FactoredFunctions2| |FactoringUtilities| |FiniteAbelianMonoidRing&| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteLinearAggregate&| |FiniteLinearAggregateFunctions2| |FiniteLinearAggregateSort| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FloatingPointSystem&| |FortranCode| |FortranExpression| |FortranProgram| |FortranTemplate| |FourierSeries| |Fraction| |FractionalIdeal| |FractionalIdealFunctions2| |FramedAlgebra&| |FramedModule| |FramedNonAssociativeAlgebra&| |FramedNonAssociativeAlgebraFunctions2| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FullyRetractableTo&| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GaussianFactorizationPackage| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralModulePolynomial| |GeneralPolynomialGcdPackage| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GosperSummationMethod| |GraphImage| |GraphicsDefaults| |GrayCode| |GroebnerInternalPackage| |GroebnerPackage| |GroebnerSolve| |Group&| |HallBasis| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperbolicFunctionCategory&| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfiniteProductCharacteristicZero| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySign| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |Integer| |IntegerBits| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerMod| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRetractions| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegralBasisTools| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InternalRationalUnivariateRepresentationPackage| |InverseLaplaceTransform| |IrrRepSymNatPackage| |KeyedAccessFile| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LazyStreamAggregate&| |LeadingCoefDetermination| |LeftAlgebra&| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorsOps| |LinearSystemMatrixPackage| |LinearSystemPolynomialPackage| |LiouvillianFunction| |List| |ListAggregate&| |ListMonoidOps| |ListToMap| |LocalAlgebra| |Localize| |LyndonWord| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineComplex| |MachineFloat| |MachineInteger| |MakeFloatCompiledFunction| |MappingPackage1| |Matrix| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |MeshCreationRoutinesForThreeDimensions| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModularRing| |Module&| |ModuleOperator| |MoebiusTransform| |MonogenicAlgebra&| |MonoidRing| |MonomialExtensionTools| |MultFiniteFactorize| |MultiVariableCalculusFunctions| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |NPCoef| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonAssociativeRing&| |NonLinearFirstOrderODESolver| |NonNegativeInteger| |NumberFieldIntegralBasis| |NumberFormats| |NumberTheoreticPolynomialFunctions| |NumericContinuedFraction| |NumericTubePlot| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODEIntegration| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |OpenMathDevice| |OpenMathError| |OpenMathServerPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedRing&| |OrderedVariableList| |OrderingFunctions| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OrthogonalPolynomialFunctions| |OutputForm| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |Palette| |ParadoxicalCombinatorsForStreams| |ParametricLinearEquations| |PartialFraction| |Partition| |PartitionsAndPermutations| |Pattern| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchPolynomialCategory| |PendantTree| |Permanent| |Permutation| |PermutationGroup| |PermutationGroupExamples| |Pi| |PiCoercions| |PlaneAlgebraicCurvePlot| |Plot| |Plot3D| |PoincareBirkhoffWittLyndonBasis| |Point| |PointFunctions2| |PointPackage| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |Polynomial| |PolynomialCategory&| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialNumberTheoryFunctions| |PolynomialRing| |PolynomialRoots| |PolynomialSolveByFormulas| |PowerSeriesCategory&| |PowerSeriesLimitPackage| |PrecomputedAssociatedEquations| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |QuadraticForm| |Quaternion| |QuaternionCategory&| |QuotientFieldCategory&| |RadicalCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RadixUtilities| |RandomDistributions| |RandomFloatDistributions| |RandomIntegerDistributions| |RandomNumberSource| |RationalFactorize| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalFunctionSum| |RationalLODE| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealSolvePackage| |RealZeroPackage| |RealZeroPackageQ| |RectangularMatrix| |RectangularMatrixCategory&| |RectangularMatrixCategoryFunctions2| |RecursivePolynomialCategory&| |ReduceLODE| |ReductionOfOrder| |RegularTriangularSet| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RightOpenIntervalRootCharacterization| |Ring&| |RomanNumeral| |RoutinesTable| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentFunctions2| |SequentialDifferentialPolynomial| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SortPackage| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingTree| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |Stream| |StreamAggregate&| |StreamInfiniteProduct| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringAggregate&| |StructuralConstantsPackage| |SturmHabichtPackage| |SubSpace| |Symbol| |SymmetricFunctions| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Tableau| |TableauxBumpers| |TangentExpansions| |TaylorSeries| |TemplateUtilities| |TexFormat| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ToolsForSign| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TransSolvePackage| |TransSolvePackageService| |TranscendentalFunctionCategory&| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDE| |TranscendentalRischDESystem| |Tree| |TriangularMatrixOperations| |TriangularSetCategory&| |TrigonometricManipulations| |TubePlotTools| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |UTSodetools| |UnaryRecursiveAggregate&| |UnivariateFactorize| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariateLaurentSeriesFunctions2| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategoryOps| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesODESolver| |UniversalSegment| |Vector| |VectorCategory&| |ViewDefaultsPackage| |ViewportPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |XDistributedPolynomial| |XExponentialPackage| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AbelianGroup&| |AbelianMonoidRing&| |AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgFactor| |Algebra&| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |ApplyRules| |ArrayStack| |Asp10| |Asp19| |Asp27| |Asp28| |Asp30| |Asp31| |Asp34| |Asp35| |Asp55| |Asp73| |Asp74| |Asp77| |Asp8| |Asp80| |Asp9| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |AxiomServer| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |Bezier| |BezoutMatrix| |BinaryExpansion| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlowUpPackage| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |BoundIntegerRoots| |BrillhartTests| |CardinalNumber| |CartesianTensor| |ChangeOfVariable| |Character| |CharacterClass| |CharacteristicPolynomialPackage| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |Color| |CombinatorialFunction| |Commutator| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexRootFindingPackage| |ComplexRootPackage| |ContinuedFraction| |CoordinateSystems| |CycleIndicators| |CyclotomicPolynomialPackage| |DataList| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DisplayPackage| |DistributedMultivariatePolynomial| |DivisionRing&| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DrawComplex| |EigenPackage| |ElementaryFunction| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EllipticFunctionsUnivariateTaylorSeries| |Equation| |EuclideanDomain&| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Export3D| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |ExtensibleLinearAggregate&| |Factored| |FactoredFunctions| |FactoredFunctions2| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |FiniteAbelianMonoidRing&| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSquareFreeDecomposition| |FiniteLinearAggregate&| |FiniteLinearAggregateFunctions2| |FiniteLinearAggregateSort| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FloatingPointSystem&| |FortranCode| |FortranExpression| |FortranProgram| |FortranTemplate| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FractionalIdealFunctions2| |FramedAlgebra&| |FramedModule| |FramedNonAssociativeAlgebra&| |FramedNonAssociativeAlgebraFunctions2| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FullyRetractableTo&| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GaussianFactorizationPackage| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GnuDraw| |GosperSummationMethod| |GraphImage| |GraphicsDefaults| |GrayCode| |GroebnerInternalPackage| |GroebnerPackage| |GroebnerSolve| |Group&| |Guess| |GuessFinite| |GuessFiniteFunctions| |GuessOption| |GuessOptionFunctions0| |HTMLFormat| |HallBasis| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperbolicFunctionCategory&| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfiniteProductCharacteristicZero| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InfinitlyClosePoint| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySign| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |Integer| |IntegerBits| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerMod| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRetractions| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegralBasisTools| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InternalRationalUnivariateRepresentationPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrrRepSymNatPackage| |KeyedAccessFile| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LazyStreamAggregate&| |LeadingCoefDetermination| |LeftAlgebra&| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorsOps| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemPolynomialPackage| |LinesOpPack| |LiouvillianFunction| |List| |ListAggregate&| |ListMonoidOps| |ListToMap| |LocalAlgebra| |LocalParametrizationOfSimplePointPackage| |Localize| |LyndonWord| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineComplex| |MachineFloat| |MachineInteger| |MakeFloatCompiledFunction| |MappingPackage1| |MathMLFormat| |Matrix| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |MeshCreationRoutinesForThreeDimensions| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModularRing| |Module&| |ModuleOperator| |MoebiusTransform| |MonogenicAlgebra&| |MonoidRing| |MonomialExtensionTools| |MultFiniteFactorize| |MultiVariableCalculusFunctions| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NPCoef| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonInterpolation| |NewtonPolygon| |NonAssociativeRing&| |NonLinearFirstOrderODESolver| |NonNegativeInteger| |NottinghamGroup| |NumberFieldIntegralBasis| |NumberFormats| |NumberTheoreticPolynomialFunctions| |NumericContinuedFraction| |NumericTubePlot| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODEIntegration| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |OpenMathDevice| |OpenMathEncoding| |OpenMathError| |OpenMathServerPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedRing&| |OrderedVariableList| |OrderingFunctions| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OrthogonalPolynomialFunctions| |OutputForm| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |Palette| |ParadoxicalCombinatorsForStreams| |ParametricLinearEquations| |ParametrizationPackage| |PartialFraction| |Partition| |PartitionsAndPermutations| |Pattern| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchPolynomialCategory| |PendantTree| |Permanent| |Permutation| |PermutationGroup| |PermutationGroupExamples| |Pi| |PiCoercions| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PoincareBirkhoffWittLyndonBasis| |Point| |PointFunctions2| |PointPackage| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |Polynomial| |PolynomialCategory&| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialNumberTheoryFunctions| |PolynomialPackageForCurve| |PolynomialRing| |PolynomialRoots| |PolynomialSolveByFormulas| |PowerSeriesCategory&| |PowerSeriesLimitPackage| |PrecomputedAssociatedEquations| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |QuadraticForm| |Quaternion| |QuaternionCategory&| |QuotientFieldCategory&| |RadicalCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RadixUtilities| |RandomDistributions| |RandomFloatDistributions| |RandomIntegerDistributions| |RandomNumberSource| |RationalFactorize| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalFunctionSum| |RationalInterpolation| |RationalLODE| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealSolvePackage| |RealZeroPackage| |RealZeroPackageQ| |RectangularMatrix| |RectangularMatrixCategory&| |RectangularMatrixCategoryFunctions2| |RecurrenceOperator| |RecursivePolynomialCategory&| |ReduceLODE| |ReductionOfOrder| |RegularTriangularSet| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RightOpenIntervalRootCharacterization| |Ring&| |RomanNumeral| |RootsFindingPackage| |RoutinesTable| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentFunctions2| |SequentialDifferentialPolynomial| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SortPackage| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingTree| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |Stream| |StreamAggregate&| |StreamInfiniteProduct| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringAggregate&| |StructuralConstantsPackage| |SturmHabichtPackage| |SubSpace| |Symbol| |SymmetricFunctions| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Tableau| |TableauxBumpers| |TangentExpansions| |TaylorSeries| |TaylorSolve| |TemplateUtilities| |TexFormat| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ToolsForSign| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TransSolvePackage| |TransSolvePackageService| |TranscendentalFunctionCategory&| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDE| |TranscendentalRischDESystem| |Tree| |TriangularMatrixOperations| |TriangularSetCategory&| |TrigonometricManipulations| |TubePlotTools| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |UTSodetools| |UnaryRecursiveAggregate&| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariateLaurentSeriesFunctions2| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategoryOps| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesODESolver| |UniversalSegment| |Vector| |VectorCategory&| |ViewDefaultsPackage| |ViewportPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |XDistributedPolynomial| |XExponentialPackage| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|RandomIntegerDistributions|)
-(|ComplexRootFindingPackage| |GaloisGroupUtilities| |IntegerNumberSystem&| |IrrRepSymNatPackage| |MultivariateLifting| |RepresentationPackage1| |SetOfMIntegersInOneToN| |SymmetricGroupCombinatoricFunctions|)
+(|ComplexRootFindingPackage| |GaloisGroupUtilities| |Guess| |IntegerNumberSystem&| |IrrRepSymNatPackage| |MultivariateLifting| |RepresentationPackage1| |SetOfMIntegersInOneToN| |SymmetricGroupCombinatoricFunctions|)
 (|CyclotomicPolynomialPackage| |Factored| |GaussianFactorizationPackage| |IntegerNumberSystem&| |NumberFieldIntegralBasis|)
 (|ElementaryFunctionStructurePackage|)
 (|InnerPrimeField|)
-(|CycleIndicators| |FiniteFieldPolynomialPackage| |PolynomialNumberTheoryFunctions|)
+(|CycleIndicators| |DirichletRing| |FiniteFieldPolynomialPackage| |PolynomialNumberTheoryFunctions|)
 (|ComplexIntegerSolveLinearPolynomialEquation| |GaloisGroupFactorizer| |GaussianFactorizationPackage| |HeuGcd| |InnerMultFact| |IntegerFactorizationPackage| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |MultivariateSquareFree| |PointsOfFiniteOrder| |PointsOfFiniteOrderTools| |PolynomialGcdPackage| |PolynomialNumberTheoryFunctions| |PrimeField| |UnivariateFactorize|)
 (|DoubleFloatSpecialFunctions|)
 (|ComplexRootFindingPackage| |Float| |GaloisGroupFactorizer| |GenExEuclid| |IntegerFactorizationPackage| |IntegerPrimesPackage| |PatternMatchIntegerNumberSystem| |UnivariateFactorize|)
@@ -241,16 +268,19 @@
 (|PAdicWildFunctionFieldIntegralBasis|)
 (|FunctionFieldIntegralBasis| |NumberFieldIntegralBasis| |PAdicWildFunctionFieldIntegralBasis| |WildFunctionFieldIntegralBasis|)
 (|AnnaNumericalIntegrationPackage| |d01AgentsPackage|)
-(|AlgebraicIntegrate| |AlgebraicIntegration| |ElementaryIntegration| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |GenusZeroIntegration| |IntegrationResultFunctions2| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |LaplaceTransform| |PureAlgebraicIntegration| |RationalFunctionIntegration| |RationalIntegration| |TranscendentalIntegration|)
+(|AlgebraicIntegrate| |AlgebraicIntegration| |ElementaryIntegration| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |GenusZeroIntegration| |IntegrationResultFunctions2| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |PureAlgebraicIntegration| |RationalFunctionIntegration| |RationalIntegration| |TranscendentalIntegration|)
 (|ElementaryIntegration| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |GenusZeroIntegration| |IntegrationResultRFToFunction| |PureAlgebraicIntegration| |RationalFunctionIntegration|)
 (|RationalFunctionDefiniteIntegration|)
 (|FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |IntegrationResultRFToFunction|)
 (|ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |IntegrationResultRFToFunction| |LaplaceTransform| |PureAlgebraicIntegration|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis|)
 (|RegularSetDecompositionPackage| |SquareFreeRegularSetDecompositionPackage| |TabulatedComputationPackage|)
 (|RationalUnivariateRepresentationPackage| |ZeroDimensionalSolvePackage|)
+(|GeneralPackageForAlgebraicFunctionField|)
+(|GeneralPackageForAlgebraicFunctionField|)
 (|ElementaryFunctionSign| |TransSolvePackage|)
 (|PAdicWildFunctionFieldIntegralBasis|)
-(|AlgFactor| |AlgebraicFunction| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedFunctionSpace&| |ApplyRules| |CombinatorialFunction| |ComplexTrigonometricManipulations| |DefiniteIntegrationTools| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |Expression| |ExpressionFunctions2| |ExpressionSpace&| |ExpressionSpaceFunctions1| |ExpressionSpaceFunctions2| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |FortranExpression| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceFunctions2| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GenusZeroIntegration| |InnerAlgebraicNumber| |InnerTrigonometricManipulations| |IntegrationResultToFunction| |IntegrationTools| |InverseLaplaceTransform| |KernelFunctions2| |LaplaceTransform| |LiouvillianFunction| |NonLinearFirstOrderODESolver| |ODEIntegration| |PatternMatchFunctionSpace| |PatternMatchIntegration| |PatternMatchKernel| |PointsOfFiniteOrder| |PowerSeriesLimitPackage| |PureAlgebraicIntegration| |RadicalEigenPackage| |RadicalSolvePackage| |RationalFunctionDefiniteIntegration| |RewriteRule| |TransSolvePackage| |TransSolvePackageService| |TranscendentalManipulations| |TrigonometricManipulations| |d01AgentsPackage| |d01WeightsPackage|)
+(|AlgFactor| |AlgebraicFunction| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedFunctionSpace&| |ApplyRules| |CombinatorialFunction| |ComplexTrigonometricManipulations| |DefiniteIntegrationTools| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |Expression| |ExpressionFunctions2| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceFunctions1| |ExpressionSpaceFunctions2| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |FortranExpression| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceFunctions2| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GenusZeroIntegration| |Guess| |InnerAlgebraicNumber| |InnerTrigonometricManipulations| |IntegrationResultToFunction| |IntegrationTools| |InverseLaplaceTransform| |KernelFunctions2| |LaplaceTransform| |LiouvillianFunction| |MyExpression| |NonLinearFirstOrderODESolver| |ODEIntegration| |PatternMatchFunctionSpace| |PatternMatchIntegration| |PatternMatchKernel| |PointsOfFiniteOrder| |PowerSeriesLimitPackage| |PureAlgebraicIntegration| |RadicalEigenPackage| |RadicalSolvePackage| |RationalFunctionDefiniteIntegration| |RecurrenceOperator| |RewriteRule| |TransSolvePackage| |TransSolvePackageService| |TranscendentalManipulations| |TrigonometricManipulations| |d01AgentsPackage| |d01WeightsPackage|)
 (|Expression|)
 (|Library|)
 (|ElementaryFunctionLODESolver|)
@@ -266,18 +296,21 @@
 (|ElementaryFunctionLODESolver|)
 (|LinearOrdinaryDifferentialOperator|)
 (|PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&|)
+(|InterpolateFormsPackage|)
 (|AlgebraGivenByStructuralConstants| |AlgebraicHermiteIntegration| |CliffordAlgebra| |ElementaryFunctionLODESolver| |FramedNonAssociativeAlgebra&| |GosperSummationMethod| |LinearDependence| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |ODETools| |RationalLODE| |StructuralConstantsPackage| |TransSolvePackageService|)
 (|SystemSolvePackage|)
+(|InterpolateFormsPackage| |LinearSystemFromPowerSeriesPackage|)
 (|Expression| |PowerSeriesLimitPackage|)
-(|AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicManipulations| |AlgebraicMultFact| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |Any| |ApplyRules| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttachPredicates| |AttributeButtons| |BagAggregate&| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BinaryExpansion| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BoundIntegerRoots| |CRApackage| |CardinalNumber| |CartesianTensor| |CartesianTensorFunctions2| |Character| |CharacterClass| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |CoerceVectorMatrixPackage| |Collection&| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |Complex| |ComplexCategory&| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexRootFindingPackage| |ComplexRootPackage| |ComplexTrigonometricManipulations| |ConstantLODE| |ContinuedFraction| |CycleIndicators| |CyclotomicPolynomialPackage| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |Dictionary&| |DictionaryOperations&| |DifferentialExtension&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DisplayPackage| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DoubleFloat| |DrawComplex| |DrawOption| |DrawOptionFunctions0| |DrawOptionFunctions1| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EllipticFunctionsUnivariateTaylorSeries| |EqTable| |Equation| |ErrorFunctions| |EuclideanDomain&| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |Evalable&| |EvaluateCycleIndicators| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExpertSystemToolsPackage1| |ExpertSystemToolsPackage2| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSpace&| |ExpressionSpaceFunctions1| |ExpressionSpaceFunctions2| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |ExtAlgBasis| |ExtensibleLinearAggregate&| |FGLMIfCanPackage| |Factored| |FactoredFunctionUtilities| |FactoredFunctions| |FactoredFunctions2| |FactoringUtilities| |Field&| |FiniteAbelianMonoidRing&| |FiniteAlgebraicExtensionField&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldSolveLinearPolynomialEquation| |FiniteLinearAggregateFunctions2| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FiniteSetAggregateFunctions2| |FlexibleArray| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranOutputStackPackage| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |Fraction| |FractionalIdeal| |FramedAlgebra&| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FullyEvalableOver&| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaussianFactorizationPackage| |GcdDomain&| |GenExEuclid| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |GraphImage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |GroebnerSolve| |HallBasis| |HashTable| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexedAggregate&| |IndexedBits| |IndexedDirectProductObject| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerEvalable&| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerMatrixQuotientFieldFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTrigonometricManipulations| |InputForm| |InputFormFunctions1| |Integer| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegrationFunctionsTable| |IntegrationResult| |IntegrationResultFunctions2| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |InternalRationalUnivariateRepresentationPackage| |InverseLaplaceTransform| |IrrRepSymNatPackage| |Kernel| |KernelFunctions2| |KeyedAccessFile| |KeyedDictionary&| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LazardSetSolvingPackage| |LazyStreamAggregate&| |LeadingCoefDetermination| |LexTriangularPackage| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperatorsOps| |LinearPolynomialEquationByFractions| |LinearSystemMatrixPackage| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |LiouvillianFunction| |List| |ListFunctions2| |ListFunctions3| |ListMonoidOps| |ListMultiDictionary| |ListToMap| |LyndonWord| |MPolyCatFunctions2| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeBinaryCompiledFunction| |MakeFloatCompiledFunction| |MakeFunction| |MakeUnaryCompiledFunction| |MappingPackage1| |Matrix| |MatrixCategory&| |MatrixCommonDenominator| |MatrixLinearAlgebraFunctions| |MergeThing| |MeshCreationRoutinesForThreeDimensions| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModuleOperator| |MoebiusTransform| |MonogenicAlgebra&| |MonoidRing| |MonoidRingFunctions2| |MonomialExtensionTools| |MultFiniteFactorize| |MultiVariableCalculusFunctions| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |NAGLinkSupportPackage| |NPCoef| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonLinearFirstOrderODESolver| |NonLinearSolvePackage| |NormRetractPackage| |NormalizationPackage| |NumberFieldIntegralBasis| |NumberFormats| |NumericComplexEigenPackage| |NumericRealEigenPackage| |NumericTubePlot| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODEIntegration| |ODEIntensityFunctionsTable| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OpenMathError| |OpenMathPackage| |OppositeMonogenicLinearOperator| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PadeApproximants| |Palette| |ParadoxicalCombinatorsForStreams| |ParametricLinearEquations| |PartialDifferentialRing&| |PartialFraction| |PartialFractionPackage| |Partition| |PartitionsAndPermutations| |Pattern| |PatternFunctions1| |PatternFunctions2| |PatternMatch| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchPolynomialCategory| |PatternMatchPushDown| |PatternMatchResult| |PatternMatchResultFunctions2| |PatternMatchTools| |PendantTree| |Permutation| |PermutationGroup| |PermutationGroupExamples| |Pi| |PlaneAlgebraicCurvePlot| |Plot| |Plot3D| |PlotTools| |PoincareBirkhoffWittLyndonBasis| |Point| |PointFunctions2| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |PolyGroebner| |Polynomial| |PolynomialCategory&| |PolynomialCategoryQuotientFunctions| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialInterpolation| |PolynomialInterpolationAlgorithms| |PolynomialRing| |PolynomialRoots| |PolynomialSetCategory&| |PolynomialSetUtilitiesPackage| |PolynomialSolveByFormulas| |PolynomialSquareFree| |PowerSeriesLimitPackage| |PrecomputedAssociatedEquations| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |PushVariables| |QuasiAlgebraicSet| |QuasiAlgebraicSet2| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |Queue| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RandomDistributions| |RationalFactorize| |RationalFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionIntegration| |RationalFunctionSign| |RationalIntegration| |RationalLODE| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealSolvePackage| |RealZeroPackage| |RealZeroPackageQ| |RectangularMatrix| |RecursiveAggregate&| |RecursivePolynomialCategory&| |ReductionOfOrder| |Reference| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RetractSolvePackage| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RoutinesTable| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentFunctions2| |SequentialDifferentialPolynomial| |Set| |SetAggregate&| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SimpleFortranProgram| |SingleInteger| |SmithNormalForm| |SortedCache| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |Stack| |Stream| |StreamAggregate&| |StreamFunctions2| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |String| |StringTable| |StructuralConstantsPackage| |SturmHabichtPackage| |SubResultantPackage| |SubSpace| |SubSpaceComponentProperty| |SupFractionFactorizer| |Switch| |Symbol| |SymbolTable| |SymmetricFunctions| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Table| |TableAggregate&| |Tableau| |TableauxBumpers| |TangentExpansions| |TaylorSeries| |TexFormat| |TheSymbolTable| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TransSolvePackage| |TransSolvePackageService| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDESystem| |Tree| |TriangularSetCategory&| |TrigonometricManipulations| |TubePlot| |TubePlotTools| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |UnaryRecursiveAggregate&| |UniqueFactorizationDomain&| |UnivariateFactorize| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCommonDenominator| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePolynomialSquareFree| |UnivariatePowerSeriesCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesODESolver| |UniversalSegment| |UserDefinedPartialOrdering| |UserDefinedVariableOrdering| |Vector| |VectorCategory&| |VectorFunctions2| |ViewDefaultsPackage| |ViewportPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
-(|AlgebraPackage| |Asp19| |Asp55| |ElementaryFunctionSign| |FiniteSetAggregateFunctions2| |FramedNonAssociativeAlgebra&| |GaloisGroupFactorizer| |GenericNonAssociativeAlgebra| |LieSquareMatrix| |MatrixCommonDenominator| |PAdicWildFunctionFieldIntegralBasis| |PermutationGroupExamples| |RealSolvePackage| |ThreeSpace| |TwoDimensionalPlotClipping| |UnivariateTaylorSeriesODESolver|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicManipulations| |AlgebraicMultFact| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |Any| |ApplicationProgramInterface| |ApplyRules| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttachPredicates| |AttributeButtons| |AxiomServer| |BagAggregate&| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |Bezier| |BinaryExpansion| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlowUpPackage| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |BoundIntegerRoots| |CRApackage| |CardinalNumber| |CartesianTensor| |CartesianTensorFunctions2| |Character| |CharacterClass| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |CoerceVectorMatrixPackage| |Collection&| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexRootFindingPackage| |ComplexRootPackage| |ComplexTrigonometricManipulations| |ConstantLODE| |ContinuedFraction| |CycleIndicators| |CyclotomicPolynomialPackage| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |Dictionary&| |DictionaryOperations&| |DifferentialExtension&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DisplayPackage| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatVector| |DrawComplex| |DrawOption| |DrawOptionFunctions0| |DrawOptionFunctions1| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EllipticFunctionsUnivariateTaylorSeries| |EqTable| |Equation| |ErrorFunctions| |EuclideanDomain&| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |Evalable&| |EvaluateCycleIndicators| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExpertSystemToolsPackage1| |ExpertSystemToolsPackage2| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Export3D| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceFunctions1| |ExpressionSpaceFunctions2| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |ExtAlgBasis| |ExtensibleLinearAggregate&| |FGLMIfCanPackage| |Factored| |FactoredFunctionUtilities| |FactoredFunctions| |FactoredFunctions2| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |Field&| |FiniteAbelianMonoidRing&| |FiniteAlgebraicExtensionField&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteLinearAggregateFunctions2| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FiniteSetAggregateFunctions2| |FlexibleArray| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranOutputStackPackage| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FramedAlgebra&| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FullyEvalableOver&| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaussianFactorizationPackage| |GcdDomain&| |GenExEuclid| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GnuDraw| |GosperSummationMethod| |GraphImage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |GroebnerSolve| |Guess| |GuessAlgebraicNumber| |GuessFinite| |GuessInteger| |GuessOption| |GuessOptionFunctions0| |GuessPolynomial| |GuessUnivariatePolynomial| |HTMLFormat| |HallBasis| |HashTable| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexedAggregate&| |IndexedBits| |IndexedDirectProductObject| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerEvalable&| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerMatrixQuotientFieldFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTrigonometricManipulations| |InputForm| |InputFormFunctions1| |Integer| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegrationFunctionsTable| |IntegrationResult| |IntegrationResultFunctions2| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |InterfaceGroebnerPackage| |InternalRationalUnivariateRepresentationPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrrRepSymNatPackage| |Kernel| |KernelFunctions2| |KeyedAccessFile| |KeyedDictionary&| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LazardSetSolvingPackage| |LazyStreamAggregate&| |LeadingCoefDetermination| |LexTriangularPackage| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperatorsOps| |LinearPolynomialEquationByFractions| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |LinesOpPack| |LiouvillianFunction| |List| |ListFunctions2| |ListFunctions3| |ListMonoidOps| |ListMultiDictionary| |ListToMap| |LocalParametrizationOfSimplePointPackage| |LyndonWord| |MPolyCatFunctions2| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeBinaryCompiledFunction| |MakeFloatCompiledFunction| |MakeFunction| |MakeUnaryCompiledFunction| |MappingPackage1| |MathMLFormat| |Matrix| |MatrixCategory&| |MatrixCommonDenominator| |MatrixLinearAlgebraFunctions| |MergeThing| |MeshCreationRoutinesForThreeDimensions| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModuleOperator| |MoebiusTransform| |MonogenicAlgebra&| |MonoidRing| |MonoidRingFunctions2| |MonomialExtensionTools| |MultFiniteFactorize| |MultiVariableCalculusFunctions| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NPCoef| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonInterpolation| |NewtonPolygon| |NonLinearFirstOrderODESolver| |NonLinearSolvePackage| |NormRetractPackage| |NormalizationPackage| |NumberFieldIntegralBasis| |NumberFormats| |NumericComplexEigenPackage| |NumericRealEigenPackage| |NumericTubePlot| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODEIntegration| |ODEIntensityFunctionsTable| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OpenMathError| |OpenMathPackage| |OppositeMonogenicLinearOperator| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |PadeApproximants| |Palette| |ParadoxicalCombinatorsForStreams| |ParametricLinearEquations| |ParametrizationPackage| |PartialDifferentialRing&| |PartialFraction| |PartialFractionPackage| |Partition| |PartitionsAndPermutations| |Pattern| |PatternFunctions1| |PatternFunctions2| |PatternMatch| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchPolynomialCategory| |PatternMatchPushDown| |PatternMatchResult| |PatternMatchResultFunctions2| |PatternMatchTools| |PendantTree| |Permutation| |PermutationGroup| |PermutationGroupExamples| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PlotTools| |PoincareBirkhoffWittLyndonBasis| |Point| |PointFunctions2| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |PolyGroebner| |Polynomial| |PolynomialCategory&| |PolynomialCategoryQuotientFunctions| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialInterpolation| |PolynomialInterpolationAlgorithms| |PolynomialPackageForCurve| |PolynomialRing| |PolynomialRoots| |PolynomialSetCategory&| |PolynomialSetUtilitiesPackage| |PolynomialSolveByFormulas| |PolynomialSquareFree| |PowerSeriesLimitPackage| |PrecomputedAssociatedEquations| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |PushVariables| |QuasiAlgebraicSet| |QuasiAlgebraicSet2| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |Queue| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RandomDistributions| |RationalFactorize| |RationalFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionIntegration| |RationalFunctionSign| |RationalIntegration| |RationalInterpolation| |RationalLODE| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealSolvePackage| |RealZeroPackage| |RealZeroPackageQ| |RectangularMatrix| |RecurrenceOperator| |RecursiveAggregate&| |RecursivePolynomialCategory&| |ReductionOfOrder| |Reference| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RetractSolvePackage| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RootsFindingPackage| |RoutinesTable| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentFunctions2| |SequentialDifferentialPolynomial| |Set| |SetAggregate&| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SimpleFortranProgram| |SingleInteger| |SmithNormalForm| |SortedCache| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |Stack| |Stream| |StreamAggregate&| |StreamFunctions2| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |String| |StringTable| |StructuralConstantsPackage| |SturmHabichtPackage| |SubResultantPackage| |SubSpace| |SubSpaceComponentProperty| |SupFractionFactorizer| |Switch| |Symbol| |SymbolTable| |SymmetricFunctions| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Table| |TableAggregate&| |Tableau| |TableauxBumpers| |TangentExpansions| |TaylorSeries| |TaylorSolve| |TexFormat| |TheSymbolTable| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TransSolvePackage| |TransSolvePackageService| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDESystem| |Tree| |TriangularSetCategory&| |TrigonometricManipulations| |TubePlot| |TubePlotTools| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |UnaryRecursiveAggregate&| |UniqueFactorizationDomain&| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCommonDenominator| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePolynomialSquareFree| |UnivariatePowerSeriesCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesODESolver| |UniversalSegment| |UserDefinedPartialOrdering| |UserDefinedVariableOrdering| |Vector| |VectorCategory&| |VectorFunctions2| |ViewDefaultsPackage| |ViewportPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AlgebraPackage| |Asp19| |Asp55| |DirichletRing| |ElementaryFunctionSign| |FiniteSetAggregateFunctions2| |FramedNonAssociativeAlgebra&| |GaloisGroupFactorizer| |GenericNonAssociativeAlgebra| |Guess| |LieSquareMatrix| |MatrixCommonDenominator| |PAdicWildFunctionFieldIntegralBasis| |PermutationGroupExamples| |RealSolvePackage| |TaylorSolve| |ThreeSpace| |TwoDimensionalPlotClipping| |UnivariateTaylorSeriesODESolver|)
 (|FreeGroup| |FreeMonoid| |InnerFreeAbelianMonoid|)
 (|IntegerFactorizationPackage|)
 (|Expression| |FunctionSpace&| |RationalFunction|)
 (|Fraction|)
+(|DesingTreePackage| |GeneralPackageForAlgebraicFunctionField| |IntersectionDivisorPackage|)
 (|LocalAlgebra|)
 (|LieExponentials| |LiePolynomial| |PoincareBirkhoffWittLyndonBasis| |XPBWPolynomial|)
-(|IdealDecompositionPackage| |MultFiniteFactorize|)
+(|Guess| |IdealDecompositionPackage| |InterfaceGroebnerPackage| |MultFiniteFactorize|)
 (|PolToPol|)
 (|GeneralizedMultivariateFactorize|)
 (|GeneralizedMultivariateFactorize| |IdealDecompositionPackage| |MultivariateFactorize| |SystemSolvePackage|)
@@ -285,14 +318,15 @@
 (|Asp27| |Asp28| |Asp8| |ExpertSystemToolsPackage| |MachineComplex|)
 (|MachineComplex| |MachineFloat|)
 (|LiePolynomial| |LyndonWord|)
-(|MakeFloatCompiledFunction|)
+(|ExpressionSolve| |MakeFloatCompiledFunction|)
 (|ExpressionTubePlot| |PlotFunctions1| |TopLevelDrawFunctions|)
 (|MakeBinaryCompiledFunction| |MakeUnaryCompiledFunction|)
 (|Expression| |FunctionSpace&| |MakeFloatCompiledFunction|)
+(|Guess| |GuessAlgebraicNumber| |GuessInteger| |GuessPolynomial| |GuessUnivariatePolynomial|)
 (|MappingPackage1|)
 (|MappingPackage2|)
 (|MappingPackage3|)
-(|AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicNumber| |AnnaNumericalOptimizationPackage| |AnnaPartialDifferentialEquationPackage| |Asp19| |Asp20| |Asp27| |Asp28| |Asp30| |Asp31| |Asp34| |Asp35| |Asp41| |Asp42| |Asp55| |Asp74| |Asp77| |Asp80| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |BalancedPAdicRational| |BinaryExpansion| |CharacteristicPolynomialPackage| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |CoerceVectorMatrixPackage| |Complex| |ComplexCategory&| |CycleIndicators| |DecimalExpansion| |DenavitHartenbergMatrix| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DistributedMultivariatePolynomial| |EigenPackage| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ExpertSystemToolsPackage| |ExpertSystemToolsPackage2| |ExponentialExpansion| |Expression| |FiniteAlgebraicExtensionField&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FortranCode| |Fraction| |FractionalIdeal| |FramedAlgebra&| |FramedModule| |FramedNonAssociativeAlgebra&| |FullyLinearlyExplicitRingOver&| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |GeneralDistributedMultivariatePolynomial| |GenericNonAssociativeAlgebra| |GosperSummationMethod| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |IndexedVector| |InnerAlgebraicNumber| |InnerFiniteField| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerPrimeField| |Integer| |IntegralBasisPolynomialTools| |IntegralBasisTools| |IrrRepSymNatPackage| |LieSquareMatrix| |LinGroebnerPackage| |LinearDependence| |LinearOrdinaryDifferentialOperatorsOps| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |MachineComplex| |MachineInteger| |Matrix| |MatrixCommonDenominator| |MatrixLinearAlgebraFunctions| |ModMonic| |ModularHermitianRowReduction| |MonogenicAlgebra&| |MultiVariableCalculusFunctions| |MultivariatePolynomial| |NAGLinkSupportPackage| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NumberFieldIntegralBasis| |NumericComplexEigenPackage| |NumericRealEigenPackage| |ODETools| |OrderedDirectProduct| |OrderlyDifferentialPolynomial| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |ParametricLinearEquations| |Point| |Polynomial| |PolynomialCategory&| |PolynomialFactorizationExplicit&| |PrecomputedAssociatedEquations| |PrimeField| |PseudoLinearNormalForm| |PureAlgebraicLODE| |Quaternion| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadixExpansion| |RationalLODE| |RectangularMatrix| |RectangularMatrixCategoryFunctions2| |ReduceLODE| |RepresentationPackage1| |RepresentationPackage2| |RomanNumeral| |SequentialDifferentialPolynomial| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SparseMultivariatePolynomial| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SplitHomogeneousDirectProduct| |SquareMatrix| |SquareMatrixCategory&| |StorageEfficientMatrixOperations| |StructuralConstantsPackage| |SymmetricGroupCombinatoricFunctions| |SystemODESolver| |TransSolvePackageService| |TranscendentalIntegration| |TranscendentalRischDESystem| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |Vector| |VectorCategory&| |WildFunctionFieldIntegralBasis| |d01alfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicNumber| |AnnaNumericalOptimizationPackage| |AnnaPartialDifferentialEquationPackage| |Asp19| |Asp20| |Asp27| |Asp28| |Asp30| |Asp31| |Asp34| |Asp35| |Asp41| |Asp42| |Asp55| |Asp74| |Asp77| |Asp80| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |BalancedPAdicRational| |BinaryExpansion| |CharacteristicPolynomialPackage| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |CoerceVectorMatrixPackage| |Complex| |ComplexCategory&| |ComplexDoubleFloatVector| |CycleIndicators| |DecimalExpansion| |DenavitHartenbergMatrix| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DistributedMultivariatePolynomial| |DoubleFloatVector| |EigenPackage| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ExpertSystemToolsPackage| |ExpertSystemToolsPackage2| |ExponentialExpansion| |Expression| |FiniteAlgebraicExtensionField&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FortranCode| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FramedAlgebra&| |FramedModule| |FramedNonAssociativeAlgebra&| |FullyLinearlyExplicitRingOver&| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |GeneralDistributedMultivariatePolynomial| |GenericNonAssociativeAlgebra| |GosperSummationMethod| |Guess| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |IndexedVector| |InnerAlgebraicNumber| |InnerFiniteField| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerPrimeField| |Integer| |IntegralBasisPolynomialTools| |IntegralBasisTools| |InterpolateFormsPackage| |IrrRepSymNatPackage| |LieSquareMatrix| |LinGroebnerPackage| |LinearDependence| |LinearOrdinaryDifferentialOperatorsOps| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |LinesOpPack| |MachineComplex| |MachineInteger| |Matrix| |MatrixCommonDenominator| |MatrixLinearAlgebraFunctions| |ModMonic| |ModularHermitianRowReduction| |MonogenicAlgebra&| |MultiVariableCalculusFunctions| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NumberFieldIntegralBasis| |NumericComplexEigenPackage| |NumericRealEigenPackage| |ODETools| |OrderedDirectProduct| |OrderlyDifferentialPolynomial| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |ParametricLinearEquations| |Point| |Polynomial| |PolynomialCategory&| |PolynomialFactorizationExplicit&| |PrecomputedAssociatedEquations| |PrimeField| |PseudoAlgebraicClosureOfFiniteField| |PseudoLinearNormalForm| |PureAlgebraicLODE| |Quaternion| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadixExpansion| |RationalInterpolation| |RationalLODE| |RectangularMatrix| |RectangularMatrixCategoryFunctions2| |ReduceLODE| |RepresentationPackage1| |RepresentationPackage2| |RomanNumeral| |SequentialDifferentialPolynomial| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SparseMultivariatePolynomial| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SplitHomogeneousDirectProduct| |SquareMatrix| |SquareMatrixCategory&| |StorageEfficientMatrixOperations| |StructuralConstantsPackage| |SymmetricGroupCombinatoricFunctions| |SystemODESolver| |TransSolvePackageService| |TranscendentalIntegration| |TranscendentalRischDESystem| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |Vector| |VectorCategory&| |WildFunctionFieldIntegralBasis| |d01alfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|AlgebraicHermiteIntegration| |Asp19| |Asp20| |Asp31| |Asp35| |Asp41| |Asp42| |Asp74| |Asp77| |Asp80| |CoerceVectorMatrixPackage| |ComplexCategory&| |FractionalIdeal| |FramedAlgebra&| |FunctionFieldCategory&| |InnerMatrixQuotientFieldFunctions| |LinearDependence| |MatrixCommonDenominator| |MatrixLinearAlgebraFunctions| |ReduceLODE| |SimpleAlgebraicExtension| |SmithNormalForm|)
 (|AlgebraicFunctionField| |FractionalIdeal| |FramedModule| |FunctionFieldCategory&| |QuotientFieldCategory&|)
 (|IndexedMatrix| |Matrix|)
@@ -307,7 +341,7 @@
 (|ContinuedFraction|)
 (|MonoidRingFunctions2|)
 (|TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalRischDE| |TranscendentalRischDESystem|)
-(|FortranOutputStackPackage| |FortranPackage| |NAGLinkSupportPackage|)
+(|FortranOutputStackPackage| |FortranPackage| |Guess| |NAGLinkSupportPackage|)
 (|GeneralizedMultivariateFactorize| |MPolyCatRationalFunctionFactorizer|)
 (|Asp19| |Asp31| |Asp35| |Asp41| |Asp42| |Asp49| |Asp55| |d02AgentsPackage| |e04nafAnnaType|)
 (|FunctionFieldCategoryFunctions2| |PointsOfFiniteOrder| |ReducedDivisor|)
@@ -315,6 +349,8 @@
 (|Equation| |GeneralizedMultivariateFactorize| |GroebnerFactorizationPackage| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |ParametricLinearEquations| |PartialFractionPackage| |PolynomialSetUtilitiesPackage| |QuasiAlgebraicSet| |RadicalSolvePackage| |RationalFunctionFactor| |SupFractionFactorizer| |TransSolvePackage|)
 (|InnerMultFact| |MultFiniteFactorize| |MultivariateSquareFree| |PolynomialGcdPackage|)
 (|InnerMultFact| |PolynomialCategory&| |SupFractionFactorizer|)
+(|GuessUnivariatePolynomial|)
+(|MyExpression|)
 (|Asp1| |Asp10| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp30| |Asp31| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |NagEigenPackage| |NagIntegrationPackage| |NagLinearEquationSolvingPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagRootFindingPackage|)
 (|MultivariateLifting|)
 (|d02AgentsPackage|)
@@ -322,13 +358,16 @@
 (|AnnaNumericalOptimizationPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType|)
 (|d03eefAnnaType|)
+(|PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField|)
 (|LexTriangularPackage| |RationalUnivariateRepresentationPackage| |RegularChain| |ZeroDimensionalSolvePackage|)
 (|NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomialFunctions2|)
 (|NewSparseMultivariatePolynomial|)
+(|Guess|)
+(|BlowUpPackage|)
 (|ElementaryFunctionODESolver|)
 (|RationalRicDE|)
-(|AbelianGroup&| |AbelianMonoid&| |AbelianMonoidRing&| |Aggregate&| |AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |ApplyRules| |ApplyUnivariateSkewPolynomial| |ArrayStack| |Asp19| |Asp20| |Asp27| |Asp28| |Asp30| |Asp31| |Asp34| |Asp35| |Asp41| |Asp42| |Asp55| |Asp74| |Asp77| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |Automorphism| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicOperator| |BasicOperatorFunctions1| |BezoutMatrix| |BinaryExpansion| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |BinaryTreeCategory&| |Bits| |Boolean| |BoundIntegerRoots| |BrillhartTests| |CRApackage| |CardinalNumber| |CartesianTensor| |ChangeOfVariable| |Character| |CharacterClass| |CharacteristicPolynomialInMonogenicalAlgebra| |CharacteristicPolynomialPackage| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |Collection&| |CommonOperators| |CommuteUnivariatePolynomialCategory| |Complex| |ComplexCategory&| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexPatternMatch| |ComplexRootFindingPackage| |ConstantLODE| |ContinuedFraction| |CoordinateSystems| |CyclicStreamTools| |CyclotomicPolynomialPackage| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |Dictionary&| |DifferentialExtension&| |DifferentialPolynomialCategory&| |DifferentialRing&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DiscreteLogarithmPackage| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DivisionRing&| |DoubleFloat| |DoubleFloatSpecialFunctions| |DoubleResultantPackage| |DrawComplex| |EigenPackage| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |EqTable| |Equation| |EuclideanDomain&| |EuclideanModularRing| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToUnivariatePowerSeries| |ExtAlgBasis| |ExtensibleLinearAggregate&| |ExtensionField&| |Factored| |FactoredFunctionUtilities| |FactoredFunctions| |FactoringUtilities| |Field&| |FieldOfPrimeCharacteristic&| |FindOrderFinite| |FiniteAbelianMonoidRing&| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSolveLinearPolynomialEquation| |FiniteLinearAggregateFunctions2| |FiniteLinearAggregateSort| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FortranExpression| |FourierSeries| |Fraction| |FractionalIdeal| |FramedAlgebra&| |FramedModule| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GaussianFactorizationPackage| |GcdDomain&| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralModulePolynomial| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |GraphImage| |GrayCode| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerSolve| |Group&| |HallBasis| |HashTable| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfiniteProductFiniteField| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySign| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |Integer| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerMod| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegralBasisTools| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InternalRationalUnivariateRepresentationPackage| |InverseLaplaceTransform| |IrrRepSymNatPackage| |IrredPolyOverFiniteField| |Kernel| |KernelFunctions2| |KeyedAccessFile| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LazyStreamAggregate&| |LeadingCoefDetermination| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorCategory&| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperatorsOps| |LinearPolynomialEquationByFractions| |LinearSystemMatrixPackage| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |List| |ListAggregate&| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |Localize| |LyndonWord| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MachineFloat| |MachineInteger| |MakeCachableSet| |MappingPackage1| |MappingPackageInternalHacks1| |Matrix| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModularRing| |Module&| |ModuleOperator| |MoebiusTransform| |MonadWithUnit&| |MonogenicAlgebra&| |Monoid&| |MonoidRing| |MonomialExtensionTools| |MultFiniteFactorize| |MultiVariableCalculusFunctions| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |NAGLinkSupportPackage| |NPCoef| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonCommutativeOperatorDivision| |NonLinearFirstOrderODESolver| |NonNegativeInteger| |NormInMonogenicAlgebra| |NormRetractPackage| |NormalizationPackage| |NumberFieldIntegralBasis| |NumberFormats| |NumberTheoreticPolynomialFunctions| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |Operator| |OppositeMonogenicLinearOperator| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OrthogonalPolynomialFunctions| |OutputForm| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PadeApproximantPackage| |PadeApproximants| |ParametricLinearEquations| |ParametricPlaneCurve| |ParametricPlaneCurveFunctions2| |ParametricSpaceCurve| |ParametricSpaceCurveFunctions2| |ParametricSurface| |ParametricSurfaceFunctions2| |PartialDifferentialRing&| |PartialFraction| |Partition| |Pattern| |PatternFunctions2| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchPushDown| |PatternMatchTools| |PendantTree| |Permanent| |Permutation| |PermutationGroup| |Pi| |PlaneAlgebraicCurvePlot| |PoincareBirkhoffWittLyndonBasis| |Point| |PointPackage| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |Polynomial| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialComposition| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialInterpolationAlgorithms| |PolynomialNumberTheoryFunctions| |PolynomialRing| |PolynomialRoots| |PolynomialSetUtilitiesPackage| |PolynomialSolveByFormulas| |PolynomialSquareFree| |PositiveInteger| |PowerSeriesCategory&| |PrecomputedAssociatedEquations| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |PushVariables| |QuadraticForm| |QuasiAlgebraicSet| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |Queue| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RandomDistributions| |RandomFloatDistributions| |RandomIntegerDistributions| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalLODE| |RationalRicDE| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealZeroPackage| |RectangularMatrix| |RectangularMatrixCategory&| |RectangularMatrixCategoryFunctions2| |RecursivePolynomialCategory&| |ReduceLODE| |ReducedDivisor| |ReductionOfOrder| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RetractSolvePackage| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RoutinesTable| |SExpressionOf| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SortPackage| |SortedCache| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |Stack| |StorageEfficientMatrixOperations| |Stream| |StreamAggregate&| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |String| |StringAggregate&| |StringTable| |StructuralConstantsPackage| |SturmHabichtPackage| |SubResultantPackage| |SubSpace| |Symbol| |SymmetricFunctions| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Table| |TableAggregate&| |Tableau| |TabulatedComputationPackage| |TangentExpansions| |TaylorSeries| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TransSolvePackageService| |TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDE| |TranscendentalRischDESystem| |Tree| |TriangularMatrixOperations| |TriangularSetCategory&| |TubePlotTools| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |UTSodetools| |UnaryRecursiveAggregate&| |UnivariateFactorize| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategoryOps| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCategory&| |Vector| |VectorCategory&| |ViewDefaultsPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XExponentialPackage| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01aqfAnnaType| |d01fcfAnnaType| |d02AgentsPackage| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
-(|AlgebraicFunction| |Any| |AnyFunctions1| |BasicOperator| |BasicOperatorFunctions1| |CombinatorialFunction| |CommonOperators| |FunctionSpace&| |FunctionSpaceAttachPredicates| |LaplaceTransform| |LiouvillianFunction| |ModuleOperator| |NoneFunctions1|)
+(|AbelianGroup&| |AbelianMonoid&| |AbelianMonoidRing&| |AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |Aggregate&| |AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |ApplyRules| |ApplyUnivariateSkewPolynomial| |ArrayStack| |Asp19| |Asp20| |Asp27| |Asp28| |Asp30| |Asp31| |Asp34| |Asp35| |Asp41| |Asp42| |Asp55| |Asp74| |Asp77| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |Automorphism| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicOperator| |BasicOperatorFunctions1| |BezoutMatrix| |BinaryExpansion| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |BinaryTreeCategory&| |Bits| |BlowUpPackage| |Boolean| |BoundIntegerRoots| |BrillhartTests| |CRApackage| |CardinalNumber| |CartesianTensor| |ChangeOfVariable| |Character| |CharacterClass| |CharacteristicPolynomialInMonogenicalAlgebra| |CharacteristicPolynomialPackage| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |Collection&| |CommonOperators| |CommuteUnivariatePolynomialCategory| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexPatternMatch| |ComplexRootFindingPackage| |ConstantLODE| |ContinuedFraction| |CoordinateSystems| |CyclicStreamTools| |CyclotomicPolynomialPackage| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |Dictionary&| |DifferentialExtension&| |DifferentialPolynomialCategory&| |DifferentialRing&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DivisionRing&| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DoubleResultantPackage| |DrawComplex| |EigenPackage| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |EqTable| |Equation| |EuclideanDomain&| |EuclideanModularRing| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Export3D| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToUnivariatePowerSeries| |ExtAlgBasis| |ExtensibleLinearAggregate&| |ExtensionField&| |Factored| |FactoredFunctionUtilities| |FactoredFunctions| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |Field&| |FieldOfPrimeCharacteristic&| |FindOrderFinite| |FiniteAbelianMonoidRing&| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteLinearAggregateFunctions2| |FiniteLinearAggregateSort| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FortranExpression| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FramedAlgebra&| |FramedModule| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GaussianFactorizationPackage| |GcdDomain&| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |GraphImage| |GrayCode| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerSolve| |Group&| |Guess| |GuessOption| |GuessOptionFunctions0| |HallBasis| |HashTable| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfiniteProductFiniteField| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySign| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |Integer| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerMod| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegralBasisTools| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InterfaceGroebnerPackage| |InternalRationalUnivariateRepresentationPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrrRepSymNatPackage| |IrredPolyOverFiniteField| |Kernel| |KernelFunctions2| |KeyedAccessFile| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LazyStreamAggregate&| |LeadingCoefDetermination| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorCategory&| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperatorsOps| |LinearPolynomialEquationByFractions| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |LinesOpPack| |List| |ListAggregate&| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |LocalParametrizationOfSimplePointPackage| |Localize| |LyndonWord| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MachineFloat| |MachineInteger| |MakeCachableSet| |MappingPackage1| |MappingPackageInternalHacks1| |Matrix| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModularRing| |Module&| |ModuleOperator| |MoebiusTransform| |MonadWithUnit&| |MonogenicAlgebra&| |Monoid&| |MonoidRing| |MonomialExtensionTools| |MultFiniteFactorize| |MultiVariableCalculusFunctions| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NPCoef| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonInterpolation| |NewtonPolygon| |NonCommutativeOperatorDivision| |NonLinearFirstOrderODESolver| |NonNegativeInteger| |NormInMonogenicAlgebra| |NormRetractPackage| |NormalizationPackage| |NottinghamGroup| |NumberFieldIntegralBasis| |NumberFormats| |NumberTheoreticPolynomialFunctions| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |Operator| |OppositeMonogenicLinearOperator| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OrthogonalPolynomialFunctions| |OutputForm| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |PadeApproximantPackage| |PadeApproximants| |ParametricLinearEquations| |ParametricPlaneCurve| |ParametricPlaneCurveFunctions2| |ParametricSpaceCurve| |ParametricSpaceCurveFunctions2| |ParametricSurface| |ParametricSurfaceFunctions2| |ParametrizationPackage| |PartialDifferentialRing&| |PartialFraction| |Partition| |Pattern| |PatternFunctions2| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchPushDown| |PatternMatchTools| |PendantTree| |Permanent| |Permutation| |PermutationGroup| |Pi| |PlaneAlgebraicCurvePlot| |PoincareBirkhoffWittLyndonBasis| |Point| |PointPackage| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |Polynomial| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialComposition| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialInterpolationAlgorithms| |PolynomialNumberTheoryFunctions| |PolynomialPackageForCurve| |PolynomialRing| |PolynomialRoots| |PolynomialSetUtilitiesPackage| |PolynomialSolveByFormulas| |PolynomialSquareFree| |PositiveInteger| |PowerSeriesCategory&| |PrecomputedAssociatedEquations| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |PushVariables| |QuadraticForm| |QuasiAlgebraicSet| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |Queue| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RandomDistributions| |RandomFloatDistributions| |RandomIntegerDistributions| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalInterpolation| |RationalLODE| |RationalRicDE| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealZeroPackage| |RectangularMatrix| |RectangularMatrixCategory&| |RectangularMatrixCategoryFunctions2| |RecurrenceOperator| |RecursivePolynomialCategory&| |ReduceLODE| |ReducedDivisor| |ReductionOfOrder| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RetractSolvePackage| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RootsFindingPackage| |RoutinesTable| |SExpressionOf| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SortPackage| |SortedCache| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |Stack| |StorageEfficientMatrixOperations| |Stream| |StreamAggregate&| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |String| |StringAggregate&| |StringTable| |StructuralConstantsPackage| |SturmHabichtPackage| |SubResultantPackage| |SubSpace| |Symbol| |SymmetricFunctions| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Table| |TableAggregate&| |Tableau| |TabulatedComputationPackage| |TangentExpansions| |TaylorSeries| |TaylorSolve| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TransSolvePackageService| |TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDE| |TranscendentalRischDESystem| |Tree| |TriangularMatrixOperations| |TriangularSetCategory&| |TubePlotTools| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |UTSodetools| |UnaryRecursiveAggregate&| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategoryOps| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |Vector| |VectorCategory&| |ViewDefaultsPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XExponentialPackage| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01aqfAnnaType| |d01fcfAnnaType| |d02AgentsPackage| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AlgebraicFunction| |Any| |AnyFunctions1| |BasicOperator| |BasicOperatorFunctions1| |CombinatorialFunction| |CommonOperators| |FunctionSpace&| |FunctionSpaceAttachPredicates| |FunctionalSpecialFunction| |LaplaceTransform| |LiouvillianFunction| |ModuleOperator| |NoneFunctions1| |RecurrenceOperator|)
 (|AnyFunctions1| |ModuleOperator|)
 (|InternalRationalUnivariateRepresentationPackage| |LazardSetSolvingPackage| |LexTriangularPackage| |RationalUnivariateRepresentationPackage| |ZeroDimensionalSolvePackage|)
 (|OutputForm| |RomanNumeral|)
@@ -344,7 +383,7 @@
 (|AnnaOrdinaryDifferentialEquationPackage| |d02AgentsPackage|)
 (|ConstantLODE| |ElementaryFunctionLODESolver|)
 (|LyndonWord| |OneDimensionalArrayFunctions2| |TwoDimensionalArray|)
-(|AlgebraicFunctionField| |Complex| |ExtensionField&| |FiniteAlgebraicExtensionField&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |Infinity| |InnerFiniteField| |InnerPrimeField| |MachineComplex| |MoebiusTransform| |OnePointCompletionFunctions2| |PowerSeriesLimitPackage| |PrimeField| |RadicalFunctionField| |RationalFunctionLimitPackage| |SimpleAlgebraicExtension|)
+(|AlgebraicFunctionField| |Complex| |DoubleFloatSpecialFunctions| |ExtensionField&| |FiniteAlgebraicExtensionField&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |Infinity| |InnerFiniteField| |InnerPrimeField| |MachineComplex| |MoebiusTransform| |OnePointCompletionFunctions2| |PowerSeriesLimitPackage| |PrimeField| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |RadicalFunctionField| |RationalFunctionLimitPackage| |SimpleAlgebraicExtension|)
 (|RationalFunctionLimitPackage|)
 (|OpenMathServerPackage|)
 (|Complex| |DoubleFloat| |ExpressionToOpenMath| |Float| |Fraction| |Integer| |List| |OpenMathConnection| |OpenMathPackage| |OpenMathServerPackage| |SingleInteger| |String| |Symbol|)
@@ -355,21 +394,23 @@
 (|AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |DefiniteIntegrationTools| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionSign| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |Infinity| |InnerSparseUnivariatePowerSeries| |LaplaceTransform| |OrderedCompletionFunctions2| |PatternMatchIntegration| |PowerSeriesLimitPackage| |RationalFunctionDefiniteIntegration| |RationalFunctionLimitPackage| |RationalFunctionSign| |SparseUnivariateLaurentSeries| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |UnivariatePuiseuxSeriesWithExponentialSingularity| |d01AgentsPackage| |d01TransformFunctionType| |d03AgentsPackage| |e04AgentsPackage| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04ucfAnnaType|)
 (|RationalFunctionDefiniteIntegration| |RationalFunctionLimitPackage|)
 (|LiePolynomial| |LyndonWord| |Magma| |PoincareBirkhoffWittLyndonBasis| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XRecursivePolynomial|)
-(|DistributedMultivariatePolynomial| |FGLMIfCanPackage| |GeneralDistributedMultivariatePolynomial| |GroebnerSolve| |HomogeneousDistributedMultivariatePolynomial| |IdealDecompositionPackage| |LexTriangularPackage| |LinGroebnerPackage| |MultivariatePolynomial| |PolToPol| |QuasiAlgebraicSet2| |RationalUnivariateRepresentationPackage| |RegularChain| |ZeroDimensionalSolvePackage|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |DesingTreePackage| |DistributedMultivariatePolynomial| |FGLMIfCanPackage| |GeneralDistributedMultivariatePolynomial| |GroebnerSolve| |Guess| |HomogeneousDistributedMultivariatePolynomial| |IdealDecompositionPackage| |InterpolateFormsPackage| |LexTriangularPackage| |LinGroebnerPackage| |LocalParametrizationOfSimplePointPackage| |MultivariatePolynomial| |PolToPol| |ProjectiveAlgebraicSetPackage| |QuasiAlgebraicSet2| |RationalUnivariateRepresentationPackage| |RegularChain| |ZeroDimensionalSolvePackage|)
 (|FullPartialFractionExpansion|)
 (|FullPartialFractionExpansion| |LinearOrdinaryDifferentialOperatorsOps| |OrderlyDifferentialPolynomial|)
-(|Algebra&| |AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicNumber| |AnonymousFunction| |AntiSymm| |Any| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |BalancedBinaryTree| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BinaryExpansion| |BinaryFile| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |Boolean| |CRApackage| |CardinalNumber| |CartesianTensor| |Character| |CharacterClass| |CliffordAlgebra| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |Complex| |ComplexCategory&| |ComplexRootFindingPackage| |ContinuedFraction| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DenavitHartenbergMatrix| |Dequeue| |DictionaryOperations&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DiscreteLogarithmPackage| |DistributedMultivariatePolynomial| |DoubleFloat| |DrawOption| |ElementaryFunctionODESolver| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |EqTable| |Equation| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |Exit| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionToOpenMath| |ExtAlgBasis| |Factored| |File| |FileName| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FortranCode| |FortranExpression| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |FourierComponent| |FourierSeries| |Fraction| |FractionalIdeal| |FramedModule| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionCalled| |FunctionSpace&| |GaloisGroupFactorizationUtilities| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GraphImage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |HashTable| |Heap| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IndexCard| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfiniteTuple| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InputForm| |Integer| |IntegerMod| |IntegrationResult| |InternalRationalUnivariateRepresentationPackage| |Kernel| |KeyedAccessFile| |LaurentPolynomial| |LeftAlgebra&| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LiouvillianFunction| |List| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |Localize| |LyndonWord| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeCachableSet| |Matrix| |MatrixCategory&| |ModMonic| |ModularField| |ModularRing| |ModuleMonomial| |ModuleOperator| |MoebiusTransform| |MonoidRing| |Multiset| |MultivariatePolynomial| |NAGLinkSupportPackage| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonAssociativeRing&| |NonNegativeInteger| |None| |NormalizationPackage| |NumberFormats| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalOrdinaryDifferentialEquations| |NumericalPDEProblem| |NumericalQuadrature| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OpenMathPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |Palette| |PartialFraction| |Partition| |Pattern| |PatternMatchListResult| |PatternMatchResult| |PendantTree| |Permutation| |PermutationGroup| |Pi| |PlaneAlgebraicCurvePlot| |Plot| |Plot3D| |PoincareBirkhoffWittLyndonBasis| |Point| |Polynomial| |PolynomialIdeals| |PolynomialRing| |PositiveInteger| |PrimeField| |PrimitiveArray| |PrintPackage| |Product| |QuadraticForm| |QuasiAlgebraicSet| |Quaternion| |QuaternionCategory&| |QueryEquation| |Queue| |QuotientFieldCategory&| |RadicalFunctionField| |RadixExpansion| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealZeroPackage| |RectangularMatrix| |RecursivePolynomialCategory&| |Reference| |RegularChain| |RegularTriangularSet| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RewriteRule| |RightOpenIntervalRootCharacterization| |Ring&| |RomanNumeral| |RoutinesTable| |RuleCalled| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |ScriptFormulaFormat1| |Segment| |SegmentBinding| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SimpleFortranProgram| |SingleInteger| |SingletonAsOrderedSet| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeRegularTriangularSet| |SquareMatrix| |SquareMatrixCategory&| |Stack| |Stream| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringAggregate&| |StringTable| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |Switch| |Symbol| |SymbolTable| |SymmetricPolynomial| |Table| |TableAggregate&| |Tableau| |TabulatedComputationPackage| |TaylorSeries| |TexFormat| |TexFormat1| |TextFile| |TheSymbolTable| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |TopLevelDrawFunctionsForCompiledFunctions| |Tree| |TriangularSetCategory&| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalViewport| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCategory&| |UniversalSegment| |Variable| |Vector| |Void| |WeightedPolynomials| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |d03fafAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
-(|GenUFactorize| |IndexCard| |InternalRationalUnivariateRepresentationPackage| |NormalizationPackage| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |RationalUnivariateRepresentationPackage| |TabulatedComputationPackage| |ZeroDimensionalSolvePackage|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |Algebra&| |AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicNumber| |AnonymousFunction| |AntiSymm| |Any| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |BalancedBinaryTree| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BinaryExpansion| |BinaryFile| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlowUpPackage| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |CRApackage| |CardinalNumber| |CartesianTensor| |Character| |CharacterClass| |CliffordAlgebra| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexRootFindingPackage| |ContinuedFraction| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |DictionaryOperations&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DistributedMultivariatePolynomial| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatVector| |DrawOption| |ElementaryFunctionODESolver| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |EqTable| |Equation| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |Exit| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionToOpenMath| |ExtAlgBasis| |Factored| |File| |FileName| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FortranCode| |FortranExpression| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |FourierComponent| |FourierSeries| |Fraction| |FractionalIdeal| |FramedModule| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionCalled| |FunctionSpace&| |GaloisGroupFactorizationUtilities| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GraphImage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |Guess| |GuessOption| |GuessOptionFunctions0| |HTMLFormat| |HashTable| |Heap| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IndexCard| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfiniteTuple| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InputForm| |Integer| |IntegerMod| |IntegrationResult| |InternalRationalUnivariateRepresentationPackage| |IntersectionDivisorPackage| |Interval| |Kernel| |KeyedAccessFile| |LaurentPolynomial| |LeftAlgebra&| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LiouvillianFunction| |List| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |Localize| |LyndonWord| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeCachableSet| |MathMLFormat| |Matrix| |MatrixCategory&| |ModMonic| |ModularField| |ModularRing| |ModuleMonomial| |ModuleOperator| |MoebiusTransform| |MonoidRing| |Multiset| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonAssociativeRing&| |NonNegativeInteger| |None| |NormalizationPackage| |NottinghamGroup| |NumberFormats| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalOrdinaryDifferentialEquations| |NumericalPDEProblem| |NumericalQuadrature| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OpenMathPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |Palette| |PartialFraction| |Partition| |Pattern| |PatternMatchListResult| |PatternMatchResult| |PendantTree| |Permutation| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PoincareBirkhoffWittLyndonBasis| |Point| |Polynomial| |PolynomialIdeals| |PolynomialRing| |PositiveInteger| |PrimeField| |PrimitiveArray| |PrintPackage| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |QuadraticForm| |QuasiAlgebraicSet| |Quaternion| |QuaternionCategory&| |QueryEquation| |Queue| |QuotientFieldCategory&| |RadicalFunctionField| |RadixExpansion| |RationalInterpolation| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealZeroPackage| |RectangularMatrix| |RecurrenceOperator| |RecursivePolynomialCategory&| |Reference| |RegularChain| |RegularTriangularSet| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RewriteRule| |RightOpenIntervalRootCharacterization| |Ring&| |RomanNumeral| |RoutinesTable| |RuleCalled| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |ScriptFormulaFormat1| |Segment| |SegmentBinding| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SimpleFortranProgram| |SingleInteger| |SingletonAsOrderedSet| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeRegularTriangularSet| |SquareMatrix| |SquareMatrixCategory&| |Stack| |Stream| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringAggregate&| |StringTable| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |Switch| |Symbol| |SymbolTable| |SymmetricPolynomial| |Table| |TableAggregate&| |Tableau| |TabulatedComputationPackage| |TaylorSeries| |TaylorSolve| |TexFormat| |TexFormat1| |TextFile| |TheSymbolTable| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |TopLevelDrawFunctionsForCompiledFunctions| |Tree| |TriangularSetCategory&| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalViewport| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UniversalSegment| |Variable| |Vector| |Void| |WeightedPolynomials| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |d03fafAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|DirichletRing| |GenUFactorize| |Guess| |IndexCard| |InternalRationalUnivariateRepresentationPackage| |NormalizationPackage| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |RationalInterpolation| |RationalUnivariateRepresentationPackage| |SparseUnivariatePolynomialExpressions| |TabulatedComputationPackage| |TaylorSolve| |ZeroDimensionalSolvePackage|)
 (|PAdicRational|)
 (|BalancedPAdicRational| |PAdicRational|)
+(|BlowUpPackage| |DesingTreePackage| |GeneralPackageForAlgebraicFunctionField| |InterpolateFormsPackage| |IntersectionDivisorPackage| |LocalParametrizationOfSimplePointPackage| |NewtonPolygon| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PolynomialPackageForCurve|)
 (|DrawOption| |DrawOptionFunctions0| |GraphImage| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TwoDimensionalViewport| |ViewDefaultsPackage| |ViewportPackage|)
 (|EllipticFunctionsUnivariateTaylorSeries| |InnerSparseUnivariatePowerSeries| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |UnivariateTaylorSeriesODESolver| |WeierstrassPreparation|)
 (|ParametricPlaneCurveFunctions2| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForCompiledFunctions|)
 (|ParametricSpaceCurveFunctions2| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForCompiledFunctions|)
 (|ParametricSurfaceFunctions2| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForCompiledFunctions|)
-(|CycleIndicators| |EvaluateCycleIndicators| |Permutation| |PermutationGroupExamples| |SymmetricPolynomial|)
-(|CycleIndicators| |IrrRepSymNatPackage| |Partition| |SymmetricGroupCombinatoricFunctions|)
-(|ApplyRules| |BalancedPAdicRational| |BinaryExpansion| |Complex| |ComplexCategory&| |ComplexPattern| |ComplexPatternMatch| |DecimalExpansion| |DifferentialSparseMultivariatePolynomial| |DistributedMultivariatePolynomial| |DoubleFloat| |ExponentialExpansion| |Expression| |Float| |Fraction| |FunctionSpace&| |GeneralDistributedMultivariatePolynomial| |HexadecimalExpansion| |HomogeneousDistributedMultivariatePolynomial| |Integer| |IntegerNumberSystem&| |Kernel| |MachineComplex| |MachineFloat| |MachineInteger| |ModMonic| |MultivariatePolynomial| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |OrderedVariableList| |OrderlyDifferentialPolynomial| |PAdicRational| |PAdicRationalConstructor| |PatternFunctions1| |PatternFunctions2| |PatternMatch| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchListAggregate| |PatternMatchPolynomialCategory| |PatternMatchPushDown| |PatternMatchQuotientFieldCategory| |PatternMatchResult| |PatternMatchSymbol| |PatternMatchTools| |Polynomial| |PolynomialCategory&| |QuotientFieldCategory&| |RadixExpansion| |RealNumberSystem&| |RecursivePolynomialCategory&| |RewriteRule| |RomanNumeral| |SequentialDifferentialPolynomial| |SingleInteger| |SparseMultivariatePolynomial| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |Symbol| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial|)
+(|DesingTreePackage| |GeneralPackageForAlgebraicFunctionField| |InterpolateFormsPackage| |IntersectionDivisorPackage|)
+(|CycleIndicators| |EvaluateCycleIndicators| |Guess| |Permutation| |PermutationGroupExamples| |SymmetricPolynomial|)
+(|CycleIndicators| |Guess| |IrrRepSymNatPackage| |Partition| |SymmetricGroupCombinatoricFunctions|)
+(|ApplyRules| |BalancedPAdicRational| |BinaryExpansion| |Complex| |ComplexCategory&| |ComplexPattern| |ComplexPatternMatch| |DecimalExpansion| |DifferentialSparseMultivariatePolynomial| |DistributedMultivariatePolynomial| |DoubleFloat| |ExponentialExpansion| |Expression| |Float| |Fraction| |FunctionSpace&| |GeneralDistributedMultivariatePolynomial| |HexadecimalExpansion| |HomogeneousDistributedMultivariatePolynomial| |Integer| |IntegerNumberSystem&| |Kernel| |MachineComplex| |MachineFloat| |MachineInteger| |ModMonic| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |OrderedVariableList| |OrderlyDifferentialPolynomial| |PAdicRational| |PAdicRationalConstructor| |PatternFunctions1| |PatternFunctions2| |PatternMatch| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchListAggregate| |PatternMatchPolynomialCategory| |PatternMatchPushDown| |PatternMatchQuotientFieldCategory| |PatternMatchResult| |PatternMatchSymbol| |PatternMatchTools| |Polynomial| |PolynomialCategory&| |QuotientFieldCategory&| |RadixExpansion| |RealNumberSystem&| |RecursivePolynomialCategory&| |RewriteRule| |RomanNumeral| |SequentialDifferentialPolynomial| |SingleInteger| |SparseMultivariatePolynomial| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |Symbol| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial|)
 (|ApplyRules| |PatternMatchResult| |PatternMatchTools| |RewriteRule|)
 (|Expression|)
 (|IntegerNumberSystem&|)
@@ -380,7 +421,7 @@
 (|Expression| |PolynomialCategory&|)
 (|ComplexPatternMatch| |PatternMatchFunctionSpace| |PatternMatchPolynomialCategory| |PatternMatchQuotientFieldCategory|)
 (|QuotientFieldCategory&|)
-(|ApplyRules| |BalancedPAdicRational| |BinaryExpansion| |Complex| |ComplexCategory&| |ComplexPatternMatch| |DecimalExpansion| |DifferentialSparseMultivariatePolynomial| |DistributedMultivariatePolynomial| |DoubleFloat| |ExponentialExpansion| |Expression| |Float| |Fraction| |GeneralDistributedMultivariatePolynomial| |HexadecimalExpansion| |HomogeneousDistributedMultivariatePolynomial| |Integer| |IntegerNumberSystem&| |MachineComplex| |MachineFloat| |MachineInteger| |ModMonic| |MultivariatePolynomial| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |OrderlyDifferentialPolynomial| |PAdicRational| |PAdicRationalConstructor| |PatternMatch| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchListAggregate| |PatternMatchListResult| |PatternMatchPolynomialCategory| |PatternMatchPushDown| |PatternMatchQuotientFieldCategory| |PatternMatchResultFunctions2| |PatternMatchSymbol| |PatternMatchTools| |Polynomial| |PolynomialCategory&| |QuotientFieldCategory&| |RadixExpansion| |RealNumberSystem&| |RomanNumeral| |SequentialDifferentialPolynomial| |SingleInteger| |SparseMultivariatePolynomial| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |Symbol| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial|)
+(|ApplyRules| |BalancedPAdicRational| |BinaryExpansion| |Complex| |ComplexCategory&| |ComplexPatternMatch| |DecimalExpansion| |DifferentialSparseMultivariatePolynomial| |DistributedMultivariatePolynomial| |DoubleFloat| |ExponentialExpansion| |Expression| |Float| |Fraction| |GeneralDistributedMultivariatePolynomial| |HexadecimalExpansion| |HomogeneousDistributedMultivariatePolynomial| |Integer| |IntegerNumberSystem&| |MachineComplex| |MachineFloat| |MachineInteger| |ModMonic| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |OrderlyDifferentialPolynomial| |PAdicRational| |PAdicRationalConstructor| |PatternMatch| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchListAggregate| |PatternMatchListResult| |PatternMatchPolynomialCategory| |PatternMatchPushDown| |PatternMatchQuotientFieldCategory| |PatternMatchResultFunctions2| |PatternMatchSymbol| |PatternMatchTools| |Polynomial| |PolynomialCategory&| |QuotientFieldCategory&| |RadixExpansion| |RealNumberSystem&| |RomanNumeral| |SequentialDifferentialPolynomial| |SingleInteger| |SparseMultivariatePolynomial| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |Symbol| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial|)
 (|ComplexPatternMatch| |PatternMatchPushDown|)
 (|Symbol|)
 (|PatternMatchFunctionSpace| |PatternMatchPolynomialCategory|)
@@ -388,19 +429,22 @@
 (|PermutationGroupExamples|)
 (|FortranExpression| |PiCoercions|)
 (|FortranExpression|)
+(|PackageForAlgebraicFunctionField|)
+(|PackageForAlgebraicFunctionFieldOverFiniteField|)
 (|TopLevelDrawFunctionsForAlgebraicCurves|)
+(|Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField|)
 (|GraphicsDefaults| |PlaneAlgebraicCurvePlot| |PlotFunctions1| |TopLevelDrawFunctionsForCompiledFunctions| |TwoDimensionalPlotClipping|)
 (|ExpressionTubePlot| |TopLevelDrawFunctionsForCompiledFunctions|)
 (|GraphImage|)
 (|LieExponentials| |XPBWPolynomial|)
-(|CoordinateSystems| |DenavitHartenbergMatrix| |DrawComplex| |ExpressionTubePlot| |GraphImage| |MeshCreationRoutinesForThreeDimensions| |NumericTubePlot| |PlaneAlgebraicCurvePlot| |Plot| |Plot3D| |PlotTools| |PointFunctions2| |PointPackage| |SubSpace| |ThreeDimensionalViewport| |ThreeSpace| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TubePlotTools| |TwoDimensionalPlotClipping|)
+(|CoordinateSystems| |DenavitHartenbergMatrix| |DrawComplex| |Export3D| |ExpressionTubePlot| |GnuDraw| |GraphImage| |MeshCreationRoutinesForThreeDimensions| |NumericTubePlot| |PlaneAlgebraicCurvePlot| |Plot| |Plot3D| |PlotTools| |PointFunctions2| |PointPackage| |SubSpace| |ThreeDimensionalViewport| |ThreeSpace| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TubePlotTools| |TwoDimensionalPlotClipping|)
 (|GraphImage| |PlaneAlgebraicCurvePlot| |Plot| |Plot3D| |PlotTools| |ThreeDimensionalViewport| |TubePlotTools| |TwoDimensionalPlotClipping|)
 (|AlgebraicIntegrate|)
 (|PointsOfFiniteOrder| |PointsOfFiniteOrderRational|)
 (|FGLMIfCanPackage| |GroebnerSolve|)
 (|FunctionFieldCategory&| |PrimitiveElement|)
-(|AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |Asp1| |Asp10| |Asp19| |Asp20| |Asp24| |Asp30| |Asp31| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |CoerceVectorMatrixPackage| |ComplexPatternMatch| |ComplexRootPackage| |DefiniteIntegrationTools| |DiophantineSolutionPackage| |EigenPackage| |Equation| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |Expression| |FGLMIfCanPackage| |FloatingComplexPackage| |FloatingRealPackage| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranPackage| |FortranType| |FramedNonAssociativeAlgebra&| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpacePrimitiveElement| |FunctionSpaceToUnivariatePowerSeries| |FunctionalSpecialFunction| |GenericNonAssociativeAlgebra| |IdealDecompositionPackage| |InnerAlgebraicNumber| |InnerNumericFloatSolvePackage| |LexTriangularPackage| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |NewSparseMultivariatePolynomial| |NonLinearSolvePackage| |Numeric| |NumericComplexEigenPackage| |NumericRealEigenPackage| |OrdinaryWeightedPolynomials| |ParametricLinearEquations| |PartialFractionPackage| |PatternMatch| |Pi| |PlaneAlgebraicCurvePlot| |PolToPol| |PolynomialAN2Expression| |PolynomialFunctions2| |PolynomialIdeals| |PolynomialToUnivariatePolynomial| |PrimitiveElement| |PushVariables| |RadicalEigenPackage| |RadicalSolvePackage| |RationalFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionFactor| |RationalFunctionFactorizer| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalFunctionSum| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealSolvePackage| |RecursivePolynomialCategory&| |RepresentationPackage1| |RetractSolvePackage| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariateTaylorSeries| |StructuralConstantsPackage| |SymbolTable| |SystemSolvePackage| |TaylorSeries| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |UnivariateLaurentSeriesConstructor| |UnivariateTaylorSeries| |WeierstrassPreparation| |ZeroDimensionalSolvePackage| |e04AgentsPackage| |e04mbfAnnaType| |e04nafAnnaType|)
-(|CombinatorialFunction| |DifferentialSparseMultivariatePolynomial| |ElementaryFunctionStructurePackage| |Expression| |ExpressionSpaceODESolver| |FunctionSpace&| |FunctionSpaceFunctions2| |FunctionSpacePrimitiveElement| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GosperSummationMethod| |InnerTrigonometricManipulations| |MRationalFactorize| |ParametricLinearEquations| |PolynomialAN2Expression| |PolynomialCategory&| |PolynomialFunctions2| |QuasiAlgebraicSet2| |RationalFunction| |RealSolvePackage| |TransSolvePackage| |TranscendentalManipulations|)
+(|AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |Asp1| |Asp10| |Asp19| |Asp20| |Asp24| |Asp30| |Asp31| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |CoerceVectorMatrixPackage| |ComplexPatternMatch| |ComplexRootPackage| |DefiniteIntegrationTools| |DiophantineSolutionPackage| |EigenPackage| |Equation| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |Expression| |FGLMIfCanPackage| |FloatingComplexPackage| |FloatingRealPackage| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranPackage| |FortranType| |FramedNonAssociativeAlgebra&| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpacePrimitiveElement| |FunctionSpaceToUnivariatePowerSeries| |FunctionalSpecialFunction| |GenericNonAssociativeAlgebra| |IdealDecompositionPackage| |InnerAlgebraicNumber| |InnerNumericFloatSolvePackage| |LexTriangularPackage| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MyExpression| |MyUnivariatePolynomial| |NewSparseMultivariatePolynomial| |NonLinearSolvePackage| |Numeric| |NumericComplexEigenPackage| |NumericRealEigenPackage| |OrdinaryWeightedPolynomials| |ParametricLinearEquations| |PartialFractionPackage| |PatternMatch| |Pi| |PlaneAlgebraicCurvePlot| |PolToPol| |PolynomialAN2Expression| |PolynomialFunctions2| |PolynomialIdeals| |PolynomialToUnivariatePolynomial| |PrimitiveElement| |PushVariables| |RadicalEigenPackage| |RadicalSolvePackage| |RationalFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionFactor| |RationalFunctionFactorizer| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalFunctionSum| |RationalInterpolation| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealSolvePackage| |RecursivePolynomialCategory&| |RepresentationPackage1| |RetractSolvePackage| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariateTaylorSeries| |StructuralConstantsPackage| |SymbolTable| |SystemSolvePackage| |TaylorSeries| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |UnivariateFormalPowerSeries| |UnivariateLaurentSeriesConstructor| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |WeierstrassPreparation| |ZeroDimensionalSolvePackage| |e04AgentsPackage| |e04mbfAnnaType| |e04nafAnnaType|)
+(|CombinatorialFunction| |DifferentialSparseMultivariatePolynomial| |ElementaryFunctionStructurePackage| |Expression| |ExpressionSpaceODESolver| |FunctionSpace&| |FunctionSpaceFunctions2| |FunctionSpacePrimitiveElement| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GosperSummationMethod| |Guess| |InnerTrigonometricManipulations| |MRationalFactorize| |ParametricLinearEquations| |PolynomialAN2Expression| |PolynomialCategory&| |PolynomialFunctions2| |QuasiAlgebraicSet2| |RationalFunction| |RealSolvePackage| |TransSolvePackage| |TranscendentalManipulations|)
 (|AlgFactor| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |ElementaryFunctionLODESolver| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |Expression| |FunctionSpace&| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |GenusZeroIntegration| |RationalFunction| |RationalFunctionIntegration| |RationalFunctionLimitPackage| |RationalFunctionSign|)
 (|AlgebraicallyClosedField&|)
 (|PolynomialCategory&|)
@@ -410,21 +454,28 @@
 (|IdealDecompositionPackage| |QuasiAlgebraicSet2|)
 (|PolynomialInterpolation|)
 (|InnerPolySum| |NumberTheoreticPolynomialFunctions|)
+(|DesingTreePackage| |LocalParametrizationOfSimplePointPackage| |ProjectiveAlgebraicSetPackage|)
 (|GeneralDistributedMultivariatePolynomial| |QuasiAlgebraicSet| |SparseUnivariatePolynomial| |SymmetricPolynomial| |UnivariatePuiseuxSeriesWithExponentialSingularity|)
 (|AlgebraicFunction| |AlgebraicManipulations| |IntegrationResultToFunction| |PatternMatchIntegration|)
 (|InternalRationalUnivariateRepresentationPackage| |LazardSetSolvingPackage| |QuasiComponentPackage| |RationalUnivariateRepresentationPackage| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory&| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |WuWenTsunTriangularSet| |ZeroDimensionalSolvePackage|)
 (|RadicalSolvePackage|)
 (|PolynomialCategory&|)
-(|AbelianGroup&| |AbelianMonoid&| |AbelianMonoidRing&| |AbelianSemiGroup&| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicNumber| |AlgebraicallyClosedField&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |ApplyRules| |Asp19| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AttributeButtons| |Automorphism| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BinaryExpansion| |Boolean| |CardinalNumber| |CartesianTensor| |Character| |CharacterClass| |CliffordAlgebra| |Color| |CommonOperators| |Complex| |ComplexCategory&| |ComplexRootFindingPackage| |ConstantLODE| |ContinuedFraction| |CoordinateSystems| |CycleIndicators| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductMatrixModule| |DirectProductModule| |DiscreteLogarithmPackage| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DivisionRing&| |DoubleFloat| |DoubleFloatSpecialFunctions| |DrawComplex| |DrawOption| |DrawOptionFunctions0| |ElementaryFunction| |ElementaryFunctionLODESolver| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |EllipticFunctionsUnivariateTaylorSeries| |Equation| |EuclideanModularRing| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionTubePlot| |Factored| |FactoringUtilities| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteLinearAggregateSort| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |Float| |FloatingPointSystem&| |FortranExpression| |FourierSeries| |Fraction| |FractionalIdeal| |FramedAlgebra&| |FramedModule| |FramedNonAssociativeAlgebra&| |FramedNonAssociativeAlgebraFunctions2| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceIntegration| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GaussianFactorizationPackage| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralModulePolynomial| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GraphImage| |GrayCode| |Group&| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTaylorSeries| |InnerTrigonometricManipulations| |Integer| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerMod| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRoots| |IntegralBasisTools| |IntegrationResult| |IntegrationResultToFunction| |InverseLaplaceTransform| |IrredPolyOverFiniteField| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorFactorizer| |LiouvillianFunction| |LocalAlgebra| |Localize| |LyndonWord| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MeshCreationRoutinesForThreeDimensions| |ModMonic| |ModularField| |ModularRing| |Module&| |ModuleOperator| |MoebiusTransform| |Monad&| |MonadWithUnit&| |MonogenicAlgebra&| |Monoid&| |MonoidRing| |MultFiniteFactorize| |MultivariatePolynomial| |MultivariateSquareFree| |NagEigenPackage| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonAssociativeAlgebra&| |NonLinearFirstOrderODESolver| |NonNegativeInteger| |NumberFieldIntegralBasis| |NumberFormats| |Numeric| |NumericTubePlot| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |Octonion| |OctonionCategory&| |OnePointCompletion| |Operator| |OppositeMonogenicLinearOperator| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OrthogonalPolynomialFunctions| |OutputForm| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |ParametricLinearEquations| |PartialFraction| |Partition| |PatternMatchIntegration| |Permanent| |Permutation| |PermutationGroupExamples| |Pi| |PlaneAlgebraicCurvePlot| |Plot| |Plot3D| |PoincareBirkhoffWittLyndonBasis| |Point| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |Polynomial| |PolynomialFactorizationByRecursion| |PolynomialGcdPackage| |PolynomialNumberTheoryFunctions| |PolynomialRing| |PolynomialSolveByFormulas| |PositiveInteger| |PowerSeriesCategory&| |PrecomputedAssociatedEquations| |PrimeField| |Product| |PseudoRemainderSequence| |PureAlgebraicIntegration| |QuadraticForm| |Quaternion| |QuaternionCategory&| |QuotientFieldCategory&| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RandomFloatDistributions| |RandomIntegerDistributions| |RandomNumberSource| |RealClosedField&| |RealClosure| |RealRootCharacterizationCategory&| |RealZeroPackage| |RectangularMatrix| |RecursivePolynomialCategory&| |ReduceLODE| |RegularTriangularSetCategory&| |RepeatedDoubling| |RepeatedSquaring| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RoutinesTable| |Ruleset| |SemiGroup&| |SequentialDifferentialPolynomial| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SquareMatrix| |SquareMatrixCategory&| |StreamTranscendentalFunctions| |SturmHabichtPackage| |SubSpace| |SymmetricFunctions| |SymmetricPolynomial| |TangentExpansions| |TaylorSeries| |ThreeDimensionalViewport| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TranscendentalFunctionCategory&| |TranscendentalIntegration| |TranscendentalManipulations| |TubePlotTools| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |UnivariateFactorize| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialMultiplicationPackage| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCategory&| |ViewDefaultsPackage| |ViewportPackage| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |d01AgentsPackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AbelianGroup&| |AbelianMonoid&| |AbelianMonoidRing&| |AbelianSemiGroup&| |AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicNumber| |AlgebraicallyClosedField&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |ApplyRules| |Asp19| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AttributeButtons| |Automorphism| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |Bezier| |BinaryExpansion| |BlowUpPackage| |Boolean| |CardinalNumber| |CartesianTensor| |Character| |CharacterClass| |CliffordAlgebra| |Color| |Complex| |ComplexCategory&| |ComplexRootFindingPackage| |ConstantLODE| |ContinuedFraction| |CoordinateSystems| |CycleIndicators| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DesingTreePackage| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DivisionRing&| |Divisor| |DoubleFloat| |DoubleFloatSpecialFunctions| |DrawComplex| |DrawOption| |DrawOptionFunctions0| |ElementaryFunction| |ElementaryFunctionLODESolver| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |EllipticFunctionsUnivariateTaylorSeries| |Equation| |EuclideanModularRing| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionTubePlot| |Factored| |FactoringUtilities| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteLinearAggregateSort| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |Float| |FloatingPointSystem&| |FortranExpression| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FramedAlgebra&| |FramedModule| |FramedNonAssociativeAlgebra&| |FramedNonAssociativeAlgebraFunctions2| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceIntegration| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GaussianFactorizationPackage| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GnuDraw| |GraphImage| |GrayCode| |Group&| |Guess| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTaylorSeries| |InnerTrigonometricManipulations| |Integer| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerMod| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRoots| |IntegralBasisTools| |IntegrationResult| |IntegrationResultToFunction| |InterfaceGroebnerPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrredPolyOverFiniteField| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorFactorizer| |LiouvillianFunction| |LocalAlgebra| |LocalParametrizationOfSimplePointPackage| |Localize| |LyndonWord| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MeshCreationRoutinesForThreeDimensions| |ModMonic| |ModularField| |ModularRing| |Module&| |ModuleOperator| |MoebiusTransform| |Monad&| |MonadWithUnit&| |MonogenicAlgebra&| |Monoid&| |MonoidRing| |MultFiniteFactorize| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NagEigenPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonAssociativeAlgebra&| |NonLinearFirstOrderODESolver| |NonNegativeInteger| |NottinghamGroup| |NumberFieldIntegralBasis| |NumberFormats| |Numeric| |NumericTubePlot| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |Octonion| |OctonionCategory&| |OnePointCompletion| |Operator| |OppositeMonogenicLinearOperator| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OrthogonalPolynomialFunctions| |OutputForm| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |ParametricLinearEquations| |PartialFraction| |Partition| |PatternMatchIntegration| |Permanent| |Permutation| |PermutationGroupExamples| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PoincareBirkhoffWittLyndonBasis| |Point| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |Polynomial| |PolynomialFactorizationByRecursion| |PolynomialGcdPackage| |PolynomialNumberTheoryFunctions| |PolynomialRing| |PolynomialSolveByFormulas| |PositiveInteger| |PowerSeriesCategory&| |PrecomputedAssociatedEquations| |PrimeField| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoRemainderSequence| |PureAlgebraicIntegration| |QuadraticForm| |Quaternion| |QuaternionCategory&| |QuotientFieldCategory&| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RandomFloatDistributions| |RandomIntegerDistributions| |RandomNumberSource| |RealClosedField&| |RealClosure| |RealRootCharacterizationCategory&| |RealZeroPackage| |RectangularMatrix| |RecursivePolynomialCategory&| |ReduceLODE| |RegularTriangularSetCategory&| |RepeatedDoubling| |RepeatedSquaring| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RoutinesTable| |Ruleset| |SemiGroup&| |SequentialDifferentialPolynomial| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SquareMatrix| |SquareMatrixCategory&| |StreamTranscendentalFunctions| |SturmHabichtPackage| |SubSpace| |SymmetricFunctions| |SymmetricPolynomial| |TangentExpansions| |TaylorSeries| |TaylorSolve| |ThreeDimensionalViewport| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TranscendentalFunctionCategory&| |TranscendentalIntegration| |TranscendentalManipulations| |TubePlotTools| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialMultiplicationPackage| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |ViewDefaultsPackage| |ViewportPackage| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |d01AgentsPackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|DefiniteIntegrationTools| |ElementaryFunctionSign| |LaplaceTransform| |d01AgentsPackage|)
 (|AssociatedEquations|)
-(|FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldNormalBasis|)
-(|Character| |DistinctDegreeFactorize| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |IndexedFlexibleArray| |InnerIndexedTwoDimensionalArray| |InnerNumericFloatSolvePackage| |LinearSystemMatrixPackage| |MatrixLinearAlgebraFunctions| |ModMonic| |NumberFormats| |PrecomputedAssociatedEquations| |PrimitiveArrayFunctions2| |RadicalFunctionField| |ReductionOfOrder| |StorageEfficientMatrixOperations| |SubResultantPackage| |Symbol| |ThreeDimensionalMatrix| |TranscendentalIntegration| |Tuple|)
+(|FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldNormalBasis| |InterfaceGroebnerPackage|)
+(|BlasLevelOne| |Character| |DistinctDegreeFactorize| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |IndexedFlexibleArray| |InnerIndexedTwoDimensionalArray| |InnerNumericFloatSolvePackage| |LinearSystemMatrixPackage| |MatrixLinearAlgebraFunctions| |ModMonic| |NumberFormats| |PrecomputedAssociatedEquations| |PrimitiveArrayFunctions2| |RadicalFunctionField| |ReductionOfOrder| |StorageEfficientMatrixOperations| |SubResultantPackage| |Symbol| |ThreeDimensionalMatrix| |TranscendentalIntegration| |Tuple|)
 (|FunctionSpacePrimitiveElement|)
 (|PrimitiveRatRicDE| |RationalLODE| |RationalRicDE|)
 (|RationalRicDE|)
 (|NAGLinkSupportPackage|)
 (|PolynomialIdeals| |QuasiAlgebraicSet|)
+(|DesingTreePackage| |GeneralPackageForAlgebraicFunctionField| |IntersectionDivisorPackage|)
+(|InfClsPt| |PackageForAlgebraicFunctionField| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField|)
+(|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |PackageForAlgebraicFunctionFieldOverFiniteField|)
+(|ProjectivePlane|)
+(|AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField|)
+(|FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber|)
 (|SystemODESolver|)
 (|NewSparseUnivariatePolynomial| |SparseUnivariatePolynomial| |SubResultantPackage|)
 (|ElementaryFunctionLODESolver| |ElementaryIntegration| |ElementaryRischDE|)
@@ -439,7 +490,7 @@
 (|TransSolvePackage|)
 (|BinaryExpansion| |DecimalExpansion| |HexadecimalExpansion|)
 (|RandomDistributions| |RandomFloatDistributions| |RandomIntegerDistributions|)
-(|AlgFactor| |BoundIntegerRoots| |FunctionSpaceUnivariatePolynomialFactor| |GenUFactorize| |PointsOfFiniteOrder| |SimpleAlgebraicExtensionAlgFactor|)
+(|AlgFactor| |BoundIntegerRoots| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |FunctionSpaceUnivariatePolynomialFactor| |GenUFactorize| |PointsOfFiniteOrder| |RootsFindingPackage| |SimpleAlgebraicExtensionAlgFactor|)
 (|NonLinearSolvePackage| |RationalFunctionSum|)
 (|SAERationalFunctionAlgFactor|)
 (|IntegrationResultRFToFunction|)
@@ -451,6 +502,7 @@
 (|RightOpenIntervalRootCharacterization|)
 (|PlaneAlgebraicCurvePlot|)
 (|DefiniteIntegrationTools| |InnerNumericFloatSolvePackage| |RealZeroPackageQ|)
+(|Guess|)
 (|PureAlgebraicLODE|)
 (|ElementaryFunctionLODESolver|)
 (|AlgebraicFunctionField| |Any| |CardinalNumber| |CommonOperators| |Float| |FramedModule| |InnerSparseUnivariatePowerSeries| |RadicalFunctionField| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SparseUnivariateLaurentSeries| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |Symbol| |ThreeDimensionalViewport| |UserDefinedPartialOrdering| |ViewDefaultsPackage|)
@@ -458,32 +510,34 @@
 (|RegularTriangularSet|)
 (|RegularChain|)
 (|RegularSetDecompositionPackage| |RegularTriangularSet|)
-(|AbelianGroup&| |AbelianMonoid&| |AbelianSemiGroup&|)
-(|DivisionRing&| |Group&| |InnerTaylorSeries| |ModuleOperator| |Monad&| |MonadWithUnit&| |Monoid&| |PAdicRationalConstructor| |SemiGroup&| |SparseUnivariatePolynomial|)
+(|AbelianGroup&| |AbelianMonoid&| |AbelianSemiGroup&| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber|)
+(|DivisionRing&| |Group&| |InnerTaylorSeries| |ModuleOperator| |Monad&| |MonadWithUnit&| |Monoid&| |NeitherSparseOrDensePowerSeries| |PAdicRationalConstructor| |PseudoAlgebraicClosureOfFiniteField| |SemiGroup&| |SparseUnivariatePolynomial|)
 (|AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |ExpertSystemToolsPackage| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |RoutinesTable| |d01AgentsPackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |d03fafAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|NonLinearSolvePackage|)
 (|ApplyRules| |TranscendentalManipulations|)
 (|RealClosure|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |BlowUpPackage| |ProjectiveAlgebraicSetPackage|)
 (|AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AttributeButtons| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03eefAnnaType| |d03fafAnnaType| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
-(|Any| |AnyFunctions1| |FortranCode| |FortranPackage| |FortranProgram| |FortranScalarType| |InputForm| |NAGLinkSupportPackage| |NumberFormats| |OpenMathPackage| |Result| |SymbolTable|)
+(|Any| |AnyFunctions1| |ApplicationProgramInterface| |AxiomServer| |FortranCode| |FortranPackage| |FortranProgram| |FortranScalarType| |InputForm| |NAGLinkSupportPackage| |NumberFormats| |OpenMathPackage| |Result| |SymbolTable|)
 (|SExpression|)
 (|ScriptFormulaFormat1|)
-(|AnnaNumericalIntegrationPackage| |Asp19| |Asp8| |CombinatorialFunction| |DrawComplex| |ElementaryFunctionDefiniteIntegration| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExpressionTubePlot| |FortranCode| |FortranCodePackage1| |FunctionSpaceSum| |GraphImage| |InnerPolySum| |LiouvillianFunction| |MeshCreationRoutinesForThreeDimensions| |ParametricLinearEquations| |PlaneAlgebraicCurvePlot| |Plot| |Plot3D| |PlotFunctions1| |PlotTools| |RandomIntegerDistributions| |RationalFunctionDefiniteIntegration| |RationalFunctionSum| |SegmentBinding| |SegmentBindingFunctions2| |SegmentFunctions2| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TwoDimensionalPlotClipping| |UniversalSegment| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d03AgentsPackage| |e04AgentsPackage| |e04gcfAnnaType|)
-(|AnnaNumericalIntegrationPackage| |Asp19| |Asp8| |CombinatorialFunction| |DrawNumericHack| |ElementaryFunctionDefiniteIntegration| |Expression| |FortranCode| |FortranCodePackage1| |FunctionSpaceSum| |LiouvillianFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionSum| |SegmentBindingFunctions2| |TopLevelDrawFunctions|)
+(|AnnaNumericalIntegrationPackage| |Asp19| |Asp8| |CombinatorialFunction| |DrawComplex| |ElementaryFunctionDefiniteIntegration| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExpressionTubePlot| |FortranCode| |FortranCodePackage1| |FunctionSpaceSum| |GraphImage| |Guess| |InnerPolySum| |LiouvillianFunction| |MeshCreationRoutinesForThreeDimensions| |ParametricLinearEquations| |PlaneAlgebraicCurvePlot| |Plot| |Plot3D| |PlotFunctions1| |PlotTools| |RandomIntegerDistributions| |RationalFunctionDefiniteIntegration| |RationalFunctionSum| |SegmentBinding| |SegmentBindingFunctions2| |SegmentFunctions2| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TwoDimensionalPlotClipping| |UniversalSegment| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d03AgentsPackage| |e04AgentsPackage| |e04gcfAnnaType|)
+(|AnnaNumericalIntegrationPackage| |Asp19| |Asp8| |CombinatorialFunction| |DrawNumericHack| |ElementaryFunctionDefiniteIntegration| |Expression| |FortranCode| |FortranCodePackage1| |FunctionSpaceSum| |GnuDraw| |Guess| |LiouvillianFunction| |MyExpression| |RationalFunctionDefiniteIntegration| |RationalFunctionSum| |SegmentBindingFunctions2| |TopLevelDrawFunctions|)
 (|DrawNumericHack| |RationalFunctionSum|)
 (|SegmentBindingFunctions2| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions|)
 (|SequentialDifferentialPolynomial|)
-(|BasicOperator| |ExpressionSpace&| |Factored| |GaloisGroupFactorizer| |GeneralPolynomialSet| |IntegerPrimesPackage| |ModularHermitianRowReduction| |MonoidRing| |ParametricLinearEquations| |Pattern| |Permutation| |PermutationGroup| |PolynomialSetCategory&| |QuasiAlgebraicSet| |RandomDistributions| |SymmetricGroupCombinatoricFunctions| |ThreeDimensionalViewport| |ThreeSpace|)
+(|ApplicationProgramInterface| |BasicOperator| |ExpressionSpace&| |Factored| |GaloisGroupFactorizer| |GeneralPolynomialSet| |IntegerPrimesPackage| |ModularHermitianRowReduction| |MonoidRing| |ParametricLinearEquations| |Pattern| |Permutation| |PermutationGroup| |PolynomialSetCategory&| |QuasiAlgebraicSet| |RandomDistributions| |SymmetricGroupCombinatoricFunctions| |ThreeDimensionalViewport| |ThreeSpace|)
 (|AlgebraicFunctionField| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtensionByPolynomial| |RadicalFunctionField|)
-(|AlgebraGivenByStructuralConstants| |AlgebraicFunctionField| |AlgebraicNumber| |AnonymousFunction| |AntiSymm| |Any| |ArrayStack| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |BalancedBinaryTree| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BinaryExpansion| |BinaryFile| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |Boolean| |CardinalNumber| |CartesianTensor| |Character| |CharacterClass| |CliffordAlgebra| |Color| |Commutator| |Complex| |ComplexRootFindingPackage| |ContinuedFraction| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DenavitHartenbergMatrix| |Dequeue| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductMatrixModule| |DirectProductModule| |DistributedMultivariatePolynomial| |DoubleFloat| |DrawOption| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionSign| |EqTable| |Equation| |EuclideanModularRing| |Exit| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExtAlgBasis| |Factored| |File| |FileName| |FiniteDivisor| |FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FlexibleArray| |Float| |FortranCode| |FortranExpression| |FortranProgram| |FortranTemplate| |FortranType| |FourierComponent| |FourierSeries| |Fraction| |FractionalIdeal| |FramedModule| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionCalled| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GraphImage| |HashTable| |Heap| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IndexCard| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerNormalBasisFieldFunctions| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InputForm| |Integer| |IntegerMod| |IntegrationResult| |Kernel| |KeyedAccessFile| |LaurentPolynomial| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |List| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |Localize| |LyndonWord| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeCachableSet| |Matrix| |MatrixLinearAlgebraFunctions| |ModMonic| |ModularField| |ModularRing| |ModuleMonomial| |ModuleOperator| |MoebiusTransform| |MonoidRing| |Multiset| |MultivariatePolynomial| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonNegativeInteger| |None| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalPDEProblem| |NumericalQuadrature| |Octonion| |OneDimensionalArray| |OnePointCompletion| |OpenMathConnection| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OpenMathServerPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedCompletionFunctions2| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OutputForm| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |Palette| |PartialFraction| |Partition| |Pattern| |PatternMatchIntegration| |PatternMatchListResult| |PatternMatchResult| |PendantTree| |Permutation| |PermutationGroup| |Pi| |PoincareBirkhoffWittLyndonBasis| |Point| |Polynomial| |PolynomialIdeals| |PolynomialRing| |PositiveInteger| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveArray| |Product| |QuadraticForm| |QuasiAlgebraicSet| |Quaternion| |Queue| |RadicalFunctionField| |RadixExpansion| |RandomDistributions| |RationalFunctionLimitPackage| |RationalFunctionSign| |RealClosure| |RectangularMatrix| |Reference| |RegularChain| |RegularTriangularSet| |ResidueRing| |Result| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RoutinesTable| |RuleCalled| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentBinding| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetCategory&| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SingletonAsOrderedSet| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeRegularTriangularSet| |SquareMatrix| |Stack| |Stream| |String| |StringTable| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |Symbol| |SymmetricPolynomial| |Table| |TaylorSeries| |TexFormat| |TextFile| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |Tree| |Tuple| |TwoDimensionalArray| |TwoDimensionalViewport| |UTSodetools| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateTaylorSeries| |UniversalSegment| |Variable| |Vector| |WeightedPolynomials| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |d01AgentsPackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03eefAnnaType| |d03fafAnnaType| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
-(|ExponentialOfUnivariatePuiseuxSeries| |GeneralUnivariatePowerSeries| |InnerSparseUnivariatePowerSeries| |ModMonic| |MultivariateSquareFree| |NewSparseUnivariatePolynomial| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePowerSeriesCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariateTaylorSeries|)
+(|AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgebraGivenByStructuralConstants| |AlgebraicFunctionField| |AlgebraicNumber| |AnonymousFunction| |AntiSymm| |Any| |ArrayStack| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |BalancedBinaryTree| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BinaryExpansion| |BinaryFile| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlasLevelOne| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |CardinalNumber| |CartesianTensor| |Character| |CharacterClass| |CliffordAlgebra| |Color| |Commutator| |Complex| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexRootFindingPackage| |ContinuedFraction| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DistributedMultivariatePolynomial| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatVector| |DrawOption| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionSign| |EqTable| |Equation| |EuclideanModularRing| |Exit| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExtAlgBasis| |Factored| |File| |FileName| |FiniteDivisor| |FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FlexibleArray| |Float| |FortranCode| |FortranExpression| |FortranProgram| |FortranTemplate| |FortranType| |FourierComponent| |FourierSeries| |Fraction| |FractionalIdeal| |FramedModule| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionCalled| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GraphImage| |GuessOption| |GuessOptionFunctions0| |HTMLFormat| |HashTable| |Heap| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IndexCard| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerNormalBasisFieldFunctions| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InputForm| |Integer| |IntegerMod| |IntegrationResult| |Interval| |Kernel| |KeyedAccessFile| |LaurentPolynomial| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |List| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |Localize| |LyndonWord| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeCachableSet| |MathMLFormat| |Matrix| |MatrixLinearAlgebraFunctions| |ModMonic| |ModularField| |ModularRing| |ModuleMonomial| |ModuleOperator| |MoebiusTransform| |MonoidRing| |Multiset| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonNegativeInteger| |None| |NottinghamGroup| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalPDEProblem| |NumericalQuadrature| |Octonion| |OneDimensionalArray| |OnePointCompletion| |OpenMathConnection| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OpenMathServerPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedCompletionFunctions2| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OutputForm| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |Palette| |PartialFraction| |Partition| |Pattern| |PatternMatchIntegration| |PatternMatchListResult| |PatternMatchResult| |PendantTree| |Permutation| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |Plcs| |PoincareBirkhoffWittLyndonBasis| |Point| |Polynomial| |PolynomialIdeals| |PolynomialRing| |PositiveInteger| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveArray| |Product| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |QuadraticForm| |QuasiAlgebraicSet| |Quaternion| |Queue| |RadicalFunctionField| |RadixExpansion| |RandomDistributions| |RationalFunctionLimitPackage| |RationalFunctionSign| |RealClosure| |RectangularMatrix| |Reference| |RegularChain| |RegularTriangularSet| |ResidueRing| |Result| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RoutinesTable| |RuleCalled| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentBinding| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetCategory&| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SingletonAsOrderedSet| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeRegularTriangularSet| |SquareMatrix| |Stack| |Stream| |String| |StringTable| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |Symbol| |SymmetricPolynomial| |Table| |TaylorSeries| |TexFormat| |TextFile| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |Tree| |Tuple| |TwoDimensionalArray| |TwoDimensionalViewport| |UTSodetools| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UniversalSegment| |Variable| |Vector| |WeightedPolynomials| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |d01AgentsPackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03eefAnnaType| |d03fafAnnaType| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|ExponentialOfUnivariatePuiseuxSeries| |GeneralUnivariatePowerSeries| |InnerSparseUnivariatePowerSeries| |ModMonic| |MultivariateSquareFree| |MyUnivariatePolynomial| |NeitherSparseOrDensePowerSeries| |NewSparseUnivariatePolynomial| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePowerSeriesCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero|)
 (|TranscendentalRischDESystem|)
 (|Kernel| |MakeCachableSet|)
-(|AlgebraicFunction| |AlgebraicManipulations| |AlgebraicNumber| |CombinatorialFunction| |ComplexTrigonometricManipulations| |DifferentialSparseMultivariatePolynomial| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |Expression| |ExpressionSpaceODESolver| |FunctionSpace&| |FunctionSpaceFunctions2| |FunctionSpacePrimitiveElement| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GosperSummationMethod| |InnerAlgebraicNumber| |InnerTrigonometricManipulations| |IntegrationResultToFunction| |IntegrationTools| |InverseLaplaceTransform| |LaplaceTransform| |MRationalFactorize| |MultFiniteFactorize| |MultivariatePolynomial| |NewSparseMultivariatePolynomial| |NonLinearFirstOrderODESolver| |ODEIntegration| |OrderlyDifferentialPolynomial| |PatternMatchFunctionSpace| |PatternMatchIntegration| |PointsOfFiniteOrder| |Polynomial| |PureAlgebraicIntegration| |SequentialDifferentialPolynomial| |TransSolvePackage| |TranscendentalManipulations|)
+(|AlgebraicFunction| |AlgebraicManipulations| |AlgebraicNumber| |CombinatorialFunction| |ComplexTrigonometricManipulations| |DifferentialSparseMultivariatePolynomial| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |Expression| |ExpressionSpaceODESolver| |FunctionSpace&| |FunctionSpaceFunctions2| |FunctionSpacePrimitiveElement| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GosperSummationMethod| |Guess| |InnerAlgebraicNumber| |InnerTrigonometricManipulations| |IntegrationResultToFunction| |IntegrationTools| |InverseLaplaceTransform| |LaplaceTransform| |MRationalFactorize| |MultFiniteFactorize| |MultivariatePolynomial| |MyExpression| |NewSparseMultivariatePolynomial| |NonLinearFirstOrderODESolver| |ODEIntegration| |OrderlyDifferentialPolynomial| |PatternMatchFunctionSpace| |PatternMatchIntegration| |PointsOfFiniteOrder| |Polynomial| |PureAlgebraicIntegration| |RecurrenceOperator| |SequentialDifferentialPolynomial| |TransSolvePackage| |TranscendentalManipulations|)
 (|TaylorSeries|)
 (|SparseUnivariatePuiseuxSeries|)
-(|AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicMultFact| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |BalancedPAdicInteger| |BalancedPAdicRational| |BinaryExpansion| |BoundIntegerRoots| |CharacteristicPolynomialInMonogenicalAlgebra| |ChineseRemainderToolsForIntegralBases| |Complex| |ComplexCategory&| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexPatternMatch| |ComplexRootPackage| |ConstantLODE| |ContinuedFraction| |CyclotomicPolynomialPackage| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DistributedMultivariatePolynomial| |DoubleFloat| |DoubleResultantPackage| |EigenPackage| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |EuclideanModularRing| |ExpertSystemContinuityPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSpaceODESolver| |FGLMIfCanPackage| |Factored| |FactoringUtilities| |FiniteAlgebraicExtensionField&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteRankNonAssociativeAlgebra&| |Float| |FloatingComplexPackage| |FortranExpression| |Fraction| |FractionalIdeal| |FramedNonAssociativeAlgebra&| |FullPartialFractionExpansion| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GcdDomain&| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralPolynomialGcdPackage| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |GroebnerSolve| |HexadecimalExpansion| |HomogeneousDistributedMultivariatePolynomial| |IdealDecompositionPackage| |InfiniteProductFiniteField| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySum| |InnerPrimeField| |InnerTrigonometricManipulations| |Integer| |IntegerCombinatoricFunctions| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegrationResult| |IntegrationResultFunctions2| |IntegrationResultToFunction| |IntegrationTools| |InverseLaplaceTransform| |IrredPolyOverFiniteField| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LeadingCoefDetermination| |LieSquareMatrix| |LinGroebnerPackage| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearPolynomialEquationByFractions| |LinearSystemPolynomialPackage| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MachineFloat| |MachineInteger| |ModMonic| |ModularField| |MultFiniteFactorize| |MultivariateFactorize| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |NPCoef| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonLinearFirstOrderODESolver| |NonLinearSolvePackage| |NormInMonogenicAlgebra| |NormRetractPackage| |NumberTheoreticPolynomialFunctions| |NumericComplexEigenPackage| |NumericRealEigenPackage| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PartialFraction| |PartialFractionPackage| |PatternMatchIntegration| |Pi| |PiCoercions| |PlaneAlgebraicCurvePlot| |PointsOfFiniteOrder| |Polynomial| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialInterpolation| |PolynomialNumberTheoryFunctions| |PolynomialSquareFree| |PolynomialToUnivariatePolynomial| |PrimeField| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |PureAlgebraicIntegration| |PushVariables| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RationalFactorize| |RationalFunctionFactor| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealZeroPackageQ| |RecursivePolynomialCategory&| |ReducedDivisor| |RetractSolvePackage| |RomanNumeral| |SequentialDifferentialPolynomial| |SimpleAlgebraicExtension| |SingleInteger| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialFunctions2| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SupFractionFactorizer| |SymmetricFunctions| |SystemSolvePackage| |TangentExpansions| |TransSolvePackage| |TransSolvePackageService| |TranscendentalIntegration| |TranscendentalManipulations| |TwoFactorize| |UnivariateFactorize| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |WeierstrassPreparation| |WeightedPolynomials| |ZeroDimensionalSolvePackage|)
-(|AlgebraicIntegration| |DefiniteIntegrationTools| |ElementaryFunctionLODESolver| |FiniteFieldPolynomialPackage2| |FunctionSpace&| |FunctionSpaceReduce| |GenusZeroIntegration| |InnerAlgebraicNumber| |InnerPolySum| |InnerTrigonometricManipulations| |IntegrationResultFunctions2| |MultivariateLifting| |Pi| |PiCoercions| |PointsOfFiniteOrder| |PolynomialCategoryQuotientFunctions| |PureAlgebraicIntegration| |RadicalSolvePackage| |RealClosedField&| |TranscendentalIntegration| |TranscendentalManipulations|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicMultFact| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |BalancedPAdicInteger| |BalancedPAdicRational| |BinaryExpansion| |BlowUpPackage| |BoundIntegerRoots| |CharacteristicPolynomialInMonogenicalAlgebra| |ChineseRemainderToolsForIntegralBases| |Complex| |ComplexCategory&| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexPatternMatch| |ComplexRootPackage| |ConstantLODE| |ContinuedFraction| |CyclotomicPolynomialPackage| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DistributedMultivariatePolynomial| |DoubleFloat| |DoubleResultantPackage| |EigenPackage| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |EuclideanModularRing| |ExpertSystemContinuityPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSpaceODESolver| |FGLMIfCanPackage| |Factored| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |FiniteAlgebraicExtensionField&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteRankNonAssociativeAlgebra&| |Float| |FloatingComplexPackage| |FortranExpression| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FramedNonAssociativeAlgebra&| |FullPartialFractionExpansion| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GcdDomain&| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |GroebnerSolve| |Guess| |HexadecimalExpansion| |HomogeneousDistributedMultivariatePolynomial| |IdealDecompositionPackage| |InfiniteProductFiniteField| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySum| |InnerPrimeField| |InnerTrigonometricManipulations| |Integer| |IntegerCombinatoricFunctions| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegrationResult| |IntegrationResultFunctions2| |IntegrationResultToFunction| |IntegrationTools| |Interval| |InverseLaplaceTransform| |IrredPolyOverFiniteField| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LeadingCoefDetermination| |LieSquareMatrix| |LinGroebnerPackage| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearPolynomialEquationByFractions| |LinearSystemPolynomialPackage| |LocalParametrizationOfSimplePointPackage| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MachineFloat| |MachineInteger| |MatrixCategory&| |ModMonic| |ModularField| |MultFiniteFactorize| |MultivariateFactorize| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NPCoef| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonInterpolation| |NonLinearFirstOrderODESolver| |NonLinearSolvePackage| |NormInMonogenicAlgebra| |NormRetractPackage| |NumberTheoreticPolynomialFunctions| |NumericComplexEigenPackage| |NumericRealEigenPackage| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |PartialFraction| |PartialFractionPackage| |PatternMatchIntegration| |Pi| |PiCoercions| |PlaneAlgebraicCurvePlot| |PointsOfFiniteOrder| |Polynomial| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialInterpolation| |PolynomialNumberTheoryFunctions| |PolynomialSquareFree| |PolynomialToUnivariatePolynomial| |PrimeField| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |ProjectiveAlgebraicSetPackage| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PureAlgebraicIntegration| |PushVariables| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RationalFactorize| |RationalFunctionFactor| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealZeroPackageQ| |RecurrenceOperator| |RecursivePolynomialCategory&| |ReducedDivisor| |RetractSolvePackage| |RomanNumeral| |RootsFindingPackage| |SequentialDifferentialPolynomial| |SimpleAlgebraicExtension| |SingleInteger| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePolynomialFunctions2| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SupFractionFactorizer| |SymmetricFunctions| |SystemSolvePackage| |TangentExpansions| |TransSolvePackage| |TransSolvePackageService| |TranscendentalIntegration| |TranscendentalManipulations| |TwoFactorize| |UnivariateFactorize| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |WeierstrassPreparation| |WeightedPolynomials| |ZeroDimensionalSolvePackage|)
+(|ExpressionSolve| |TaylorSolve|)
+(|AlgebraicIntegration| |DefiniteIntegrationTools| |ElementaryFunctionLODESolver| |FiniteFieldPolynomialPackage2| |FunctionSpace&| |FunctionSpaceReduce| |GenusZeroIntegration| |Guess| |InnerAlgebraicNumber| |InnerPolySum| |InnerTrigonometricManipulations| |IntegrationResultFunctions2| |MultivariateLifting| |Pi| |PiCoercions| |PointsOfFiniteOrder| |PolynomialCategoryQuotientFunctions| |PureAlgebraicIntegration| |RadicalSolvePackage| |RealClosedField&| |TranscendentalIntegration| |TranscendentalManipulations|)
 (|LinearOrdinaryDifferentialOperator| |UnivariateSkewPolynomial|)
 (|SparseUnivariateLaurentSeries| |SparseUnivariatePuiseuxSeries|)
 (|SplittingTree| |WuWenTsunTriangularSet|)
@@ -495,41 +549,43 @@
 (|AlgebraGivenByStructuralConstants| |CartesianTensor| |GenericNonAssociativeAlgebra| |LieSquareMatrix| |Permanent| |QuadraticForm|)
 (|FortranOutputStackPackage| |Queue|)
 (|Matrix|)
-(|BalancedPAdicInteger| |BasicFunctions| |ContinuedFraction| |CycleIndicators| |ElementaryFunctionsUnivariateLaurentSeries| |EllipticFunctionsUnivariateTaylorSeries| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialOfUnivariatePuiseuxSeries| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |InfiniteProductCharacteristicZero| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InfiniteTuple| |InfiniteTupleFunctions2| |InfiniteTupleFunctions3| |InnerPAdicInteger| |InnerSparseUnivariatePowerSeries| |InnerTaylorSeries| |NumericContinuedFraction| |PAdicInteger| |PAdicRationalConstructor| |PadeApproximants| |ParadoxicalCombinatorsForStreams| |PartitionsAndPermutations| |RadixExpansion| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |Stream| |StreamFunctions1| |StreamFunctions2| |StreamFunctions3| |StreamInfiniteProduct| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |TableauxBumpers| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesFunctions2| |UnivariateTaylorSeriesODESolver| |UniversalSegment| |UniversalSegmentFunctions2| |WeierstrassPreparation| |d01AgentsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01aqfAnnaType| |e04gcfAnnaType|)
-(|PartitionsAndPermutations|)
-(|ContinuedFraction| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InfiniteTupleFunctions2| |PartitionsAndPermutations| |SparseMultivariateTaylorSeries| |Stream| |StreamFunctions3| |StreamInfiniteProduct| |StreamTaylorSeriesOperations| |TableauxBumpers| |UnivariatePuiseuxSeriesConstructor| |UnivariateTaylorSeriesFunctions2| |UniversalSegmentFunctions2| |WeierstrassPreparation|)
-(|InfiniteTupleFunctions3| |PartitionsAndPermutations| |SparseMultivariateTaylorSeries| |Stream| |StreamTaylorSeriesOperations| |WeierstrassPreparation|)
+(|BalancedPAdicInteger| |BasicFunctions| |ContinuedFraction| |CycleIndicators| |DirichletRing| |ElementaryFunctionsUnivariateLaurentSeries| |EllipticFunctionsUnivariateTaylorSeries| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialOfUnivariatePuiseuxSeries| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |Guess| |InfiniteProductCharacteristicZero| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InfiniteTuple| |InfiniteTupleFunctions2| |InfiniteTupleFunctions3| |InnerPAdicInteger| |InnerSparseUnivariatePowerSeries| |InnerTaylorSeries| |LinearSystemFromPowerSeriesPackage| |NeitherSparseOrDensePowerSeries| |NumericContinuedFraction| |PAdicInteger| |PAdicRationalConstructor| |PadeApproximants| |ParadoxicalCombinatorsForStreams| |PartitionsAndPermutations| |RadixExpansion| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |Stream| |StreamFunctions1| |StreamFunctions2| |StreamFunctions3| |StreamInfiniteProduct| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |TableauxBumpers| |TaylorSolve| |UnivariateFormalPowerSeries| |UnivariateFormalPowerSeriesFunctions| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesFunctions2| |UnivariateTaylorSeriesODESolver| |UniversalSegment| |UniversalSegmentFunctions2| |WeierstrassPreparation| |d01AgentsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01aqfAnnaType| |e04gcfAnnaType|)
+(|Guess| |PartitionsAndPermutations|)
+(|ContinuedFraction| |DirichletRing| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |FractionFreeFastGaussian| |Guess| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InfiniteTupleFunctions2| |PartitionsAndPermutations| |SparseMultivariateTaylorSeries| |Stream| |StreamFunctions3| |StreamInfiniteProduct| |StreamTaylorSeriesOperations| |TableauxBumpers| |UnivariatePuiseuxSeriesConstructor| |UnivariateTaylorSeriesFunctions2| |UniversalSegmentFunctions2| |WeierstrassPreparation|)
+(|InfiniteTupleFunctions3| |PartitionsAndPermutations| |SparseMultivariateTaylorSeries| |Stream| |StreamTaylorSeriesOperations| |UnivariateFormalPowerSeriesFunctions| |WeierstrassPreparation|)
 (|InfiniteProductCharacteristicZero| |InfiniteProductPrimeField|)
-(|EllipticFunctionsUnivariateTaylorSeries| |InfiniteProductFiniteField| |InnerTaylorSeries| |SparseMultivariateTaylorSeries| |StreamInfiniteProduct| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |UnivariateLaurentSeriesConstructor| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesODESolver| |WeierstrassPreparation|)
+(|DirichletRing| |EllipticFunctionsUnivariateTaylorSeries| |InfiniteProductFiniteField| |InnerTaylorSeries| |SparseMultivariateTaylorSeries| |StreamInfiniteProduct| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |UnivariateLaurentSeriesConstructor| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesODESolver| |WeierstrassPreparation|)
 (|ElementaryFunctionsUnivariateLaurentSeries| |InfiniteProductFiniteField| |SparseMultivariateTaylorSeries| |StreamInfiniteProduct| |StreamTranscendentalFunctionsNonCommutative| |UnivariateTaylorSeriesCategory&|)
 (|UnivariateTaylorSeriesCategory&|)
-(|AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AnonymousFunction| |AntiSymm| |Any| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |BalancedBinaryTree| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BinaryExpansion| |BinaryFile| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |Boolean| |CardinalNumber| |CartesianTensor| |Character| |CharacterClass| |CliffordAlgebra| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |Complex| |ComplexCategory&| |ComplexPattern| |ComplexPatternMatch| |ComplexRootFindingPackage| |ComplexTrigonometricManipulations| |ContinuedFraction| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DenavitHartenbergMatrix| |Dequeue| |DictionaryOperations&| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductMatrixModule| |DirectProductModule| |DiscreteLogarithmPackage| |DisplayPackage| |DistributedMultivariatePolynomial| |DoubleFloat| |DrawComplex| |DrawOption| |DrawOptionFunctions0| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |EqTable| |Equation| |ErrorFunctions| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |Exit| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSpace&| |ExpressionSpaceFunctions1| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionTubePlot| |ExtAlgBasis| |Factored| |File| |FileName| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteRankNonAssociativeAlgebra&| |FlexibleArray| |Float| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranOutputStackPackage| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |FourierComponent| |FourierSeries| |Fraction| |FractionalIdeal| |FramedModule| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionCalled| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionalSpecialFunction| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GraphImage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |HashTable| |Heap| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IndexCard| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |InputFormFunctions1| |Integer| |IntegerMod| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InternalPrintPackage| |InternalRationalUnivariateRepresentationPackage| |Kernel| |KeyedAccessFile| |LaplaceTransform| |LaurentPolynomial| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LiouvillianFunction| |List| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |Localize| |LyndonWord| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeCachableSet| |MakeFloatCompiledFunction| |Matrix| |ModMonic| |ModularField| |ModularRing| |ModuleMonomial| |ModuleOperator| |MoebiusTransform| |MonoidRing| |MoreSystemCommands| |Multiset| |MultivariatePolynomial| |NAGLinkSupportPackage| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonNegativeInteger| |None| |NormalizationPackage| |NumberFormats| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalOrdinaryDifferentialEquations| |NumericalPDEProblem| |NumericalQuadrature| |ODEIntegration| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OnePointCompletion| |OpenMathConnection| |OpenMathDevice| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OpenMathPackage| |OpenMathServerPackage| |OperationsQuery| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |Palette| |ParametricLinearEquations| |PartialFraction| |Partition| |Pattern| |PatternMatchAssertions| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchListResult| |PatternMatchResult| |PendantTree| |Permutation| |PermutationGroup| |Pi| |PlaneAlgebraicCurvePlot| |PoincareBirkhoffWittLyndonBasis| |Point| |PointsOfFiniteOrder| |Polynomial| |PolynomialIdeals| |PolynomialRing| |PositiveInteger| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveArray| |Product| |PureAlgebraicIntegration| |QuadraticForm| |QuasiAlgebraicSet| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |QueryEquation| |Queue| |RadicalFunctionField| |RadixExpansion| |RationalFunctionDefiniteIntegration| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalUnivariateRepresentationPackage| |RealClosure| |RectangularMatrix| |RecursivePolynomialCategory&| |Reference| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetGcdPackage| |RepresentationPackage2| |ResidueRing| |Result| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RoutinesTable| |RuleCalled| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentBinding| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetCategory&| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SingletonAsOrderedSet| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |Stack| |Stream| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringTable| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |Switch| |Symbol| |SymbolTable| |SymmetricPolynomial| |Table| |Tableau| |TabulatedComputationPackage| |TaylorSeries| |TemplateUtilities| |TexFormat| |TextFile| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |ToolsForSign| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TranscendentalManipulations| |Tree| |TrigonometricManipulations| |Tuple| |TwoDimensionalArray| |TwoDimensionalViewport| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateTaylorSeries| |UniversalSegment| |Variable| |Vector| |ViewDefaultsPackage| |ViewportPackage| |WeightedPolynomials| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03eefAnnaType| |d03fafAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AnonymousFunction| |AntiSymm| |Any| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |AxiomServer| |BalancedBinaryTree| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BinaryExpansion| |BinaryFile| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |CardinalNumber| |CartesianTensor| |Character| |CharacterClass| |CliffordAlgebra| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexPattern| |ComplexPatternMatch| |ComplexRootFindingPackage| |ComplexTrigonometricManipulations| |ContinuedFraction| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DictionaryOperations&| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DisplayPackage| |DistributedMultivariatePolynomial| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatVector| |DrawComplex| |DrawOption| |DrawOptionFunctions0| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |EqTable| |Equation| |ErrorFunctions| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |Exit| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Export3D| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceFunctions1| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionTubePlot| |ExtAlgBasis| |Factored| |File| |FileName| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteRankNonAssociativeAlgebra&| |FlexibleArray| |Float| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranOutputStackPackage| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |FourierComponent| |FourierSeries| |Fraction| |FractionalIdeal| |FramedModule| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionCalled| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionalSpecialFunction| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GnuDraw| |GraphImage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |Guess| |GuessOption| |GuessOptionFunctions0| |HTMLFormat| |HashTable| |Heap| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IndexCard| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |InputFormFunctions1| |Integer| |IntegerMod| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InternalPrintPackage| |InternalRationalUnivariateRepresentationPackage| |Interval| |Kernel| |KeyedAccessFile| |LaplaceTransform| |LaurentPolynomial| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LiouvillianFunction| |List| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |Localize| |LyndonWord| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeCachableSet| |MakeFloatCompiledFunction| |MathMLFormat| |Matrix| |ModMonic| |ModularField| |ModularRing| |ModuleMonomial| |ModuleOperator| |MoebiusTransform| |MonoidRing| |MoreSystemCommands| |Multiset| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonNegativeInteger| |None| |NormalizationPackage| |NottinghamGroup| |NumberFormats| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalOrdinaryDifferentialEquations| |NumericalPDEProblem| |NumericalQuadrature| |ODEIntegration| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OnePointCompletion| |OpenMathConnection| |OpenMathDevice| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OpenMathPackage| |OpenMathServerPackage| |OperationsQuery| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |Palette| |ParametricLinearEquations| |PartialFraction| |Partition| |Pattern| |PatternMatchAssertions| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchListResult| |PatternMatchResult| |PendantTree| |Permutation| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |PoincareBirkhoffWittLyndonBasis| |Point| |PointsOfFiniteOrder| |Polynomial| |PolynomialIdeals| |PolynomialRing| |PositiveInteger| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveArray| |Product| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PureAlgebraicIntegration| |QuadraticForm| |QuasiAlgebraicSet| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |QueryEquation| |Queue| |RadicalFunctionField| |RadixExpansion| |RationalFunctionDefiniteIntegration| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalUnivariateRepresentationPackage| |RealClosure| |RectangularMatrix| |RecurrenceOperator| |RecursivePolynomialCategory&| |Reference| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetGcdPackage| |RepresentationPackage2| |ResidueRing| |Result| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RoutinesTable| |RuleCalled| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentBinding| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetCategory&| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SingletonAsOrderedSet| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |Stack| |Stream| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringTable| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |Switch| |Symbol| |SymbolTable| |SymmetricPolynomial| |Table| |Tableau| |TabulatedComputationPackage| |TaylorSeries| |TemplateUtilities| |TexFormat| |TextFile| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |ToolsForSign| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TranscendentalManipulations| |Tree| |TrigonometricManipulations| |Tuple| |TwoDimensionalArray| |TwoDimensionalViewport| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UniversalSegment| |Variable| |Vector| |ViewDefaultsPackage| |ViewportPackage| |WeightedPolynomials| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03eefAnnaType| |d03fafAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|InnerNumericFloatSolvePackage| |TranscendentalIntegration|)
-(|ThreeSpace|)
+(|Export3D| |ThreeSpace|)
 (|MeshCreationRoutinesForThreeDimensions| |SubSpace| |ThreeDimensionalViewport| |ThreeSpace|)
 (|EigenPackage| |PolynomialIdeals| |RadicalEigenPackage| |RadicalSolvePackage|)
 (|Expression|)
 (|Asp12| |Asp30| |Asp35| |Asp55| |Asp74| |Asp8| |FortranCode|)
-(|AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |Any| |ApplyRules| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AttachPredicates| |AttributeButtons| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BinaryExpansion| |Boolean| |CombinatorialFunction| |CommonOperators| |Complex| |ComplexCategory&| |ComplexPattern| |ComplexPatternMatch| |ComplexRootPackage| |ComplexTrigonometricManipulations| |ConstantLODE| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DifferentialExtension&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DrawOption| |DrawOptionFunctions0| |DrawOptionFunctions1| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |Equation| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |FGLMIfCanPackage| |Factored| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasisExtensionByPolynomial| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranType| |Fraction| |FramedNonAssociativeAlgebra&| |FullPartialFractionExpansion| |FullyEvalableOver&| |FunctionCalled| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |HexadecimalExpansion| |HomogeneousDirectProduct| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexCard| |InnerAlgebraicNumber| |InnerNumericFloatSolvePackage| |InnerSparseUnivariatePowerSeries| |InnerTrigonometricManipulations| |InputForm| |InputFormFunctions1| |IntegrationResult| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |InternalPrintPackage| |InverseLaplaceTransform| |Kernel| |KeyedAccessFile| |LaplaceTransform| |LaurentPolynomial| |LexTriangularPackage| |Library| |LieSquareMatrix| |LinGroebnerPackage| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperatorsOps| |LiouvillianFunction| |List| |ListMultiDictionary| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MakeBinaryCompiledFunction| |MakeFloatCompiledFunction| |MakeFunction| |MakeUnaryCompiledFunction| |Matrix| |ModMonic| |MonogenicAlgebra&| |Multiset| |NAGLinkSupportPackage| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NewSparseUnivariatePolynomial| |NonLinearFirstOrderODESolver| |NonLinearSolvePackage| |NumberFormats| |NumericComplexEigenPackage| |NumericRealEigenPackage| |ODEIntegration| |Octonion| |OctonionCategory&| |OpenMathDevice| |OpenMathError| |OpenMathErrorKind| |OrdSetInts| |OrderedDirectProduct| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OutputForm| |PAdicRational| |PAdicRationalConstructor| |ParametricLinearEquations| |PartialFractionPackage| |Pattern| |PatternFunctions2| |PatternMatch| |PatternMatchAssertions| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchPushDown| |PatternMatchResult| |PatternMatchSymbol| |PermutationGroup| |Pi| |PlaneAlgebraicCurvePlot| |PlotFunctions1| |PolToPol| |Polynomial| |PolynomialAN2Expression| |PolynomialFunctions2| |PolynomialIdeals| |PolynomialToUnivariatePolynomial| |PowerSeriesLimitPackage| |PrimitiveElement| |PureAlgebraicIntegration| |PushVariables| |QuasiAlgebraicSet2| |Quaternion| |QuaternionCategory&| |QueryEquation| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RationalFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionFactor| |RationalFunctionIntegration| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalFunctionSum| |RationalLODE| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosure| |RealSolvePackage| |RectangularMatrix| |RecursivePolynomialCategory&| |RepresentationPackage1| |Result| |RetractSolvePackage| |RewriteRule| |RomanNumeral| |RoutinesTable| |RuleCalled| |SExpression| |SegmentBinding| |SegmentBindingFunctions2| |SequentialDifferentialPolynomial| |Set| |SimpleAlgebraicExtension| |SimpleFortranProgram| |SingletonAsOrderedSet| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SquareMatrix| |SquareMatrixCategory&| |StructuralConstantsPackage| |Switch| |Symbol| |SymbolTable| |SystemSolvePackage| |TaylorSeries| |TheSymbolTable| |ThreeDimensionalMatrix| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TransSolvePackageService| |TranscendentalManipulations| |TrigonometricManipulations| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCategory&| |Variable| |Vector| |WeierstrassPreparation| |XPolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |Any| |ApplicationProgramInterface| |ApplyRules| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AttachPredicates| |AttributeButtons| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BinaryExpansion| |Boolean| |CombinatorialFunction| |CommonOperators| |Complex| |ComplexCategory&| |ComplexPattern| |ComplexPatternMatch| |ComplexRootPackage| |ComplexTrigonometricManipulations| |ConstantLODE| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DesingTreePackage| |DifferentialExtension&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DrawOption| |DrawOptionFunctions0| |DrawOptionFunctions1| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |Equation| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |FGLMIfCanPackage| |Factored| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasisExtensionByPolynomial| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranType| |Fraction| |FramedNonAssociativeAlgebra&| |FullPartialFractionExpansion| |FullyEvalableOver&| |FunctionCalled| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |Guess| |GuessAlgebraicNumber| |GuessFinite| |GuessInteger| |GuessOption| |GuessOptionFunctions0| |GuessPolynomial| |GuessUnivariatePolynomial| |HexadecimalExpansion| |HomogeneousDirectProduct| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexCard| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerNumericFloatSolvePackage| |InnerSparseUnivariatePowerSeries| |InnerTrigonometricManipulations| |InputForm| |InputFormFunctions1| |IntegrationResult| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |InternalPrintPackage| |InverseLaplaceTransform| |Kernel| |KeyedAccessFile| |LaplaceTransform| |LaurentPolynomial| |LexTriangularPackage| |Library| |LieSquareMatrix| |LinGroebnerPackage| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperatorsOps| |LiouvillianFunction| |List| |ListMultiDictionary| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MakeBinaryCompiledFunction| |MakeFloatCompiledFunction| |MakeFunction| |MakeUnaryCompiledFunction| |Matrix| |ModMonic| |MonogenicAlgebra&| |Multiset| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseUnivariatePolynomial| |NonLinearFirstOrderODESolver| |NonLinearSolvePackage| |NumberFormats| |NumericComplexEigenPackage| |NumericRealEigenPackage| |ODEIntegration| |Octonion| |OctonionCategory&| |OpenMathDevice| |OpenMathError| |OpenMathErrorKind| |OrdSetInts| |OrderedDirectProduct| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OutputForm| |PAdicRational| |PAdicRationalConstructor| |ParametricLinearEquations| |PartialFractionPackage| |Pattern| |PatternFunctions2| |PatternMatch| |PatternMatchAssertions| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchPushDown| |PatternMatchResult| |PatternMatchSymbol| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |PlotFunctions1| |PolToPol| |Polynomial| |PolynomialAN2Expression| |PolynomialFunctions2| |PolynomialIdeals| |PolynomialToUnivariatePolynomial| |PowerSeriesLimitPackage| |PrimitiveElement| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PureAlgebraicIntegration| |PushVariables| |QuasiAlgebraicSet2| |Quaternion| |QuaternionCategory&| |QueryEquation| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RationalFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionFactor| |RationalFunctionIntegration| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalFunctionSum| |RationalInterpolation| |RationalLODE| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosure| |RealSolvePackage| |RectangularMatrix| |RecurrenceOperator| |RecursivePolynomialCategory&| |RepresentationPackage1| |Result| |RetractSolvePackage| |RewriteRule| |RomanNumeral| |RoutinesTable| |RuleCalled| |SExpression| |SegmentBinding| |SegmentBindingFunctions2| |SequentialDifferentialPolynomial| |Set| |SimpleAlgebraicExtension| |SimpleFortranProgram| |SingletonAsOrderedSet| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SquareMatrix| |SquareMatrixCategory&| |StructuralConstantsPackage| |Switch| |Symbol| |SymbolTable| |SystemSolvePackage| |TaylorSeries| |TheSymbolTable| |ThreeDimensionalMatrix| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TransSolvePackageService| |TranscendentalManipulations| |TrigonometricManipulations| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |Variable| |Vector| |WeierstrassPreparation| |XPolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |FortranPackage| |FortranProgram| |TheSymbolTable|)
 (|TangentExpansions|)
 (|IrrRepSymNatPackage| |RepresentationPackage1|)
 (|CycleIndicators| |EvaluateCycleIndicators|)
 (|PureAlgebraicLODE|)
 (|EigenPackage| |NonLinearSolvePackage| |RadicalSolvePackage| |RetractSolvePackage| |TransSolvePackage|)
-(|AlgebraicFunctionField| |Complex| |DiscreteLogarithmPackage| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |InnerFiniteField| |InnerPrimeField| |MachineComplex| |Multiset| |PrimeField| |RadicalFunctionField| |RandomDistributions| |Result| |SimpleAlgebraicExtension| |SymbolTable| |TransSolvePackage|)
+(|AlgebraicFunctionField| |Complex| |DiscreteLogarithmPackage| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |InnerFiniteField| |InnerPrimeField| |MachineComplex| |Multiset| |PrimeField| |PseudoAlgebraicClosureOfFiniteField| |RadicalFunctionField| |RandomDistributions| |Result| |SimpleAlgebraicExtension| |SymbolTable| |TransSolvePackage|)
 (|TableauxBumpers|)
 (|QuasiComponentPackage| |RegularTriangularSetGcdPackage| |SquareFreeQuasiComponentPackage| |SquareFreeRegularTriangularSetGcdPackage|)
 (|ElementaryFunctionStructurePackage|)
 (|WeierstrassPreparation|)
+(|ExpressionSolve|)
 (|FortranTemplate|)
 (|TexFormat1|)
-(|FortranTemplate|)
+(|Export3D| |FortranTemplate| |GnuDraw|)
 (|FortranCode| |FortranPackage| |FortranProgram|)
 (|NagPartialDifferentialEquationsPackage|)
-(|DrawComplex| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints|)
-(|DrawComplex| |DrawOption| |DrawOptionFunctions0| |MeshCreationRoutinesForThreeDimensions| |ThreeDimensionalViewport| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TopLevelThreeSpace|)
+(|DrawComplex| |GnuDraw| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints|)
+(|DrawComplex| |DrawOption| |DrawOptionFunctions0| |GnuDraw| |MeshCreationRoutinesForThreeDimensions| |ThreeDimensionalViewport| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TopLevelThreeSpace|)
 (|ElementaryFunctionSign| |PowerSeriesLimitPackage| |RationalFunctionLimitPackage| |RationalFunctionSign|)
+(|GnuDraw|)
 (|TopLevelDrawFunctions|)
 (|TransSolvePackage|)
 (|TranscendentalIntegration|)
@@ -537,21 +593,23 @@
 (|FunctionSpaceIntegration| |SimplifyAlgebraicNumberConvertPackage| |TransSolvePackage| |d01TransformFunctionType|)
 (|ElementaryRischDE| |RationalIntegration|)
 (|ElementaryRischDESystem|)
-(|BinaryTree| |PendantTree|)
+(|BinaryTree| |HTMLFormat| |PendantTree|)
 (|ChineseRemainderToolsForIntegralBases| |FunctionFieldIntegralBasis| |IntegralBasisTools| |NumberFieldIntegralBasis| |PAdicWildFunctionFieldIntegralBasis| |WildFunctionFieldIntegralBasis|)
 (|ElementaryFunctionSign| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |IntegrationResultRFToFunction| |LaplaceTransform| |PatternMatchIntegration| |TransSolvePackage|)
 (|ExpressionTubePlot| |NumericTubePlot| |TopLevelDrawFunctionsForCompiledFunctions|)
 (|ExpressionTubePlot| |NumericTubePlot|)
 (|DrawComplex|)
 (|TopLevelDrawFunctionsForCompiledFunctions|)
-(|TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |ViewportPackage|)
+(|GnuDraw| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |ViewportPackage|)
 (|MultFiniteFactorize| |SparseUnivariatePolynomial|)
+(|Guess| |NottinghamGroup| |RecurrenceOperator| |UnivariateFormalPowerSeriesFunctions|)
+(|Guess|)
 (|UnivariateLaurentSeriesFunctions2| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesFunctions2|)
 (|UnivariateLaurentSeries|)
 (|UnivariatePuiseuxSeriesFunctions2|)
-(|PadeApproximantPackage| |PolynomialInterpolation| |PolynomialToUnivariatePolynomial| |SparseUnivariateTaylorSeries| |SturmHabichtPackage| |UnivariatePolynomialFunctions2| |UnivariateTaylorSeries|)
-(|AlgFactor| |AlgebraicFunctionField| |AlgebraicIntegrate| |BoundIntegerRoots| |CharacteristicPolynomialInMonogenicalAlgebra| |ComplexCategory&| |DoubleResultantPackage| |FiniteDivisorFunctions2| |Fraction| |FullPartialFractionExpansion| |FunctionFieldCategory&| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupPolynomialUtilities| |GeneralPolynomialGcdPackage| |InnerAlgFactor| |InnerMultFact| |InnerNumericEigenPackage| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearPolynomialEquationByFractions| |MultFiniteFactorize| |MultipleMap| |MultivariateSquareFree| |NewSparseUnivariatePolynomialFunctions2| |NormInMonogenicAlgebra| |PartialFractionPackage| |PointsOfFiniteOrder| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialToUnivariatePolynomial| |PrimitiveRatDE| |RadicalFunctionField| |RationalFactorize| |RationalFunctionFactor| |RationalRicDE| |RealZeroPackageQ| |ReducedDivisor| |SparseUnivariatePolynomialFunctions2| |SupFractionFactorizer| |TranscendentalIntegration| |TwoFactorize| |UnivariatePolynomialFunctions2|)
-(|ChangeOfVariable| |DefiniteIntegrationTools| |DoubleResultantPackage| |FiniteDivisor| |FunctionFieldCategory&| |InnerPolySum| |PointsOfFiniteOrder| |PointsOfFiniteOrderTools| |PureAlgebraicIntegration|)
+(|GeneralPackageForAlgebraicFunctionField| |Guess| |PadeApproximantPackage| |PolynomialInterpolation| |PolynomialToUnivariatePolynomial| |SparseUnivariateTaylorSeries| |SturmHabichtPackage| |UnivariateFormalPowerSeries| |UnivariatePolynomialFunctions2| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero|)
+(|AlgFactor| |AlgebraicFunctionField| |AlgebraicIntegrate| |BoundIntegerRoots| |CharacteristicPolynomialInMonogenicalAlgebra| |ComplexCategory&| |DoubleResultantPackage| |FiniteDivisorFunctions2| |Fraction| |FullPartialFractionExpansion| |FunctionFieldCategory&| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupPolynomialUtilities| |GeneralPolynomialGcdPackage| |InnerAlgFactor| |InnerMultFact| |InnerNumericEigenPackage| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearPolynomialEquationByFractions| |MultFiniteFactorize| |MultipleMap| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NewSparseUnivariatePolynomialFunctions2| |NormInMonogenicAlgebra| |PartialFractionPackage| |PointsOfFiniteOrder| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialToUnivariatePolynomial| |PrimitiveRatDE| |RadicalFunctionField| |RationalFactorize| |RationalFunctionFactor| |RationalRicDE| |RealZeroPackageQ| |ReducedDivisor| |SparseUnivariatePolynomialFunctions2| |SupFractionFactorizer| |TranscendentalIntegration| |TwoFactorize| |UnivariatePolynomialFunctions2|)
+(|ChangeOfVariable| |DefiniteIntegrationTools| |DoubleResultantPackage| |FiniteDivisor| |FunctionFieldCategory&| |Guess| |InnerPolySum| |PointsOfFiniteOrder| |PointsOfFiniteOrderTools| |PureAlgebraicIntegration|)
 (|GaloisGroupFactorizer|)
 (|UnivariatePolynomialDecompositionPackage|)
 (|FiniteFieldCategory&| |Integer| |PolynomialSquareFree| |SparseUnivariatePolynomial| |UnivariatePolynomialCategory&|)
@@ -559,17 +617,18 @@
 (|SparseUnivariatePuiseuxSeries| |UnivariatePuiseuxSeries|)
 (|ExponentialExpansion| |FunctionSpaceToExponentialExpansion|)
 (|SparseUnivariateSkewPolynomial|)
-(|PadeApproximantPackage| |RationalRicDE| |UnivariateLaurentSeries| |UnivariateLaurentSeriesFunctions2| |UnivariatePuiseuxSeries|)
+(|PadeApproximantPackage| |RationalRicDE| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesFunctions2| |UnivariatePuiseuxSeries|)
+(|GeneralPackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField|)
 (|UnivariateLaurentSeriesFunctions2|)
-(|AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AssociationList| |Bits| |DataList| |DisplayPackage| |ExtensibleLinearAggregate&| |FlexibleArray| |Float| |GaloisGroupUtilities| |GenerateUnivariatePowerSeries| |IndexedBits| |IndexedFlexibleArray| |IndexedList| |IndexedOneDimensionalArray| |IndexedString| |IndexedVector| |InnerNormalBasisFieldFunctions| |LazyStreamAggregate&| |List| |ListAggregate&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |Point| |PrimitiveArray| |Stream| |StreamAggregate&| |String| |StringAggregate&| |Symbol| |TemplateUtilities| |TexFormat| |UniversalSegmentFunctions2| |Vector|)
+(|AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AssociationList| |AxiomServer| |Bits| |ComplexDoubleFloatVector| |DataList| |DisplayPackage| |DoubleFloatVector| |ExtensibleLinearAggregate&| |FlexibleArray| |Float| |GaloisGroupUtilities| |GenerateUnivariatePowerSeries| |IndexedBits| |IndexedFlexibleArray| |IndexedList| |IndexedOneDimensionalArray| |IndexedString| |IndexedVector| |InnerNormalBasisFieldFunctions| |LazyStreamAggregate&| |List| |ListAggregate&| |MathMLFormat| |NeitherSparseOrDensePowerSeries| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |Point| |PrimitiveArray| |Stream| |StreamAggregate&| |String| |StringAggregate&| |Symbol| |TemplateUtilities| |TexFormat| |UniversalSegmentFunctions2| |Vector|)
 (|GenerateUnivariatePowerSeries|)
 (|FunctionSpace&| |Polynomial| |UserDefinedVariableOrdering|)
-(|GeneralUnivariatePowerSeries| |PolynomialToUnivariatePolynomial| |SparseUnivariateLaurentSeries| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |UnivariateLaurentSeries| |UnivariatePolynomial| |UnivariatePuiseuxSeries| |UnivariateSkewPolynomial| |UnivariateTaylorSeries|)
-(|AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicNumber| |AnnaOrdinaryDifferentialEquationPackage| |Asp10| |Asp19| |Asp20| |Asp28| |Asp31| |Asp35| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp78| |Asp8| |Asp80| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |BalancedPAdicRational| |BinaryExpansion| |CartesianTensor| |CliffordAlgebra| |CoerceVectorMatrixPackage| |Complex| |ComplexCategory&| |ComplexIntegerSolveLinearPolynomialEquation| |DecimalExpansion| |DenavitHartenbergMatrix| |DifferentialSparseMultivariatePolynomial| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductFunctions2| |DirectProductMatrixModule| |DirectProductModule| |DistributedMultivariatePolynomial| |EigenPackage| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionStructurePackage| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |Expression| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSolveLinearPolynomialEquation| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FortranCode| |Fraction| |FractionalIdeal| |FractionalIdealFunctions2| |FramedAlgebra&| |FramedModule| |FramedNonAssociativeAlgebra&| |FramedNonAssociativeAlgebraFunctions2| |FreeNilpotentLie| |FullyLinearlyExplicitRingOver&| |FunctionFieldCategory&| |GaloisGroupPolynomialUtilities| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GenericNonAssociativeAlgebra| |GosperSummationMethod| |GrayCode| |HallBasis| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerPrimeField| |Integer| |IntegerLinearDependence| |IntegerPrimesPackage| |IntegerSolveLinearPolynomialEquation| |IntegralBasisTools| |IntegrationResultToFunction| |IrrRepSymNatPackage| |LieSquareMatrix| |LinGroebnerPackage| |LinearDependence| |LinearOrdinaryDifferentialOperatorsOps| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |MachineComplex| |MachineInteger| |Matrix| |MatrixLinearAlgebraFunctions| |ModMonic| |ModularHermitianRowReduction| |MonogenicAlgebra&| |MultiVariableCalculusFunctions| |MultivariateLifting| |MultivariatePolynomial| |NPCoef| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NumberFieldIntegralBasis| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODETools| |OrderedDirectProduct| |OrderingFunctions| |OrderlyDifferentialPolynomial| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |ParametricLinearEquations| |Permanent| |Permutation| |PermutationGroup| |Point| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PolToPol| |Polynomial| |PolynomialCategory&| |PolynomialFactorizationExplicit&| |PolynomialIdeals| |PrimeField| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicLODE| |Quaternion| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadixExpansion| |RandomDistributions| |RationalLODE| |RealZeroPackage| |RectangularMatrix| |ReduceLODE| |RepresentationPackage1| |RepresentationPackage2| |RomanNumeral| |SequentialDifferentialPolynomial| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SparseMultivariatePolynomial| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SplitHomogeneousDirectProduct| |SquareMatrix| |SquareMatrixCategory&| |StructuralConstantsPackage| |SymmetricFunctions| |SymmetricGroupCombinatoricFunctions| |SystemODESolver| |SystemSolvePackage| |TangentExpansions| |ThreeDimensionalMatrix| |TransSolvePackageService| |TranscendentalRischDESystem| |TwoDimensionalViewport| |UTSodetools| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |VectorFunctions2| |WildFunctionFieldIntegralBasis| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03eefAnnaType| |e04AgentsPackage| |e04fdfAnnaType| |e04gcfAnnaType| |e04ucfAnnaType|)
+(|GeneralUnivariatePowerSeries| |MyUnivariatePolynomial| |PolynomialToUnivariatePolynomial| |SparseUnivariateLaurentSeries| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariatePolynomial| |UnivariatePuiseuxSeries| |UnivariateSkewPolynomial| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicNumber| |AnnaOrdinaryDifferentialEquationPackage| |Asp10| |Asp19| |Asp20| |Asp28| |Asp31| |Asp35| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp78| |Asp8| |Asp80| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |BalancedPAdicRational| |BinaryExpansion| |BlowUpPackage| |CartesianTensor| |CliffordAlgebra| |CoerceVectorMatrixPackage| |Complex| |ComplexCategory&| |ComplexIntegerSolveLinearPolynomialEquation| |DecimalExpansion| |DenavitHartenbergMatrix| |DesingTreePackage| |DifferentialSparseMultivariatePolynomial| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductFunctions2| |DirectProductMatrixModule| |DirectProductModule| |DistributedMultivariatePolynomial| |EigenPackage| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionStructurePackage| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |Expression| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSolveLinearPolynomialEquation| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FortranCode| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FractionalIdealFunctions2| |FramedAlgebra&| |FramedModule| |FramedNonAssociativeAlgebra&| |FramedNonAssociativeAlgebraFunctions2| |FreeNilpotentLie| |FullyLinearlyExplicitRingOver&| |FunctionFieldCategory&| |GaloisGroupPolynomialUtilities| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GenericNonAssociativeAlgebra| |GosperSummationMethod| |GrayCode| |Guess| |HallBasis| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |InfinitlyClosePoint| |InnerAlgebraicNumber| |InnerFiniteField| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerPrimeField| |Integer| |IntegerLinearDependence| |IntegerPrimesPackage| |IntegerSolveLinearPolynomialEquation| |IntegralBasisTools| |IntegrationResultToFunction| |InterpolateFormsPackage| |IrrRepSymNatPackage| |LieSquareMatrix| |LinGroebnerPackage| |LinearDependence| |LinearOrdinaryDifferentialOperatorsOps| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |LinesOpPack| |MachineComplex| |MachineInteger| |Matrix| |MatrixLinearAlgebraFunctions| |ModMonic| |ModularHermitianRowReduction| |MonogenicAlgebra&| |MultiVariableCalculusFunctions| |MultivariateLifting| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NPCoef| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NumberFieldIntegralBasis| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODETools| |OrderedDirectProduct| |OrderingFunctions| |OrderlyDifferentialPolynomial| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForPoly| |ParametricLinearEquations| |Permanent| |Permutation| |PermutationGroup| |Point| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PolToPol| |Polynomial| |PolynomialCategory&| |PolynomialFactorizationExplicit&| |PolynomialIdeals| |PrimeField| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicLODE| |Quaternion| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadixExpansion| |RandomDistributions| |RationalInterpolation| |RationalLODE| |RealZeroPackage| |RectangularMatrix| |ReduceLODE| |RepresentationPackage1| |RepresentationPackage2| |RomanNumeral| |SequentialDifferentialPolynomial| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SparseMultivariatePolynomial| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SplitHomogeneousDirectProduct| |SquareMatrix| |SquareMatrixCategory&| |StructuralConstantsPackage| |SymmetricFunctions| |SymmetricGroupCombinatoricFunctions| |SystemODESolver| |SystemSolvePackage| |TangentExpansions| |ThreeDimensionalMatrix| |TransSolvePackageService| |TranscendentalRischDESystem| |TwoDimensionalViewport| |UTSodetools| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |VectorFunctions2| |WildFunctionFieldIntegralBasis| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03eefAnnaType| |e04AgentsPackage| |e04fdfAnnaType| |e04gcfAnnaType| |e04ucfAnnaType|)
 (|AlgebraicHermiteIntegration| |AlgebraicIntegrate| |Asp10| |Asp19| |Asp20| |Asp31| |Asp35| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp78| |Asp8| |Asp80| |FramedNonAssociativeAlgebraFunctions2| |GenExEuclid| |GenericNonAssociativeAlgebra| |LinearDependence| |SimpleAlgebraicExtension|)
 (|GraphImage| |MeshCreationRoutinesForThreeDimensions| |ThreeDimensionalViewport| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TwoDimensionalViewport| |ViewportPackage|)
 (|TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions|)
-(|AlgebraGivenByStructuralConstants| |AlgebraicFunctionField| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociationList| |AttributeButtons| |Bits| |CommonOperators| |Complex| |ComplexRootFindingPackage| |DataList| |Database| |DirectProduct| |DirectProductMatrixModule| |DirectProductModule| |DiscreteLogarithmPackage| |DisplayPackage| |DoubleFloat| |EqTable| |EuclideanGroebnerBasisPackage| |ExpressionToOpenMath| |FiniteAlgebraicExtensionField&| |FiniteFieldCategory&| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtensionByPolynomial| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteLinearAggregateSort| |FiniteRankNonAssociativeAlgebra&| |FlexibleArray| |Float| |FortranCode| |FortranExpression| |FortranOutputStackPackage| |FortranPackage| |FortranProgram| |FortranTemplate| |Fraction| |FramedNonAssociativeAlgebra&| |FunctionSpaceReduce| |GaloisGroupFactorizer| |GaloisGroupUtilities| |GenUFactorize| |GeneralSparseTable| |GenericNonAssociativeAlgebra| |GraphImage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |HashTable| |HomogeneousDirectProduct| |IndexCard| |IndexedAggregate&| |IndexedBits| |IndexedFlexibleArray| |IndexedList| |IndexedOneDimensionalArray| |IndexedString| |IndexedVector| |InnerNormalBasisFieldFunctions| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |Integer| |IntegrationFunctionsTable| |InternalPrintPackage| |InternalRationalUnivariateRepresentationPackage| |Kernel| |KeyedAccessFile| |Library| |List| |MachineFloat| |MakeCachableSet| |MoreSystemCommands| |NAGLinkSupportPackage| |NagEigenPackage| |NagIntegrationPackage| |NagLinearEquationSolvingPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagRootFindingPackage| |NormalizationPackage| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODEIntensityFunctionsTable| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OpenMathConnection| |OpenMathDevice| |OpenMathPackage| |OpenMathServerPackage| |OrderedDirectProduct| |OrdinaryWeightedPolynomials| |OutputForm| |OutputPackage| |PermutationGroup| |Point| |PointsOfFiniteOrder| |PrimitiveArray| |PrintPackage| |QuasiComponentPackage| |RadicalFunctionField| |RandomNumberSource| |RationalUnivariateRepresentationPackage| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetGcdPackage| |RepresentationPackage2| |ResolveLatticeCompletion| |Result| |RoutinesTable| |ScriptFormulaFormat| |SimpleAlgebraicExtension| |SimpleFortranProgram| |SingleInteger| |SortPackage| |SortedCache| |SparseTable| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |Stream| |String| |StringTable| |Symbol| |SymbolTable| |SystemODESolver| |Table| |TabulatedComputationPackage| |TexFormat| |TheSymbolTable| |ThreeDimensionalViewport| |TwoDimensionalViewport| |UserDefinedPartialOrdering| |UserDefinedVariableOrdering| |Vector| |ViewDefaultsPackage| |ViewportPackage| |WeightedPolynomials| |ZeroDimensionalSolvePackage| |e04AgentsPackage|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AlgebraGivenByStructuralConstants| |AlgebraicFunctionField| |ApplicationProgramInterface| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociationList| |AttributeButtons| |AxiomServer| |BinaryFile| |Bits| |BlowUpPackage| |CommonOperators| |Complex| |ComplexDoubleFloatVector| |ComplexRootFindingPackage| |DataList| |Database| |DesingTreePackage| |DirectProduct| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DisplayPackage| |DoubleFloat| |DoubleFloatVector| |EqTable| |EuclideanGroebnerBasisPackage| |Export3D| |ExpressionToOpenMath| |File| |FiniteAlgebraicExtensionField&| |FiniteFieldCategory&| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtensionByPolynomial| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteLinearAggregateSort| |FiniteRankNonAssociativeAlgebra&| |FlexibleArray| |Float| |FortranCode| |FortranExpression| |FortranOutputStackPackage| |FortranPackage| |FortranProgram| |FortranTemplate| |Fraction| |FramedNonAssociativeAlgebra&| |FunctionSpaceReduce| |GaloisGroupFactorizer| |GaloisGroupUtilities| |GenUFactorize| |GeneralPackageForAlgebraicFunctionField| |GeneralSparseTable| |GenericNonAssociativeAlgebra| |GnuDraw| |GraphImage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |Guess| |GuessOption| |HTMLFormat| |HashTable| |HomogeneousDirectProduct| |IndexCard| |IndexedAggregate&| |IndexedBits| |IndexedFlexibleArray| |IndexedList| |IndexedOneDimensionalArray| |IndexedString| |IndexedVector| |InnerNormalBasisFieldFunctions| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |Integer| |IntegrationFunctionsTable| |InternalPrintPackage| |InternalRationalUnivariateRepresentationPackage| |IntersectionDivisorPackage| |Kernel| |KeyedAccessFile| |Library| |List| |LocalParametrizationOfSimplePointPackage| |MachineFloat| |MakeCachableSet| |MathMLFormat| |MoreSystemCommands| |NAGLinkSupportPackage| |NagEigenPackage| |NagIntegrationPackage| |NagLinearEquationSolvingPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagRootFindingPackage| |NeitherSparseOrDensePowerSeries| |NormalizationPackage| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODEIntensityFunctionsTable| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OpenMathConnection| |OpenMathDevice| |OpenMathPackage| |OpenMathServerPackage| |OrderedDirectProduct| |OrdinaryWeightedPolynomials| |OutputForm| |OutputPackage| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PermutationGroup| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |Plcs| |Point| |PointsOfFiniteOrder| |PrimitiveArray| |PrintPackage| |ProjectiveAlgebraicSetPackage| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |QuasiComponentPackage| |RadicalFunctionField| |RandomNumberSource| |RationalInterpolation| |RationalUnivariateRepresentationPackage| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetGcdPackage| |RepresentationPackage2| |ResolveLatticeCompletion| |Result| |RoutinesTable| |ScriptFormulaFormat| |SimpleAlgebraicExtension| |SimpleFortranProgram| |SingleInteger| |SortPackage| |SortedCache| |SparseTable| |SparseUnivariatePolynomialExpressions| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |Stream| |String| |StringTable| |Symbol| |SymbolTable| |SystemODESolver| |Table| |TabulatedComputationPackage| |TaylorSolve| |TexFormat| |TextFile| |TheSymbolTable| |ThreeDimensionalViewport| |TwoDimensionalViewport| |UserDefinedPartialOrdering| |UserDefinedVariableOrdering| |Vector| |ViewDefaultsPackage| |ViewportPackage| |WeightedPolynomials| |ZeroDimensionalSolvePackage| |e04AgentsPackage|)
 (|OrdinaryWeightedPolynomials|)
 (|PAdicWildFunctionFieldIntegralBasis|)
 (|LieExponentials| |LiePolynomial| |XPBWPolynomial| |XPolynomial| |XRecursivePolynomial|)
@@ -604,4 +663,4 @@
 (|AnnaNumericalOptimizationPackage|)
 (|AnnaNumericalOptimizationPackage|)
 (|AnnaNumericalOptimizationPackage|)
-(("e04ucfAnnaType" 0 209882) ("e04nafAnnaType" 0 209845) ("e04mbfAnnaType" 0 209808) ("e04jafAnnaType" 0 209771) ("e04gcfAnnaType" 0 209734) ("e04fdfAnnaType" 0 209697) ("e04dgfAnnaType" 0 209660) ("e04AgentsPackage" 0 209521) ("d03eefAnnaType" 0 209478) ("d03AgentsPackage" 0 209459) ("d02ejfAnnaType" 0 209415) ("d02cjfAnnaType" 0 209371) ("d02bhfAnnaType" 0 209327) ("d02bbfAnnaType" 0 209283) ("d02AgentsPackage" 0 209213) ("d01gbfAnnaType" 0 209177) ("d01fcfAnnaType" 0 209141) ("d01asfAnnaType" 0 209105) ("d01aqfAnnaType" 0 209069) ("d01apfAnnaType" 0 209033) ("d01anfAnnaType" 0 208997) ("d01amfAnnaType" 0 208961) ("d01alfAnnaType" 0 208925) ("d01akfAnnaType" 0 208889) ("d01ajfAnnaType" 0 208853) ("d01WeightsPackage" 0 208800) ("d01TransformFunctionType" 0 208764) ("d01AgentsPackage" 0 208511) ("XRecursivePolynomial" 0 208462) ("XPolynomialRing" 0 208435) ("XPBWPolynomial" 0 208415) ("XDistributedPolynomial" 0 208325) ("WildFunctionFieldIntegralBasis" 0 208285) ("WeightedPolynomials" 0 208253) ("Void" 0 204855) ("ViewportPackage" 0 204767) ("ViewDefaultsPackage" 0 204555) ("VectorSpace&" 0 NIL) ("VectorFunctions2" 0 204246) ("VectorCategory&" 0 NIL) ("Vector" 0 199634) ("Variable" 0 199344) ("UserDefinedPartialOrdering" 0 199282) ("UniversalSegmentFunctions2" 0 199248) ("UniversalSegment" 0 198527) ("UnivariateTaylorSeriesFunctions2" 0 198489) ("UnivariateTaylorSeriesCategory&" 0 NIL) ("UnivariateTaylorSeries" 0 198358) ("UnivariateSkewPolynomialCategoryOps" 0 198323) ("UnivariateSkewPolynomialCategory&" 0 NIL) ("UnivariatePuiseuxSeriesWithExponentialSingularity" 0 198260) ("UnivariatePuiseuxSeriesConstructorCategory&" 0 NIL) ("UnivariatePuiseuxSeriesConstructor" 0 198200) ("UnivariatePuiseuxSeries" 0 197979) ("UnivariatePowerSeriesCategory&" 0 NIL) ("UnivariatePolynomialSquareFree" 0 197860) ("UnivariatePolynomialDivisionPackage" 0 197815) ("UnivariatePolynomialDecompositionPackage" 0 197789) ("UnivariatePolynomialCommonDenominator" 0 197584) ("UnivariatePolynomialCategoryFunctions2" 0 196500) ("UnivariatePolynomialCategory&" 0 NIL) ("UnivariatePolynomial" 0 196301) ("UnivariateLaurentSeriesFunctions2" 0 196263) ("UnivariateLaurentSeriesConstructorCategory&" 0 NIL) ("UnivariateLaurentSeriesConstructor" 0 196235) ("UnivariateLaurentSeries" 0 196135) ("UniqueFactorizationDomain&" 0 NIL) ("UnaryRecursiveAggregate&" 0 NIL) ("TwoFactorize" 0 196082) ("TwoDimensionalViewport" 0 195919) ("TwoDimensionalPlotClipping" 0 195873) ("TwoDimensionalArrayCategory&" 0 NIL) ("TwoDimensionalArray" 0 195857) ("TubePlotTools" 0 195816) ("TubePlot" 0 195731) ("TrigonometricManipulations" 0 195546) ("TrigonometricFunctionCategory&" 0 NIL) ("TriangularSetCategory&" 0 NIL) ("TriangularMatrixOperations" 0 195356) ("Tree" 0 195327) ("TranscendentalRischDESystem" 0 195299) ("TranscendentalRischDE" 0 195255) ("TranscendentalManipulations" 0 195139) ("TranscendentalIntegration" 0 195071) ("TranscendentalHermiteIntegration" 0 195041) ("TranscendentalFunctionCategory&" 0 NIL) ("TransSolvePackageService" 0 195019) ("TopLevelDrawFunctionsForCompiledFunctions" 0 194993) ("ToolsForSign" 0 194886) ("ThreeSpace" 0 194644) ("ThreeDimensionalViewport" 0 194527) ("ThreeDimensionalMatrix" 0 194484) ("TheSymbolTable" 0 194434) ("TextFile" 0 194414) ("TexFormat" 0 194399) ("TemplateUtilities" 0 194379) ("TaylorSeries" 0 194352) ("TangentExpansions" 0 194313) ("TabulatedComputationPackage" 0 194177) ("Tableau" 0 194157) ("TableAggregate&" 0 NIL) ("Table" 0 193595) ("SystemSolvePackage" 0 193490) ("SystemODESolver" 0 193468) ("SymmetricPolynomial" 0 193422) ("SymmetricGroupCombinatoricFunctions" 0 193373) ("SymmetricFunctions" 0 193351) ("SymbolTable" 0 193072) ("Symbol" 0 185716) ("Switch" 0 185653) ("SupFractionFactorizer" 0 185638) ("SuchThat" 0 185558) ("SubSpaceComponentProperty" 0 185464) ("SubSpace" 0 185449) ("SubResultantPackage" 0 185387) ("StringAggregate&" 0 NIL) ("String" 0 175238) ("StreamTranscendentalFunctionsNonCommutative" 0 175202) ("StreamTranscendentalFunctions" 0 174989) ("StreamTaylorSeriesOperations" 0 174606) ("StreamInfiniteProduct" 0 174540) ("StreamFunctions3" 0 174386) ("StreamFunctions2" 0 173934) ("StreamFunctions1" 0 173904) ("StreamAggregate&" 0 NIL) ("Stream" 0 172327) ("StorageEfficientMatrixOperations" 0 172316) ("Stack" 0 172278) ("SquareMatrixCategory&" 0 NIL) ("SquareMatrix" 0 172145) ("SquareFreeRegularTriangularSetGcdPackage" 0 172018) ("SquareFreeRegularTriangularSet" 0 171921) ("SquareFreeRegularSetDecompositionPackage" 0 171886) ("SquareFreeQuasiComponentPackage" 0 171709) ("SplittingTree" 0 171682) ("SplittingNode" 0 171639) ("SparseUnivariateTaylorSeries" 0 171573) ("SparseUnivariateSkewPolynomial" 0 171507) ("SparseUnivariatePolynomialFunctions2" 0 171001) ("SparseUnivariatePolynomial" 0 165214) ("SparseUnivariateLaurentSeries" 0 165180) ("SparseMultivariateTaylorSeries" 0 165163) ("SparseMultivariatePolynomial" 0 163975) ("SortedCache" 0 163946) ("SmithNormalForm" 0 163914) ("SingletonAsOrderedSet" 0 163376) ("SingleInteger" 0 156738) ("SimpleAlgebraicExtension" 0 156607) ("SetCategory&" 0 NIL) ("SetAggregate&" 0 NIL) ("Set" 0 156229) ("SequentialDifferentialVariable" 0 156192) ("SemiGroup&" 0 NIL) ("SegmentFunctions2" 0 156077) ("SegmentBindingFunctions2" 0 156035) ("SegmentBinding" 0 155701) ("Segment" 0 154645) ("ScriptFormulaFormat" 0 154620) ("SExpressionOf" 0 154604) ("SExpression" 0 154419) ("RoutinesTable" 0 153828) ("Ring&" 0 NIL) ("RightOpenIntervalRootCharacterization" 0 153812) ("RewriteRule" 0 153767) ("RetractableTo&" 0 NIL) ("RetractSolvePackage" 0 153741) ("Result" 0 152670) ("RepeatedSquaring" 0 152501) ("RepeatedDoubling" 0 152446) ("RegularTriangularSetGcdPackage" 0 152388) ("RegularTriangularSetCategory&" 0 NIL) ("RegularTriangularSet" 0 152371) ("RegularSetDecompositionPackage" 0 152346) ("RegularChain" 0 152291) ("Reference" 0 151908) ("ReductionOfOrder" 0 151875) ("ReduceLODE" 0 151853) ("RecursivePolynomialCategory&" 0 NIL) ("RecursiveAggregate&" 0 NIL) ("RectangularMatrixCategory&" 0 NIL) ("RealZeroPackage" 0 151773) ("RealSolvePackage" 0 151745) ("RealRootCharacterizationCategory&" 0 NIL) ("RealPolynomialUtilitiesPackage" 0 151703) ("RealNumberSystem&" 0 NIL) ("RealClosure" 0 151671) ("RealClosedField&" 0 NIL) ("RationalRicDE" 0 151581) ("RationalLODE" 0 151442) ("RationalIntegration" 0 151321) ("RationalFunctionSign" 0 151263) ("RationalFunctionIntegration" 0 151229) ("RationalFunctionFactor" 0 151196) ("RationalFunction" 0 151148) ("RationalFactorize" 0 150998) ("RandomNumberSource" 0 150918) ("RadixExpansion" 0 150856) ("RadicalSolvePackage" 0 150834) ("RadicalCategory&" 0 NIL) ("QuotientFieldCategoryFunctions2" 0 150811) ("QuotientFieldCategory&" 0 NIL) ("Queue" 0 150799) ("QueryEquation" 0 150786) ("QuaternionCategory&" 0 NIL) ("Quaternion" 0 150773) ("QuasiComponentPackage" 0 150659) ("QuasiAlgebraicSet" 0 150636) ("QuadraticForm" 0 150616) ("PushVariables" 0 150589) ("PureAlgebraicIntegration" 0 150512) ("PseudoRemainderSequence" 0 150427) ("PseudoLinearNormalForm" 0 150407) ("Product" 0 150366) ("PrintPackage" 0 150340) ("PrimitiveRatRicDE" 0 150322) ("PrimitiveRatDE" 0 150269) ("PrimitiveElement" 0 150235) ("PrimitiveArray" 0 149573) ("PrimeField" 0 149507) ("PrecomputedAssociatedEquations" 0 149483) ("PowerSeriesLimitPackage" 0 149391) ("PowerSeriesCategory&" 0 NIL) ("PositiveInteger" 0 140912) ("PolynomialSquareFree" 0 140888) ("PolynomialSolveByFormulas" 0 140864) ("PolynomialSetUtilitiesPackage" 0 140467) ("PolynomialSetCategory&" 0 NIL) ("PolynomialRoots" 0 140364) ("PolynomialRing" 0 140196) ("PolynomialNumberTheoryFunctions" 0 140142) ("PolynomialInterpolationAlgorithms" 0 140114) ("PolynomialIdeals" 0 140063) ("PolynomialGcdPackage" 0 139987) ("PolynomialFunctions2" 0 139791) ("PolynomialFactorizationExplicit&" 0 NIL) ("PolynomialFactorizationByRecursionUnivariate" 0 139728) ("PolynomialFactorizationByRecursion" 0 139704) ("PolynomialDecomposition" 0 139674) ("PolynomialCategoryQuotientFunctions" 0 139275) ("PolynomialCategoryLifting" 0 138648) ("PolynomialCategory&" 0 NIL) ("Polynomial" 0 136402) ("PolyGroebner" 0 136356) ("PolToPol" 0 136319) ("PointsOfFiniteOrderTools" 0 136265) ("PointsOfFiniteOrder" 0 136242) ("PointPackage" 0 136101) ("Point" 0 135686) ("PoincareBirkhoffWittLyndonBasis" 0 135649) ("PlotTools" 0 135634) ("Plot3D" 0 135567) ("Plot" 0 135430) ("PlaneAlgebraicCurvePlot" 0 135386) ("PiCoercions" 0 135364) ("Pi" 0 135328) ("PermutationGroup" 0 135299) ("Permutation" 0 135204) ("PatternMatchTools" 0 135141) ("PatternMatchSymbol" 0 135130) ("PatternMatchResultFunctions2" 0 135083) ("PatternMatchResult" 0 133745) ("PatternMatchQuotientFieldCategory" 0 133718) ("PatternMatchPushDown" 0 133597) ("PatternMatchPolynomialCategory" 0 133560) ("PatternMatchListResult" 0 133515) ("PatternMatchListAggregate" 0 133498) ("PatternMatchKernel" 0 133455) ("PatternMatchIntegration" 0 133336) ("PatternMatchIntegerNumberSystem" 0 133311) ("PatternMatchFunctionSpace" 0 133296) ("PatternFunctions1" 0 133226) ("Pattern" 0 131773) ("PartitionsAndPermutations" 0 131681) ("Partition" 0 131572) ("PartialDifferentialRing&" 0 NIL) ("ParametricSurface" 0 131472) ("ParametricSpaceCurve" 0 131369) ("ParametricPlaneCurve" 0 131266) ("ParadoxicalCombinatorsForStreams" 0 131065) ("Palette" 0 130863) ("PAdicRationalConstructor" 0 130821) ("PAdicInteger" 0 130803) ("OutputPackage" 0 130535) ("OutputForm" 0 122038) ("OrderlyDifferentialVariable" 0 121932) ("OrderlyDifferentialPolynomial" 0 121899) ("OrderedVariableList" 0 121520) ("OrderedSet&" 0 NIL) ("OrderedRing&" 0 NIL) ("OrderedFreeMonoid" 0 121368) ("OrderedCompletionFunctions2" 0 121297) ("OrderedCompletion" 0 120514) ("OrdSetInts" 0 120480) ("OpenMathPackage" 0 120454) ("OpenMathErrorKind" 0 120436) ("OpenMathEncoding" 0 120258) ("OpenMathDevice" 0 120076) ("OpenMathConnection" 0 120050) ("OnePointCompletionFunctions2" 0 120017) ("OnePointCompletion" 0 119362) ("OneDimensionalArrayAggregate&" 0 NIL) ("OneDimensionalArray" 0 119293) ("OctonionCategory&" 0 NIL) ("ODETools" 0 119245) ("ODEIntensityFunctionsTable" 0 119182) ("ODEIntegration" 0 119073) ("NumericalPDEProblem" 0 119030) ("NumericalOptimizationProblem" 0 118974) ("NumericalODEProblem" 0 118930) ("NumericalIntegrationProblem" 0 118867) ("NumericTubePlot" 0 118821) ("NumericRealEigenPackage" 0 118800) ("Numeric" 0 118761) ("NumberTheoreticPolynomialFunctions" 0 118731) ("NumberFormats" 0 118701) ("NormalizationPackage" 0 118528) ("NoneFunctions1" 0 118493) ("None" 0 118241) ("NonNegativeInteger" 0 104313) ("NonLinearSolvePackage" 0 104295) ("NonLinearFirstOrderODESolver" 0 104263) ("NonAssociativeRng&" 0 NIL) ("NonAssociativeRing&" 0 NIL) ("NonAssociativeAlgebra&" 0 NIL) ("NewSparseUnivariatePolynomialFunctions2" 0 104227) ("NewSparseUnivariatePolynomial" 0 104149) ("NewSparseMultivariatePolynomial" 0 104037) ("NagPartialDifferentialEquationsPackage" 0 104018) ("NagOrdinaryDifferentialEquationsPackage" 0 103948) ("NagOptimisationPackage" 0 103792) ("NagIntegrationPackage" 0 103620) ("NagEigenPackage" 0 103599) ("NPCoef" 0 103575) ("NAGLinkSupportPackage" 0 103163) ("MultivariateSquareFree" 0 103099) ("MultivariateLifting" 0 103011) ("MultivariateFactorize" 0 102678) ("Multiset" 0 102619) ("MultipleMap" 0 102544) ("MultiVariableCalculusFunctions" 0 102450) ("MultFiniteFactorize" 0 102376) ("MoreSystemCommands" 0 102305) ("MonomialExtensionTools" 0 102186) ("MonoidRing" 0 102161) ("Monoid&" 0 NIL) ("MonogenicAlgebra&" 0 NIL) ("MonadWithUnit&" 0 NIL) ("Monad&" 0 NIL) ("MoebiusTransform" 0 102139) ("ModuleOperator" 0 102126) ("ModuleMonomial" 0 102098) ("Module&" 0 NIL) ("ModularRing" 0 102058) ("ModularHermitianRowReduction" 0 101853) ("ModularDistinctDegreeFactorizer" 0 101796) ("ModMonic" 0 101686) ("MeshCreationRoutinesForThreeDimensions" 0 101640) ("MergeThing" 0 101627) ("MatrixLinearAlgebraFunctions" 0 101600) ("MatrixCommonDenominator" 0 101490) ("MatrixCategoryFunctions2" 0 101109) ("MatrixCategory&" 0 NIL) ("Matrix" 0 96647) ("MappingPackageInternalHacks3" 0 96627) ("MappingPackageInternalHacks2" 0 96607) ("MappingPackageInternalHacks1" 0 96587) ("MakeUnaryCompiledFunction" 0 96527) ("MakeFunction" 0 96468) ("MakeFloatCompiledFunction" 0 96404) ("MakeBinaryCompiledFunction" 0 96374) ("Magma" 0 96343) ("MachineInteger" 0 96309) ("MachineFloat" 0 96240) ("MRationalFactorize" 0 96076) ("MPolyCatRationalFunctionFactorizer" 0 95966) ("MPolyCatPolyFactorizer" 0 95929) ("MPolyCatFunctions3" 0 95916) ("MPolyCatFunctions2" 0 95864) ("LyndonWord" 0 95777) ("Logic&" 0 NIL) ("Localize" 0 95760) ("LocalAlgebra" 0 95747) ("ListToMap" 0 95696) ("ListMultiDictionary" 0 95664) ("ListMonoidOps" 0 95612) ("ListFunctions2" 0 95231) ("ListAggregate&" 0 NIL) ("List" 0 79846) ("LiouvillianFunction" 0 79805) ("LinearSystemPolynomialPackage" 0 79782) ("LinearSystemMatrixPackage" 0 79448) ("LinearPolynomialEquationByFractions" 0 79327) ("LinearOrdinaryDifferentialOperatorsOps" 0 79288) ("LinearOrdinaryDifferentialOperatorFactorizer" 0 79255) ("LinearOrdinaryDifferentialOperatorCategory&" 0 NIL) ("LinearOrdinaryDifferentialOperator2" 0 79222) ("LinearOrdinaryDifferentialOperator1" 0 79058) ("LinearOrdinaryDifferentialOperator" 0 78980) ("LinearDependence" 0 78952) ("LinearAggregate&" 0 NIL) ("LinGroebnerPackage" 0 78915) ("LiePolynomial" 0 78878) ("LieAlgebra&" 0 NIL) ("LexTriangularPackage" 0 78846) ("LeftAlgebra&" 0 NIL) ("LeadingCoefDetermination" 0 78806) ("LazyStreamAggregate&" 0 NIL) ("LaurentPolynomial" 0 78735) ("Kovacic" 0 78702) ("KeyedDictionary&" 0 NIL) ("KeyedAccessFile" 0 78690) ("KernelFunctions2" 0 78675) ("Kernel" 0 76916) ("IrredPolyOverFiniteField" 0 76876) ("Interval" 0 76829) ("InternalRationalUnivariateRepresentationPackage" 0 76755) ("InternalPrintPackage" 0 76647) ("IntegrationTools" 0 76338) ("IntegrationResultToFunction" 0 76243) ("IntegrationResultRFToFunction" 0 76203) ("IntegrationResultFunctions2" 0 76004) ("IntegrationResult" 0 75613) ("IntegrationFunctionsTable" 0 75558) ("IntegralDomain&" 0 NIL) ("IntegralBasisTools" 0 75429) ("IntegralBasisPolynomialTools" 0 75389) ("IntegerSolveLinearPolynomialEquation" 0 75377) ("IntegerRoots" 0 75192) ("IntegerRetractions" 0 75160) ("IntegerPrimesPackage" 0 74728) ("IntegerNumberTheoryFunctions" 0 74643) ("IntegerNumberSystem&" 0 NIL) ("IntegerMod" 0 74623) ("IntegerLinearDependence" 0 74584) ("IntegerFactorizationPackage" 0 74460) ("IntegerCombinatoricFunctions" 0 74252) ("IntegerBits" 0 74221) ("Integer" 0 60455) ("InputFormFunctions1" 0 60436) ("InputForm" 0 58392) ("InnerTrigonometricManipulations" 0 58264) ("InnerTaylorSeries" 0 58204) ("InnerTable" 0 58194) ("InnerSparseUnivariatePowerSeries" 0 58097) ("InnerPrimeField" 0 58063) ("InnerPolySum" 0 58039) ("InnerPolySign" 0 57956) ("InnerPAdicInteger" 0 57916) ("InnerNumericFloatSolvePackage" 0 57819) ("InnerNumericEigenPackage" 0 57762) ("InnerNormalBasisFieldFunctions" 0 57714) ("InnerMultFact" 0 57668) ("InnerMatrixQuotientFieldFunctions" 0 57635) ("InnerMatrixLinearAlgebraFunctions" 0 57566) ("InnerIndexedTwoDimensionalArray" 0 57488) ("InnerFreeAbelianMonoid" 0 57447) ("InnerEvalable&" 0 NIL) ("InnerCommonDenominator" 0 57228) ("InnerAlgebraicNumber" 0 57208) ("InnerAlgFactor" 0 57139) ("InfiniteTuple" 0 57085) ("IndexedVector" 0 57058) ("IndexedString" 0 57047) ("IndexedOneDimensionalArray" 0 56978) ("IndexedList" 0 56969) ("IndexedFlexibleArray" 0 56882) ("IndexedExponents" 0 56606) ("IndexedDirectProductOrderedAbelianMonoidSup" 0 56585) ("IndexedDirectProductOrderedAbelianMonoid" 0 56537) ("IndexedDirectProductObject" 0 56499) ("IndexedDirectProductAbelianMonoid" 0 56419) ("IndexedDirectProductAbelianGroup" 0 56404) ("IndexedBits" 0 56395) ("IndexedAggregate&" 0 NIL) ("IdealDecompositionPackage" 0 56372) ("HyperbolicFunctionCategory&" 0 NIL) ("HomogeneousDistributedMultivariatePolynomial" 0 56303) ("HomogeneousDirectProduct" 0 56222) ("HomogeneousAggregate&" 0 NIL) ("HeuGcd" 0 56210) ("HashTable" 0 56154) ("HallBasis" 0 56133) ("Group&" 0 NIL) ("GroebnerPackage" 0 55945) ("GroebnerInternalPackage" 0 55790) ("GrayCode" 0 55776) ("GraphicsDefaults" 0 55676) ("GraphImage" 0 55598) ("GradedModule&" 0 NIL) ("GradedAlgebra&" 0 NIL) ("GosperSummationMethod" 0 55555) ("GenusZeroIntegration" 0 55526) ("GeneralizedMultivariateFactorize" 0 55462) ("GeneralTriangularSet" 0 55403) ("GeneralSparseTable" 0 55387) ("GeneralPolynomialSet" 0 55196) ("GeneralPolynomialGcdPackage" 0 55172) ("GeneralHenselPackage" 0 55086) ("GeneralDistributedMultivariatePolynomial" 0 55001) ("GenUFactorize" 0 54949) ("GenExEuclid" 0 54775) ("GcdDomain&" 0 NIL) ("GaloisGroupUtilities" 0 54737) ("GaloisGroupPolynomialUtilities" 0 54711) ("GaloisGroupFactorizer" 0 54663) ("GaloisGroupFactorizationUtilities" 0 54620) ("FunctionalSpecialFunction" 0 54605) ("FunctionSpaceUnivariatePolynomialFactor" 0 54506) ("FunctionSpaceToUnivariatePowerSeries" 0 54466) ("FunctionSpacePrimitiveElement" 0 54389) ("FunctionSpaceIntegration" 0 54181) ("FunctionSpaceFunctions2" 0 54097) ("FunctionSpaceComplexIntegration" 0 54068) ("FunctionSpaceAttachPredicates" 0 54021) ("FunctionSpaceAssertions" 0 53954) ("FunctionSpace&" 0 NIL) ("FunctionFieldCategoryFunctions2" 0 53926) ("FunctionFieldCategory&" 0 NIL) ("FullyRetractableTo&" 0 NIL) ("FullyLinearlyExplicitRingOver&" 0 NIL) ("FullyEvalableOver&" 0 NIL) ("FreeMonoid" 0 53904) ("FreeModule1" 0 53828) ("FreeModule" 0 53723) ("FreeGroup" 0 53693) ("FreeAbelianGroup" 0 53674) ("FramedNonAssociativeAlgebra&" 0 NIL) ("FramedModule" 0 53656) ("FramedAlgebra&" 0 NIL) ("FractionalIdealFunctions2" 0 53628) ("FractionalIdeal" 0 53460) ("Fraction" 0 46384) ("FourierComponent" 0 46366) ("FortranType" 0 46076) ("FortranScalarType" 0 45796) ("FortranPackage" 0 45586) ("FortranOutputStackPackage" 0 45341) ("FortranExpression" 0 45176) ("FortranCode" 0 44909) ("FloatingRealPackage" 0 44888) ("FloatingPointSystem&" 0 NIL) ("Float" 0 43075) ("FlexibleArray" 0 43050) ("FiniteSetAggregate&" 0 NIL) ("FiniteRankNonAssociativeAlgebra&" 0 NIL) ("FiniteRankAlgebra&" 0 NIL) ("FiniteLinearAggregateSort" 0 43016) ("FiniteLinearAggregateFunctions2" 0 42837) ("FiniteLinearAggregate&" 0 NIL) ("FiniteFieldSolveLinearPolynomialEquation" 0 42806) ("FiniteFieldPolynomialPackage" 0 42604) ("FiniteFieldNormalBasisExtensionByPolynomial" 0 42543) ("FiniteFieldFunctions" 0 42390) ("FiniteFieldExtensionByPolynomial" 0 42305) ("FiniteFieldExtension" 0 42284) ("FiniteFieldCyclicGroupExtensionByPolynomial" 0 42223) ("FiniteFieldCategory&" 0 NIL) ("FiniteDivisorCategory&" 0 NIL) ("FiniteDivisor" 0 42087) ("FiniteAlgebraicExtensionField&" 0 NIL) ("FiniteAbelianMonoidRing&" 0 NIL) ("FileName" 0 41727) ("File" 0 41673) ("FieldOfPrimeCharacteristic&" 0 NIL) ("Field&" 0 NIL) ("FactoringUtilities" 0 41585) ("FactoredFunctions2" 0 41390) ("FactoredFunctions" 0 41321) ("FactoredFunctionUtilities" 0 41206) ("Factored" 0 37252) ("ExtensionField&" 0 NIL) ("ExtensibleLinearAggregate&" 0 NIL) ("ExtAlgBasis" 0 37223) ("ExpressionSpaceFunctions2" 0 37125) ("ExpressionSpace&" 0 NIL) ("ExpressionFunctions2" 0 36748) ("Expression" 0 35073) ("ExponentialOfUnivariatePuiseuxSeries" 0 34958) ("ExponentialExpansion" 0 34918) ("ExpertSystemToolsPackage2" 0 34880) ("ExpertSystemToolsPackage1" 0 34859) ("ExpertSystemToolsPackage" 0 34368) ("ExpertSystemContinuityPackage" 0 34330) ("Exit" 0 34060) ("Evalable&" 0 NIL) ("EuclideanModularRing" 0 34040) ("EuclideanDomain&" 0 NIL) ("ErrorFunctions" 0 33832) ("Equation" 0 30788) ("EltableAggregate&" 0 NIL) ("ElementaryRischDESystem" 0 30762) ("ElementaryRischDE" 0 30736) ("ElementaryIntegration" 0 30654) ("ElementaryFunctionsUnivariatePuiseuxSeries" 0 30614) ("ElementaryFunctionsUnivariateLaurentSeries" 0 30543) ("ElementaryFunctionStructurePackage" 0 30213) ("ElementaryFunctionSign" 0 29851) ("ElementaryFunctionODESolver" 0 29818) ("ElementaryFunctionCategory&" 0 NIL) ("ElementaryFunction" 0 29803) ("EigenPackage" 0 29779) ("DrawOptionFunctions1" 0 29754) ("DrawOptionFunctions0" 0 29560) ("DrawOption" 0 29398) ("DoubleResultantPackage" 0 29375) ("DoubleFloatSpecialFunctions" 0 29359) ("DoubleFloat" 0 27285) ("DivisionRing&" 0 NIL) ("DistributedMultivariatePolynomial" 0 27167) ("DistinctDegreeFactorize" 0 26848) ("DisplayPackage" 0 26822) ("DiscreteLogarithmPackage" 0 26797) ("DirectProductCategory&" 0 NIL) ("DirectProduct" 0 26388) ("DifferentialVariableCategory&" 0 NIL) ("DifferentialSparseMultivariatePolynomial" 0 26278) ("DifferentialRing&" 0 NIL) ("DifferentialPolynomialCategory&" 0 NIL) ("DifferentialExtension&" 0 NIL) ("DictionaryOperations&" 0 NIL) ("Dictionary&" 0 NIL) ("DegreeReductionPackage" 0 26254) ("DefiniteIntegrationTools" 0 26174) ("Database" 0 26154) ("DataList" 0 26141) ("CyclotomicPolynomialPackage" 0 26093) ("CyclicStreamTools" 0 26059) ("CoordinateSystems" 0 26017) ("ContinuedFraction" 0 25902) ("ConstantLODE" 0 25869) ("ComplexRootPackage" 0 25810) ("ComplexPatternMatch" 0 25789) ("ComplexPattern" 0 25768) ("ComplexIntegerSolveLinearPolynomialEquation" 0 25747) ("ComplexFunctions2" 0 25715) ("ComplexFactorization" 0 25647) ("ComplexCategory&" 0 NIL) ("Complex" 0 25130) ("CommuteUnivariatePolynomialCategory" 0 24983) ("Commutator" 0 24962) ("CommonOperators" 0 24809) ("CommonDenominator" 0 24711) ("CombinatorialFunction" 0 24696) ("Color" 0 24597) ("Collection&" 0 NIL) ("CoerceVectorMatrixPackage" 0 24533) ("ChineseRemainderToolsForIntegralBases" 0 24493) ("CharacteristicPolynomialInMonogenicalAlgebra" 0 24471) ("CharacterClass" 0 24413) ("Character" 0 24133) ("ChangeOfVariable" 0 24033) ("CartesianTensor" 0 24003) ("CardinalNumber" 0 23414) ("BrillhartTests" 0 23388) ("BoundIntegerRoots" 0 23354) ("Boolean" 0 7075) ("Bits" 0 7048) ("BitAggregate&" 0 NIL) ("BinaryTreeCategory&" 0 NIL) ("BinaryTree" 0 6987) ("BinaryRecursiveAggregate&" 0 NIL) ("BasicType&" 0 NIL) ("BasicOperatorFunctions1" 0 6815) ("BasicOperator" 0 5470) ("BasicFunctions" 0 5436) ("BalancedPAdicInteger" 0 5410) ("BalancedFactorisation" 0 5371) ("BagAggregate&" 0 NIL) ("Automorphism" 0 5191) ("AttributeButtons" 0 4917) ("AssociationList" 0 4765) ("AssociatedLieAlgebra" 0 4745) ("Asp9" 0 4650) ("Asp80" 0 4606) ("Asp8" 0 4511) ("Asp78" 0 4467) ("Asp77" 0 4423) ("Asp74" 0 4363) ("Asp73" 0 4303) ("Asp7" 0 4191) ("Asp6" 0 4165) ("Asp55" 0 4121) ("Asp50" 0 4077) ("Asp49" 0 4016) ("Asp42" 0 3972) ("Asp41" 0 3928) ("Asp4" 0 3868) ("Asp35" 0 3842) ("Asp34" 0 3806) ("Asp33" 0 3762) ("Asp31" 0 3701) ("Asp30" 0 3665) ("Asp29" 0 3645) ("Asp28" 0 3591) ("Asp27" 0 3571) ("Asp24" 0 3527) ("Asp20" 0 3483) ("Asp19" 0 3439) ("Asp12" 0 3395) ("Asp10" 0 3351) ("Asp1" 0 3165) ("ArcTrigonometricFunctionCategory&" 0 NIL) ("ApplyUnivariateSkewPolynomial" 0 3125) ("ApplyRules" 0 3069) ("AnyFunctions1" 0 2040) ("Any" 0 728) ("AntiSymm" 0 710) ("AnnaNumericalOptimizationPackage" 0 689) ("AnnaNumericalIntegrationPackage" 0 660) ("AlgebraicallyClosedFunctionSpace&" 0 NIL) ("AlgebraicallyClosedField&" 0 NIL) ("AlgebraicNumber" 0 510) ("AlgebraicManipulations" 0 224) ("AlgebraicIntegration" 0 198) ("AlgebraicHermiteIntegration" 0 175) ("AlgebraicFunction" 0 160) ("AlgebraGivenByStructuralConstants" 0 127) ("Algebra&" 0 NIL) ("AlgFactor" 0 20) ("Aggregate&" 0 NIL) ("AbelianSemiGroup&" 0 NIL) ("AbelianMonoidRing&" 0 NIL) ("AbelianMonoid&" 0 NIL) ("AbelianGroup&" 0 NIL))
\ No newline at end of file
+(("e04ucfAnnaType" 0 234510) ("e04nafAnnaType" 0 234473) ("e04mbfAnnaType" 0 234436) ("e04jafAnnaType" 0 234399) ("e04gcfAnnaType" 0 234362) ("e04fdfAnnaType" 0 234325) ("e04dgfAnnaType" 0 234288) ("e04AgentsPackage" 0 234149) ("d03eefAnnaType" 0 234106) ("d03AgentsPackage" 0 234087) ("d02ejfAnnaType" 0 234043) ("d02cjfAnnaType" 0 233999) ("d02bhfAnnaType" 0 233955) ("d02bbfAnnaType" 0 233911) ("d02AgentsPackage" 0 233841) ("d01gbfAnnaType" 0 233805) ("d01fcfAnnaType" 0 233769) ("d01asfAnnaType" 0 233733) ("d01aqfAnnaType" 0 233697) ("d01apfAnnaType" 0 233661) ("d01anfAnnaType" 0 233625) ("d01amfAnnaType" 0 233589) ("d01alfAnnaType" 0 233553) ("d01akfAnnaType" 0 233517) ("d01ajfAnnaType" 0 233481) ("d01WeightsPackage" 0 233428) ("d01TransformFunctionType" 0 233392) ("d01AgentsPackage" 0 233139) ("XRecursivePolynomial" 0 233090) ("XPolynomialRing" 0 233063) ("XPBWPolynomial" 0 233043) ("XDistributedPolynomial" 0 232953) ("WildFunctionFieldIntegralBasis" 0 232913) ("WeightedPolynomials" 0 232881) ("Void" 0 228617) ("ViewportPackage" 0 228529) ("ViewDefaultsPackage" 0 228317) ("VectorSpace&" 0 NIL) ("VectorFunctions2" 0 228008) ("VectorCategory&" 0 NIL) ("Vector" 0 222892) ("Variable" 0 222517) ("UserDefinedPartialOrdering" 0 222455) ("UniversalSegmentFunctions2" 0 222421) ("UniversalSegment" 0 221590) ("UnivariateTaylorSeriesFunctions2" 0 221552) ("UnivariateTaylorSeriesCategory&" 0 NIL) ("UnivariateTaylorSeriesCZero" 0 221423) ("UnivariateTaylorSeries" 0 221262) ("UnivariateSkewPolynomialCategoryOps" 0 221227) ("UnivariateSkewPolynomialCategory&" 0 NIL) ("UnivariatePuiseuxSeriesWithExponentialSingularity" 0 221164) ("UnivariatePuiseuxSeriesConstructorCategory&" 0 NIL) ("UnivariatePuiseuxSeriesConstructor" 0 221104) ("UnivariatePuiseuxSeries" 0 220883) ("UnivariatePowerSeriesCategory&" 0 NIL) ("UnivariatePolynomialSquareFree" 0 220764) ("UnivariatePolynomialDivisionPackage" 0 220719) ("UnivariatePolynomialDecompositionPackage" 0 220693) ("UnivariatePolynomialCommonDenominator" 0 220480) ("UnivariatePolynomialCategoryFunctions2" 0 219356) ("UnivariatePolynomialCategory&" 0 NIL) ("UnivariatePolynomial" 0 219047) ("UnivariateLaurentSeriesFunctions2" 0 219009) ("UnivariateLaurentSeriesConstructorCategory&" 0 NIL) ("UnivariateLaurentSeriesConstructor" 0 218981) ("UnivariateLaurentSeries" 0 218881) ("UnivariateFormalPowerSeriesFunctions" 0 218871) ("UnivariateFormalPowerSeries" 0 218783) ("UniqueFactorizationDomain&" 0 NIL) ("UnaryRecursiveAggregate&" 0 NIL) ("TwoFactorize" 0 218730) ("TwoDimensionalViewport" 0 218557) ("TwoDimensionalPlotClipping" 0 218511) ("TwoDimensionalArrayCategory&" 0 NIL) ("TwoDimensionalArray" 0 218495) ("TubePlotTools" 0 218454) ("TubePlot" 0 218369) ("TrigonometricManipulations" 0 218184) ("TrigonometricFunctionCategory&" 0 NIL) ("TriangularSetCategory&" 0 NIL) ("TriangularMatrixOperations" 0 217994) ("Tree" 0 217952) ("TranscendentalRischDESystem" 0 217924) ("TranscendentalRischDE" 0 217880) ("TranscendentalManipulations" 0 217764) ("TranscendentalIntegration" 0 217696) ("TranscendentalHermiteIntegration" 0 217666) ("TranscendentalFunctionCategory&" 0 NIL) ("TransSolvePackageService" 0 217644) ("TopLevelDrawFunctionsForCompiledFunctions" 0 217618) ("TopLevelDrawFunctions" 0 217606) ("ToolsForSign" 0 217499) ("ThreeSpace" 0 217247) ("ThreeDimensionalViewport" 0 217120) ("ThreeDimensionalMatrix" 0 217077) ("TheSymbolTable" 0 217027) ("TextFile" 0 216986) ("TexFormat" 0 216971) ("TemplateUtilities" 0 216951) ("TaylorSolve" 0 216931) ("TaylorSeries" 0 216904) ("TangentExpansions" 0 216865) ("TabulatedComputationPackage" 0 216729) ("Tableau" 0 216709) ("TableAggregate&" 0 NIL) ("Table" 0 216109) ("SystemSolvePackage" 0 216004) ("SystemODESolver" 0 215982) ("SymmetricPolynomial" 0 215936) ("SymmetricGroupCombinatoricFunctions" 0 215887) ("SymmetricFunctions" 0 215865) ("SymbolTable" 0 215586) ("Symbol" 0 207513) ("Switch" 0 207450) ("SupFractionFactorizer" 0 207435) ("SuchThat" 0 207355) ("SubSpaceComponentProperty" 0 207261) ("SubSpace" 0 207235) ("SubResultantPackage" 0 207173) ("StringAggregate&" 0 NIL) ("String" 0 196029) ("StreamTranscendentalFunctionsNonCommutative" 0 195993) ("StreamTranscendentalFunctions" 0 195780) ("StreamTaylorSeriesOperations" 0 195351) ("StreamInfiniteProduct" 0 195285) ("StreamFunctions3" 0 195092) ("StreamFunctions2" 0 194589) ("StreamFunctions1" 0 194551) ("StreamAggregate&" 0 NIL) ("Stream" 0 192703) ("StorageEfficientMatrixOperations" 0 192692) ("Stack" 0 192654) ("SquareMatrixCategory&" 0 NIL) ("SquareMatrix" 0 192521) ("SquareFreeRegularTriangularSetGcdPackage" 0 192394) ("SquareFreeRegularTriangularSet" 0 192297) ("SquareFreeRegularSetDecompositionPackage" 0 192262) ("SquareFreeQuasiComponentPackage" 0 192085) ("SplittingTree" 0 192058) ("SplittingNode" 0 192015) ("SparseUnivariateTaylorSeries" 0 191949) ("SparseUnivariateSkewPolynomial" 0 191883) ("SparseUnivariatePolynomialFunctions2" 0 191369) ("SparseUnivariatePolynomialExpressions" 0 191335) ("SparseUnivariatePolynomial" 0 184696) ("SparseUnivariateLaurentSeries" 0 184662) ("SparseMultivariateTaylorSeries" 0 184645) ("SparseMultivariatePolynomial" 0 183413) ("SortedCache" 0 183384) ("SmithNormalForm" 0 183352) ("SingletonAsOrderedSet" 0 182655) ("SingleInteger" 0 175089) ("SimpleAlgebraicExtension" 0 174958) ("SetCategory&" 0 NIL) ("SetAggregate&" 0 NIL) ("Set" 0 174550) ("SequentialDifferentialVariable" 0 174513) ("SemiGroup&" 0 NIL) ("SegmentFunctions2" 0 174398) ("SegmentBindingFunctions2" 0 174356) ("SegmentBinding" 0 173989) ("Segment" 0 172925) ("ScriptFormulaFormat" 0 172900) ("SExpressionOf" 0 172884) ("SExpression" 0 172655) ("RoutinesTable" 0 172064) ("RootsFindingPackage" 0 171928) ("Ring&" 0 NIL) ("RightOpenIntervalRootCharacterization" 0 171912) ("RewriteRule" 0 171867) ("RetractableTo&" 0 NIL) ("RetractSolvePackage" 0 171841) ("Result" 0 170770) ("RepeatedSquaring" 0 170529) ("RepeatedDoubling" 0 170346) ("RegularTriangularSetGcdPackage" 0 170288) ("RegularTriangularSetCategory&" 0 NIL) ("RegularTriangularSet" 0 170271) ("RegularSetDecompositionPackage" 0 170246) ("RegularChain" 0 170191) ("Reference" 0 169808) ("ReductionOfOrder" 0 169775) ("ReduceLODE" 0 169753) ("RecursivePolynomialCategory&" 0 NIL) ("RecursiveAggregate&" 0 NIL) ("RecurrenceOperator" 0 169743) ("RectangularMatrixCategory&" 0 NIL) ("RealZeroPackage" 0 169663) ("RealSolvePackage" 0 169635) ("RealRootCharacterizationCategory&" 0 NIL) ("RealPolynomialUtilitiesPackage" 0 169593) ("RealNumberSystem&" 0 NIL) ("RealClosure" 0 169561) ("RealClosedField&" 0 NIL) ("RationalRicDE" 0 169471) ("RationalLODE" 0 169332) ("RationalIntegration" 0 169211) ("RationalFunctionSign" 0 169153) ("RationalFunctionIntegration" 0 169119) ("RationalFunctionFactor" 0 169086) ("RationalFunction" 0 169038) ("RationalFactorize" 0 168808) ("RandomNumberSource" 0 168728) ("RadixExpansion" 0 168666) ("RadicalSolvePackage" 0 168644) ("RadicalCategory&" 0 NIL) ("QuotientFieldCategoryFunctions2" 0 168621) ("QuotientFieldCategory&" 0 NIL) ("Queue" 0 168609) ("QueryEquation" 0 168596) ("QuaternionCategory&" 0 NIL) ("Quaternion" 0 168583) ("QuasiComponentPackage" 0 168469) ("QuasiAlgebraicSet" 0 168446) ("QuadraticForm" 0 168426) ("PushVariables" 0 168399) ("PureAlgebraicIntegration" 0 168322) ("PseudoRemainderSequence" 0 168237) ("PseudoLinearNormalForm" 0 168217) ("PseudoAlgebraicClosureOfRationalNumber" 0 168100) ("PseudoAlgebraicClosureOfFiniteField" 0 167829) ("ProjectiveSpace" 0 167809) ("ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField" 0 167696) ("ProjectivePlane" 0 167591) ("ProjectiveAlgebraicSetPackage" 0 167498) ("Product" 0 167457) ("PrintPackage" 0 167431) ("PrimitiveRatRicDE" 0 167413) ("PrimitiveRatDE" 0 167360) ("PrimitiveElement" 0 167326) ("PrimitiveArray" 0 166597) ("PrimeField" 0 166504) ("PrecomputedAssociatedEquations" 0 166480) ("PowerSeriesLimitPackage" 0 166388) ("PowerSeriesCategory&" 0 NIL) ("PositiveInteger" 0 156711) ("PolynomialSquareFree" 0 156687) ("PolynomialSolveByFormulas" 0 156663) ("PolynomialSetUtilitiesPackage" 0 156266) ("PolynomialSetCategory&" 0 NIL) ("PolynomialRoots" 0 156163) ("PolynomialRing" 0 155995) ("PolynomialPackageForCurve" 0 155898) ("PolynomialNumberTheoryFunctions" 0 155844) ("PolynomialInterpolationAlgorithms" 0 155816) ("PolynomialIdeals" 0 155765) ("PolynomialGcdPackage" 0 155689) ("PolynomialFunctions2" 0 155493) ("PolynomialFactorizationExplicit&" 0 NIL) ("PolynomialFactorizationByRecursionUnivariate" 0 155430) ("PolynomialFactorizationByRecursion" 0 155406) ("PolynomialDecomposition" 0 155376) ("PolynomialCategoryQuotientFunctions" 0 154977) ("PolynomialCategoryLifting" 0 154342) ("PolynomialCategory&" 0 NIL) ("Polynomial" 0 151972) ("PolyGroebner" 0 151926) ("PolToPol" 0 151889) ("PointsOfFiniteOrderTools" 0 151835) ("PointsOfFiniteOrder" 0 151812) ("PointPackage" 0 151671) ("Point" 0 151235) ("PoincareBirkhoffWittLyndonBasis" 0 151198) ("PlotTools" 0 151183) ("Plot3D" 0 151116) ("Plot" 0 150979) ("Plcs" 0 150920) ("PlaneAlgebraicCurvePlot" 0 150876) ("PlacesOverPseudoAlgebraicClosureOfFiniteField" 0 150824) ("Places" 0 150787) ("PiCoercions" 0 150765) ("Pi" 0 150729) ("PermutationGroup" 0 150700) ("Permutation" 0 150605) ("PatternMatchTools" 0 150542) ("PatternMatchSymbol" 0 150531) ("PatternMatchResultFunctions2" 0 150484) ("PatternMatchResult" 0 149066) ("PatternMatchQuotientFieldCategory" 0 149039) ("PatternMatchPushDown" 0 148918) ("PatternMatchPolynomialCategory" 0 148881) ("PatternMatchListResult" 0 148836) ("PatternMatchListAggregate" 0 148819) ("PatternMatchKernel" 0 148776) ("PatternMatchIntegration" 0 148657) ("PatternMatchIntegerNumberSystem" 0 148632) ("PatternMatchFunctionSpace" 0 148617) ("PatternFunctions1" 0 148547) ("Pattern" 0 147014) ("PartitionsAndPermutations" 0 146914) ("Partition" 0 146797) ("PartialDifferentialRing&" 0 NIL) ("ParametrizationPackage" 0 146678) ("ParametricSurface" 0 146578) ("ParametricSpaceCurve" 0 146475) ("ParametricPlaneCurve" 0 146372) ("ParadoxicalCombinatorsForStreams" 0 146171) ("Palette" 0 145969) ("PackageForPoly" 0 145662) ("PAdicRationalConstructor" 0 145620) ("PAdicInteger" 0 145602) ("OutputPackage" 0 145232) ("OutputForm" 0 135530) ("OrderlyDifferentialVariable" 0 135424) ("OrderlyDifferentialPolynomial" 0 135391) ("OrderedVariableList" 0 134838) ("OrderedSet&" 0 NIL) ("OrderedRing&" 0 NIL) ("OrderedFreeMonoid" 0 134686) ("OrderedCompletionFunctions2" 0 134615) ("OrderedCompletion" 0 133832) ("OrdSetInts" 0 133798) ("OpenMathPackage" 0 133772) ("OpenMathErrorKind" 0 133754) ("OpenMathEncoding" 0 133576) ("OpenMathDevice" 0 133394) ("OpenMathConnection" 0 133368) ("OnePointCompletionFunctions2" 0 133335) ("OnePointCompletion" 0 132522) ("OneDimensionalArrayAggregate&" 0 NIL) ("OneDimensionalArray" 0 132453) ("OctonionCategory&" 0 NIL) ("ODETools" 0 132405) ("ODEIntensityFunctionsTable" 0 132342) ("ODEIntegration" 0 132233) ("NumericalPDEProblem" 0 132190) ("NumericalOptimizationProblem" 0 132134) ("NumericalODEProblem" 0 132090) ("NumericalIntegrationProblem" 0 132027) ("NumericTubePlot" 0 131981) ("NumericRealEigenPackage" 0 131960) ("Numeric" 0 131921) ("NumberTheoreticPolynomialFunctions" 0 131891) ("NumberFormats" 0 131861) ("NormalizationPackage" 0 131688) ("NoneFunctions1" 0 131653) ("None" 0 131352) ("NonNegativeInteger" 0 115695) ("NonLinearSolvePackage" 0 115677) ("NonLinearFirstOrderODESolver" 0 115645) ("NonAssociativeRng&" 0 NIL) ("NonAssociativeRing&" 0 NIL) ("NonAssociativeAlgebra&" 0 NIL) ("NewtonPolygon" 0 115627) ("NewtonInterpolation" 0 115617) ("NewSparseUnivariatePolynomialFunctions2" 0 115581) ("NewSparseUnivariatePolynomial" 0 115503) ("NewSparseMultivariatePolynomial" 0 115391) ("NeitherSparseOrDensePowerSeries" 0 115304) ("NagPartialDifferentialEquationsPackage" 0 115285) ("NagOrdinaryDifferentialEquationsPackage" 0 115215) ("NagOptimisationPackage" 0 115059) ("NagIntegrationPackage" 0 114887) ("NagEigenPackage" 0 114866) ("NPCoef" 0 114842) ("NAGLinkSupportPackage" 0 114430) ("MyUnivariatePolynomial" 0 114413) ("MyExpression" 0 114383) ("MultivariateSquareFree" 0 114319) ("MultivariateLifting" 0 114231) ("MultivariateFactorize" 0 113898) ("Multiset" 0 113839) ("MultipleMap" 0 113764) ("MultiVariableCalculusFunctions" 0 113670) ("MultFiniteFactorize" 0 113596) ("MoreSystemCommands" 0 113517) ("MonomialExtensionTools" 0 113398) ("MonoidRing" 0 113373) ("Monoid&" 0 NIL) ("MonogenicAlgebra&" 0 NIL) ("MonadWithUnit&" 0 NIL) ("Monad&" 0 NIL) ("MoebiusTransform" 0 113351) ("ModuleOperator" 0 113338) ("ModuleMonomial" 0 113310) ("Module&" 0 NIL) ("ModularRing" 0 113270) ("ModularHermitianRowReduction" 0 113065) ("ModularDistinctDegreeFactorizer" 0 113008) ("ModMonic" 0 112898) ("MeshCreationRoutinesForThreeDimensions" 0 112852) ("MergeThing" 0 112839) ("MatrixLinearAlgebraFunctions" 0 112812) ("MatrixCommonDenominator" 0 112702) ("MatrixCategoryFunctions2" 0 112321) ("MatrixCategory&" 0 NIL) ("Matrix" 0 107437) ("MappingPackageInternalHacks3" 0 107417) ("MappingPackageInternalHacks2" 0 107397) ("MappingPackageInternalHacks1" 0 107377) ("MappingPackage1" 0 107283) ("MakeUnaryCompiledFunction" 0 107223) ("MakeFunction" 0 107164) ("MakeFloatCompiledFunction" 0 107100) ("MakeBinaryCompiledFunction" 0 107052) ("Magma" 0 107021) ("MachineInteger" 0 106987) ("MachineFloat" 0 106918) ("MRationalFactorize" 0 106754) ("MPolyCatRationalFunctionFactorizer" 0 106644) ("MPolyCatPolyFactorizer" 0 106607) ("MPolyCatFunctions3" 0 106594) ("MPolyCatFunctions2" 0 106507) ("LyndonWord" 0 106420) ("Logic&" 0 NIL) ("Localize" 0 106403) ("LocalParametrizationOfSimplePointPackage" 0 106310) ("LocalAlgebra" 0 106297) ("ListToMap" 0 106246) ("ListMultiDictionary" 0 106214) ("ListMonoidOps" 0 106162) ("ListFunctions2" 0 105743) ("ListAggregate&" 0 NIL) ("List" 0 88343) ("LiouvillianFunction" 0 88302) ("LinesOpPack" 0 88237) ("LinearSystemPolynomialPackage" 0 88214) ("LinearSystemMatrixPackage" 0 87880) ("LinearSystemFromPowerSeriesPackage" 0 87852) ("LinearPolynomialEquationByFractions" 0 87731) ("LinearOrdinaryDifferentialOperatorsOps" 0 87692) ("LinearOrdinaryDifferentialOperatorFactorizer" 0 87659) ("LinearOrdinaryDifferentialOperatorCategory&" 0 NIL) ("LinearOrdinaryDifferentialOperator2" 0 87626) ("LinearOrdinaryDifferentialOperator1" 0 87462) ("LinearOrdinaryDifferentialOperator" 0 87384) ("LinearDependence" 0 87356) ("LinearAggregate&" 0 NIL) ("LinGroebnerPackage" 0 87319) ("LiePolynomial" 0 87282) ("LieAlgebra&" 0 NIL) ("LexTriangularPackage" 0 87250) ("LeftAlgebra&" 0 NIL) ("LeadingCoefDetermination" 0 87210) ("LazyStreamAggregate&" 0 NIL) ("LaurentPolynomial" 0 87139) ("Kovacic" 0 87106) ("KeyedDictionary&" 0 NIL) ("KeyedAccessFile" 0 87094) ("KernelFunctions2" 0 87079) ("Kernel" 0 85230) ("IrredPolyOverFiniteField" 0 85190) ("Interval" 0 85143) ("IntersectionDivisorPackage" 0 85099) ("InterpolateFormsPackage" 0 85055) ("InternalRationalUnivariateRepresentationPackage" 0 84981) ("InternalPrintPackage" 0 84873) ("InterfaceGroebnerPackage" 0 84826) ("IntegrationTools" 0 84517) ("IntegrationResultToFunction" 0 84422) ("IntegrationResultRFToFunction" 0 84382) ("IntegrationResultFunctions2" 0 84183) ("IntegrationResult" 0 83811) ("IntegrationFunctionsTable" 0 83756) ("IntegralDomain&" 0 NIL) ("IntegralBasisTools" 0 83627) ("IntegralBasisPolynomialTools" 0 83587) ("IntegerSolveLinearPolynomialEquation" 0 83575) ("IntegerRoots" 0 83390) ("IntegerRetractions" 0 83358) ("IntegerPrimesPackage" 0 82926) ("IntegerNumberTheoryFunctions" 0 82825) ("IntegerNumberSystem&" 0 NIL) ("IntegerMod" 0 82805) ("IntegerLinearDependence" 0 82766) ("IntegerFactorizationPackage" 0 82642) ("IntegerCombinatoricFunctions" 0 82426) ("IntegerBits" 0 82395) ("Integer" 0 66785) ("InputFormFunctions1" 0 66766) ("InputForm" 0 64540) ("InnerTrigonometricManipulations" 0 64412) ("InnerTaylorSeries" 0 64322) ("InnerTable" 0 64312) ("InnerSparseUnivariatePowerSeries" 0 64215) ("InnerPrimeField" 0 64181) ("InnerPolySum" 0 64157) ("InnerPolySign" 0 64074) ("InnerPAdicInteger" 0 64034) ("InnerNumericFloatSolvePackage" 0 63937) ("InnerNumericEigenPackage" 0 63880) ("InnerNormalBasisFieldFunctions" 0 63832) ("InnerMultFact" 0 63786) ("InnerMatrixQuotientFieldFunctions" 0 63753) ("InnerMatrixLinearAlgebraFunctions" 0 63684) ("InnerIndexedTwoDimensionalArray" 0 63606) ("InnerFreeAbelianMonoid" 0 63565) ("InnerEvalable&" 0 NIL) ("InnerCommonDenominator" 0 63319) ("InnerAlgebraicNumber" 0 63299) ("InnerAlgFactor" 0 63230) ("InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField" 0 63178) ("InfinitlyClosePoint" 0 63104) ("InfiniteTuple" 0 63050) ("InfClsPt" 0 63013) ("IndexedVector" 0 62986) ("IndexedString" 0 62975) ("IndexedOneDimensionalArray" 0 62906) ("IndexedList" 0 62897) ("IndexedFlexibleArray" 0 62810) ("IndexedExponents" 0 62534) ("IndexedDirectProductOrderedAbelianMonoidSup" 0 62513) ("IndexedDirectProductOrderedAbelianMonoid" 0 62465) ("IndexedDirectProductObject" 0 62427) ("IndexedDirectProductAbelianMonoid" 0 62347) ("IndexedDirectProductAbelianGroup" 0 62332) ("IndexedBits" 0 62323) ("IndexedAggregate&" 0 NIL) ("IdealDecompositionPackage" 0 62300) ("HyperbolicFunctionCategory&" 0 NIL) ("HomogeneousDistributedMultivariatePolynomial" 0 62231) ("HomogeneousDirectProduct" 0 62150) ("HomogeneousAggregate&" 0 NIL) ("HeuGcd" 0 62138) ("HashTable" 0 62082) ("HallBasis" 0 62061) ("GuessOptionFunctions0" 0 62051) ("GuessOption" 0 62017) ("GuessFiniteFunctions" 0 62001) ("Guess" 0 61901) ("Group&" 0 NIL) ("GroebnerPackage" 0 61672) ("GroebnerInternalPackage" 0 61545) ("GrayCode" 0 61531) ("GraphicsDefaults" 0 61431) ("GraphImage" 0 61343) ("GradedModule&" 0 NIL) ("GradedAlgebra&" 0 NIL) ("GosperSummationMethod" 0 61300) ("GenusZeroIntegration" 0 61271) ("GeneralizedMultivariateFactorize" 0 61199) ("GeneralTriangularSet" 0 61140) ("GeneralSparseTable" 0 61124) ("GeneralPolynomialSet" 0 60933) ("GeneralPolynomialGcdPackage" 0 60909) ("GeneralPackageForAlgebraicFunctionField" 0 60822) ("GeneralHenselPackage" 0 60736) ("GeneralDistributedMultivariatePolynomial" 0 60651) ("GenUFactorize" 0 60599) ("GenExEuclid" 0 60425) ("GcdDomain&" 0 NIL) ("GaloisGroupUtilities" 0 60387) ("GaloisGroupPolynomialUtilities" 0 60361) ("GaloisGroupFactorizer" 0 60313) ("GaloisGroupFactorizationUtilities" 0 60270) ("FunctionalSpecialFunction" 0 60255) ("FunctionSpaceUnivariatePolynomialFactor" 0 60156) ("FunctionSpaceToUnivariatePowerSeries" 0 60116) ("FunctionSpacePrimitiveElement" 0 60039) ("FunctionSpaceIntegration" 0 59801) ("FunctionSpaceFunctions2" 0 59717) ("FunctionSpaceComplexIntegration" 0 59688) ("FunctionSpaceAttachPredicates" 0 59641) ("FunctionSpaceAssertions" 0 59574) ("FunctionSpace&" 0 NIL) ("FunctionFieldCategoryFunctions2" 0 59546) ("FunctionFieldCategory&" 0 NIL) ("FullyRetractableTo&" 0 NIL) ("FullyLinearlyExplicitRingOver&" 0 NIL) ("FullyEvalableOver&" 0 NIL) ("FreeMonoid" 0 59524) ("FreeModule1" 0 59448) ("FreeModule" 0 59343) ("FreeGroup" 0 59313) ("FreeAbelianGroup" 0 59294) ("FramedNonAssociativeAlgebra&" 0 NIL) ("FramedModule" 0 59276) ("FramedAlgebra&" 0 NIL) ("FractionalIdealFunctions2" 0 59248) ("FractionalIdeal" 0 59080) ("FractionFreeFastGaussianFractions" 0 59070) ("FractionFreeFastGaussian" 0 59024) ("Fraction" 0 51206) ("FourierComponent" 0 51188) ("FortranType" 0 50898) ("FortranScalarType" 0 50618) ("FortranPackage" 0 50408) ("FortranOutputStackPackage" 0 50163) ("FortranExpression" 0 49998) ("FortranCode" 0 49731) ("FloatingRealPackage" 0 49710) ("FloatingPointSystem&" 0 NIL) ("Float" 0 47856) ("FlexibleArray" 0 47831) ("FiniteSetAggregate&" 0 NIL) ("FiniteRankNonAssociativeAlgebra&" 0 NIL) ("FiniteRankAlgebra&" 0 NIL) ("FiniteLinearAggregateSort" 0 47797) ("FiniteLinearAggregateFunctions2" 0 47618) ("FiniteLinearAggregate&" 0 NIL) ("FiniteFieldSquareFreeDecomposition" 0 47564) ("FiniteFieldSolveLinearPolynomialEquation" 0 47533) ("FiniteFieldPolynomialPackage" 0 47331) ("FiniteFieldNormalBasisExtensionByPolynomial" 0 47270) ("FiniteFieldFunctions" 0 47117) ("FiniteFieldFactorizationWithSizeParseBySideEffect" 0 47055) ("FiniteFieldExtensionByPolynomial" 0 46970) ("FiniteFieldExtension" 0 46949) ("FiniteFieldCyclicGroupExtensionByPolynomial" 0 46888) ("FiniteFieldCategory&" 0 NIL) ("FiniteDivisorCategory&" 0 NIL) ("FiniteDivisor" 0 46752) ("FiniteAlgebraicExtensionField&" 0 NIL) ("FiniteAbelianMonoidRingFunctions2" 0 46714) ("FiniteAbelianMonoidRing&" 0 NIL) ("FileName" 0 46333) ("File" 0 46279) ("FieldOfPrimeCharacteristic&" 0 NIL) ("Field&" 0 NIL) ("FactorisationOverPseudoAlgebraicClosureOfRationalNumber" 0 46170) ("FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber" 0 46119) ("FactoringUtilities" 0 46031) ("FactoredFunctions2" 0 45836) ("FactoredFunctions" 0 45767) ("FactoredFunctionUtilities" 0 45652) ("Factored" 0 41197) ("ExtensionField&" 0 NIL) ("ExtensibleLinearAggregate&" 0 NIL) ("ExtAlgBasis" 0 41168) ("ExpressionSpaceFunctions2" 0 41070) ("ExpressionSpace&" 0 NIL) ("ExpressionSolve" 0 41047) ("ExpressionFunctions2" 0 40670) ("Expression" 0 38859) ("ExponentialOfUnivariatePuiseuxSeries" 0 38744) ("ExponentialExpansion" 0 38704) ("ExpertSystemToolsPackage2" 0 38666) ("ExpertSystemToolsPackage1" 0 38645) ("ExpertSystemToolsPackage" 0 38154) ("ExpertSystemContinuityPackage" 0 38116) ("Exit" 0 37846) ("Evalable&" 0 NIL) ("EuclideanModularRing" 0 37826) ("EuclideanGroebnerBasisPackage" 0 37796) ("EuclideanDomain&" 0 NIL) ("ErrorFunctions" 0 37588) ("Equation" 0 34284) ("EltableAggregate&" 0 NIL) ("ElementaryRischDESystem" 0 34258) ("ElementaryRischDE" 0 34232) ("ElementaryIntegration" 0 34169) ("ElementaryFunctionsUnivariatePuiseuxSeries" 0 34129) ("ElementaryFunctionsUnivariateLaurentSeries" 0 34058) ("ElementaryFunctionStructurePackage" 0 33728) ("ElementaryFunctionSign" 0 33366) ("ElementaryFunctionODESolver" 0 33333) ("ElementaryFunctionCategory&" 0 NIL) ("ElementaryFunction" 0 33318) ("EigenPackage" 0 33294) ("DrawOptionFunctions1" 0 33269) ("DrawOptionFunctions0" 0 33065) ("DrawOption" 0 32893) ("DoubleResultantPackage" 0 32870) ("DoubleFloatVector" 0 32848) ("DoubleFloatSpecialFunctions" 0 32832) ("DoubleFloat" 0 30700) ("Divisor" 0 30477) ("DivisionRing&" 0 NIL) ("DistributedMultivariatePolynomial" 0 30072) ("DistinctDegreeFactorize" 0 29753) ("DisplayPackage" 0 29727) ("DiscreteLogarithmPackage" 0 29702) ("DirectProductCategory&" 0 NIL) ("DirectProduct" 0 29140) ("DifferentialVariableCategory&" 0 NIL) ("DifferentialSparseMultivariatePolynomial" 0 29030) ("DifferentialRing&" 0 NIL) ("DifferentialPolynomialCategory&" 0 NIL) ("DifferentialExtension&" 0 NIL) ("DictionaryOperations&" 0 NIL) ("Dictionary&" 0 NIL) ("DesingTreePackage" 0 28957) ("DesingTree" 0 28870) ("DegreeReductionPackage" 0 28846) ("DefiniteIntegrationTools" 0 28766) ("Database" 0 28746) ("DataList" 0 28733) ("CyclotomicPolynomialPackage" 0 28685) ("CyclicStreamTools" 0 28651) ("CoordinateSystems" 0 28609) ("ContinuedFraction" 0 28494) ("ConstantLODE" 0 28461) ("ComplexRootPackage" 0 28402) ("ComplexPatternMatch" 0 28381) ("ComplexPattern" 0 28360) ("ComplexIntegerSolveLinearPolynomialEquation" 0 28339) ("ComplexFunctions2" 0 28307) ("ComplexFactorization" 0 28239) ("ComplexDoubleFloatVector" 0 28210) ("ComplexCategory&" 0 NIL) ("Complex" 0 27624) ("CommuteUnivariatePolynomialCategory" 0 27477) ("Commutator" 0 27456) ("CommonOperators" 0 27303) ("CommonDenominator" 0 27169) ("CombinatorialFunction" 0 27154) ("Color" 0 27055) ("Collection&" 0 NIL) ("CoerceVectorMatrixPackage" 0 26991) ("ChineseRemainderToolsForIntegralBases" 0 26951) ("CharacteristicPolynomialInMonogenicalAlgebra" 0 26929) ("CharacterClass" 0 26856) ("Character" 0 26534) ("ChangeOfVariable" 0 26434) ("CartesianTensor" 0 26404) ("CardinalNumber" 0 25687) ("BrillhartTests" 0 25661) ("BoundIntegerRoots" 0 25627) ("Boolean" 0 7548) ("BlowUpPackage" 0 7526) ("Bits" 0 7499) ("BitAggregate&" 0 NIL) ("BinaryTreeCategory&" 0 NIL) ("BinaryTree" 0 7438) ("BinaryRecursiveAggregate&" 0 NIL) ("BasicType&" 0 NIL) ("BasicOperatorFunctions1" 0 7245) ("BasicOperator" 0 5838) ("BasicFunctions" 0 5804) ("BalancedPAdicInteger" 0 5778) ("BalancedFactorisation" 0 5739) ("BagAggregate&" 0 NIL) ("Automorphism" 0 5559) ("AttributeButtons" 0 5285) ("AssociationList" 0 5133) ("AssociatedLieAlgebra" 0 5113) ("Asp9" 0 5018) ("Asp80" 0 4974) ("Asp8" 0 4879) ("Asp78" 0 4835) ("Asp77" 0 4791) ("Asp74" 0 4731) ("Asp73" 0 4671) ("Asp7" 0 4559) ("Asp6" 0 4533) ("Asp55" 0 4489) ("Asp50" 0 4445) ("Asp49" 0 4384) ("Asp42" 0 4340) ("Asp41" 0 4296) ("Asp4" 0 4236) ("Asp35" 0 4210) ("Asp34" 0 4174) ("Asp33" 0 4130) ("Asp31" 0 4069) ("Asp30" 0 4033) ("Asp29" 0 4013) ("Asp28" 0 3959) ("Asp27" 0 3939) ("Asp24" 0 3895) ("Asp20" 0 3851) ("Asp19" 0 3807) ("Asp12" 0 3763) ("Asp10" 0 3719) ("Asp1" 0 3533) ("ArcTrigonometricFunctionCategory&" 0 NIL) ("ApplyUnivariateSkewPolynomial" 0 3493) ("ApplyRules" 0 3437) ("AnyFunctions1" 0 2370) ("Any" 0 1020) ("AntiSymm" 0 1002) ("AnnaNumericalOptimizationPackage" 0 981) ("AnnaNumericalIntegrationPackage" 0 952) ("AlgebraicallyClosedFunctionSpace&" 0 NIL) ("AlgebraicallyClosedField&" 0 NIL) ("AlgebraicNumber" 0 779) ("AlgebraicManipulations" 0 493) ("AlgebraicIntegration" 0 467) ("AlgebraicHermiteIntegration" 0 444) ("AlgebraicFunction" 0 429) ("AlgebraGivenByStructuralConstants" 0 396) ("Algebra&" 0 NIL) ("AlgFactor" 0 289) ("Aggregate&" 0 NIL) ("AffineSpace" 0 273) ("AffinePlane" 0 88) ("AffineAlgebraicSetComputeWithResultant" 0 54) ("AffineAlgebraicSetComputeWithGroebnerBasis" 0 20) ("AbelianSemiGroup&" 0 NIL) ("AbelianMonoidRing&" 0 NIL) ("AbelianMonoid&" 0 NIL) ("AbelianGroup&" 0 NIL))
\ No newline at end of file
